#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 17880
#define LARGE_STATE_COUNT 2351
#define SYMBOL_COUNT 327
#define ALIAS_COUNT 4
#define TOKEN_COUNT 109
#define EXTERNAL_TOKEN_COUNT 15
#define FIELD_COUNT 32
#define MAX_ALIAS_SEQUENCE_LENGTH 8
#define PRODUCTION_ID_COUNT 189

enum ts_symbol_identifiers {
  sym__alpha_identifier = 1,
  anon_sym_enum = 2,
  anon_sym_COLON = 3,
  anon_sym_LBRACE = 4,
  anon_sym_RBRACE = 5,
  anon_sym_case = 6,
  anon_sym_COMMA = 7,
  anon_sym_package = 8,
  anon_sym_DOT = 9,
  anon_sym_object = 10,
  anon_sym_import = 11,
  anon_sym_export = 12,
  anon_sym_STAR = 13,
  anon_sym__ = 14,
  anon_sym_given = 15,
  anon_sym_EQ_GT = 16,
  anon_sym_as = 17,
  anon_sym_class = 18,
  anon_sym_trait = 19,
  anon_sym_LBRACK = 20,
  anon_sym_RBRACK = 21,
  anon_sym_PLUS = 22,
  anon_sym_DASH = 23,
  anon_sym_LT_COLON = 24,
  anon_sym_GT_COLON = 25,
  anon_sym_LT_PERCENT = 26,
  anon_sym_end = 27,
  anon_sym_if = 28,
  anon_sym_while = 29,
  anon_sym_for = 30,
  anon_sym_match = 31,
  anon_sym_try = 32,
  anon_sym_new = 33,
  anon_sym_this = 34,
  anon_sym_extension = 35,
  anon_sym_val = 36,
  anon_sym_AT = 37,
  anon_sym_EQ = 38,
  anon_sym_var = 39,
  anon_sym_type = 40,
  anon_sym_def = 41,
  anon_sym_opaque = 42,
  anon_sym_with = 43,
  anon_sym_abstract = 44,
  anon_sym_final = 45,
  anon_sym_sealed = 46,
  anon_sym_implicit = 47,
  anon_sym_lazy = 48,
  anon_sym_override = 49,
  anon_sym_private = 50,
  anon_sym_protected = 51,
  anon_sym_inline = 52,
  anon_sym_infix = 53,
  anon_sym_open = 54,
  anon_sym_transparent = 55,
  anon_sym_extends = 56,
  anon_sym_derives = 57,
  anon_sym_LPAREN = 58,
  anon_sym_using = 59,
  anon_sym_RPAREN = 60,
  anon_sym_SEMI = 61,
  anon_sym_POUND = 62,
  anon_sym_QMARK_EQ_GT = 63,
  anon_sym_EQ_GT_GT = 64,
  anon_sym_PIPE = 65,
  anon_sym_else = 66,
  anon_sym_then = 67,
  anon_sym_catch = 68,
  anon_sym_finally = 69,
  anon_sym_macro = 70,
  anon_sym_BANG = 71,
  anon_sym_TILDE = 72,
  anon_sym_DOLLAR = 73,
  anon_sym_SQUOTE = 74,
  sym__interpolation_identifier = 75,
  sym__backquoted_id = 76,
  sym_operator_identifier = 77,
  sym_integer_literal = 78,
  sym_floating_point_literal = 79,
  anon_sym_true = 80,
  anon_sym_false = 81,
  sym_character_literal = 82,
  anon_sym_DQUOTE = 83,
  anon_sym_DQUOTE_DQUOTE_DQUOTE = 84,
  sym_null_literal = 85,
  anon_sym_return = 86,
  anon_sym_throw = 87,
  anon_sym_do = 88,
  anon_sym_yield = 89,
  anon_sym_LT_DASH = 90,
  aux_sym__shebang_token1 = 91,
  anon_sym_SLASH_SLASH = 92,
  sym__comment_text = 93,
  anon_sym_GT = 94,
  sym_using_directive_key = 95,
  sym_using_directive_value = 96,
  anon_sym_SLASH_STAR = 97,
  aux_sym_block_comment_token1 = 98,
  anon_sym_STAR_SLASH = 99,
  sym__automatic_semicolon = 100,
  sym__indent = 101,
  sym__interpolated_string_middle = 102,
  sym__interpolated_string_end = 103,
  sym__interpolated_multiline_string_middle = 104,
  sym__interpolated_multiline_string_end = 105,
  sym__outdent = 106,
  sym__simple_multiline_string = 107,
  sym__simple_string = 108,
  sym_compilation_unit = 109,
  sym__top_level_definition = 110,
  sym_enum_definition = 111,
  sym__enum_block = 112,
  sym_enum_body = 113,
  sym_enum_case_definitions = 114,
  sym_simple_enum_case = 115,
  sym_full_enum_case = 116,
  sym__full_enum_def = 117,
  sym_package_clause = 118,
  sym_package_identifier = 119,
  sym_package_object = 120,
  sym_import_declaration = 121,
  sym_export_declaration = 122,
  sym__namespace_expression = 123,
  sym_namespace_wildcard = 124,
  sym__namespace_given_by_type = 125,
  sym_namespace_selectors = 126,
  sym_arrow_renamed_identifier = 127,
  sym_as_renamed_identifier = 128,
  sym_object_definition = 129,
  sym__object_definition = 130,
  sym_class_definition = 131,
  sym__class_definition = 132,
  sym__definition_body = 133,
  sym__class_constructor = 134,
  sym_trait_definition = 135,
  sym_type_parameters = 136,
  sym__variant_type_parameter = 137,
  sym_covariant_type_parameter = 138,
  sym_contravariant_type_parameter = 139,
  sym__type_parameter = 140,
  sym_upper_bound = 141,
  sym_lower_bound = 142,
  sym_view_bound = 143,
  sym_context_bound = 144,
  sym_template_body = 145,
  sym__indented_template_body = 146,
  sym__braced_template_body = 147,
  sym__braced_template_body1 = 148,
  sym__braced_template_body2 = 149,
  sym_with_template_body = 150,
  sym__extension_template_body = 151,
  sym__end_marker = 152,
  sym_self_type = 153,
  sym__self_type_ascription = 154,
  sym_annotation = 155,
  sym_val_definition = 156,
  sym_val_declaration = 157,
  sym__start_val = 158,
  sym_var_declaration = 159,
  sym_var_definition = 160,
  sym__start_var = 161,
  sym_type_definition = 162,
  sym__type_constructor = 163,
  sym_function_definition = 164,
  sym_function_declaration = 165,
  sym__function_declaration = 166,
  sym__function_constructor = 167,
  sym_opaque_modifier = 168,
  sym_extension_definition = 169,
  sym_given_definition = 170,
  sym__given_constructor = 171,
  sym__structural_instance = 172,
  sym__constructor_application = 173,
  sym__constructor_applications = 174,
  sym_modifiers = 175,
  sym_access_modifier = 176,
  sym_access_qualifier = 177,
  sym_inline_modifier = 178,
  sym_infix_modifier = 179,
  sym_open_modifier = 180,
  sym_transparent_modifier = 181,
  sym_extends_clause = 182,
  sym_derives_clause = 183,
  sym_class_parameters = 184,
  sym_parameters = 185,
  sym__using_parameters_clause = 186,
  sym_class_parameter = 187,
  sym_parameter = 188,
  sym__block = 189,
  sym__indentable_expression = 190,
  sym_block = 191,
  sym_indented_block = 192,
  sym_indented_cases = 193,
  sym__indented_type_cases = 194,
  sym__type = 195,
  sym__annotated_type = 196,
  sym_annotated_type = 197,
  sym__simple_type = 198,
  sym_compound_type = 199,
  sym__structural_type = 200,
  sym__refinement = 201,
  sym__infix_type_choice = 202,
  sym_infix_type = 203,
  sym_tuple_type = 204,
  sym_singleton_type = 205,
  sym_stable_type_identifier = 206,
  sym_stable_identifier = 207,
  sym_generic_type = 208,
  sym_projected_type = 209,
  sym_match_type = 210,
  sym_type_case_clause = 211,
  sym_function_type = 212,
  sym__arrow_then_type = 213,
  sym_parameter_types = 214,
  sym_lazy_parameter_type = 215,
  sym_repeated_parameter_type = 216,
  sym__type_identifier = 217,
  sym_type_lambda = 218,
  sym_case_class_pattern = 219,
  sym_infix_pattern = 220,
  sym_capture_pattern = 221,
  sym_repeat_pattern = 222,
  sym_typed_pattern = 223,
  sym_given_pattern = 224,
  sym_alternative_pattern = 225,
  sym_tuple_pattern = 226,
  sym_expression = 227,
  sym__simple_expression = 228,
  sym_lambda_expression = 229,
  sym_if_expression = 230,
  sym__if_condition = 231,
  sym_match_expression = 232,
  sym_try_expression = 233,
  sym_catch_clause = 234,
  sym__expr_case_clause = 235,
  sym_finally_clause = 236,
  sym_binding = 237,
  sym_bindings = 238,
  sym_case_block = 239,
  sym_case_clause = 240,
  sym__case_pattern = 241,
  sym_guard = 242,
  sym_assignment_expression = 243,
  sym_generic_function = 244,
  sym_call_expression = 245,
  sym_colon_argument = 246,
  sym_field_expression = 247,
  sym_instance_expression = 248,
  sym_ascription_expression = 249,
  sym_infix_expression = 250,
  sym_postfix_expression = 251,
  sym__postfix_expression_choice = 252,
  sym_macro_body = 253,
  sym_prefix_expression = 254,
  sym_tuple_expression = 255,
  sym_parenthesized_expression = 256,
  sym_type_arguments = 257,
  sym_arguments = 258,
  sym__exprs_in_parens = 259,
  sym_splice_expression = 260,
  sym_quote_expression = 261,
  sym_identifier = 262,
  sym__soft_identifier = 263,
  sym_identifiers = 264,
  sym_wildcard = 265,
  sym__non_null_literal = 266,
  sym_literal_type = 267,
  sym_boolean_literal = 268,
  sym_interpolated_string_expression = 269,
  sym__interpolated_string_start = 270,
  sym__interpolated_multiline_string_start = 271,
  sym__dollar_escape = 272,
  sym__aliased_interpolation_identifier = 273,
  sym_interpolation = 274,
  sym_interpolated_string = 275,
  sym_string = 276,
  sym_unit = 277,
  sym_return_expression = 278,
  sym_throw_expression = 279,
  sym_while_expression = 280,
  sym_do_while_expression = 281,
  sym_for_expression = 282,
  sym_enumerators = 283,
  sym_enumerator = 284,
  sym__shebang = 285,
  sym_comment = 286,
  sym_using_directive = 287,
  sym_block_comment = 288,
  aux_sym_compilation_unit_repeat1 = 289,
  aux_sym_enum_definition_repeat1 = 290,
  aux_sym__enum_block_repeat1 = 291,
  aux_sym_enum_case_definitions_repeat1 = 292,
  aux_sym__full_enum_def_repeat1 = 293,
  aux_sym_package_identifier_repeat1 = 294,
  aux_sym_import_declaration_repeat1 = 295,
  aux_sym_namespace_selectors_repeat1 = 296,
  aux_sym__class_constructor_repeat1 = 297,
  aux_sym_type_parameters_repeat1 = 298,
  aux_sym__type_parameter_repeat1 = 299,
  aux_sym__type_parameter_repeat2 = 300,
  aux_sym_annotation_repeat1 = 301,
  aux_sym_val_declaration_repeat1 = 302,
  aux_sym__function_constructor_repeat1 = 303,
  aux_sym_extension_definition_repeat1 = 304,
  aux_sym__constructor_applications_repeat1 = 305,
  aux_sym__constructor_applications_repeat2 = 306,
  aux_sym_modifiers_repeat1 = 307,
  aux_sym_derives_clause_repeat1 = 308,
  aux_sym_class_parameters_repeat1 = 309,
  aux_sym_parameters_repeat1 = 310,
  aux_sym__using_parameters_clause_repeat1 = 311,
  aux_sym__block_repeat1 = 312,
  aux_sym_indented_cases_repeat1 = 313,
  aux_sym__indented_type_cases_repeat1 = 314,
  aux_sym_compound_type_repeat1 = 315,
  aux_sym_tuple_type_repeat1 = 316,
  aux_sym_type_lambda_repeat1 = 317,
  aux_sym_case_class_pattern_repeat1 = 318,
  aux_sym_bindings_repeat1 = 319,
  aux_sym_tuple_expression_repeat1 = 320,
  aux_sym_identifiers_repeat1 = 321,
  aux_sym_interpolated_string_repeat1 = 322,
  aux_sym_interpolated_string_repeat2 = 323,
  aux_sym_enumerators_repeat1 = 324,
  aux_sym_enumerator_repeat1 = 325,
  aux_sym_block_comment_repeat1 = 326,
  anon_alias_sym__end_ident = 327,
  alias_sym_refinement = 328,
  alias_sym_structural_type = 329,
  alias_sym_type_identifier = 330,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym__alpha_identifier] = "_alpha_identifier",
  [anon_sym_enum] = "enum",
  [anon_sym_COLON] = ":",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_case] = "case",
  [anon_sym_COMMA] = ",",
  [anon_sym_package] = "package",
  [anon_sym_DOT] = ".",
  [anon_sym_object] = "object",
  [anon_sym_import] = "import",
  [anon_sym_export] = "export",
  [anon_sym_STAR] = "*",
  [anon_sym__] = "_",
  [anon_sym_given] = "given",
  [anon_sym_EQ_GT] = "=>",
  [anon_sym_as] = "as",
  [anon_sym_class] = "class",
  [anon_sym_trait] = "trait",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_LT_COLON] = "<:",
  [anon_sym_GT_COLON] = ">:",
  [anon_sym_LT_PERCENT] = "<%",
  [anon_sym_end] = "end",
  [anon_sym_if] = "if",
  [anon_sym_while] = "while",
  [anon_sym_for] = "for",
  [anon_sym_match] = "match",
  [anon_sym_try] = "try",
  [anon_sym_new] = "new",
  [anon_sym_this] = "this",
  [anon_sym_extension] = "extension",
  [anon_sym_val] = "val",
  [anon_sym_AT] = "@",
  [anon_sym_EQ] = "=",
  [anon_sym_var] = "var",
  [anon_sym_type] = "type",
  [anon_sym_def] = "def",
  [anon_sym_opaque] = "opaque",
  [anon_sym_with] = "with",
  [anon_sym_abstract] = "abstract",
  [anon_sym_final] = "final",
  [anon_sym_sealed] = "sealed",
  [anon_sym_implicit] = "implicit",
  [anon_sym_lazy] = "lazy",
  [anon_sym_override] = "override",
  [anon_sym_private] = "private",
  [anon_sym_protected] = "protected",
  [anon_sym_inline] = "inline",
  [anon_sym_infix] = "infix",
  [anon_sym_open] = "open",
  [anon_sym_transparent] = "transparent",
  [anon_sym_extends] = "extends",
  [anon_sym_derives] = "derives",
  [anon_sym_LPAREN] = "(",
  [anon_sym_using] = "using",
  [anon_sym_RPAREN] = ")",
  [anon_sym_SEMI] = ";",
  [anon_sym_POUND] = "#",
  [anon_sym_QMARK_EQ_GT] = "\?=>",
  [anon_sym_EQ_GT_GT] = "=>>",
  [anon_sym_PIPE] = "|",
  [anon_sym_else] = "else",
  [anon_sym_then] = "then",
  [anon_sym_catch] = "catch",
  [anon_sym_finally] = "finally",
  [anon_sym_macro] = "macro",
  [anon_sym_BANG] = "!",
  [anon_sym_TILDE] = "~",
  [anon_sym_DOLLAR] = "$",
  [anon_sym_SQUOTE] = "'",
  [sym__interpolation_identifier] = "identifier",
  [sym__backquoted_id] = "_backquoted_id",
  [sym_operator_identifier] = "operator_identifier",
  [sym_integer_literal] = "integer_literal",
  [sym_floating_point_literal] = "floating_point_literal",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [sym_character_literal] = "character_literal",
  [anon_sym_DQUOTE] = "\"",
  [anon_sym_DQUOTE_DQUOTE_DQUOTE] = "\"\"\"",
  [sym_null_literal] = "null_literal",
  [anon_sym_return] = "return",
  [anon_sym_throw] = "throw",
  [anon_sym_do] = "do",
  [anon_sym_yield] = "yield",
  [anon_sym_LT_DASH] = "<-",
  [aux_sym__shebang_token1] = "comment",
  [anon_sym_SLASH_SLASH] = "//",
  [sym__comment_text] = "_comment_text",
  [anon_sym_GT] = ">",
  [sym_using_directive_key] = "using_directive_key",
  [sym_using_directive_value] = "using_directive_value",
  [anon_sym_SLASH_STAR] = "/*",
  [aux_sym_block_comment_token1] = "block_comment_token1",
  [anon_sym_STAR_SLASH] = "*/",
  [sym__automatic_semicolon] = "_automatic_semicolon",
  [sym__indent] = "_indent",
  [sym__interpolated_string_middle] = "_interpolated_string_middle",
  [sym__interpolated_string_end] = "_interpolated_string_end",
  [sym__interpolated_multiline_string_middle] = "_interpolated_multiline_string_middle",
  [sym__interpolated_multiline_string_end] = "_interpolated_multiline_string_end",
  [sym__outdent] = "_outdent",
  [sym__simple_multiline_string] = "_simple_multiline_string",
  [sym__simple_string] = "_simple_string",
  [sym_compilation_unit] = "compilation_unit",
  [sym__top_level_definition] = "_top_level_definition",
  [sym_enum_definition] = "enum_definition",
  [sym__enum_block] = "_enum_block",
  [sym_enum_body] = "enum_body",
  [sym_enum_case_definitions] = "enum_case_definitions",
  [sym_simple_enum_case] = "simple_enum_case",
  [sym_full_enum_case] = "full_enum_case",
  [sym__full_enum_def] = "_full_enum_def",
  [sym_package_clause] = "package_clause",
  [sym_package_identifier] = "package_identifier",
  [sym_package_object] = "package_object",
  [sym_import_declaration] = "import_declaration",
  [sym_export_declaration] = "export_declaration",
  [sym__namespace_expression] = "_namespace_expression",
  [sym_namespace_wildcard] = "namespace_wildcard",
  [sym__namespace_given_by_type] = "_namespace_given_by_type",
  [sym_namespace_selectors] = "namespace_selectors",
  [sym_arrow_renamed_identifier] = "arrow_renamed_identifier",
  [sym_as_renamed_identifier] = "as_renamed_identifier",
  [sym_object_definition] = "object_definition",
  [sym__object_definition] = "_object_definition",
  [sym_class_definition] = "class_definition",
  [sym__class_definition] = "_class_definition",
  [sym__definition_body] = "_definition_body",
  [sym__class_constructor] = "_class_constructor",
  [sym_trait_definition] = "trait_definition",
  [sym_type_parameters] = "type_parameters",
  [sym__variant_type_parameter] = "_variant_type_parameter",
  [sym_covariant_type_parameter] = "covariant_type_parameter",
  [sym_contravariant_type_parameter] = "contravariant_type_parameter",
  [sym__type_parameter] = "_type_parameter",
  [sym_upper_bound] = "upper_bound",
  [sym_lower_bound] = "lower_bound",
  [sym_view_bound] = "view_bound",
  [sym_context_bound] = "context_bound",
  [sym_template_body] = "template_body",
  [sym__indented_template_body] = "_indented_template_body",
  [sym__braced_template_body] = "_braced_template_body",
  [sym__braced_template_body1] = "_braced_template_body1",
  [sym__braced_template_body2] = "_braced_template_body2",
  [sym_with_template_body] = "with_template_body",
  [sym__extension_template_body] = "_extension_template_body",
  [sym__end_marker] = "_end_marker",
  [sym_self_type] = "self_type",
  [sym__self_type_ascription] = "_self_type_ascription",
  [sym_annotation] = "annotation",
  [sym_val_definition] = "val_definition",
  [sym_val_declaration] = "val_declaration",
  [sym__start_val] = "_start_val",
  [sym_var_declaration] = "var_declaration",
  [sym_var_definition] = "var_definition",
  [sym__start_var] = "_start_var",
  [sym_type_definition] = "type_definition",
  [sym__type_constructor] = "_type_constructor",
  [sym_function_definition] = "function_definition",
  [sym_function_declaration] = "function_declaration",
  [sym__function_declaration] = "_function_declaration",
  [sym__function_constructor] = "_function_constructor",
  [sym_opaque_modifier] = "opaque_modifier",
  [sym_extension_definition] = "extension_definition",
  [sym_given_definition] = "given_definition",
  [sym__given_constructor] = "_given_constructor",
  [sym__structural_instance] = "_structural_instance",
  [sym__constructor_application] = "_constructor_application",
  [sym__constructor_applications] = "_constructor_applications",
  [sym_modifiers] = "modifiers",
  [sym_access_modifier] = "access_modifier",
  [sym_access_qualifier] = "access_qualifier",
  [sym_inline_modifier] = "inline_modifier",
  [sym_infix_modifier] = "infix_modifier",
  [sym_open_modifier] = "open_modifier",
  [sym_transparent_modifier] = "transparent_modifier",
  [sym_extends_clause] = "extends_clause",
  [sym_derives_clause] = "derives_clause",
  [sym_class_parameters] = "class_parameters",
  [sym_parameters] = "parameters",
  [sym__using_parameters_clause] = "_using_parameters_clause",
  [sym_class_parameter] = "class_parameter",
  [sym_parameter] = "parameter",
  [sym__block] = "_block",
  [sym__indentable_expression] = "_indentable_expression",
  [sym_block] = "block",
  [sym_indented_block] = "indented_block",
  [sym_indented_cases] = "indented_cases",
  [sym__indented_type_cases] = "_indented_type_cases",
  [sym__type] = "_type",
  [sym__annotated_type] = "_annotated_type",
  [sym_annotated_type] = "annotated_type",
  [sym__simple_type] = "_simple_type",
  [sym_compound_type] = "compound_type",
  [sym__structural_type] = "_structural_type",
  [sym__refinement] = "_refinement",
  [sym__infix_type_choice] = "_infix_type_choice",
  [sym_infix_type] = "infix_type",
  [sym_tuple_type] = "tuple_type",
  [sym_singleton_type] = "singleton_type",
  [sym_stable_type_identifier] = "stable_type_identifier",
  [sym_stable_identifier] = "stable_identifier",
  [sym_generic_type] = "generic_type",
  [sym_projected_type] = "projected_type",
  [sym_match_type] = "match_type",
  [sym_type_case_clause] = "type_case_clause",
  [sym_function_type] = "function_type",
  [sym__arrow_then_type] = "_arrow_then_type",
  [sym_parameter_types] = "parameter_types",
  [sym_lazy_parameter_type] = "lazy_parameter_type",
  [sym_repeated_parameter_type] = "repeated_parameter_type",
  [sym__type_identifier] = "_type_identifier",
  [sym_type_lambda] = "type_lambda",
  [sym_case_class_pattern] = "case_class_pattern",
  [sym_infix_pattern] = "infix_pattern",
  [sym_capture_pattern] = "capture_pattern",
  [sym_repeat_pattern] = "repeat_pattern",
  [sym_typed_pattern] = "typed_pattern",
  [sym_given_pattern] = "given_pattern",
  [sym_alternative_pattern] = "alternative_pattern",
  [sym_tuple_pattern] = "tuple_pattern",
  [sym_expression] = "expression",
  [sym__simple_expression] = "_simple_expression",
  [sym_lambda_expression] = "lambda_expression",
  [sym_if_expression] = "if_expression",
  [sym__if_condition] = "_if_condition",
  [sym_match_expression] = "match_expression",
  [sym_try_expression] = "try_expression",
  [sym_catch_clause] = "catch_clause",
  [sym__expr_case_clause] = "_expr_case_clause",
  [sym_finally_clause] = "finally_clause",
  [sym_binding] = "binding",
  [sym_bindings] = "bindings",
  [sym_case_block] = "case_block",
  [sym_case_clause] = "case_clause",
  [sym__case_pattern] = "_case_pattern",
  [sym_guard] = "guard",
  [sym_assignment_expression] = "assignment_expression",
  [sym_generic_function] = "generic_function",
  [sym_call_expression] = "call_expression",
  [sym_colon_argument] = "colon_argument",
  [sym_field_expression] = "field_expression",
  [sym_instance_expression] = "instance_expression",
  [sym_ascription_expression] = "ascription_expression",
  [sym_infix_expression] = "infix_expression",
  [sym_postfix_expression] = "postfix_expression",
  [sym__postfix_expression_choice] = "_postfix_expression_choice",
  [sym_macro_body] = "macro_body",
  [sym_prefix_expression] = "prefix_expression",
  [sym_tuple_expression] = "tuple_expression",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_type_arguments] = "type_arguments",
  [sym_arguments] = "arguments",
  [sym__exprs_in_parens] = "_exprs_in_parens",
  [sym_splice_expression] = "splice_expression",
  [sym_quote_expression] = "quote_expression",
  [sym_identifier] = "identifier",
  [sym__soft_identifier] = "_soft_identifier",
  [sym_identifiers] = "identifiers",
  [sym_wildcard] = "wildcard",
  [sym__non_null_literal] = "_non_null_literal",
  [sym_literal_type] = "literal_type",
  [sym_boolean_literal] = "boolean_literal",
  [sym_interpolated_string_expression] = "interpolated_string_expression",
  [sym__interpolated_string_start] = "_interpolated_string_start",
  [sym__interpolated_multiline_string_start] = "_interpolated_multiline_string_start",
  [sym__dollar_escape] = "_dollar_escape",
  [sym__aliased_interpolation_identifier] = "_aliased_interpolation_identifier",
  [sym_interpolation] = "interpolation",
  [sym_interpolated_string] = "interpolated_string",
  [sym_string] = "string",
  [sym_unit] = "unit",
  [sym_return_expression] = "return_expression",
  [sym_throw_expression] = "throw_expression",
  [sym_while_expression] = "while_expression",
  [sym_do_while_expression] = "do_while_expression",
  [sym_for_expression] = "for_expression",
  [sym_enumerators] = "enumerators",
  [sym_enumerator] = "enumerator",
  [sym__shebang] = "_shebang",
  [sym_comment] = "comment",
  [sym_using_directive] = "using_directive",
  [sym_block_comment] = "block_comment",
  [aux_sym_compilation_unit_repeat1] = "compilation_unit_repeat1",
  [aux_sym_enum_definition_repeat1] = "enum_definition_repeat1",
  [aux_sym__enum_block_repeat1] = "_enum_block_repeat1",
  [aux_sym_enum_case_definitions_repeat1] = "enum_case_definitions_repeat1",
  [aux_sym__full_enum_def_repeat1] = "_full_enum_def_repeat1",
  [aux_sym_package_identifier_repeat1] = "package_identifier_repeat1",
  [aux_sym_import_declaration_repeat1] = "import_declaration_repeat1",
  [aux_sym_namespace_selectors_repeat1] = "namespace_selectors_repeat1",
  [aux_sym__class_constructor_repeat1] = "_class_constructor_repeat1",
  [aux_sym_type_parameters_repeat1] = "type_parameters_repeat1",
  [aux_sym__type_parameter_repeat1] = "_type_parameter_repeat1",
  [aux_sym__type_parameter_repeat2] = "_type_parameter_repeat2",
  [aux_sym_annotation_repeat1] = "annotation_repeat1",
  [aux_sym_val_declaration_repeat1] = "val_declaration_repeat1",
  [aux_sym__function_constructor_repeat1] = "_function_constructor_repeat1",
  [aux_sym_extension_definition_repeat1] = "extension_definition_repeat1",
  [aux_sym__constructor_applications_repeat1] = "_constructor_applications_repeat1",
  [aux_sym__constructor_applications_repeat2] = "_constructor_applications_repeat2",
  [aux_sym_modifiers_repeat1] = "modifiers_repeat1",
  [aux_sym_derives_clause_repeat1] = "derives_clause_repeat1",
  [aux_sym_class_parameters_repeat1] = "class_parameters_repeat1",
  [aux_sym_parameters_repeat1] = "parameters_repeat1",
  [aux_sym__using_parameters_clause_repeat1] = "_using_parameters_clause_repeat1",
  [aux_sym__block_repeat1] = "_block_repeat1",
  [aux_sym_indented_cases_repeat1] = "indented_cases_repeat1",
  [aux_sym__indented_type_cases_repeat1] = "_indented_type_cases_repeat1",
  [aux_sym_compound_type_repeat1] = "compound_type_repeat1",
  [aux_sym_tuple_type_repeat1] = "tuple_type_repeat1",
  [aux_sym_type_lambda_repeat1] = "type_lambda_repeat1",
  [aux_sym_case_class_pattern_repeat1] = "case_class_pattern_repeat1",
  [aux_sym_bindings_repeat1] = "bindings_repeat1",
  [aux_sym_tuple_expression_repeat1] = "tuple_expression_repeat1",
  [aux_sym_identifiers_repeat1] = "identifiers_repeat1",
  [aux_sym_interpolated_string_repeat1] = "interpolated_string_repeat1",
  [aux_sym_interpolated_string_repeat2] = "interpolated_string_repeat2",
  [aux_sym_enumerators_repeat1] = "enumerators_repeat1",
  [aux_sym_enumerator_repeat1] = "enumerator_repeat1",
  [aux_sym_block_comment_repeat1] = "block_comment_repeat1",
  [anon_alias_sym__end_ident] = "_end_ident",
  [alias_sym_refinement] = "refinement",
  [alias_sym_structural_type] = "structural_type",
  [alias_sym_type_identifier] = "type_identifier",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym__alpha_identifier] = sym__alpha_identifier,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_package] = anon_sym_package,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_object] = anon_sym_object,
  [anon_sym_import] = anon_sym_import,
  [anon_sym_export] = anon_sym_export,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym__] = anon_sym__,
  [anon_sym_given] = anon_sym_given,
  [anon_sym_EQ_GT] = anon_sym_EQ_GT,
  [anon_sym_as] = anon_sym_as,
  [anon_sym_class] = anon_sym_class,
  [anon_sym_trait] = anon_sym_trait,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_LT_COLON] = anon_sym_LT_COLON,
  [anon_sym_GT_COLON] = anon_sym_GT_COLON,
  [anon_sym_LT_PERCENT] = anon_sym_LT_PERCENT,
  [anon_sym_end] = anon_sym_end,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_match] = anon_sym_match,
  [anon_sym_try] = anon_sym_try,
  [anon_sym_new] = anon_sym_new,
  [anon_sym_this] = anon_sym_this,
  [anon_sym_extension] = anon_sym_extension,
  [anon_sym_val] = anon_sym_val,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_var] = anon_sym_var,
  [anon_sym_type] = anon_sym_type,
  [anon_sym_def] = anon_sym_def,
  [anon_sym_opaque] = anon_sym_opaque,
  [anon_sym_with] = anon_sym_with,
  [anon_sym_abstract] = anon_sym_abstract,
  [anon_sym_final] = anon_sym_final,
  [anon_sym_sealed] = anon_sym_sealed,
  [anon_sym_implicit] = anon_sym_implicit,
  [anon_sym_lazy] = anon_sym_lazy,
  [anon_sym_override] = anon_sym_override,
  [anon_sym_private] = anon_sym_private,
  [anon_sym_protected] = anon_sym_protected,
  [anon_sym_inline] = anon_sym_inline,
  [anon_sym_infix] = anon_sym_infix,
  [anon_sym_open] = anon_sym_open,
  [anon_sym_transparent] = anon_sym_transparent,
  [anon_sym_extends] = anon_sym_extends,
  [anon_sym_derives] = anon_sym_derives,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_using] = anon_sym_using,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_POUND] = anon_sym_POUND,
  [anon_sym_QMARK_EQ_GT] = anon_sym_QMARK_EQ_GT,
  [anon_sym_EQ_GT_GT] = anon_sym_EQ_GT_GT,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_then] = anon_sym_then,
  [anon_sym_catch] = anon_sym_catch,
  [anon_sym_finally] = anon_sym_finally,
  [anon_sym_macro] = anon_sym_macro,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_DOLLAR] = anon_sym_DOLLAR,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [sym__interpolation_identifier] = sym_identifier,
  [sym__backquoted_id] = sym__backquoted_id,
  [sym_operator_identifier] = sym_operator_identifier,
  [sym_integer_literal] = sym_integer_literal,
  [sym_floating_point_literal] = sym_floating_point_literal,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [sym_character_literal] = sym_character_literal,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [anon_sym_DQUOTE_DQUOTE_DQUOTE] = anon_sym_DQUOTE_DQUOTE_DQUOTE,
  [sym_null_literal] = sym_null_literal,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_throw] = anon_sym_throw,
  [anon_sym_do] = anon_sym_do,
  [anon_sym_yield] = anon_sym_yield,
  [anon_sym_LT_DASH] = anon_sym_LT_DASH,
  [aux_sym__shebang_token1] = sym_comment,
  [anon_sym_SLASH_SLASH] = anon_sym_SLASH_SLASH,
  [sym__comment_text] = sym__comment_text,
  [anon_sym_GT] = anon_sym_GT,
  [sym_using_directive_key] = sym_using_directive_key,
  [sym_using_directive_value] = sym_using_directive_value,
  [anon_sym_SLASH_STAR] = anon_sym_SLASH_STAR,
  [aux_sym_block_comment_token1] = aux_sym_block_comment_token1,
  [anon_sym_STAR_SLASH] = anon_sym_STAR_SLASH,
  [sym__automatic_semicolon] = sym__automatic_semicolon,
  [sym__indent] = sym__indent,
  [sym__interpolated_string_middle] = sym__interpolated_string_middle,
  [sym__interpolated_string_end] = sym__interpolated_string_end,
  [sym__interpolated_multiline_string_middle] = sym__interpolated_multiline_string_middle,
  [sym__interpolated_multiline_string_end] = sym__interpolated_multiline_string_end,
  [sym__outdent] = sym__outdent,
  [sym__simple_multiline_string] = sym__simple_multiline_string,
  [sym__simple_string] = sym__simple_string,
  [sym_compilation_unit] = sym_compilation_unit,
  [sym__top_level_definition] = sym__top_level_definition,
  [sym_enum_definition] = sym_enum_definition,
  [sym__enum_block] = sym__enum_block,
  [sym_enum_body] = sym_enum_body,
  [sym_enum_case_definitions] = sym_enum_case_definitions,
  [sym_simple_enum_case] = sym_simple_enum_case,
  [sym_full_enum_case] = sym_full_enum_case,
  [sym__full_enum_def] = sym__full_enum_def,
  [sym_package_clause] = sym_package_clause,
  [sym_package_identifier] = sym_package_identifier,
  [sym_package_object] = sym_package_object,
  [sym_import_declaration] = sym_import_declaration,
  [sym_export_declaration] = sym_export_declaration,
  [sym__namespace_expression] = sym__namespace_expression,
  [sym_namespace_wildcard] = sym_namespace_wildcard,
  [sym__namespace_given_by_type] = sym__namespace_given_by_type,
  [sym_namespace_selectors] = sym_namespace_selectors,
  [sym_arrow_renamed_identifier] = sym_arrow_renamed_identifier,
  [sym_as_renamed_identifier] = sym_as_renamed_identifier,
  [sym_object_definition] = sym_object_definition,
  [sym__object_definition] = sym__object_definition,
  [sym_class_definition] = sym_class_definition,
  [sym__class_definition] = sym__class_definition,
  [sym__definition_body] = sym__definition_body,
  [sym__class_constructor] = sym__class_constructor,
  [sym_trait_definition] = sym_trait_definition,
  [sym_type_parameters] = sym_type_parameters,
  [sym__variant_type_parameter] = sym__variant_type_parameter,
  [sym_covariant_type_parameter] = sym_covariant_type_parameter,
  [sym_contravariant_type_parameter] = sym_contravariant_type_parameter,
  [sym__type_parameter] = sym__type_parameter,
  [sym_upper_bound] = sym_upper_bound,
  [sym_lower_bound] = sym_lower_bound,
  [sym_view_bound] = sym_view_bound,
  [sym_context_bound] = sym_context_bound,
  [sym_template_body] = sym_template_body,
  [sym__indented_template_body] = sym__indented_template_body,
  [sym__braced_template_body] = sym__braced_template_body,
  [sym__braced_template_body1] = sym__braced_template_body1,
  [sym__braced_template_body2] = sym__braced_template_body2,
  [sym_with_template_body] = sym_with_template_body,
  [sym__extension_template_body] = sym__extension_template_body,
  [sym__end_marker] = sym__end_marker,
  [sym_self_type] = sym_self_type,
  [sym__self_type_ascription] = sym__self_type_ascription,
  [sym_annotation] = sym_annotation,
  [sym_val_definition] = sym_val_definition,
  [sym_val_declaration] = sym_val_declaration,
  [sym__start_val] = sym__start_val,
  [sym_var_declaration] = sym_var_declaration,
  [sym_var_definition] = sym_var_definition,
  [sym__start_var] = sym__start_var,
  [sym_type_definition] = sym_type_definition,
  [sym__type_constructor] = sym__type_constructor,
  [sym_function_definition] = sym_function_definition,
  [sym_function_declaration] = sym_function_declaration,
  [sym__function_declaration] = sym__function_declaration,
  [sym__function_constructor] = sym__function_constructor,
  [sym_opaque_modifier] = sym_opaque_modifier,
  [sym_extension_definition] = sym_extension_definition,
  [sym_given_definition] = sym_given_definition,
  [sym__given_constructor] = sym__given_constructor,
  [sym__structural_instance] = sym__structural_instance,
  [sym__constructor_application] = sym__constructor_application,
  [sym__constructor_applications] = sym__constructor_applications,
  [sym_modifiers] = sym_modifiers,
  [sym_access_modifier] = sym_access_modifier,
  [sym_access_qualifier] = sym_access_qualifier,
  [sym_inline_modifier] = sym_inline_modifier,
  [sym_infix_modifier] = sym_infix_modifier,
  [sym_open_modifier] = sym_open_modifier,
  [sym_transparent_modifier] = sym_transparent_modifier,
  [sym_extends_clause] = sym_extends_clause,
  [sym_derives_clause] = sym_derives_clause,
  [sym_class_parameters] = sym_class_parameters,
  [sym_parameters] = sym_parameters,
  [sym__using_parameters_clause] = sym__using_parameters_clause,
  [sym_class_parameter] = sym_class_parameter,
  [sym_parameter] = sym_parameter,
  [sym__block] = sym__block,
  [sym__indentable_expression] = sym__indentable_expression,
  [sym_block] = sym_block,
  [sym_indented_block] = sym_indented_block,
  [sym_indented_cases] = sym_indented_cases,
  [sym__indented_type_cases] = sym__indented_type_cases,
  [sym__type] = sym__type,
  [sym__annotated_type] = sym__annotated_type,
  [sym_annotated_type] = sym_annotated_type,
  [sym__simple_type] = sym__simple_type,
  [sym_compound_type] = sym_compound_type,
  [sym__structural_type] = sym__structural_type,
  [sym__refinement] = sym__refinement,
  [sym__infix_type_choice] = sym__infix_type_choice,
  [sym_infix_type] = sym_infix_type,
  [sym_tuple_type] = sym_tuple_type,
  [sym_singleton_type] = sym_singleton_type,
  [sym_stable_type_identifier] = sym_stable_type_identifier,
  [sym_stable_identifier] = sym_stable_identifier,
  [sym_generic_type] = sym_generic_type,
  [sym_projected_type] = sym_projected_type,
  [sym_match_type] = sym_match_type,
  [sym_type_case_clause] = sym_type_case_clause,
  [sym_function_type] = sym_function_type,
  [sym__arrow_then_type] = sym__arrow_then_type,
  [sym_parameter_types] = sym_parameter_types,
  [sym_lazy_parameter_type] = sym_lazy_parameter_type,
  [sym_repeated_parameter_type] = sym_repeated_parameter_type,
  [sym__type_identifier] = sym__type_identifier,
  [sym_type_lambda] = sym_type_lambda,
  [sym_case_class_pattern] = sym_case_class_pattern,
  [sym_infix_pattern] = sym_infix_pattern,
  [sym_capture_pattern] = sym_capture_pattern,
  [sym_repeat_pattern] = sym_repeat_pattern,
  [sym_typed_pattern] = sym_typed_pattern,
  [sym_given_pattern] = sym_given_pattern,
  [sym_alternative_pattern] = sym_alternative_pattern,
  [sym_tuple_pattern] = sym_tuple_pattern,
  [sym_expression] = sym_expression,
  [sym__simple_expression] = sym__simple_expression,
  [sym_lambda_expression] = sym_lambda_expression,
  [sym_if_expression] = sym_if_expression,
  [sym__if_condition] = sym__if_condition,
  [sym_match_expression] = sym_match_expression,
  [sym_try_expression] = sym_try_expression,
  [sym_catch_clause] = sym_catch_clause,
  [sym__expr_case_clause] = sym__expr_case_clause,
  [sym_finally_clause] = sym_finally_clause,
  [sym_binding] = sym_binding,
  [sym_bindings] = sym_bindings,
  [sym_case_block] = sym_case_block,
  [sym_case_clause] = sym_case_clause,
  [sym__case_pattern] = sym__case_pattern,
  [sym_guard] = sym_guard,
  [sym_assignment_expression] = sym_assignment_expression,
  [sym_generic_function] = sym_generic_function,
  [sym_call_expression] = sym_call_expression,
  [sym_colon_argument] = sym_colon_argument,
  [sym_field_expression] = sym_field_expression,
  [sym_instance_expression] = sym_instance_expression,
  [sym_ascription_expression] = sym_ascription_expression,
  [sym_infix_expression] = sym_infix_expression,
  [sym_postfix_expression] = sym_postfix_expression,
  [sym__postfix_expression_choice] = sym__postfix_expression_choice,
  [sym_macro_body] = sym_macro_body,
  [sym_prefix_expression] = sym_prefix_expression,
  [sym_tuple_expression] = sym_tuple_expression,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_type_arguments] = sym_type_arguments,
  [sym_arguments] = sym_arguments,
  [sym__exprs_in_parens] = sym__exprs_in_parens,
  [sym_splice_expression] = sym_splice_expression,
  [sym_quote_expression] = sym_quote_expression,
  [sym_identifier] = sym_identifier,
  [sym__soft_identifier] = sym__soft_identifier,
  [sym_identifiers] = sym_identifiers,
  [sym_wildcard] = sym_wildcard,
  [sym__non_null_literal] = sym__non_null_literal,
  [sym_literal_type] = sym_literal_type,
  [sym_boolean_literal] = sym_boolean_literal,
  [sym_interpolated_string_expression] = sym_interpolated_string_expression,
  [sym__interpolated_string_start] = sym__interpolated_string_start,
  [sym__interpolated_multiline_string_start] = sym__interpolated_multiline_string_start,
  [sym__dollar_escape] = sym__dollar_escape,
  [sym__aliased_interpolation_identifier] = sym__aliased_interpolation_identifier,
  [sym_interpolation] = sym_interpolation,
  [sym_interpolated_string] = sym_interpolated_string,
  [sym_string] = sym_string,
  [sym_unit] = sym_unit,
  [sym_return_expression] = sym_return_expression,
  [sym_throw_expression] = sym_throw_expression,
  [sym_while_expression] = sym_while_expression,
  [sym_do_while_expression] = sym_do_while_expression,
  [sym_for_expression] = sym_for_expression,
  [sym_enumerators] = sym_enumerators,
  [sym_enumerator] = sym_enumerator,
  [sym__shebang] = sym__shebang,
  [sym_comment] = sym_comment,
  [sym_using_directive] = sym_using_directive,
  [sym_block_comment] = sym_block_comment,
  [aux_sym_compilation_unit_repeat1] = aux_sym_compilation_unit_repeat1,
  [aux_sym_enum_definition_repeat1] = aux_sym_enum_definition_repeat1,
  [aux_sym__enum_block_repeat1] = aux_sym__enum_block_repeat1,
  [aux_sym_enum_case_definitions_repeat1] = aux_sym_enum_case_definitions_repeat1,
  [aux_sym__full_enum_def_repeat1] = aux_sym__full_enum_def_repeat1,
  [aux_sym_package_identifier_repeat1] = aux_sym_package_identifier_repeat1,
  [aux_sym_import_declaration_repeat1] = aux_sym_import_declaration_repeat1,
  [aux_sym_namespace_selectors_repeat1] = aux_sym_namespace_selectors_repeat1,
  [aux_sym__class_constructor_repeat1] = aux_sym__class_constructor_repeat1,
  [aux_sym_type_parameters_repeat1] = aux_sym_type_parameters_repeat1,
  [aux_sym__type_parameter_repeat1] = aux_sym__type_parameter_repeat1,
  [aux_sym__type_parameter_repeat2] = aux_sym__type_parameter_repeat2,
  [aux_sym_annotation_repeat1] = aux_sym_annotation_repeat1,
  [aux_sym_val_declaration_repeat1] = aux_sym_val_declaration_repeat1,
  [aux_sym__function_constructor_repeat1] = aux_sym__function_constructor_repeat1,
  [aux_sym_extension_definition_repeat1] = aux_sym_extension_definition_repeat1,
  [aux_sym__constructor_applications_repeat1] = aux_sym__constructor_applications_repeat1,
  [aux_sym__constructor_applications_repeat2] = aux_sym__constructor_applications_repeat2,
  [aux_sym_modifiers_repeat1] = aux_sym_modifiers_repeat1,
  [aux_sym_derives_clause_repeat1] = aux_sym_derives_clause_repeat1,
  [aux_sym_class_parameters_repeat1] = aux_sym_class_parameters_repeat1,
  [aux_sym_parameters_repeat1] = aux_sym_parameters_repeat1,
  [aux_sym__using_parameters_clause_repeat1] = aux_sym__using_parameters_clause_repeat1,
  [aux_sym__block_repeat1] = aux_sym__block_repeat1,
  [aux_sym_indented_cases_repeat1] = aux_sym_indented_cases_repeat1,
  [aux_sym__indented_type_cases_repeat1] = aux_sym__indented_type_cases_repeat1,
  [aux_sym_compound_type_repeat1] = aux_sym_compound_type_repeat1,
  [aux_sym_tuple_type_repeat1] = aux_sym_tuple_type_repeat1,
  [aux_sym_type_lambda_repeat1] = aux_sym_type_lambda_repeat1,
  [aux_sym_case_class_pattern_repeat1] = aux_sym_case_class_pattern_repeat1,
  [aux_sym_bindings_repeat1] = aux_sym_bindings_repeat1,
  [aux_sym_tuple_expression_repeat1] = aux_sym_tuple_expression_repeat1,
  [aux_sym_identifiers_repeat1] = aux_sym_identifiers_repeat1,
  [aux_sym_interpolated_string_repeat1] = aux_sym_interpolated_string_repeat1,
  [aux_sym_interpolated_string_repeat2] = aux_sym_interpolated_string_repeat2,
  [aux_sym_enumerators_repeat1] = aux_sym_enumerators_repeat1,
  [aux_sym_enumerator_repeat1] = aux_sym_enumerator_repeat1,
  [aux_sym_block_comment_repeat1] = aux_sym_block_comment_repeat1,
  [anon_alias_sym__end_ident] = anon_alias_sym__end_ident,
  [alias_sym_refinement] = alias_sym_refinement,
  [alias_sym_structural_type] = alias_sym_structural_type,
  [alias_sym_type_identifier] = alias_sym_type_identifier,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym__alpha_identifier] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_package] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_object] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_import] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_export] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_given] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_as] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_class] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_trait] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_end] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_match] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_new] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_this] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_extension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_val] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_var] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_type] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_def] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_opaque] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_with] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_abstract] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_final] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sealed] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_implicit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_lazy] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_override] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_private] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_protected] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_inline] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_infix] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_open] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_transparent] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_extends] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_derives] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_using] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_then] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_catch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_finally] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_macro] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym__interpolation_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__backquoted_id] = {
    .visible = false,
    .named = true,
  },
  [sym_operator_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_integer_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_floating_point_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [sym_character_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE_DQUOTE_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym_null_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_throw] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_yield] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_DASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__shebang_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SLASH_SLASH] = {
    .visible = true,
    .named = false,
  },
  [sym__comment_text] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [sym_using_directive_key] = {
    .visible = true,
    .named = true,
  },
  [sym_using_directive_value] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SLASH_STAR] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_block_comment_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_STAR_SLASH] = {
    .visible = true,
    .named = false,
  },
  [sym__automatic_semicolon] = {
    .visible = false,
    .named = true,
  },
  [sym__indent] = {
    .visible = false,
    .named = true,
  },
  [sym__interpolated_string_middle] = {
    .visible = false,
    .named = true,
  },
  [sym__interpolated_string_end] = {
    .visible = false,
    .named = true,
  },
  [sym__interpolated_multiline_string_middle] = {
    .visible = false,
    .named = true,
  },
  [sym__interpolated_multiline_string_end] = {
    .visible = false,
    .named = true,
  },
  [sym__outdent] = {
    .visible = false,
    .named = true,
  },
  [sym__simple_multiline_string] = {
    .visible = false,
    .named = true,
  },
  [sym__simple_string] = {
    .visible = false,
    .named = true,
  },
  [sym_compilation_unit] = {
    .visible = true,
    .named = true,
  },
  [sym__top_level_definition] = {
    .visible = false,
    .named = true,
  },
  [sym_enum_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__enum_block] = {
    .visible = false,
    .named = true,
  },
  [sym_enum_body] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_case_definitions] = {
    .visible = true,
    .named = true,
  },
  [sym_simple_enum_case] = {
    .visible = true,
    .named = true,
  },
  [sym_full_enum_case] = {
    .visible = true,
    .named = true,
  },
  [sym__full_enum_def] = {
    .visible = false,
    .named = true,
  },
  [sym_package_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_package_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_package_object] = {
    .visible = true,
    .named = true,
  },
  [sym_import_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_export_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__namespace_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_namespace_wildcard] = {
    .visible = true,
    .named = true,
  },
  [sym__namespace_given_by_type] = {
    .visible = false,
    .named = true,
  },
  [sym_namespace_selectors] = {
    .visible = true,
    .named = true,
  },
  [sym_arrow_renamed_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_as_renamed_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_object_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__object_definition] = {
    .visible = false,
    .named = true,
  },
  [sym_class_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__class_definition] = {
    .visible = false,
    .named = true,
  },
  [sym__definition_body] = {
    .visible = false,
    .named = true,
  },
  [sym__class_constructor] = {
    .visible = false,
    .named = true,
  },
  [sym_trait_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym__variant_type_parameter] = {
    .visible = false,
    .named = true,
  },
  [sym_covariant_type_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_contravariant_type_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym__type_parameter] = {
    .visible = false,
    .named = true,
  },
  [sym_upper_bound] = {
    .visible = true,
    .named = true,
  },
  [sym_lower_bound] = {
    .visible = true,
    .named = true,
  },
  [sym_view_bound] = {
    .visible = true,
    .named = true,
  },
  [sym_context_bound] = {
    .visible = true,
    .named = true,
  },
  [sym_template_body] = {
    .visible = true,
    .named = true,
  },
  [sym__indented_template_body] = {
    .visible = false,
    .named = true,
  },
  [sym__braced_template_body] = {
    .visible = false,
    .named = true,
  },
  [sym__braced_template_body1] = {
    .visible = false,
    .named = true,
  },
  [sym__braced_template_body2] = {
    .visible = false,
    .named = true,
  },
  [sym_with_template_body] = {
    .visible = true,
    .named = true,
  },
  [sym__extension_template_body] = {
    .visible = false,
    .named = true,
  },
  [sym__end_marker] = {
    .visible = false,
    .named = true,
  },
  [sym_self_type] = {
    .visible = true,
    .named = true,
  },
  [sym__self_type_ascription] = {
    .visible = false,
    .named = true,
  },
  [sym_annotation] = {
    .visible = true,
    .named = true,
  },
  [sym_val_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_val_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__start_val] = {
    .visible = false,
    .named = true,
  },
  [sym_var_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_var_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__start_var] = {
    .visible = false,
    .named = true,
  },
  [sym_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__type_constructor] = {
    .visible = false,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_function_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__function_declaration] = {
    .visible = false,
    .named = true,
  },
  [sym__function_constructor] = {
    .visible = false,
    .named = true,
  },
  [sym_opaque_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_extension_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_given_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__given_constructor] = {
    .visible = false,
    .named = true,
  },
  [sym__structural_instance] = {
    .visible = false,
    .named = true,
  },
  [sym__constructor_application] = {
    .visible = false,
    .named = true,
  },
  [sym__constructor_applications] = {
    .visible = false,
    .named = true,
  },
  [sym_modifiers] = {
    .visible = true,
    .named = true,
  },
  [sym_access_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_access_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym_inline_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_open_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_transparent_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_extends_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_derives_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_class_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym__using_parameters_clause] = {
    .visible = false,
    .named = true,
  },
  [sym_class_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym__block] = {
    .visible = false,
    .named = true,
  },
  [sym__indentable_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_indented_block] = {
    .visible = true,
    .named = true,
  },
  [sym_indented_cases] = {
    .visible = true,
    .named = true,
  },
  [sym__indented_type_cases] = {
    .visible = false,
    .named = true,
  },
  [sym__type] = {
    .visible = false,
    .named = true,
  },
  [sym__annotated_type] = {
    .visible = false,
    .named = true,
  },
  [sym_annotated_type] = {
    .visible = true,
    .named = true,
  },
  [sym__simple_type] = {
    .visible = false,
    .named = true,
  },
  [sym_compound_type] = {
    .visible = true,
    .named = true,
  },
  [sym__structural_type] = {
    .visible = false,
    .named = true,
  },
  [sym__refinement] = {
    .visible = false,
    .named = true,
  },
  [sym__infix_type_choice] = {
    .visible = false,
    .named = true,
  },
  [sym_infix_type] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_type] = {
    .visible = true,
    .named = true,
  },
  [sym_singleton_type] = {
    .visible = true,
    .named = true,
  },
  [sym_stable_type_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_stable_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_generic_type] = {
    .visible = true,
    .named = true,
  },
  [sym_projected_type] = {
    .visible = true,
    .named = true,
  },
  [sym_match_type] = {
    .visible = true,
    .named = true,
  },
  [sym_type_case_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_function_type] = {
    .visible = true,
    .named = true,
  },
  [sym__arrow_then_type] = {
    .visible = false,
    .named = true,
  },
  [sym_parameter_types] = {
    .visible = true,
    .named = true,
  },
  [sym_lazy_parameter_type] = {
    .visible = true,
    .named = true,
  },
  [sym_repeated_parameter_type] = {
    .visible = true,
    .named = true,
  },
  [sym__type_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_type_lambda] = {
    .visible = true,
    .named = true,
  },
  [sym_case_class_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_capture_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_repeat_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_typed_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_given_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_alternative_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__simple_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_lambda_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_if_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__if_condition] = {
    .visible = false,
    .named = true,
  },
  [sym_match_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_try_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym__expr_case_clause] = {
    .visible = false,
    .named = true,
  },
  [sym_finally_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_binding] = {
    .visible = true,
    .named = true,
  },
  [sym_bindings] = {
    .visible = true,
    .named = true,
  },
  [sym_case_block] = {
    .visible = true,
    .named = true,
  },
  [sym_case_clause] = {
    .visible = true,
    .named = true,
  },
  [sym__case_pattern] = {
    .visible = false,
    .named = true,
  },
  [sym_guard] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_generic_function] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_colon_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_field_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_instance_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_ascription_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_postfix_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__postfix_expression_choice] = {
    .visible = false,
    .named = true,
  },
  [sym_macro_body] = {
    .visible = true,
    .named = true,
  },
  [sym_prefix_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_type_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym__exprs_in_parens] = {
    .visible = false,
    .named = true,
  },
  [sym_splice_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_quote_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__soft_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_identifiers] = {
    .visible = true,
    .named = true,
  },
  [sym_wildcard] = {
    .visible = true,
    .named = true,
  },
  [sym__non_null_literal] = {
    .visible = false,
    .named = true,
  },
  [sym_literal_type] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_interpolated_string_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__interpolated_string_start] = {
    .visible = false,
    .named = true,
  },
  [sym__interpolated_multiline_string_start] = {
    .visible = false,
    .named = true,
  },
  [sym__dollar_escape] = {
    .visible = false,
    .named = true,
  },
  [sym__aliased_interpolation_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_interpolation] = {
    .visible = true,
    .named = true,
  },
  [sym_interpolated_string] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_unit] = {
    .visible = true,
    .named = true,
  },
  [sym_return_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_throw_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_while_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_do_while_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_for_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_enumerators] = {
    .visible = true,
    .named = true,
  },
  [sym_enumerator] = {
    .visible = true,
    .named = true,
  },
  [sym__shebang] = {
    .visible = false,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_using_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_block_comment] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_compilation_unit_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__enum_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_case_definitions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__full_enum_def_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_package_identifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_import_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_namespace_selectors_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__class_constructor_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__type_parameter_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__type_parameter_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_annotation_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_val_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__function_constructor_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_extension_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__constructor_applications_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__constructor_applications_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_modifiers_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_derives_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__using_parameters_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_indented_cases_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__indented_type_cases_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tuple_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_lambda_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_case_class_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_bindings_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tuple_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_identifiers_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_interpolated_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_interpolated_string_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enumerators_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enumerator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_comment_repeat1] = {
    .visible = false,
    .named = false,
  },
  [anon_alias_sym__end_ident] = {
    .visible = true,
    .named = false,
  },
  [alias_sym_refinement] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_structural_type] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_type_identifier] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_alias = 1,
  field_alternative = 2,
  field_arguments = 3,
  field_base = 4,
  field_body = 5,
  field_bound = 6,
  field_class_parameters = 7,
  field_condition = 8,
  field_consequence = 9,
  field_default_value = 10,
  field_derive = 11,
  field_enumerators = 12,
  field_extend = 13,
  field_extra = 14,
  field_field = 15,
  field_function = 16,
  field_interpolator = 17,
  field_lambda_start = 18,
  field_left = 19,
  field_name = 20,
  field_operator = 21,
  field_parameter_types = 22,
  field_parameters = 23,
  field_path = 24,
  field_pattern = 25,
  field_return_type = 26,
  field_right = 27,
  field_selector = 28,
  field_type = 29,
  field_type_arguments = 30,
  field_type_parameters = 31,
  field_value = 32,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alias] = "alias",
  [field_alternative] = "alternative",
  [field_arguments] = "arguments",
  [field_base] = "base",
  [field_body] = "body",
  [field_bound] = "bound",
  [field_class_parameters] = "class_parameters",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_default_value] = "default_value",
  [field_derive] = "derive",
  [field_enumerators] = "enumerators",
  [field_extend] = "extend",
  [field_extra] = "extra",
  [field_field] = "field",
  [field_function] = "function",
  [field_interpolator] = "interpolator",
  [field_lambda_start] = "lambda_start",
  [field_left] = "left",
  [field_name] = "name",
  [field_operator] = "operator",
  [field_parameter_types] = "parameter_types",
  [field_parameters] = "parameters",
  [field_path] = "path",
  [field_pattern] = "pattern",
  [field_return_type] = "return_type",
  [field_right] = "right",
  [field_selector] = "selector",
  [field_type] = "type",
  [field_type_arguments] = "type_arguments",
  [field_type_parameters] = "type_parameters",
  [field_value] = "value",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 4},
  [2] = {.index = 4, .length = 1},
  [3] = {.index = 5, .length = 1},
  [4] = {.index = 6, .length = 4},
  [5] = {.index = 10, .length = 1},
  [6] = {.index = 11, .length = 1},
  [9] = {.index = 12, .length = 3},
  [10] = {.index = 15, .length = 1},
  [11] = {.index = 16, .length = 6},
  [12] = {.index = 22, .length = 3},
  [14] = {.index = 25, .length = 1},
  [15] = {.index = 26, .length = 1},
  [16] = {.index = 27, .length = 3},
  [17] = {.index = 30, .length = 3},
  [18] = {.index = 33, .length = 5},
  [19] = {.index = 38, .length = 2},
  [20] = {.index = 40, .length = 2},
  [21] = {.index = 42, .length = 1},
  [22] = {.index = 43, .length = 2},
  [23] = {.index = 45, .length = 2},
  [24] = {.index = 47, .length = 4},
  [25] = {.index = 51, .length = 1},
  [26] = {.index = 52, .length = 4},
  [27] = {.index = 56, .length = 6},
  [28] = {.index = 62, .length = 2},
  [29] = {.index = 64, .length = 3},
  [30] = {.index = 67, .length = 1},
  [31] = {.index = 68, .length = 2},
  [32] = {.index = 70, .length = 2},
  [33] = {.index = 72, .length = 2},
  [34] = {.index = 74, .length = 2},
  [35] = {.index = 76, .length = 3},
  [36] = {.index = 79, .length = 1},
  [37] = {.index = 80, .length = 6},
  [38] = {.index = 86, .length = 4},
  [40] = {.index = 90, .length = 1},
  [41] = {.index = 91, .length = 1},
  [42] = {.index = 92, .length = 2},
  [43] = {.index = 94, .length = 2},
  [44] = {.index = 96, .length = 1},
  [45] = {.index = 97, .length = 5},
  [46] = {.index = 102, .length = 4},
  [47] = {.index = 106, .length = 4},
  [48] = {.index = 110, .length = 2},
  [49] = {.index = 112, .length = 2},
  [50] = {.index = 114, .length = 1},
  [51] = {.index = 115, .length = 1},
  [52] = {.index = 116, .length = 1},
  [53] = {.index = 117, .length = 2},
  [54] = {.index = 119, .length = 2},
  [55] = {.index = 121, .length = 2},
  [56] = {.index = 123, .length = 2},
  [57] = {.index = 125, .length = 2},
  [58] = {.index = 127, .length = 5},
  [59] = {.index = 132, .length = 3},
  [60] = {.index = 135, .length = 3},
  [61] = {.index = 138, .length = 1},
  [62] = {.index = 139, .length = 3},
  [63] = {.index = 142, .length = 2},
  [64] = {.index = 144, .length = 2},
  [65] = {.index = 146, .length = 2},
  [66] = {.index = 148, .length = 3},
  [67] = {.index = 151, .length = 2},
  [68] = {.index = 153, .length = 3},
  [69] = {.index = 156, .length = 2},
  [70] = {.index = 158, .length = 1},
  [71] = {.index = 159, .length = 2},
  [72] = {.index = 161, .length = 5},
  [73] = {.index = 166, .length = 5},
  [74] = {.index = 171, .length = 2},
  [75] = {.index = 173, .length = 4},
  [76] = {.index = 177, .length = 3},
  [77] = {.index = 180, .length = 4},
  [78] = {.index = 184, .length = 2},
  [79] = {.index = 186, .length = 2},
  [80] = {.index = 188, .length = 2},
  [81] = {.index = 190, .length = 2},
  [82] = {.index = 192, .length = 2},
  [83] = {.index = 194, .length = 1},
  [84] = {.index = 195, .length = 2},
  [85] = {.index = 197, .length = 2},
  [86] = {.index = 199, .length = 6},
  [87] = {.index = 205, .length = 5},
  [88] = {.index = 210, .length = 6},
  [89] = {.index = 216, .length = 3},
  [90] = {.index = 219, .length = 2},
  [91] = {.index = 221, .length = 2},
  [92] = {.index = 223, .length = 1},
  [93] = {.index = 224, .length = 2},
  [94] = {.index = 226, .length = 2},
  [95] = {.index = 228, .length = 3},
  [96] = {.index = 231, .length = 4},
  [97] = {.index = 235, .length = 3},
  [98] = {.index = 238, .length = 3},
  [99] = {.index = 241, .length = 3},
  [100] = {.index = 244, .length = 4},
  [101] = {.index = 248, .length = 2},
  [102] = {.index = 250, .length = 2},
  [103] = {.index = 252, .length = 1},
  [104] = {.index = 253, .length = 2},
  [105] = {.index = 255, .length = 2},
  [106] = {.index = 257, .length = 2},
  [107] = {.index = 259, .length = 2},
  [108] = {.index = 261, .length = 4},
  [109] = {.index = 265, .length = 6},
  [110] = {.index = 271, .length = 6},
  [111] = {.index = 277, .length = 4},
  [112] = {.index = 281, .length = 3},
  [113] = {.index = 284, .length = 2},
  [114] = {.index = 286, .length = 2},
  [115] = {.index = 288, .length = 4},
  [116] = {.index = 292, .length = 4},
  [117] = {.index = 296, .length = 3},
  [118] = {.index = 299, .length = 1},
  [119] = {.index = 300, .length = 3},
  [120] = {.index = 303, .length = 3},
  [121] = {.index = 306, .length = 2},
  [122] = {.index = 308, .length = 2},
  [123] = {.index = 310, .length = 2},
  [124] = {.index = 312, .length = 6},
  [125] = {.index = 318, .length = 5},
  [126] = {.index = 323, .length = 6},
  [127] = {.index = 329, .length = 6},
  [128] = {.index = 335, .length = 5},
  [129] = {.index = 340, .length = 7},
  [130] = {.index = 347, .length = 3},
  [131] = {.index = 350, .length = 4},
  [132] = {.index = 354, .length = 2},
  [133] = {.index = 356, .length = 4},
  [134] = {.index = 360, .length = 3},
  [135] = {.index = 363, .length = 4},
  [136] = {.index = 367, .length = 2},
  [137] = {.index = 369, .length = 4},
  [138] = {.index = 373, .length = 2},
  [139] = {.index = 375, .length = 5},
  [140] = {.index = 380, .length = 5},
  [141] = {.index = 385, .length = 4},
  [142] = {.index = 389, .length = 6},
  [143] = {.index = 395, .length = 6},
  [144] = {.index = 401, .length = 4},
  [145] = {.index = 405, .length = 3},
  [146] = {.index = 408, .length = 2},
  [147] = {.index = 410, .length = 1},
  [148] = {.index = 411, .length = 3},
  [149] = {.index = 414, .length = 4},
  [150] = {.index = 418, .length = 1},
  [151] = {.index = 419, .length = 2},
  [152] = {.index = 421, .length = 2},
  [153] = {.index = 423, .length = 4},
  [154] = {.index = 427, .length = 3},
  [155] = {.index = 430, .length = 4},
  [156] = {.index = 434, .length = 3},
  [157] = {.index = 437, .length = 3},
  [158] = {.index = 440, .length = 5},
  [159] = {.index = 445, .length = 4},
  [160] = {.index = 449, .length = 3},
  [161] = {.index = 452, .length = 6},
  [162] = {.index = 458, .length = 2},
  [163] = {.index = 460, .length = 4},
  [164] = {.index = 464, .length = 2},
  [165] = {.index = 466, .length = 1},
  [166] = {.index = 467, .length = 2},
  [167] = {.index = 469, .length = 2},
  [168] = {.index = 471, .length = 4},
  [169] = {.index = 475, .length = 5},
  [170] = {.index = 480, .length = 5},
  [171] = {.index = 485, .length = 3},
  [172] = {.index = 488, .length = 2},
  [173] = {.index = 490, .length = 4},
  [174] = {.index = 494, .length = 3},
  [175] = {.index = 497, .length = 5},
  [176] = {.index = 502, .length = 4},
  [177] = {.index = 506, .length = 2},
  [178] = {.index = 508, .length = 3},
  [179] = {.index = 511, .length = 4},
  [180] = {.index = 515, .length = 7},
  [181] = {.index = 522, .length = 6},
  [182] = {.index = 528, .length = 3},
  [183] = {.index = 531, .length = 2},
  [184] = {.index = 533, .length = 2},
  [185] = {.index = 535, .length = 2},
  [186] = {.index = 537, .length = 7},
  [187] = {.index = 544, .length = 3},
  [188] = {.index = 547, .length = 3},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_name, 0, .inherited = true},
    {field_parameters, 0, .inherited = true},
    {field_return_type, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [4] =
    {field_name, 0},
  [5] =
    {field_name, 1},
  [6] =
    {field_body, 1, .inherited = true},
    {field_derive, 1, .inherited = true},
    {field_extend, 1, .inherited = true},
    {field_name, 1, .inherited = true},
  [10] =
    {field_path, 0},
  [11] =
    {field_path, 1, .inherited = true},
  [12] =
    {field_arguments, 1, .inherited = true},
    {field_body, 1, .inherited = true},
    {field_return_type, 1},
  [15] =
    {field_return_type, 1},
  [16] =
    {field_body, 1, .inherited = true},
    {field_class_parameters, 1, .inherited = true},
    {field_derive, 1, .inherited = true},
    {field_extend, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [22] =
    {field_class_parameters, 0, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [25] =
    {field_body, 1},
  [26] =
    {field_arguments, 1, .inherited = true},
  [27] =
    {field_bound, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [30] =
    {field_name, 1, .inherited = true},
    {field_parameters, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [33] =
    {field_body, 1},
    {field_name, 0, .inherited = true},
    {field_parameters, 0, .inherited = true},
    {field_return_type, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [38] =
    {field_function, 0},
    {field_type_arguments, 1},
  [40] =
    {field_arguments, 1},
    {field_function, 0},
  [42] =
    {field_interpolator, 0},
  [43] =
    {field_name, 0},
    {field_type_parameters, 1},
  [45] =
    {field_class_parameters, 1},
    {field_name, 0},
  [47] =
    {field_body, 2},
    {field_class_parameters, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [51] =
    {field_pattern, 1, .inherited = true},
  [52] =
    {field_body, 2, .inherited = true},
    {field_derive, 2, .inherited = true},
    {field_extend, 2, .inherited = true},
    {field_name, 2, .inherited = true},
  [56] =
    {field_body, 2, .inherited = true},
    {field_class_parameters, 2, .inherited = true},
    {field_derive, 2, .inherited = true},
    {field_extend, 2, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [62] =
    {field_body, 2},
    {field_name, 1},
  [64] =
    {field_body, 1},
    {field_body, 1, .inherited = true},
    {field_name, 0},
  [67] =
    {field_body, 0},
  [68] =
    {field_extend, 1},
    {field_name, 0},
  [70] =
    {field_derive, 1},
    {field_name, 0},
  [72] =
    {field_path, 0},
    {field_path, 1},
  [74] =
    {field_path, 1, .inherited = true},
    {field_path, 2, .inherited = true},
  [76] =
    {field_bound, 0, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [79] =
    {field_type_parameters, 0},
  [80] =
    {field_arguments, 2, .inherited = true},
    {field_body, 2, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_parameters, 1, .inherited = true},
    {field_return_type, 2},
    {field_type_parameters, 1, .inherited = true},
  [86] =
    {field_name, 1, .inherited = true},
    {field_parameters, 1, .inherited = true},
    {field_return_type, 2},
    {field_type_parameters, 1, .inherited = true},
  [90] =
    {field_base, 0},
  [91] =
    {field_arguments, 1},
  [92] =
    {field_base, 0},
    {field_extra, 1, .inherited = true},
  [94] =
    {field_type, 0},
    {field_type_arguments, 1},
  [96] =
    {field_parameters, 0},
  [97] =
    {field_body, 1},
    {field_body, 1, .inherited = true},
    {field_class_parameters, 0, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [102] =
    {field_class_parameters, 0, .inherited = true},
    {field_extend, 1},
    {field_name, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [106] =
    {field_class_parameters, 0, .inherited = true},
    {field_derive, 1},
    {field_name, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [110] =
    {field_condition, 1},
    {field_consequence, 2},
  [112] =
    {field_body, 2},
    {field_condition, 1},
  [114] =
    {field_type, 1},
  [115] =
    {field_condition, 1},
  [116] =
    {field_pattern, 0},
  [117] =
    {field_body, 2},
    {field_type_parameters, 1},
  [119] =
    {field_body, 2},
    {field_parameters, 1},
  [121] =
    {field_arguments, 2},
    {field_name, 1},
  [123] =
    {field_bound, 1},
    {field_name, 0},
  [125] =
    {field_name, 0},
    {field_parameters, 1},
  [127] =
    {field_body, 2},
    {field_name, 0, .inherited = true},
    {field_parameters, 0, .inherited = true},
    {field_return_type, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [132] =
    {field_bound, 2, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [135] =
    {field_arguments, 2, .inherited = true},
    {field_body, 2, .inherited = true},
    {field_return_type, 2},
  [138] =
    {field_return_type, 2},
  [139] =
    {field_name, 2, .inherited = true},
    {field_parameters, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [142] =
    {field_body, 2},
    {field_value, 0},
  [144] =
    {field_field, 2},
    {field_value, 0},
  [146] =
    {field_left, 0},
    {field_right, 2},
  [148] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [151] =
    {field_arguments, 2},
    {field_function, 0},
  [153] =
    {field_class_parameters, 2},
    {field_name, 0},
    {field_type_parameters, 1},
  [156] =
    {field_class_parameters, 2},
    {field_name, 0},
  [158] =
    {field_arguments, 0, .inherited = true},
  [159] =
    {field_arguments, 1, .inherited = true},
    {field_type, 1},
  [161] =
    {field_body, 3},
    {field_class_parameters, 1, .inherited = true},
    {field_extend, 2},
    {field_name, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [166] =
    {field_body, 3},
    {field_class_parameters, 1, .inherited = true},
    {field_derive, 2},
    {field_name, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [171] =
    {field_body, 2},
    {field_pattern, 1, .inherited = true},
  [173] =
    {field_body, 2},
    {field_body, 2, .inherited = true},
    {field_extend, 1},
    {field_name, 0},
  [177] =
    {field_derive, 2},
    {field_extend, 1},
    {field_name, 0},
  [180] =
    {field_body, 2},
    {field_body, 2, .inherited = true},
    {field_derive, 1},
    {field_name, 0},
  [184] =
    {field_path, 0, .inherited = true},
    {field_path, 1, .inherited = true},
  [186] =
    {field_parameter_types, 0},
    {field_return_type, 1, .inherited = true},
  [188] =
    {field_parameters, 1},
    {field_type_parameters, 0},
  [190] =
    {field_arguments, 0, .inherited = true},
    {field_body, 2},
  [192] =
    {field_body, 3},
    {field_return_type, 1},
  [194] =
    {field_extra, 1},
  [195] =
    {field_extra, 0, .inherited = true},
    {field_extra, 1, .inherited = true},
  [197] =
    {field_selector, 2},
    {field_type, 0},
  [199] =
    {field_body, 2},
    {field_body, 2, .inherited = true},
    {field_class_parameters, 0, .inherited = true},
    {field_extend, 1},
    {field_name, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [205] =
    {field_class_parameters, 0, .inherited = true},
    {field_derive, 2},
    {field_extend, 1},
    {field_name, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [210] =
    {field_body, 2},
    {field_body, 2, .inherited = true},
    {field_class_parameters, 0, .inherited = true},
    {field_derive, 1},
    {field_name, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [216] =
    {field_body, 3},
    {field_condition, 1},
    {field_condition, 2},
  [219] =
    {field_pattern, 0},
    {field_type, 2},
  [221] =
    {field_name, 0},
    {field_pattern, 2},
  [223] =
    {field_type, 0},
  [224] =
    {field_body, 3},
    {field_enumerators, 1},
  [226] =
    {field_body, 1, .inherited = true},
    {field_pattern, 1, .inherited = true},
  [228] =
    {field_body, 3},
    {field_parameters, 2},
    {field_type_parameters, 1},
  [231] =
    {field_bound, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_type, 3},
    {field_type_parameters, 1, .inherited = true},
  [235] =
    {field_bound, 2},
    {field_name, 0},
    {field_type_parameters, 1},
  [238] =
    {field_bound, 1},
    {field_bound, 2},
    {field_name, 0},
  [241] =
    {field_name, 0},
    {field_parameters, 2},
    {field_type_parameters, 1},
  [244] =
    {field_name, 1, .inherited = true},
    {field_parameters, 1, .inherited = true},
    {field_return_type, 3},
    {field_type_parameters, 1, .inherited = true},
  [248] =
    {field_parameters, 0},
    {field_parameters, 1},
  [250] =
    {field_name, 0},
    {field_type, 2},
  [252] =
    {field_type, 2},
  [253] =
    {field_body, 1},
    {field_condition, 3},
  [255] =
    {field_name, 1},
    {field_type, 3},
  [257] =
    {field_pattern, 1},
    {field_value, 3},
  [259] =
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
  [261] =
    {field_body, 3, .inherited = true},
    {field_derive, 3, .inherited = true},
    {field_extend, 3, .inherited = true},
    {field_name, 3, .inherited = true},
  [265] =
    {field_body, 3, .inherited = true},
    {field_class_parameters, 3, .inherited = true},
    {field_derive, 3, .inherited = true},
    {field_extend, 3, .inherited = true},
    {field_name, 3, .inherited = true},
    {field_type_parameters, 3, .inherited = true},
  [271] =
    {field_arguments, 3, .inherited = true},
    {field_body, 3, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_parameters, 2, .inherited = true},
    {field_return_type, 3},
    {field_type_parameters, 2, .inherited = true},
  [277] =
    {field_name, 2, .inherited = true},
    {field_parameters, 2, .inherited = true},
    {field_return_type, 3},
    {field_type_parameters, 2, .inherited = true},
  [281] =
    {field_bound, 3, .inherited = true},
    {field_name, 3, .inherited = true},
    {field_type_parameters, 3, .inherited = true},
  [284] =
    {field_condition, 2},
    {field_consequence, 3},
  [286] =
    {field_body, 3},
    {field_value, 1},
  [288] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
    {field_right, 3},
  [292] =
    {field_body, 3},
    {field_class_parameters, 2, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [296] =
    {field_arguments, 3, .inherited = true},
    {field_body, 3, .inherited = true},
    {field_return_type, 3},
  [299] =
    {field_return_type, 3},
  [300] =
    {field_name, 3, .inherited = true},
    {field_parameters, 3, .inherited = true},
    {field_type_parameters, 3, .inherited = true},
  [303] =
    {field_class_parameters, 3},
    {field_name, 0},
    {field_type_parameters, 1},
  [306] =
    {field_class_parameters, 3},
    {field_name, 0},
  [308] =
    {field_arguments, 0, .inherited = true},
    {field_arguments, 1, .inherited = true},
  [310] =
    {field_type, 1},
    {field_type, 2, .inherited = true},
  [312] =
    {field_body, 4},
    {field_class_parameters, 1, .inherited = true},
    {field_derive, 3},
    {field_extend, 2},
    {field_name, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [318] =
    {field_body, 3},
    {field_body, 3, .inherited = true},
    {field_derive, 2},
    {field_extend, 1},
    {field_name, 0},
  [323] =
    {field_bound, 1, .inherited = true},
    {field_bound, 2, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [329] =
    {field_bound, 0, .inherited = true},
    {field_bound, 1, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [335] =
    {field_body, 4},
    {field_name, 1, .inherited = true},
    {field_parameters, 1, .inherited = true},
    {field_return_type, 2},
    {field_type_parameters, 1, .inherited = true},
  [340] =
    {field_body, 3},
    {field_body, 3, .inherited = true},
    {field_class_parameters, 0, .inherited = true},
    {field_derive, 2},
    {field_extend, 1},
    {field_name, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [347] =
    {field_alternative, 4},
    {field_condition, 1},
    {field_consequence, 2},
  [350] =
    {field_body, 4},
    {field_enumerators, 1},
    {field_enumerators, 2},
    {field_enumerators, 3},
  [354] =
    {field_pattern, 2},
    {field_type, 0},
  [356] =
    {field_bound, 2},
    {field_bound, 3},
    {field_name, 0},
    {field_type_parameters, 1},
  [360] =
    {field_name, 1},
    {field_name, 2, .inherited = true},
    {field_type, 4},
  [363] =
    {field_bound, 2, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_type, 4},
    {field_type_parameters, 2, .inherited = true},
  [367] =
    {field_body, 4},
    {field_return_type, 2},
  [369] =
    {field_name, 2, .inherited = true},
    {field_parameters, 2, .inherited = true},
    {field_return_type, 4},
    {field_type_parameters, 2, .inherited = true},
  [373] =
    {field_lambda_start, 0},
    {field_lambda_start, 1},
  [375] =
    {field_body, 4},
    {field_class_parameters, 2, .inherited = true},
    {field_extend, 3},
    {field_name, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [380] =
    {field_body, 4},
    {field_class_parameters, 2, .inherited = true},
    {field_derive, 3},
    {field_name, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [385] =
    {field_body, 4, .inherited = true},
    {field_derive, 4, .inherited = true},
    {field_extend, 4, .inherited = true},
    {field_name, 4, .inherited = true},
  [389] =
    {field_body, 4, .inherited = true},
    {field_class_parameters, 4, .inherited = true},
    {field_derive, 4, .inherited = true},
    {field_extend, 4, .inherited = true},
    {field_name, 4, .inherited = true},
    {field_type_parameters, 4, .inherited = true},
  [395] =
    {field_arguments, 4, .inherited = true},
    {field_body, 4, .inherited = true},
    {field_name, 3, .inherited = true},
    {field_parameters, 3, .inherited = true},
    {field_return_type, 4},
    {field_type_parameters, 3, .inherited = true},
  [401] =
    {field_name, 3, .inherited = true},
    {field_parameters, 3, .inherited = true},
    {field_return_type, 4},
    {field_type_parameters, 3, .inherited = true},
  [405] =
    {field_bound, 4, .inherited = true},
    {field_name, 4, .inherited = true},
    {field_type_parameters, 4, .inherited = true},
  [408] =
    {field_default_value, 2},
    {field_name, 0},
  [410] =
    {field_name, 2},
  [411] =
    {field_class_parameters, 4},
    {field_name, 0},
    {field_type_parameters, 1},
  [414] =
    {field_class_parameters, 1, .inherited = true},
    {field_extend, 1, .inherited = true},
    {field_name, 0},
    {field_type_parameters, 1, .inherited = true},
  [418] =
    {field_class_parameters, 0},
  [419] =
    {field_type, 0, .inherited = true},
    {field_type, 1, .inherited = true},
  [421] =
    {field_alias, 2},
    {field_name, 0},
  [423] =
    {field_bound, 1},
    {field_bound, 2},
    {field_bound, 3},
    {field_name, 0},
  [427] =
    {field_alternative, 5},
    {field_condition, 1},
    {field_consequence, 2},
  [430] =
    {field_body, 5},
    {field_enumerators, 1},
    {field_enumerators, 2},
    {field_enumerators, 3},
  [434] =
    {field_pattern, 2},
    {field_pattern, 3},
    {field_type, 0},
  [437] =
    {field_pattern, 1},
    {field_type, 3},
    {field_value, 5},
  [440] =
    {field_body, 5},
    {field_name, 2, .inherited = true},
    {field_parameters, 2, .inherited = true},
    {field_return_type, 3},
    {field_type_parameters, 2, .inherited = true},
  [445] =
    {field_bound, 3, .inherited = true},
    {field_name, 3, .inherited = true},
    {field_type, 5},
    {field_type_parameters, 3, .inherited = true},
  [449] =
    {field_alternative, 5},
    {field_condition, 2},
    {field_consequence, 3},
  [452] =
    {field_body, 5},
    {field_class_parameters, 2, .inherited = true},
    {field_derive, 4},
    {field_extend, 3},
    {field_name, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [458] =
    {field_body, 5},
    {field_return_type, 3},
  [460] =
    {field_name, 3, .inherited = true},
    {field_parameters, 3, .inherited = true},
    {field_return_type, 5},
    {field_type_parameters, 3, .inherited = true},
  [464] =
    {field_default_value, 3},
    {field_name, 1},
  [466] =
    {field_name, 3},
  [467] =
    {field_class_parameters, 1},
    {field_type_parameters, 0},
  [469] =
    {field_class_parameters, 0},
    {field_extend, 1},
  [471] =
    {field_bound, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_return_type, 4},
    {field_type_parameters, 1, .inherited = true},
  [475] =
    {field_bound, 2},
    {field_bound, 3},
    {field_bound, 4},
    {field_name, 0},
    {field_type_parameters, 1},
  [480] =
    {field_bound, 1},
    {field_bound, 2},
    {field_bound, 3},
    {field_bound, 4},
    {field_name, 0},
  [485] =
    {field_default_value, 4},
    {field_name, 0},
    {field_type, 2},
  [488] =
    {field_name, 2},
    {field_type, 4},
  [490] =
    {field_pattern, 2},
    {field_pattern, 3},
    {field_pattern, 4},
    {field_type, 0},
  [494] =
    {field_alternative, 6},
    {field_condition, 2},
    {field_consequence, 3},
  [497] =
    {field_body, 6},
    {field_name, 3, .inherited = true},
    {field_parameters, 3, .inherited = true},
    {field_return_type, 4},
    {field_type_parameters, 3, .inherited = true},
  [502] =
    {field_bound, 4, .inherited = true},
    {field_name, 4, .inherited = true},
    {field_type, 6},
    {field_type_parameters, 4, .inherited = true},
  [506] =
    {field_default_value, 4},
    {field_name, 2},
  [508] =
    {field_class_parameters, 1},
    {field_extend, 2},
    {field_type_parameters, 0},
  [511] =
    {field_bound, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_return_type, 5},
    {field_type_parameters, 1, .inherited = true},
  [515] =
    {field_bound, 1, .inherited = true},
    {field_bound, 2, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_return_type, 5},
    {field_type_parameters, 1, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [522] =
    {field_bound, 2},
    {field_bound, 3},
    {field_bound, 4},
    {field_bound, 5},
    {field_name, 0},
    {field_type_parameters, 1},
  [528] =
    {field_default_value, 5},
    {field_name, 1},
    {field_type, 3},
  [531] =
    {field_body, 2},
    {field_return_type, 2, .inherited = true},
  [533] =
    {field_name, 3},
    {field_type, 5},
  [535] =
    {field_default_value, 5},
    {field_name, 3},
  [537] =
    {field_bound, 1, .inherited = true},
    {field_bound, 2, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_return_type, 6},
    {field_type_parameters, 1, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [544] =
    {field_default_value, 6},
    {field_name, 2},
    {field_type, 4},
  [547] =
    {field_default_value, 7},
    {field_name, 3},
    {field_type, 5},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [7] = {
    [0] = alias_sym_type_identifier,
  },
  [8] = {
    [0] = alias_sym_structural_type,
  },
  [13] = {
    [1] = anon_alias_sym__end_ident,
  },
  [39] = {
    [0] = alias_sym_refinement,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_template_body, 3,
    sym_template_body,
    alias_sym_refinement,
    alias_sym_structural_type,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 2,
  [4] = 2,
  [5] = 2,
  [6] = 2,
  [7] = 2,
  [8] = 2,
  [9] = 2,
  [10] = 2,
  [11] = 2,
  [12] = 2,
  [13] = 2,
  [14] = 2,
  [15] = 2,
  [16] = 2,
  [17] = 2,
  [18] = 2,
  [19] = 2,
  [20] = 2,
  [21] = 2,
  [22] = 2,
  [23] = 2,
  [24] = 2,
  [25] = 2,
  [26] = 2,
  [27] = 2,
  [28] = 2,
  [29] = 2,
  [30] = 2,
  [31] = 2,
  [32] = 2,
  [33] = 2,
  [34] = 2,
  [35] = 2,
  [36] = 2,
  [37] = 2,
  [38] = 2,
  [39] = 2,
  [40] = 2,
  [41] = 2,
  [42] = 2,
  [43] = 2,
  [44] = 2,
  [45] = 2,
  [46] = 2,
  [47] = 2,
  [48] = 2,
  [49] = 2,
  [50] = 2,
  [51] = 2,
  [52] = 2,
  [53] = 2,
  [54] = 2,
  [55] = 2,
  [56] = 2,
  [57] = 2,
  [58] = 2,
  [59] = 2,
  [60] = 2,
  [61] = 2,
  [62] = 2,
  [63] = 2,
  [64] = 2,
  [65] = 2,
  [66] = 2,
  [67] = 2,
  [68] = 2,
  [69] = 2,
  [70] = 2,
  [71] = 2,
  [72] = 2,
  [73] = 2,
  [74] = 2,
  [75] = 2,
  [76] = 2,
  [77] = 2,
  [78] = 2,
  [79] = 2,
  [80] = 2,
  [81] = 2,
  [82] = 2,
  [83] = 2,
  [84] = 2,
  [85] = 2,
  [86] = 2,
  [87] = 2,
  [88] = 2,
  [89] = 2,
  [90] = 2,
  [91] = 2,
  [92] = 2,
  [93] = 2,
  [94] = 2,
  [95] = 2,
  [96] = 2,
  [97] = 2,
  [98] = 2,
  [99] = 2,
  [100] = 2,
  [101] = 2,
  [102] = 2,
  [103] = 2,
  [104] = 2,
  [105] = 2,
  [106] = 2,
  [107] = 2,
  [108] = 2,
  [109] = 2,
  [110] = 2,
  [111] = 2,
  [112] = 2,
  [113] = 2,
  [114] = 2,
  [115] = 2,
  [116] = 2,
  [117] = 2,
  [118] = 2,
  [119] = 2,
  [120] = 120,
  [121] = 121,
  [122] = 121,
  [123] = 121,
  [124] = 121,
  [125] = 121,
  [126] = 121,
  [127] = 121,
  [128] = 121,
  [129] = 121,
  [130] = 130,
  [131] = 121,
  [132] = 121,
  [133] = 121,
  [134] = 134,
  [135] = 121,
  [136] = 121,
  [137] = 121,
  [138] = 121,
  [139] = 121,
  [140] = 121,
  [141] = 121,
  [142] = 121,
  [143] = 121,
  [144] = 121,
  [145] = 121,
  [146] = 121,
  [147] = 121,
  [148] = 148,
  [149] = 149,
  [150] = 149,
  [151] = 151,
  [152] = 149,
  [153] = 149,
  [154] = 149,
  [155] = 149,
  [156] = 149,
  [157] = 149,
  [158] = 149,
  [159] = 149,
  [160] = 149,
  [161] = 149,
  [162] = 149,
  [163] = 149,
  [164] = 149,
  [165] = 149,
  [166] = 149,
  [167] = 149,
  [168] = 168,
  [169] = 149,
  [170] = 149,
  [171] = 149,
  [172] = 149,
  [173] = 149,
  [174] = 149,
  [175] = 149,
  [176] = 149,
  [177] = 149,
  [178] = 149,
  [179] = 149,
  [180] = 149,
  [181] = 149,
  [182] = 149,
  [183] = 149,
  [184] = 149,
  [185] = 149,
  [186] = 149,
  [187] = 149,
  [188] = 149,
  [189] = 149,
  [190] = 149,
  [191] = 149,
  [192] = 149,
  [193] = 149,
  [194] = 194,
  [195] = 194,
  [196] = 194,
  [197] = 197,
  [198] = 194,
  [199] = 194,
  [200] = 194,
  [201] = 201,
  [202] = 194,
  [203] = 194,
  [204] = 194,
  [205] = 197,
  [206] = 194,
  [207] = 194,
  [208] = 194,
  [209] = 209,
  [210] = 194,
  [211] = 194,
  [212] = 194,
  [213] = 201,
  [214] = 194,
  [215] = 194,
  [216] = 194,
  [217] = 197,
  [218] = 194,
  [219] = 194,
  [220] = 194,
  [221] = 221,
  [222] = 194,
  [223] = 194,
  [224] = 194,
  [225] = 225,
  [226] = 194,
  [227] = 194,
  [228] = 194,
  [229] = 197,
  [230] = 194,
  [231] = 194,
  [232] = 194,
  [233] = 233,
  [234] = 194,
  [235] = 194,
  [236] = 194,
  [237] = 194,
  [238] = 194,
  [239] = 194,
  [240] = 194,
  [241] = 225,
  [242] = 194,
  [243] = 194,
  [244] = 194,
  [245] = 194,
  [246] = 194,
  [247] = 194,
  [248] = 194,
  [249] = 194,
  [250] = 194,
  [251] = 194,
  [252] = 194,
  [253] = 194,
  [254] = 194,
  [255] = 194,
  [256] = 194,
  [257] = 194,
  [258] = 194,
  [259] = 194,
  [260] = 194,
  [261] = 194,
  [262] = 194,
  [263] = 194,
  [264] = 194,
  [265] = 233,
  [266] = 194,
  [267] = 194,
  [268] = 194,
  [269] = 194,
  [270] = 194,
  [271] = 194,
  [272] = 194,
  [273] = 194,
  [274] = 194,
  [275] = 194,
  [276] = 194,
  [277] = 194,
  [278] = 194,
  [279] = 194,
  [280] = 194,
  [281] = 194,
  [282] = 194,
  [283] = 194,
  [284] = 194,
  [285] = 194,
  [286] = 194,
  [287] = 194,
  [288] = 194,
  [289] = 194,
  [290] = 194,
  [291] = 194,
  [292] = 194,
  [293] = 194,
  [294] = 194,
  [295] = 194,
  [296] = 194,
  [297] = 194,
  [298] = 194,
  [299] = 194,
  [300] = 194,
  [301] = 194,
  [302] = 194,
  [303] = 194,
  [304] = 194,
  [305] = 194,
  [306] = 194,
  [307] = 194,
  [308] = 194,
  [309] = 194,
  [310] = 194,
  [311] = 194,
  [312] = 194,
  [313] = 194,
  [314] = 194,
  [315] = 194,
  [316] = 194,
  [317] = 194,
  [318] = 194,
  [319] = 194,
  [320] = 194,
  [321] = 194,
  [322] = 194,
  [323] = 194,
  [324] = 324,
  [325] = 324,
  [326] = 326,
  [327] = 327,
  [328] = 324,
  [329] = 326,
  [330] = 327,
  [331] = 324,
  [332] = 326,
  [333] = 327,
  [334] = 324,
  [335] = 326,
  [336] = 327,
  [337] = 324,
  [338] = 326,
  [339] = 327,
  [340] = 324,
  [341] = 326,
  [342] = 327,
  [343] = 324,
  [344] = 326,
  [345] = 327,
  [346] = 324,
  [347] = 326,
  [348] = 327,
  [349] = 324,
  [350] = 326,
  [351] = 327,
  [352] = 324,
  [353] = 326,
  [354] = 327,
  [355] = 324,
  [356] = 326,
  [357] = 327,
  [358] = 326,
  [359] = 327,
  [360] = 324,
  [361] = 326,
  [362] = 327,
  [363] = 324,
  [364] = 326,
  [365] = 327,
  [366] = 324,
  [367] = 326,
  [368] = 327,
  [369] = 324,
  [370] = 326,
  [371] = 327,
  [372] = 324,
  [373] = 326,
  [374] = 327,
  [375] = 324,
  [376] = 326,
  [377] = 327,
  [378] = 324,
  [379] = 326,
  [380] = 324,
  [381] = 326,
  [382] = 324,
  [383] = 326,
  [384] = 324,
  [385] = 326,
  [386] = 326,
  [387] = 326,
  [388] = 326,
  [389] = 326,
  [390] = 326,
  [391] = 326,
  [392] = 326,
  [393] = 326,
  [394] = 326,
  [395] = 326,
  [396] = 326,
  [397] = 326,
  [398] = 398,
  [399] = 326,
  [400] = 326,
  [401] = 324,
  [402] = 402,
  [403] = 326,
  [404] = 326,
  [405] = 326,
  [406] = 326,
  [407] = 407,
  [408] = 326,
  [409] = 409,
  [410] = 326,
  [411] = 326,
  [412] = 327,
  [413] = 326,
  [414] = 326,
  [415] = 326,
  [416] = 326,
  [417] = 417,
  [418] = 326,
  [419] = 326,
  [420] = 326,
  [421] = 326,
  [422] = 326,
  [423] = 326,
  [424] = 326,
  [425] = 407,
  [426] = 326,
  [427] = 326,
  [428] = 398,
  [429] = 326,
  [430] = 326,
  [431] = 326,
  [432] = 326,
  [433] = 326,
  [434] = 326,
  [435] = 326,
  [436] = 326,
  [437] = 326,
  [438] = 326,
  [439] = 407,
  [440] = 326,
  [441] = 326,
  [442] = 398,
  [443] = 326,
  [444] = 326,
  [445] = 326,
  [446] = 326,
  [447] = 326,
  [448] = 326,
  [449] = 407,
  [450] = 326,
  [451] = 398,
  [452] = 326,
  [453] = 326,
  [454] = 326,
  [455] = 326,
  [456] = 326,
  [457] = 326,
  [458] = 326,
  [459] = 326,
  [460] = 326,
  [461] = 409,
  [462] = 326,
  [463] = 327,
  [464] = 326,
  [465] = 324,
  [466] = 326,
  [467] = 326,
  [468] = 326,
  [469] = 326,
  [470] = 326,
  [471] = 326,
  [472] = 417,
  [473] = 326,
  [474] = 326,
  [475] = 327,
  [476] = 326,
  [477] = 324,
  [478] = 326,
  [479] = 402,
  [480] = 326,
  [481] = 326,
  [482] = 326,
  [483] = 326,
  [484] = 327,
  [485] = 326,
  [486] = 324,
  [487] = 326,
  [488] = 326,
  [489] = 326,
  [490] = 326,
  [491] = 326,
  [492] = 327,
  [493] = 326,
  [494] = 324,
  [495] = 326,
  [496] = 326,
  [497] = 326,
  [498] = 326,
  [499] = 326,
  [500] = 327,
  [501] = 326,
  [502] = 324,
  [503] = 326,
  [504] = 326,
  [505] = 326,
  [506] = 326,
  [507] = 326,
  [508] = 327,
  [509] = 509,
  [510] = 510,
  [511] = 509,
  [512] = 509,
  [513] = 510,
  [514] = 514,
  [515] = 514,
  [516] = 516,
  [517] = 516,
  [518] = 509,
  [519] = 519,
  [520] = 519,
  [521] = 521,
  [522] = 521,
  [523] = 521,
  [524] = 524,
  [525] = 524,
  [526] = 524,
  [527] = 524,
  [528] = 524,
  [529] = 529,
  [530] = 529,
  [531] = 529,
  [532] = 529,
  [533] = 529,
  [534] = 529,
  [535] = 529,
  [536] = 536,
  [537] = 536,
  [538] = 529,
  [539] = 529,
  [540] = 536,
  [541] = 529,
  [542] = 536,
  [543] = 529,
  [544] = 529,
  [545] = 529,
  [546] = 536,
  [547] = 536,
  [548] = 529,
  [549] = 536,
  [550] = 536,
  [551] = 536,
  [552] = 529,
  [553] = 529,
  [554] = 536,
  [555] = 536,
  [556] = 529,
  [557] = 536,
  [558] = 529,
  [559] = 536,
  [560] = 536,
  [561] = 536,
  [562] = 536,
  [563] = 529,
  [564] = 529,
  [565] = 529,
  [566] = 536,
  [567] = 536,
  [568] = 536,
  [569] = 536,
  [570] = 536,
  [571] = 536,
  [572] = 536,
  [573] = 536,
  [574] = 529,
  [575] = 529,
  [576] = 536,
  [577] = 536,
  [578] = 536,
  [579] = 536,
  [580] = 580,
  [581] = 580,
  [582] = 580,
  [583] = 580,
  [584] = 536,
  [585] = 580,
  [586] = 536,
  [587] = 580,
  [588] = 536,
  [589] = 580,
  [590] = 580,
  [591] = 580,
  [592] = 580,
  [593] = 580,
  [594] = 580,
  [595] = 580,
  [596] = 580,
  [597] = 580,
  [598] = 580,
  [599] = 580,
  [600] = 529,
  [601] = 580,
  [602] = 536,
  [603] = 529,
  [604] = 580,
  [605] = 580,
  [606] = 536,
  [607] = 580,
  [608] = 580,
  [609] = 580,
  [610] = 580,
  [611] = 529,
  [612] = 580,
  [613] = 580,
  [614] = 536,
  [615] = 536,
  [616] = 580,
  [617] = 580,
  [618] = 580,
  [619] = 536,
  [620] = 536,
  [621] = 580,
  [622] = 536,
  [623] = 580,
  [624] = 580,
  [625] = 536,
  [626] = 580,
  [627] = 580,
  [628] = 536,
  [629] = 580,
  [630] = 580,
  [631] = 631,
  [632] = 631,
  [633] = 631,
  [634] = 631,
  [635] = 631,
  [636] = 536,
  [637] = 631,
  [638] = 631,
  [639] = 631,
  [640] = 536,
  [641] = 631,
  [642] = 631,
  [643] = 631,
  [644] = 536,
  [645] = 631,
  [646] = 631,
  [647] = 631,
  [648] = 536,
  [649] = 631,
  [650] = 631,
  [651] = 631,
  [652] = 631,
  [653] = 631,
  [654] = 631,
  [655] = 631,
  [656] = 631,
  [657] = 631,
  [658] = 631,
  [659] = 631,
  [660] = 631,
  [661] = 536,
  [662] = 631,
  [663] = 631,
  [664] = 631,
  [665] = 631,
  [666] = 666,
  [667] = 631,
  [668] = 666,
  [669] = 631,
  [670] = 670,
  [671] = 666,
  [672] = 670,
  [673] = 666,
  [674] = 631,
  [675] = 670,
  [676] = 666,
  [677] = 670,
  [678] = 666,
  [679] = 670,
  [680] = 666,
  [681] = 631,
  [682] = 670,
  [683] = 666,
  [684] = 670,
  [685] = 666,
  [686] = 670,
  [687] = 666,
  [688] = 631,
  [689] = 670,
  [690] = 666,
  [691] = 670,
  [692] = 666,
  [693] = 670,
  [694] = 536,
  [695] = 631,
  [696] = 666,
  [697] = 536,
  [698] = 670,
  [699] = 666,
  [700] = 670,
  [701] = 666,
  [702] = 631,
  [703] = 670,
  [704] = 631,
  [705] = 666,
  [706] = 670,
  [707] = 666,
  [708] = 670,
  [709] = 666,
  [710] = 631,
  [711] = 670,
  [712] = 666,
  [713] = 670,
  [714] = 666,
  [715] = 670,
  [716] = 666,
  [717] = 631,
  [718] = 670,
  [719] = 666,
  [720] = 670,
  [721] = 666,
  [722] = 670,
  [723] = 631,
  [724] = 631,
  [725] = 670,
  [726] = 666,
  [727] = 670,
  [728] = 666,
  [729] = 670,
  [730] = 670,
  [731] = 666,
  [732] = 631,
  [733] = 670,
  [734] = 666,
  [735] = 670,
  [736] = 666,
  [737] = 670,
  [738] = 666,
  [739] = 670,
  [740] = 666,
  [741] = 631,
  [742] = 670,
  [743] = 666,
  [744] = 670,
  [745] = 666,
  [746] = 670,
  [747] = 666,
  [748] = 670,
  [749] = 666,
  [750] = 670,
  [751] = 631,
  [752] = 666,
  [753] = 670,
  [754] = 666,
  [755] = 670,
  [756] = 666,
  [757] = 670,
  [758] = 666,
  [759] = 670,
  [760] = 666,
  [761] = 670,
  [762] = 631,
  [763] = 666,
  [764] = 670,
  [765] = 666,
  [766] = 670,
  [767] = 666,
  [768] = 670,
  [769] = 666,
  [770] = 670,
  [771] = 666,
  [772] = 670,
  [773] = 631,
  [774] = 666,
  [775] = 670,
  [776] = 666,
  [777] = 670,
  [778] = 666,
  [779] = 670,
  [780] = 666,
  [781] = 670,
  [782] = 666,
  [783] = 670,
  [784] = 666,
  [785] = 670,
  [786] = 666,
  [787] = 670,
  [788] = 631,
  [789] = 666,
  [790] = 670,
  [791] = 666,
  [792] = 670,
  [793] = 666,
  [794] = 670,
  [795] = 666,
  [796] = 670,
  [797] = 536,
  [798] = 631,
  [799] = 631,
  [800] = 631,
  [801] = 631,
  [802] = 631,
  [803] = 631,
  [804] = 631,
  [805] = 631,
  [806] = 666,
  [807] = 807,
  [808] = 808,
  [809] = 809,
  [810] = 810,
  [811] = 811,
  [812] = 807,
  [813] = 813,
  [814] = 814,
  [815] = 814,
  [816] = 816,
  [817] = 814,
  [818] = 818,
  [819] = 819,
  [820] = 808,
  [821] = 809,
  [822] = 810,
  [823] = 811,
  [824] = 807,
  [825] = 813,
  [826] = 818,
  [827] = 818,
  [828] = 816,
  [829] = 814,
  [830] = 818,
  [831] = 819,
  [832] = 808,
  [833] = 809,
  [834] = 810,
  [835] = 811,
  [836] = 807,
  [837] = 813,
  [838] = 819,
  [839] = 819,
  [840] = 816,
  [841] = 814,
  [842] = 818,
  [843] = 819,
  [844] = 808,
  [845] = 809,
  [846] = 810,
  [847] = 811,
  [848] = 807,
  [849] = 813,
  [850] = 808,
  [851] = 808,
  [852] = 816,
  [853] = 814,
  [854] = 818,
  [855] = 819,
  [856] = 808,
  [857] = 809,
  [858] = 810,
  [859] = 811,
  [860] = 807,
  [861] = 813,
  [862] = 862,
  [863] = 809,
  [864] = 816,
  [865] = 814,
  [866] = 818,
  [867] = 819,
  [868] = 808,
  [869] = 809,
  [870] = 810,
  [871] = 811,
  [872] = 807,
  [873] = 813,
  [874] = 874,
  [875] = 875,
  [876] = 813,
  [877] = 877,
  [878] = 878,
  [879] = 816,
  [880] = 877,
  [881] = 809,
  [882] = 882,
  [883] = 883,
  [884] = 810,
  [885] = 885,
  [886] = 886,
  [887] = 862,
  [888] = 874,
  [889] = 877,
  [890] = 883,
  [891] = 891,
  [892] = 892,
  [893] = 893,
  [894] = 894,
  [895] = 895,
  [896] = 811,
  [897] = 875,
  [898] = 898,
  [899] = 891,
  [900] = 878,
  [901] = 892,
  [902] = 893,
  [903] = 882,
  [904] = 807,
  [905] = 875,
  [906] = 898,
  [907] = 894,
  [908] = 878,
  [909] = 809,
  [910] = 813,
  [911] = 882,
  [912] = 895,
  [913] = 875,
  [914] = 898,
  [915] = 878,
  [916] = 882,
  [917] = 816,
  [918] = 875,
  [919] = 898,
  [920] = 885,
  [921] = 878,
  [922] = 882,
  [923] = 875,
  [924] = 898,
  [925] = 886,
  [926] = 878,
  [927] = 814,
  [928] = 882,
  [929] = 818,
  [930] = 875,
  [931] = 898,
  [932] = 819,
  [933] = 878,
  [934] = 808,
  [935] = 882,
  [936] = 862,
  [937] = 875,
  [938] = 898,
  [939] = 874,
  [940] = 878,
  [941] = 878,
  [942] = 882,
  [943] = 877,
  [944] = 875,
  [945] = 898,
  [946] = 809,
  [947] = 878,
  [948] = 882,
  [949] = 883,
  [950] = 875,
  [951] = 898,
  [952] = 810,
  [953] = 878,
  [954] = 811,
  [955] = 882,
  [956] = 891,
  [957] = 875,
  [958] = 898,
  [959] = 892,
  [960] = 878,
  [961] = 893,
  [962] = 882,
  [963] = 807,
  [964] = 875,
  [965] = 898,
  [966] = 894,
  [967] = 878,
  [968] = 813,
  [969] = 882,
  [970] = 895,
  [971] = 875,
  [972] = 898,
  [973] = 883,
  [974] = 878,
  [975] = 810,
  [976] = 882,
  [977] = 816,
  [978] = 875,
  [979] = 898,
  [980] = 878,
  [981] = 814,
  [982] = 882,
  [983] = 818,
  [984] = 875,
  [985] = 898,
  [986] = 819,
  [987] = 878,
  [988] = 808,
  [989] = 882,
  [990] = 809,
  [991] = 875,
  [992] = 898,
  [993] = 878,
  [994] = 810,
  [995] = 882,
  [996] = 811,
  [997] = 875,
  [998] = 898,
  [999] = 807,
  [1000] = 878,
  [1001] = 813,
  [1002] = 882,
  [1003] = 875,
  [1004] = 898,
  [1005] = 811,
  [1006] = 878,
  [1007] = 816,
  [1008] = 882,
  [1009] = 875,
  [1010] = 898,
  [1011] = 814,
  [1012] = 878,
  [1013] = 818,
  [1014] = 882,
  [1015] = 819,
  [1016] = 875,
  [1017] = 898,
  [1018] = 808,
  [1019] = 878,
  [1020] = 809,
  [1021] = 882,
  [1022] = 875,
  [1023] = 898,
  [1024] = 810,
  [1025] = 878,
  [1026] = 811,
  [1027] = 882,
  [1028] = 807,
  [1029] = 875,
  [1030] = 898,
  [1031] = 813,
  [1032] = 878,
  [1033] = 807,
  [1034] = 882,
  [1035] = 813,
  [1036] = 875,
  [1037] = 898,
  [1038] = 816,
  [1039] = 878,
  [1040] = 882,
  [1041] = 814,
  [1042] = 875,
  [1043] = 898,
  [1044] = 818,
  [1045] = 878,
  [1046] = 819,
  [1047] = 882,
  [1048] = 875,
  [1049] = 898,
  [1050] = 808,
  [1051] = 878,
  [1052] = 809,
  [1053] = 882,
  [1054] = 875,
  [1055] = 898,
  [1056] = 878,
  [1057] = 810,
  [1058] = 882,
  [1059] = 875,
  [1060] = 898,
  [1061] = 811,
  [1062] = 878,
  [1063] = 807,
  [1064] = 882,
  [1065] = 875,
  [1066] = 898,
  [1067] = 813,
  [1068] = 878,
  [1069] = 886,
  [1070] = 882,
  [1071] = 875,
  [1072] = 898,
  [1073] = 893,
  [1074] = 878,
  [1075] = 816,
  [1076] = 882,
  [1077] = 875,
  [1078] = 898,
  [1079] = 814,
  [1080] = 878,
  [1081] = 814,
  [1082] = 882,
  [1083] = 875,
  [1084] = 898,
  [1085] = 818,
  [1086] = 878,
  [1087] = 819,
  [1088] = 882,
  [1089] = 875,
  [1090] = 898,
  [1091] = 808,
  [1092] = 878,
  [1093] = 809,
  [1094] = 882,
  [1095] = 875,
  [1096] = 898,
  [1097] = 878,
  [1098] = 810,
  [1099] = 882,
  [1100] = 875,
  [1101] = 898,
  [1102] = 811,
  [1103] = 878,
  [1104] = 807,
  [1105] = 882,
  [1106] = 875,
  [1107] = 898,
  [1108] = 813,
  [1109] = 878,
  [1110] = 816,
  [1111] = 882,
  [1112] = 875,
  [1113] = 898,
  [1114] = 816,
  [1115] = 878,
  [1116] = 882,
  [1117] = 875,
  [1118] = 898,
  [1119] = 816,
  [1120] = 878,
  [1121] = 882,
  [1122] = 875,
  [1123] = 898,
  [1124] = 818,
  [1125] = 878,
  [1126] = 882,
  [1127] = 875,
  [1128] = 898,
  [1129] = 814,
  [1130] = 878,
  [1131] = 882,
  [1132] = 875,
  [1133] = 898,
  [1134] = 818,
  [1135] = 878,
  [1136] = 882,
  [1137] = 875,
  [1138] = 898,
  [1139] = 819,
  [1140] = 878,
  [1141] = 882,
  [1142] = 875,
  [1143] = 898,
  [1144] = 808,
  [1145] = 878,
  [1146] = 882,
  [1147] = 875,
  [1148] = 898,
  [1149] = 809,
  [1150] = 878,
  [1151] = 882,
  [1152] = 875,
  [1153] = 898,
  [1154] = 878,
  [1155] = 882,
  [1156] = 875,
  [1157] = 898,
  [1158] = 810,
  [1159] = 878,
  [1160] = 882,
  [1161] = 875,
  [1162] = 898,
  [1163] = 811,
  [1164] = 878,
  [1165] = 882,
  [1166] = 875,
  [1167] = 898,
  [1168] = 807,
  [1169] = 878,
  [1170] = 882,
  [1171] = 875,
  [1172] = 898,
  [1173] = 813,
  [1174] = 878,
  [1175] = 882,
  [1176] = 875,
  [1177] = 898,
  [1178] = 810,
  [1179] = 878,
  [1180] = 882,
  [1181] = 875,
  [1182] = 898,
  [1183] = 811,
  [1184] = 878,
  [1185] = 882,
  [1186] = 875,
  [1187] = 816,
  [1188] = 878,
  [1189] = 882,
  [1190] = 875,
  [1191] = 891,
  [1192] = 878,
  [1193] = 882,
  [1194] = 875,
  [1195] = 814,
  [1196] = 878,
  [1197] = 882,
  [1198] = 875,
  [1199] = 818,
  [1200] = 878,
  [1201] = 882,
  [1202] = 875,
  [1203] = 819,
  [1204] = 808,
  [1205] = 809,
  [1206] = 810,
  [1207] = 811,
  [1208] = 807,
  [1209] = 813,
  [1210] = 536,
  [1211] = 816,
  [1212] = 814,
  [1213] = 818,
  [1214] = 819,
  [1215] = 808,
  [1216] = 809,
  [1217] = 810,
  [1218] = 811,
  [1219] = 807,
  [1220] = 813,
  [1221] = 536,
  [1222] = 814,
  [1223] = 816,
  [1224] = 892,
  [1225] = 814,
  [1226] = 818,
  [1227] = 819,
  [1228] = 808,
  [1229] = 809,
  [1230] = 810,
  [1231] = 811,
  [1232] = 807,
  [1233] = 813,
  [1234] = 893,
  [1235] = 818,
  [1236] = 816,
  [1237] = 807,
  [1238] = 814,
  [1239] = 818,
  [1240] = 819,
  [1241] = 808,
  [1242] = 809,
  [1243] = 810,
  [1244] = 811,
  [1245] = 819,
  [1246] = 813,
  [1247] = 808,
  [1248] = 816,
  [1249] = 814,
  [1250] = 818,
  [1251] = 819,
  [1252] = 808,
  [1253] = 809,
  [1254] = 810,
  [1255] = 811,
  [1256] = 807,
  [1257] = 809,
  [1258] = 898,
  [1259] = 813,
  [1260] = 894,
  [1261] = 816,
  [1262] = 810,
  [1263] = 885,
  [1264] = 814,
  [1265] = 818,
  [1266] = 819,
  [1267] = 808,
  [1268] = 898,
  [1269] = 878,
  [1270] = 882,
  [1271] = 811,
  [1272] = 898,
  [1273] = 809,
  [1274] = 810,
  [1275] = 807,
  [1276] = 811,
  [1277] = 807,
  [1278] = 898,
  [1279] = 813,
  [1280] = 813,
  [1281] = 813,
  [1282] = 807,
  [1283] = 816,
  [1284] = 898,
  [1285] = 816,
  [1286] = 814,
  [1287] = 818,
  [1288] = 819,
  [1289] = 894,
  [1290] = 808,
  [1291] = 809,
  [1292] = 814,
  [1293] = 810,
  [1294] = 811,
  [1295] = 818,
  [1296] = 807,
  [1297] = 813,
  [1298] = 819,
  [1299] = 895,
  [1300] = 808,
  [1301] = 816,
  [1302] = 809,
  [1303] = 819,
  [1304] = 814,
  [1305] = 818,
  [1306] = 819,
  [1307] = 808,
  [1308] = 810,
  [1309] = 809,
  [1310] = 811,
  [1311] = 810,
  [1312] = 811,
  [1313] = 807,
  [1314] = 807,
  [1315] = 813,
  [1316] = 536,
  [1317] = 813,
  [1318] = 814,
  [1319] = 816,
  [1320] = 818,
  [1321] = 814,
  [1322] = 818,
  [1323] = 816,
  [1324] = 819,
  [1325] = 808,
  [1326] = 809,
  [1327] = 875,
  [1328] = 810,
  [1329] = 814,
  [1330] = 811,
  [1331] = 807,
  [1332] = 813,
  [1333] = 818,
  [1334] = 819,
  [1335] = 808,
  [1336] = 809,
  [1337] = 816,
  [1338] = 814,
  [1339] = 810,
  [1340] = 818,
  [1341] = 819,
  [1342] = 811,
  [1343] = 808,
  [1344] = 809,
  [1345] = 807,
  [1346] = 810,
  [1347] = 811,
  [1348] = 813,
  [1349] = 807,
  [1350] = 813,
  [1351] = 813,
  [1352] = 819,
  [1353] = 816,
  [1354] = 816,
  [1355] = 895,
  [1356] = 814,
  [1357] = 818,
  [1358] = 814,
  [1359] = 819,
  [1360] = 808,
  [1361] = 818,
  [1362] = 809,
  [1363] = 810,
  [1364] = 819,
  [1365] = 811,
  [1366] = 807,
  [1367] = 808,
  [1368] = 813,
  [1369] = 536,
  [1370] = 809,
  [1371] = 816,
  [1372] = 816,
  [1373] = 810,
  [1374] = 814,
  [1375] = 818,
  [1376] = 819,
  [1377] = 811,
  [1378] = 808,
  [1379] = 809,
  [1380] = 807,
  [1381] = 810,
  [1382] = 811,
  [1383] = 813,
  [1384] = 807,
  [1385] = 813,
  [1386] = 898,
  [1387] = 885,
  [1388] = 808,
  [1389] = 816,
  [1390] = 816,
  [1391] = 529,
  [1392] = 814,
  [1393] = 809,
  [1394] = 818,
  [1395] = 819,
  [1396] = 808,
  [1397] = 814,
  [1398] = 809,
  [1399] = 818,
  [1400] = 810,
  [1401] = 811,
  [1402] = 807,
  [1403] = 819,
  [1404] = 813,
  [1405] = 808,
  [1406] = 808,
  [1407] = 809,
  [1408] = 816,
  [1409] = 814,
  [1410] = 818,
  [1411] = 810,
  [1412] = 819,
  [1413] = 808,
  [1414] = 809,
  [1415] = 811,
  [1416] = 810,
  [1417] = 807,
  [1418] = 811,
  [1419] = 807,
  [1420] = 813,
  [1421] = 813,
  [1422] = 810,
  [1423] = 816,
  [1424] = 816,
  [1425] = 862,
  [1426] = 814,
  [1427] = 814,
  [1428] = 818,
  [1429] = 819,
  [1430] = 818,
  [1431] = 808,
  [1432] = 809,
  [1433] = 819,
  [1434] = 808,
  [1435] = 810,
  [1436] = 811,
  [1437] = 809,
  [1438] = 807,
  [1439] = 813,
  [1440] = 886,
  [1441] = 810,
  [1442] = 811,
  [1443] = 807,
  [1444] = 816,
  [1445] = 813,
  [1446] = 814,
  [1447] = 816,
  [1448] = 818,
  [1449] = 819,
  [1450] = 811,
  [1451] = 808,
  [1452] = 816,
  [1453] = 809,
  [1454] = 810,
  [1455] = 814,
  [1456] = 811,
  [1457] = 807,
  [1458] = 818,
  [1459] = 813,
  [1460] = 819,
  [1461] = 814,
  [1462] = 808,
  [1463] = 809,
  [1464] = 816,
  [1465] = 818,
  [1466] = 814,
  [1467] = 810,
  [1468] = 818,
  [1469] = 811,
  [1470] = 819,
  [1471] = 808,
  [1472] = 807,
  [1473] = 809,
  [1474] = 813,
  [1475] = 810,
  [1476] = 807,
  [1477] = 811,
  [1478] = 813,
  [1479] = 807,
  [1480] = 813,
  [1481] = 816,
  [1482] = 819,
  [1483] = 814,
  [1484] = 816,
  [1485] = 818,
  [1486] = 808,
  [1487] = 819,
  [1488] = 814,
  [1489] = 818,
  [1490] = 808,
  [1491] = 819,
  [1492] = 809,
  [1493] = 808,
  [1494] = 809,
  [1495] = 810,
  [1496] = 810,
  [1497] = 811,
  [1498] = 811,
  [1499] = 807,
  [1500] = 807,
  [1501] = 813,
  [1502] = 813,
  [1503] = 885,
  [1504] = 862,
  [1505] = 891,
  [1506] = 816,
  [1507] = 816,
  [1508] = 814,
  [1509] = 818,
  [1510] = 814,
  [1511] = 818,
  [1512] = 819,
  [1513] = 808,
  [1514] = 819,
  [1515] = 808,
  [1516] = 809,
  [1517] = 809,
  [1518] = 810,
  [1519] = 811,
  [1520] = 810,
  [1521] = 811,
  [1522] = 807,
  [1523] = 813,
  [1524] = 807,
  [1525] = 813,
  [1526] = 811,
  [1527] = 816,
  [1528] = 814,
  [1529] = 816,
  [1530] = 874,
  [1531] = 818,
  [1532] = 819,
  [1533] = 814,
  [1534] = 818,
  [1535] = 808,
  [1536] = 809,
  [1537] = 819,
  [1538] = 808,
  [1539] = 810,
  [1540] = 809,
  [1541] = 810,
  [1542] = 811,
  [1543] = 807,
  [1544] = 813,
  [1545] = 811,
  [1546] = 807,
  [1547] = 816,
  [1548] = 874,
  [1549] = 814,
  [1550] = 818,
  [1551] = 819,
  [1552] = 808,
  [1553] = 809,
  [1554] = 810,
  [1555] = 811,
  [1556] = 807,
  [1557] = 813,
  [1558] = 882,
  [1559] = 813,
  [1560] = 816,
  [1561] = 877,
  [1562] = 814,
  [1563] = 818,
  [1564] = 819,
  [1565] = 808,
  [1566] = 809,
  [1567] = 810,
  [1568] = 811,
  [1569] = 807,
  [1570] = 813,
  [1571] = 809,
  [1572] = 816,
  [1573] = 816,
  [1574] = 814,
  [1575] = 818,
  [1576] = 819,
  [1577] = 808,
  [1578] = 809,
  [1579] = 810,
  [1580] = 811,
  [1581] = 807,
  [1582] = 813,
  [1583] = 892,
  [1584] = 816,
  [1585] = 814,
  [1586] = 818,
  [1587] = 819,
  [1588] = 808,
  [1589] = 809,
  [1590] = 810,
  [1591] = 811,
  [1592] = 807,
  [1593] = 813,
  [1594] = 816,
  [1595] = 816,
  [1596] = 814,
  [1597] = 818,
  [1598] = 819,
  [1599] = 808,
  [1600] = 809,
  [1601] = 810,
  [1602] = 811,
  [1603] = 807,
  [1604] = 813,
  [1605] = 883,
  [1606] = 886,
  [1607] = 816,
  [1608] = 814,
  [1609] = 818,
  [1610] = 819,
  [1611] = 808,
  [1612] = 809,
  [1613] = 810,
  [1614] = 811,
  [1615] = 807,
  [1616] = 813,
  [1617] = 814,
  [1618] = 816,
  [1619] = 814,
  [1620] = 818,
  [1621] = 819,
  [1622] = 808,
  [1623] = 809,
  [1624] = 810,
  [1625] = 811,
  [1626] = 807,
  [1627] = 813,
  [1628] = 818,
  [1629] = 816,
  [1630] = 814,
  [1631] = 818,
  [1632] = 819,
  [1633] = 808,
  [1634] = 809,
  [1635] = 810,
  [1636] = 811,
  [1637] = 807,
  [1638] = 813,
  [1639] = 810,
  [1640] = 819,
  [1641] = 816,
  [1642] = 814,
  [1643] = 818,
  [1644] = 819,
  [1645] = 808,
  [1646] = 809,
  [1647] = 810,
  [1648] = 811,
  [1649] = 807,
  [1650] = 898,
  [1651] = 1651,
  [1652] = 1651,
  [1653] = 1651,
  [1654] = 1651,
  [1655] = 1651,
  [1656] = 1651,
  [1657] = 1651,
  [1658] = 1651,
  [1659] = 1651,
  [1660] = 1651,
  [1661] = 1651,
  [1662] = 529,
  [1663] = 1651,
  [1664] = 1651,
  [1665] = 1651,
  [1666] = 1651,
  [1667] = 529,
  [1668] = 1651,
  [1669] = 1651,
  [1670] = 1651,
  [1671] = 1651,
  [1672] = 1651,
  [1673] = 1651,
  [1674] = 1651,
  [1675] = 1651,
  [1676] = 529,
  [1677] = 1651,
  [1678] = 1651,
  [1679] = 1651,
  [1680] = 1651,
  [1681] = 1651,
  [1682] = 1651,
  [1683] = 529,
  [1684] = 1651,
  [1685] = 1651,
  [1686] = 1651,
  [1687] = 1651,
  [1688] = 1651,
  [1689] = 1651,
  [1690] = 1651,
  [1691] = 1651,
  [1692] = 1651,
  [1693] = 1651,
  [1694] = 1651,
  [1695] = 529,
  [1696] = 1651,
  [1697] = 1651,
  [1698] = 529,
  [1699] = 1651,
  [1700] = 1651,
  [1701] = 1651,
  [1702] = 529,
  [1703] = 529,
  [1704] = 1651,
  [1705] = 1651,
  [1706] = 1651,
  [1707] = 1651,
  [1708] = 1651,
  [1709] = 1651,
  [1710] = 529,
  [1711] = 1651,
  [1712] = 529,
  [1713] = 1651,
  [1714] = 1651,
  [1715] = 1651,
  [1716] = 1651,
  [1717] = 1651,
  [1718] = 1651,
  [1719] = 1651,
  [1720] = 1651,
  [1721] = 536,
  [1722] = 529,
  [1723] = 1651,
  [1724] = 1651,
  [1725] = 1651,
  [1726] = 1651,
  [1727] = 529,
  [1728] = 1651,
  [1729] = 1651,
  [1730] = 529,
  [1731] = 1651,
  [1732] = 1651,
  [1733] = 1651,
  [1734] = 1651,
  [1735] = 1651,
  [1736] = 1651,
  [1737] = 1651,
  [1738] = 1651,
  [1739] = 1651,
  [1740] = 1651,
  [1741] = 1651,
  [1742] = 1651,
  [1743] = 529,
  [1744] = 1651,
  [1745] = 529,
  [1746] = 1651,
  [1747] = 529,
  [1748] = 1651,
  [1749] = 1651,
  [1750] = 1651,
  [1751] = 1651,
  [1752] = 529,
  [1753] = 1651,
  [1754] = 529,
  [1755] = 1651,
  [1756] = 1651,
  [1757] = 1651,
  [1758] = 536,
  [1759] = 1651,
  [1760] = 529,
  [1761] = 1651,
  [1762] = 1651,
  [1763] = 1651,
  [1764] = 1651,
  [1765] = 1651,
  [1766] = 529,
  [1767] = 1651,
  [1768] = 1651,
  [1769] = 529,
  [1770] = 1651,
  [1771] = 1651,
  [1772] = 1651,
  [1773] = 1651,
  [1774] = 1651,
  [1775] = 1651,
  [1776] = 1651,
  [1777] = 529,
  [1778] = 1651,
  [1779] = 1651,
  [1780] = 1651,
  [1781] = 1651,
  [1782] = 1651,
  [1783] = 1651,
  [1784] = 529,
  [1785] = 1651,
  [1786] = 1651,
  [1787] = 1651,
  [1788] = 1651,
  [1789] = 529,
  [1790] = 1651,
  [1791] = 1651,
  [1792] = 1651,
  [1793] = 529,
  [1794] = 1651,
  [1795] = 1651,
  [1796] = 1651,
  [1797] = 1651,
  [1798] = 1651,
  [1799] = 1651,
  [1800] = 1800,
  [1801] = 1800,
  [1802] = 1800,
  [1803] = 1800,
  [1804] = 1800,
  [1805] = 1800,
  [1806] = 1800,
  [1807] = 1800,
  [1808] = 1800,
  [1809] = 1800,
  [1810] = 1800,
  [1811] = 1800,
  [1812] = 1800,
  [1813] = 1800,
  [1814] = 1800,
  [1815] = 1800,
  [1816] = 1800,
  [1817] = 536,
  [1818] = 1800,
  [1819] = 1800,
  [1820] = 1800,
  [1821] = 1800,
  [1822] = 1800,
  [1823] = 1800,
  [1824] = 1800,
  [1825] = 1800,
  [1826] = 536,
  [1827] = 1800,
  [1828] = 1800,
  [1829] = 1829,
  [1830] = 1829,
  [1831] = 1829,
  [1832] = 1832,
  [1833] = 1832,
  [1834] = 1829,
  [1835] = 1829,
  [1836] = 1829,
  [1837] = 1832,
  [1838] = 1829,
  [1839] = 1829,
  [1840] = 1840,
  [1841] = 1840,
  [1842] = 1829,
  [1843] = 1832,
  [1844] = 1840,
  [1845] = 1829,
  [1846] = 1840,
  [1847] = 1832,
  [1848] = 1829,
  [1849] = 1829,
  [1850] = 1832,
  [1851] = 1829,
  [1852] = 1832,
  [1853] = 1832,
  [1854] = 1829,
  [1855] = 1840,
  [1856] = 1829,
  [1857] = 1829,
  [1858] = 1832,
  [1859] = 1832,
  [1860] = 1829,
  [1861] = 1840,
  [1862] = 1829,
  [1863] = 1829,
  [1864] = 1829,
  [1865] = 1840,
  [1866] = 1829,
  [1867] = 1829,
  [1868] = 1832,
  [1869] = 1829,
  [1870] = 1829,
  [1871] = 1832,
  [1872] = 1829,
  [1873] = 1832,
  [1874] = 1829,
  [1875] = 1829,
  [1876] = 1829,
  [1877] = 1829,
  [1878] = 1829,
  [1879] = 1832,
  [1880] = 1832,
  [1881] = 1829,
  [1882] = 1840,
  [1883] = 1832,
  [1884] = 1829,
  [1885] = 1832,
  [1886] = 1829,
  [1887] = 1829,
  [1888] = 1829,
  [1889] = 1840,
  [1890] = 1829,
  [1891] = 1891,
  [1892] = 1829,
  [1893] = 1829,
  [1894] = 1840,
  [1895] = 1829,
  [1896] = 1829,
  [1897] = 1840,
  [1898] = 1832,
  [1899] = 1829,
  [1900] = 1832,
  [1901] = 1829,
  [1902] = 1829,
  [1903] = 1829,
  [1904] = 1840,
  [1905] = 1829,
  [1906] = 1840,
  [1907] = 1832,
  [1908] = 1829,
  [1909] = 1829,
  [1910] = 1832,
  [1911] = 1829,
  [1912] = 1832,
  [1913] = 1840,
  [1914] = 1829,
  [1915] = 1832,
  [1916] = 1829,
  [1917] = 1829,
  [1918] = 1829,
  [1919] = 1832,
  [1920] = 1829,
  [1921] = 1832,
  [1922] = 1832,
  [1923] = 1829,
  [1924] = 1840,
  [1925] = 1832,
  [1926] = 1829,
  [1927] = 1829,
  [1928] = 1829,
  [1929] = 1829,
  [1930] = 1832,
  [1931] = 1840,
  [1932] = 1829,
  [1933] = 1832,
  [1934] = 1829,
  [1935] = 1829,
  [1936] = 1829,
  [1937] = 1832,
  [1938] = 1829,
  [1939] = 1829,
  [1940] = 1829,
  [1941] = 1829,
  [1942] = 1832,
  [1943] = 1829,
  [1944] = 1829,
  [1945] = 1832,
  [1946] = 1832,
  [1947] = 1829,
  [1948] = 1829,
  [1949] = 1832,
  [1950] = 1829,
  [1951] = 1832,
  [1952] = 1832,
  [1953] = 1829,
  [1954] = 1840,
  [1955] = 1840,
  [1956] = 1829,
  [1957] = 1829,
  [1958] = 1829,
  [1959] = 1829,
  [1960] = 1829,
  [1961] = 1829,
  [1962] = 1829,
  [1963] = 1832,
  [1964] = 1840,
  [1965] = 1829,
  [1966] = 1829,
  [1967] = 1832,
  [1968] = 1829,
  [1969] = 1829,
  [1970] = 1829,
  [1971] = 1829,
  [1972] = 1840,
  [1973] = 1829,
  [1974] = 1829,
  [1975] = 1832,
  [1976] = 1832,
  [1977] = 1829,
  [1978] = 1829,
  [1979] = 1832,
  [1980] = 1829,
  [1981] = 1840,
  [1982] = 1840,
  [1983] = 1829,
  [1984] = 1832,
  [1985] = 1829,
  [1986] = 1829,
  [1987] = 1832,
  [1988] = 1988,
  [1989] = 1829,
  [1990] = 1832,
  [1991] = 1832,
  [1992] = 1829,
  [1993] = 1829,
  [1994] = 1829,
  [1995] = 1829,
  [1996] = 1832,
  [1997] = 1829,
  [1998] = 1829,
  [1999] = 1832,
  [2000] = 1829,
  [2001] = 1829,
  [2002] = 1829,
  [2003] = 1840,
  [2004] = 1829,
  [2005] = 1832,
  [2006] = 1829,
  [2007] = 1829,
  [2008] = 1829,
  [2009] = 1832,
  [2010] = 1829,
  [2011] = 1832,
  [2012] = 1832,
  [2013] = 1829,
  [2014] = 1840,
  [2015] = 1832,
  [2016] = 1829,
  [2017] = 1840,
  [2018] = 1829,
  [2019] = 1829,
  [2020] = 1829,
  [2021] = 1829,
  [2022] = 1829,
  [2023] = 1832,
  [2024] = 1829,
  [2025] = 1829,
  [2026] = 1829,
  [2027] = 1829,
  [2028] = 1832,
  [2029] = 1832,
  [2030] = 1829,
  [2031] = 1832,
  [2032] = 1829,
  [2033] = 1829,
  [2034] = 2034,
  [2035] = 2035,
  [2036] = 2036,
  [2037] = 2037,
  [2038] = 2034,
  [2039] = 2036,
  [2040] = 2035,
  [2041] = 2041,
  [2042] = 2035,
  [2043] = 2036,
  [2044] = 2034,
  [2045] = 2035,
  [2046] = 2034,
  [2047] = 2034,
  [2048] = 2036,
  [2049] = 2049,
  [2050] = 2050,
  [2051] = 2035,
  [2052] = 2036,
  [2053] = 2035,
  [2054] = 2054,
  [2055] = 2035,
  [2056] = 2034,
  [2057] = 2035,
  [2058] = 2036,
  [2059] = 2034,
  [2060] = 2034,
  [2061] = 2034,
  [2062] = 2036,
  [2063] = 2035,
  [2064] = 2064,
  [2065] = 2036,
  [2066] = 2034,
  [2067] = 2035,
  [2068] = 2034,
  [2069] = 2035,
  [2070] = 2034,
  [2071] = 2071,
  [2072] = 2035,
  [2073] = 2073,
  [2074] = 2037,
  [2075] = 2034,
  [2076] = 2041,
  [2077] = 2036,
  [2078] = 2049,
  [2079] = 2049,
  [2080] = 2035,
  [2081] = 2050,
  [2082] = 2036,
  [2083] = 2034,
  [2084] = 2049,
  [2085] = 2050,
  [2086] = 2035,
  [2087] = 2035,
  [2088] = 2034,
  [2089] = 2034,
  [2090] = 2071,
  [2091] = 2073,
  [2092] = 2037,
  [2093] = 2054,
  [2094] = 2041,
  [2095] = 2036,
  [2096] = 2049,
  [2097] = 2050,
  [2098] = 2035,
  [2099] = 2035,
  [2100] = 2100,
  [2101] = 2034,
  [2102] = 2034,
  [2103] = 2041,
  [2104] = 2036,
  [2105] = 2049,
  [2106] = 2050,
  [2107] = 2050,
  [2108] = 2035,
  [2109] = 2109,
  [2110] = 2034,
  [2111] = 2041,
  [2112] = 2036,
  [2113] = 2049,
  [2114] = 2050,
  [2115] = 2035,
  [2116] = 2034,
  [2117] = 2035,
  [2118] = 2034,
  [2119] = 2041,
  [2120] = 2036,
  [2121] = 2049,
  [2122] = 2050,
  [2123] = 2123,
  [2124] = 2124,
  [2125] = 2050,
  [2126] = 2035,
  [2127] = 2035,
  [2128] = 2034,
  [2129] = 2041,
  [2130] = 2036,
  [2131] = 2049,
  [2132] = 2050,
  [2133] = 2034,
  [2134] = 2134,
  [2135] = 2035,
  [2136] = 2136,
  [2137] = 2034,
  [2138] = 2138,
  [2139] = 2041,
  [2140] = 2036,
  [2141] = 2049,
  [2142] = 2050,
  [2143] = 2143,
  [2144] = 2035,
  [2145] = 2145,
  [2146] = 2146,
  [2147] = 2034,
  [2148] = 2049,
  [2149] = 2041,
  [2150] = 2036,
  [2151] = 2049,
  [2152] = 2050,
  [2153] = 2035,
  [2154] = 2035,
  [2155] = 2034,
  [2156] = 2035,
  [2157] = 2034,
  [2158] = 2041,
  [2159] = 2036,
  [2160] = 2049,
  [2161] = 2050,
  [2162] = 2050,
  [2163] = 2034,
  [2164] = 2035,
  [2165] = 2073,
  [2166] = 2034,
  [2167] = 2041,
  [2168] = 2036,
  [2169] = 2049,
  [2170] = 2050,
  [2171] = 2035,
  [2172] = 2035,
  [2173] = 2034,
  [2174] = 2034,
  [2175] = 2035,
  [2176] = 2041,
  [2177] = 2036,
  [2178] = 2049,
  [2179] = 2050,
  [2180] = 2034,
  [2181] = 2041,
  [2182] = 2036,
  [2183] = 2049,
  [2184] = 2050,
  [2185] = 2035,
  [2186] = 2034,
  [2187] = 2035,
  [2188] = 2034,
  [2189] = 2041,
  [2190] = 2036,
  [2191] = 2049,
  [2192] = 2050,
  [2193] = 2035,
  [2194] = 2034,
  [2195] = 2035,
  [2196] = 2034,
  [2197] = 2041,
  [2198] = 2036,
  [2199] = 2049,
  [2200] = 2050,
  [2201] = 2035,
  [2202] = 2202,
  [2203] = 2034,
  [2204] = 2041,
  [2205] = 2036,
  [2206] = 2049,
  [2207] = 2050,
  [2208] = 2035,
  [2209] = 2034,
  [2210] = 2035,
  [2211] = 2041,
  [2212] = 2036,
  [2213] = 2049,
  [2214] = 2050,
  [2215] = 2034,
  [2216] = 2035,
  [2217] = 2071,
  [2218] = 2034,
  [2219] = 2041,
  [2220] = 2036,
  [2221] = 2049,
  [2222] = 2050,
  [2223] = 2035,
  [2224] = 2034,
  [2225] = 2035,
  [2226] = 2036,
  [2227] = 2049,
  [2228] = 2050,
  [2229] = 2035,
  [2230] = 2034,
  [2231] = 2035,
  [2232] = 2034,
  [2233] = 2034,
  [2234] = 2036,
  [2235] = 2049,
  [2236] = 2050,
  [2237] = 2049,
  [2238] = 2036,
  [2239] = 2049,
  [2240] = 2035,
  [2241] = 2035,
  [2242] = 2034,
  [2243] = 2034,
  [2244] = 2035,
  [2245] = 2036,
  [2246] = 2049,
  [2247] = 2050,
  [2248] = 2034,
  [2249] = 2035,
  [2250] = 2034,
  [2251] = 2035,
  [2252] = 2036,
  [2253] = 2050,
  [2254] = 2034,
  [2255] = 2035,
  [2256] = 2049,
  [2257] = 2034,
  [2258] = 2036,
  [2259] = 2035,
  [2260] = 2035,
  [2261] = 2034,
  [2262] = 2034,
  [2263] = 2036,
  [2264] = 2035,
  [2265] = 2034,
  [2266] = 2036,
  [2267] = 2035,
  [2268] = 2268,
  [2269] = 2035,
  [2270] = 2036,
  [2271] = 2034,
  [2272] = 2035,
  [2273] = 2034,
  [2274] = 2036,
  [2275] = 2268,
  [2276] = 2054,
  [2277] = 2268,
  [2278] = 2054,
  [2279] = 2268,
  [2280] = 2054,
  [2281] = 2268,
  [2282] = 2054,
  [2283] = 2268,
  [2284] = 2054,
  [2285] = 2268,
  [2286] = 2054,
  [2287] = 2268,
  [2288] = 2054,
  [2289] = 2268,
  [2290] = 2054,
  [2291] = 2268,
  [2292] = 2054,
  [2293] = 2268,
  [2294] = 2054,
  [2295] = 2268,
  [2296] = 2054,
  [2297] = 2268,
  [2298] = 2054,
  [2299] = 2268,
  [2300] = 2054,
  [2301] = 2268,
  [2302] = 2054,
  [2303] = 2268,
  [2304] = 2054,
  [2305] = 2268,
  [2306] = 2054,
  [2307] = 2268,
  [2308] = 2054,
  [2309] = 2054,
  [2310] = 2054,
  [2311] = 2054,
  [2312] = 2054,
  [2313] = 2054,
  [2314] = 2054,
  [2315] = 2054,
  [2316] = 2054,
  [2317] = 2054,
  [2318] = 2054,
  [2319] = 2054,
  [2320] = 2054,
  [2321] = 2054,
  [2322] = 2054,
  [2323] = 2054,
  [2324] = 2054,
  [2325] = 2054,
  [2326] = 2054,
  [2327] = 2054,
  [2328] = 2054,
  [2329] = 2054,
  [2330] = 2054,
  [2331] = 2035,
  [2332] = 2054,
  [2333] = 2054,
  [2334] = 2054,
  [2335] = 2054,
  [2336] = 2054,
  [2337] = 2054,
  [2338] = 2054,
  [2339] = 2054,
  [2340] = 2054,
  [2341] = 2054,
  [2342] = 2054,
  [2343] = 2054,
  [2344] = 2054,
  [2345] = 2054,
  [2346] = 2054,
  [2347] = 2034,
  [2348] = 2348,
  [2349] = 2348,
  [2350] = 2348,
  [2351] = 2351,
  [2352] = 2351,
  [2353] = 2351,
  [2354] = 2351,
  [2355] = 2351,
  [2356] = 2351,
  [2357] = 2351,
  [2358] = 2351,
  [2359] = 2351,
  [2360] = 2351,
  [2361] = 2351,
  [2362] = 2351,
  [2363] = 2351,
  [2364] = 2351,
  [2365] = 2351,
  [2366] = 2351,
  [2367] = 2351,
  [2368] = 2351,
  [2369] = 2351,
  [2370] = 2351,
  [2371] = 2351,
  [2372] = 2351,
  [2373] = 2351,
  [2374] = 2351,
  [2375] = 2351,
  [2376] = 2351,
  [2377] = 2351,
  [2378] = 2351,
  [2379] = 2351,
  [2380] = 2351,
  [2381] = 2351,
  [2382] = 2351,
  [2383] = 2351,
  [2384] = 2351,
  [2385] = 2351,
  [2386] = 2351,
  [2387] = 2351,
  [2388] = 2351,
  [2389] = 2351,
  [2390] = 2351,
  [2391] = 2351,
  [2392] = 2351,
  [2393] = 2351,
  [2394] = 2351,
  [2395] = 2351,
  [2396] = 2351,
  [2397] = 2351,
  [2398] = 2351,
  [2399] = 2399,
  [2400] = 2400,
  [2401] = 2401,
  [2402] = 2402,
  [2403] = 2400,
  [2404] = 2401,
  [2405] = 2399,
  [2406] = 2406,
  [2407] = 2407,
  [2408] = 2401,
  [2409] = 2407,
  [2410] = 2406,
  [2411] = 2406,
  [2412] = 2412,
  [2413] = 2412,
  [2414] = 2412,
  [2415] = 2412,
  [2416] = 2412,
  [2417] = 2412,
  [2418] = 2412,
  [2419] = 2412,
  [2420] = 2412,
  [2421] = 2412,
  [2422] = 2412,
  [2423] = 2412,
  [2424] = 2412,
  [2425] = 2412,
  [2426] = 2412,
  [2427] = 2412,
  [2428] = 2412,
  [2429] = 2412,
  [2430] = 2412,
  [2431] = 2412,
  [2432] = 2412,
  [2433] = 2412,
  [2434] = 2412,
  [2435] = 2412,
  [2436] = 2436,
  [2437] = 2436,
  [2438] = 2438,
  [2439] = 2438,
  [2440] = 2436,
  [2441] = 2438,
  [2442] = 2436,
  [2443] = 2436,
  [2444] = 2438,
  [2445] = 2436,
  [2446] = 2436,
  [2447] = 2436,
  [2448] = 2438,
  [2449] = 2438,
  [2450] = 2438,
  [2451] = 2438,
  [2452] = 2438,
  [2453] = 2436,
  [2454] = 2438,
  [2455] = 2436,
  [2456] = 2436,
  [2457] = 2436,
  [2458] = 2438,
  [2459] = 2459,
  [2460] = 2438,
  [2461] = 2436,
  [2462] = 2438,
  [2463] = 2436,
  [2464] = 2348,
  [2465] = 2438,
  [2466] = 2466,
  [2467] = 2466,
  [2468] = 2436,
  [2469] = 2438,
  [2470] = 2436,
  [2471] = 2438,
  [2472] = 2436,
  [2473] = 2438,
  [2474] = 2438,
  [2475] = 2436,
  [2476] = 2438,
  [2477] = 2438,
  [2478] = 2438,
  [2479] = 2479,
  [2480] = 2436,
  [2481] = 2438,
  [2482] = 2438,
  [2483] = 2438,
  [2484] = 2436,
  [2485] = 2436,
  [2486] = 2438,
  [2487] = 2438,
  [2488] = 2436,
  [2489] = 2438,
  [2490] = 2490,
  [2491] = 2438,
  [2492] = 2438,
  [2493] = 2438,
  [2494] = 2436,
  [2495] = 2438,
  [2496] = 2436,
  [2497] = 2438,
  [2498] = 2438,
  [2499] = 2438,
  [2500] = 2438,
  [2501] = 2436,
  [2502] = 2436,
  [2503] = 2436,
  [2504] = 2490,
  [2505] = 2438,
  [2506] = 2436,
  [2507] = 2438,
  [2508] = 2438,
  [2509] = 2436,
  [2510] = 2438,
  [2511] = 2436,
  [2512] = 2438,
  [2513] = 2436,
  [2514] = 2438,
  [2515] = 2436,
  [2516] = 2438,
  [2517] = 2466,
  [2518] = 2438,
  [2519] = 2436,
  [2520] = 2438,
  [2521] = 2436,
  [2522] = 2438,
  [2523] = 2438,
  [2524] = 2436,
  [2525] = 2438,
  [2526] = 2438,
  [2527] = 2438,
  [2528] = 2438,
  [2529] = 2436,
  [2530] = 2438,
  [2531] = 2438,
  [2532] = 2438,
  [2533] = 2436,
  [2534] = 2438,
  [2535] = 2490,
  [2536] = 2436,
  [2537] = 2436,
  [2538] = 2436,
  [2539] = 2436,
  [2540] = 2436,
  [2541] = 2436,
  [2542] = 2436,
  [2543] = 2436,
  [2544] = 2436,
  [2545] = 2436,
  [2546] = 2436,
  [2547] = 2436,
  [2548] = 2438,
  [2549] = 2436,
  [2550] = 2436,
  [2551] = 2438,
  [2552] = 2436,
  [2553] = 2436,
  [2554] = 2436,
  [2555] = 2436,
  [2556] = 2436,
  [2557] = 2436,
  [2558] = 2436,
  [2559] = 2438,
  [2560] = 2436,
  [2561] = 2438,
  [2562] = 2438,
  [2563] = 2563,
  [2564] = 2564,
  [2565] = 2565,
  [2566] = 2566,
  [2567] = 2567,
  [2568] = 2568,
  [2569] = 2569,
  [2570] = 2570,
  [2571] = 2348,
  [2572] = 2572,
  [2573] = 2573,
  [2574] = 2348,
  [2575] = 2348,
  [2576] = 2348,
  [2577] = 2348,
  [2578] = 2578,
  [2579] = 2348,
  [2580] = 2580,
  [2581] = 2581,
  [2582] = 2582,
  [2583] = 2581,
  [2584] = 2582,
  [2585] = 2581,
  [2586] = 2582,
  [2587] = 2581,
  [2588] = 2582,
  [2589] = 2581,
  [2590] = 2582,
  [2591] = 2581,
  [2592] = 2582,
  [2593] = 2581,
  [2594] = 2582,
  [2595] = 2581,
  [2596] = 2582,
  [2597] = 2581,
  [2598] = 2582,
  [2599] = 2581,
  [2600] = 2582,
  [2601] = 2581,
  [2602] = 2582,
  [2603] = 2581,
  [2604] = 2582,
  [2605] = 2581,
  [2606] = 2582,
  [2607] = 2581,
  [2608] = 2582,
  [2609] = 2582,
  [2610] = 2582,
  [2611] = 2580,
  [2612] = 2580,
  [2613] = 2581,
  [2614] = 2614,
  [2615] = 2582,
  [2616] = 2581,
  [2617] = 2582,
  [2618] = 2580,
  [2619] = 2614,
  [2620] = 2581,
  [2621] = 2582,
  [2622] = 2580,
  [2623] = 2581,
  [2624] = 2614,
  [2625] = 2582,
  [2626] = 2614,
  [2627] = 2614,
  [2628] = 2580,
  [2629] = 2581,
  [2630] = 2582,
  [2631] = 2580,
  [2632] = 2614,
  [2633] = 2581,
  [2634] = 2580,
  [2635] = 2582,
  [2636] = 2580,
  [2637] = 2580,
  [2638] = 2581,
  [2639] = 2581,
  [2640] = 2614,
  [2641] = 2614,
  [2642] = 2581,
  [2643] = 2582,
  [2644] = 2582,
  [2645] = 2580,
  [2646] = 2581,
  [2647] = 2614,
  [2648] = 2614,
  [2649] = 2582,
  [2650] = 2582,
  [2651] = 2580,
  [2652] = 2581,
  [2653] = 2580,
  [2654] = 2581,
  [2655] = 2614,
  [2656] = 2582,
  [2657] = 2580,
  [2658] = 2580,
  [2659] = 2581,
  [2660] = 2614,
  [2661] = 2614,
  [2662] = 2582,
  [2663] = 2581,
  [2664] = 2582,
  [2665] = 2614,
  [2666] = 2580,
  [2667] = 2582,
  [2668] = 2580,
  [2669] = 2581,
  [2670] = 2580,
  [2671] = 2581,
  [2672] = 2614,
  [2673] = 2582,
  [2674] = 2614,
  [2675] = 2614,
  [2676] = 2582,
  [2677] = 2581,
  [2678] = 2580,
  [2679] = 2581,
  [2680] = 2580,
  [2681] = 2581,
  [2682] = 2614,
  [2683] = 2582,
  [2684] = 2580,
  [2685] = 2614,
  [2686] = 2581,
  [2687] = 2581,
  [2688] = 2580,
  [2689] = 2614,
  [2690] = 2581,
  [2691] = 2582,
  [2692] = 2582,
  [2693] = 2614,
  [2694] = 2582,
  [2695] = 2614,
  [2696] = 2580,
  [2697] = 2581,
  [2698] = 2582,
  [2699] = 2614,
  [2700] = 2580,
  [2701] = 2581,
  [2702] = 2614,
  [2703] = 2582,
  [2704] = 2582,
  [2705] = 2580,
  [2706] = 2580,
  [2707] = 2581,
  [2708] = 2581,
  [2709] = 2580,
  [2710] = 2581,
  [2711] = 2580,
  [2712] = 2614,
  [2713] = 2581,
  [2714] = 2582,
  [2715] = 2614,
  [2716] = 2582,
  [2717] = 2614,
  [2718] = 2582,
  [2719] = 2581,
  [2720] = 2580,
  [2721] = 2580,
  [2722] = 2580,
  [2723] = 2581,
  [2724] = 2614,
  [2725] = 2581,
  [2726] = 2580,
  [2727] = 2582,
  [2728] = 2581,
  [2729] = 2580,
  [2730] = 2614,
  [2731] = 2581,
  [2732] = 2581,
  [2733] = 2614,
  [2734] = 2582,
  [2735] = 2614,
  [2736] = 2582,
  [2737] = 2582,
  [2738] = 2580,
  [2739] = 2581,
  [2740] = 2614,
  [2741] = 2582,
  [2742] = 2581,
  [2743] = 2580,
  [2744] = 2580,
  [2745] = 2581,
  [2746] = 2614,
  [2747] = 2581,
  [2748] = 2582,
  [2749] = 2580,
  [2750] = 2580,
  [2751] = 2614,
  [2752] = 2582,
  [2753] = 2581,
  [2754] = 2580,
  [2755] = 2581,
  [2756] = 2614,
  [2757] = 2614,
  [2758] = 2582,
  [2759] = 2582,
  [2760] = 2580,
  [2761] = 2581,
  [2762] = 2614,
  [2763] = 2614,
  [2764] = 2582,
  [2765] = 2614,
  [2766] = 2581,
  [2767] = 2580,
  [2768] = 2580,
  [2769] = 2581,
  [2770] = 2614,
  [2771] = 2582,
  [2772] = 2581,
  [2773] = 2614,
  [2774] = 2614,
  [2775] = 2580,
  [2776] = 2582,
  [2777] = 2580,
  [2778] = 2581,
  [2779] = 2581,
  [2780] = 2614,
  [2781] = 2614,
  [2782] = 2582,
  [2783] = 2582,
  [2784] = 2614,
  [2785] = 2582,
  [2786] = 2581,
  [2787] = 2580,
  [2788] = 2580,
  [2789] = 2581,
  [2790] = 2581,
  [2791] = 2614,
  [2792] = 2614,
  [2793] = 2582,
  [2794] = 2582,
  [2795] = 2582,
  [2796] = 2580,
  [2797] = 2581,
  [2798] = 2580,
  [2799] = 2581,
  [2800] = 2614,
  [2801] = 2614,
  [2802] = 2582,
  [2803] = 2582,
  [2804] = 2580,
  [2805] = 2580,
  [2806] = 2581,
  [2807] = 2582,
  [2808] = 2614,
  [2809] = 2581,
  [2810] = 2582,
  [2811] = 2614,
  [2812] = 2582,
  [2813] = 2580,
  [2814] = 2582,
  [2815] = 2580,
  [2816] = 2581,
  [2817] = 2581,
  [2818] = 2614,
  [2819] = 2582,
  [2820] = 2614,
  [2821] = 2582,
  [2822] = 2614,
  [2823] = 2582,
  [2824] = 2580,
  [2825] = 2580,
  [2826] = 2581,
  [2827] = 2614,
  [2828] = 2581,
  [2829] = 2582,
  [2830] = 2614,
  [2831] = 2580,
  [2832] = 2582,
  [2833] = 2580,
  [2834] = 2581,
  [2835] = 2582,
  [2836] = 2580,
  [2837] = 2581,
  [2838] = 2614,
  [2839] = 2614,
  [2840] = 2582,
  [2841] = 2582,
  [2842] = 2580,
  [2843] = 2580,
  [2844] = 2580,
  [2845] = 2581,
  [2846] = 2580,
  [2847] = 2581,
  [2848] = 2581,
  [2849] = 2614,
  [2850] = 2614,
  [2851] = 2582,
  [2852] = 2614,
  [2853] = 2582,
  [2854] = 2581,
  [2855] = 2580,
  [2856] = 2581,
  [2857] = 2580,
  [2858] = 2580,
  [2859] = 2581,
  [2860] = 2614,
  [2861] = 2614,
  [2862] = 2582,
  [2863] = 2582,
  [2864] = 2614,
  [2865] = 2580,
  [2866] = 2580,
  [2867] = 2581,
  [2868] = 2581,
  [2869] = 2581,
  [2870] = 2614,
  [2871] = 2582,
  [2872] = 2614,
  [2873] = 2582,
  [2874] = 2582,
  [2875] = 2580,
  [2876] = 2581,
  [2877] = 2580,
  [2878] = 2614,
  [2879] = 2581,
  [2880] = 2582,
  [2881] = 2580,
  [2882] = 2580,
  [2883] = 2581,
  [2884] = 2580,
  [2885] = 2614,
  [2886] = 2581,
  [2887] = 2614,
  [2888] = 2582,
  [2889] = 2614,
  [2890] = 2582,
  [2891] = 2582,
  [2892] = 2580,
  [2893] = 2614,
  [2894] = 2581,
  [2895] = 2614,
  [2896] = 2348,
  [2897] = 2582,
  [2898] = 2582,
  [2899] = 2580,
  [2900] = 2581,
  [2901] = 2581,
  [2902] = 2581,
  [2903] = 2580,
  [2904] = 2580,
  [2905] = 2581,
  [2906] = 2614,
  [2907] = 2581,
  [2908] = 2614,
  [2909] = 2582,
  [2910] = 2614,
  [2911] = 2582,
  [2912] = 2614,
  [2913] = 2582,
  [2914] = 2614,
  [2915] = 2580,
  [2916] = 2580,
  [2917] = 2581,
  [2918] = 2581,
  [2919] = 2580,
  [2920] = 2581,
  [2921] = 2614,
  [2922] = 2614,
  [2923] = 2582,
  [2924] = 2582,
  [2925] = 2614,
  [2926] = 2348,
  [2927] = 2582,
  [2928] = 2580,
  [2929] = 2580,
  [2930] = 2614,
  [2931] = 2581,
  [2932] = 2580,
  [2933] = 2582,
  [2934] = 2581,
  [2935] = 2581,
  [2936] = 2614,
  [2937] = 2614,
  [2938] = 2582,
  [2939] = 2582,
  [2940] = 2580,
  [2941] = 2581,
  [2942] = 2582,
  [2943] = 2581,
  [2944] = 2614,
  [2945] = 2582,
  [2946] = 2580,
  [2947] = 2582,
  [2948] = 2581,
  [2949] = 2581,
  [2950] = 2614,
  [2951] = 2581,
  [2952] = 2582,
  [2953] = 2582,
  [2954] = 2580,
  [2955] = 2581,
  [2956] = 2614,
  [2957] = 2581,
  [2958] = 2614,
  [2959] = 2580,
  [2960] = 2581,
  [2961] = 2582,
  [2962] = 2614,
  [2963] = 2582,
  [2964] = 2582,
  [2965] = 2348,
  [2966] = 2580,
  [2967] = 2582,
  [2968] = 2580,
  [2969] = 2581,
  [2970] = 2581,
  [2971] = 2580,
  [2972] = 2581,
  [2973] = 2582,
  [2974] = 2614,
  [2975] = 2581,
  [2976] = 2582,
  [2977] = 2582,
  [2978] = 2614,
  [2979] = 2580,
  [2980] = 2580,
  [2981] = 2582,
  [2982] = 2580,
  [2983] = 2581,
  [2984] = 2581,
  [2985] = 2614,
  [2986] = 2614,
  [2987] = 2582,
  [2988] = 2580,
  [2989] = 2581,
  [2990] = 2582,
  [2991] = 2581,
  [2992] = 2348,
  [2993] = 2580,
  [2994] = 2581,
  [2995] = 2581,
  [2996] = 2614,
  [2997] = 2614,
  [2998] = 2582,
  [2999] = 2582,
  [3000] = 2582,
  [3001] = 2582,
  [3002] = 2580,
  [3003] = 2580,
  [3004] = 2581,
  [3005] = 2614,
  [3006] = 2614,
  [3007] = 2581,
  [3008] = 2582,
  [3009] = 2581,
  [3010] = 2614,
  [3011] = 2582,
  [3012] = 2582,
  [3013] = 2614,
  [3014] = 2580,
  [3015] = 2581,
  [3016] = 2614,
  [3017] = 2582,
  [3018] = 2582,
  [3019] = 2580,
  [3020] = 2581,
  [3021] = 2614,
  [3022] = 2582,
  [3023] = 2581,
  [3024] = 2582,
  [3025] = 2580,
  [3026] = 2581,
  [3027] = 2614,
  [3028] = 2582,
  [3029] = 2582,
  [3030] = 2580,
  [3031] = 2581,
  [3032] = 2614,
  [3033] = 2582,
  [3034] = 2580,
  [3035] = 2580,
  [3036] = 2581,
  [3037] = 2614,
  [3038] = 2582,
  [3039] = 2580,
  [3040] = 2580,
  [3041] = 2581,
  [3042] = 2614,
  [3043] = 2582,
  [3044] = 2580,
  [3045] = 2581,
  [3046] = 2614,
  [3047] = 2582,
  [3048] = 2581,
  [3049] = 2580,
  [3050] = 2581,
  [3051] = 2614,
  [3052] = 2582,
  [3053] = 2580,
  [3054] = 2581,
  [3055] = 2614,
  [3056] = 2582,
  [3057] = 2581,
  [3058] = 2580,
  [3059] = 2581,
  [3060] = 2614,
  [3061] = 2582,
  [3062] = 2580,
  [3063] = 2581,
  [3064] = 2614,
  [3065] = 2582,
  [3066] = 2582,
  [3067] = 2580,
  [3068] = 2581,
  [3069] = 2614,
  [3070] = 2582,
  [3071] = 2580,
  [3072] = 2581,
  [3073] = 2614,
  [3074] = 2582,
  [3075] = 2582,
  [3076] = 2580,
  [3077] = 2580,
  [3078] = 2581,
  [3079] = 2614,
  [3080] = 2582,
  [3081] = 2581,
  [3082] = 3082,
  [3083] = 3083,
  [3084] = 3084,
  [3085] = 3085,
  [3086] = 3086,
  [3087] = 3082,
  [3088] = 3088,
  [3089] = 3089,
  [3090] = 3090,
  [3091] = 3091,
  [3092] = 3092,
  [3093] = 3093,
  [3094] = 3094,
  [3095] = 3089,
  [3096] = 3096,
  [3097] = 3097,
  [3098] = 3097,
  [3099] = 3083,
  [3100] = 3085,
  [3101] = 3101,
  [3102] = 3082,
  [3103] = 3097,
  [3104] = 3088,
  [3105] = 3083,
  [3106] = 3090,
  [3107] = 3101,
  [3108] = 3084,
  [3109] = 3091,
  [3110] = 3092,
  [3111] = 3093,
  [3112] = 3094,
  [3113] = 3084,
  [3114] = 3114,
  [3115] = 3115,
  [3116] = 3083,
  [3117] = 3085,
  [3118] = 3101,
  [3119] = 3082,
  [3120] = 3089,
  [3121] = 3088,
  [3122] = 3101,
  [3123] = 3090,
  [3124] = 2348,
  [3125] = 3084,
  [3126] = 3097,
  [3127] = 3083,
  [3128] = 3101,
  [3129] = 3084,
  [3130] = 3085,
  [3131] = 3131,
  [3132] = 3088,
  [3133] = 3090,
  [3134] = 3089,
  [3135] = 3097,
  [3136] = 3136,
  [3137] = 3085,
  [3138] = 3097,
  [3139] = 3082,
  [3140] = 3083,
  [3141] = 3088,
  [3142] = 3090,
  [3143] = 3089,
  [3144] = 3101,
  [3145] = 3097,
  [3146] = 3083,
  [3147] = 3101,
  [3148] = 3084,
  [3149] = 3085,
  [3150] = 3084,
  [3151] = 3082,
  [3152] = 3115,
  [3153] = 3088,
  [3154] = 3090,
  [3155] = 3084,
  [3156] = 3083,
  [3157] = 3097,
  [3158] = 3083,
  [3159] = 3101,
  [3160] = 3085,
  [3161] = 3084,
  [3162] = 3082,
  [3163] = 3088,
  [3164] = 3090,
  [3165] = 3165,
  [3166] = 3101,
  [3167] = 3089,
  [3168] = 3085,
  [3169] = 3082,
  [3170] = 3088,
  [3171] = 3171,
  [3172] = 3090,
  [3173] = 3173,
  [3174] = 3084,
  [3175] = 3089,
  [3176] = 3097,
  [3177] = 3085,
  [3178] = 3083,
  [3179] = 3082,
  [3180] = 3101,
  [3181] = 3088,
  [3182] = 3084,
  [3183] = 3090,
  [3184] = 2348,
  [3185] = 3115,
  [3186] = 3097,
  [3187] = 3083,
  [3188] = 3085,
  [3189] = 3082,
  [3190] = 3088,
  [3191] = 3089,
  [3192] = 3090,
  [3193] = 3101,
  [3194] = 3084,
  [3195] = 3089,
  [3196] = 3097,
  [3197] = 3085,
  [3198] = 3086,
  [3199] = 3082,
  [3200] = 3088,
  [3201] = 3089,
  [3202] = 3090,
  [3203] = 3203,
  [3204] = 3114,
  [3205] = 3205,
  [3206] = 3089,
  [3207] = 3097,
  [3208] = 3085,
  [3209] = 3083,
  [3210] = 3082,
  [3211] = 3101,
  [3212] = 3088,
  [3213] = 3097,
  [3214] = 3090,
  [3215] = 3083,
  [3216] = 3084,
  [3217] = 3101,
  [3218] = 3084,
  [3219] = 3097,
  [3220] = 3115,
  [3221] = 3085,
  [3222] = 3083,
  [3223] = 3082,
  [3224] = 3101,
  [3225] = 3088,
  [3226] = 3084,
  [3227] = 3090,
  [3228] = 3228,
  [3229] = 3115,
  [3230] = 3136,
  [3231] = 3085,
  [3232] = 3082,
  [3233] = 3088,
  [3234] = 3090,
  [3235] = 3089,
  [3236] = 3085,
  [3237] = 3089,
  [3238] = 3082,
  [3239] = 3089,
  [3240] = 3088,
  [3241] = 3090,
  [3242] = 3089,
  [3243] = 3097,
  [3244] = 3097,
  [3245] = 3097,
  [3246] = 3083,
  [3247] = 3101,
  [3248] = 3085,
  [3249] = 3084,
  [3250] = 3082,
  [3251] = 3083,
  [3252] = 3088,
  [3253] = 3115,
  [3254] = 3090,
  [3255] = 3101,
  [3256] = 3084,
  [3257] = 3136,
  [3258] = 3085,
  [3259] = 3089,
  [3260] = 3082,
  [3261] = 3088,
  [3262] = 3090,
  [3263] = 3083,
  [3264] = 3101,
  [3265] = 3083,
  [3266] = 3085,
  [3267] = 3089,
  [3268] = 3082,
  [3269] = 3088,
  [3270] = 3084,
  [3271] = 3090,
  [3272] = 3089,
  [3273] = 3089,
  [3274] = 3089,
  [3275] = 3097,
  [3276] = 3097,
  [3277] = 3083,
  [3278] = 3085,
  [3279] = 3097,
  [3280] = 3082,
  [3281] = 3083,
  [3282] = 3088,
  [3283] = 3101,
  [3284] = 3090,
  [3285] = 3084,
  [3286] = 3097,
  [3287] = 3083,
  [3288] = 3097,
  [3289] = 3115,
  [3290] = 3083,
  [3291] = 3085,
  [3292] = 3082,
  [3293] = 3088,
  [3294] = 3101,
  [3295] = 3090,
  [3296] = 3084,
  [3297] = 3101,
  [3298] = 3298,
  [3299] = 3084,
  [3300] = 3300,
  [3301] = 3085,
  [3302] = 3302,
  [3303] = 3082,
  [3304] = 3088,
  [3305] = 3090,
  [3306] = 3089,
  [3307] = 3101,
  [3308] = 3165,
  [3309] = 3115,
  [3310] = 3171,
  [3311] = 3173,
  [3312] = 3085,
  [3313] = 3084,
  [3314] = 3082,
  [3315] = 3083,
  [3316] = 3088,
  [3317] = 3090,
  [3318] = 3097,
  [3319] = 3089,
  [3320] = 3083,
  [3321] = 3101,
  [3322] = 3084,
  [3323] = 3085,
  [3324] = 3115,
  [3325] = 3088,
  [3326] = 3090,
  [3327] = 3101,
  [3328] = 2348,
  [3329] = 3298,
  [3330] = 3096,
  [3331] = 3097,
  [3332] = 3085,
  [3333] = 3300,
  [3334] = 3088,
  [3335] = 3115,
  [3336] = 3090,
  [3337] = 3083,
  [3338] = 3101,
  [3339] = 3084,
  [3340] = 3085,
  [3341] = 3089,
  [3342] = 3088,
  [3343] = 3090,
  [3344] = 3084,
  [3345] = 3089,
  [3346] = 3346,
  [3347] = 3085,
  [3348] = 3090,
  [3349] = 3097,
  [3350] = 3089,
  [3351] = 3083,
  [3352] = 3101,
  [3353] = 3084,
  [3354] = 3089,
  [3355] = 3085,
  [3356] = 3115,
  [3357] = 3090,
  [3358] = 3101,
  [3359] = 3084,
  [3360] = 3097,
  [3361] = 3165,
  [3362] = 3085,
  [3363] = 3302,
  [3364] = 3090,
  [3365] = 3083,
  [3366] = 3101,
  [3367] = 3084,
  [3368] = 3097,
  [3369] = 3089,
  [3370] = 3085,
  [3371] = 3097,
  [3372] = 3090,
  [3373] = 3089,
  [3374] = 3083,
  [3375] = 3085,
  [3376] = 3101,
  [3377] = 3090,
  [3378] = 3084,
  [3379] = 3165,
  [3380] = 3171,
  [3381] = 3097,
  [3382] = 3083,
  [3383] = 3085,
  [3384] = 3101,
  [3385] = 3090,
  [3386] = 3084,
  [3387] = 3089,
  [3388] = 3115,
  [3389] = 3085,
  [3390] = 2348,
  [3391] = 3090,
  [3392] = 3173,
  [3393] = 3097,
  [3394] = 3394,
  [3395] = 3083,
  [3396] = 3085,
  [3397] = 3101,
  [3398] = 3090,
  [3399] = 3203,
  [3400] = 3084,
  [3401] = 3205,
  [3402] = 3089,
  [3403] = 3085,
  [3404] = 3228,
  [3405] = 3090,
  [3406] = 3083,
  [3407] = 3089,
  [3408] = 3097,
  [3409] = 3085,
  [3410] = 3097,
  [3411] = 3090,
  [3412] = 3097,
  [3413] = 3101,
  [3414] = 3083,
  [3415] = 3101,
  [3416] = 3084,
  [3417] = 3085,
  [3418] = 3115,
  [3419] = 3090,
  [3420] = 3089,
  [3421] = 3346,
  [3422] = 3089,
  [3423] = 3084,
  [3424] = 3089,
  [3425] = 3090,
  [3426] = 3131,
  [3427] = 3097,
  [3428] = 3083,
  [3429] = 3101,
  [3430] = 3086,
  [3431] = 3085,
  [3432] = 3084,
  [3433] = 3090,
  [3434] = 3089,
  [3435] = 3083,
  [3436] = 3101,
  [3437] = 3085,
  [3438] = 3084,
  [3439] = 3090,
  [3440] = 3089,
  [3441] = 3089,
  [3442] = 3097,
  [3443] = 3097,
  [3444] = 3083,
  [3445] = 3085,
  [3446] = 3101,
  [3447] = 3090,
  [3448] = 3084,
  [3449] = 3083,
  [3450] = 3097,
  [3451] = 3115,
  [3452] = 3101,
  [3453] = 3085,
  [3454] = 3084,
  [3455] = 3090,
  [3456] = 3097,
  [3457] = 3083,
  [3458] = 3171,
  [3459] = 3083,
  [3460] = 3101,
  [3461] = 3085,
  [3462] = 3101,
  [3463] = 3090,
  [3464] = 3084,
  [3465] = 3089,
  [3466] = 3091,
  [3467] = 3085,
  [3468] = 3084,
  [3469] = 3090,
  [3470] = 3089,
  [3471] = 3092,
  [3472] = 3097,
  [3473] = 3085,
  [3474] = 3083,
  [3475] = 3090,
  [3476] = 3115,
  [3477] = 3089,
  [3478] = 3085,
  [3479] = 3097,
  [3480] = 3090,
  [3481] = 3083,
  [3482] = 3101,
  [3483] = 3084,
  [3484] = 3085,
  [3485] = 3115,
  [3486] = 3090,
  [3487] = 3097,
  [3488] = 3083,
  [3489] = 3173,
  [3490] = 3085,
  [3491] = 3101,
  [3492] = 3090,
  [3493] = 3114,
  [3494] = 3084,
  [3495] = 3093,
  [3496] = 3094,
  [3497] = 3101,
  [3498] = 3085,
  [3499] = 3096,
  [3500] = 3090,
  [3501] = 3085,
  [3502] = 3084,
  [3503] = 3089,
  [3504] = 3085,
  [3505] = 3090,
  [3506] = 3300,
  [3507] = 3089,
  [3508] = 3085,
  [3509] = 3090,
  [3510] = 3097,
  [3511] = 3089,
  [3512] = 3083,
  [3513] = 3101,
  [3514] = 3084,
  [3515] = 3085,
  [3516] = 3090,
  [3517] = 3115,
  [3518] = 3097,
  [3519] = 3083,
  [3520] = 3520,
  [3521] = 3085,
  [3522] = 3097,
  [3523] = 3090,
  [3524] = 3101,
  [3525] = 3084,
  [3526] = 3097,
  [3527] = 3083,
  [3528] = 3085,
  [3529] = 3115,
  [3530] = 3090,
  [3531] = 3097,
  [3532] = 3115,
  [3533] = 3085,
  [3534] = 3090,
  [3535] = 3089,
  [3536] = 3089,
  [3537] = 3097,
  [3538] = 3085,
  [3539] = 3090,
  [3540] = 3083,
  [3541] = 3101,
  [3542] = 3084,
  [3543] = 3085,
  [3544] = 3090,
  [3545] = 3097,
  [3546] = 3083,
  [3547] = 3101,
  [3548] = 3097,
  [3549] = 3085,
  [3550] = 3090,
  [3551] = 3083,
  [3552] = 3101,
  [3553] = 3084,
  [3554] = 3085,
  [3555] = 3090,
  [3556] = 3089,
  [3557] = 3115,
  [3558] = 3085,
  [3559] = 3090,
  [3560] = 3560,
  [3561] = 3084,
  [3562] = 3083,
  [3563] = 3085,
  [3564] = 3090,
  [3565] = 3101,
  [3566] = 3084,
  [3567] = 3085,
  [3568] = 3090,
  [3569] = 3085,
  [3570] = 3090,
  [3571] = 3085,
  [3572] = 3090,
  [3573] = 3089,
  [3574] = 3085,
  [3575] = 3090,
  [3576] = 3089,
  [3577] = 3085,
  [3578] = 3090,
  [3579] = 3083,
  [3580] = 3097,
  [3581] = 3083,
  [3582] = 3085,
  [3583] = 3090,
  [3584] = 3101,
  [3585] = 3084,
  [3586] = 3085,
  [3587] = 3090,
  [3588] = 3115,
  [3589] = 3097,
  [3590] = 2348,
  [3591] = 3085,
  [3592] = 3090,
  [3593] = 3083,
  [3594] = 3101,
  [3595] = 3085,
  [3596] = 3090,
  [3597] = 3084,
  [3598] = 3085,
  [3599] = 3090,
  [3600] = 3101,
  [3601] = 3085,
  [3602] = 3090,
  [3603] = 3089,
  [3604] = 3085,
  [3605] = 3090,
  [3606] = 3089,
  [3607] = 3089,
  [3608] = 3097,
  [3609] = 3085,
  [3610] = 3090,
  [3611] = 3083,
  [3612] = 3084,
  [3613] = 3097,
  [3614] = 3085,
  [3615] = 3090,
  [3616] = 3083,
  [3617] = 3101,
  [3618] = 3084,
  [3619] = 3085,
  [3620] = 3090,
  [3621] = 3101,
  [3622] = 3085,
  [3623] = 3090,
  [3624] = 3084,
  [3625] = 3394,
  [3626] = 3085,
  [3627] = 3090,
  [3628] = 3097,
  [3629] = 3085,
  [3630] = 3090,
  [3631] = 3083,
  [3632] = 3115,
  [3633] = 3101,
  [3634] = 3085,
  [3635] = 3090,
  [3636] = 3089,
  [3637] = 3084,
  [3638] = 3085,
  [3639] = 3090,
  [3640] = 3131,
  [3641] = 3097,
  [3642] = 3085,
  [3643] = 3090,
  [3644] = 3097,
  [3645] = 3085,
  [3646] = 3090,
  [3647] = 3083,
  [3648] = 3101,
  [3649] = 3084,
  [3650] = 3085,
  [3651] = 3090,
  [3652] = 3089,
  [3653] = 3085,
  [3654] = 3090,
  [3655] = 3082,
  [3656] = 3083,
  [3657] = 3085,
  [3658] = 3090,
  [3659] = 3101,
  [3660] = 3084,
  [3661] = 3661,
  [3662] = 3085,
  [3663] = 3090,
  [3664] = 3097,
  [3665] = 3085,
  [3666] = 3090,
  [3667] = 3089,
  [3668] = 3088,
  [3669] = 3083,
  [3670] = 3085,
  [3671] = 3090,
  [3672] = 3101,
  [3673] = 3084,
  [3674] = 3085,
  [3675] = 3090,
  [3676] = 3097,
  [3677] = 3083,
  [3678] = 3085,
  [3679] = 3090,
  [3680] = 3101,
  [3681] = 3084,
  [3682] = 3085,
  [3683] = 3090,
  [3684] = 3298,
  [3685] = 3300,
  [3686] = 3085,
  [3687] = 3090,
  [3688] = 3302,
  [3689] = 3089,
  [3690] = 3085,
  [3691] = 3090,
  [3692] = 3560,
  [3693] = 3693,
  [3694] = 3085,
  [3695] = 3090,
  [3696] = 3089,
  [3697] = 3085,
  [3698] = 3090,
  [3699] = 3097,
  [3700] = 3083,
  [3701] = 3085,
  [3702] = 3090,
  [3703] = 3101,
  [3704] = 3084,
  [3705] = 3115,
  [3706] = 3085,
  [3707] = 3090,
  [3708] = 3097,
  [3709] = 3083,
  [3710] = 3101,
  [3711] = 3085,
  [3712] = 3090,
  [3713] = 3084,
  [3714] = 3714,
  [3715] = 3101,
  [3716] = 3085,
  [3717] = 3090,
  [3718] = 3115,
  [3719] = 3085,
  [3720] = 3090,
  [3721] = 3089,
  [3722] = 3089,
  [3723] = 3085,
  [3724] = 3090,
  [3725] = 3089,
  [3726] = 3085,
  [3727] = 3090,
  [3728] = 3090,
  [3729] = 3097,
  [3730] = 3083,
  [3731] = 3085,
  [3732] = 3090,
  [3733] = 3101,
  [3734] = 3084,
  [3735] = 3097,
  [3736] = 3085,
  [3737] = 3090,
  [3738] = 3083,
  [3739] = 3101,
  [3740] = 3084,
  [3741] = 3085,
  [3742] = 3090,
  [3743] = 3089,
  [3744] = 3089,
  [3745] = 3084,
  [3746] = 3085,
  [3747] = 3090,
  [3748] = 3097,
  [3749] = 3085,
  [3750] = 3090,
  [3751] = 3394,
  [3752] = 3089,
  [3753] = 3083,
  [3754] = 3085,
  [3755] = 3090,
  [3756] = 3089,
  [3757] = 3101,
  [3758] = 3085,
  [3759] = 3090,
  [3760] = 3084,
  [3761] = 3097,
  [3762] = 3083,
  [3763] = 3090,
  [3764] = 3097,
  [3765] = 3083,
  [3766] = 3090,
  [3767] = 3101,
  [3768] = 3084,
  [3769] = 3101,
  [3770] = 3090,
  [3771] = 3203,
  [3772] = 3205,
  [3773] = 3090,
  [3774] = 3228,
  [3775] = 3090,
  [3776] = 3346,
  [3777] = 3090,
  [3778] = 3089,
  [3779] = 3090,
  [3780] = 3084,
  [3781] = 3090,
  [3782] = 3560,
  [3783] = 3090,
  [3784] = 3090,
  [3785] = 3097,
  [3786] = 3090,
  [3787] = 3090,
  [3788] = 3090,
  [3789] = 3090,
  [3790] = 3090,
  [3791] = 3090,
  [3792] = 3090,
  [3793] = 3090,
  [3794] = 3090,
  [3795] = 3090,
  [3796] = 3090,
  [3797] = 3090,
  [3798] = 3090,
  [3799] = 3090,
  [3800] = 3090,
  [3801] = 3083,
  [3802] = 3085,
  [3803] = 3101,
  [3804] = 3082,
  [3805] = 3084,
  [3806] = 3089,
  [3807] = 3088,
  [3808] = 3090,
  [3809] = 3089,
  [3810] = 3091,
  [3811] = 3092,
  [3812] = 3093,
  [3813] = 3094,
  [3814] = 3097,
  [3815] = 3083,
  [3816] = 3101,
  [3817] = 3097,
  [3818] = 3083,
  [3819] = 3101,
  [3820] = 3084,
  [3821] = 3171,
  [3822] = 3173,
  [3823] = 3084,
  [3824] = 3115,
  [3825] = 3085,
  [3826] = 3082,
  [3827] = 3088,
  [3828] = 3089,
  [3829] = 3090,
  [3830] = 3089,
  [3831] = 3091,
  [3832] = 3092,
  [3833] = 3093,
  [3834] = 3094,
  [3835] = 2348,
  [3836] = 3089,
  [3837] = 3097,
  [3838] = 3083,
  [3839] = 3101,
  [3840] = 3085,
  [3841] = 2348,
  [3842] = 2348,
  [3843] = 2348,
  [3844] = 2348,
  [3845] = 2348,
  [3846] = 3846,
  [3847] = 3846,
  [3848] = 3846,
  [3849] = 3846,
  [3850] = 3850,
  [3851] = 2348,
  [3852] = 3852,
  [3853] = 3846,
  [3854] = 3846,
  [3855] = 3846,
  [3856] = 3846,
  [3857] = 3846,
  [3858] = 3846,
  [3859] = 3846,
  [3860] = 3846,
  [3861] = 3846,
  [3862] = 3846,
  [3863] = 3846,
  [3864] = 3846,
  [3865] = 3846,
  [3866] = 3846,
  [3867] = 3846,
  [3868] = 3846,
  [3869] = 3846,
  [3870] = 3846,
  [3871] = 3846,
  [3872] = 3846,
  [3873] = 3846,
  [3874] = 3846,
  [3875] = 3846,
  [3876] = 3846,
  [3877] = 3846,
  [3878] = 3846,
  [3879] = 3846,
  [3880] = 3846,
  [3881] = 3846,
  [3882] = 3846,
  [3883] = 3846,
  [3884] = 3846,
  [3885] = 3846,
  [3886] = 3846,
  [3887] = 3846,
  [3888] = 3846,
  [3889] = 3846,
  [3890] = 3846,
  [3891] = 3846,
  [3892] = 3846,
  [3893] = 3846,
  [3894] = 3846,
  [3895] = 3846,
  [3896] = 3846,
  [3897] = 3846,
  [3898] = 3846,
  [3899] = 3846,
  [3900] = 3846,
  [3901] = 3846,
  [3902] = 3846,
  [3903] = 3846,
  [3904] = 3846,
  [3905] = 3905,
  [3906] = 3905,
  [3907] = 3907,
  [3908] = 3907,
  [3909] = 3905,
  [3910] = 3905,
  [3911] = 3907,
  [3912] = 3907,
  [3913] = 3905,
  [3914] = 3905,
  [3915] = 3907,
  [3916] = 3905,
  [3917] = 3907,
  [3918] = 3905,
  [3919] = 3907,
  [3920] = 3905,
  [3921] = 3907,
  [3922] = 3905,
  [3923] = 3907,
  [3924] = 3907,
  [3925] = 3905,
  [3926] = 3905,
  [3927] = 3907,
  [3928] = 3905,
  [3929] = 3907,
  [3930] = 3907,
  [3931] = 3907,
  [3932] = 3852,
  [3933] = 3905,
  [3934] = 3905,
  [3935] = 3905,
  [3936] = 3907,
  [3937] = 3905,
  [3938] = 3907,
  [3939] = 3907,
  [3940] = 3907,
  [3941] = 3907,
  [3942] = 3905,
  [3943] = 3907,
  [3944] = 3905,
  [3945] = 3905,
  [3946] = 3907,
  [3947] = 3905,
  [3948] = 3907,
  [3949] = 3905,
  [3950] = 3905,
  [3951] = 3951,
  [3952] = 3907,
  [3953] = 3907,
  [3954] = 3905,
  [3955] = 3905,
  [3956] = 3907,
  [3957] = 3907,
  [3958] = 3905,
  [3959] = 3907,
  [3960] = 3960,
  [3961] = 3905,
  [3962] = 3907,
  [3963] = 3905,
  [3964] = 3907,
  [3965] = 3905,
  [3966] = 3905,
  [3967] = 3907,
  [3968] = 3907,
  [3969] = 3905,
  [3970] = 3905,
  [3971] = 3907,
  [3972] = 3905,
  [3973] = 3907,
  [3974] = 3905,
  [3975] = 3905,
  [3976] = 3852,
  [3977] = 3907,
  [3978] = 3905,
  [3979] = 3907,
  [3980] = 3907,
  [3981] = 3905,
  [3982] = 3907,
  [3983] = 3905,
  [3984] = 3907,
  [3985] = 3905,
  [3986] = 3907,
  [3987] = 3905,
  [3988] = 3907,
  [3989] = 3905,
  [3990] = 3907,
  [3991] = 3905,
  [3992] = 3907,
  [3993] = 3905,
  [3994] = 3905,
  [3995] = 3907,
  [3996] = 3905,
  [3997] = 3907,
  [3998] = 3905,
  [3999] = 3907,
  [4000] = 3905,
  [4001] = 3907,
  [4002] = 3907,
  [4003] = 3905,
  [4004] = 3907,
  [4005] = 3905,
  [4006] = 3905,
  [4007] = 3907,
  [4008] = 3960,
  [4009] = 3907,
  [4010] = 3905,
  [4011] = 3905,
  [4012] = 3951,
  [4013] = 3907,
  [4014] = 3905,
  [4015] = 3907,
  [4016] = 3905,
  [4017] = 3905,
  [4018] = 3907,
  [4019] = 3905,
  [4020] = 3850,
  [4021] = 3850,
  [4022] = 3907,
  [4023] = 3907,
  [4024] = 3907,
  [4025] = 4025,
  [4026] = 3850,
  [4027] = 3852,
  [4028] = 3850,
  [4029] = 3850,
  [4030] = 3852,
  [4031] = 3852,
  [4032] = 4032,
  [4033] = 3850,
  [4034] = 3852,
  [4035] = 3850,
  [4036] = 3850,
  [4037] = 3850,
  [4038] = 3850,
  [4039] = 3852,
  [4040] = 4040,
  [4041] = 3852,
  [4042] = 4042,
  [4043] = 3852,
  [4044] = 3850,
  [4045] = 3852,
  [4046] = 4040,
  [4047] = 4040,
  [4048] = 3852,
  [4049] = 3852,
  [4050] = 3852,
  [4051] = 3852,
  [4052] = 3850,
  [4053] = 3850,
  [4054] = 3850,
  [4055] = 3852,
  [4056] = 3852,
  [4057] = 3850,
  [4058] = 3852,
  [4059] = 3852,
  [4060] = 3850,
  [4061] = 3850,
  [4062] = 3850,
  [4063] = 3852,
  [4064] = 3850,
  [4065] = 4065,
  [4066] = 3852,
  [4067] = 4065,
  [4068] = 3852,
  [4069] = 4069,
  [4070] = 3850,
  [4071] = 3852,
  [4072] = 3850,
  [4073] = 4073,
  [4074] = 3850,
  [4075] = 3852,
  [4076] = 3852,
  [4077] = 3850,
  [4078] = 3850,
  [4079] = 4079,
  [4080] = 4079,
  [4081] = 4081,
  [4082] = 4082,
  [4083] = 4081,
  [4084] = 4084,
  [4085] = 4081,
  [4086] = 4081,
  [4087] = 4081,
  [4088] = 4081,
  [4089] = 4089,
  [4090] = 4073,
  [4091] = 4091,
  [4092] = 4081,
  [4093] = 4081,
  [4094] = 4081,
  [4095] = 4081,
  [4096] = 4096,
  [4097] = 4096,
  [4098] = 4081,
  [4099] = 4081,
  [4100] = 4084,
  [4101] = 4081,
  [4102] = 4081,
  [4103] = 4089,
  [4104] = 4081,
  [4105] = 4079,
  [4106] = 4081,
  [4107] = 4081,
  [4108] = 4081,
  [4109] = 4081,
  [4110] = 4079,
  [4111] = 4089,
  [4112] = 4081,
  [4113] = 4082,
  [4114] = 4081,
  [4115] = 4081,
  [4116] = 4082,
  [4117] = 4081,
  [4118] = 4081,
  [4119] = 4081,
  [4120] = 4081,
  [4121] = 4079,
  [4122] = 4081,
  [4123] = 4091,
  [4124] = 4081,
  [4125] = 4091,
  [4126] = 4081,
  [4127] = 4081,
  [4128] = 4081,
  [4129] = 4084,
  [4130] = 4089,
  [4131] = 4081,
  [4132] = 4081,
  [4133] = 4089,
  [4134] = 4081,
  [4135] = 4081,
  [4136] = 4081,
  [4137] = 4137,
  [4138] = 4138,
  [4139] = 4139,
  [4140] = 4139,
  [4141] = 4141,
  [4142] = 4142,
  [4143] = 4143,
  [4144] = 4144,
  [4145] = 4145,
  [4146] = 4145,
  [4147] = 4142,
  [4148] = 4143,
  [4149] = 4137,
  [4150] = 4150,
  [4151] = 4143,
  [4152] = 4139,
  [4153] = 4153,
  [4154] = 4153,
  [4155] = 4138,
  [4156] = 4141,
  [4157] = 4144,
  [4158] = 4145,
  [4159] = 4150,
  [4160] = 4138,
  [4161] = 3850,
  [4162] = 4162,
  [4163] = 4137,
  [4164] = 3852,
  [4165] = 4138,
  [4166] = 4162,
  [4167] = 4167,
  [4168] = 4141,
  [4169] = 4153,
  [4170] = 4137,
  [4171] = 4138,
  [4172] = 4137,
  [4173] = 4144,
  [4174] = 4142,
  [4175] = 4150,
  [4176] = 4150,
  [4177] = 4162,
  [4178] = 4150,
  [4179] = 4179,
  [4180] = 4180,
  [4181] = 4180,
  [4182] = 4180,
  [4183] = 4180,
  [4184] = 4180,
  [4185] = 4180,
  [4186] = 4180,
  [4187] = 4180,
  [4188] = 4180,
  [4189] = 4180,
  [4190] = 4180,
  [4191] = 4180,
  [4192] = 4180,
  [4193] = 4180,
  [4194] = 4180,
  [4195] = 4180,
  [4196] = 4180,
  [4197] = 4180,
  [4198] = 4180,
  [4199] = 4180,
  [4200] = 4180,
  [4201] = 4180,
  [4202] = 4180,
  [4203] = 4180,
  [4204] = 4180,
  [4205] = 4180,
  [4206] = 4180,
  [4207] = 4180,
  [4208] = 4180,
  [4209] = 4180,
  [4210] = 4210,
  [4211] = 4180,
  [4212] = 4180,
  [4213] = 4180,
  [4214] = 4180,
  [4215] = 4180,
  [4216] = 4180,
  [4217] = 4180,
  [4218] = 4180,
  [4219] = 4180,
  [4220] = 4180,
  [4221] = 4180,
  [4222] = 4180,
  [4223] = 4180,
  [4224] = 4180,
  [4225] = 4180,
  [4226] = 4180,
  [4227] = 4180,
  [4228] = 4180,
  [4229] = 4180,
  [4230] = 4180,
  [4231] = 4180,
  [4232] = 4180,
  [4233] = 4180,
  [4234] = 4180,
  [4235] = 4180,
  [4236] = 4180,
  [4237] = 4180,
  [4238] = 4180,
  [4239] = 4180,
  [4240] = 4180,
  [4241] = 4180,
  [4242] = 4180,
  [4243] = 4180,
  [4244] = 4244,
  [4245] = 4245,
  [4246] = 4246,
  [4247] = 4247,
  [4248] = 4246,
  [4249] = 4249,
  [4250] = 4246,
  [4251] = 4246,
  [4252] = 4246,
  [4253] = 4247,
  [4254] = 4254,
  [4255] = 4255,
  [4256] = 4256,
  [4257] = 4257,
  [4258] = 4254,
  [4259] = 4259,
  [4260] = 4254,
  [4261] = 4256,
  [4262] = 4256,
  [4263] = 4247,
  [4264] = 4264,
  [4265] = 4265,
  [4266] = 4265,
  [4267] = 4267,
  [4268] = 4268,
  [4269] = 4259,
  [4270] = 4254,
  [4271] = 4259,
  [4272] = 4272,
  [4273] = 4259,
  [4274] = 4272,
  [4275] = 4256,
  [4276] = 4256,
  [4277] = 4277,
  [4278] = 4267,
  [4279] = 4279,
  [4280] = 4280,
  [4281] = 4281,
  [4282] = 4282,
  [4283] = 4257,
  [4284] = 4284,
  [4285] = 4255,
  [4286] = 4264,
  [4287] = 4287,
  [4288] = 4288,
  [4289] = 4279,
  [4290] = 4290,
  [4291] = 4291,
  [4292] = 4264,
  [4293] = 4264,
  [4294] = 4294,
  [4295] = 4295,
  [4296] = 4296,
  [4297] = 4297,
  [4298] = 4298,
  [4299] = 4299,
  [4300] = 4300,
  [4301] = 4296,
  [4302] = 4302,
  [4303] = 4303,
  [4304] = 4304,
  [4305] = 4305,
  [4306] = 4306,
  [4307] = 4307,
  [4308] = 4308,
  [4309] = 4309,
  [4310] = 4280,
  [4311] = 4281,
  [4312] = 4282,
  [4313] = 4284,
  [4314] = 4287,
  [4315] = 4288,
  [4316] = 4303,
  [4317] = 4317,
  [4318] = 4298,
  [4319] = 4299,
  [4320] = 4300,
  [4321] = 4317,
  [4322] = 4296,
  [4323] = 4304,
  [4324] = 4305,
  [4325] = 4298,
  [4326] = 4309,
  [4327] = 4280,
  [4328] = 4281,
  [4329] = 4284,
  [4330] = 4288,
  [4331] = 4317,
  [4332] = 4298,
  [4333] = 4290,
  [4334] = 4300,
  [4335] = 4296,
  [4336] = 4304,
  [4337] = 4305,
  [4338] = 4299,
  [4339] = 4309,
  [4340] = 4280,
  [4341] = 4281,
  [4342] = 4284,
  [4343] = 4288,
  [4344] = 4317,
  [4345] = 4300,
  [4346] = 4300,
  [4347] = 4300,
  [4348] = 4267,
  [4349] = 4302,
  [4350] = 4304,
  [4351] = 4305,
  [4352] = 4297,
  [4353] = 4353,
  [4354] = 4297,
  [4355] = 4355,
  [4356] = 4302,
  [4357] = 4306,
  [4358] = 4297,
  [4359] = 4302,
  [4360] = 4306,
  [4361] = 4298,
  [4362] = 4299,
  [4363] = 4296,
  [4364] = 4297,
  [4365] = 4302,
  [4366] = 4306,
  [4367] = 4367,
  [4368] = 4368,
  [4369] = 4369,
  [4370] = 4255,
  [4371] = 4300,
  [4372] = 4372,
  [4373] = 4306,
  [4374] = 4307,
  [4375] = 4308,
  [4376] = 4257,
  [4377] = 4309,
  [4378] = 4264,
  [4379] = 4379,
  [4380] = 4380,
  [4381] = 4381,
  [4382] = 4299,
  [4383] = 4379,
  [4384] = 4245,
  [4385] = 4279,
  [4386] = 4386,
  [4387] = 4387,
  [4388] = 4264,
  [4389] = 4290,
  [4390] = 4264,
  [4391] = 4290,
  [4392] = 4392,
  [4393] = 4279,
  [4394] = 4290,
  [4395] = 4268,
  [4396] = 4264,
  [4397] = 4264,
  [4398] = 3850,
  [4399] = 3852,
  [4400] = 4400,
  [4401] = 4401,
  [4402] = 4402,
  [4403] = 4403,
  [4404] = 4380,
  [4405] = 4400,
  [4406] = 3850,
  [4407] = 4402,
  [4408] = 4403,
  [4409] = 4379,
  [4410] = 4400,
  [4411] = 3852,
  [4412] = 4264,
  [4413] = 4380,
  [4414] = 4402,
  [4415] = 4403,
  [4416] = 4264,
  [4417] = 4400,
  [4418] = 4402,
  [4419] = 4403,
  [4420] = 4400,
  [4421] = 4400,
  [4422] = 4400,
  [4423] = 4400,
  [4424] = 4400,
  [4425] = 4400,
  [4426] = 4257,
  [4427] = 4427,
  [4428] = 4290,
  [4429] = 4400,
  [4430] = 4400,
  [4431] = 4400,
  [4432] = 4400,
  [4433] = 4400,
  [4434] = 4400,
  [4435] = 4379,
  [4436] = 4400,
  [4437] = 4255,
  [4438] = 4400,
  [4439] = 4380,
  [4440] = 4279,
  [4441] = 4400,
  [4442] = 4400,
  [4443] = 4400,
  [4444] = 4400,
  [4445] = 4445,
  [4446] = 4400,
  [4447] = 4447,
  [4448] = 4448,
  [4449] = 4264,
  [4450] = 4257,
  [4451] = 4267,
  [4452] = 4255,
  [4453] = 4255,
  [4454] = 4257,
  [4455] = 4279,
  [4456] = 4290,
  [4457] = 4457,
  [4458] = 4279,
  [4459] = 4400,
  [4460] = 4267,
  [4461] = 4402,
  [4462] = 4267,
  [4463] = 4403,
  [4464] = 4464,
  [4465] = 4465,
  [4466] = 4400,
  [4467] = 3852,
  [4468] = 4264,
  [4469] = 4268,
  [4470] = 3850,
  [4471] = 3852,
  [4472] = 3850,
  [4473] = 3852,
  [4474] = 3852,
  [4475] = 3850,
  [4476] = 3852,
  [4477] = 4279,
  [4478] = 4478,
  [4479] = 4279,
  [4480] = 4290,
  [4481] = 4290,
  [4482] = 4267,
  [4483] = 4267,
  [4484] = 3850,
  [4485] = 4267,
  [4486] = 4279,
  [4487] = 4386,
  [4488] = 4387,
  [4489] = 4267,
  [4490] = 4367,
  [4491] = 4290,
  [4492] = 4264,
  [4493] = 4493,
  [4494] = 4264,
  [4495] = 4279,
  [4496] = 4257,
  [4497] = 4290,
  [4498] = 4268,
  [4499] = 4245,
  [4500] = 4264,
  [4501] = 4291,
  [4502] = 4294,
  [4503] = 4295,
  [4504] = 4268,
  [4505] = 4448,
  [4506] = 4386,
  [4507] = 4387,
  [4508] = 4179,
  [4509] = 4509,
  [4510] = 4264,
  [4511] = 4511,
  [4512] = 3852,
  [4513] = 4264,
  [4514] = 4264,
  [4515] = 4290,
  [4516] = 4478,
  [4517] = 4264,
  [4518] = 4255,
  [4519] = 4387,
  [4520] = 4447,
  [4521] = 4290,
  [4522] = 4448,
  [4523] = 4379,
  [4524] = 4279,
  [4525] = 4380,
  [4526] = 3850,
  [4527] = 4279,
  [4528] = 4290,
  [4529] = 4379,
  [4530] = 3852,
  [4531] = 4290,
  [4532] = 4255,
  [4533] = 4249,
  [4534] = 4379,
  [4535] = 4257,
  [4536] = 4380,
  [4537] = 4380,
  [4538] = 4279,
  [4539] = 4353,
  [4540] = 4255,
  [4541] = 4279,
  [4542] = 4381,
  [4543] = 4355,
  [4544] = 4368,
  [4545] = 4369,
  [4546] = 4372,
  [4547] = 4257,
  [4548] = 4245,
  [4549] = 4245,
  [4550] = 4264,
  [4551] = 4277,
  [4552] = 4386,
  [4553] = 4387,
  [4554] = 4264,
  [4555] = 3850,
  [4556] = 4386,
  [4557] = 4379,
  [4558] = 4379,
  [4559] = 4447,
  [4560] = 4267,
  [4561] = 4380,
  [4562] = 4493,
  [4563] = 4445,
  [4564] = 4380,
  [4565] = 4445,
  [4566] = 4478,
  [4567] = 4290,
  [4568] = 4264,
  [4569] = 4386,
  [4570] = 4387,
  [4571] = 4445,
  [4572] = 3852,
  [4573] = 4249,
  [4574] = 4268,
  [4575] = 4264,
  [4576] = 4493,
  [4577] = 4464,
  [4578] = 4465,
  [4579] = 4379,
  [4580] = 3850,
  [4581] = 4427,
  [4582] = 3850,
  [4583] = 4386,
  [4584] = 4478,
  [4585] = 4387,
  [4586] = 4448,
  [4587] = 4290,
  [4588] = 4249,
  [4589] = 4478,
  [4590] = 4279,
  [4591] = 4353,
  [4592] = 4380,
  [4593] = 4381,
  [4594] = 3852,
  [4595] = 4355,
  [4596] = 4368,
  [4597] = 3852,
  [4598] = 4369,
  [4599] = 4372,
  [4600] = 4478,
  [4601] = 4277,
  [4602] = 4493,
  [4603] = 4279,
  [4604] = 3850,
  [4605] = 3852,
  [4606] = 3850,
  [4607] = 4257,
  [4608] = 3852,
  [4609] = 4290,
  [4610] = 4268,
  [4611] = 4268,
  [4612] = 4290,
  [4613] = 4267,
  [4614] = 4386,
  [4615] = 4257,
  [4616] = 4387,
  [4617] = 4264,
  [4618] = 3850,
  [4619] = 4264,
  [4620] = 3852,
  [4621] = 4367,
  [4622] = 4379,
  [4623] = 4245,
  [4624] = 4255,
  [4625] = 3850,
  [4626] = 3852,
  [4627] = 4493,
  [4628] = 4380,
  [4629] = 4279,
  [4630] = 4268,
  [4631] = 4386,
  [4632] = 4632,
  [4633] = 3852,
  [4634] = 3850,
  [4635] = 4255,
  [4636] = 4386,
  [4637] = 4637,
  [4638] = 4445,
  [4639] = 4279,
  [4640] = 4264,
  [4641] = 4447,
  [4642] = 4379,
  [4643] = 4445,
  [4644] = 4448,
  [4645] = 4447,
  [4646] = 4367,
  [4647] = 4264,
  [4648] = 4355,
  [4649] = 4386,
  [4650] = 4387,
  [4651] = 4448,
  [4652] = 4387,
  [4653] = 4367,
  [4654] = 4368,
  [4655] = 4249,
  [4656] = 4257,
  [4657] = 4264,
  [4658] = 4267,
  [4659] = 4353,
  [4660] = 4369,
  [4661] = 4291,
  [4662] = 4381,
  [4663] = 4372,
  [4664] = 4509,
  [4665] = 4267,
  [4666] = 4264,
  [4667] = 4294,
  [4668] = 4387,
  [4669] = 4267,
  [4670] = 3850,
  [4671] = 4277,
  [4672] = 4355,
  [4673] = 4290,
  [4674] = 4295,
  [4675] = 4381,
  [4676] = 4279,
  [4677] = 4279,
  [4678] = 4291,
  [4679] = 4493,
  [4680] = 4290,
  [4681] = 4279,
  [4682] = 4279,
  [4683] = 4294,
  [4684] = 4509,
  [4685] = 3852,
  [4686] = 4379,
  [4687] = 4179,
  [4688] = 4295,
  [4689] = 4290,
  [4690] = 4493,
  [4691] = 4401,
  [4692] = 4291,
  [4693] = 4294,
  [4694] = 4380,
  [4695] = 4379,
  [4696] = 4295,
  [4697] = 4267,
  [4698] = 4264,
  [4699] = 4267,
  [4700] = 4368,
  [4701] = 4179,
  [4702] = 4245,
  [4703] = 4478,
  [4704] = 4369,
  [4705] = 4249,
  [4706] = 4264,
  [4707] = 4267,
  [4708] = 4267,
  [4709] = 4386,
  [4710] = 4380,
  [4711] = 4245,
  [4712] = 4255,
  [4713] = 4353,
  [4714] = 4380,
  [4715] = 4355,
  [4716] = 4367,
  [4717] = 4368,
  [4718] = 4369,
  [4719] = 4372,
  [4720] = 4245,
  [4721] = 4372,
  [4722] = 4277,
  [4723] = 4277,
  [4724] = 4379,
  [4725] = 4381,
  [4726] = 3850,
  [4727] = 3852,
  [4728] = 4380,
  [4729] = 4729,
  [4730] = 4730,
  [4731] = 4245,
  [4732] = 4257,
  [4733] = 4387,
  [4734] = 3850,
  [4735] = 4267,
  [4736] = 4179,
  [4737] = 4290,
  [4738] = 4245,
  [4739] = 4264,
  [4740] = 4267,
  [4741] = 4353,
  [4742] = 4291,
  [4743] = 4379,
  [4744] = 4279,
  [4745] = 4294,
  [4746] = 4380,
  [4747] = 4290,
  [4748] = 4255,
  [4749] = 4267,
  [4750] = 4268,
  [4751] = 4295,
  [4752] = 4267,
  [4753] = 4279,
  [4754] = 4290,
  [4755] = 4447,
  [4756] = 4179,
  [4757] = 4268,
  [4758] = 4637,
  [4759] = 4759,
  [4760] = 4294,
  [4761] = 4267,
  [4762] = 4295,
  [4763] = 4493,
  [4764] = 3850,
  [4765] = 4368,
  [4766] = 4249,
  [4767] = 4369,
  [4768] = 4290,
  [4769] = 4401,
  [4770] = 4372,
  [4771] = 4245,
  [4772] = 4493,
  [4773] = 4249,
  [4774] = 4277,
  [4775] = 4730,
  [4776] = 4290,
  [4777] = 4386,
  [4778] = 4387,
  [4779] = 4291,
  [4780] = 4294,
  [4781] = 4295,
  [4782] = 4632,
  [4783] = 4179,
  [4784] = 4179,
  [4785] = 4291,
  [4786] = 4509,
  [4787] = 4294,
  [4788] = 4295,
  [4789] = 4367,
  [4790] = 4381,
  [4791] = 4386,
  [4792] = 4464,
  [4793] = 4245,
  [4794] = 4179,
  [4795] = 4387,
  [4796] = 4465,
  [4797] = 4447,
  [4798] = 4427,
  [4799] = 4179,
  [4800] = 4386,
  [4801] = 4249,
  [4802] = 4291,
  [4803] = 4294,
  [4804] = 4290,
  [4805] = 4295,
  [4806] = 4386,
  [4807] = 4729,
  [4808] = 4730,
  [4809] = 3852,
  [4810] = 4268,
  [4811] = 3850,
  [4812] = 4387,
  [4813] = 4353,
  [4814] = 4381,
  [4815] = 4355,
  [4816] = 4290,
  [4817] = 4264,
  [4818] = 4368,
  [4819] = 4369,
  [4820] = 4353,
  [4821] = 4372,
  [4822] = 4277,
  [4823] = 4401,
  [4824] = 4179,
  [4825] = 4355,
  [4826] = 4826,
  [4827] = 4368,
  [4828] = 4249,
  [4829] = 4369,
  [4830] = 4353,
  [4831] = 4264,
  [4832] = 4372,
  [4833] = 4245,
  [4834] = 4277,
  [4835] = 4381,
  [4836] = 4355,
  [4837] = 4257,
  [4838] = 4386,
  [4839] = 4387,
  [4840] = 4264,
  [4841] = 4464,
  [4842] = 4465,
  [4843] = 4427,
  [4844] = 4448,
  [4845] = 4387,
  [4846] = 4268,
  [4847] = 4249,
  [4848] = 4267,
  [4849] = 4368,
  [4850] = 4279,
  [4851] = 4353,
  [4852] = 4381,
  [4853] = 4381,
  [4854] = 4854,
  [4855] = 4355,
  [4856] = 4368,
  [4857] = 4290,
  [4858] = 4369,
  [4859] = 4509,
  [4860] = 4255,
  [4861] = 4372,
  [4862] = 4277,
  [4863] = 4369,
  [4864] = 4291,
  [4865] = 4509,
  [4866] = 4245,
  [4867] = 4267,
  [4868] = 4294,
  [4869] = 4295,
  [4870] = 4268,
  [4871] = 4372,
  [4872] = 4277,
  [4873] = 4367,
  [4874] = 3852,
  [4875] = 4245,
  [4876] = 4264,
  [4877] = 4290,
  [4878] = 4386,
  [4879] = 4387,
  [4880] = 4245,
  [4881] = 4445,
  [4882] = 4179,
  [4883] = 4267,
  [4884] = 4447,
  [4885] = 4478,
  [4886] = 4264,
  [4887] = 4279,
  [4888] = 4448,
  [4889] = 4379,
  [4890] = 4353,
  [4891] = 3850,
  [4892] = 4264,
  [4893] = 4268,
  [4894] = 4255,
  [4895] = 4895,
  [4896] = 4257,
  [4897] = 4264,
  [4898] = 4379,
  [4899] = 4380,
  [4900] = 4268,
  [4901] = 4632,
  [4902] = 4291,
  [4903] = 4294,
  [4904] = 4295,
  [4905] = 4355,
  [4906] = 4368,
  [4907] = 4637,
  [4908] = 4445,
  [4909] = 4386,
  [4910] = 4387,
  [4911] = 4386,
  [4912] = 4387,
  [4913] = 4255,
  [4914] = 4447,
  [4915] = 4257,
  [4916] = 3850,
  [4917] = 4291,
  [4918] = 4267,
  [4919] = 4294,
  [4920] = 4295,
  [4921] = 4448,
  [4922] = 3852,
  [4923] = 4493,
  [4924] = 4179,
  [4925] = 3852,
  [4926] = 4369,
  [4927] = 4380,
  [4928] = 4372,
  [4929] = 4493,
  [4930] = 3850,
  [4931] = 3852,
  [4932] = 4179,
  [4933] = 4895,
  [4934] = 4268,
  [4935] = 3850,
  [4936] = 4277,
  [4937] = 3852,
  [4938] = 3850,
  [4939] = 3852,
  [4940] = 3850,
  [4941] = 3852,
  [4942] = 4255,
  [4943] = 4268,
  [4944] = 4381,
  [4945] = 4729,
  [4946] = 3850,
  [4947] = 4379,
  [4948] = 3852,
  [4949] = 4257,
  [4950] = 4478,
  [4951] = 4493,
  [4952] = 4249,
  [4953] = 4264,
  [4954] = 4267,
  [4955] = 4279,
  [4956] = 4729,
  [4957] = 4379,
  [4958] = 4380,
  [4959] = 4268,
  [4960] = 4264,
  [4961] = 4379,
  [4962] = 4478,
  [4963] = 4264,
  [4964] = 4730,
  [4965] = 4464,
  [4966] = 4379,
  [4967] = 4967,
  [4968] = 4465,
  [4969] = 4367,
  [4970] = 4264,
  [4971] = 4478,
  [4972] = 4380,
  [4973] = 4264,
  [4974] = 4367,
  [4975] = 4249,
  [4976] = 4380,
  [4977] = 4427,
  [4978] = 4353,
  [4979] = 4353,
  [4980] = 4381,
  [4981] = 4367,
  [4982] = 4355,
  [4983] = 4368,
  [4984] = 4279,
  [4985] = 4369,
  [4986] = 4372,
  [4987] = 4279,
  [4988] = 4290,
  [4989] = 4277,
  [4990] = 4380,
  [4991] = 4267,
  [4992] = 4267,
  [4993] = 3850,
  [4994] = 4290,
  [4995] = 4267,
  [4996] = 4290,
  [4997] = 3852,
  [4998] = 4267,
  [4999] = 3850,
  [5000] = 4759,
  [5001] = 4264,
  [5002] = 4279,
  [5003] = 4290,
  [5004] = 4386,
  [5005] = 4245,
  [5006] = 4267,
  [5007] = 4387,
  [5008] = 3852,
  [5009] = 4279,
  [5010] = 4478,
  [5011] = 4379,
  [5012] = 4401,
  [5013] = 4267,
  [5014] = 4464,
  [5015] = 4367,
  [5016] = 4465,
  [5017] = 4386,
  [5018] = 4387,
  [5019] = 4427,
  [5020] = 3850,
  [5021] = 4380,
  [5022] = 4279,
  [5023] = 4478,
  [5024] = 4268,
  [5025] = 3852,
  [5026] = 4267,
  [5027] = 4264,
  [5028] = 4367,
  [5029] = 4826,
  [5030] = 4279,
  [5031] = 4267,
  [5032] = 4493,
  [5033] = 4267,
  [5034] = 4245,
  [5035] = 4279,
  [5036] = 4290,
  [5037] = 4478,
  [5038] = 4355,
  [5039] = 4279,
  [5040] = 4245,
  [5041] = 4401,
  [5042] = 4291,
  [5043] = 4267,
  [5044] = 4264,
  [5045] = 4478,
  [5046] = 4493,
  [5047] = 4493,
  [5048] = 4295,
  [5049] = 3852,
  [5050] = 4268,
  [5051] = 4967,
  [5052] = 4493,
  [5053] = 4895,
  [5054] = 4264,
  [5055] = 4464,
  [5056] = 4465,
  [5057] = 4427,
  [5058] = 4290,
  [5059] = 4464,
  [5060] = 4249,
  [5061] = 4465,
  [5062] = 4427,
  [5063] = 4379,
  [5064] = 4478,
  [5065] = 4290,
  [5066] = 4353,
  [5067] = 4268,
  [5068] = 4381,
  [5069] = 4355,
  [5070] = 4368,
  [5071] = 4249,
  [5072] = 4369,
  [5073] = 4372,
  [5074] = 4277,
  [5075] = 4279,
  [5076] = 4267,
  [5077] = 4380,
  [5078] = 4353,
  [5079] = 4264,
  [5080] = 4381,
  [5081] = 4355,
  [5082] = 4368,
  [5083] = 4369,
  [5084] = 4372,
  [5085] = 4277,
  [5086] = 4245,
  [5087] = 4279,
  [5088] = 4401,
  [5089] = 4249,
  [5090] = 4179,
  [5091] = 4380,
  [5092] = 4279,
  [5093] = 4291,
  [5094] = 4294,
  [5095] = 4295,
  [5096] = 4353,
  [5097] = 4381,
  [5098] = 4355,
  [5099] = 4368,
  [5100] = 4369,
  [5101] = 4245,
  [5102] = 4372,
  [5103] = 4277,
  [5104] = 4179,
  [5105] = 4386,
  [5106] = 4387,
  [5107] = 4380,
  [5108] = 4464,
  [5109] = 4367,
  [5110] = 4465,
  [5111] = 4427,
  [5112] = 4268,
  [5113] = 4401,
  [5114] = 4179,
  [5115] = 4264,
  [5116] = 4367,
  [5117] = 4249,
  [5118] = 5118,
  [5119] = 4264,
  [5120] = 4264,
  [5121] = 4367,
  [5122] = 4353,
  [5123] = 4381,
  [5124] = 4290,
  [5125] = 4355,
  [5126] = 4368,
  [5127] = 4369,
  [5128] = 4372,
  [5129] = 4277,
  [5130] = 4729,
  [5131] = 4264,
  [5132] = 4730,
  [5133] = 3850,
  [5134] = 5134,
  [5135] = 4268,
  [5136] = 4380,
  [5137] = 3852,
  [5138] = 4401,
  [5139] = 4367,
  [5140] = 4245,
  [5141] = 3850,
  [5142] = 4386,
  [5143] = 4387,
  [5144] = 4264,
  [5145] = 3852,
  [5146] = 4249,
  [5147] = 3850,
  [5148] = 4290,
  [5149] = 4401,
  [5150] = 4493,
  [5151] = 4386,
  [5152] = 4387,
  [5153] = 4291,
  [5154] = 4294,
  [5155] = 3852,
  [5156] = 4386,
  [5157] = 4464,
  [5158] = 4245,
  [5159] = 4387,
  [5160] = 4465,
  [5161] = 4427,
  [5162] = 4179,
  [5163] = 4268,
  [5164] = 4291,
  [5165] = 4294,
  [5166] = 4295,
  [5167] = 4245,
  [5168] = 4179,
  [5169] = 3850,
  [5170] = 4291,
  [5171] = 4294,
  [5172] = 4295,
  [5173] = 3852,
  [5174] = 4179,
  [5175] = 3850,
  [5176] = 3852,
  [5177] = 4291,
  [5178] = 4294,
  [5179] = 4295,
  [5180] = 4179,
  [5181] = 4386,
  [5182] = 4267,
  [5183] = 4387,
  [5184] = 3850,
  [5185] = 3852,
  [5186] = 4386,
  [5187] = 4387,
  [5188] = 4264,
  [5189] = 4478,
  [5190] = 3850,
  [5191] = 3852,
  [5192] = 3850,
  [5193] = 3852,
  [5194] = 3850,
  [5195] = 3852,
  [5196] = 4268,
  [5197] = 4268,
  [5198] = 4447,
  [5199] = 4264,
  [5200] = 4379,
  [5201] = 4245,
  [5202] = 4493,
  [5203] = 4386,
  [5204] = 4245,
  [5205] = 4759,
  [5206] = 4759,
  [5207] = 4267,
  [5208] = 4759,
  [5209] = 4267,
  [5210] = 4267,
  [5211] = 4379,
  [5212] = 4387,
  [5213] = 3850,
  [5214] = 4367,
  [5215] = 4264,
  [5216] = 4759,
  [5217] = 4267,
  [5218] = 4380,
  [5219] = 4759,
  [5220] = 4279,
  [5221] = 4464,
  [5222] = 4267,
  [5223] = 4759,
  [5224] = 4291,
  [5225] = 4637,
  [5226] = 4257,
  [5227] = 4465,
  [5228] = 4445,
  [5229] = 4427,
  [5230] = 4294,
  [5231] = 3852,
  [5232] = 4478,
  [5233] = 4290,
  [5234] = 4267,
  [5235] = 4249,
  [5236] = 4386,
  [5237] = 4295,
  [5238] = 4632,
  [5239] = 4379,
  [5240] = 4267,
  [5241] = 5241,
  [5242] = 4387,
  [5243] = 4353,
  [5244] = 5244,
  [5245] = 4268,
  [5246] = 4267,
  [5247] = 4447,
  [5248] = 5248,
  [5249] = 5249,
  [5250] = 4445,
  [5251] = 4448,
  [5252] = 4290,
  [5253] = 4179,
  [5254] = 4967,
  [5255] = 4386,
  [5256] = 4255,
  [5257] = 4447,
  [5258] = 4464,
  [5259] = 4264,
  [5260] = 4445,
  [5261] = 4379,
  [5262] = 4355,
  [5263] = 4387,
  [5264] = 4291,
  [5265] = 4445,
  [5266] = 4448,
  [5267] = 4826,
  [5268] = 4465,
  [5269] = 4478,
  [5270] = 4294,
  [5271] = 4427,
  [5272] = 4267,
  [5273] = 4380,
  [5274] = 4295,
  [5275] = 4368,
  [5276] = 5276,
  [5277] = 4249,
  [5278] = 4353,
  [5279] = 4493,
  [5280] = 4387,
  [5281] = 4381,
  [5282] = 4369,
  [5283] = 4279,
  [5284] = 4355,
  [5285] = 4368,
  [5286] = 4372,
  [5287] = 4369,
  [5288] = 4372,
  [5289] = 4277,
  [5290] = 4277,
  [5291] = 4179,
  [5292] = 4179,
  [5293] = 4895,
  [5294] = 4267,
  [5295] = 3850,
  [5296] = 4353,
  [5297] = 4380,
  [5298] = 4264,
  [5299] = 4264,
  [5300] = 4381,
  [5301] = 4279,
  [5302] = 4290,
  [5303] = 4355,
  [5304] = 4290,
  [5305] = 5305,
  [5306] = 4073,
  [5307] = 4368,
  [5308] = 4249,
  [5309] = 4369,
  [5310] = 4509,
  [5311] = 4372,
  [5312] = 4277,
  [5313] = 4279,
  [5314] = 4291,
  [5315] = 4290,
  [5316] = 4294,
  [5317] = 4478,
  [5318] = 4295,
  [5319] = 4632,
  [5320] = 4637,
  [5321] = 4381,
  [5322] = 4632,
  [5323] = 4759,
  [5324] = 4290,
  [5325] = 4637,
  [5326] = 4279,
  [5327] = 4401,
  [5328] = 4826,
  [5329] = 3852,
  [5330] = 4759,
  [5331] = 3850,
  [5332] = 5332,
  [5333] = 4509,
  [5334] = 4367,
  [5335] = 4179,
  [5336] = 4448,
  [5337] = 3852,
  [5338] = 4464,
  [5339] = 4267,
  [5340] = 4465,
  [5341] = 4729,
  [5342] = 4427,
  [5343] = 4730,
  [5344] = 4279,
  [5345] = 4759,
  [5346] = 4267,
  [5347] = 4290,
  [5348] = 4257,
  [5349] = 4826,
  [5350] = 4729,
  [5351] = 4730,
  [5352] = 5352,
  [5353] = 4854,
  [5354] = 5354,
  [5355] = 4509,
  [5356] = 5356,
  [5357] = 4826,
  [5358] = 4291,
  [5359] = 5359,
  [5360] = 4294,
  [5361] = 5361,
  [5362] = 4295,
  [5363] = 4493,
  [5364] = 4445,
  [5365] = 5365,
  [5366] = 4493,
  [5367] = 4895,
  [5368] = 5365,
  [5369] = 4493,
  [5370] = 4447,
  [5371] = 5365,
  [5372] = 4268,
  [5373] = 5365,
  [5374] = 4448,
  [5375] = 4179,
  [5376] = 4895,
  [5377] = 4267,
  [5378] = 4353,
  [5379] = 4493,
  [5380] = 4493,
  [5381] = 4255,
  [5382] = 4249,
  [5383] = 4379,
  [5384] = 4895,
  [5385] = 4257,
  [5386] = 4291,
  [5387] = 4353,
  [5388] = 5365,
  [5389] = 4478,
  [5390] = 4380,
  [5391] = 4279,
  [5392] = 4355,
  [5393] = 4368,
  [5394] = 4249,
  [5395] = 4369,
  [5396] = 4372,
  [5397] = 4290,
  [5398] = 4277,
  [5399] = 5399,
  [5400] = 4478,
  [5401] = 4355,
  [5402] = 4264,
  [5403] = 4381,
  [5404] = 4368,
  [5405] = 4267,
  [5406] = 4353,
  [5407] = 4478,
  [5408] = 4369,
  [5409] = 4355,
  [5410] = 4255,
  [5411] = 4367,
  [5412] = 4368,
  [5413] = 4369,
  [5414] = 5414,
  [5415] = 4372,
  [5416] = 4493,
  [5417] = 4277,
  [5418] = 4257,
  [5419] = 4401,
  [5420] = 4381,
  [5421] = 4367,
  [5422] = 4245,
  [5423] = 4372,
  [5424] = 4264,
  [5425] = 4279,
  [5426] = 4464,
  [5427] = 4294,
  [5428] = 4465,
  [5429] = 4379,
  [5430] = 4427,
  [5431] = 4478,
  [5432] = 4401,
  [5433] = 4277,
  [5434] = 4367,
  [5435] = 4729,
  [5436] = 4730,
  [5437] = 4380,
  [5438] = 4729,
  [5439] = 4730,
  [5440] = 4267,
  [5441] = 4381,
  [5442] = 4290,
  [5443] = 4267,
  [5444] = 4264,
  [5445] = 3850,
  [5446] = 4279,
  [5447] = 4478,
  [5448] = 4279,
  [5449] = 4379,
  [5450] = 4279,
  [5451] = 5118,
  [5452] = 4295,
  [5453] = 4279,
  [5454] = 4255,
  [5455] = 5134,
  [5456] = 4245,
  [5457] = 4854,
  [5458] = 4245,
  [5459] = 4386,
  [5460] = 4379,
  [5461] = 4367,
  [5462] = 4268,
  [5463] = 4826,
  [5464] = 4264,
  [5465] = 5465,
  [5466] = 4826,
  [5467] = 4379,
  [5468] = 4369,
  [5469] = 4367,
  [5470] = 4372,
  [5471] = 4291,
  [5472] = 4277,
  [5473] = 4294,
  [5474] = 4295,
  [5475] = 4264,
  [5476] = 4493,
  [5477] = 4386,
  [5478] = 4387,
  [5479] = 5332,
  [5480] = 4179,
  [5481] = 3850,
  [5482] = 4493,
  [5483] = 4277,
  [5484] = 4245,
  [5485] = 3852,
  [5486] = 4369,
  [5487] = 4367,
  [5488] = 4381,
  [5489] = 3850,
  [5490] = 4493,
  [5491] = 4381,
  [5492] = 3852,
  [5493] = 3850,
  [5494] = 4291,
  [5495] = 4294,
  [5496] = 4295,
  [5497] = 4179,
  [5498] = 3852,
  [5499] = 4729,
  [5500] = 4464,
  [5501] = 4826,
  [5502] = 4369,
  [5503] = 4268,
  [5504] = 4291,
  [5505] = 4294,
  [5506] = 4295,
  [5507] = 4179,
  [5508] = 4380,
  [5509] = 4730,
  [5510] = 4291,
  [5511] = 4294,
  [5512] = 4295,
  [5513] = 4895,
  [5514] = 3850,
  [5515] = 4179,
  [5516] = 3852,
  [5517] = 3850,
  [5518] = 3850,
  [5519] = 3852,
  [5520] = 3852,
  [5521] = 3850,
  [5522] = 3852,
  [5523] = 3850,
  [5524] = 4291,
  [5525] = 3852,
  [5526] = 4465,
  [5527] = 3850,
  [5528] = 3852,
  [5529] = 3850,
  [5530] = 3852,
  [5531] = 3850,
  [5532] = 3852,
  [5533] = 4179,
  [5534] = 4372,
  [5535] = 4379,
  [5536] = 4245,
  [5537] = 3850,
  [5538] = 3852,
  [5539] = 4267,
  [5540] = 4895,
  [5541] = 4895,
  [5542] = 4729,
  [5543] = 4179,
  [5544] = 4895,
  [5545] = 4380,
  [5546] = 4279,
  [5547] = 4268,
  [5548] = 4294,
  [5549] = 4427,
  [5550] = 4730,
  [5551] = 4386,
  [5552] = 4478,
  [5553] = 5553,
  [5554] = 4381,
  [5555] = 4386,
  [5556] = 4267,
  [5557] = 4759,
  [5558] = 4759,
  [5559] = 4759,
  [5560] = 4387,
  [5561] = 4895,
  [5562] = 4759,
  [5563] = 4290,
  [5564] = 4290,
  [5565] = 4267,
  [5566] = 4379,
  [5567] = 3850,
  [5568] = 4295,
  [5569] = 3852,
  [5570] = 4381,
  [5571] = 5352,
  [5572] = 4268,
  [5573] = 4493,
  [5574] = 4478,
  [5575] = 5354,
  [5576] = 4267,
  [5577] = 4493,
  [5578] = 4401,
  [5579] = 4367,
  [5580] = 4267,
  [5581] = 4759,
  [5582] = 4759,
  [5583] = 4464,
  [5584] = 5356,
  [5585] = 4267,
  [5586] = 5361,
  [5587] = 4245,
  [5588] = 4355,
  [5589] = 4730,
  [5590] = 4895,
  [5591] = 5591,
  [5592] = 4854,
  [5593] = 5359,
  [5594] = 4478,
  [5595] = 4465,
  [5596] = 5361,
  [5597] = 4268,
  [5598] = 4279,
  [5599] = 4290,
  [5600] = 4464,
  [5601] = 4367,
  [5602] = 4245,
  [5603] = 4277,
  [5604] = 4465,
  [5605] = 4427,
  [5606] = 4729,
  [5607] = 3850,
  [5608] = 4291,
  [5609] = 4427,
  [5610] = 4294,
  [5611] = 4295,
  [5612] = 4730,
  [5613] = 4380,
  [5614] = 4386,
  [5615] = 4279,
  [5616] = 4257,
  [5617] = 4478,
  [5618] = 4264,
  [5619] = 4509,
  [5620] = 4291,
  [5621] = 4294,
  [5622] = 4290,
  [5623] = 4295,
  [5624] = 5134,
  [5625] = 4401,
  [5626] = 4464,
  [5627] = 5356,
  [5628] = 4465,
  [5629] = 4637,
  [5630] = 4290,
  [5631] = 4427,
  [5632] = 4291,
  [5633] = 4509,
  [5634] = 5118,
  [5635] = 4895,
  [5636] = 4073,
  [5637] = 4179,
  [5638] = 4759,
  [5639] = 4386,
  [5640] = 4255,
  [5641] = 4447,
  [5642] = 4294,
  [5643] = 4464,
  [5644] = 4264,
  [5645] = 4445,
  [5646] = 4279,
  [5647] = 4465,
  [5648] = 4448,
  [5649] = 4427,
  [5650] = 4729,
  [5651] = 5553,
  [5652] = 4730,
  [5653] = 4179,
  [5654] = 4279,
  [5655] = 4759,
  [5656] = 4295,
  [5657] = 4268,
  [5658] = 4464,
  [5659] = 4367,
  [5660] = 4465,
  [5661] = 4401,
  [5662] = 4427,
  [5663] = 4368,
  [5664] = 4401,
  [5665] = 4268,
  [5666] = 4264,
  [5667] = 4245,
  [5668] = 4249,
  [5669] = 4387,
  [5670] = 4464,
  [5671] = 4245,
  [5672] = 5414,
  [5673] = 4632,
  [5674] = 4291,
  [5675] = 3852,
  [5676] = 4465,
  [5677] = 5677,
  [5678] = 4294,
  [5679] = 5679,
  [5680] = 4427,
  [5681] = 4257,
  [5682] = 4295,
  [5683] = 5359,
  [5684] = 5684,
  [5685] = 5685,
  [5686] = 5686,
  [5687] = 5687,
  [5688] = 5276,
  [5689] = 4379,
  [5690] = 5690,
  [5691] = 5691,
  [5692] = 5692,
  [5693] = 5693,
  [5694] = 3850,
  [5695] = 5695,
  [5696] = 5696,
  [5697] = 5697,
  [5698] = 5698,
  [5699] = 3852,
  [5700] = 5241,
  [5701] = 4267,
  [5702] = 3850,
  [5703] = 5134,
  [5704] = 4268,
  [5705] = 4268,
  [5706] = 3852,
  [5707] = 4854,
  [5708] = 4279,
  [5709] = 4290,
  [5710] = 4493,
  [5711] = 4729,
  [5712] = 4279,
  [5713] = 4379,
  [5714] = 4478,
  [5715] = 4255,
  [5716] = 4372,
  [5717] = 4386,
  [5718] = 4249,
  [5719] = 4854,
  [5720] = 4445,
  [5721] = 4380,
  [5722] = 4386,
  [5723] = 4073,
  [5724] = 5118,
  [5725] = 4249,
  [5726] = 4267,
  [5727] = 4447,
  [5728] = 4445,
  [5729] = 5729,
  [5730] = 5730,
  [5731] = 4290,
  [5732] = 4401,
  [5733] = 4448,
  [5734] = 5734,
  [5735] = 4291,
  [5736] = 5736,
  [5737] = 5737,
  [5738] = 5244,
  [5739] = 4387,
  [5740] = 4277,
  [5741] = 5741,
  [5742] = 4447,
  [5743] = 5248,
  [5744] = 5249,
  [5745] = 4478,
  [5746] = 5746,
  [5747] = 4448,
  [5748] = 4632,
  [5749] = 4264,
  [5750] = 5241,
  [5751] = 5244,
  [5752] = 3852,
  [5753] = 4967,
  [5754] = 4294,
  [5755] = 3850,
  [5756] = 4379,
  [5757] = 5248,
  [5758] = 5249,
  [5759] = 4295,
  [5760] = 4637,
  [5761] = 4445,
  [5762] = 4179,
  [5763] = 4386,
  [5764] = 3850,
  [5765] = 4372,
  [5766] = 5241,
  [5767] = 4387,
  [5768] = 5134,
  [5769] = 5244,
  [5770] = 4447,
  [5771] = 4279,
  [5772] = 4448,
  [5773] = 4478,
  [5774] = 4379,
  [5775] = 4464,
  [5776] = 3852,
  [5777] = 4386,
  [5778] = 5276,
  [5779] = 4279,
  [5780] = 4268,
  [5781] = 4386,
  [5782] = 5118,
  [5783] = 4245,
  [5784] = 4826,
  [5785] = 4387,
  [5786] = 4465,
  [5787] = 4427,
  [5788] = 4387,
  [5789] = 4179,
  [5790] = 3852,
  [5791] = 4380,
  [5792] = 4279,
  [5793] = 4245,
  [5794] = 4632,
  [5795] = 4353,
  [5796] = 5118,
  [5797] = 4380,
  [5798] = 4381,
  [5799] = 4355,
  [5800] = 4179,
  [5801] = 4279,
  [5802] = 4368,
  [5803] = 5803,
  [5804] = 4179,
  [5805] = 5805,
  [5806] = 5806,
  [5807] = 4290,
  [5808] = 4369,
  [5809] = 4637,
  [5810] = 4367,
  [5811] = 4279,
  [5812] = 4509,
  [5813] = 4249,
  [5814] = 4372,
  [5815] = 4073,
  [5816] = 4509,
  [5817] = 3852,
  [5818] = 4264,
  [5819] = 4290,
  [5820] = 4277,
  [5821] = 3852,
  [5822] = 4759,
  [5823] = 4267,
  [5824] = 5134,
  [5825] = 4290,
  [5826] = 4380,
  [5827] = 4387,
  [5828] = 4387,
  [5829] = 4464,
  [5830] = 4465,
  [5831] = 4427,
  [5832] = 3850,
  [5833] = 4759,
  [5834] = 4465,
  [5835] = 4353,
  [5836] = 4401,
  [5837] = 4381,
  [5838] = 4264,
  [5839] = 4355,
  [5840] = 4895,
  [5841] = 4759,
  [5842] = 4290,
  [5843] = 4387,
  [5844] = 4368,
  [5845] = 4245,
  [5846] = 4386,
  [5847] = 4369,
  [5848] = 4268,
  [5849] = 4427,
  [5850] = 4372,
  [5851] = 4290,
  [5852] = 4277,
  [5853] = 4267,
  [5854] = 4387,
  [5855] = 4249,
  [5856] = 4826,
  [5857] = 4268,
  [5858] = 4379,
  [5859] = 4464,
  [5860] = 4401,
  [5861] = 4367,
  [5862] = 4249,
  [5863] = 4493,
  [5864] = 4464,
  [5865] = 4353,
  [5866] = 4967,
  [5867] = 4465,
  [5868] = 4729,
  [5869] = 5352,
  [5870] = 5332,
  [5871] = 4427,
  [5872] = 5354,
  [5873] = 4380,
  [5874] = 4465,
  [5875] = 4493,
  [5876] = 4268,
  [5877] = 4353,
  [5878] = 5356,
  [5879] = 5248,
  [5880] = 5359,
  [5881] = 5249,
  [5882] = 5361,
  [5883] = 4967,
  [5884] = 4381,
  [5885] = 4264,
  [5886] = 4353,
  [5887] = 4379,
  [5888] = 4493,
  [5889] = 4245,
  [5890] = 4353,
  [5891] = 4264,
  [5892] = 4379,
  [5893] = 5893,
  [5894] = 4381,
  [5895] = 5276,
  [5896] = 4355,
  [5897] = 4493,
  [5898] = 4368,
  [5899] = 4249,
  [5900] = 4369,
  [5901] = 4729,
  [5902] = 4464,
  [5903] = 4355,
  [5904] = 4493,
  [5905] = 4730,
  [5906] = 4372,
  [5907] = 4427,
  [5908] = 4730,
  [5909] = 5553,
  [5910] = 4478,
  [5911] = 4380,
  [5912] = 4249,
  [5913] = 4401,
  [5914] = 4464,
  [5915] = 4277,
  [5916] = 4245,
  [5917] = 4465,
  [5918] = 4478,
  [5919] = 4427,
  [5920] = 4279,
  [5921] = 4367,
  [5922] = 4478,
  [5923] = 4355,
  [5924] = 4279,
  [5925] = 4290,
  [5926] = 4368,
  [5927] = 4268,
  [5928] = 4353,
  [5929] = 4249,
  [5930] = 4249,
  [5931] = 4355,
  [5932] = 4369,
  [5933] = 4401,
  [5934] = 4478,
  [5935] = 4279,
  [5936] = 4401,
  [5937] = 4386,
  [5938] = 4245,
  [5939] = 4245,
  [5940] = 4387,
  [5941] = 4372,
  [5942] = 4380,
  [5943] = 4353,
  [5944] = 4368,
  [5945] = 4279,
  [5946] = 4355,
  [5947] = 4368,
  [5948] = 4369,
  [5949] = 4826,
  [5950] = 4372,
  [5951] = 4355,
  [5952] = 4277,
  [5953] = 4277,
  [5954] = 4369,
  [5955] = 4353,
  [5956] = 4268,
  [5957] = 4381,
  [5958] = 4386,
  [5959] = 4179,
  [5960] = 4381,
  [5961] = 4355,
  [5962] = 4387,
  [5963] = 4291,
  [5964] = 4759,
  [5965] = 4294,
  [5966] = 5966,
  [5967] = 5967,
  [5968] = 4295,
  [5969] = 3850,
  [5970] = 5970,
  [5971] = 4826,
  [5972] = 5352,
  [5973] = 4353,
  [5974] = 5134,
  [5975] = 4367,
  [5976] = 4368,
  [5977] = 4279,
  [5978] = 4368,
  [5979] = 4369,
  [5980] = 4826,
  [5981] = 4368,
  [5982] = 4290,
  [5983] = 4372,
  [5984] = 3850,
  [5985] = 4245,
  [5986] = 5118,
  [5987] = 4277,
  [5988] = 5354,
  [5989] = 4386,
  [5990] = 4826,
  [5991] = 5414,
  [5992] = 4387,
  [5993] = 4367,
  [5994] = 4368,
  [5995] = 4267,
  [5996] = 4493,
  [5997] = 4465,
  [5998] = 4073,
  [5999] = 5134,
  [6000] = 4730,
  [6001] = 6001,
  [6002] = 3850,
  [6003] = 4268,
  [6004] = 4465,
  [6005] = 4267,
  [6006] = 4368,
  [6007] = 4245,
  [6008] = 4427,
  [6009] = 4759,
  [6010] = 4967,
  [6011] = 4759,
  [6012] = 4369,
  [6013] = 4478,
  [6014] = 5352,
  [6015] = 4386,
  [6016] = 4464,
  [6017] = 4759,
  [6018] = 4268,
  [6019] = 5697,
  [6020] = 4268,
  [6021] = 4367,
  [6022] = 4291,
  [6023] = 4372,
  [6024] = 4294,
  [6025] = 4295,
  [6026] = 5354,
  [6027] = 4294,
  [6028] = 4277,
  [6029] = 4277,
  [6030] = 6030,
  [6031] = 4295,
  [6032] = 4381,
  [6033] = 4493,
  [6034] = 5736,
  [6035] = 4291,
  [6036] = 4478,
  [6037] = 4637,
  [6038] = 4386,
  [6039] = 4478,
  [6040] = 5737,
  [6041] = 3852,
  [6042] = 4290,
  [6043] = 5356,
  [6044] = 4245,
  [6045] = 4367,
  [6046] = 5359,
  [6047] = 4386,
  [6048] = 4291,
  [6049] = 4509,
  [6050] = 5695,
  [6051] = 4249,
  [6052] = 4493,
  [6053] = 4729,
  [6054] = 4730,
  [6055] = 4759,
  [6056] = 4294,
  [6057] = 5359,
  [6058] = 4353,
  [6059] = 4368,
  [6060] = 4268,
  [6061] = 4465,
  [6062] = 6062,
  [6063] = 5361,
  [6064] = 4245,
  [6065] = 4295,
  [6066] = 4355,
  [6067] = 4379,
  [6068] = 4367,
  [6069] = 4387,
  [6070] = 4967,
  [6071] = 4509,
  [6072] = 4387,
  [6073] = 4368,
  [6074] = 4369,
  [6075] = 4245,
  [6076] = 4355,
  [6077] = 4291,
  [6078] = 4372,
  [6079] = 4179,
  [6080] = 4277,
  [6081] = 3852,
  [6082] = 4478,
  [6083] = 4291,
  [6084] = 4294,
  [6085] = 4295,
  [6086] = 4759,
  [6087] = 4427,
  [6088] = 4290,
  [6089] = 5359,
  [6090] = 4279,
  [6091] = 3852,
  [6092] = 4179,
  [6093] = 5361,
  [6094] = 3850,
  [6095] = 4294,
  [6096] = 4267,
  [6097] = 4291,
  [6098] = 4249,
  [6099] = 4294,
  [6100] = 4387,
  [6101] = 4267,
  [6102] = 4493,
  [6103] = 4295,
  [6104] = 4759,
  [6105] = 5361,
  [6106] = 5332,
  [6107] = 4353,
  [6108] = 4967,
  [6109] = 4386,
  [6110] = 4367,
  [6111] = 4465,
  [6112] = 4268,
  [6113] = 4295,
  [6114] = 4381,
  [6115] = 4854,
  [6116] = 4179,
  [6117] = 3852,
  [6118] = 4355,
  [6119] = 3850,
  [6120] = 4179,
  [6121] = 4509,
  [6122] = 4268,
  [6123] = 4368,
  [6124] = 4369,
  [6125] = 5696,
  [6126] = 4387,
  [6127] = 4372,
  [6128] = 4759,
  [6129] = 5803,
  [6130] = 4277,
  [6131] = 6131,
  [6132] = 4826,
  [6133] = 4759,
  [6134] = 4353,
  [6135] = 4294,
  [6136] = 3850,
  [6137] = 4381,
  [6138] = 4445,
  [6139] = 6139,
  [6140] = 4353,
  [6141] = 3852,
  [6142] = 4367,
  [6143] = 4401,
  [6144] = 4381,
  [6145] = 4355,
  [6146] = 3850,
  [6147] = 4386,
  [6148] = 4447,
  [6149] = 4367,
  [6150] = 3852,
  [6151] = 4368,
  [6152] = 4245,
  [6153] = 4369,
  [6154] = 5332,
  [6155] = 4447,
  [6156] = 4355,
  [6157] = 4427,
  [6158] = 4249,
  [6159] = 4381,
  [6160] = 4368,
  [6161] = 4447,
  [6162] = 4179,
  [6163] = 5693,
  [6164] = 4895,
  [6165] = 4290,
  [6166] = 4478,
  [6167] = 4291,
  [6168] = 4464,
  [6169] = 4448,
  [6170] = 4249,
  [6171] = 5134,
  [6172] = 4367,
  [6173] = 4493,
  [6174] = 5118,
  [6175] = 4895,
  [6176] = 5414,
  [6177] = 4387,
  [6178] = 4368,
  [6179] = 3850,
  [6180] = 4465,
  [6181] = 4372,
  [6182] = 4379,
  [6183] = 4445,
  [6184] = 4369,
  [6185] = 4427,
  [6186] = 4759,
  [6187] = 4401,
  [6188] = 5465,
  [6189] = 6189,
  [6190] = 4759,
  [6191] = 4372,
  [6192] = 5677,
  [6193] = 4277,
  [6194] = 4277,
  [6195] = 4268,
  [6196] = 5679,
  [6197] = 4279,
  [6198] = 4179,
  [6199] = 3852,
  [6200] = 5684,
  [6201] = 5685,
  [6202] = 5686,
  [6203] = 5276,
  [6204] = 4401,
  [6205] = 5134,
  [6206] = 4279,
  [6207] = 4264,
  [6208] = 5690,
  [6209] = 5691,
  [6210] = 3850,
  [6211] = 4353,
  [6212] = 5692,
  [6213] = 5693,
  [6214] = 4245,
  [6215] = 5805,
  [6216] = 3850,
  [6217] = 4249,
  [6218] = 5695,
  [6219] = 5696,
  [6220] = 5134,
  [6221] = 4729,
  [6222] = 4729,
  [6223] = 4379,
  [6224] = 5697,
  [6225] = 5803,
  [6226] = 5698,
  [6227] = 4895,
  [6228] = 4730,
  [6229] = 4268,
  [6230] = 3850,
  [6231] = 4290,
  [6232] = 4478,
  [6233] = 3852,
  [6234] = 4387,
  [6235] = 4759,
  [6236] = 5966,
  [6237] = 5967,
  [6238] = 5134,
  [6239] = 3850,
  [6240] = 3852,
  [6241] = 5248,
  [6242] = 5249,
  [6243] = 6243,
  [6244] = 4268,
  [6245] = 5134,
  [6246] = 4854,
  [6247] = 5805,
  [6248] = 4380,
  [6249] = 4267,
  [6250] = 4291,
  [6251] = 4759,
  [6252] = 3850,
  [6253] = 5970,
  [6254] = 4826,
  [6255] = 4291,
  [6256] = 4380,
  [6257] = 3852,
  [6258] = 4294,
  [6259] = 4730,
  [6260] = 4632,
  [6261] = 4245,
  [6262] = 4295,
  [6263] = 4826,
  [6264] = 5241,
  [6265] = 4637,
  [6266] = 4294,
  [6267] = 4353,
  [6268] = 3850,
  [6269] = 4381,
  [6270] = 4295,
  [6271] = 4264,
  [6272] = 4355,
  [6273] = 5244,
  [6274] = 4387,
  [6275] = 4295,
  [6276] = 4368,
  [6277] = 4179,
  [6278] = 5352,
  [6279] = 4478,
  [6280] = 4249,
  [6281] = 3850,
  [6282] = 5352,
  [6283] = 4073,
  [6284] = 4826,
  [6285] = 4369,
  [6286] = 4464,
  [6287] = 5806,
  [6288] = 4353,
  [6289] = 4637,
  [6290] = 3852,
  [6291] = 4464,
  [6292] = 5687,
  [6293] = 5354,
  [6294] = 4380,
  [6295] = 4279,
  [6296] = 4632,
  [6297] = 4372,
  [6298] = 4277,
  [6299] = 4448,
  [6300] = 6300,
  [6301] = 4073,
  [6302] = 4245,
  [6303] = 4179,
  [6304] = 5356,
  [6305] = 5241,
  [6306] = 5359,
  [6307] = 4729,
  [6308] = 4179,
  [6309] = 4255,
  [6310] = 5361,
  [6311] = 4730,
  [6312] = 4268,
  [6313] = 3852,
  [6314] = 4291,
  [6315] = 4355,
  [6316] = 4267,
  [6317] = 4465,
  [6318] = 5244,
  [6319] = 4493,
  [6320] = 4427,
  [6321] = 3850,
  [6322] = 5729,
  [6323] = 5730,
  [6324] = 4632,
  [6325] = 4290,
  [6326] = 4478,
  [6327] = 4826,
  [6328] = 4264,
  [6329] = 5734,
  [6330] = 5736,
  [6331] = 5737,
  [6332] = 4386,
  [6333] = 4290,
  [6334] = 4381,
  [6335] = 4245,
  [6336] = 4401,
  [6337] = 4268,
  [6338] = 4759,
  [6339] = 4478,
  [6340] = 4464,
  [6341] = 4355,
  [6342] = 4464,
  [6343] = 4294,
  [6344] = 4291,
  [6345] = 4465,
  [6346] = 5118,
  [6347] = 4294,
  [6348] = 4427,
  [6349] = 4478,
  [6350] = 4295,
  [6351] = 3852,
  [6352] = 5806,
  [6353] = 4826,
  [6354] = 4372,
  [6355] = 5248,
  [6356] = 5249,
  [6357] = 4264,
  [6358] = 6358,
  [6359] = 4295,
  [6360] = 4465,
  [6361] = 4637,
  [6362] = 4427,
  [6363] = 4493,
  [6364] = 4465,
  [6365] = 4245,
  [6366] = 4368,
  [6367] = 4895,
  [6368] = 3850,
  [6369] = 4379,
  [6370] = 4380,
  [6371] = 3850,
  [6372] = 4353,
  [6373] = 4179,
  [6374] = 5746,
  [6375] = 4465,
  [6376] = 4493,
  [6377] = 4464,
  [6378] = 3852,
  [6379] = 4826,
  [6380] = 4427,
  [6381] = 4368,
  [6382] = 4267,
  [6383] = 3852,
  [6384] = 4279,
  [6385] = 5966,
  [6386] = 4291,
  [6387] = 4401,
  [6388] = 5134,
  [6389] = 4179,
  [6390] = 4381,
  [6391] = 5967,
  [6392] = 4355,
  [6393] = 3850,
  [6394] = 4369,
  [6395] = 4369,
  [6396] = 4367,
  [6397] = 4245,
  [6398] = 4291,
  [6399] = 4368,
  [6400] = 4249,
  [6401] = 4386,
  [6402] = 4369,
  [6403] = 4854,
  [6404] = 4372,
  [6405] = 4387,
  [6406] = 4291,
  [6407] = 4277,
  [6408] = 4379,
  [6409] = 4249,
  [6410] = 4895,
  [6411] = 4759,
  [6412] = 4294,
  [6413] = 4372,
  [6414] = 4295,
  [6415] = 3852,
  [6416] = 3852,
  [6417] = 4632,
  [6418] = 4464,
  [6419] = 5970,
  [6420] = 4294,
  [6421] = 5741,
  [6422] = 5241,
  [6423] = 4268,
  [6424] = 4465,
  [6425] = 4264,
  [6426] = 4729,
  [6427] = 4291,
  [6428] = 4277,
  [6429] = 4379,
  [6430] = 5746,
  [6431] = 4268,
  [6432] = 5893,
  [6433] = 5244,
  [6434] = 6434,
  [6435] = 4295,
  [6436] = 4386,
  [6437] = 4294,
  [6438] = 4245,
  [6439] = 4249,
  [6440] = 4386,
  [6441] = 4427,
  [6442] = 4447,
  [6443] = 4179,
  [6444] = 4294,
  [6445] = 4730,
  [6446] = 4369,
  [6447] = 4387,
  [6448] = 4387,
  [6449] = 4295,
  [6450] = 5352,
  [6451] = 3850,
  [6452] = 4264,
  [6453] = 4267,
  [6454] = 5332,
  [6455] = 4295,
  [6456] = 4445,
  [6457] = 4380,
  [6458] = 5248,
  [6459] = 4367,
  [6460] = 5249,
  [6461] = 4372,
  [6462] = 4386,
  [6463] = 5352,
  [6464] = 5414,
  [6465] = 4826,
  [6466] = 4367,
  [6467] = 4277,
  [6468] = 4367,
  [6469] = 4179,
  [6470] = 3852,
  [6471] = 4895,
  [6472] = 4353,
  [6473] = 5354,
  [6474] = 4268,
  [6475] = 4380,
  [6476] = 4464,
  [6477] = 4353,
  [6478] = 4355,
  [6479] = 4367,
  [6480] = 4245,
  [6481] = 4367,
  [6482] = 4368,
  [6483] = 4387,
  [6484] = 4369,
  [6485] = 4294,
  [6486] = 4730,
  [6487] = 4372,
  [6488] = 4509,
  [6489] = 5893,
  [6490] = 5356,
  [6491] = 4245,
  [6492] = 4465,
  [6493] = 4826,
  [6494] = 4277,
  [6495] = 4381,
  [6496] = 4729,
  [6497] = 4381,
  [6498] = 5354,
  [6499] = 5359,
  [6500] = 4355,
  [6501] = 4381,
  [6502] = 4427,
  [6503] = 4179,
  [6504] = 5729,
  [6505] = 5361,
  [6506] = 4427,
  [6507] = 4277,
  [6508] = 4368,
  [6509] = 4295,
  [6510] = 4380,
  [6511] = 4478,
  [6512] = 4249,
  [6513] = 5414,
  [6514] = 4369,
  [6515] = 4448,
  [6516] = 4179,
  [6517] = 3850,
  [6518] = 4493,
  [6519] = 4401,
  [6520] = 5730,
  [6521] = 4372,
  [6522] = 4277,
  [6523] = 3850,
  [6524] = 4179,
  [6525] = 4257,
  [6526] = 4386,
  [6527] = 5276,
  [6528] = 5276,
  [6529] = 4826,
  [6530] = 4493,
  [6531] = 4073,
  [6532] = 3850,
  [6533] = 5691,
  [6534] = 4464,
  [6535] = 4387,
  [6536] = 4245,
  [6537] = 5893,
  [6538] = 4268,
  [6539] = 5354,
  [6540] = 4379,
  [6541] = 5248,
  [6542] = 4355,
  [6543] = 5241,
  [6544] = 3852,
  [6545] = 4464,
  [6546] = 4353,
  [6547] = 4448,
  [6548] = 3852,
  [6549] = 4464,
  [6550] = 4249,
  [6551] = 4355,
  [6552] = 4493,
  [6553] = 4465,
  [6554] = 4464,
  [6555] = 4368,
  [6556] = 4353,
  [6557] = 4249,
  [6558] = 4369,
  [6559] = 4279,
  [6560] = 4372,
  [6561] = 5249,
  [6562] = 4291,
  [6563] = 4277,
  [6564] = 5244,
  [6565] = 4401,
  [6566] = 4290,
  [6567] = 4465,
  [6568] = 4353,
  [6569] = 4381,
  [6570] = 4380,
  [6571] = 5741,
  [6572] = 4290,
  [6573] = 4294,
  [6574] = 4895,
  [6575] = 5118,
  [6576] = 4268,
  [6577] = 6577,
  [6578] = 4427,
  [6579] = 4179,
  [6580] = 4478,
  [6581] = 4295,
  [6582] = 4369,
  [6583] = 4268,
  [6584] = 4493,
  [6585] = 4353,
  [6586] = 5698,
  [6587] = 4427,
  [6588] = 4478,
  [6589] = 4386,
  [6590] = 4895,
  [6591] = 4290,
  [6592] = 4355,
  [6593] = 4386,
  [6594] = 4478,
  [6595] = 4464,
  [6596] = 4367,
  [6597] = 4369,
  [6598] = 4387,
  [6599] = 4372,
  [6600] = 4381,
  [6601] = 4277,
  [6602] = 5465,
  [6603] = 4291,
  [6604] = 4381,
  [6605] = 4427,
  [6606] = 4290,
  [6607] = 4401,
  [6608] = 4249,
  [6609] = 4387,
  [6610] = 4290,
  [6611] = 4379,
  [6612] = 4386,
  [6613] = 5677,
  [6614] = 4245,
  [6615] = 5118,
  [6616] = 4353,
  [6617] = 5692,
  [6618] = 4372,
  [6619] = 3852,
  [6620] = 4367,
  [6621] = 4895,
  [6622] = 4967,
  [6623] = 3850,
  [6624] = 4249,
  [6625] = 4493,
  [6626] = 4355,
  [6627] = 4264,
  [6628] = 5679,
  [6629] = 4967,
  [6630] = 4279,
  [6631] = 4465,
  [6632] = 4249,
  [6633] = 4401,
  [6634] = 4729,
  [6635] = 5118,
  [6636] = 5118,
  [6637] = 4464,
  [6638] = 4401,
  [6639] = 4264,
  [6640] = 5684,
  [6641] = 5685,
  [6642] = 5690,
  [6643] = 4427,
  [6644] = 5134,
  [6645] = 5118,
  [6646] = 6646,
  [6647] = 5686,
  [6648] = 5734,
  [6649] = 5356,
  [6650] = 5687,
  [6651] = 5276,
  [6652] = 5356,
  [6653] = 4381,
  [6654] = 4245,
  [6655] = 5118,
  [6656] = 4179,
  [6657] = 4379,
  [6658] = 3852,
  [6659] = 4895,
  [6660] = 4368,
  [6661] = 4381,
  [6662] = 4493,
  [6663] = 4401,
  [6664] = 6664,
  [6665] = 6665,
  [6666] = 4464,
  [6667] = 4379,
  [6668] = 4295,
  [6669] = 6669,
  [6670] = 6670,
  [6671] = 6671,
  [6672] = 4465,
  [6673] = 4427,
  [6674] = 6674,
  [6675] = 5465,
  [6676] = 4895,
  [6677] = 4493,
  [6678] = 5677,
  [6679] = 4367,
  [6680] = 4967,
  [6681] = 4353,
  [6682] = 4759,
  [6683] = 3850,
  [6684] = 4386,
  [6685] = 4464,
  [6686] = 4267,
  [6687] = 4759,
  [6688] = 4967,
  [6689] = 4387,
  [6690] = 4465,
  [6691] = 6691,
  [6692] = 5679,
  [6693] = 4967,
  [6694] = 6664,
  [6695] = 6665,
  [6696] = 4427,
  [6697] = 4381,
  [6698] = 4826,
  [6699] = 3852,
  [6700] = 4895,
  [6701] = 5684,
  [6702] = 6670,
  [6703] = 4353,
  [6704] = 5685,
  [6705] = 4073,
  [6706] = 5686,
  [6707] = 4291,
  [6708] = 6674,
  [6709] = 5687,
  [6710] = 5276,
  [6711] = 4380,
  [6712] = 4729,
  [6713] = 4279,
  [6714] = 4290,
  [6715] = 4355,
  [6716] = 6664,
  [6717] = 6665,
  [6718] = 5690,
  [6719] = 6670,
  [6720] = 5691,
  [6721] = 4294,
  [6722] = 6674,
  [6723] = 5692,
  [6724] = 5693,
  [6725] = 3850,
  [6726] = 4249,
  [6727] = 4268,
  [6728] = 4369,
  [6729] = 4478,
  [6730] = 5695,
  [6731] = 5696,
  [6732] = 6670,
  [6733] = 4372,
  [6734] = 4379,
  [6735] = 6674,
  [6736] = 4730,
  [6737] = 5697,
  [6738] = 4369,
  [6739] = 5698,
  [6740] = 4277,
  [6741] = 4464,
  [6742] = 4249,
  [6743] = 4826,
  [6744] = 6001,
  [6745] = 5305,
  [6746] = 4465,
  [6747] = 4854,
  [6748] = 4478,
  [6749] = 4380,
  [6750] = 4279,
  [6751] = 4427,
  [6752] = 4386,
  [6753] = 4295,
  [6754] = 4387,
  [6755] = 4826,
  [6756] = 6669,
  [6757] = 4478,
  [6758] = 5803,
  [6759] = 3852,
  [6760] = 5805,
  [6761] = 5806,
  [6762] = 4381,
  [6763] = 4854,
  [6764] = 4353,
  [6765] = 4381,
  [6766] = 4355,
  [6767] = 3852,
  [6768] = 4386,
  [6769] = 4073,
  [6770] = 4445,
  [6771] = 4464,
  [6772] = 4368,
  [6773] = 4387,
  [6774] = 4369,
  [6775] = 4465,
  [6776] = 4372,
  [6777] = 4427,
  [6778] = 4277,
  [6779] = 6779,
  [6780] = 5134,
  [6781] = 4895,
  [6782] = 5741,
  [6783] = 4493,
  [6784] = 5966,
  [6785] = 4637,
  [6786] = 4367,
  [6787] = 4249,
  [6788] = 5729,
  [6789] = 5730,
  [6790] = 5967,
  [6791] = 5746,
  [6792] = 4367,
  [6793] = 4386,
  [6794] = 4632,
  [6795] = 5734,
  [6796] = 4895,
  [6797] = 5118,
  [6798] = 3850,
  [6799] = 5241,
  [6800] = 4387,
  [6801] = 5736,
  [6802] = 5737,
  [6803] = 5244,
  [6804] = 5803,
  [6805] = 4386,
  [6806] = 5414,
  [6807] = 4967,
  [6808] = 5805,
  [6809] = 5806,
  [6810] = 4447,
  [6811] = 5248,
  [6812] = 5249,
  [6813] = 4445,
  [6814] = 4245,
  [6815] = 4290,
  [6816] = 4448,
  [6817] = 4367,
  [6818] = 4245,
  [6819] = 4353,
  [6820] = 4355,
  [6821] = 4179,
  [6822] = 4493,
  [6823] = 4381,
  [6824] = 4759,
  [6825] = 4355,
  [6826] = 4401,
  [6827] = 4368,
  [6828] = 4493,
  [6829] = 6829,
  [6830] = 4369,
  [6831] = 4245,
  [6832] = 4372,
  [6833] = 4277,
  [6834] = 3852,
  [6835] = 4386,
  [6836] = 4464,
  [6837] = 4387,
  [6838] = 4249,
  [6839] = 4826,
  [6840] = 4387,
  [6841] = 4465,
  [6842] = 4729,
  [6843] = 4427,
  [6844] = 4730,
  [6845] = 4245,
  [6846] = 4478,
  [6847] = 4759,
  [6848] = 4464,
  [6849] = 4290,
  [6850] = 4509,
  [6851] = 4386,
  [6852] = 5970,
  [6853] = 4245,
  [6854] = 4464,
  [6855] = 4387,
  [6856] = 4249,
  [6857] = 4353,
  [6858] = 4368,
  [6859] = 4381,
  [6860] = 4355,
  [6861] = 4465,
  [6862] = 4179,
  [6863] = 4368,
  [6864] = 4369,
  [6865] = 4826,
  [6866] = 5893,
  [6867] = 4372,
  [6868] = 4291,
  [6869] = 4379,
  [6870] = 4294,
  [6871] = 4277,
  [6872] = 4295,
  [6873] = 4249,
  [6874] = 5465,
  [6875] = 4372,
  [6876] = 4427,
  [6877] = 5677,
  [6878] = 5352,
  [6879] = 4478,
  [6880] = 5248,
  [6881] = 5249,
  [6882] = 5679,
  [6883] = 4179,
  [6884] = 5684,
  [6885] = 5685,
  [6886] = 5686,
  [6887] = 5687,
  [6888] = 5276,
  [6889] = 5354,
  [6890] = 4380,
  [6891] = 4367,
  [6892] = 6131,
  [6893] = 5690,
  [6894] = 5691,
  [6895] = 5692,
  [6896] = 5693,
  [6897] = 4268,
  [6898] = 5356,
  [6899] = 4353,
  [6900] = 5241,
  [6901] = 6189,
  [6902] = 5695,
  [6903] = 5696,
  [6904] = 5359,
  [6905] = 5244,
  [6906] = 5697,
  [6907] = 5698,
  [6908] = 5361,
  [6909] = 6243,
  [6910] = 5465,
  [6911] = 5244,
  [6912] = 6912,
  [6913] = 5677,
  [6914] = 4279,
  [6915] = 5679,
  [6916] = 4355,
  [6917] = 5684,
  [6918] = 5685,
  [6919] = 5686,
  [6920] = 5687,
  [6921] = 5276,
  [6922] = 5690,
  [6923] = 4367,
  [6924] = 4368,
  [6925] = 5118,
  [6926] = 5691,
  [6927] = 5692,
  [6928] = 5693,
  [6929] = 4632,
  [6930] = 4369,
  [6931] = 5352,
  [6932] = 5695,
  [6933] = 5696,
  [6934] = 4291,
  [6935] = 5697,
  [6936] = 4294,
  [6937] = 5698,
  [6938] = 4268,
  [6939] = 4295,
  [6940] = 4179,
  [6941] = 6664,
  [6942] = 4478,
  [6943] = 5354,
  [6944] = 4372,
  [6945] = 4637,
  [6946] = 4401,
  [6947] = 4249,
  [6948] = 4367,
  [6949] = 4401,
  [6950] = 4493,
  [6951] = 4464,
  [6952] = 5356,
  [6953] = 4073,
  [6954] = 4277,
  [6955] = 4632,
  [6956] = 4291,
  [6957] = 4465,
  [6958] = 6665,
  [6959] = 4268,
  [6960] = 6670,
  [6961] = 4895,
  [6962] = 5359,
  [6963] = 4294,
  [6964] = 4427,
  [6965] = 5361,
  [6966] = 4637,
  [6967] = 4295,
  [6968] = 5729,
  [6969] = 5730,
  [6970] = 4279,
  [6971] = 5134,
  [6972] = 4290,
  [6973] = 4073,
  [6974] = 4291,
  [6975] = 5134,
  [6976] = 5734,
  [6977] = 4294,
  [6978] = 4380,
  [6979] = 5736,
  [6980] = 5737,
  [6981] = 4295,
  [6982] = 4179,
  [6983] = 4759,
  [6984] = 4381,
  [6985] = 5741,
  [6986] = 4367,
  [6987] = 4249,
  [6988] = 5118,
  [6989] = 5966,
  [6990] = 5967,
  [6991] = 5729,
  [6992] = 5730,
  [6993] = 5746,
  [6994] = 4290,
  [6995] = 4493,
  [6996] = 4401,
  [6997] = 5241,
  [6998] = 4632,
  [6999] = 5734,
  [7000] = 4179,
  [7001] = 5736,
  [7002] = 5737,
  [7003] = 6691,
  [7004] = 4464,
  [7005] = 4179,
  [7006] = 4967,
  [7007] = 4465,
  [7008] = 4427,
  [7009] = 5248,
  [7010] = 5249,
  [7011] = 4637,
  [7012] = 3850,
  [7013] = 4478,
  [7014] = 4353,
  [7015] = 5134,
  [7016] = 4509,
  [7017] = 4381,
  [7018] = 5241,
  [7019] = 4291,
  [7020] = 4355,
  [7021] = 4464,
  [7022] = 5893,
  [7023] = 5244,
  [7024] = 4294,
  [7025] = 5134,
  [7026] = 4295,
  [7027] = 4368,
  [7028] = 5332,
  [7029] = 4369,
  [7030] = 5741,
  [7031] = 4268,
  [7032] = 4372,
  [7033] = 6577,
  [7034] = 4277,
  [7035] = 5966,
  [7036] = 5967,
  [7037] = 5746,
  [7038] = 4401,
  [7039] = 4401,
  [7040] = 4249,
  [7041] = 5970,
  [7042] = 4291,
  [7043] = 4386,
  [7044] = 4294,
  [7045] = 5970,
  [7046] = 4295,
  [7047] = 3852,
  [7048] = 4367,
  [7049] = 5893,
  [7050] = 4967,
  [7051] = 4179,
  [7052] = 5118,
  [7053] = 4291,
  [7054] = 4465,
  [7055] = 4387,
  [7056] = 4478,
  [7057] = 3850,
  [7058] = 6001,
  [7059] = 4464,
  [7060] = 4367,
  [7061] = 4249,
  [7062] = 4367,
  [7063] = 5134,
  [7064] = 4294,
  [7065] = 4465,
  [7066] = 4427,
  [7067] = 4427,
  [7068] = 4268,
  [7069] = 4268,
  [7070] = 4465,
  [7071] = 4290,
  [7072] = 4295,
  [7073] = 4386,
  [7074] = 4967,
  [7075] = 4729,
  [7076] = 5414,
  [7077] = 4245,
  [7078] = 4387,
  [7079] = 4353,
  [7080] = 4367,
  [7081] = 4353,
  [7082] = 4249,
  [7083] = 5118,
  [7084] = 4493,
  [7085] = 3852,
  [7086] = 4493,
  [7087] = 4290,
  [7088] = 4355,
  [7089] = 4355,
  [7090] = 4367,
  [7091] = 4368,
  [7092] = 5118,
  [7093] = 3850,
  [7094] = 4369,
  [7095] = 4368,
  [7096] = 4249,
  [7097] = 4729,
  [7098] = 4372,
  [7099] = 4369,
  [7100] = 4291,
  [7101] = 4730,
  [7102] = 4277,
  [7103] = 5803,
  [7104] = 6671,
  [7105] = 5805,
  [7106] = 5806,
  [7107] = 5248,
  [7108] = 4493,
  [7109] = 4729,
  [7110] = 4372,
  [7111] = 4854,
  [7112] = 4294,
  [7113] = 4730,
  [7114] = 4277,
  [7115] = 4295,
  [7116] = 4179,
  [7117] = 4264,
  [7118] = 5134,
  [7119] = 4353,
  [7120] = 5249,
  [7121] = 4381,
  [7122] = 3852,
  [7123] = 3850,
  [7124] = 4401,
  [7125] = 4355,
  [7126] = 4353,
  [7127] = 5134,
  [7128] = 4381,
  [7129] = 4381,
  [7130] = 4368,
  [7131] = 5118,
  [7132] = 5118,
  [7133] = 4369,
  [7134] = 4386,
  [7135] = 4464,
  [7136] = 4249,
  [7137] = 4387,
  [7138] = 4372,
  [7139] = 4465,
  [7140] = 4427,
  [7141] = 4967,
  [7142] = 4464,
  [7143] = 4277,
  [7144] = 4291,
  [7145] = 4465,
  [7146] = 5332,
  [7147] = 4353,
  [7148] = 4294,
  [7149] = 4427,
  [7150] = 4295,
  [7151] = 4290,
  [7152] = 4355,
  [7153] = 4367,
  [7154] = 4368,
  [7155] = 4369,
  [7156] = 4179,
  [7157] = 4372,
  [7158] = 4277,
  [7159] = 3850,
  [7160] = 4355,
  [7161] = 4179,
  [7162] = 4493,
  [7163] = 4464,
  [7164] = 4464,
  [7165] = 4291,
  [7166] = 4465,
  [7167] = 4729,
  [7168] = 4465,
  [7169] = 4294,
  [7170] = 4427,
  [7171] = 4427,
  [7172] = 4730,
  [7173] = 4295,
  [7174] = 3852,
  [7175] = 4179,
  [7176] = 4381,
  [7177] = 7177,
  [7178] = 4368,
  [7179] = 4493,
  [7180] = 4854,
  [7181] = 4291,
  [7182] = 4294,
  [7183] = 4295,
  [7184] = 4826,
  [7185] = 4729,
  [7186] = 4730,
  [7187] = 4179,
  [7188] = 4369,
  [7189] = 4291,
  [7190] = 4294,
  [7191] = 4295,
  [7192] = 5276,
  [7193] = 4372,
  [7194] = 4245,
  [7195] = 4249,
  [7196] = 4826,
  [7197] = 4427,
  [7198] = 4478,
  [7199] = 4277,
  [7200] = 4291,
  [7201] = 4294,
  [7202] = 4295,
  [7203] = 3850,
  [7204] = 4179,
  [7205] = 3852,
  [7206] = 4401,
  [7207] = 4478,
  [7208] = 4179,
  [7209] = 4464,
  [7210] = 4249,
  [7211] = 4465,
  [7212] = 4427,
  [7213] = 4179,
  [7214] = 4826,
  [7215] = 4730,
  [7216] = 4379,
  [7217] = 4381,
  [7218] = 4353,
  [7219] = 4493,
  [7220] = 5803,
  [7221] = 4179,
  [7222] = 4401,
  [7223] = 5805,
  [7224] = 5806,
  [7225] = 5352,
  [7226] = 5332,
  [7227] = 4353,
  [7228] = 4245,
  [7229] = 5354,
  [7230] = 4355,
  [7231] = 5356,
  [7232] = 4368,
  [7233] = 4277,
  [7234] = 4369,
  [7235] = 3850,
  [7236] = 5359,
  [7237] = 4372,
  [7238] = 3852,
  [7239] = 7239,
  [7240] = 5361,
  [7241] = 4277,
  [7242] = 4367,
  [7243] = 4381,
  [7244] = 4380,
  [7245] = 4279,
  [7246] = 4380,
  [7247] = 4353,
  [7248] = 6674,
  [7249] = 4386,
  [7250] = 4381,
  [7251] = 4478,
  [7252] = 4245,
  [7253] = 4387,
  [7254] = 4355,
  [7255] = 4368,
  [7256] = 4895,
  [7257] = 4369,
  [7258] = 4268,
  [7259] = 4291,
  [7260] = 4372,
  [7261] = 4294,
  [7262] = 4277,
  [7263] = 7263,
  [7264] = 4295,
  [7265] = 4493,
  [7266] = 4355,
  [7267] = 3852,
  [7268] = 4379,
  [7269] = 5893,
  [7270] = 4509,
  [7271] = 4291,
  [7272] = 3850,
  [7273] = 4179,
  [7274] = 3852,
  [7275] = 4967,
  [7276] = 4895,
  [7277] = 4294,
  [7278] = 4386,
  [7279] = 4295,
  [7280] = 4179,
  [7281] = 5134,
  [7282] = 4759,
  [7283] = 4464,
  [7284] = 4367,
  [7285] = 4368,
  [7286] = 4478,
  [7287] = 4465,
  [7288] = 4895,
  [7289] = 5893,
  [7290] = 4826,
  [7291] = 4427,
  [7292] = 6664,
  [7293] = 6665,
  [7294] = 4895,
  [7295] = 4447,
  [7296] = 4268,
  [7297] = 4380,
  [7298] = 7177,
  [7299] = 4401,
  [7300] = 4445,
  [7301] = 6669,
  [7302] = 4729,
  [7303] = 5118,
  [7304] = 5118,
  [7305] = 4379,
  [7306] = 4730,
  [7307] = 4369,
  [7308] = 6670,
  [7309] = 6671,
  [7310] = 4478,
  [7311] = 4387,
  [7312] = 4478,
  [7313] = 4291,
  [7314] = 4386,
  [7315] = 4179,
  [7316] = 4249,
  [7317] = 6674,
  [7318] = 4387,
  [7319] = 4291,
  [7320] = 4729,
  [7321] = 4294,
  [7322] = 4730,
  [7323] = 5134,
  [7324] = 4291,
  [7325] = 4295,
  [7326] = 5352,
  [7327] = 4372,
  [7328] = 5354,
  [7329] = 4895,
  [7330] = 5356,
  [7331] = 4759,
  [7332] = 4249,
  [7333] = 4294,
  [7334] = 4445,
  [7335] = 5414,
  [7336] = 5359,
  [7337] = 4729,
  [7338] = 4826,
  [7339] = 5361,
  [7340] = 4730,
  [7341] = 4353,
  [7342] = 4264,
  [7343] = 4448,
  [7344] = 4509,
  [7345] = 4355,
  [7346] = 4401,
  [7347] = 4367,
  [7348] = 4368,
  [7349] = 4967,
  [7350] = 4277,
  [7351] = 4369,
  [7352] = 4729,
  [7353] = 4372,
  [7354] = 4730,
  [7355] = 4277,
  [7356] = 4759,
  [7357] = 4179,
  [7358] = 4445,
  [7359] = 4295,
  [7360] = 4353,
  [7361] = 4381,
  [7362] = 4355,
  [7363] = 7363,
  [7364] = 4895,
  [7365] = 4368,
  [7366] = 4379,
  [7367] = 4369,
  [7368] = 4291,
  [7369] = 4372,
  [7370] = 4294,
  [7371] = 6577,
  [7372] = 4294,
  [7373] = 4277,
  [7374] = 4295,
  [7375] = 4826,
  [7376] = 4381,
  [7377] = 4267,
  [7378] = 4279,
  [7379] = 5966,
  [7380] = 5967,
  [7381] = 4759,
  [7382] = 4967,
  [7383] = 4401,
  [7384] = 5970,
  [7385] = 4967,
  [7386] = 3850,
  [7387] = 4380,
  [7388] = 4355,
  [7389] = 4729,
  [7390] = 7390,
  [7391] = 4372,
  [7392] = 6001,
  [7393] = 4379,
  [7394] = 4464,
  [7395] = 7390,
  [7396] = 5414,
  [7397] = 5241,
  [7398] = 4249,
  [7399] = 4730,
  [7400] = 4386,
  [7401] = 7390,
  [7402] = 5244,
  [7403] = 4291,
  [7404] = 4465,
  [7405] = 5118,
  [7406] = 4387,
  [7407] = 4369,
  [7408] = 4465,
  [7409] = 7390,
  [7410] = 5737,
  [7411] = 5803,
  [7412] = 4255,
  [7413] = 7390,
  [7414] = 7390,
  [7415] = 5893,
  [7416] = 4427,
  [7417] = 4854,
  [7418] = 7390,
  [7419] = 4729,
  [7420] = 4464,
  [7421] = 4279,
  [7422] = 4249,
  [7423] = 4179,
  [7424] = 7390,
  [7425] = 4967,
  [7426] = 5967,
  [7427] = 5361,
  [7428] = 4369,
  [7429] = 4372,
  [7430] = 4465,
  [7431] = 4387,
  [7432] = 7390,
  [7433] = 4427,
  [7434] = 4179,
  [7435] = 4729,
  [7436] = 7390,
  [7437] = 5118,
  [7438] = 4730,
  [7439] = 5697,
  [7440] = 4179,
  [7441] = 7390,
  [7442] = 4355,
  [7443] = 7390,
  [7444] = 5679,
  [7445] = 7390,
  [7446] = 7363,
  [7447] = 4401,
  [7448] = 4895,
  [7449] = 7390,
  [7450] = 7450,
  [7451] = 4268,
  [7452] = 5805,
  [7453] = 4854,
  [7454] = 4478,
  [7455] = 7390,
  [7456] = 4294,
  [7457] = 4427,
  [7458] = 5698,
  [7459] = 5352,
  [7460] = 4380,
  [7461] = 7390,
  [7462] = 4277,
  [7463] = 4493,
  [7464] = 7390,
  [7465] = 4268,
  [7466] = 5803,
  [7467] = 4895,
  [7468] = 7390,
  [7469] = 4379,
  [7470] = 4730,
  [7471] = 7390,
  [7472] = 7390,
  [7473] = 5806,
  [7474] = 7363,
  [7475] = 7390,
  [7476] = 5465,
  [7477] = 4295,
  [7478] = 5677,
  [7479] = 5354,
  [7480] = 4386,
  [7481] = 6577,
  [7482] = 7390,
  [7483] = 7239,
  [7484] = 4464,
  [7485] = 5679,
  [7486] = 4245,
  [7487] = 7390,
  [7488] = 5684,
  [7489] = 4493,
  [7490] = 5685,
  [7491] = 5686,
  [7492] = 7263,
  [7493] = 5276,
  [7494] = 4465,
  [7495] = 7390,
  [7496] = 4387,
  [7497] = 5684,
  [7498] = 4447,
  [7499] = 7390,
  [7500] = 5690,
  [7501] = 4826,
  [7502] = 5691,
  [7503] = 4427,
  [7504] = 5692,
  [7505] = 5693,
  [7506] = 7390,
  [7507] = 5241,
  [7508] = 5803,
  [7509] = 5805,
  [7510] = 7390,
  [7511] = 5806,
  [7512] = 5695,
  [7513] = 5696,
  [7514] = 7390,
  [7515] = 7390,
  [7516] = 7390,
  [7517] = 4264,
  [7518] = 4464,
  [7519] = 5697,
  [7520] = 5698,
  [7521] = 7239,
  [7522] = 7390,
  [7523] = 5729,
  [7524] = 7390,
  [7525] = 5970,
  [7526] = 3850,
  [7527] = 4268,
  [7528] = 7390,
  [7529] = 7529,
  [7530] = 4854,
  [7531] = 7390,
  [7532] = 7390,
  [7533] = 7390,
  [7534] = 4380,
  [7535] = 4826,
  [7536] = 7390,
  [7537] = 4290,
  [7538] = 4759,
  [7539] = 7390,
  [7540] = 7390,
  [7541] = 7390,
  [7542] = 4632,
  [7543] = 7390,
  [7544] = 4245,
  [7545] = 4249,
  [7546] = 7390,
  [7547] = 5685,
  [7548] = 7390,
  [7549] = 4355,
  [7550] = 7390,
  [7551] = 5356,
  [7552] = 7390,
  [7553] = 5352,
  [7554] = 4464,
  [7555] = 7390,
  [7556] = 4465,
  [7557] = 4401,
  [7558] = 7390,
  [7559] = 4372,
  [7560] = 4367,
  [7561] = 7390,
  [7562] = 4729,
  [7563] = 5741,
  [7564] = 4249,
  [7565] = 7390,
  [7566] = 3850,
  [7567] = 4291,
  [7568] = 7390,
  [7569] = 5686,
  [7570] = 4353,
  [7571] = 4465,
  [7572] = 5248,
  [7573] = 5249,
  [7574] = 7390,
  [7575] = 4427,
  [7576] = 4637,
  [7577] = 4294,
  [7578] = 4427,
  [7579] = 7390,
  [7580] = 6829,
  [7581] = 5352,
  [7582] = 7390,
  [7583] = 4478,
  [7584] = 7390,
  [7585] = 4478,
  [7586] = 5687,
  [7587] = 4295,
  [7588] = 7390,
  [7589] = 4730,
  [7590] = 4854,
  [7591] = 5966,
  [7592] = 7390,
  [7593] = 4355,
  [7594] = 7390,
  [7595] = 5967,
  [7596] = 4637,
  [7597] = 4073,
  [7598] = 5730,
  [7599] = 4368,
  [7600] = 4245,
  [7601] = 4464,
  [7602] = 4369,
  [7603] = 5241,
  [7604] = 4179,
  [7605] = 4353,
  [7606] = 7263,
  [7607] = 4372,
  [7608] = 4381,
  [7609] = 5244,
  [7610] = 4355,
  [7611] = 4368,
  [7612] = 3852,
  [7613] = 4369,
  [7614] = 4277,
  [7615] = 4372,
  [7616] = 3852,
  [7617] = 4277,
  [7618] = 5970,
  [7619] = 4445,
  [7620] = 7390,
  [7621] = 5687,
  [7622] = 4465,
  [7623] = 5359,
  [7624] = 4427,
  [7625] = 5729,
  [7626] = 5730,
  [7627] = 3850,
  [7628] = 5966,
  [7629] = 5967,
  [7630] = 4493,
  [7631] = 5134,
  [7632] = 5276,
  [7633] = 4401,
  [7634] = 4401,
  [7635] = 5734,
  [7636] = 4381,
  [7637] = 5970,
  [7638] = 5352,
  [7639] = 5414,
  [7640] = 5736,
  [7641] = 5737,
  [7642] = 4826,
  [7643] = 5354,
  [7644] = 5361,
  [7645] = 5354,
  [7646] = 7390,
  [7647] = 4367,
  [7648] = 5465,
  [7649] = 4268,
  [7650] = 3850,
  [7651] = 5677,
  [7652] = 4353,
  [7653] = 4478,
  [7654] = 5356,
  [7655] = 5893,
  [7656] = 5248,
  [7657] = 4277,
  [7658] = 5679,
  [7659] = 4381,
  [7660] = 4267,
  [7661] = 5684,
  [7662] = 5966,
  [7663] = 5685,
  [7664] = 5967,
  [7665] = 5746,
  [7666] = 5686,
  [7667] = 5276,
  [7668] = 4478,
  [7669] = 4372,
  [7670] = 5332,
  [7671] = 7450,
  [7672] = 5359,
  [7673] = 4464,
  [7674] = 7674,
  [7675] = 4464,
  [7676] = 5361,
  [7677] = 5690,
  [7678] = 5691,
  [7679] = 4465,
  [7680] = 3852,
  [7681] = 5692,
  [7682] = 5693,
  [7683] = 7683,
  [7684] = 4427,
  [7685] = 5249,
  [7686] = 7390,
  [7687] = 7390,
  [7688] = 4464,
  [7689] = 5695,
  [7690] = 5696,
  [7691] = 4895,
  [7692] = 5332,
  [7693] = 7363,
  [7694] = 4826,
  [7695] = 4368,
  [7696] = 5697,
  [7697] = 7450,
  [7698] = 5698,
  [7699] = 4245,
  [7700] = 5354,
  [7701] = 7674,
  [7702] = 5966,
  [7703] = 4401,
  [7704] = 5967,
  [7705] = 4268,
  [7706] = 7683,
  [7707] = 4465,
  [7708] = 6912,
  [7709] = 7390,
  [7710] = 7390,
  [7711] = 4464,
  [7712] = 5803,
  [7713] = 7450,
  [7714] = 5805,
  [7715] = 5806,
  [7716] = 4465,
  [7717] = 4427,
  [7718] = 5970,
  [7719] = 6001,
  [7720] = 4465,
  [7721] = 7450,
  [7722] = 4427,
  [7723] = 5803,
  [7724] = 4464,
  [7725] = 4895,
  [7726] = 4249,
  [7727] = 7450,
  [7728] = 4427,
  [7729] = 5805,
  [7730] = 5806,
  [7731] = 7390,
  [7732] = 4509,
  [7733] = 5356,
  [7734] = 4245,
  [7735] = 5244,
  [7736] = 4353,
  [7737] = 7683,
  [7738] = 4478,
  [7739] = 5687,
  [7740] = 4291,
  [7741] = 4367,
  [7742] = 4355,
  [7743] = 5970,
  [7744] = 4729,
  [7745] = 4291,
  [7746] = 4729,
  [7747] = 4073,
  [7748] = 4729,
  [7749] = 4368,
  [7750] = 4245,
  [7751] = 4895,
  [7752] = 4369,
  [7753] = 5414,
  [7754] = 4759,
  [7755] = 7390,
  [7756] = 5690,
  [7757] = 4294,
  [7758] = 4729,
  [7759] = 4372,
  [7760] = 4294,
  [7761] = 4730,
  [7762] = 4277,
  [7763] = 6131,
  [7764] = 4730,
  [7765] = 6691,
  [7766] = 4295,
  [7767] = 3850,
  [7768] = 5741,
  [7769] = 5134,
  [7770] = 4448,
  [7771] = 5729,
  [7772] = 6189,
  [7773] = 5730,
  [7774] = 4401,
  [7775] = 4295,
  [7776] = 5746,
  [7777] = 7390,
  [7778] = 4493,
  [7779] = 6243,
  [7780] = 4372,
  [7781] = 5118,
  [7782] = 4245,
  [7783] = 5736,
  [7784] = 5737,
  [7785] = 4729,
  [7786] = 5332,
  [7787] = 4730,
  [7788] = 3852,
  [7789] = 4967,
  [7790] = 4465,
  [7791] = 4381,
  [7792] = 4179,
  [7793] = 4073,
  [7794] = 4386,
  [7795] = 5359,
  [7796] = 4967,
  [7797] = 4729,
  [7798] = 4387,
  [7799] = 5803,
  [7800] = 7390,
  [7801] = 5691,
  [7802] = 5805,
  [7803] = 4291,
  [7804] = 4268,
  [7805] = 4294,
  [7806] = 5806,
  [7807] = 4295,
  [7808] = 4464,
  [7809] = 4367,
  [7810] = 7390,
  [7811] = 4464,
  [7812] = 4245,
  [7813] = 5118,
  [7814] = 4759,
  [7815] = 5361,
  [7816] = 4427,
  [7817] = 4464,
  [7818] = 4730,
  [7819] = 4826,
  [7820] = 4249,
  [7821] = 4179,
  [7822] = 4179,
  [7823] = 4465,
  [7824] = 4291,
  [7825] = 4268,
  [7826] = 4427,
  [7827] = 4465,
  [7828] = 4478,
  [7829] = 5805,
  [7830] = 4401,
  [7831] = 7390,
  [7832] = 7390,
  [7833] = 5118,
  [7834] = 4826,
  [7835] = 4294,
  [7836] = 4427,
  [7837] = 4367,
  [7838] = 3850,
  [7839] = 4895,
  [7840] = 4295,
  [7841] = 5692,
  [7842] = 5806,
  [7843] = 3852,
  [7844] = 4493,
  [7845] = 3850,
  [7846] = 5134,
  [7847] = 4291,
  [7848] = 4294,
  [7849] = 4295,
  [7850] = 4179,
  [7851] = 5134,
  [7852] = 4729,
  [7853] = 7390,
  [7854] = 5693,
  [7855] = 4367,
  [7856] = 3852,
  [7857] = 4290,
  [7858] = 4826,
  [7859] = 4386,
  [7860] = 5734,
  [7861] = 5118,
  [7862] = 4895,
  [7863] = 4353,
  [7864] = 4387,
  [7865] = 4381,
  [7866] = 4179,
  [7867] = 4967,
  [7868] = 4355,
  [7869] = 7390,
  [7870] = 4637,
  [7871] = 4369,
  [7872] = 3852,
  [7873] = 5465,
  [7874] = 4277,
  [7875] = 4381,
  [7876] = 4368,
  [7877] = 5134,
  [7878] = 4493,
  [7879] = 5741,
  [7880] = 5356,
  [7881] = 4369,
  [7882] = 4268,
  [7883] = 3850,
  [7884] = 5746,
  [7885] = 7390,
  [7886] = 4730,
  [7887] = 4386,
  [7888] = 3852,
  [7889] = 4372,
  [7890] = 4967,
  [7891] = 4826,
  [7892] = 4387,
  [7893] = 4464,
  [7894] = 4759,
  [7895] = 6577,
  [7896] = 4895,
  [7897] = 4179,
  [7898] = 4730,
  [7899] = 4277,
  [7900] = 4401,
  [7901] = 4730,
  [7902] = 4967,
  [7903] = 4179,
  [7904] = 3850,
  [7905] = 5352,
  [7906] = 5134,
  [7907] = 3852,
  [7908] = 4401,
  [7909] = 5414,
  [7910] = 4632,
  [7911] = 5354,
  [7912] = 3850,
  [7913] = 3852,
  [7914] = 7390,
  [7915] = 5356,
  [7916] = 5893,
  [7917] = 4826,
  [7918] = 7390,
  [7919] = 4291,
  [7920] = 4386,
  [7921] = 5359,
  [7922] = 4826,
  [7923] = 5893,
  [7924] = 3850,
  [7925] = 3852,
  [7926] = 4294,
  [7927] = 7239,
  [7928] = 5361,
  [7929] = 4401,
  [7930] = 7263,
  [7931] = 4295,
  [7932] = 4967,
  [7933] = 4353,
  [7934] = 5332,
  [7935] = 7390,
  [7936] = 4381,
  [7937] = 5118,
  [7938] = 4895,
  [7939] = 4493,
  [7940] = 4179,
  [7941] = 4387,
  [7942] = 7674,
  [7943] = 7390,
  [7944] = 4632,
  [7945] = 5118,
  [7946] = 4179,
  [7947] = 7390,
  [7948] = 4730,
  [7949] = 5118,
  [7950] = 5352,
  [7951] = 4637,
  [7952] = 4291,
  [7953] = 5134,
  [7954] = 4381,
  [7955] = 4179,
  [7956] = 4353,
  [7957] = 7390,
  [7958] = 4895,
  [7959] = 4759,
  [7960] = 5354,
  [7961] = 4294,
  [7962] = 7390,
  [7963] = 4493,
  [7964] = 4367,
  [7965] = 4826,
  [7966] = 4381,
  [7967] = 5134,
  [7968] = 7390,
  [7969] = 4895,
  [7970] = 4245,
  [7971] = 6577,
  [7972] = 5677,
  [7973] = 4179,
  [7974] = 4291,
  [7975] = 4277,
  [7976] = 7390,
  [7977] = 4294,
  [7978] = 4295,
  [7979] = 4493,
  [7980] = 4401,
  [7981] = 5356,
  [7982] = 4826,
  [7983] = 5893,
  [7984] = 6001,
  [7985] = 5134,
  [7986] = 4464,
  [7987] = 7390,
  [7988] = 5966,
  [7989] = 4967,
  [7990] = 4895,
  [7991] = 5967,
  [7992] = 4355,
  [7993] = 4355,
  [7994] = 7994,
  [7995] = 4268,
  [7996] = 4493,
  [7997] = 4367,
  [7998] = 4401,
  [7999] = 5893,
  [8000] = 4493,
  [8001] = 4401,
  [8002] = 4759,
  [8003] = 5966,
  [8004] = 4295,
  [8005] = 4245,
  [8006] = 7390,
  [8007] = 4291,
  [8008] = 4465,
  [8009] = 7390,
  [8010] = 5118,
  [8011] = 5893,
  [8012] = 5970,
  [8013] = 4967,
  [8014] = 5134,
  [8015] = 4294,
  [8016] = 4967,
  [8017] = 4267,
  [8018] = 4295,
  [8019] = 4509,
  [8020] = 6912,
  [8021] = 4478,
  [8022] = 7390,
  [8023] = 4632,
  [8024] = 4368,
  [8025] = 4249,
  [8026] = 3852,
  [8027] = 4967,
  [8028] = 4369,
  [8029] = 4249,
  [8030] = 4291,
  [8031] = 5695,
  [8032] = 4895,
  [8033] = 4759,
  [8034] = 4294,
  [8035] = 7390,
  [8036] = 5359,
  [8037] = 4295,
  [8038] = 3850,
  [8039] = 5134,
  [8040] = 4967,
  [8041] = 3850,
  [8042] = 7390,
  [8043] = 4367,
  [8044] = 4759,
  [8045] = 4268,
  [8046] = 4729,
  [8047] = 4478,
  [8048] = 4967,
  [8049] = 5248,
  [8050] = 4826,
  [8051] = 5249,
  [8052] = 4464,
  [8053] = 5696,
  [8054] = 4478,
  [8055] = 4368,
  [8056] = 6829,
  [8057] = 4257,
  [8058] = 4465,
  [8059] = 4729,
  [8060] = 5361,
  [8061] = 4368,
  [8062] = 4967,
  [8063] = 5359,
  [8064] = 4427,
  [8065] = 4730,
  [8066] = 5736,
  [8067] = 7390,
  [8068] = 3852,
  [8069] = 4967,
  [8070] = 5118,
  [8071] = 4353,
  [8072] = 4179,
  [8073] = 4465,
  [8074] = 4478,
  [8075] = 4353,
  [8076] = 4277,
  [8077] = 4895,
  [8078] = 4427,
  [8079] = 4401,
  [8080] = 4368,
  [8081] = 4249,
  [8082] = 4427,
  [8083] = 4369,
  [8084] = 7390,
  [8085] = 4386,
  [8086] = 4967,
  [8087] = 5734,
  [8088] = 4967,
  [8089] = 4245,
  [8090] = 4427,
  [8091] = 5134,
  [8092] = 5729,
  [8093] = 5966,
  [8094] = 5966,
  [8095] = 4369,
  [8096] = 5359,
  [8097] = 4967,
  [8098] = 4464,
  [8099] = 4291,
  [8100] = 4465,
  [8101] = 6577,
  [8102] = 5741,
  [8103] = 4294,
  [8104] = 4427,
  [8105] = 4895,
  [8106] = 5356,
  [8107] = 4295,
  [8108] = 5803,
  [8109] = 5805,
  [8110] = 5806,
  [8111] = 5332,
  [8112] = 4291,
  [8113] = 7363,
  [8114] = 4464,
  [8115] = 5361,
  [8116] = 5729,
  [8117] = 5967,
  [8118] = 4465,
  [8119] = 5730,
  [8120] = 4967,
  [8121] = 4427,
  [8122] = 4401,
  [8123] = 4729,
  [8124] = 4967,
  [8125] = 5697,
  [8126] = 4294,
  [8127] = 5805,
  [8128] = 4295,
  [8129] = 5734,
  [8130] = 4367,
  [8131] = 4826,
  [8132] = 5967,
  [8133] = 5414,
  [8134] = 5803,
  [8135] = 7263,
  [8136] = 5736,
  [8137] = 5805,
  [8138] = 5737,
  [8139] = 5352,
  [8140] = 5729,
  [8141] = 8141,
  [8142] = 5730,
  [8143] = 4355,
  [8144] = 3850,
  [8145] = 4179,
  [8146] = 5244,
  [8147] = 4478,
  [8148] = 4294,
  [8149] = 3852,
  [8150] = 4372,
  [8151] = 5746,
  [8152] = 4268,
  [8153] = 5805,
  [8154] = 5697,
  [8155] = 5806,
  [8156] = 4294,
  [8157] = 5691,
  [8158] = 5806,
  [8159] = 5966,
  [8160] = 5967,
  [8161] = 5893,
  [8162] = 5687,
  [8163] = 6001,
  [8164] = 4895,
  [8165] = 4401,
  [8166] = 4073,
  [8167] = 5970,
  [8168] = 4367,
  [8169] = 5118,
  [8170] = 4368,
  [8171] = 4291,
  [8172] = 5805,
  [8173] = 5690,
  [8174] = 4367,
  [8175] = 5698,
  [8176] = 5970,
  [8177] = 4294,
  [8178] = 4730,
  [8179] = 4465,
  [8180] = 4369,
  [8181] = 4295,
  [8182] = 3852,
  [8183] = 4826,
  [8184] = 5736,
  [8185] = 4401,
  [8186] = 4295,
  [8187] = 5241,
  [8188] = 5118,
  [8189] = 5806,
  [8190] = 5352,
  [8191] = 5734,
  [8192] = 4367,
  [8193] = 5359,
  [8194] = 4141,
  [8195] = 4145,
  [8196] = 4162,
  [8197] = 4967,
  [8198] = 4729,
  [8199] = 4290,
  [8200] = 5803,
  [8201] = 3852,
  [8202] = 4381,
  [8203] = 4372,
  [8204] = 5241,
  [8205] = 3852,
  [8206] = 5805,
  [8207] = 5893,
  [8208] = 5118,
  [8209] = 5244,
  [8210] = 4295,
  [8211] = 5806,
  [8212] = 4895,
  [8213] = 4895,
  [8214] = 5134,
  [8215] = 4179,
  [8216] = 5893,
  [8217] = 5354,
  [8218] = 5746,
  [8219] = 4379,
  [8220] = 5352,
  [8221] = 4277,
  [8222] = 5465,
  [8223] = 5736,
  [8224] = 5244,
  [8225] = 4895,
  [8226] = 4401,
  [8227] = 4264,
  [8228] = 5737,
  [8229] = 5805,
  [8230] = 5803,
  [8231] = 4493,
  [8232] = 4826,
  [8233] = 3850,
  [8234] = 4294,
  [8235] = 5737,
  [8236] = 5803,
  [8237] = 4427,
  [8238] = 5352,
  [8239] = 5690,
  [8240] = 4493,
  [8241] = 5361,
  [8242] = 4730,
  [8243] = 5352,
  [8244] = 5966,
  [8245] = 5967,
  [8246] = 7239,
  [8247] = 4179,
  [8248] = 5805,
  [8249] = 5118,
  [8250] = 5893,
  [8251] = 4355,
  [8252] = 5805,
  [8253] = 4464,
  [8254] = 4277,
  [8255] = 4729,
  [8256] = 8256,
  [8257] = 5806,
  [8258] = 5698,
  [8259] = 4295,
  [8260] = 5970,
  [8261] = 5806,
  [8262] = 4386,
  [8263] = 5354,
  [8264] = 5134,
  [8265] = 4509,
  [8266] = 5356,
  [8267] = 4465,
  [8268] = 4401,
  [8269] = 4729,
  [8270] = 5352,
  [8271] = 4967,
  [8272] = 4401,
  [8273] = 5677,
  [8274] = 4427,
  [8275] = 4294,
  [8276] = 4730,
  [8277] = 6829,
  [8278] = 5691,
  [8279] = 5354,
  [8280] = 4427,
  [8281] = 4478,
  [8282] = 4759,
  [8283] = 4478,
  [8284] = 5118,
  [8285] = 4295,
  [8286] = 7363,
  [8287] = 4369,
  [8288] = 4826,
  [8289] = 7263,
  [8290] = 5359,
  [8291] = 5966,
  [8292] = 5332,
  [8293] = 7363,
  [8294] = 4826,
  [8295] = 4854,
  [8296] = 5967,
  [8297] = 5684,
  [8298] = 5966,
  [8299] = 4493,
  [8300] = 5741,
  [8301] = 5967,
  [8302] = 7239,
  [8303] = 3852,
  [8304] = 4369,
  [8305] = 5966,
  [8306] = 4493,
  [8307] = 5118,
  [8308] = 4401,
  [8309] = 5354,
  [8310] = 4826,
  [8311] = 4730,
  [8312] = 5803,
  [8313] = 5730,
  [8314] = 4291,
  [8315] = 5134,
  [8316] = 4464,
  [8317] = 6001,
  [8318] = 6829,
  [8319] = 6912,
  [8320] = 8320,
  [8321] = 5361,
  [8322] = 5356,
  [8323] = 4294,
  [8324] = 4279,
  [8325] = 4267,
  [8326] = 5806,
  [8327] = 4295,
  [8328] = 5134,
  [8329] = 5805,
  [8330] = 4249,
  [8331] = 5806,
  [8332] = 4268,
  [8333] = 5970,
  [8334] = 5806,
  [8335] = 5356,
  [8336] = 4895,
  [8337] = 5134,
  [8338] = 4967,
  [8339] = 5354,
  [8340] = 4826,
  [8341] = 7263,
  [8342] = 4367,
  [8343] = 2348,
  [8344] = 4464,
  [8345] = 5692,
  [8346] = 5352,
  [8347] = 5693,
  [8348] = 4967,
  [8349] = 4401,
  [8350] = 4967,
  [8351] = 5354,
  [8352] = 4179,
  [8353] = 5966,
  [8354] = 5967,
  [8355] = 5352,
  [8356] = 4249,
  [8357] = 5118,
  [8358] = 5741,
  [8359] = 4245,
  [8360] = 4367,
  [8361] = 4465,
  [8362] = 4372,
  [8363] = 4464,
  [8364] = 5118,
  [8365] = 5970,
  [8366] = 4427,
  [8367] = 4387,
  [8368] = 5354,
  [8369] = 4464,
  [8370] = 4277,
  [8371] = 4279,
  [8372] = 5685,
  [8373] = 5697,
  [8374] = 5118,
  [8375] = 5698,
  [8376] = 4637,
  [8377] = 4249,
  [8378] = 5361,
  [8379] = 4291,
  [8380] = 5465,
  [8381] = 4465,
  [8382] = 4380,
  [8383] = 5352,
  [8384] = 5359,
  [8385] = 5741,
  [8386] = 4367,
  [8387] = 5684,
  [8388] = 4277,
  [8389] = 4465,
  [8390] = 4386,
  [8391] = 4895,
  [8392] = 4895,
  [8393] = 5354,
  [8394] = 4427,
  [8395] = 5361,
  [8396] = 7239,
  [8397] = 8397,
  [8398] = 5746,
  [8399] = 5465,
  [8400] = 5970,
  [8401] = 8401,
  [8402] = 6912,
  [8403] = 4294,
  [8404] = 5729,
  [8405] = 5356,
  [8406] = 4427,
  [8407] = 5686,
  [8408] = 3850,
  [8409] = 4295,
  [8410] = 5118,
  [8411] = 3852,
  [8412] = 4464,
  [8413] = 4465,
  [8414] = 5359,
  [8415] = 5134,
  [8416] = 4464,
  [8417] = 7239,
  [8418] = 5677,
  [8419] = 5352,
  [8420] = 8420,
  [8421] = 5361,
  [8422] = 5970,
  [8423] = 5332,
  [8424] = 5692,
  [8425] = 4353,
  [8426] = 5679,
  [8427] = 5677,
  [8428] = 4401,
  [8429] = 5970,
  [8430] = 5134,
  [8431] = 4353,
  [8432] = 4268,
  [8433] = 5803,
  [8434] = 8434,
  [8435] = 5356,
  [8436] = 5359,
  [8437] = 5276,
  [8438] = 5118,
  [8439] = 4895,
  [8440] = 3850,
  [8441] = 4355,
  [8442] = 5730,
  [8443] = 8443,
  [8444] = 4895,
  [8445] = 5805,
  [8446] = 4353,
  [8447] = 5356,
  [8448] = 5806,
  [8449] = 4381,
  [8450] = 4368,
  [8451] = 5679,
  [8452] = 4381,
  [8453] = 4369,
  [8454] = 5414,
  [8455] = 4854,
  [8456] = 5332,
  [8457] = 4291,
  [8458] = 4353,
  [8459] = 5356,
  [8460] = 4372,
  [8461] = 8141,
  [8462] = 7239,
  [8463] = 4368,
  [8464] = 4355,
  [8465] = 4355,
  [8466] = 4294,
  [8467] = 5693,
  [8468] = 4895,
  [8469] = 4277,
  [8470] = 5361,
  [8471] = 4295,
  [8472] = 5465,
  [8473] = 5679,
  [8474] = 4967,
  [8475] = 5893,
  [8476] = 8476,
  [8477] = 5356,
  [8478] = 4368,
  [8479] = 4387,
  [8480] = 5248,
  [8481] = 4381,
  [8482] = 5249,
  [8483] = 4381,
  [8484] = 6912,
  [8485] = 5118,
  [8486] = 5684,
  [8487] = 5359,
  [8488] = 7263,
  [8489] = 4368,
  [8490] = 5685,
  [8491] = 7363,
  [8492] = 4637,
  [8493] = 5686,
  [8494] = 4478,
  [8495] = 6577,
  [8496] = 5276,
  [8497] = 4249,
  [8498] = 4826,
  [8499] = 5414,
  [8500] = 5359,
  [8501] = 4368,
  [8502] = 5803,
  [8503] = 7263,
  [8504] = 6829,
  [8505] = 5687,
  [8506] = 5684,
  [8507] = 5685,
  [8508] = 4464,
  [8509] = 5359,
  [8510] = 4967,
  [8511] = 5686,
  [8512] = 4895,
  [8513] = 4369,
  [8514] = 4355,
  [8515] = 5746,
  [8516] = 5687,
  [8517] = 5354,
  [8518] = 5276,
  [8519] = 5361,
  [8520] = 4372,
  [8521] = 7263,
  [8522] = 5690,
  [8523] = 4179,
  [8524] = 5244,
  [8525] = 4277,
  [8526] = 5691,
  [8527] = 4401,
  [8528] = 5134,
  [8529] = 5354,
  [8530] = 4245,
  [8531] = 4291,
  [8532] = 6001,
  [8533] = 5248,
  [8534] = 4355,
  [8535] = 5692,
  [8536] = 5693,
  [8537] = 5359,
  [8538] = 3850,
  [8539] = 5361,
  [8540] = 4367,
  [8541] = 8541,
  [8542] = 5249,
  [8543] = 4368,
  [8544] = 5690,
  [8545] = 4179,
  [8546] = 4381,
  [8547] = 4465,
  [8548] = 4369,
  [8549] = 5695,
  [8550] = 5696,
  [8551] = 5970,
  [8552] = 4073,
  [8553] = 5803,
  [8554] = 4372,
  [8555] = 5276,
  [8556] = 5685,
  [8557] = 4401,
  [8558] = 5893,
  [8559] = 5697,
  [8560] = 8560,
  [8561] = 4826,
  [8562] = 4179,
  [8563] = 4493,
  [8564] = 5698,
  [8565] = 5695,
  [8566] = 4826,
  [8567] = 4277,
  [8568] = 5691,
  [8569] = 4632,
  [8570] = 4465,
  [8571] = 4465,
  [8572] = 4967,
  [8573] = 5734,
  [8574] = 4291,
  [8575] = 3850,
  [8576] = 5361,
  [8577] = 5696,
  [8578] = 3850,
  [8579] = 4464,
  [8580] = 4294,
  [8581] = 4895,
  [8582] = 4249,
  [8583] = 4073,
  [8584] = 4295,
  [8585] = 5354,
  [8586] = 4464,
  [8587] = 4291,
  [8588] = 5692,
  [8589] = 8589,
  [8590] = 5693,
  [8591] = 4464,
  [8592] = 8592,
  [8593] = 4493,
  [8594] = 4372,
  [8595] = 4632,
  [8596] = 5736,
  [8597] = 4381,
  [8598] = 5361,
  [8599] = 5686,
  [8600] = 5803,
  [8601] = 5679,
  [8602] = 5134,
  [8603] = 4291,
  [8604] = 4401,
  [8605] = 4464,
  [8606] = 4826,
  [8607] = 5737,
  [8608] = 5805,
  [8609] = 5806,
  [8610] = 3852,
  [8611] = 5356,
  [8612] = 5414,
  [8613] = 5241,
  [8614] = 4478,
  [8615] = 4249,
  [8616] = 5803,
  [8617] = 4401,
  [8618] = 4464,
  [8619] = 5359,
  [8620] = 4368,
  [8621] = 5241,
  [8622] = 4372,
  [8623] = 5134,
  [8624] = 4465,
  [8625] = 4465,
  [8626] = 4249,
  [8627] = 5248,
  [8628] = 5893,
  [8629] = 8629,
  [8630] = 4826,
  [8631] = 4826,
  [8632] = 5249,
  [8633] = 4179,
  [8634] = 5356,
  [8635] = 4353,
  [8636] = 4465,
  [8637] = 3850,
  [8638] = 4291,
  [8639] = 5118,
  [8640] = 4729,
  [8641] = 5966,
  [8642] = 5967,
  [8643] = 4369,
  [8644] = 4427,
  [8645] = 7239,
  [8646] = 8256,
  [8647] = 4386,
  [8648] = 4427,
  [8649] = 4427,
  [8650] = 4294,
  [8651] = 5967,
  [8652] = 4249,
  [8653] = 4759,
  [8654] = 5970,
  [8655] = 4465,
  [8656] = 4854,
  [8657] = 5352,
  [8658] = 5966,
  [8659] = 4387,
  [8660] = 4464,
  [8661] = 4295,
  [8662] = 8141,
  [8663] = 5967,
  [8664] = 7363,
  [8665] = 4291,
  [8666] = 5677,
  [8667] = 4427,
  [8668] = 4427,
  [8669] = 8669,
  [8670] = 5734,
  [8671] = 4730,
  [8672] = 4967,
  [8673] = 4179,
  [8674] = 4465,
  [8675] = 4826,
  [8676] = 4427,
  [8677] = 4381,
  [8678] = 5695,
  [8679] = 4967,
  [8680] = 4277,
  [8681] = 7363,
  [8682] = 4895,
  [8683] = 5695,
  [8684] = 5696,
  [8685] = 4478,
  [8686] = 5696,
  [8687] = 4967,
  [8688] = 5687,
  [8689] = 7363,
  [8690] = 4967,
  [8691] = 4290,
  [8692] = 5803,
  [8693] = 4353,
  [8694] = 4464,
  [8695] = 4854,
  [8696] = 5134,
  [8697] = 4427,
  [8698] = 5134,
  [8699] = 4380,
  [8700] = 5332,
  [8701] = 4967,
  [8702] = 4353,
  [8703] = 4353,
  [8704] = 4355,
  [8705] = 4179,
  [8706] = 4073,
  [8707] = 4465,
  [8708] = 5248,
  [8709] = 5249,
  [8710] = 4967,
  [8711] = 4427,
  [8712] = 4729,
  [8713] = 3850,
  [8714] = 3850,
  [8715] = 8715,
  [8716] = 5736,
  [8717] = 5893,
  [8718] = 5737,
  [8719] = 8715,
  [8720] = 4369,
  [8721] = 4967,
  [8722] = 3852,
  [8723] = 4759,
  [8724] = 8715,
  [8725] = 4464,
  [8726] = 8715,
  [8727] = 4826,
  [8728] = 5966,
  [8729] = 5967,
  [8730] = 8715,
  [8731] = 4895,
  [8732] = 5118,
  [8733] = 5970,
  [8734] = 5970,
  [8735] = 8715,
  [8736] = 5803,
  [8737] = 5352,
  [8738] = 4729,
  [8739] = 7239,
  [8740] = 5354,
  [8741] = 8715,
  [8742] = 4730,
  [8743] = 4179,
  [8744] = 5356,
  [8745] = 5966,
  [8746] = 5967,
  [8747] = 8256,
  [8748] = 8715,
  [8749] = 8397,
  [8750] = 4465,
  [8751] = 5359,
  [8752] = 8752,
  [8753] = 5361,
  [8754] = 3852,
  [8755] = 8715,
  [8756] = 5970,
  [8757] = 5359,
  [8758] = 8715,
  [8759] = 5893,
  [8760] = 7239,
  [8761] = 5134,
  [8762] = 5966,
  [8763] = 3850,
  [8764] = 5967,
  [8765] = 7263,
  [8766] = 3852,
  [8767] = 8715,
  [8768] = 5352,
  [8769] = 4826,
  [8770] = 5803,
  [8771] = 8715,
  [8772] = 5805,
  [8773] = 5806,
  [8774] = 4895,
  [8775] = 4379,
  [8776] = 4427,
  [8777] = 5352,
  [8778] = 8715,
  [8779] = 5803,
  [8780] = 4290,
  [8781] = 4967,
  [8782] = 5354,
  [8783] = 4967,
  [8784] = 5805,
  [8785] = 5806,
  [8786] = 5465,
  [8787] = 4401,
  [8788] = 5354,
  [8789] = 5677,
  [8790] = 8715,
  [8791] = 5352,
  [8792] = 5134,
  [8793] = 5248,
  [8794] = 5249,
  [8795] = 5679,
  [8796] = 5134,
  [8797] = 4401,
  [8798] = 8715,
  [8799] = 5684,
  [8800] = 5354,
  [8801] = 5356,
  [8802] = 5685,
  [8803] = 3850,
  [8804] = 5686,
  [8805] = 5687,
  [8806] = 5276,
  [8807] = 5354,
  [8808] = 8715,
  [8809] = 3852,
  [8810] = 5356,
  [8811] = 4372,
  [8812] = 5352,
  [8813] = 5690,
  [8814] = 5118,
  [8815] = 5970,
  [8816] = 5691,
  [8817] = 5692,
  [8818] = 5693,
  [8819] = 8715,
  [8820] = 5359,
  [8821] = 5356,
  [8822] = 5354,
  [8823] = 5118,
  [8824] = 5241,
  [8825] = 5695,
  [8826] = 5696,
  [8827] = 5361,
  [8828] = 8715,
  [8829] = 5359,
  [8830] = 5244,
  [8831] = 5697,
  [8832] = 5698,
  [8833] = 5361,
  [8834] = 5356,
  [8835] = 5359,
  [8836] = 8715,
  [8837] = 8715,
  [8838] = 5465,
  [8839] = 7239,
  [8840] = 3850,
  [8841] = 8256,
  [8842] = 5361,
  [8843] = 8715,
  [8844] = 5677,
  [8845] = 5679,
  [8846] = 5359,
  [8847] = 8715,
  [8848] = 6829,
  [8849] = 5684,
  [8850] = 5685,
  [8851] = 5361,
  [8852] = 5686,
  [8853] = 5687,
  [8854] = 5276,
  [8855] = 8715,
  [8856] = 4380,
  [8857] = 7363,
  [8858] = 5803,
  [8859] = 5690,
  [8860] = 8715,
  [8861] = 5691,
  [8862] = 5805,
  [8863] = 5806,
  [8864] = 6001,
  [8865] = 5692,
  [8866] = 5693,
  [8867] = 4854,
  [8868] = 4268,
  [8869] = 8715,
  [8870] = 5695,
  [8871] = 5696,
  [8872] = 4464,
  [8873] = 8715,
  [8874] = 5697,
  [8875] = 5698,
  [8876] = 4277,
  [8877] = 8715,
  [8878] = 5134,
  [8879] = 8715,
  [8880] = 8715,
  [8881] = 8715,
  [8882] = 8715,
  [8883] = 4073,
  [8884] = 8715,
  [8885] = 5414,
  [8886] = 8715,
  [8887] = 8887,
  [8888] = 7263,
  [8889] = 8715,
  [8890] = 4759,
  [8891] = 5966,
  [8892] = 5967,
  [8893] = 8715,
  [8894] = 5465,
  [8895] = 5361,
  [8896] = 8715,
  [8897] = 4826,
  [8898] = 5677,
  [8899] = 8256,
  [8900] = 8715,
  [8901] = 5970,
  [8902] = 5679,
  [8903] = 4967,
  [8904] = 8715,
  [8905] = 5684,
  [8906] = 5729,
  [8907] = 8715,
  [8908] = 5685,
  [8909] = 5686,
  [8910] = 5730,
  [8911] = 5352,
  [8912] = 8715,
  [8913] = 5276,
  [8914] = 8715,
  [8915] = 8715,
  [8916] = 5118,
  [8917] = 5690,
  [8918] = 4073,
  [8919] = 5691,
  [8920] = 8715,
  [8921] = 5354,
  [8922] = 5692,
  [8923] = 5693,
  [8924] = 8715,
  [8925] = 5734,
  [8926] = 4464,
  [8927] = 8715,
  [8928] = 4826,
  [8929] = 4464,
  [8930] = 8715,
  [8931] = 5695,
  [8932] = 4464,
  [8933] = 5696,
  [8934] = 5736,
  [8935] = 5356,
  [8936] = 8715,
  [8937] = 5737,
  [8938] = 4826,
  [8939] = 8715,
  [8940] = 8256,
  [8941] = 5697,
  [8942] = 8715,
  [8943] = 5134,
  [8944] = 5698,
  [8945] = 4465,
  [8946] = 8256,
  [8947] = 8715,
  [8948] = 5359,
  [8949] = 4427,
  [8950] = 8715,
  [8951] = 5361,
  [8952] = 4465,
  [8953] = 4895,
  [8954] = 8715,
  [8955] = 6912,
  [8956] = 8256,
  [8957] = 4291,
  [8958] = 8715,
  [8959] = 4967,
  [8960] = 8715,
  [8961] = 4427,
  [8962] = 8715,
  [8963] = 8715,
  [8964] = 8715,
  [8965] = 5729,
  [8966] = 8715,
  [8967] = 5730,
  [8968] = 8715,
  [8969] = 4729,
  [8970] = 8715,
  [8971] = 4268,
  [8972] = 8715,
  [8973] = 5118,
  [8974] = 8715,
  [8975] = 8715,
  [8976] = 5734,
  [8977] = 8715,
  [8978] = 4294,
  [8979] = 8715,
  [8980] = 8715,
  [8981] = 5736,
  [8982] = 4730,
  [8983] = 5737,
  [8984] = 8715,
  [8985] = 4295,
  [8986] = 8715,
  [8987] = 8715,
  [8988] = 8715,
  [8989] = 8715,
  [8990] = 3852,
  [8991] = 8715,
  [8992] = 8715,
  [8993] = 5741,
  [8994] = 8715,
  [8995] = 4895,
  [8996] = 8715,
  [8997] = 6829,
  [8998] = 8256,
  [8999] = 4967,
  [9000] = 8715,
  [9001] = 5687,
  [9002] = 8715,
  [9003] = 4895,
  [9004] = 8715,
  [9005] = 4759,
  [9006] = 5746,
  [9007] = 8715,
  [9008] = 4478,
  [9009] = 8715,
  [9010] = 4073,
  [9011] = 5966,
  [9012] = 5967,
  [9013] = 8715,
  [9014] = 8256,
  [9015] = 8715,
  [9016] = 4967,
  [9017] = 8715,
  [9018] = 8420,
  [9019] = 5970,
  [9020] = 8256,
  [9021] = 4401,
  [9022] = 4967,
  [9023] = 8715,
  [9024] = 6577,
  [9025] = 5729,
  [9026] = 5134,
  [9027] = 5730,
  [9028] = 4826,
  [9029] = 5352,
  [9030] = 5354,
  [9031] = 7363,
  [9032] = 5356,
  [9033] = 7239,
  [9034] = 5734,
  [9035] = 4367,
  [9036] = 5359,
  [9037] = 5736,
  [9038] = 5737,
  [9039] = 5118,
  [9040] = 5361,
  [9041] = 5893,
  [9042] = 8715,
  [9043] = 4967,
  [9044] = 4826,
  [9045] = 4464,
  [9046] = 4465,
  [9047] = 5741,
  [9048] = 4379,
  [9049] = 4291,
  [9050] = 8715,
  [9051] = 5746,
  [9052] = 4465,
  [9053] = 5803,
  [9054] = 4465,
  [9055] = 4637,
  [9056] = 4427,
  [9057] = 4826,
  [9058] = 4291,
  [9059] = 4427,
  [9060] = 4294,
  [9061] = 4295,
  [9062] = 8715,
  [9063] = 5803,
  [9064] = 5805,
  [9065] = 5806,
  [9066] = 4895,
  [9067] = 6912,
  [9068] = 5134,
  [9069] = 4245,
  [9070] = 4249,
  [9071] = 5741,
  [9072] = 7363,
  [9073] = 4294,
  [9074] = 5966,
  [9075] = 8715,
  [9076] = 5967,
  [9077] = 7239,
  [9078] = 4245,
  [9079] = 5118,
  [9080] = 6577,
  [9081] = 4427,
  [9082] = 5805,
  [9083] = 5806,
  [9084] = 4464,
  [9085] = 5746,
  [9086] = 5118,
  [9087] = 5970,
  [9088] = 8715,
  [9089] = 4295,
  [9090] = 4465,
  [9091] = 6001,
  [9092] = 4427,
  [9093] = 6577,
  [9094] = 5803,
  [9095] = 5805,
  [9096] = 5806,
  [9097] = 8715,
  [9098] = 5134,
  [9099] = 5741,
  [9100] = 5332,
  [9101] = 7363,
  [9102] = 4353,
  [9103] = 5966,
  [9104] = 5967,
  [9105] = 5746,
  [9106] = 4401,
  [9107] = 8715,
  [9108] = 5134,
  [9109] = 4895,
  [9110] = 5893,
  [9111] = 4291,
  [9112] = 4967,
  [9113] = 5352,
  [9114] = 4291,
  [9115] = 5332,
  [9116] = 5118,
  [9117] = 5803,
  [9118] = 5970,
  [9119] = 5805,
  [9120] = 5806,
  [9121] = 7363,
  [9122] = 4290,
  [9123] = 9123,
  [9124] = 4464,
  [9125] = 8715,
  [9126] = 6577,
  [9127] = 4465,
  [9128] = 5893,
  [9129] = 4427,
  [9130] = 5354,
  [9131] = 4895,
  [9132] = 5118,
  [9133] = 4294,
  [9134] = 8715,
  [9135] = 4493,
  [9136] = 4464,
  [9137] = 6001,
  [9138] = 5356,
  [9139] = 4465,
  [9140] = 4729,
  [9141] = 4427,
  [9142] = 4730,
  [9143] = 5414,
  [9144] = 5803,
  [9145] = 6577,
  [9146] = 5805,
  [9147] = 5806,
  [9148] = 8715,
  [9149] = 5359,
  [9150] = 4295,
  [9151] = 7363,
  [9152] = 5361,
  [9153] = 5332,
  [9154] = 4401,
  [9155] = 8715,
  [9156] = 5134,
  [9157] = 2348,
  [9158] = 5465,
  [9159] = 5677,
  [9160] = 5803,
  [9161] = 5805,
  [9162] = 5806,
  [9163] = 5679,
  [9164] = 8715,
  [9165] = 4381,
  [9166] = 5684,
  [9167] = 5685,
  [9168] = 4401,
  [9169] = 4464,
  [9170] = 5686,
  [9171] = 4249,
  [9172] = 5118,
  [9173] = 5687,
  [9174] = 4427,
  [9175] = 4465,
  [9176] = 7363,
  [9177] = 8397,
  [9178] = 5966,
  [9179] = 5967,
  [9180] = 8715,
  [9181] = 4427,
  [9182] = 5893,
  [9183] = 5803,
  [9184] = 5690,
  [9185] = 5805,
  [9186] = 5806,
  [9187] = 8887,
  [9188] = 5691,
  [9189] = 5692,
  [9190] = 5693,
  [9191] = 4478,
  [9192] = 5966,
  [9193] = 5967,
  [9194] = 5356,
  [9195] = 4380,
  [9196] = 5970,
  [9197] = 5118,
  [9198] = 5966,
  [9199] = 8715,
  [9200] = 5695,
  [9201] = 5696,
  [9202] = 5970,
  [9203] = 5967,
  [9204] = 7239,
  [9205] = 5118,
  [9206] = 8887,
  [9207] = 5697,
  [9208] = 5698,
  [9209] = 9209,
  [9210] = 5805,
  [9211] = 7263,
  [9212] = 5134,
  [9213] = 8715,
  [9214] = 4353,
  [9215] = 5352,
  [9216] = 4355,
  [9217] = 4368,
  [9218] = 4826,
  [9219] = 4369,
  [9220] = 4854,
  [9221] = 4291,
  [9222] = 8715,
  [9223] = 4372,
  [9224] = 8715,
  [9225] = 7363,
  [9226] = 4294,
  [9227] = 5134,
  [9228] = 4277,
  [9229] = 4295,
  [9230] = 5803,
  [9231] = 5805,
  [9232] = 5806,
  [9233] = 5806,
  [9234] = 4381,
  [9235] = 7263,
  [9236] = 8715,
  [9237] = 4355,
  [9238] = 4826,
  [9239] = 7239,
  [9240] = 7263,
  [9241] = 5414,
  [9242] = 5241,
  [9243] = 5970,
  [9244] = 3850,
  [9245] = 8715,
  [9246] = 5352,
  [9247] = 5244,
  [9248] = 5354,
  [9249] = 4294,
  [9250] = 5356,
  [9251] = 4179,
  [9252] = 4826,
  [9253] = 8715,
  [9254] = 5893,
  [9255] = 5359,
  [9256] = 4730,
  [9257] = 5361,
  [9258] = 4447,
  [9259] = 5248,
  [9260] = 5249,
  [9261] = 5966,
  [9262] = 8715,
  [9263] = 7363,
  [9264] = 5893,
  [9265] = 4730,
  [9266] = 8715,
  [9267] = 5967,
  [9268] = 5134,
  [9269] = 5803,
  [9270] = 3852,
  [9271] = 5805,
  [9272] = 5806,
  [9273] = 4448,
  [9274] = 5893,
  [9275] = 7263,
  [9276] = 8715,
  [9277] = 4179,
  [9278] = 4895,
  [9279] = 5241,
  [9280] = 7363,
  [9281] = 5966,
  [9282] = 4386,
  [9283] = 8715,
  [9284] = 5967,
  [9285] = 5893,
  [9286] = 5244,
  [9287] = 7263,
  [9288] = 5134,
  [9289] = 4387,
  [9290] = 5893,
  [9291] = 5332,
  [9292] = 8715,
  [9293] = 4895,
  [9294] = 5352,
  [9295] = 4632,
  [9296] = 5354,
  [9297] = 4295,
  [9298] = 5741,
  [9299] = 8715,
  [9300] = 5356,
  [9301] = 5248,
  [9302] = 5249,
  [9303] = 5414,
  [9304] = 5118,
  [9305] = 8715,
  [9306] = 5970,
  [9307] = 5359,
  [9308] = 4179,
  [9309] = 5729,
  [9310] = 5361,
  [9311] = 8715,
  [9312] = 5730,
  [9313] = 8420,
  [9314] = 4895,
  [9315] = 5746,
  [9316] = 4367,
  [9317] = 8397,
  [9318] = 4401,
  [9319] = 8715,
  [9320] = 4368,
  [9321] = 4464,
  [9322] = 5734,
  [9323] = 4465,
  [9324] = 4729,
  [9325] = 6001,
  [9326] = 9326,
  [9327] = 5361,
  [9328] = 3852,
  [9329] = 5118,
  [9330] = 4967,
  [9331] = 5465,
  [9332] = 5332,
  [9333] = 9333,
  [9334] = 5684,
  [9335] = 8256,
  [9336] = 4967,
  [9337] = 6001,
  [9338] = 8256,
  [9339] = 5698,
  [9340] = 6912,
  [9341] = 4464,
  [9342] = 5118,
  [9343] = 8256,
  [9344] = 5414,
  [9345] = 5677,
  [9346] = 3850,
  [9347] = 5118,
  [9348] = 4465,
  [9349] = 3852,
  [9350] = 5118,
  [9351] = 4401,
  [9352] = 4967,
  [9353] = 5677,
  [9354] = 4427,
  [9355] = 8420,
  [9356] = 5685,
  [9357] = 5465,
  [9358] = 7239,
  [9359] = 8256,
  [9360] = 7239,
  [9361] = 5677,
  [9362] = 7363,
  [9363] = 7363,
  [9364] = 4895,
  [9365] = 5679,
  [9366] = 5893,
  [9367] = 5684,
  [9368] = 5685,
  [9369] = 5248,
  [9370] = 5249,
  [9371] = 5686,
  [9372] = 5893,
  [9373] = 5679,
  [9374] = 5690,
  [9375] = 5691,
  [9376] = 5692,
  [9377] = 5693,
  [9378] = 5686,
  [9379] = 5118,
  [9380] = 5966,
  [9381] = 5695,
  [9382] = 5696,
  [9383] = 7263,
  [9384] = 5244,
  [9385] = 5697,
  [9386] = 5803,
  [9387] = 5698,
  [9388] = 9388,
  [9389] = 5805,
  [9390] = 5806,
  [9391] = 5684,
  [9392] = 5729,
  [9393] = 5967,
  [9394] = 9326,
  [9395] = 3850,
  [9396] = 5134,
  [9397] = 5687,
  [9398] = 5276,
  [9399] = 6912,
  [9400] = 5685,
  [9401] = 5966,
  [9402] = 4291,
  [9403] = 9403,
  [9404] = 5967,
  [9405] = 9326,
  [9406] = 8397,
  [9407] = 4294,
  [9408] = 3850,
  [9409] = 5686,
  [9410] = 5730,
  [9411] = 6577,
  [9412] = 4464,
  [9413] = 4295,
  [9414] = 5352,
  [9415] = 4967,
  [9416] = 5465,
  [9417] = 4249,
  [9418] = 8256,
  [9419] = 5687,
  [9420] = 4967,
  [9421] = 4465,
  [9422] = 8256,
  [9423] = 7239,
  [9424] = 5276,
  [9425] = 4427,
  [9426] = 5118,
  [9427] = 5354,
  [9428] = 3852,
  [9429] = 5803,
  [9430] = 4895,
  [9431] = 7263,
  [9432] = 4386,
  [9433] = 6829,
  [9434] = 5687,
  [9435] = 8397,
  [9436] = 4353,
  [9437] = 4381,
  [9438] = 4355,
  [9439] = 5966,
  [9440] = 4179,
  [9441] = 5967,
  [9442] = 9326,
  [9443] = 5805,
  [9444] = 4368,
  [9445] = 4369,
  [9446] = 5734,
  [9447] = 5356,
  [9448] = 5806,
  [9449] = 4372,
  [9450] = 5970,
  [9451] = 4277,
  [9452] = 5690,
  [9453] = 6001,
  [9454] = 5118,
  [9455] = 5970,
  [9456] = 4895,
  [9457] = 4967,
  [9458] = 7363,
  [9459] = 8256,
  [9460] = 4073,
  [9461] = 5803,
  [9462] = 5359,
  [9463] = 3852,
  [9464] = 5729,
  [9465] = 5691,
  [9466] = 4826,
  [9467] = 5730,
  [9468] = 7263,
  [9469] = 5352,
  [9470] = 5361,
  [9471] = 5354,
  [9472] = 8420,
  [9473] = 5893,
  [9474] = 5734,
  [9475] = 5356,
  [9476] = 9326,
  [9477] = 5118,
  [9478] = 5692,
  [9479] = 5693,
  [9480] = 5893,
  [9481] = 5736,
  [9482] = 5737,
  [9483] = 9326,
  [9484] = 5970,
  [9485] = 7239,
  [9486] = 5734,
  [9487] = 5359,
  [9488] = 5803,
  [9489] = 6912,
  [9490] = 5805,
  [9491] = 5806,
  [9492] = 5361,
  [9493] = 4730,
  [9494] = 5690,
  [9495] = 4826,
  [9496] = 8256,
  [9497] = 3850,
  [9498] = 6829,
  [9499] = 4826,
  [9500] = 4073,
  [9501] = 9326,
  [9502] = 5134,
  [9503] = 5691,
  [9504] = 5893,
  [9505] = 8420,
  [9506] = 6829,
  [9507] = 3850,
  [9508] = 5729,
  [9509] = 3850,
  [9510] = 4294,
  [9511] = 5134,
  [9512] = 5730,
  [9513] = 5893,
  [9514] = 9326,
  [9515] = 7363,
  [9516] = 3852,
  [9517] = 6912,
  [9518] = 8256,
  [9519] = 5134,
  [9520] = 5134,
  [9521] = 5893,
  [9522] = 4387,
  [9523] = 7263,
  [9524] = 7363,
  [9525] = 4386,
  [9526] = 5734,
  [9527] = 4387,
  [9528] = 5692,
  [9529] = 5695,
  [9530] = 5736,
  [9531] = 5696,
  [9532] = 5736,
  [9533] = 4967,
  [9534] = 5737,
  [9535] = 5693,
  [9536] = 3850,
  [9537] = 5893,
  [9538] = 5746,
  [9539] = 5805,
  [9540] = 5741,
  [9541] = 9326,
  [9542] = 7363,
  [9543] = 4367,
  [9544] = 5737,
  [9545] = 5248,
  [9546] = 5249,
  [9547] = 5134,
  [9548] = 6912,
  [9549] = 5893,
  [9550] = 5970,
  [9551] = 3852,
  [9552] = 5697,
  [9553] = 5741,
  [9554] = 5332,
  [9555] = 5806,
  [9556] = 5352,
  [9557] = 5746,
  [9558] = 5354,
  [9559] = 4493,
  [9560] = 7363,
  [9561] = 5698,
  [9562] = 9562,
  [9563] = 6829,
  [9564] = 2348,
  [9565] = 5414,
  [9566] = 5356,
  [9567] = 5359,
  [9568] = 7239,
  [9569] = 5361,
  [9570] = 5893,
  [9571] = 5687,
  [9572] = 5803,
  [9573] = 5803,
  [9574] = 5352,
  [9575] = 5805,
  [9576] = 5966,
  [9577] = 5967,
  [9578] = 5806,
  [9579] = 5966,
  [9580] = 6829,
  [9581] = 5354,
  [9582] = 5356,
  [9583] = 5970,
  [9584] = 5465,
  [9585] = 9326,
  [9586] = 5967,
  [9587] = 7363,
  [9588] = 5805,
  [9589] = 5359,
  [9590] = 7263,
  [9591] = 7263,
  [9592] = 5361,
  [9593] = 5806,
  [9594] = 5970,
  [9595] = 5677,
  [9596] = 9326,
  [9597] = 4854,
  [9598] = 5741,
  [9599] = 5352,
  [9600] = 4895,
  [9601] = 6912,
  [9602] = 8256,
  [9603] = 5679,
  [9604] = 6001,
  [9605] = 5736,
  [9606] = 4478,
  [9607] = 6577,
  [9608] = 5970,
  [9609] = 5684,
  [9610] = 9326,
  [9611] = 5685,
  [9612] = 4826,
  [9613] = 9613,
  [9614] = 5686,
  [9615] = 5687,
  [9616] = 6001,
  [9617] = 9326,
  [9618] = 4729,
  [9619] = 5966,
  [9620] = 5967,
  [9621] = 5746,
  [9622] = 4291,
  [9623] = 9623,
  [9624] = 4294,
  [9625] = 9625,
  [9626] = 4295,
  [9627] = 5354,
  [9628] = 5690,
  [9629] = 4401,
  [9630] = 8256,
  [9631] = 5241,
  [9632] = 5695,
  [9633] = 5691,
  [9634] = 5118,
  [9635] = 5697,
  [9636] = 5970,
  [9637] = 5692,
  [9638] = 5970,
  [9639] = 5966,
  [9640] = 5693,
  [9641] = 5803,
  [9642] = 7363,
  [9643] = 8397,
  [9644] = 4291,
  [9645] = 5967,
  [9646] = 5746,
  [9647] = 5679,
  [9648] = 5966,
  [9649] = 5967,
  [9650] = 5118,
  [9651] = 7239,
  [9652] = 7363,
  [9653] = 6577,
  [9654] = 5970,
  [9655] = 5134,
  [9656] = 9326,
  [9657] = 5695,
  [9658] = 9658,
  [9659] = 5696,
  [9660] = 4826,
  [9661] = 8397,
  [9662] = 9326,
  [9663] = 4291,
  [9664] = 5118,
  [9665] = 5134,
  [9666] = 5244,
  [9667] = 5697,
  [9668] = 9209,
  [9669] = 4895,
  [9670] = 9326,
  [9671] = 4291,
  [9672] = 8397,
  [9673] = 5803,
  [9674] = 4294,
  [9675] = 4294,
  [9676] = 5698,
  [9677] = 5356,
  [9678] = 5805,
  [9679] = 4295,
  [9680] = 4295,
  [9681] = 5134,
  [9682] = 5696,
  [9683] = 5806,
  [9684] = 5803,
  [9685] = 5805,
  [9686] = 9326,
  [9687] = 5806,
  [9688] = 5805,
  [9689] = 5806,
  [9690] = 5134,
  [9691] = 4895,
  [9692] = 5803,
  [9693] = 5805,
  [9694] = 5806,
  [9695] = 4493,
  [9696] = 8256,
  [9697] = 7363,
  [9698] = 4295,
  [9699] = 5966,
  [9700] = 7363,
  [9701] = 5741,
  [9702] = 4826,
  [9703] = 9703,
  [9704] = 4401,
  [9705] = 5967,
  [9706] = 5359,
  [9707] = 8397,
  [9708] = 6577,
  [9709] = 5893,
  [9710] = 5729,
  [9711] = 4967,
  [9712] = 5803,
  [9713] = 5805,
  [9714] = 5806,
  [9715] = 5737,
  [9716] = 5352,
  [9717] = 5730,
  [9718] = 5354,
  [9719] = 9719,
  [9720] = 4478,
  [9721] = 5356,
  [9722] = 5803,
  [9723] = 9326,
  [9724] = 5805,
  [9725] = 5806,
  [9726] = 5359,
  [9727] = 5241,
  [9728] = 5966,
  [9729] = 5967,
  [9730] = 5361,
  [9731] = 5134,
  [9732] = 7239,
  [9733] = 5967,
  [9734] = 5967,
  [9735] = 4509,
  [9736] = 5967,
  [9737] = 8256,
  [9738] = 5803,
  [9739] = 9739,
  [9740] = 5970,
  [9741] = 4509,
  [9742] = 5805,
  [9743] = 5356,
  [9744] = 5806,
  [9745] = 8256,
  [9746] = 5736,
  [9747] = 5966,
  [9748] = 7363,
  [9749] = 6577,
  [9750] = 4509,
  [9751] = 8256,
  [9752] = 6577,
  [9753] = 5970,
  [9754] = 7263,
  [9755] = 5966,
  [9756] = 4509,
  [9757] = 5967,
  [9758] = 5118,
  [9759] = 5967,
  [9760] = 5970,
  [9761] = 5966,
  [9762] = 5746,
  [9763] = 9763,
  [9764] = 5737,
  [9765] = 5967,
  [9766] = 4509,
  [9767] = 5970,
  [9768] = 5356,
  [9769] = 6912,
  [9770] = 8256,
  [9771] = 5359,
  [9772] = 8256,
  [9773] = 5352,
  [9774] = 7239,
  [9775] = 4465,
  [9776] = 4509,
  [9777] = 5361,
  [9778] = 5970,
  [9779] = 4509,
  [9780] = 7363,
  [9781] = 5803,
  [9782] = 5966,
  [9783] = 4353,
  [9784] = 5803,
  [9785] = 4179,
  [9786] = 8397,
  [9787] = 4509,
  [9788] = 5805,
  [9789] = 6912,
  [9790] = 5970,
  [9791] = 6001,
  [9792] = 4509,
  [9793] = 5806,
  [9794] = 8256,
  [9795] = 5134,
  [9796] = 4509,
  [9797] = 5805,
  [9798] = 5352,
  [9799] = 9799,
  [9800] = 5806,
  [9801] = 5893,
  [9802] = 5354,
  [9803] = 5134,
  [9804] = 8256,
  [9805] = 4509,
  [9806] = 5352,
  [9807] = 5970,
  [9808] = 4967,
  [9809] = 4509,
  [9810] = 5354,
  [9811] = 7239,
  [9812] = 9403,
  [9813] = 4509,
  [9814] = 7363,
  [9815] = 5677,
  [9816] = 5354,
  [9817] = 7263,
  [9818] = 5741,
  [9819] = 4509,
  [9820] = 7363,
  [9821] = 6829,
  [9822] = 5803,
  [9823] = 4826,
  [9824] = 4509,
  [9825] = 5805,
  [9826] = 9826,
  [9827] = 5806,
  [9828] = 9333,
  [9829] = 5356,
  [9830] = 7239,
  [9831] = 4372,
  [9832] = 8256,
  [9833] = 5356,
  [9834] = 4509,
  [9835] = 7363,
  [9836] = 3850,
  [9837] = 3850,
  [9838] = 5359,
  [9839] = 5741,
  [9840] = 4509,
  [9841] = 9799,
  [9842] = 5134,
  [9843] = 5970,
  [9844] = 5729,
  [9845] = 4509,
  [9846] = 5803,
  [9847] = 9763,
  [9848] = 4367,
  [9849] = 5356,
  [9850] = 5970,
  [9851] = 5729,
  [9852] = 5354,
  [9853] = 5359,
  [9854] = 4509,
  [9855] = 5359,
  [9856] = 5730,
  [9857] = 5361,
  [9858] = 5361,
  [9859] = 7263,
  [9860] = 5746,
  [9861] = 5134,
  [9862] = 5805,
  [9863] = 8256,
  [9864] = 5803,
  [9865] = 7263,
  [9866] = 7363,
  [9867] = 3852,
  [9868] = 5806,
  [9869] = 5805,
  [9870] = 5806,
  [9871] = 3852,
  [9872] = 8256,
  [9873] = 4967,
  [9874] = 5734,
  [9875] = 5359,
  [9876] = 5361,
  [9877] = 9826,
  [9878] = 4380,
  [9879] = 8256,
  [9880] = 8256,
  [9881] = 5361,
  [9882] = 5736,
  [9883] = 5695,
  [9884] = 5737,
  [9885] = 4895,
  [9886] = 5966,
  [9887] = 5352,
  [9888] = 5967,
  [9889] = 7263,
  [9890] = 5803,
  [9891] = 5354,
  [9892] = 5352,
  [9893] = 5805,
  [9894] = 4493,
  [9895] = 9895,
  [9896] = 5356,
  [9897] = 7363,
  [9898] = 5806,
  [9899] = 3852,
  [9900] = 5679,
  [9901] = 5970,
  [9902] = 9799,
  [9903] = 5893,
  [9904] = 9763,
  [9905] = 5696,
  [9906] = 5359,
  [9907] = 9907,
  [9908] = 5966,
  [9909] = 5361,
  [9910] = 3852,
  [9911] = 5803,
  [9912] = 8397,
  [9913] = 5967,
  [9914] = 5352,
  [9915] = 5803,
  [9916] = 6829,
  [9917] = 5354,
  [9918] = 5805,
  [9919] = 5806,
  [9920] = 6577,
  [9921] = 5354,
  [9922] = 5805,
  [9923] = 5966,
  [9924] = 5966,
  [9925] = 5352,
  [9926] = 5803,
  [9927] = 5967,
  [9928] = 5118,
  [9929] = 5352,
  [9930] = 5805,
  [9931] = 9931,
  [9932] = 5806,
  [9933] = 7239,
  [9934] = 5354,
  [9935] = 4368,
  [9936] = 4895,
  [9937] = 5684,
  [9938] = 7363,
  [9939] = 5893,
  [9940] = 7363,
  [9941] = 5354,
  [9942] = 5356,
  [9943] = 5685,
  [9944] = 5970,
  [9945] = 5803,
  [9946] = 4381,
  [9947] = 5806,
  [9948] = 5970,
  [9949] = 5359,
  [9950] = 5803,
  [9951] = 7263,
  [9952] = 5967,
  [9953] = 5805,
  [9954] = 9799,
  [9955] = 3850,
  [9956] = 5806,
  [9957] = 5361,
  [9958] = 5686,
  [9959] = 5966,
  [9960] = 5356,
  [9961] = 5465,
  [9962] = 9719,
  [9963] = 9739,
  [9964] = 6912,
  [9965] = 5677,
  [9966] = 5356,
  [9967] = 5734,
  [9968] = 9968,
  [9969] = 8397,
  [9970] = 5679,
  [9971] = 4427,
  [9972] = 6912,
  [9973] = 5805,
  [9974] = 5684,
  [9975] = 6001,
  [9976] = 5687,
  [9977] = 9739,
  [9978] = 5685,
  [9979] = 7263,
  [9980] = 5356,
  [9981] = 5686,
  [9982] = 4729,
  [9983] = 5687,
  [9984] = 5893,
  [9985] = 5893,
  [9986] = 4355,
  [9987] = 8420,
  [9988] = 7363,
  [9989] = 8256,
  [9990] = 9763,
  [9991] = 8397,
  [9992] = 5966,
  [9993] = 5967,
  [9994] = 4509,
  [9995] = 5690,
  [9996] = 5359,
  [9997] = 5691,
  [9998] = 4249,
  [9999] = 5692,
  [10000] = 5805,
  [10001] = 5970,
  [10002] = 5693,
  [10003] = 5803,
  [10004] = 5805,
  [10005] = 5806,
  [10006] = 4730,
  [10007] = 5695,
  [10008] = 5696,
  [10009] = 5803,
  [10010] = 5361,
  [10011] = 6829,
  [10012] = 7239,
  [10013] = 5118,
  [10014] = 5465,
  [10015] = 5893,
  [10016] = 4478,
  [10017] = 5352,
  [10018] = 8420,
  [10019] = 9931,
  [10020] = 9799,
  [10021] = 5697,
  [10022] = 5354,
  [10023] = 5698,
  [10024] = 9763,
  [10025] = 5805,
  [10026] = 5806,
  [10027] = 5806,
  [10028] = 5803,
  [10029] = 5356,
  [10030] = 5805,
  [10031] = 5806,
  [10032] = 4291,
  [10033] = 5359,
  [10034] = 7239,
  [10035] = 4294,
  [10036] = 5361,
  [10037] = 4295,
  [10038] = 7363,
  [10039] = 8397,
  [10040] = 5359,
  [10041] = 5134,
  [10042] = 3852,
  [10043] = 5352,
  [10044] = 4637,
  [10045] = 5803,
  [10046] = 4277,
  [10047] = 4245,
  [10048] = 7239,
  [10049] = 5361,
  [10050] = 4291,
  [10051] = 3850,
  [10052] = 5359,
  [10053] = 4509,
  [10054] = 5966,
  [10055] = 5967,
  [10056] = 7263,
  [10057] = 7363,
  [10058] = 5414,
  [10059] = 5806,
  [10060] = 4294,
  [10061] = 5134,
  [10062] = 5361,
  [10063] = 7239,
  [10064] = 4295,
  [10065] = 5893,
  [10066] = 4268,
  [10067] = 5970,
  [10068] = 5697,
  [10069] = 5118,
  [10070] = 5966,
  [10071] = 5967,
  [10072] = 4369,
  [10073] = 7263,
  [10074] = 9931,
  [10075] = 6001,
  [10076] = 7363,
  [10077] = 4291,
  [10078] = 5352,
  [10079] = 4401,
  [10080] = 5690,
  [10081] = 5354,
  [10082] = 7363,
  [10083] = 5356,
  [10084] = 7239,
  [10085] = 5359,
  [10086] = 4294,
  [10087] = 7239,
  [10088] = 4509,
  [10089] = 5361,
  [10090] = 4295,
  [10091] = 5118,
  [10092] = 5730,
  [10093] = 7263,
  [10094] = 10094,
  [10095] = 6829,
  [10096] = 4464,
  [10097] = 8256,
  [10098] = 6001,
  [10099] = 8420,
  [10100] = 5691,
  [10101] = 4509,
  [10102] = 7363,
  [10103] = 5352,
  [10104] = 5966,
  [10105] = 8397,
  [10106] = 5118,
  [10107] = 7363,
  [10108] = 7263,
  [10109] = 5967,
  [10110] = 5893,
  [10111] = 7263,
  [10112] = 5803,
  [10113] = 4509,
  [10114] = 5805,
  [10115] = 5806,
  [10116] = 8397,
  [10117] = 7239,
  [10118] = 7363,
  [10119] = 5354,
  [10120] = 5692,
  [10121] = 5966,
  [10122] = 7363,
  [10123] = 7363,
  [10124] = 5698,
  [10125] = 5693,
  [10126] = 10126,
  [10127] = 10127,
  [10128] = 5803,
  [10129] = 10129,
  [10130] = 10130,
  [10131] = 10127,
  [10132] = 5970,
  [10133] = 5356,
  [10134] = 4826,
  [10135] = 4632,
  [10136] = 4632,
  [10137] = 4632,
  [10138] = 8420,
  [10139] = 7239,
  [10140] = 7239,
  [10141] = 5803,
  [10142] = 5737,
  [10143] = 10143,
  [10144] = 5805,
  [10145] = 5806,
  [10146] = 4632,
  [10147] = 4632,
  [10148] = 5736,
  [10149] = 5966,
  [10150] = 4632,
  [10151] = 7239,
  [10152] = 7363,
  [10153] = 10143,
  [10154] = 5359,
  [10155] = 10127,
  [10156] = 5730,
  [10157] = 5352,
  [10158] = 10158,
  [10159] = 7263,
  [10160] = 10127,
  [10161] = 10127,
  [10162] = 5359,
  [10163] = 3850,
  [10164] = 4895,
  [10165] = 5361,
  [10166] = 5970,
  [10167] = 4401,
  [10168] = 3850,
  [10169] = 5359,
  [10170] = 5803,
  [10171] = 5352,
  [10172] = 10172,
  [10173] = 7263,
  [10174] = 8256,
  [10175] = 5970,
  [10176] = 5361,
  [10177] = 5805,
  [10178] = 5806,
  [10179] = 6577,
  [10180] = 5134,
  [10181] = 5803,
  [10182] = 5356,
  [10183] = 5893,
  [10184] = 5970,
  [10185] = 8420,
  [10186] = 5805,
  [10187] = 5356,
  [10188] = 4464,
  [10189] = 10127,
  [10190] = 5806,
  [10191] = 5893,
  [10192] = 10192,
  [10193] = 5967,
  [10194] = 5359,
  [10195] = 4632,
  [10196] = 5354,
  [10197] = 7363,
  [10198] = 5359,
  [10199] = 5696,
  [10200] = 10127,
  [10201] = 5967,
  [10202] = 7263,
  [10203] = 7239,
  [10204] = 7239,
  [10205] = 5352,
  [10206] = 4967,
  [10207] = 5352,
  [10208] = 10127,
  [10209] = 7363,
  [10210] = 4632,
  [10211] = 4464,
  [10212] = 5465,
  [10213] = 5970,
  [10214] = 6001,
  [10215] = 5354,
  [10216] = 5354,
  [10217] = 8256,
  [10218] = 10127,
  [10219] = 4632,
  [10220] = 5361,
  [10221] = 5970,
  [10222] = 9719,
  [10223] = 5806,
  [10224] = 5893,
  [10225] = 7263,
  [10226] = 10226,
  [10227] = 4465,
  [10228] = 5354,
  [10229] = 5352,
  [10230] = 6912,
  [10231] = 7363,
  [10232] = 6912,
  [10233] = 4632,
  [10234] = 8397,
  [10235] = 5359,
  [10236] = 4427,
  [10237] = 7363,
  [10238] = 5967,
  [10239] = 5361,
  [10240] = 5803,
  [10241] = 8420,
  [10242] = 5803,
  [10243] = 10127,
  [10244] = 5691,
  [10245] = 10245,
  [10246] = 7263,
  [10247] = 6829,
  [10248] = 5354,
  [10249] = 10127,
  [10250] = 5361,
  [10251] = 5805,
  [10252] = 5806,
  [10253] = 10253,
  [10254] = 5685,
  [10255] = 4632,
  [10256] = 5677,
  [10257] = 5806,
  [10258] = 3852,
  [10259] = 5361,
  [10260] = 5966,
  [10261] = 9333,
  [10262] = 7363,
  [10263] = 5803,
  [10264] = 5966,
  [10265] = 8397,
  [10266] = 5967,
  [10267] = 10127,
  [10268] = 5356,
  [10269] = 5805,
  [10270] = 4632,
  [10271] = 5805,
  [10272] = 5967,
  [10273] = 8256,
  [10274] = 5893,
  [10275] = 4632,
  [10276] = 10127,
  [10277] = 5805,
  [10278] = 7263,
  [10279] = 3852,
  [10280] = 5805,
  [10281] = 10281,
  [10282] = 10143,
  [10283] = 5893,
  [10284] = 10127,
  [10285] = 5118,
  [10286] = 4632,
  [10287] = 8397,
  [10288] = 7263,
  [10289] = 7363,
  [10290] = 5679,
  [10291] = 10291,
  [10292] = 4632,
  [10293] = 5359,
  [10294] = 10127,
  [10295] = 5352,
  [10296] = 4826,
  [10297] = 5806,
  [10298] = 10130,
  [10299] = 5966,
  [10300] = 5354,
  [10301] = 5361,
  [10302] = 6577,
  [10303] = 10303,
  [10304] = 10127,
  [10305] = 8397,
  [10306] = 5684,
  [10307] = 8256,
  [10308] = 5803,
  [10309] = 5354,
  [10310] = 5356,
  [10311] = 5805,
  [10312] = 5806,
  [10313] = 7239,
  [10314] = 6829,
  [10315] = 4632,
  [10316] = 5803,
  [10317] = 10127,
  [10318] = 10127,
  [10319] = 7239,
  [10320] = 5359,
  [10321] = 4632,
  [10322] = 5361,
  [10323] = 10127,
  [10324] = 9403,
  [10325] = 7363,
  [10326] = 5805,
  [10327] = 4895,
  [10328] = 5805,
  [10329] = 5352,
  [10330] = 5966,
  [10331] = 10331,
  [10332] = 5686,
  [10333] = 5354,
  [10334] = 4632,
  [10335] = 5803,
  [10336] = 10127,
  [10337] = 5805,
  [10338] = 5806,
  [10339] = 5356,
  [10340] = 5359,
  [10341] = 7363,
  [10342] = 6829,
  [10343] = 4294,
  [10344] = 5967,
  [10345] = 5361,
  [10346] = 5695,
  [10347] = 10127,
  [10348] = 5356,
  [10349] = 5966,
  [10350] = 5967,
  [10351] = 6577,
  [10352] = 5356,
  [10353] = 10130,
  [10354] = 5803,
  [10355] = 5806,
  [10356] = 7263,
  [10357] = 5352,
  [10358] = 5352,
  [10359] = 7363,
  [10360] = 4264,
  [10361] = 5806,
  [10362] = 5970,
  [10363] = 5805,
  [10364] = 8256,
  [10365] = 7363,
  [10366] = 5806,
  [10367] = 6577,
  [10368] = 7263,
  [10369] = 8397,
  [10370] = 5356,
  [10371] = 4632,
  [10372] = 5966,
  [10373] = 4401,
  [10374] = 5967,
  [10375] = 5356,
  [10376] = 5803,
  [10377] = 4632,
  [10378] = 5692,
  [10379] = 5352,
  [10380] = 5805,
  [10381] = 5806,
  [10382] = 5693,
  [10383] = 5697,
  [10384] = 6577,
  [10385] = 7363,
  [10386] = 8256,
  [10387] = 5729,
  [10388] = 7363,
  [10389] = 7363,
  [10390] = 4291,
  [10391] = 10127,
  [10392] = 7239,
  [10393] = 5354,
  [10394] = 8397,
  [10395] = 4632,
  [10396] = 4465,
  [10397] = 5803,
  [10398] = 5970,
  [10399] = 5966,
  [10400] = 7239,
  [10401] = 5970,
  [10402] = 5734,
  [10403] = 10127,
  [10404] = 10245,
  [10405] = 4632,
  [10406] = 4967,
  [10407] = 10127,
  [10408] = 10303,
  [10409] = 7239,
  [10410] = 5970,
  [10411] = 5805,
  [10412] = 5806,
  [10413] = 10331,
  [10414] = 8256,
  [10415] = 10245,
  [10416] = 6912,
  [10417] = 5966,
  [10418] = 5803,
  [10419] = 5966,
  [10420] = 4427,
  [10421] = 5803,
  [10422] = 5967,
  [10423] = 5354,
  [10424] = 6001,
  [10425] = 4632,
  [10426] = 5967,
  [10427] = 5893,
  [10428] = 4295,
  [10429] = 7363,
  [10430] = 8256,
  [10431] = 4632,
  [10432] = 8420,
  [10433] = 8256,
  [10434] = 10127,
  [10435] = 7363,
  [10436] = 10436,
  [10437] = 5690,
  [10438] = 5893,
  [10439] = 5698,
  [10440] = 4264,
  [10441] = 5361,
  [10442] = 5359,
  [10443] = 5806,
  [10444] = 8397,
  [10445] = 5361,
  [10446] = 4826,
  [10447] = 7239,
  [10448] = 5805,
  [10449] = 7263,
  [10450] = 7263,
  [10451] = 5356,
  [10452] = 10129,
  [10453] = 5806,
  [10454] = 5967,
  [10455] = 7263,
  [10456] = 10456,
  [10457] = 10158,
  [10458] = 7363,
  [10459] = 10459,
  [10460] = 5352,
  [10461] = 6829,
  [10462] = 7239,
  [10463] = 10463,
  [10464] = 5352,
  [10465] = 5970,
  [10466] = 5356,
  [10467] = 5966,
  [10468] = 5967,
  [10469] = 5354,
  [10470] = 10470,
  [10471] = 8420,
  [10472] = 10472,
  [10473] = 5352,
  [10474] = 6912,
  [10475] = 5803,
  [10476] = 5354,
  [10477] = 7363,
  [10478] = 5354,
  [10479] = 5893,
  [10480] = 7239,
  [10481] = 7263,
  [10482] = 10463,
  [10483] = 7263,
  [10484] = 5356,
  [10485] = 7363,
  [10486] = 4967,
  [10487] = 8420,
  [10488] = 5356,
  [10489] = 5354,
  [10490] = 5359,
  [10491] = 5118,
  [10492] = 10492,
  [10493] = 5803,
  [10494] = 10226,
  [10495] = 5361,
  [10496] = 5359,
  [10497] = 10497,
  [10498] = 7239,
  [10499] = 5805,
  [10500] = 5803,
  [10501] = 5803,
  [10502] = 5361,
  [10503] = 5805,
  [10504] = 7363,
  [10505] = 5805,
  [10506] = 5966,
  [10507] = 5967,
  [10508] = 5806,
  [10509] = 10509,
  [10510] = 5970,
  [10511] = 5805,
  [10512] = 5806,
  [10513] = 5806,
  [10514] = 5803,
  [10515] = 5805,
  [10516] = 6912,
  [10517] = 5805,
  [10518] = 5806,
  [10519] = 5970,
  [10520] = 5352,
  [10521] = 5806,
  [10522] = 4264,
  [10523] = 10497,
  [10524] = 10509,
  [10525] = 6829,
  [10526] = 10470,
  [10527] = 5803,
  [10528] = 5803,
  [10529] = 6577,
  [10530] = 7363,
  [10531] = 10253,
  [10532] = 10472,
  [10533] = 8397,
  [10534] = 5803,
  [10535] = 6829,
  [10536] = 8256,
  [10537] = 5352,
  [10538] = 5354,
  [10539] = 4264,
  [10540] = 8397,
  [10541] = 5354,
  [10542] = 10192,
  [10543] = 8397,
  [10544] = 10456,
  [10545] = 5805,
  [10546] = 5356,
  [10547] = 7239,
  [10548] = 5356,
  [10549] = 5359,
  [10550] = 4895,
  [10551] = 5361,
  [10552] = 5361,
  [10553] = 5970,
  [10554] = 7363,
  [10555] = 8256,
  [10556] = 7239,
  [10557] = 8256,
  [10558] = 5359,
  [10559] = 5805,
  [10560] = 5354,
  [10561] = 7363,
  [10562] = 4255,
  [10563] = 7363,
  [10564] = 4255,
  [10565] = 5967,
  [10566] = 10566,
  [10567] = 5356,
  [10568] = 5806,
  [10569] = 5966,
  [10570] = 5806,
  [10571] = 5967,
  [10572] = 5134,
  [10573] = 5806,
  [10574] = 5359,
  [10575] = 5970,
  [10576] = 5359,
  [10577] = 10281,
  [10578] = 8420,
  [10579] = 10497,
  [10580] = 5806,
  [10581] = 10472,
  [10582] = 6912,
  [10583] = 10509,
  [10584] = 7263,
  [10585] = 5361,
  [10586] = 8256,
  [10587] = 5361,
  [10588] = 5803,
  [10589] = 7363,
  [10590] = 7363,
  [10591] = 7263,
  [10592] = 10592,
  [10593] = 8256,
  [10594] = 5970,
  [10595] = 5118,
  [10596] = 5806,
  [10597] = 4854,
  [10598] = 8256,
  [10599] = 6001,
  [10600] = 10470,
  [10601] = 5803,
  [10602] = 5352,
  [10603] = 10603,
  [10604] = 7263,
  [10605] = 8397,
  [10606] = 7363,
  [10607] = 5805,
  [10608] = 10436,
  [10609] = 7363,
  [10610] = 5806,
  [10611] = 10611,
  [10612] = 5134,
  [10613] = 8397,
  [10614] = 8256,
  [10615] = 8397,
  [10616] = 8420,
  [10617] = 8256,
  [10618] = 5352,
  [10619] = 6912,
  [10620] = 5414,
  [10621] = 6829,
  [10622] = 5966,
  [10623] = 6829,
  [10624] = 5332,
  [10625] = 5803,
  [10626] = 5803,
  [10627] = 5805,
  [10628] = 5803,
  [10629] = 5806,
  [10630] = 6912,
  [10631] = 6912,
  [10632] = 10566,
  [10633] = 7363,
  [10634] = 7363,
  [10635] = 5805,
  [10636] = 10492,
  [10637] = 5803,
  [10638] = 5966,
  [10639] = 5805,
  [10640] = 5806,
  [10641] = 7363,
  [10642] = 7363,
  [10643] = 8397,
  [10644] = 7363,
  [10645] = 5359,
  [10646] = 5967,
  [10647] = 7239,
  [10648] = 5970,
  [10649] = 5805,
  [10650] = 7363,
  [10651] = 8397,
  [10652] = 8397,
  [10653] = 8397,
  [10654] = 7363,
  [10655] = 8397,
  [10656] = 10656,
  [10657] = 5966,
  [10658] = 10603,
  [10659] = 5967,
  [10660] = 10660,
  [10661] = 4245,
  [10662] = 5966,
  [10663] = 5967,
  [10664] = 7363,
  [10665] = 10665,
  [10666] = 6829,
  [10667] = 10592,
  [10668] = 10668,
  [10669] = 4073,
  [10670] = 5356,
  [10671] = 8541,
  [10672] = 5966,
  [10673] = 10673,
  [10674] = 5730,
  [10675] = 5803,
  [10676] = 5354,
  [10677] = 10253,
  [10678] = 10678,
  [10679] = 5354,
  [10680] = 5737,
  [10681] = 5966,
  [10682] = 5967,
  [10683] = 8420,
  [10684] = 10459,
  [10685] = 8443,
  [10686] = 5354,
  [10687] = 5248,
  [10688] = 8420,
  [10689] = 4257,
  [10690] = 5249,
  [10691] = 8629,
  [10692] = 10158,
  [10693] = 8560,
  [10694] = 4386,
  [10695] = 5356,
  [10696] = 10696,
  [10697] = 5803,
  [10698] = 8541,
  [10699] = 5970,
  [10700] = 5354,
  [10701] = 5361,
  [10702] = 5805,
  [10703] = 10703,
  [10704] = 5806,
  [10705] = 5803,
  [10706] = 7363,
  [10707] = 10707,
  [10708] = 10656,
  [10709] = 5970,
  [10710] = 5805,
  [10711] = 5356,
  [10712] = 10712,
  [10713] = 5803,
  [10714] = 8669,
  [10715] = 5359,
  [10716] = 5893,
  [10717] = 5805,
  [10718] = 5806,
  [10719] = 7263,
  [10720] = 8397,
  [10721] = 10707,
  [10722] = 8256,
  [10723] = 5970,
  [10724] = 5361,
  [10725] = 5967,
  [10726] = 7363,
  [10727] = 7239,
  [10728] = 5359,
  [10729] = 4255,
  [10730] = 10730,
  [10731] = 8420,
  [10732] = 4386,
  [10733] = 5352,
  [10734] = 7263,
  [10735] = 10735,
  [10736] = 8397,
  [10737] = 10436,
  [10738] = 8397,
  [10739] = 8420,
  [10740] = 5806,
  [10741] = 10741,
  [10742] = 10742,
  [10743] = 10743,
  [10744] = 10744,
  [10745] = 10129,
  [10746] = 4427,
  [10747] = 7263,
  [10748] = 5465,
  [10749] = 7363,
  [10750] = 8256,
  [10751] = 4264,
  [10752] = 10742,
  [10753] = 10665,
  [10754] = 10754,
  [10755] = 8397,
  [10756] = 4245,
  [10757] = 7239,
  [10758] = 5803,
  [10759] = 4264,
  [10760] = 5677,
  [10761] = 5359,
  [10762] = 4264,
  [10763] = 4257,
  [10764] = 10226,
  [10765] = 5803,
  [10766] = 7239,
  [10767] = 8397,
  [10768] = 4245,
  [10769] = 10707,
  [10770] = 4268,
  [10771] = 5679,
  [10772] = 8476,
  [10773] = 8397,
  [10774] = 5966,
  [10775] = 5359,
  [10776] = 10776,
  [10777] = 4387,
  [10778] = 5805,
  [10779] = 5241,
  [10780] = 10780,
  [10781] = 5684,
  [10782] = 10696,
  [10783] = 10783,
  [10784] = 7363,
  [10785] = 5361,
  [10786] = 5685,
  [10787] = 5686,
  [10788] = 5359,
  [10789] = 5687,
  [10790] = 10790,
  [10791] = 5276,
  [10792] = 5803,
  [10793] = 5803,
  [10794] = 10794,
  [10795] = 5805,
  [10796] = 10796,
  [10797] = 5806,
  [10798] = 5361,
  [10799] = 5734,
  [10800] = 5966,
  [10801] = 5967,
  [10802] = 10754,
  [10803] = 5806,
  [10804] = 10804,
  [10805] = 5244,
  [10806] = 5352,
  [10807] = 8541,
  [10808] = 4179,
  [10809] = 10809,
  [10810] = 10696,
  [10811] = 5690,
  [10812] = 5970,
  [10813] = 10813,
  [10814] = 4268,
  [10815] = 8589,
  [10816] = 10816,
  [10817] = 5691,
  [10818] = 5803,
  [10819] = 7363,
  [10820] = 5805,
  [10821] = 8397,
  [10822] = 5692,
  [10823] = 5806,
  [10824] = 5693,
  [10825] = 5805,
  [10826] = 8397,
  [10827] = 5361,
  [10828] = 4291,
  [10829] = 4264,
  [10830] = 10703,
  [10831] = 5356,
  [10832] = 5806,
  [10833] = 3850,
  [10834] = 5354,
  [10835] = 4279,
  [10836] = 7263,
  [10837] = 10837,
  [10838] = 7363,
  [10839] = 3850,
  [10840] = 5695,
  [10841] = 5696,
  [10842] = 10665,
  [10843] = 4255,
  [10844] = 5966,
  [10845] = 10780,
  [10846] = 5967,
  [10847] = 5805,
  [10848] = 10796,
  [10849] = 8434,
  [10850] = 5352,
  [10851] = 5134,
  [10852] = 8592,
  [10853] = 4387,
  [10854] = 5697,
  [10855] = 5746,
  [10856] = 10794,
  [10857] = 5806,
  [10858] = 5970,
  [10859] = 5803,
  [10860] = 4245,
  [10861] = 7263,
  [10862] = 5698,
  [10863] = 7363,
  [10864] = 5803,
  [10865] = 3852,
  [10866] = 5805,
  [10867] = 5806,
  [10868] = 8629,
  [10869] = 7239,
  [10870] = 5970,
  [10871] = 10783,
  [10872] = 5356,
  [10873] = 5805,
  [10874] = 3850,
  [10875] = 4245,
  [10876] = 5352,
  [10877] = 5806,
  [10878] = 3852,
  [10879] = 5354,
  [10880] = 10735,
  [10881] = 4465,
  [10882] = 5356,
  [10883] = 5352,
  [10884] = 5359,
  [10885] = 4264,
  [10886] = 10886,
  [10887] = 5361,
  [10888] = 10804,
  [10889] = 10703,
  [10890] = 10660,
  [10891] = 10712,
  [10892] = 10743,
  [10893] = 10744,
  [10894] = 8320,
  [10895] = 4255,
  [10896] = 10794,
  [10897] = 7363,
  [10898] = 7363,
  [10899] = 5805,
  [10900] = 4294,
  [10901] = 10901,
  [10902] = 10742,
  [10903] = 8397,
  [10904] = 10754,
  [10905] = 7363,
  [10906] = 8434,
  [10907] = 5359,
  [10908] = 5966,
  [10909] = 5741,
  [10910] = 5736,
  [10911] = 5729,
  [10912] = 5354,
  [10913] = 8476,
  [10914] = 5806,
  [10915] = 7363,
  [10916] = 5352,
  [10917] = 5354,
  [10918] = 7363,
  [10919] = 5361,
  [10920] = 10920,
  [10921] = 10921,
  [10922] = 7363,
  [10923] = 10281,
  [10924] = 4295,
  [10925] = 4464,
  [10926] = 5356,
  [10927] = 10796,
  [10928] = 10780,
  [10929] = 5967,
  [10930] = 5359,
  [10931] = 5352,
  [10932] = 6912,
  [10933] = 5361,
  [10934] = 3852,
  [10935] = 10804,
  [10936] = 5356,
  [10937] = 5352,
  [10938] = 8320,
  [10939] = 8443,
  [10940] = 8560,
  [10941] = 10941,
  [10942] = 10712,
  [10943] = 8592,
  [10944] = 8669,
  [10945] = 10783,
  [10946] = 7239,
  [10947] = 8589,
  [10948] = 5118,
  [10949] = 10949,
  [10950] = 5354,
  [10951] = 10951,
  [10952] = 4277,
  [10953] = 7363,
  [10954] = 10954,
  [10955] = 5414,
  [10956] = 4372,
  [10957] = 3852,
  [10958] = 10958,
  [10959] = 7363,
  [10960] = 10958,
  [10961] = 4279,
  [10962] = 5803,
  [10963] = 10963,
  [10964] = 4257,
  [10965] = 5352,
  [10966] = 4179,
  [10967] = 5970,
  [10968] = 8397,
  [10969] = 10954,
  [10970] = 5730,
  [10971] = 10971,
  [10972] = 5359,
  [10973] = 10656,
  [10974] = 7363,
  [10975] = 10592,
  [10976] = 8589,
  [10977] = 4381,
  [10978] = 5806,
  [10979] = 4264,
  [10980] = 10743,
  [10981] = 5361,
  [10982] = 4249,
  [10983] = 4353,
  [10984] = 8256,
  [10985] = 10459,
  [10986] = 7363,
  [10987] = 4386,
  [10988] = 8397,
  [10989] = 4387,
  [10990] = 8629,
  [10991] = 5893,
  [10992] = 5803,
  [10993] = 5737,
  [10994] = 5361,
  [10995] = 10995,
  [10996] = 7363,
  [10997] = 5356,
  [10998] = 10744,
  [10999] = 4367,
  [11000] = 4291,
  [11001] = 4245,
  [11002] = 5354,
  [11003] = 5734,
  [11004] = 10951,
  [11005] = 5805,
  [11006] = 5966,
  [11007] = 8420,
  [11008] = 5805,
  [11009] = 5806,
  [11010] = 4291,
  [11011] = 10837,
  [11012] = 3850,
  [11013] = 10963,
  [11014] = 10958,
  [11015] = 5805,
  [11016] = 5729,
  [11017] = 3850,
  [11018] = 4387,
  [11019] = 5354,
  [11020] = 11020,
  [11021] = 4372,
  [11022] = 4245,
  [11023] = 4381,
  [11024] = 10954,
  [11025] = 4179,
  [11026] = 4294,
  [11027] = 11027,
  [11028] = 4386,
  [11029] = 8397,
  [11030] = 4368,
  [11031] = 7363,
  [11032] = 8397,
  [11033] = 4369,
  [11034] = 4264,
  [11035] = 3852,
  [11036] = 11036,
  [11037] = 4255,
  [11038] = 11038,
  [11039] = 8320,
  [11040] = 8443,
  [11041] = 8560,
  [11042] = 11042,
  [11043] = 4257,
  [11044] = 7363,
  [11045] = 4249,
  [11046] = 7263,
  [11047] = 5352,
  [11048] = 11048,
  [11049] = 4295,
  [11050] = 4179,
  [11051] = 11051,
  [11052] = 4295,
  [11053] = 5356,
  [11054] = 10743,
  [11055] = 11055,
  [11056] = 11027,
  [11057] = 8541,
  [11058] = 4381,
  [11059] = 5806,
  [11060] = 5359,
  [11061] = 5967,
  [11062] = 3852,
  [11063] = 3852,
  [11064] = 7363,
  [11065] = 8592,
  [11066] = 8669,
  [11067] = 8434,
  [11068] = 5805,
  [11069] = 8397,
  [11070] = 5361,
  [11071] = 4355,
  [11072] = 10963,
  [11073] = 10743,
  [11074] = 4290,
  [11075] = 4268,
  [11076] = 5806,
  [11077] = 4245,
  [11078] = 4290,
  [11079] = 4353,
  [11080] = 5803,
  [11081] = 10951,
  [11082] = 10958,
  [11083] = 8397,
  [11084] = 10744,
  [11085] = 7363,
  [11086] = 8397,
  [11087] = 8256,
  [11088] = 11088,
  [11089] = 5359,
  [11090] = 5805,
  [11091] = 5806,
  [11092] = 8476,
  [11093] = 8256,
  [11094] = 4249,
  [11095] = 11095,
  [11096] = 6001,
  [11097] = 3850,
  [11098] = 5806,
  [11099] = 5803,
  [11100] = 4264,
  [11101] = 4294,
  [11102] = 11055,
  [11103] = 4369,
  [11104] = 5352,
  [11105] = 8397,
  [11106] = 10963,
  [11107] = 4355,
  [11108] = 5803,
  [11109] = 8420,
  [11110] = 5805,
  [11111] = 3850,
  [11112] = 4367,
  [11113] = 4268,
  [11114] = 5356,
  [11115] = 4264,
  [11116] = 4478,
  [11117] = 10744,
  [11118] = 4264,
  [11119] = 7263,
  [11120] = 7239,
  [11121] = 10951,
  [11122] = 11122,
  [11123] = 10963,
  [11124] = 11027,
  [11125] = 5803,
  [11126] = 10954,
  [11127] = 10958,
  [11128] = 5736,
  [11129] = 10954,
  [11130] = 11055,
  [11131] = 4368,
  [11132] = 10951,
  [11133] = 4277,
  [11134] = 11134,
  [11135] = 8629,
  [11136] = 11136,
  [11137] = 4179,
  [11138] = 11038,
  [11139] = 8434,
  [11140] = 11140,
  [11141] = 8420,
  [11142] = 8476,
  [11143] = 10192,
  [11144] = 8320,
  [11145] = 8443,
  [11146] = 8560,
  [11147] = 8592,
  [11148] = 8669,
  [11149] = 4386,
  [11150] = 4387,
  [11151] = 5803,
  [11152] = 4268,
  [11153] = 5805,
  [11154] = 5806,
  [11155] = 4245,
  [11156] = 11156,
  [11157] = 11157,
  [11158] = 8541,
  [11159] = 8397,
  [11160] = 11134,
  [11161] = 4268,
  [11162] = 4268,
  [11163] = 4245,
  [11164] = 7363,
  [11165] = 8397,
  [11166] = 11166,
  [11167] = 3852,
  [11168] = 6912,
  [11169] = 4264,
  [11170] = 11170,
  [11171] = 7363,
  [11172] = 8397,
  [11173] = 4290,
  [11174] = 3850,
  [11175] = 7363,
  [11176] = 3852,
  [11177] = 4245,
  [11178] = 4464,
  [11179] = 4465,
  [11180] = 5352,
  [11181] = 4427,
  [11182] = 8541,
  [11183] = 5729,
  [11184] = 5730,
  [11185] = 5354,
  [11186] = 11186,
  [11187] = 4367,
  [11188] = 11188,
  [11189] = 7363,
  [11190] = 8397,
  [11191] = 4249,
  [11192] = 5734,
  [11193] = 5356,
  [11194] = 4245,
  [11195] = 11136,
  [11196] = 8397,
  [11197] = 5736,
  [11198] = 5737,
  [11199] = 5359,
  [11200] = 4264,
  [11201] = 5361,
  [11202] = 4353,
  [11203] = 5803,
  [11204] = 4355,
  [11205] = 5805,
  [11206] = 5806,
  [11207] = 4368,
  [11208] = 4369,
  [11209] = 4372,
  [11210] = 4277,
  [11211] = 11211,
  [11212] = 4381,
  [11213] = 11213,
  [11214] = 3850,
  [11215] = 5352,
  [11216] = 8589,
  [11217] = 5354,
  [11218] = 5356,
  [11219] = 5359,
  [11220] = 5803,
  [11221] = 5361,
  [11222] = 5805,
  [11223] = 5806,
  [11224] = 3852,
  [11225] = 11095,
  [11226] = 11051,
  [11227] = 4249,
  [11228] = 4401,
  [11229] = 4353,
  [11230] = 4381,
  [11231] = 4355,
  [11232] = 4368,
  [11233] = 4369,
  [11234] = 4372,
  [11235] = 4277,
  [11236] = 11236,
  [11237] = 5352,
  [11238] = 11238,
  [11239] = 5354,
  [11240] = 5356,
  [11241] = 11236,
  [11242] = 5359,
  [11243] = 5361,
  [11244] = 8629,
  [11245] = 11134,
  [11246] = 11170,
  [11247] = 11247,
  [11248] = 11248,
  [11249] = 11249,
  [11250] = 11250,
  [11251] = 11251,
  [11252] = 11252,
  [11253] = 5414,
  [11254] = 11036,
  [11255] = 4290,
  [11256] = 4386,
  [11257] = 11134,
  [11258] = 11170,
  [11259] = 11042,
  [11260] = 4387,
  [11261] = 11134,
  [11262] = 11170,
  [11263] = 11263,
  [11264] = 8589,
  [11265] = 11188,
  [11266] = 8629,
  [11267] = 3850,
  [11268] = 8434,
  [11269] = 3852,
  [11270] = 8476,
  [11271] = 11156,
  [11272] = 4291,
  [11273] = 4294,
  [11274] = 4295,
  [11275] = 4179,
  [11276] = 4179,
  [11277] = 8320,
  [11278] = 8443,
  [11279] = 8560,
  [11280] = 8592,
  [11281] = 8669,
  [11282] = 11282,
  [11283] = 8434,
  [11284] = 8476,
  [11285] = 4268,
  [11286] = 3850,
  [11287] = 3852,
  [11288] = 11088,
  [11289] = 11122,
  [11290] = 4245,
  [11291] = 7363,
  [11292] = 8397,
  [11293] = 4255,
  [11294] = 11188,
  [11295] = 11136,
  [11296] = 4268,
  [11297] = 11020,
  [11298] = 8320,
  [11299] = 8443,
  [11300] = 10971,
  [11301] = 4255,
  [11302] = 8560,
  [11303] = 8592,
  [11304] = 8669,
  [11305] = 11247,
  [11306] = 4255,
  [11307] = 3850,
  [11308] = 11188,
  [11309] = 11136,
  [11310] = 11248,
  [11311] = 4367,
  [11312] = 11249,
  [11313] = 11250,
  [11314] = 11170,
  [11315] = 11252,
  [11316] = 5803,
  [11317] = 5805,
  [11318] = 5806,
  [11319] = 4255,
  [11320] = 11320,
  [11321] = 7363,
  [11322] = 5414,
  [11323] = 4401,
  [11324] = 11188,
  [11325] = 11136,
  [11326] = 8589,
  [11327] = 11134,
  [11328] = 11170,
  [11329] = 11134,
  [11330] = 11170,
  [11331] = 11134,
  [11332] = 11170,
  [11333] = 11134,
  [11334] = 11170,
  [11335] = 11134,
  [11336] = 11170,
  [11337] = 11134,
  [11338] = 11170,
  [11339] = 11134,
  [11340] = 11170,
  [11341] = 11134,
  [11342] = 11170,
  [11343] = 11134,
  [11344] = 11170,
  [11345] = 11134,
  [11346] = 11170,
  [11347] = 4291,
  [11348] = 11134,
  [11349] = 11170,
  [11350] = 11134,
  [11351] = 11170,
  [11352] = 11134,
  [11353] = 11170,
  [11354] = 11134,
  [11355] = 11170,
  [11356] = 11134,
  [11357] = 11170,
  [11358] = 4294,
  [11359] = 11134,
  [11360] = 11170,
  [11361] = 11134,
  [11362] = 11170,
  [11363] = 11134,
  [11364] = 11170,
  [11365] = 11134,
  [11366] = 11170,
  [11367] = 4295,
  [11368] = 11134,
  [11369] = 11170,
  [11370] = 11134,
  [11371] = 11170,
  [11372] = 11134,
  [11373] = 11170,
  [11374] = 11134,
  [11375] = 11170,
  [11376] = 11134,
  [11377] = 11170,
  [11378] = 11134,
  [11379] = 11170,
  [11380] = 11134,
  [11381] = 11170,
  [11382] = 11134,
  [11383] = 11170,
  [11384] = 11134,
  [11385] = 11170,
  [11386] = 11134,
  [11387] = 11170,
  [11388] = 11134,
  [11389] = 11170,
  [11390] = 11134,
  [11391] = 11170,
  [11392] = 11134,
  [11393] = 11170,
  [11394] = 11134,
  [11395] = 11170,
  [11396] = 11134,
  [11397] = 11170,
  [11398] = 11134,
  [11399] = 11170,
  [11400] = 11134,
  [11401] = 11170,
  [11402] = 11134,
  [11403] = 11170,
  [11404] = 11134,
  [11405] = 11170,
  [11406] = 11170,
  [11407] = 11134,
  [11408] = 11170,
  [11409] = 11134,
  [11410] = 11170,
  [11411] = 11134,
  [11412] = 11170,
  [11413] = 11134,
  [11414] = 11170,
  [11415] = 11134,
  [11416] = 11170,
  [11417] = 11134,
  [11418] = 11170,
  [11419] = 11134,
  [11420] = 11170,
  [11421] = 11134,
  [11422] = 11170,
  [11423] = 11134,
  [11424] = 11170,
  [11425] = 11134,
  [11426] = 11170,
  [11427] = 11134,
  [11428] = 11170,
  [11429] = 11134,
  [11430] = 11170,
  [11431] = 11134,
  [11432] = 11170,
  [11433] = 11134,
  [11434] = 11170,
  [11435] = 11134,
  [11436] = 11170,
  [11437] = 11134,
  [11438] = 11170,
  [11439] = 11134,
  [11440] = 11170,
  [11441] = 11134,
  [11442] = 11170,
  [11443] = 11134,
  [11444] = 11170,
  [11445] = 11134,
  [11446] = 11170,
  [11447] = 11134,
  [11448] = 11170,
  [11449] = 11134,
  [11450] = 11170,
  [11451] = 11134,
  [11452] = 11170,
  [11453] = 11134,
  [11454] = 11170,
  [11455] = 11134,
  [11456] = 11170,
  [11457] = 11134,
  [11458] = 11251,
  [11459] = 11459,
  [11460] = 11460,
  [11461] = 5803,
  [11462] = 11247,
  [11463] = 5805,
  [11464] = 4245,
  [11465] = 4353,
  [11466] = 4381,
  [11467] = 4291,
  [11468] = 4895,
  [11469] = 11166,
  [11470] = 5354,
  [11471] = 11471,
  [11472] = 11247,
  [11473] = 11249,
  [11474] = 11211,
  [11475] = 4386,
  [11476] = 4493,
  [11477] = 8434,
  [11478] = 8629,
  [11479] = 4264,
  [11480] = 4401,
  [11481] = 4381,
  [11482] = 5729,
  [11483] = 4387,
  [11484] = 4291,
  [11485] = 5730,
  [11486] = 8434,
  [11487] = 4294,
  [11488] = 4295,
  [11489] = 8320,
  [11490] = 8443,
  [11491] = 8560,
  [11492] = 8592,
  [11493] = 8669,
  [11494] = 4386,
  [11495] = 5806,
  [11496] = 5734,
  [11497] = 4367,
  [11498] = 4387,
  [11499] = 5736,
  [11500] = 5737,
  [11501] = 8476,
  [11502] = 11088,
  [11503] = 11122,
  [11504] = 11248,
  [11505] = 8476,
  [11506] = 5356,
  [11507] = 4294,
  [11508] = 5359,
  [11509] = 4268,
  [11510] = 11510,
  [11511] = 4264,
  [11512] = 4386,
  [11513] = 4355,
  [11514] = 11249,
  [11515] = 5361,
  [11516] = 11020,
  [11517] = 11036,
  [11518] = 3852,
  [11519] = 3850,
  [11520] = 4268,
  [11521] = 4291,
  [11522] = 4294,
  [11523] = 4295,
  [11524] = 4295,
  [11525] = 4179,
  [11526] = 5352,
  [11527] = 5354,
  [11528] = 4179,
  [11529] = 5356,
  [11530] = 5359,
  [11531] = 5361,
  [11532] = 7363,
  [11533] = 8320,
  [11534] = 8443,
  [11535] = 10971,
  [11536] = 8560,
  [11537] = 8592,
  [11538] = 8669,
  [11539] = 5803,
  [11540] = 5805,
  [11541] = 5806,
  [11542] = 11542,
  [11543] = 11471,
  [11544] = 11038,
  [11545] = 4268,
  [11546] = 7239,
  [11547] = 3850,
  [11548] = 4368,
  [11549] = 4387,
  [11550] = 3852,
  [11551] = 11551,
  [11552] = 11552,
  [11553] = 11553,
  [11554] = 4264,
  [11555] = 11555,
  [11556] = 11250,
  [11557] = 11557,
  [11558] = 11248,
  [11559] = 11559,
  [11560] = 11560,
  [11561] = 11561,
  [11562] = 11562,
  [11563] = 11563,
  [11564] = 11564,
  [11565] = 11565,
  [11566] = 11566,
  [11567] = 11567,
  [11568] = 11568,
  [11569] = 5414,
  [11570] = 11251,
  [11571] = 7263,
  [11572] = 11572,
  [11573] = 11573,
  [11574] = 4279,
  [11575] = 11575,
  [11576] = 8541,
  [11577] = 4478,
  [11578] = 11578,
  [11579] = 4257,
  [11580] = 4372,
  [11581] = 4369,
  [11582] = 11582,
  [11583] = 4257,
  [11584] = 11471,
  [11585] = 4355,
  [11586] = 4367,
  [11587] = 4268,
  [11588] = 4493,
  [11589] = 4368,
  [11590] = 3850,
  [11591] = 3852,
  [11592] = 8589,
  [11593] = 4249,
  [11594] = 8629,
  [11595] = 11247,
  [11596] = 11252,
  [11597] = 4291,
  [11598] = 8434,
  [11599] = 4367,
  [11600] = 8476,
  [11601] = 4294,
  [11602] = 11602,
  [11603] = 4353,
  [11604] = 11248,
  [11605] = 4295,
  [11606] = 8320,
  [11607] = 8443,
  [11608] = 8560,
  [11609] = 8592,
  [11610] = 8669,
  [11611] = 11249,
  [11612] = 11250,
  [11613] = 11251,
  [11614] = 11602,
  [11615] = 4257,
  [11616] = 11252,
  [11617] = 4369,
  [11618] = 4245,
  [11619] = 4353,
  [11620] = 5414,
  [11621] = 11621,
  [11622] = 11622,
  [11623] = 11623,
  [11624] = 11624,
  [11625] = 11625,
  [11626] = 11626,
  [11627] = 11627,
  [11628] = 11628,
  [11629] = 4245,
  [11630] = 4355,
  [11631] = 4179,
  [11632] = 4355,
  [11633] = 4386,
  [11634] = 11282,
  [11635] = 4257,
  [11636] = 4387,
  [11637] = 4372,
  [11638] = 11638,
  [11639] = 11602,
  [11640] = 4368,
  [11641] = 4249,
  [11642] = 4368,
  [11643] = 4369,
  [11644] = 4249,
  [11645] = 4245,
  [11646] = 4369,
  [11647] = 4372,
  [11648] = 4179,
  [11649] = 4277,
  [11650] = 11213,
  [11651] = 4367,
  [11652] = 4372,
  [11653] = 11252,
  [11654] = 8589,
  [11655] = 4277,
  [11656] = 11095,
  [11657] = 11051,
  [11658] = 4277,
  [11659] = 4268,
  [11660] = 11460,
  [11661] = 11661,
  [11662] = 11662,
  [11663] = 11663,
  [11664] = 8541,
  [11665] = 11263,
  [11666] = 11460,
  [11667] = 11460,
  [11668] = 4478,
  [11669] = 11460,
  [11670] = 4249,
  [11671] = 4249,
  [11672] = 11238,
  [11673] = 11263,
  [11674] = 11674,
  [11675] = 8629,
  [11676] = 4386,
  [11677] = 5352,
  [11678] = 4353,
  [11679] = 4381,
  [11680] = 5354,
  [11681] = 4279,
  [11682] = 4355,
  [11683] = 5356,
  [11684] = 4368,
  [11685] = 4369,
  [11686] = 5359,
  [11687] = 4372,
  [11688] = 5361,
  [11689] = 4277,
  [11690] = 4277,
  [11691] = 5966,
  [11692] = 5967,
  [11693] = 5970,
  [11694] = 4387,
  [11695] = 4381,
  [11696] = 7363,
  [11697] = 8397,
  [11698] = 4353,
  [11699] = 11042,
  [11700] = 4401,
  [11701] = 4291,
  [11702] = 4294,
  [11703] = 4295,
  [11704] = 5352,
  [11705] = 11705,
  [11706] = 5354,
  [11707] = 8541,
  [11708] = 5356,
  [11709] = 5359,
  [11710] = 5361,
  [11711] = 4179,
  [11712] = 11712,
  [11713] = 11250,
  [11714] = 11282,
  [11715] = 4367,
  [11716] = 4381,
  [11717] = 5352,
  [11718] = 4264,
  [11719] = 11251,
  [11720] = 11460,
  [11721] = 11460,
  [11722] = 11460,
  [11723] = 11460,
  [11724] = 11460,
  [11725] = 11460,
  [11726] = 11460,
  [11727] = 11460,
  [11728] = 11460,
  [11729] = 11460,
  [11730] = 11460,
  [11731] = 11460,
  [11732] = 11460,
  [11733] = 11460,
  [11734] = 11460,
  [11735] = 11460,
  [11736] = 11460,
  [11737] = 11460,
  [11738] = 11460,
  [11739] = 11460,
  [11740] = 11460,
  [11741] = 11460,
  [11742] = 11460,
  [11743] = 11460,
  [11744] = 11460,
  [11745] = 11460,
  [11746] = 11460,
  [11747] = 11460,
  [11748] = 11460,
  [11749] = 11460,
  [11750] = 11460,
  [11751] = 11460,
  [11752] = 11460,
  [11753] = 11460,
  [11754] = 11460,
  [11755] = 11460,
  [11756] = 11460,
  [11757] = 11460,
  [11758] = 11460,
  [11759] = 11460,
  [11760] = 11460,
  [11761] = 11460,
  [11762] = 11460,
  [11763] = 11460,
  [11764] = 11460,
  [11765] = 11460,
  [11766] = 11460,
  [11767] = 11460,
  [11768] = 11460,
  [11769] = 11460,
  [11770] = 11460,
  [11771] = 11460,
  [11772] = 11460,
  [11773] = 11460,
  [11774] = 11460,
  [11775] = 11460,
  [11776] = 11460,
  [11777] = 11460,
  [11778] = 11460,
  [11779] = 11460,
  [11780] = 11460,
  [11781] = 11460,
  [11782] = 11460,
  [11783] = 11460,
  [11784] = 8589,
  [11785] = 11562,
  [11786] = 11786,
  [11787] = 4353,
  [11788] = 4290,
  [11789] = 11786,
  [11790] = 4386,
  [11791] = 3850,
  [11792] = 11792,
  [11793] = 3852,
  [11794] = 4355,
  [11795] = 11795,
  [11796] = 5356,
  [11797] = 3850,
  [11798] = 3852,
  [11799] = 4268,
  [11800] = 11800,
  [11801] = 4368,
  [11802] = 11802,
  [11803] = 11803,
  [11804] = 4249,
  [11805] = 11805,
  [11806] = 4369,
  [11807] = 4387,
  [11808] = 8434,
  [11809] = 11809,
  [11810] = 4372,
  [11811] = 8476,
  [11812] = 11786,
  [11813] = 11263,
  [11814] = 5359,
  [11815] = 11815,
  [11816] = 4291,
  [11817] = 10920,
  [11818] = 4277,
  [11819] = 4294,
  [11820] = 11786,
  [11821] = 11559,
  [11822] = 11822,
  [11823] = 11786,
  [11824] = 4353,
  [11825] = 5361,
  [11826] = 4353,
  [11827] = 11560,
  [11828] = 11786,
  [11829] = 11786,
  [11830] = 4381,
  [11831] = 11786,
  [11832] = 11786,
  [11833] = 4493,
  [11834] = 11786,
  [11835] = 11786,
  [11836] = 11786,
  [11837] = 4355,
  [11838] = 4245,
  [11839] = 11839,
  [11840] = 11805,
  [11841] = 4368,
  [11842] = 4369,
  [11843] = 11843,
  [11844] = 11844,
  [11845] = 11786,
  [11846] = 11786,
  [11847] = 11847,
  [11848] = 4372,
  [11849] = 11786,
  [11850] = 11573,
  [11851] = 4277,
  [11852] = 11575,
  [11853] = 11786,
  [11854] = 4295,
  [11855] = 4381,
  [11856] = 8589,
  [11857] = 11621,
  [11858] = 11858,
  [11859] = 11859,
  [11860] = 4386,
  [11861] = 11622,
  [11862] = 11623,
  [11863] = 11624,
  [11864] = 8629,
  [11865] = 11625,
  [11866] = 11786,
  [11867] = 11626,
  [11868] = 8541,
  [11869] = 11627,
  [11870] = 4387,
  [11871] = 11871,
  [11872] = 4179,
  [11873] = 4255,
  [11874] = 11627,
  [11875] = 8434,
  [11876] = 11786,
  [11877] = 4355,
  [11878] = 8476,
  [11879] = 11839,
  [11880] = 11786,
  [11881] = 11786,
  [11882] = 8589,
  [11883] = 11565,
  [11884] = 11786,
  [11885] = 4367,
  [11886] = 11839,
  [11887] = 11786,
  [11888] = 11888,
  [11889] = 11786,
  [11890] = 8320,
  [11891] = 11621,
  [11892] = 11622,
  [11893] = 11623,
  [11894] = 11624,
  [11895] = 11625,
  [11896] = 11626,
  [11897] = 8443,
  [11898] = 8560,
  [11899] = 8592,
  [11900] = 8669,
  [11901] = 11578,
  [11902] = 11786,
  [11903] = 11903,
  [11904] = 4291,
  [11905] = 11542,
  [11906] = 11510,
  [11907] = 5352,
  [11908] = 4245,
  [11909] = 4179,
  [11910] = 11786,
  [11911] = 11786,
  [11912] = 11786,
  [11913] = 11786,
  [11914] = 4368,
  [11915] = 11915,
  [11916] = 5354,
  [11917] = 11786,
  [11918] = 11786,
  [11919] = 4367,
  [11920] = 4369,
  [11921] = 11786,
  [11922] = 11786,
  [11923] = 11923,
  [11924] = 11786,
  [11925] = 11843,
  [11926] = 11844,
  [11927] = 11927,
  [11928] = 5414,
  [11929] = 8320,
  [11930] = 5356,
  [11931] = 11931,
  [11932] = 11786,
  [11933] = 8443,
  [11934] = 4290,
  [11935] = 8560,
  [11936] = 4372,
  [11937] = 8592,
  [11938] = 11786,
  [11939] = 8629,
  [11940] = 5359,
  [11941] = 11282,
  [11942] = 8669,
  [11943] = 11786,
  [11944] = 4264,
  [11945] = 11843,
  [11946] = 11786,
  [11947] = 11786,
  [11948] = 4294,
  [11949] = 11551,
  [11950] = 11542,
  [11951] = 4277,
  [11952] = 11952,
  [11953] = 11552,
  [11954] = 11843,
  [11955] = 11786,
  [11956] = 11553,
  [11957] = 11566,
  [11958] = 5361,
  [11959] = 11786,
  [11960] = 11786,
  [11961] = 11844,
  [11962] = 11555,
  [11963] = 11786,
  [11964] = 11786,
  [11965] = 11638,
  [11966] = 4367,
  [11967] = 11510,
  [11968] = 11786,
  [11969] = 11843,
  [11970] = 11844,
  [11971] = 11786,
  [11972] = 5352,
  [11973] = 11786,
  [11974] = 11805,
  [11975] = 11786,
  [11976] = 11976,
  [11977] = 4386,
  [11978] = 5354,
  [11979] = 4353,
  [11980] = 11551,
  [11981] = 11786,
  [11982] = 4387,
  [11983] = 4367,
  [11984] = 5356,
  [11985] = 11552,
  [11986] = 11553,
  [11987] = 8434,
  [11988] = 4264,
  [11989] = 11555,
  [11990] = 11786,
  [11991] = 8476,
  [11992] = 11844,
  [11993] = 4387,
  [11994] = 4372,
  [11995] = 5359,
  [11996] = 11557,
  [11997] = 11786,
  [11998] = 11459,
  [11999] = 11561,
  [12000] = 11263,
  [12001] = 12001,
  [12002] = 11563,
  [12003] = 11564,
  [12004] = 11565,
  [12005] = 4386,
  [12006] = 11566,
  [12007] = 8320,
  [12008] = 8443,
  [12009] = 11567,
  [12010] = 8560,
  [12011] = 11786,
  [12012] = 11568,
  [12013] = 8592,
  [12014] = 8669,
  [12015] = 4277,
  [12016] = 11786,
  [12017] = 11786,
  [12018] = 11786,
  [12019] = 11572,
  [12020] = 4295,
  [12021] = 11786,
  [12022] = 11582,
  [12023] = 4387,
  [12024] = 11822,
  [12025] = 11786,
  [12026] = 4367,
  [12027] = 11786,
  [12028] = 11573,
  [12029] = 11575,
  [12030] = 4264,
  [12031] = 11578,
  [12032] = 11786,
  [12033] = 4179,
  [12034] = 11822,
  [12035] = 11582,
  [12036] = 11802,
  [12037] = 8541,
  [12038] = 12038,
  [12039] = 11786,
  [12040] = 5414,
  [12041] = 4401,
  [12042] = 11786,
  [12043] = 11786,
  [12044] = 11786,
  [12045] = 11786,
  [12046] = 11786,
  [12047] = 4245,
  [12048] = 4478,
  [12049] = 4493,
  [12050] = 11786,
  [12051] = 4368,
  [12052] = 11567,
  [12053] = 11786,
  [12054] = 11803,
  [12055] = 4290,
  [12056] = 12056,
  [12057] = 11786,
  [12058] = 4249,
  [12059] = 4291,
  [12060] = 4401,
  [12061] = 11459,
  [12062] = 4355,
  [12063] = 11786,
  [12064] = 11786,
  [12065] = 4294,
  [12066] = 11282,
  [12067] = 4295,
  [12068] = 11786,
  [12069] = 11859,
  [12070] = 11786,
  [12071] = 11559,
  [12072] = 11560,
  [12073] = 4255,
  [12074] = 11786,
  [12075] = 11786,
  [12076] = 11786,
  [12077] = 11923,
  [12078] = 4179,
  [12079] = 11786,
  [12080] = 4353,
  [12081] = 4381,
  [12082] = 11786,
  [12083] = 4290,
  [12084] = 4386,
  [12085] = 4355,
  [12086] = 11561,
  [12087] = 11562,
  [12088] = 4368,
  [12089] = 11786,
  [12090] = 4369,
  [12091] = 11786,
  [12092] = 4372,
  [12093] = 11563,
  [12094] = 4277,
  [12095] = 4291,
  [12096] = 11786,
  [12097] = 11786,
  [12098] = 4294,
  [12099] = 11786,
  [12100] = 4295,
  [12101] = 11888,
  [12102] = 11564,
  [12103] = 11786,
  [12104] = 12104,
  [12105] = 11786,
  [12106] = 11786,
  [12107] = 11786,
  [12108] = 11568,
  [12109] = 4381,
  [12110] = 11786,
  [12111] = 11786,
  [12112] = 10837,
  [12113] = 11786,
  [12114] = 12114,
  [12115] = 4478,
  [12116] = 11786,
  [12117] = 11786,
  [12118] = 11786,
  [12119] = 11557,
  [12120] = 11786,
  [12121] = 11786,
  [12122] = 11786,
  [12123] = 11786,
  [12124] = 11847,
  [12125] = 11572,
  [12126] = 11786,
  [12127] = 12104,
  [12128] = 11927,
  [12129] = 4249,
  [12130] = 11786,
  [12131] = 11847,
  [12132] = 8589,
  [12133] = 4249,
  [12134] = 11786,
  [12135] = 10886,
  [12136] = 11786,
  [12137] = 11786,
  [12138] = 11786,
  [12139] = 4268,
  [12140] = 11786,
  [12141] = 11786,
  [12142] = 4369,
  [12143] = 12143,
  [12144] = 11786,
  [12145] = 11786,
  [12146] = 11786,
  [12147] = 11786,
  [12148] = 11786,
  [12149] = 8420,
  [12150] = 12150,
  [12151] = 12151,
  [12152] = 12152,
  [12153] = 12153,
  [12154] = 11859,
  [12155] = 11871,
  [12156] = 8541,
  [12157] = 5352,
  [12158] = 11786,
  [12159] = 11786,
  [12160] = 4291,
  [12161] = 8629,
  [12162] = 4294,
  [12163] = 10901,
  [12164] = 4295,
  [12165] = 12165,
  [12166] = 4179,
  [12167] = 12167,
  [12168] = 11786,
  [12169] = 11786,
  [12170] = 5354,
  [12171] = 10668,
  [12172] = 8541,
  [12173] = 5361,
  [12174] = 12174,
  [12175] = 8320,
  [12176] = 8443,
  [12177] = 8560,
  [12178] = 12178,
  [12179] = 8592,
  [12180] = 8669,
  [12181] = 12178,
  [12182] = 12182,
  [12183] = 12183,
  [12184] = 12184,
  [12185] = 12178,
  [12186] = 12178,
  [12187] = 12178,
  [12188] = 4386,
  [12189] = 12178,
  [12190] = 12178,
  [12191] = 12191,
  [12192] = 12178,
  [12193] = 4245,
  [12194] = 4387,
  [12195] = 12195,
  [12196] = 12178,
  [12197] = 12178,
  [12198] = 4268,
  [12199] = 12183,
  [12200] = 12184,
  [12201] = 12178,
  [12202] = 12191,
  [12203] = 12178,
  [12204] = 4401,
  [12205] = 11263,
  [12206] = 12206,
  [12207] = 12178,
  [12208] = 12178,
  [12209] = 12178,
  [12210] = 12210,
  [12211] = 12178,
  [12212] = 12212,
  [12213] = 12178,
  [12214] = 12178,
  [12215] = 4249,
  [12216] = 12178,
  [12217] = 12178,
  [12218] = 11915,
  [12219] = 12178,
  [12220] = 12220,
  [12221] = 12178,
  [12222] = 12178,
  [12223] = 12183,
  [12224] = 12183,
  [12225] = 12178,
  [12226] = 12184,
  [12227] = 4268,
  [12228] = 12228,
  [12229] = 12178,
  [12230] = 4353,
  [12231] = 12178,
  [12232] = 4381,
  [12233] = 4355,
  [12234] = 12178,
  [12235] = 4368,
  [12236] = 12178,
  [12237] = 4369,
  [12238] = 12178,
  [12239] = 4372,
  [12240] = 12178,
  [12241] = 4277,
  [12242] = 12178,
  [12243] = 12243,
  [12244] = 12178,
  [12245] = 12178,
  [12246] = 12178,
  [12247] = 12183,
  [12248] = 12184,
  [12249] = 12178,
  [12250] = 12178,
  [12251] = 11809,
  [12252] = 12183,
  [12253] = 12178,
  [12254] = 12178,
  [12255] = 12178,
  [12256] = 12184,
  [12257] = 12257,
  [12258] = 12178,
  [12259] = 8541,
  [12260] = 5332,
  [12261] = 12178,
  [12262] = 12178,
  [12263] = 12183,
  [12264] = 12178,
  [12265] = 12184,
  [12266] = 12178,
  [12267] = 4401,
  [12268] = 12178,
  [12269] = 4386,
  [12270] = 12178,
  [12271] = 4387,
  [12272] = 12178,
  [12273] = 12178,
  [12274] = 12274,
  [12275] = 12178,
  [12276] = 12178,
  [12277] = 12277,
  [12278] = 12183,
  [12279] = 12184,
  [12280] = 12178,
  [12281] = 12178,
  [12282] = 12178,
  [12283] = 12178,
  [12284] = 12178,
  [12285] = 8476,
  [12286] = 12178,
  [12287] = 12257,
  [12288] = 12178,
  [12289] = 12178,
  [12290] = 4249,
  [12291] = 12184,
  [12292] = 12178,
  [12293] = 12228,
  [12294] = 12294,
  [12295] = 12295,
  [12296] = 12296,
  [12297] = 12297,
  [12298] = 12257,
  [12299] = 12184,
  [12300] = 4826,
  [12301] = 12301,
  [12302] = 12178,
  [12303] = 4895,
  [12304] = 4353,
  [12305] = 4381,
  [12306] = 4355,
  [12307] = 4368,
  [12308] = 4369,
  [12309] = 4372,
  [12310] = 4277,
  [12311] = 12311,
  [12312] = 12312,
  [12313] = 12184,
  [12314] = 12174,
  [12315] = 12178,
  [12316] = 4264,
  [12317] = 12191,
  [12318] = 12318,
  [12319] = 12206,
  [12320] = 4268,
  [12321] = 12318,
  [12322] = 12183,
  [12323] = 12323,
  [12324] = 4257,
  [12325] = 12228,
  [12326] = 4264,
  [12327] = 12184,
  [12328] = 12178,
  [12329] = 4257,
  [12330] = 7263,
  [12331] = 12184,
  [12332] = 12178,
  [12333] = 11510,
  [12334] = 12206,
  [12335] = 4245,
  [12336] = 12178,
  [12337] = 3850,
  [12338] = 12178,
  [12339] = 4245,
  [12340] = 12206,
  [12341] = 3852,
  [12342] = 12206,
  [12343] = 12343,
  [12344] = 12174,
  [12345] = 4464,
  [12346] = 12206,
  [12347] = 12178,
  [12348] = 12206,
  [12349] = 12183,
  [12350] = 12206,
  [12351] = 4386,
  [12352] = 12184,
  [12353] = 12353,
  [12354] = 12178,
  [12355] = 12355,
  [12356] = 8397,
  [12357] = 12206,
  [12358] = 12183,
  [12359] = 12359,
  [12360] = 4387,
  [12361] = 12361,
  [12362] = 12362,
  [12363] = 12301,
  [12364] = 4291,
  [12365] = 4294,
  [12366] = 4295,
  [12367] = 12178,
  [12368] = 12206,
  [12369] = 4401,
  [12370] = 12184,
  [12371] = 4179,
  [12372] = 4465,
  [12373] = 12206,
  [12374] = 11282,
  [12375] = 12178,
  [12376] = 12178,
  [12377] = 4291,
  [12378] = 4294,
  [12379] = 12206,
  [12380] = 4295,
  [12381] = 12353,
  [12382] = 4179,
  [12383] = 5352,
  [12384] = 11542,
  [12385] = 3850,
  [12386] = 12206,
  [12387] = 3852,
  [12388] = 5354,
  [12389] = 12206,
  [12390] = 3850,
  [12391] = 12183,
  [12392] = 3852,
  [12393] = 12184,
  [12394] = 5356,
  [12395] = 11621,
  [12396] = 4249,
  [12397] = 12178,
  [12398] = 12206,
  [12399] = 5359,
  [12400] = 5361,
  [12401] = 12174,
  [12402] = 12206,
  [12403] = 4427,
  [12404] = 12178,
  [12405] = 12206,
  [12406] = 12178,
  [12407] = 10901,
  [12408] = 12174,
  [12409] = 12206,
  [12410] = 11551,
  [12411] = 12183,
  [12412] = 3850,
  [12413] = 3852,
  [12414] = 12414,
  [12415] = 12415,
  [12416] = 12355,
  [12417] = 12206,
  [12418] = 11552,
  [12419] = 11553,
  [12420] = 12312,
  [12421] = 12183,
  [12422] = 12184,
  [12423] = 5414,
  [12424] = 12206,
  [12425] = 12184,
  [12426] = 12178,
  [12427] = 11555,
  [12428] = 12206,
  [12429] = 12206,
  [12430] = 12183,
  [12431] = 12431,
  [12432] = 12184,
  [12433] = 12178,
  [12434] = 4401,
  [12435] = 4895,
  [12436] = 12178,
  [12437] = 12206,
  [12438] = 12257,
  [12439] = 12178,
  [12440] = 10886,
  [12441] = 12206,
  [12442] = 11557,
  [12443] = 11459,
  [12444] = 10668,
  [12445] = 12206,
  [12446] = 11561,
  [12447] = 11562,
  [12448] = 12206,
  [12449] = 11563,
  [12450] = 12206,
  [12451] = 12183,
  [12452] = 12206,
  [12453] = 11564,
  [12454] = 11565,
  [12455] = 12178,
  [12456] = 11566,
  [12457] = 12206,
  [12458] = 12184,
  [12459] = 11567,
  [12460] = 12206,
  [12461] = 11568,
  [12462] = 12206,
  [12463] = 12206,
  [12464] = 4367,
  [12465] = 11572,
  [12466] = 12206,
  [12467] = 12178,
  [12468] = 12323,
  [12469] = 12206,
  [12470] = 12178,
  [12471] = 11627,
  [12472] = 11573,
  [12473] = 12206,
  [12474] = 11575,
  [12475] = 11627,
  [12476] = 11578,
  [12477] = 11582,
  [12478] = 12206,
  [12479] = 4245,
  [12480] = 12206,
  [12481] = 12206,
  [12482] = 10920,
  [12483] = 12206,
  [12484] = 12178,
  [12485] = 12206,
  [12486] = 11621,
  [12487] = 7363,
  [12488] = 12206,
  [12489] = 12206,
  [12490] = 11622,
  [12491] = 11623,
  [12492] = 11624,
  [12493] = 11625,
  [12494] = 11626,
  [12495] = 12206,
  [12496] = 12178,
  [12497] = 12206,
  [12498] = 11621,
  [12499] = 11510,
  [12500] = 12206,
  [12501] = 11622,
  [12502] = 11623,
  [12503] = 11624,
  [12504] = 11625,
  [12505] = 11626,
  [12506] = 12206,
  [12507] = 11622,
  [12508] = 11623,
  [12509] = 8589,
  [12510] = 12206,
  [12511] = 12183,
  [12512] = 12184,
  [12513] = 12178,
  [12514] = 12206,
  [12515] = 11542,
  [12516] = 12206,
  [12517] = 11282,
  [12518] = 12312,
  [12519] = 12206,
  [12520] = 12414,
  [12521] = 12415,
  [12522] = 12206,
  [12523] = 11624,
  [12524] = 12206,
  [12525] = 4401,
  [12526] = 12178,
  [12527] = 12178,
  [12528] = 4279,
  [12529] = 12206,
  [12530] = 12183,
  [12531] = 12184,
  [12532] = 11625,
  [12533] = 12206,
  [12534] = 4464,
  [12535] = 12206,
  [12536] = 11263,
  [12537] = 12206,
  [12538] = 12206,
  [12539] = 12206,
  [12540] = 12206,
  [12541] = 12541,
  [12542] = 12206,
  [12543] = 12178,
  [12544] = 12206,
  [12545] = 12257,
  [12546] = 12206,
  [12547] = 12220,
  [12548] = 12206,
  [12549] = 12206,
  [12550] = 12206,
  [12551] = 11559,
  [12552] = 11560,
  [12553] = 4465,
  [12554] = 12178,
  [12555] = 4381,
  [12556] = 11626,
  [12557] = 4268,
  [12558] = 4427,
  [12559] = 12559,
  [12560] = 12560,
  [12561] = 4264,
  [12562] = 12178,
  [12563] = 12178,
  [12564] = 12183,
  [12565] = 12184,
  [12566] = 12183,
  [12567] = 12183,
  [12568] = 12178,
  [12569] = 12178,
  [12570] = 12257,
  [12571] = 12184,
  [12572] = 12178,
  [12573] = 12178,
  [12574] = 12184,
  [12575] = 12178,
  [12576] = 12311,
  [12577] = 11551,
  [12578] = 12178,
  [12579] = 8629,
  [12580] = 11552,
  [12581] = 11553,
  [12582] = 12178,
  [12583] = 11555,
  [12584] = 4386,
  [12585] = 11952,
  [12586] = 12178,
  [12587] = 4464,
  [12588] = 4387,
  [12589] = 12178,
  [12590] = 12183,
  [12591] = 5399,
  [12592] = 12184,
  [12593] = 12178,
  [12594] = 11557,
  [12595] = 11459,
  [12596] = 4465,
  [12597] = 12178,
  [12598] = 5803,
  [12599] = 11561,
  [12600] = 11562,
  [12601] = 5805,
  [12602] = 5806,
  [12603] = 11563,
  [12604] = 12178,
  [12605] = 12183,
  [12606] = 11564,
  [12607] = 12184,
  [12608] = 12178,
  [12609] = 11565,
  [12610] = 11566,
  [12611] = 4427,
  [12612] = 11567,
  [12613] = 11568,
  [12614] = 12178,
  [12615] = 12178,
  [12616] = 12178,
  [12617] = 11572,
  [12618] = 12178,
  [12619] = 5414,
  [12620] = 8434,
  [12621] = 12174,
  [12622] = 12178,
  [12623] = 11573,
  [12624] = 11575,
  [12625] = 12195,
  [12626] = 11578,
  [12627] = 12183,
  [12628] = 12184,
  [12629] = 12178,
  [12630] = 4367,
  [12631] = 11582,
  [12632] = 12178,
  [12633] = 12178,
  [12634] = 12277,
  [12635] = 12178,
  [12636] = 12183,
  [12637] = 12184,
  [12638] = 12178,
  [12639] = 12206,
  [12640] = 11627,
  [12641] = 4355,
  [12642] = 12431,
  [12643] = 4368,
  [12644] = 5356,
  [12645] = 4369,
  [12646] = 5352,
  [12647] = 12647,
  [12648] = 4372,
  [12649] = 4277,
  [12650] = 11542,
  [12651] = 12651,
  [12652] = 4401,
  [12653] = 12174,
  [12654] = 12654,
  [12655] = 5359,
  [12656] = 12647,
  [12657] = 4464,
  [12658] = 5361,
  [12659] = 5354,
  [12660] = 11627,
  [12661] = 12647,
  [12662] = 12559,
  [12663] = 5414,
  [12664] = 12664,
  [12665] = 12664,
  [12666] = 12666,
  [12667] = 12647,
  [12668] = 5414,
  [12669] = 12174,
  [12670] = 4367,
  [12671] = 4465,
  [12672] = 4249,
  [12673] = 10901,
  [12674] = 5356,
  [12675] = 12647,
  [12676] = 12676,
  [12677] = 5414,
  [12678] = 12174,
  [12679] = 12647,
  [12680] = 4291,
  [12681] = 10920,
  [12682] = 4427,
  [12683] = 12647,
  [12684] = 4294,
  [12685] = 12174,
  [12686] = 8320,
  [12687] = 5359,
  [12688] = 12664,
  [12689] = 4387,
  [12690] = 8443,
  [12691] = 4268,
  [12692] = 12647,
  [12693] = 4295,
  [12694] = 8560,
  [12695] = 8592,
  [12696] = 8669,
  [12697] = 5361,
  [12698] = 12698,
  [12699] = 12664,
  [12700] = 12647,
  [12701] = 12174,
  [12702] = 4249,
  [12703] = 4268,
  [12704] = 11555,
  [12705] = 12705,
  [12706] = 12647,
  [12707] = 12707,
  [12708] = 12174,
  [12709] = 5134,
  [12710] = 11567,
  [12711] = 4179,
  [12712] = 12664,
  [12713] = 4895,
  [12714] = 12664,
  [12715] = 12647,
  [12716] = 12664,
  [12717] = 12182,
  [12718] = 4353,
  [12719] = 4291,
  [12720] = 4294,
  [12721] = 4295,
  [12722] = 11213,
  [12723] = 4179,
  [12724] = 12647,
  [12725] = 5332,
  [12726] = 4355,
  [12727] = 12727,
  [12728] = 4179,
  [12729] = 11510,
  [12730] = 12647,
  [12731] = 4368,
  [12732] = 4369,
  [12733] = 4464,
  [12734] = 12734,
  [12735] = 4401,
  [12736] = 4372,
  [12737] = 12664,
  [12738] = 12647,
  [12739] = 4277,
  [12740] = 3850,
  [12741] = 3852,
  [12742] = 3850,
  [12743] = 12647,
  [12744] = 3852,
  [12745] = 11551,
  [12746] = 4381,
  [12747] = 4401,
  [12748] = 4290,
  [12749] = 4465,
  [12750] = 12647,
  [12751] = 3850,
  [12752] = 3852,
  [12753] = 11553,
  [12754] = 4295,
  [12755] = 12647,
  [12756] = 12174,
  [12757] = 5741,
  [12758] = 4386,
  [12759] = 5332,
  [12760] = 12647,
  [12761] = 4427,
  [12762] = 12664,
  [12763] = 12664,
  [12764] = 12764,
  [12765] = 11238,
  [12766] = 4387,
  [12767] = 12647,
  [12768] = 12174,
  [12769] = 11573,
  [12770] = 12770,
  [12771] = 12647,
  [12772] = 11621,
  [12773] = 12676,
  [12774] = 11622,
  [12775] = 12647,
  [12776] = 11623,
  [12777] = 11575,
  [12778] = 4268,
  [12779] = 12664,
  [12780] = 12647,
  [12781] = 12781,
  [12782] = 12664,
  [12783] = 12783,
  [12784] = 12647,
  [12785] = 11621,
  [12786] = 11624,
  [12787] = 12664,
  [12788] = 12647,
  [12789] = 4464,
  [12790] = 11622,
  [12791] = 11623,
  [12792] = 12647,
  [12793] = 4353,
  [12794] = 4367,
  [12795] = 4381,
  [12796] = 11559,
  [12797] = 11560,
  [12798] = 12647,
  [12799] = 11578,
  [12800] = 4465,
  [12801] = 11625,
  [12802] = 12647,
  [12803] = 12541,
  [12804] = 12647,
  [12805] = 4367,
  [12806] = 12560,
  [12807] = 12647,
  [12808] = 8629,
  [12809] = 8589,
  [12810] = 12647,
  [12811] = 8589,
  [12812] = 4427,
  [12813] = 12647,
  [12814] = 4355,
  [12815] = 12815,
  [12816] = 12816,
  [12817] = 12647,
  [12818] = 11624,
  [12819] = 11572,
  [12820] = 12647,
  [12821] = 11626,
  [12822] = 12764,
  [12823] = 12647,
  [12824] = 12783,
  [12825] = 4368,
  [12826] = 12647,
  [12827] = 12664,
  [12828] = 4386,
  [12829] = 12666,
  [12830] = 12647,
  [12831] = 12831,
  [12832] = 12647,
  [12833] = 4369,
  [12834] = 12647,
  [12835] = 4401,
  [12836] = 11625,
  [12837] = 11568,
  [12838] = 12838,
  [12839] = 12647,
  [12840] = 5746,
  [12841] = 11542,
  [12842] = 11263,
  [12843] = 11622,
  [12844] = 12647,
  [12845] = 4372,
  [12846] = 8629,
  [12847] = 12647,
  [12848] = 12174,
  [12849] = 4290,
  [12850] = 11621,
  [12851] = 12647,
  [12852] = 11623,
  [12853] = 12174,
  [12854] = 12647,
  [12855] = 4277,
  [12856] = 4294,
  [12857] = 4353,
  [12858] = 12647,
  [12859] = 12647,
  [12860] = 4381,
  [12861] = 4245,
  [12862] = 5352,
  [12863] = 12647,
  [12864] = 4355,
  [12865] = 12647,
  [12866] = 5118,
  [12867] = 5970,
  [12868] = 11557,
  [12869] = 12647,
  [12870] = 5354,
  [12871] = 12647,
  [12872] = 8434,
  [12873] = 8541,
  [12874] = 12874,
  [12875] = 12651,
  [12876] = 12664,
  [12877] = 12647,
  [12878] = 10886,
  [12879] = 5399,
  [12880] = 12647,
  [12881] = 8541,
  [12882] = 11626,
  [12883] = 12647,
  [12884] = 8434,
  [12885] = 12885,
  [12886] = 11551,
  [12887] = 4826,
  [12888] = 12174,
  [12889] = 12664,
  [12890] = 4368,
  [12891] = 12647,
  [12892] = 11552,
  [12893] = 11553,
  [12894] = 8476,
  [12895] = 12647,
  [12896] = 12274,
  [12897] = 10668,
  [12898] = 5356,
  [12899] = 4369,
  [12900] = 12647,
  [12901] = 12783,
  [12902] = 11555,
  [12903] = 5414,
  [12904] = 12664,
  [12905] = 12905,
  [12906] = 8320,
  [12907] = 8320,
  [12908] = 8443,
  [12909] = 8443,
  [12910] = 5359,
  [12911] = 11624,
  [12912] = 8560,
  [12913] = 11459,
  [12914] = 8592,
  [12915] = 8560,
  [12916] = 4245,
  [12917] = 11566,
  [12918] = 11557,
  [12919] = 11459,
  [12920] = 11561,
  [12921] = 8592,
  [12922] = 11562,
  [12923] = 11563,
  [12924] = 8669,
  [12925] = 11564,
  [12926] = 11565,
  [12927] = 11566,
  [12928] = 11561,
  [12929] = 11567,
  [12930] = 8669,
  [12931] = 11568,
  [12932] = 11562,
  [12933] = 4372,
  [12934] = 12174,
  [12935] = 11572,
  [12936] = 5361,
  [12937] = 8589,
  [12938] = 12938,
  [12939] = 11573,
  [12940] = 11575,
  [12941] = 12941,
  [12942] = 11578,
  [12943] = 5352,
  [12944] = 12664,
  [12945] = 12210,
  [12946] = 11582,
  [12947] = 12212,
  [12948] = 11563,
  [12949] = 4277,
  [12950] = 5354,
  [12951] = 12174,
  [12952] = 11582,
  [12953] = 4386,
  [12954] = 5356,
  [12955] = 4387,
  [12956] = 11282,
  [12957] = 11625,
  [12958] = 11564,
  [12959] = 11565,
  [12960] = 12664,
  [12961] = 5359,
  [12962] = 5361,
  [12963] = 12664,
  [12964] = 11263,
  [12965] = 12764,
  [12966] = 12781,
  [12967] = 12764,
  [12968] = 12781,
  [12969] = 12969,
  [12970] = 4367,
  [12971] = 5352,
  [12972] = 8434,
  [12973] = 12294,
  [12974] = 12359,
  [12975] = 12295,
  [12976] = 12764,
  [12977] = 12296,
  [12978] = 12978,
  [12979] = 12361,
  [12980] = 12297,
  [12981] = 12647,
  [12982] = 12362,
  [12983] = 4291,
  [12984] = 4249,
  [12985] = 4294,
  [12986] = 11552,
  [12987] = 5134,
  [12988] = 12174,
  [12989] = 8476,
  [12990] = 12174,
  [12991] = 12651,
  [12992] = 4295,
  [12993] = 12174,
  [12994] = 8541,
  [12995] = 12664,
  [12996] = 12781,
  [12997] = 4249,
  [12998] = 12998,
  [12999] = 8476,
  [13000] = 5354,
  [13001] = 13001,
  [13002] = 4401,
  [13003] = 4895,
  [13004] = 4245,
  [13005] = 11282,
  [13006] = 11510,
  [13007] = 12174,
  [13008] = 13008,
  [13009] = 12664,
  [13010] = 12174,
  [13011] = 7363,
  [13012] = 11626,
  [13013] = 12664,
  [13014] = 12781,
  [13015] = 8397,
  [13016] = 12664,
  [13017] = 5967,
  [13018] = 12664,
  [13019] = 5966,
  [13020] = 4353,
  [13021] = 4179,
  [13022] = 4291,
  [13023] = 4381,
  [13024] = 8629,
  [13025] = 8476,
  [13026] = 11622,
  [13027] = 11623,
  [13028] = 13028,
  [13029] = 13029,
  [13030] = 12816,
  [13031] = 13031,
  [13032] = 5361,
  [13033] = 8541,
  [13034] = 6300,
  [13035] = 11623,
  [13036] = 4465,
  [13037] = 8434,
  [13038] = 13038,
  [13039] = 4249,
  [13040] = 8476,
  [13041] = 8629,
  [13042] = 13042,
  [13043] = 5746,
  [13044] = 11282,
  [13045] = 5354,
  [13046] = 5361,
  [13047] = 8434,
  [13048] = 11551,
  [13049] = 4268,
  [13050] = 8320,
  [13051] = 8443,
  [13052] = 8560,
  [13053] = 8592,
  [13054] = 6434,
  [13055] = 11552,
  [13056] = 8669,
  [13057] = 11553,
  [13058] = 12815,
  [13059] = 4464,
  [13060] = 11624,
  [13061] = 11627,
  [13062] = 5359,
  [13063] = 12174,
  [13064] = 13064,
  [13065] = 11555,
  [13066] = 13066,
  [13067] = 12666,
  [13068] = 5414,
  [13069] = 8476,
  [13070] = 5741,
  [13071] = 12666,
  [13072] = 12666,
  [13073] = 5356,
  [13074] = 4268,
  [13075] = 11282,
  [13076] = 11624,
  [13077] = 8629,
  [13078] = 12831,
  [13079] = 11282,
  [13080] = 11557,
  [13081] = 13081,
  [13082] = 11559,
  [13083] = 11459,
  [13084] = 4427,
  [13085] = 11561,
  [13086] = 11562,
  [13087] = 4291,
  [13088] = 4294,
  [13089] = 11563,
  [13090] = 11626,
  [13091] = 11564,
  [13092] = 11565,
  [13093] = 4353,
  [13094] = 5354,
  [13095] = 11560,
  [13096] = 4295,
  [13097] = 11566,
  [13098] = 11625,
  [13099] = 5118,
  [13100] = 11567,
  [13101] = 11568,
  [13102] = 12174,
  [13103] = 12770,
  [13104] = 11542,
  [13105] = 12676,
  [13106] = 12174,
  [13107] = 13107,
  [13108] = 11263,
  [13109] = 11263,
  [13110] = 11572,
  [13111] = 4381,
  [13112] = 4355,
  [13113] = 4179,
  [13114] = 11625,
  [13115] = 5746,
  [13116] = 8589,
  [13117] = 5361,
  [13118] = 4279,
  [13119] = 12666,
  [13120] = 4401,
  [13121] = 12174,
  [13122] = 5359,
  [13123] = 3850,
  [13124] = 4367,
  [13125] = 5352,
  [13126] = 12905,
  [13127] = 11573,
  [13128] = 13128,
  [13129] = 11575,
  [13130] = 5352,
  [13131] = 11578,
  [13132] = 5414,
  [13133] = 4291,
  [13134] = 5134,
  [13135] = 11582,
  [13136] = 13136,
  [13137] = 4368,
  [13138] = 8541,
  [13139] = 11559,
  [13140] = 11621,
  [13141] = 4245,
  [13142] = 5359,
  [13143] = 4369,
  [13144] = 4294,
  [13145] = 8320,
  [13146] = 8443,
  [13147] = 13147,
  [13148] = 4372,
  [13149] = 5741,
  [13150] = 8541,
  [13151] = 11621,
  [13152] = 12666,
  [13153] = 4295,
  [13154] = 8560,
  [13155] = 8434,
  [13156] = 8592,
  [13157] = 4277,
  [13158] = 8476,
  [13159] = 11551,
  [13160] = 11627,
  [13161] = 11560,
  [13162] = 4367,
  [13163] = 12174,
  [13164] = 13164,
  [13165] = 13165,
  [13166] = 12174,
  [13167] = 8541,
  [13168] = 5356,
  [13169] = 11510,
  [13170] = 11622,
  [13171] = 13164,
  [13172] = 13165,
  [13173] = 11552,
  [13174] = 4386,
  [13175] = 11553,
  [13176] = 11623,
  [13177] = 4387,
  [13178] = 3852,
  [13179] = 8669,
  [13180] = 11542,
  [13181] = 12174,
  [13182] = 4249,
  [13183] = 13183,
  [13184] = 13184,
  [13185] = 5352,
  [13186] = 11555,
  [13187] = 11621,
  [13188] = 5134,
  [13189] = 8589,
  [13190] = 5966,
  [13191] = 8629,
  [13192] = 5967,
  [13193] = 11622,
  [13194] = 11623,
  [13195] = 4264,
  [13196] = 5332,
  [13197] = 5352,
  [13198] = 13198,
  [13199] = 8541,
  [13200] = 5354,
  [13201] = 5361,
  [13202] = 11624,
  [13203] = 12174,
  [13204] = 4353,
  [13205] = 4381,
  [13206] = 13206,
  [13207] = 5354,
  [13208] = 4401,
  [13209] = 11510,
  [13210] = 4355,
  [13211] = 13211,
  [13212] = 8589,
  [13213] = 5356,
  [13214] = 13214,
  [13215] = 4368,
  [13216] = 11625,
  [13217] = 12666,
  [13218] = 4369,
  [13219] = 11557,
  [13220] = 4372,
  [13221] = 11263,
  [13222] = 4367,
  [13223] = 4277,
  [13224] = 10901,
  [13225] = 12174,
  [13226] = 5359,
  [13227] = 11459,
  [13228] = 8629,
  [13229] = 12174,
  [13230] = 13008,
  [13231] = 13164,
  [13232] = 11561,
  [13233] = 13165,
  [13234] = 12666,
  [13235] = 5361,
  [13236] = 12938,
  [13237] = 5414,
  [13238] = 4401,
  [13239] = 11263,
  [13240] = 4291,
  [13241] = 5356,
  [13242] = 11562,
  [13243] = 4249,
  [13244] = 4294,
  [13245] = 13164,
  [13246] = 4295,
  [13247] = 13165,
  [13248] = 11626,
  [13249] = 11563,
  [13250] = 12705,
  [13251] = 5356,
  [13252] = 11582,
  [13253] = 12666,
  [13254] = 11627,
  [13255] = 5966,
  [13256] = 5967,
  [13257] = 11564,
  [13258] = 12174,
  [13259] = 4386,
  [13260] = 11626,
  [13261] = 12941,
  [13262] = 8589,
  [13263] = 11621,
  [13264] = 11565,
  [13265] = 5970,
  [13266] = 8541,
  [13267] = 11566,
  [13268] = 10886,
  [13269] = 10668,
  [13270] = 4353,
  [13271] = 8434,
  [13272] = 11567,
  [13273] = 4381,
  [13274] = 4355,
  [13275] = 12174,
  [13276] = 11568,
  [13277] = 4179,
  [13278] = 4368,
  [13279] = 11624,
  [13280] = 4369,
  [13281] = 12707,
  [13282] = 4401,
  [13283] = 4372,
  [13284] = 8320,
  [13285] = 4277,
  [13286] = 4387,
  [13287] = 8443,
  [13288] = 10920,
  [13289] = 5352,
  [13290] = 11626,
  [13291] = 11622,
  [13292] = 11572,
  [13293] = 5354,
  [13294] = 12666,
  [13295] = 5352,
  [13296] = 8320,
  [13297] = 5354,
  [13298] = 12666,
  [13299] = 8443,
  [13300] = 8560,
  [13301] = 8592,
  [13302] = 8669,
  [13303] = 12874,
  [13304] = 13304,
  [13305] = 5359,
  [13306] = 5356,
  [13307] = 5361,
  [13308] = 11625,
  [13309] = 4179,
  [13310] = 11282,
  [13311] = 8560,
  [13312] = 11573,
  [13313] = 11575,
  [13314] = 8592,
  [13315] = 5359,
  [13316] = 5970,
  [13317] = 11282,
  [13318] = 8669,
  [13319] = 11578,
  [13320] = 12838,
  [13321] = 5354,
  [13322] = 11542,
  [13323] = 11542,
  [13324] = 4387,
  [13325] = 12666,
  [13326] = 11561,
  [13327] = 12174,
  [13328] = 11582,
  [13329] = 11621,
  [13330] = 13330,
  [13331] = 11552,
  [13332] = 12174,
  [13333] = 11553,
  [13334] = 11542,
  [13335] = 11625,
  [13336] = 11625,
  [13337] = 11578,
  [13338] = 4386,
  [13339] = 11562,
  [13340] = 11263,
  [13341] = 13164,
  [13342] = 13165,
  [13343] = 12666,
  [13344] = 12666,
  [13345] = 13164,
  [13346] = 13165,
  [13347] = 12666,
  [13348] = 4353,
  [13349] = 11263,
  [13350] = 13350,
  [13351] = 12666,
  [13352] = 4353,
  [13353] = 4355,
  [13354] = 13038,
  [13355] = 4401,
  [13356] = 11626,
  [13357] = 11582,
  [13358] = 4368,
  [13359] = 11621,
  [13360] = 13164,
  [13361] = 13165,
  [13362] = 4369,
  [13363] = 5361,
  [13364] = 11563,
  [13365] = 13198,
  [13366] = 11624,
  [13367] = 11552,
  [13368] = 12666,
  [13369] = 4372,
  [13370] = 11282,
  [13371] = 13371,
  [13372] = 5359,
  [13373] = 4277,
  [13374] = 13374,
  [13375] = 11568,
  [13376] = 12174,
  [13377] = 11622,
  [13378] = 13107,
  [13379] = 11623,
  [13380] = 11562,
  [13381] = 13381,
  [13382] = 4464,
  [13383] = 13165,
  [13384] = 11564,
  [13385] = 4179,
  [13386] = 13165,
  [13387] = 4368,
  [13388] = 10678,
  [13389] = 11555,
  [13390] = 13164,
  [13391] = 11510,
  [13392] = 13211,
  [13393] = 13128,
  [13394] = 12666,
  [13395] = 13395,
  [13396] = 10673,
  [13397] = 5354,
  [13398] = 11565,
  [13399] = 4294,
  [13400] = 12666,
  [13401] = 11626,
  [13402] = 11566,
  [13403] = 13064,
  [13404] = 8541,
  [13405] = 11565,
  [13406] = 8476,
  [13407] = 4355,
  [13408] = 5359,
  [13409] = 11621,
  [13410] = 4372,
  [13411] = 8476,
  [13412] = 5741,
  [13413] = 11551,
  [13414] = 11567,
  [13415] = 4295,
  [13416] = 5967,
  [13417] = 8589,
  [13418] = 11622,
  [13419] = 11627,
  [13420] = 11623,
  [13421] = 11624,
  [13422] = 11282,
  [13423] = 13165,
  [13424] = 4179,
  [13425] = 13031,
  [13426] = 11459,
  [13427] = 8320,
  [13428] = 11568,
  [13429] = 6300,
  [13430] = 11551,
  [13431] = 11555,
  [13432] = 8443,
  [13433] = 8629,
  [13434] = 5352,
  [13435] = 12666,
  [13436] = 5352,
  [13437] = 11553,
  [13438] = 8560,
  [13439] = 13164,
  [13440] = 5354,
  [13441] = 12666,
  [13442] = 4294,
  [13443] = 11552,
  [13444] = 11573,
  [13445] = 11553,
  [13446] = 4401,
  [13447] = 11282,
  [13448] = 13147,
  [13449] = 12174,
  [13450] = 4826,
  [13451] = 11573,
  [13452] = 13066,
  [13453] = 10921,
  [13454] = 11560,
  [13455] = 11555,
  [13456] = 11562,
  [13457] = 11557,
  [13458] = 4367,
  [13459] = 5356,
  [13460] = 11625,
  [13461] = 11626,
  [13462] = 13206,
  [13463] = 12174,
  [13464] = 8592,
  [13465] = 8589,
  [13466] = 8669,
  [13467] = 10776,
  [13468] = 11622,
  [13469] = 11578,
  [13470] = 5746,
  [13471] = 13164,
  [13472] = 8629,
  [13473] = 8629,
  [13474] = 13164,
  [13475] = 11555,
  [13476] = 5414,
  [13477] = 11563,
  [13478] = 12174,
  [13479] = 12174,
  [13480] = 13480,
  [13481] = 11557,
  [13482] = 12174,
  [13483] = 11459,
  [13484] = 5970,
  [13485] = 12174,
  [13486] = 11561,
  [13487] = 11562,
  [13488] = 13304,
  [13489] = 13136,
  [13490] = 11563,
  [13491] = 8476,
  [13492] = 10809,
  [13493] = 11572,
  [13494] = 10730,
  [13495] = 11564,
  [13496] = 11627,
  [13497] = 11565,
  [13498] = 11621,
  [13499] = 8541,
  [13500] = 11566,
  [13501] = 5361,
  [13502] = 13164,
  [13503] = 11622,
  [13504] = 11567,
  [13505] = 13165,
  [13506] = 13164,
  [13507] = 4493,
  [13508] = 13165,
  [13509] = 11568,
  [13510] = 11623,
  [13511] = 5361,
  [13512] = 5352,
  [13513] = 11566,
  [13514] = 11573,
  [13515] = 8434,
  [13516] = 11627,
  [13517] = 11575,
  [13518] = 8434,
  [13519] = 11563,
  [13520] = 4290,
  [13521] = 11564,
  [13522] = 11263,
  [13523] = 11557,
  [13524] = 11557,
  [13525] = 11510,
  [13526] = 5359,
  [13527] = 4465,
  [13528] = 5361,
  [13529] = 13165,
  [13530] = 5356,
  [13531] = 11572,
  [13532] = 11578,
  [13533] = 11564,
  [13534] = 11572,
  [13535] = 8320,
  [13536] = 11551,
  [13537] = 11623,
  [13538] = 11582,
  [13539] = 11565,
  [13540] = 11573,
  [13541] = 13541,
  [13542] = 13164,
  [13543] = 11575,
  [13544] = 8434,
  [13545] = 11578,
  [13546] = 4369,
  [13547] = 8320,
  [13548] = 8443,
  [13549] = 11582,
  [13550] = 8560,
  [13551] = 8592,
  [13552] = 8669,
  [13553] = 12666,
  [13554] = 8443,
  [13555] = 11567,
  [13556] = 4478,
  [13557] = 11510,
  [13558] = 5414,
  [13559] = 4249,
  [13560] = 8560,
  [13561] = 5356,
  [13562] = 10741,
  [13563] = 11575,
  [13564] = 11559,
  [13565] = 11560,
  [13566] = 11282,
  [13567] = 4291,
  [13568] = 13374,
  [13569] = 11572,
  [13570] = 4427,
  [13571] = 13571,
  [13572] = 4367,
  [13573] = 12174,
  [13574] = 13164,
  [13575] = 4401,
  [13576] = 11626,
  [13577] = 13165,
  [13578] = 11625,
  [13579] = 11551,
  [13580] = 4277,
  [13581] = 5354,
  [13582] = 10949,
  [13583] = 11566,
  [13584] = 8592,
  [13585] = 12174,
  [13586] = 13165,
  [13587] = 8541,
  [13588] = 8669,
  [13589] = 4381,
  [13590] = 13028,
  [13591] = 12666,
  [13592] = 11568,
  [13593] = 4826,
  [13594] = 8589,
  [13595] = 10813,
  [13596] = 11459,
  [13597] = 6434,
  [13598] = 11624,
  [13599] = 12174,
  [13600] = 11510,
  [13601] = 11575,
  [13602] = 11459,
  [13603] = 11552,
  [13604] = 12174,
  [13605] = 12174,
  [13606] = 13164,
  [13607] = 11624,
  [13608] = 12666,
  [13609] = 5352,
  [13610] = 13029,
  [13611] = 13165,
  [13612] = 11559,
  [13613] = 11553,
  [13614] = 11542,
  [13615] = 4295,
  [13616] = 5356,
  [13617] = 8541,
  [13618] = 11561,
  [13619] = 11560,
  [13620] = 11561,
  [13621] = 12666,
  [13622] = 13183,
  [13623] = 4291,
  [13624] = 13184,
  [13625] = 12666,
  [13626] = 5966,
  [13627] = 13627,
  [13628] = 11567,
  [13629] = 11559,
  [13630] = 12666,
  [13631] = 5359,
  [13632] = 12666,
  [13633] = 11582,
  [13634] = 11563,
  [13635] = 10921,
  [13636] = 11564,
  [13637] = 3850,
  [13638] = 13164,
  [13639] = 13165,
  [13640] = 13164,
  [13641] = 11565,
  [13642] = 11952,
  [13643] = 3852,
  [13644] = 13644,
  [13645] = 11566,
  [13646] = 13646,
  [13647] = 13647,
  [13648] = 13165,
  [13649] = 13649,
  [13650] = 11542,
  [13651] = 11627,
  [13652] = 13395,
  [13653] = 11621,
  [13654] = 11622,
  [13655] = 11623,
  [13656] = 12666,
  [13657] = 11621,
  [13658] = 11952,
  [13659] = 11567,
  [13660] = 13165,
  [13661] = 11568,
  [13662] = 13330,
  [13663] = 11952,
  [13664] = 11624,
  [13665] = 11542,
  [13666] = 11510,
  [13667] = 12294,
  [13668] = 12295,
  [13669] = 12296,
  [13670] = 12297,
  [13671] = 11625,
  [13672] = 11621,
  [13673] = 12666,
  [13674] = 11952,
  [13675] = 11263,
  [13676] = 13627,
  [13677] = 13164,
  [13678] = 11551,
  [13679] = 11552,
  [13680] = 11553,
  [13681] = 13681,
  [13682] = 13682,
  [13683] = 12666,
  [13684] = 13684,
  [13685] = 11555,
  [13686] = 10949,
  [13687] = 13687,
  [13688] = 11557,
  [13689] = 11459,
  [13690] = 11561,
  [13691] = 11562,
  [13692] = 12885,
  [13693] = 12666,
  [13694] = 11563,
  [13695] = 11559,
  [13696] = 11560,
  [13697] = 11564,
  [13698] = 13165,
  [13699] = 11565,
  [13700] = 13164,
  [13701] = 11566,
  [13702] = 11567,
  [13703] = 13703,
  [13704] = 11568,
  [13705] = 13705,
  [13706] = 10678,
  [13707] = 12666,
  [13708] = 11567,
  [13709] = 11568,
  [13710] = 13165,
  [13711] = 12666,
  [13712] = 11551,
  [13713] = 4245,
  [13714] = 11572,
  [13715] = 11552,
  [13716] = 11553,
  [13717] = 11573,
  [13718] = 11575,
  [13719] = 13719,
  [13720] = 11578,
  [13721] = 11582,
  [13722] = 11555,
  [13723] = 11626,
  [13724] = 11572,
  [13725] = 13725,
  [13726] = 12210,
  [13727] = 12212,
  [13728] = 11626,
  [13729] = 12727,
  [13730] = 12666,
  [13731] = 11557,
  [13732] = 11282,
  [13733] = 12431,
  [13734] = 12666,
  [13735] = 11621,
  [13736] = 5118,
  [13737] = 13737,
  [13738] = 13738,
  [13739] = 11622,
  [13740] = 11623,
  [13741] = 13165,
  [13742] = 13737,
  [13743] = 12359,
  [13744] = 13744,
  [13745] = 11623,
  [13746] = 11624,
  [13747] = 12666,
  [13748] = 12361,
  [13749] = 12362,
  [13750] = 13750,
  [13751] = 11459,
  [13752] = 11625,
  [13753] = 13753,
  [13754] = 13738,
  [13755] = 11557,
  [13756] = 13756,
  [13757] = 11459,
  [13758] = 13758,
  [13759] = 11561,
  [13760] = 11562,
  [13761] = 13761,
  [13762] = 11563,
  [13763] = 11624,
  [13764] = 11510,
  [13765] = 12666,
  [13766] = 5118,
  [13767] = 13164,
  [13768] = 13165,
  [13769] = 11564,
  [13770] = 13164,
  [13771] = 13165,
  [13772] = 13164,
  [13773] = 13165,
  [13774] = 11625,
  [13775] = 13164,
  [13776] = 13165,
  [13777] = 11565,
  [13778] = 11626,
  [13779] = 11263,
  [13780] = 11952,
  [13781] = 11566,
  [13782] = 10673,
  [13783] = 12666,
  [13784] = 11567,
  [13785] = 13785,
  [13786] = 11568,
  [13787] = 11573,
  [13788] = 13480,
  [13789] = 11575,
  [13790] = 10730,
  [13791] = 11622,
  [13792] = 11623,
  [13793] = 11572,
  [13794] = 10741,
  [13795] = 11561,
  [13796] = 11559,
  [13797] = 11560,
  [13798] = 10776,
  [13799] = 13164,
  [13800] = 13165,
  [13801] = 11542,
  [13802] = 4401,
  [13803] = 13164,
  [13804] = 11624,
  [13805] = 11510,
  [13806] = 11562,
  [13807] = 4268,
  [13808] = 13164,
  [13809] = 11625,
  [13810] = 13165,
  [13811] = 13164,
  [13812] = 11578,
  [13813] = 11551,
  [13814] = 11626,
  [13815] = 13164,
  [13816] = 11552,
  [13817] = 11553,
  [13818] = 13350,
  [13819] = 11627,
  [13820] = 11573,
  [13821] = 13381,
  [13822] = 13164,
  [13823] = 11575,
  [13824] = 13165,
  [13825] = 11578,
  [13826] = 11555,
  [13827] = 13761,
  [13828] = 11582,
  [13829] = 13165,
  [13830] = 10809,
  [13831] = 13374,
  [13832] = 10813,
  [13833] = 11622,
  [13834] = 12174,
  [13835] = 13725,
  [13836] = 11459,
  [13837] = 11561,
  [13838] = 11562,
  [13839] = 12816,
  [13840] = 3852,
  [13841] = 13164,
  [13842] = 13842,
  [13843] = 4355,
  [13844] = 11563,
  [13845] = 12666,
  [13846] = 4294,
  [13847] = 11564,
  [13848] = 4368,
  [13849] = 4369,
  [13850] = 13165,
  [13851] = 11565,
  [13852] = 11566,
  [13853] = 13853,
  [13854] = 4372,
  [13855] = 13855,
  [13856] = 11625,
  [13857] = 4277,
  [13858] = 13164,
  [13859] = 11622,
  [13860] = 11510,
  [13861] = 4464,
  [13862] = 12666,
  [13863] = 12174,
  [13864] = 11623,
  [13865] = 13865,
  [13866] = 12174,
  [13867] = 11572,
  [13868] = 11622,
  [13869] = 11623,
  [13870] = 13165,
  [13871] = 11542,
  [13872] = 13785,
  [13873] = 12666,
  [13874] = 13164,
  [13875] = 11624,
  [13876] = 11625,
  [13877] = 13877,
  [13878] = 13878,
  [13879] = 13853,
  [13880] = 4367,
  [13881] = 4826,
  [13882] = 13877,
  [13883] = 11510,
  [13884] = 13884,
  [13885] = 13164,
  [13886] = 13878,
  [13887] = 13165,
  [13888] = 4179,
  [13889] = 5332,
  [13890] = 4249,
  [13891] = 13855,
  [13892] = 13164,
  [13893] = 4401,
  [13894] = 4895,
  [13895] = 11626,
  [13896] = 13896,
  [13897] = 11573,
  [13898] = 11575,
  [13899] = 12174,
  [13900] = 12666,
  [13901] = 11578,
  [13902] = 12666,
  [13903] = 11551,
  [13904] = 11282,
  [13905] = 4381,
  [13906] = 13906,
  [13907] = 12666,
  [13908] = 13164,
  [13909] = 13165,
  [13910] = 13164,
  [13911] = 13165,
  [13912] = 13164,
  [13913] = 13165,
  [13914] = 5332,
  [13915] = 11551,
  [13916] = 13165,
  [13917] = 4291,
  [13918] = 13918,
  [13919] = 4295,
  [13920] = 13164,
  [13921] = 13165,
  [13922] = 13164,
  [13923] = 13165,
  [13924] = 11552,
  [13925] = 11552,
  [13926] = 12666,
  [13927] = 11553,
  [13928] = 13884,
  [13929] = 4386,
  [13930] = 11553,
  [13931] = 13165,
  [13932] = 11555,
  [13933] = 5332,
  [13934] = 13934,
  [13935] = 13935,
  [13936] = 11624,
  [13937] = 13937,
  [13938] = 4478,
  [13939] = 12666,
  [13940] = 13940,
  [13941] = 13719,
  [13942] = 12174,
  [13943] = 4465,
  [13944] = 11621,
  [13945] = 11555,
  [13946] = 13164,
  [13947] = 13842,
  [13948] = 4387,
  [13949] = 13949,
  [13950] = 13750,
  [13951] = 13951,
  [13952] = 13934,
  [13953] = 13165,
  [13954] = 12707,
  [13955] = 13955,
  [13956] = 4493,
  [13957] = 12174,
  [13958] = 11557,
  [13959] = 13959,
  [13960] = 11459,
  [13961] = 13961,
  [13962] = 11561,
  [13963] = 13164,
  [13964] = 13165,
  [13965] = 11562,
  [13966] = 13164,
  [13967] = 13165,
  [13968] = 13968,
  [13969] = 12666,
  [13970] = 13738,
  [13971] = 13971,
  [13972] = 13164,
  [13973] = 13165,
  [13974] = 3850,
  [13975] = 11563,
  [13976] = 11627,
  [13977] = 11564,
  [13978] = 12666,
  [13979] = 13687,
  [13980] = 11565,
  [13981] = 11566,
  [13982] = 13918,
  [13983] = 11567,
  [13984] = 11568,
  [13985] = 13971,
  [13986] = 4427,
  [13987] = 12707,
  [13988] = 3850,
  [13989] = 13989,
  [13990] = 11542,
  [13991] = 11572,
  [13992] = 13682,
  [13993] = 13937,
  [13994] = 3852,
  [13995] = 11626,
  [13996] = 12816,
  [13997] = 11557,
  [13998] = 11573,
  [13999] = 11575,
  [14000] = 13682,
  [14001] = 11578,
  [14002] = 14002,
  [14003] = 11582,
  [14004] = 13738,
  [14005] = 13906,
  [14006] = 4353,
  [14007] = 11621,
  [14008] = 11582,
  [14009] = 13164,
  [14010] = 13955,
  [14011] = 11621,
  [14012] = 13371,
  [14013] = 14013,
  [14014] = 13865,
  [14015] = 14015,
  [14016] = 14016,
  [14017] = 5361,
  [14018] = 13164,
  [14019] = 13165,
  [14020] = 5118,
  [14021] = 12815,
  [14022] = 13164,
  [14023] = 12816,
  [14024] = 5970,
  [14025] = 11625,
  [14026] = 5741,
  [14027] = 14015,
  [14028] = 13164,
  [14029] = 12666,
  [14030] = 14030,
  [14031] = 5361,
  [14032] = 5359,
  [14033] = 8541,
  [14034] = 14015,
  [14035] = 14015,
  [14036] = 14015,
  [14037] = 5352,
  [14038] = 13147,
  [14039] = 5746,
  [14040] = 13855,
  [14041] = 14041,
  [14042] = 12815,
  [14043] = 14043,
  [14044] = 5361,
  [14045] = 14045,
  [14046] = 11626,
  [14047] = 13959,
  [14048] = 5356,
  [14049] = 14015,
  [14050] = 14050,
  [14051] = 5352,
  [14052] = 5967,
  [14053] = 14015,
  [14054] = 5746,
  [14055] = 13165,
  [14056] = 14056,
  [14057] = 5134,
  [14058] = 12705,
  [14059] = 14059,
  [14060] = 8541,
  [14061] = 10886,
  [14062] = 14015,
  [14063] = 14063,
  [14064] = 13842,
  [14065] = 13896,
  [14066] = 14066,
  [14067] = 13147,
  [14068] = 14068,
  [14069] = 14015,
  [14070] = 13884,
  [14071] = 14015,
  [14072] = 10668,
  [14073] = 14015,
  [14074] = 14015,
  [14075] = 14075,
  [14076] = 13165,
  [14077] = 5354,
  [14078] = 8541,
  [14079] = 13541,
  [14080] = 14056,
  [14081] = 5966,
  [14082] = 5967,
  [14083] = 13165,
  [14084] = 5741,
  [14085] = 10901,
  [14086] = 14015,
  [14087] = 5332,
  [14088] = 14015,
  [14089] = 14089,
  [14090] = 5970,
  [14091] = 13164,
  [14092] = 5359,
  [14093] = 13165,
  [14094] = 13164,
  [14095] = 13165,
  [14096] = 13029,
  [14097] = 13571,
  [14098] = 14015,
  [14099] = 13989,
  [14100] = 12705,
  [14101] = 14015,
  [14102] = 5354,
  [14103] = 14015,
  [14104] = 14104,
  [14105] = 13165,
  [14106] = 5966,
  [14107] = 11624,
  [14108] = 14015,
  [14109] = 14015,
  [14110] = 5356,
  [14111] = 14015,
  [14112] = 10920,
  [14113] = 14002,
  [14114] = 14114,
  [14115] = 12705,
  [14116] = 5966,
  [14117] = 13164,
  [14118] = 14118,
  [14119] = 14119,
  [14120] = 14120,
  [14121] = 13937,
  [14122] = 5967,
  [14123] = 12666,
  [14124] = 13961,
  [14125] = 14015,
  [14126] = 14126,
  [14127] = 5970,
  [14128] = 14128,
  [14129] = 14129,
  [14130] = 5352,
  [14131] = 14131,
  [14132] = 14015,
  [14133] = 13029,
  [14134] = 12815,
  [14135] = 13853,
  [14136] = 12705,
  [14137] = 14137,
  [14138] = 14138,
  [14139] = 5354,
  [14140] = 14140,
  [14141] = 5359,
  [14142] = 13949,
  [14143] = 14015,
  [14144] = 13951,
  [14145] = 14015,
  [14146] = 14041,
  [14147] = 11622,
  [14148] = 13937,
  [14149] = 14015,
  [14150] = 14015,
  [14151] = 14114,
  [14152] = 11623,
  [14153] = 13937,
  [14154] = 14154,
  [14155] = 12705,
  [14156] = 5746,
  [14157] = 12707,
  [14158] = 5741,
  [14159] = 14015,
  [14160] = 5356,
  [14161] = 14161,
  [14162] = 13918,
  [14163] = 13164,
  [14164] = 13165,
  [14165] = 13064,
  [14166] = 14166,
  [14167] = 14167,
  [14168] = 14166,
  [14169] = 14169,
  [14170] = 13064,
  [14171] = 14171,
  [14172] = 14166,
  [14173] = 13184,
  [14174] = 14174,
  [14175] = 14166,
  [14176] = 5359,
  [14177] = 14166,
  [14178] = 14137,
  [14179] = 13206,
  [14180] = 14166,
  [14181] = 14181,
  [14182] = 14182,
  [14183] = 14166,
  [14184] = 4895,
  [14185] = 5352,
  [14186] = 14166,
  [14187] = 14013,
  [14188] = 14188,
  [14189] = 14189,
  [14190] = 14190,
  [14191] = 14191,
  [14192] = 14166,
  [14193] = 5361,
  [14194] = 14194,
  [14195] = 14195,
  [14196] = 13031,
  [14197] = 14197,
  [14198] = 14166,
  [14199] = 14199,
  [14200] = 14166,
  [14201] = 14166,
  [14202] = 14202,
  [14203] = 13684,
  [14204] = 14166,
  [14205] = 14166,
  [14206] = 14206,
  [14207] = 14207,
  [14208] = 14166,
  [14209] = 14209,
  [14210] = 14210,
  [14211] = 14166,
  [14212] = 13028,
  [14213] = 13029,
  [14214] = 12666,
  [14215] = 14166,
  [14216] = 14216,
  [14217] = 14217,
  [14218] = 14218,
  [14219] = 14219,
  [14220] = 14199,
  [14221] = 14166,
  [14222] = 14202,
  [14223] = 14166,
  [14224] = 14224,
  [14225] = 14225,
  [14226] = 14226,
  [14227] = 14166,
  [14228] = 14166,
  [14229] = 12666,
  [14230] = 14161,
  [14231] = 5966,
  [14232] = 5967,
  [14233] = 14166,
  [14234] = 14209,
  [14235] = 14166,
  [14236] = 14236,
  [14237] = 13136,
  [14238] = 14238,
  [14239] = 14239,
  [14240] = 14240,
  [14241] = 14241,
  [14242] = 14224,
  [14243] = 14243,
  [14244] = 14166,
  [14245] = 14030,
  [14246] = 14166,
  [14247] = 14247,
  [14248] = 14248,
  [14249] = 14210,
  [14250] = 4826,
  [14251] = 4401,
  [14252] = 5970,
  [14253] = 4427,
  [14254] = 14254,
  [14255] = 14171,
  [14256] = 14206,
  [14257] = 14257,
  [14258] = 5354,
  [14259] = 14218,
  [14260] = 13164,
  [14261] = 14261,
  [14262] = 13165,
  [14263] = 14263,
  [14264] = 14166,
  [14265] = 14265,
  [14266] = 14266,
  [14267] = 14267,
  [14268] = 14268,
  [14269] = 13147,
  [14270] = 12666,
  [14271] = 14271,
  [14272] = 14272,
  [14273] = 14273,
  [14274] = 14274,
  [14275] = 14154,
  [14276] = 14276,
  [14277] = 14277,
  [14278] = 14278,
  [14279] = 14166,
  [14280] = 14166,
  [14281] = 13128,
  [14282] = 14217,
  [14283] = 13136,
  [14284] = 13164,
  [14285] = 13165,
  [14286] = 14286,
  [14287] = 14120,
  [14288] = 14166,
  [14289] = 14289,
  [14290] = 14240,
  [14291] = 14291,
  [14292] = 14166,
  [14293] = 14293,
  [14294] = 14294,
  [14295] = 14295,
  [14296] = 14296,
  [14297] = 14297,
  [14298] = 14298,
  [14299] = 14166,
  [14300] = 13206,
  [14301] = 14301,
  [14302] = 14302,
  [14303] = 14303,
  [14304] = 14166,
  [14305] = 14166,
  [14306] = 14166,
  [14307] = 14166,
  [14308] = 14131,
  [14309] = 14140,
  [14310] = 14219,
  [14311] = 14311,
  [14312] = 14312,
  [14313] = 14313,
  [14314] = 14314,
  [14315] = 14286,
  [14316] = 14166,
  [14317] = 14166,
  [14318] = 14166,
  [14319] = 14319,
  [14320] = 14320,
  [14321] = 14043,
  [14322] = 14322,
  [14323] = 14322,
  [14324] = 14166,
  [14325] = 14325,
  [14326] = 14326,
  [14327] = 14327,
  [14328] = 14328,
  [14329] = 14329,
  [14330] = 14330,
  [14331] = 14331,
  [14332] = 14332,
  [14333] = 14320,
  [14334] = 14334,
  [14335] = 14166,
  [14336] = 14207,
  [14337] = 13164,
  [14338] = 13165,
  [14339] = 14339,
  [14340] = 14340,
  [14341] = 13128,
  [14342] = 14166,
  [14343] = 14343,
  [14344] = 14344,
  [14345] = 14345,
  [14346] = 13164,
  [14347] = 13165,
  [14348] = 14348,
  [14349] = 14166,
  [14350] = 13028,
  [14351] = 14166,
  [14352] = 14059,
  [14353] = 5741,
  [14354] = 14354,
  [14355] = 14166,
  [14356] = 8541,
  [14357] = 14166,
  [14358] = 14358,
  [14359] = 14359,
  [14360] = 14360,
  [14361] = 14361,
  [14362] = 14166,
  [14363] = 14363,
  [14364] = 14364,
  [14365] = 13955,
  [14366] = 14366,
  [14367] = 14063,
  [14368] = 14368,
  [14369] = 14166,
  [14370] = 14166,
  [14371] = 14166,
  [14372] = 14360,
  [14373] = 14066,
  [14374] = 14374,
  [14375] = 14375,
  [14376] = 14376,
  [14377] = 14377,
  [14378] = 14378,
  [14379] = 14379,
  [14380] = 14380,
  [14381] = 13031,
  [14382] = 14166,
  [14383] = 4465,
  [14384] = 5746,
  [14385] = 14385,
  [14386] = 14166,
  [14387] = 14243,
  [14388] = 14166,
  [14389] = 14389,
  [14390] = 13028,
  [14391] = 4464,
  [14392] = 5356,
  [14393] = 14393,
  [14394] = 14166,
  [14395] = 14395,
  [14396] = 14396,
  [14397] = 14397,
  [14398] = 14166,
  [14399] = 14166,
  [14400] = 14400,
  [14401] = 14128,
  [14402] = 4464,
  [14403] = 4465,
  [14404] = 14271,
  [14405] = 14405,
  [14406] = 4427,
  [14407] = 14166,
  [14408] = 14273,
  [14409] = 14238,
  [14410] = 12666,
  [14411] = 14411,
  [14412] = 14166,
  [14413] = 14166,
  [14414] = 13184,
  [14415] = 14415,
  [14416] = 14416,
  [14417] = 14166,
  [14418] = 14418,
  [14419] = 14419,
  [14420] = 14420,
  [14421] = 14421,
  [14422] = 14422,
  [14423] = 13381,
  [14424] = 14424,
  [14425] = 14425,
  [14426] = 14426,
  [14427] = 14427,
  [14428] = 14422,
  [14429] = 14348,
  [14430] = 13627,
  [14431] = 14361,
  [14432] = 14432,
  [14433] = 14418,
  [14434] = 14434,
  [14435] = 14427,
  [14436] = 14421,
  [14437] = 14437,
  [14438] = 14380,
  [14439] = 14421,
  [14440] = 14418,
  [14441] = 14422,
  [14442] = 14194,
  [14443] = 14393,
  [14444] = 14225,
  [14445] = 14421,
  [14446] = 14432,
  [14447] = 14263,
  [14448] = 14239,
  [14449] = 14427,
  [14450] = 14427,
  [14451] = 14451,
  [14452] = 14422,
  [14453] = 14437,
  [14454] = 14224,
  [14455] = 14395,
  [14456] = 14400,
  [14457] = 14422,
  [14458] = 13719,
  [14459] = 14167,
  [14460] = 14432,
  [14461] = 14422,
  [14462] = 14422,
  [14463] = 14463,
  [14464] = 14422,
  [14465] = 14465,
  [14466] = 14421,
  [14467] = 14421,
  [14468] = 14427,
  [14469] = 14469,
  [14470] = 14276,
  [14471] = 14238,
  [14472] = 14422,
  [14473] = 14298,
  [14474] = 14425,
  [14475] = 14437,
  [14476] = 14476,
  [14477] = 14425,
  [14478] = 14478,
  [14479] = 14427,
  [14480] = 14480,
  [14481] = 14481,
  [14482] = 14482,
  [14483] = 14218,
  [14484] = 14427,
  [14485] = 14425,
  [14486] = 14418,
  [14487] = 14226,
  [14488] = 14418,
  [14489] = 14489,
  [14490] = 14320,
  [14491] = 14491,
  [14492] = 5134,
  [14493] = 14432,
  [14494] = 14210,
  [14495] = 14437,
  [14496] = 14343,
  [14497] = 14432,
  [14498] = 14427,
  [14499] = 14195,
  [14500] = 14427,
  [14501] = 14501,
  [14502] = 14326,
  [14503] = 14328,
  [14504] = 14334,
  [14505] = 14358,
  [14506] = 14437,
  [14507] = 14425,
  [14508] = 14508,
  [14509] = 14509,
  [14510] = 14437,
  [14511] = 14340,
  [14512] = 14375,
  [14513] = 14422,
  [14514] = 14437,
  [14515] = 13480,
  [14516] = 14426,
  [14517] = 14478,
  [14518] = 13935,
  [14519] = 14422,
  [14520] = 14424,
  [14521] = 14421,
  [14522] = 14425,
  [14523] = 14432,
  [14524] = 14320,
  [14525] = 14418,
  [14526] = 14437,
  [14527] = 14422,
  [14528] = 14385,
  [14529] = 14421,
  [14530] = 14427,
  [14531] = 14418,
  [14532] = 14432,
  [14533] = 14216,
  [14534] = 14427,
  [14535] = 14418,
  [14536] = 14432,
  [14537] = 14427,
  [14538] = 14469,
  [14539] = 14421,
  [14540] = 14540,
  [14541] = 14541,
  [14542] = 14301,
  [14543] = 14543,
  [14544] = 14207,
  [14545] = 14182,
  [14546] = 14546,
  [14547] = 14425,
  [14548] = 14418,
  [14549] = 14549,
  [14550] = 14432,
  [14551] = 14551,
  [14552] = 14552,
  [14553] = 14247,
  [14554] = 14421,
  [14555] = 14248,
  [14556] = 14427,
  [14557] = 14422,
  [14558] = 14261,
  [14559] = 14559,
  [14560] = 14421,
  [14561] = 14421,
  [14562] = 14463,
  [14563] = 14265,
  [14564] = 14437,
  [14565] = 14540,
  [14566] = 14422,
  [14567] = 14421,
  [14568] = 14272,
  [14569] = 14422,
  [14570] = 14540,
  [14571] = 14540,
  [14572] = 14427,
  [14573] = 14427,
  [14574] = 14469,
  [14575] = 14427,
  [14576] = 14576,
  [14577] = 14418,
  [14578] = 14421,
  [14579] = 14579,
  [14580] = 14418,
  [14581] = 14427,
  [14582] = 14427,
  [14583] = 14427,
  [14584] = 14432,
  [14585] = 14437,
  [14586] = 14425,
  [14587] = 14421,
  [14588] = 14425,
  [14589] = 14422,
  [14590] = 14268,
  [14591] = 14540,
  [14592] = 14540,
  [14593] = 14422,
  [14594] = 14325,
  [14595] = 14437,
  [14596] = 14596,
  [14597] = 14236,
  [14598] = 14241,
  [14599] = 14278,
  [14600] = 14267,
  [14601] = 14322,
  [14602] = 14294,
  [14603] = 14603,
  [14604] = 14274,
  [14605] = 14422,
  [14606] = 14425,
  [14607] = 14422,
  [14608] = 14289,
  [14609] = 14425,
  [14610] = 14329,
  [14611] = 14291,
  [14612] = 14330,
  [14613] = 14427,
  [14614] = 14418,
  [14615] = 14437,
  [14616] = 14432,
  [14617] = 14617,
  [14618] = 14437,
  [14619] = 14331,
  [14620] = 5118,
  [14621] = 14621,
  [14622] = 14332,
  [14623] = 14437,
  [14624] = 14437,
  [14625] = 14059,
  [14626] = 14626,
  [14627] = 14422,
  [14628] = 14293,
  [14629] = 14296,
  [14630] = 14206,
  [14631] = 14418,
  [14632] = 14432,
  [14633] = 14633,
  [14634] = 14634,
  [14635] = 14327,
  [14636] = 14540,
  [14637] = 14421,
  [14638] = 14295,
  [14639] = 14422,
  [14640] = 14432,
  [14641] = 13719,
  [14642] = 14421,
  [14643] = 14540,
  [14644] = 14421,
  [14645] = 14422,
  [14646] = 14425,
  [14647] = 14418,
  [14648] = 14432,
  [14649] = 14359,
  [14650] = 14650,
  [14651] = 14418,
  [14652] = 14421,
  [14653] = 14425,
  [14654] = 14654,
  [14655] = 14451,
  [14656] = 14422,
  [14657] = 14421,
  [14658] = 14421,
  [14659] = 14659,
  [14660] = 14540,
  [14661] = 14432,
  [14662] = 14432,
  [14663] = 14540,
  [14664] = 14277,
  [14665] = 14665,
  [14666] = 14418,
  [14667] = 14421,
  [14668] = 14418,
  [14669] = 14540,
  [14670] = 14432,
  [14671] = 14188,
  [14672] = 14421,
  [14673] = 14363,
  [14674] = 14674,
  [14675] = 14421,
  [14676] = 14366,
  [14677] = 14206,
  [14678] = 14374,
  [14679] = 14364,
  [14680] = 14680,
  [14681] = 14422,
  [14682] = 14427,
  [14683] = 14218,
  [14684] = 14425,
  [14685] = 14368,
  [14686] = 14540,
  [14687] = 14540,
  [14688] = 14421,
  [14689] = 14491,
  [14690] = 14427,
  [14691] = 14540,
  [14692] = 14377,
  [14693] = 14540,
  [14694] = 14302,
  [14695] = 14695,
  [14696] = 14696,
  [14697] = 14397,
  [14698] = 14405,
  [14699] = 14376,
  [14700] = 14425,
  [14701] = 14427,
  [14702] = 14420,
  [14703] = 14437,
  [14704] = 14379,
  [14705] = 14425,
  [14706] = 14427,
  [14707] = 14540,
  [14708] = 14418,
  [14709] = 14432,
  [14710] = 14437,
  [14711] = 14421,
  [14712] = 14634,
  [14713] = 14713,
  [14714] = 14303,
  [14715] = 14437,
  [14716] = 14311,
  [14717] = 14540,
  [14718] = 14181,
  [14719] = 14422,
  [14720] = 14425,
  [14721] = 14425,
  [14722] = 3850,
  [14723] = 14723,
  [14724] = 14313,
  [14725] = 3852,
  [14726] = 14427,
  [14727] = 14339,
  [14728] = 14540,
  [14729] = 13350,
  [14730] = 14730,
  [14731] = 14354,
  [14732] = 14732,
  [14733] = 14733,
  [14734] = 14734,
  [14735] = 14735,
  [14736] = 14736,
  [14737] = 14737,
  [14738] = 14732,
  [14739] = 14733,
  [14740] = 14734,
  [14741] = 14741,
  [14742] = 14735,
  [14743] = 14737,
  [14744] = 14733,
  [14745] = 14734,
  [14746] = 14735,
  [14747] = 14737,
  [14748] = 14734,
  [14749] = 14749,
  [14750] = 14750,
  [14751] = 14733,
  [14752] = 14733,
  [14753] = 14734,
  [14754] = 14754,
  [14755] = 14735,
  [14756] = 14737,
  [14757] = 14733,
  [14758] = 14734,
  [14759] = 14734,
  [14760] = 14735,
  [14761] = 14737,
  [14762] = 14735,
  [14763] = 14732,
  [14764] = 14733,
  [14765] = 14734,
  [14766] = 14735,
  [14767] = 14737,
  [14768] = 14734,
  [14769] = 14733,
  [14770] = 14770,
  [14771] = 14771,
  [14772] = 14734,
  [14773] = 14735,
  [14774] = 14737,
  [14775] = 14737,
  [14776] = 14734,
  [14777] = 14735,
  [14778] = 14733,
  [14779] = 14734,
  [14780] = 14734,
  [14781] = 14781,
  [14782] = 14735,
  [14783] = 14737,
  [14784] = 14770,
  [14785] = 14737,
  [14786] = 14733,
  [14787] = 14787,
  [14788] = 14734,
  [14789] = 14735,
  [14790] = 14737,
  [14791] = 14749,
  [14792] = 14771,
  [14793] = 14733,
  [14794] = 14733,
  [14795] = 14770,
  [14796] = 14734,
  [14797] = 14771,
  [14798] = 14735,
  [14799] = 14737,
  [14800] = 14800,
  [14801] = 14801,
  [14802] = 14733,
  [14803] = 14735,
  [14804] = 14734,
  [14805] = 14735,
  [14806] = 14737,
  [14807] = 14735,
  [14808] = 14808,
  [14809] = 14733,
  [14810] = 14734,
  [14811] = 14735,
  [14812] = 14733,
  [14813] = 14737,
  [14814] = 14741,
  [14815] = 14815,
  [14816] = 14733,
  [14817] = 14734,
  [14818] = 14735,
  [14819] = 14737,
  [14820] = 14734,
  [14821] = 14733,
  [14822] = 14749,
  [14823] = 14734,
  [14824] = 14735,
  [14825] = 14735,
  [14826] = 14737,
  [14827] = 14750,
  [14828] = 14733,
  [14829] = 14754,
  [14830] = 14733,
  [14831] = 14735,
  [14832] = 14737,
  [14833] = 14734,
  [14834] = 14735,
  [14835] = 14737,
  [14836] = 14735,
  [14837] = 14837,
  [14838] = 14750,
  [14839] = 14733,
  [14840] = 14734,
  [14841] = 14735,
  [14842] = 14737,
  [14843] = 14737,
  [14844] = 14732,
  [14845] = 14733,
  [14846] = 14734,
  [14847] = 14735,
  [14848] = 14787,
  [14849] = 14737,
  [14850] = 14734,
  [14851] = 14754,
  [14852] = 14770,
  [14853] = 14733,
  [14854] = 14771,
  [14855] = 14734,
  [14856] = 14735,
  [14857] = 14737,
  [14858] = 14737,
  [14859] = 14735,
  [14860] = 14737,
  [14861] = 14787,
  [14862] = 14733,
  [14863] = 14734,
  [14864] = 14735,
  [14865] = 14865,
  [14866] = 14737,
  [14867] = 14734,
  [14868] = 14737,
  [14869] = 14733,
  [14870] = 14787,
  [14871] = 14734,
  [14872] = 14735,
  [14873] = 14737,
  [14874] = 5332,
  [14875] = 14733,
  [14876] = 14734,
  [14877] = 14735,
  [14878] = 14737,
  [14879] = 14733,
  [14880] = 14880,
  [14881] = 14881,
  [14882] = 14733,
  [14883] = 14734,
  [14884] = 14735,
  [14885] = 14737,
  [14886] = 14734,
  [14887] = 14754,
  [14888] = 14733,
  [14889] = 14770,
  [14890] = 14771,
  [14891] = 14734,
  [14892] = 14735,
  [14893] = 14737,
  [14894] = 14735,
  [14895] = 14733,
  [14896] = 14734,
  [14897] = 14735,
  [14898] = 14737,
  [14899] = 14737,
  [14900] = 14737,
  [14901] = 14741,
  [14902] = 14902,
  [14903] = 14733,
  [14904] = 14734,
  [14905] = 14735,
  [14906] = 14737,
  [14907] = 14734,
  [14908] = 14908,
  [14909] = 14737,
  [14910] = 14749,
  [14911] = 14750,
  [14912] = 14734,
  [14913] = 14733,
  [14914] = 14737,
  [14915] = 14754,
  [14916] = 14735,
  [14917] = 14734,
  [14918] = 14737,
  [14919] = 14734,
  [14920] = 14737,
  [14921] = 14737,
  [14922] = 14732,
  [14923] = 14734,
  [14924] = 14924,
  [14925] = 14737,
  [14926] = 14734,
  [14927] = 14737,
  [14928] = 14734,
  [14929] = 14929,
  [14930] = 14737,
  [14931] = 14734,
  [14932] = 14734,
  [14933] = 14737,
  [14934] = 14770,
  [14935] = 14771,
  [14936] = 14734,
  [14937] = 14737,
  [14938] = 14734,
  [14939] = 14735,
  [14940] = 14737,
  [14941] = 14734,
  [14942] = 14737,
  [14943] = 14734,
  [14944] = 14737,
  [14945] = 14770,
  [14946] = 14734,
  [14947] = 14737,
  [14948] = 14737,
  [14949] = 14734,
  [14950] = 14737,
  [14951] = 14787,
  [14952] = 14734,
  [14953] = 14737,
  [14954] = 14734,
  [14955] = 14737,
  [14956] = 14734,
  [14957] = 14737,
  [14958] = 14734,
  [14959] = 14737,
  [14960] = 14733,
  [14961] = 14734,
  [14962] = 14737,
  [14963] = 14734,
  [14964] = 14741,
  [14965] = 14737,
  [14966] = 14771,
  [14967] = 14734,
  [14968] = 14737,
  [14969] = 14734,
  [14970] = 14737,
  [14971] = 14734,
  [14972] = 14734,
  [14973] = 14737,
  [14974] = 14734,
  [14975] = 14737,
  [14976] = 14734,
  [14977] = 14787,
  [14978] = 14737,
  [14979] = 14741,
  [14980] = 14735,
  [14981] = 14741,
  [14982] = 14741,
  [14983] = 14737,
  [14984] = 14749,
  [14985] = 14750,
  [14986] = 14733,
  [14987] = 14754,
  [14988] = 14988,
  [14989] = 14733,
  [14990] = 14990,
  [14991] = 14754,
  [14992] = 14732,
  [14993] = 14749,
  [14994] = 14734,
  [14995] = 14733,
  [14996] = 14750,
  [14997] = 14997,
  [14998] = 14770,
  [14999] = 14771,
  [15000] = 14735,
  [15001] = 15001,
  [15002] = 14749,
  [15003] = 14734,
  [15004] = 14815,
  [15005] = 15005,
  [15006] = 14750,
  [15007] = 14733,
  [15008] = 14737,
  [15009] = 14787,
  [15010] = 14735,
  [15011] = 14733,
  [15012] = 14754,
  [15013] = 14754,
  [15014] = 14737,
  [15015] = 14737,
  [15016] = 14754,
  [15017] = 14734,
  [15018] = 14754,
  [15019] = 14754,
  [15020] = 14754,
  [15021] = 14754,
  [15022] = 14754,
  [15023] = 14754,
  [15024] = 14754,
  [15025] = 14754,
  [15026] = 14754,
  [15027] = 14754,
  [15028] = 14754,
  [15029] = 14754,
  [15030] = 14754,
  [15031] = 14754,
  [15032] = 14754,
  [15033] = 14754,
  [15034] = 14754,
  [15035] = 15035,
  [15036] = 15036,
  [15037] = 14741,
  [15038] = 14732,
  [15039] = 14733,
  [15040] = 14732,
  [15041] = 14734,
  [15042] = 14749,
  [15043] = 14990,
  [15044] = 14733,
  [15045] = 14750,
  [15046] = 14733,
  [15047] = 14754,
  [15048] = 15048,
  [15049] = 14735,
  [15050] = 14997,
  [15051] = 15001,
  [15052] = 15001,
  [15053] = 15053,
  [15054] = 14815,
  [15055] = 15005,
  [15056] = 14732,
  [15057] = 14754,
  [15058] = 14754,
  [15059] = 14754,
  [15060] = 14754,
  [15061] = 14754,
  [15062] = 14754,
  [15063] = 14754,
  [15064] = 14754,
  [15065] = 14737,
  [15066] = 14050,
  [15067] = 14734,
  [15068] = 14735,
  [15069] = 14734,
  [15070] = 14770,
  [15071] = 14771,
  [15072] = 14990,
  [15073] = 14770,
  [15074] = 14771,
  [15075] = 14735,
  [15076] = 14997,
  [15077] = 14733,
  [15078] = 15001,
  [15079] = 14737,
  [15080] = 14815,
  [15081] = 15005,
  [15082] = 14737,
  [15083] = 14787,
  [15084] = 14754,
  [15085] = 14754,
  [15086] = 14754,
  [15087] = 14754,
  [15088] = 14754,
  [15089] = 14754,
  [15090] = 14754,
  [15091] = 14754,
  [15092] = 14735,
  [15093] = 14734,
  [15094] = 14735,
  [15095] = 15095,
  [15096] = 14737,
  [15097] = 14734,
  [15098] = 14990,
  [15099] = 14749,
  [15100] = 14732,
  [15101] = 14750,
  [15102] = 14737,
  [15103] = 14997,
  [15104] = 14787,
  [15105] = 15005,
  [15106] = 14733,
  [15107] = 14754,
  [15108] = 14754,
  [15109] = 14754,
  [15110] = 14770,
  [15111] = 14771,
  [15112] = 14733,
  [15113] = 15113,
  [15114] = 14734,
  [15115] = 14741,
  [15116] = 14990,
  [15117] = 15117,
  [15118] = 14754,
  [15119] = 14997,
  [15120] = 14735,
  [15121] = 15005,
  [15122] = 15122,
  [15123] = 14754,
  [15124] = 15124,
  [15125] = 14737,
  [15126] = 14735,
  [15127] = 14749,
  [15128] = 14750,
  [15129] = 14734,
  [15130] = 14990,
  [15131] = 14733,
  [15132] = 14902,
  [15133] = 14754,
  [15134] = 14997,
  [15135] = 15135,
  [15136] = 15136,
  [15137] = 14734,
  [15138] = 15005,
  [15139] = 14787,
  [15140] = 14754,
  [15141] = 15141,
  [15142] = 14732,
  [15143] = 15143,
  [15144] = 14990,
  [15145] = 14733,
  [15146] = 14902,
  [15147] = 14997,
  [15148] = 14734,
  [15149] = 14741,
  [15150] = 15005,
  [15151] = 14770,
  [15152] = 14734,
  [15153] = 14771,
  [15154] = 14735,
  [15155] = 15155,
  [15156] = 14735,
  [15157] = 14737,
  [15158] = 14737,
  [15159] = 14990,
  [15160] = 14787,
  [15161] = 14737,
  [15162] = 14997,
  [15163] = 14737,
  [15164] = 14787,
  [15165] = 15005,
  [15166] = 15166,
  [15167] = 15167,
  [15168] = 14990,
  [15169] = 14732,
  [15170] = 14735,
  [15171] = 14997,
  [15172] = 15005,
  [15173] = 14733,
  [15174] = 14749,
  [15175] = 14750,
  [15176] = 14733,
  [15177] = 14734,
  [15178] = 14754,
  [15179] = 14990,
  [15180] = 14997,
  [15181] = 15181,
  [15182] = 15005,
  [15183] = 14735,
  [15184] = 14734,
  [15185] = 14770,
  [15186] = 14771,
  [15187] = 14741,
  [15188] = 14735,
  [15189] = 14737,
  [15190] = 14990,
  [15191] = 14737,
  [15192] = 14997,
  [15193] = 15193,
  [15194] = 15005,
  [15195] = 15195,
  [15196] = 14754,
  [15197] = 14733,
  [15198] = 15198,
  [15199] = 14735,
  [15200] = 15200,
  [15201] = 14733,
  [15202] = 14990,
  [15203] = 15203,
  [15204] = 15204,
  [15205] = 15205,
  [15206] = 14997,
  [15207] = 14732,
  [15208] = 15005,
  [15209] = 14734,
  [15210] = 15210,
  [15211] = 14749,
  [15212] = 14735,
  [15213] = 14749,
  [15214] = 14750,
  [15215] = 14750,
  [15216] = 14990,
  [15217] = 14735,
  [15218] = 14733,
  [15219] = 14754,
  [15220] = 14997,
  [15221] = 15221,
  [15222] = 15005,
  [15223] = 14734,
  [15224] = 14737,
  [15225] = 14734,
  [15226] = 14770,
  [15227] = 14990,
  [15228] = 14771,
  [15229] = 14733,
  [15230] = 14997,
  [15231] = 14754,
  [15232] = 14735,
  [15233] = 14734,
  [15234] = 15005,
  [15235] = 14741,
  [15236] = 14104,
  [15237] = 14735,
  [15238] = 14733,
  [15239] = 14737,
  [15240] = 15240,
  [15241] = 14990,
  [15242] = 14734,
  [15243] = 14997,
  [15244] = 15005,
  [15245] = 14735,
  [15246] = 14732,
  [15247] = 15247,
  [15248] = 14737,
  [15249] = 14990,
  [15250] = 14997,
  [15251] = 14737,
  [15252] = 14749,
  [15253] = 14750,
  [15254] = 15005,
  [15255] = 14733,
  [15256] = 14754,
  [15257] = 14749,
  [15258] = 14749,
  [15259] = 14733,
  [15260] = 14990,
  [15261] = 15261,
  [15262] = 14734,
  [15263] = 14750,
  [15264] = 14734,
  [15265] = 14770,
  [15266] = 15005,
  [15267] = 14771,
  [15268] = 14735,
  [15269] = 14735,
  [15270] = 14734,
  [15271] = 14733,
  [15272] = 14737,
  [15273] = 14737,
  [15274] = 15005,
  [15275] = 14754,
  [15276] = 14750,
  [15277] = 15277,
  [15278] = 14770,
  [15279] = 14770,
  [15280] = 14771,
  [15281] = 15281,
  [15282] = 14771,
  [15283] = 14735,
  [15284] = 14733,
  [15285] = 15005,
  [15286] = 14737,
  [15287] = 14741,
  [15288] = 14734,
  [15289] = 14733,
  [15290] = 15290,
  [15291] = 14754,
  [15292] = 14735,
  [15293] = 15005,
  [15294] = 14737,
  [15295] = 14734,
  [15296] = 14734,
  [15297] = 15297,
  [15298] = 14735,
  [15299] = 14787,
  [15300] = 15300,
  [15301] = 15005,
  [15302] = 14997,
  [15303] = 14737,
  [15304] = 14749,
  [15305] = 14750,
  [15306] = 14732,
  [15307] = 15053,
  [15308] = 15261,
  [15309] = 14737,
  [15310] = 14733,
  [15311] = 15311,
  [15312] = 13750,
  [15313] = 14787,
  [15314] = 15005,
  [15315] = 14734,
  [15316] = 15316,
  [15317] = 14801,
  [15318] = 14733,
  [15319] = 14754,
  [15320] = 14735,
  [15321] = 14737,
  [15322] = 15005,
  [15323] = 15323,
  [15324] = 14733,
  [15325] = 14734,
  [15326] = 15326,
  [15327] = 14732,
  [15328] = 15005,
  [15329] = 15277,
  [15330] = 14735,
  [15331] = 14770,
  [15332] = 14734,
  [15333] = 14988,
  [15334] = 15035,
  [15335] = 15124,
  [15336] = 15005,
  [15337] = 15135,
  [15338] = 14735,
  [15339] = 15339,
  [15340] = 15340,
  [15341] = 14734,
  [15342] = 14997,
  [15343] = 14733,
  [15344] = 14737,
  [15345] = 14770,
  [15346] = 14771,
  [15347] = 15347,
  [15348] = 14734,
  [15349] = 14781,
  [15350] = 14929,
  [15351] = 14902,
  [15352] = 15143,
  [15353] = 15195,
  [15354] = 14735,
  [15355] = 15205,
  [15356] = 14771,
  [15357] = 15210,
  [15358] = 14735,
  [15359] = 14737,
  [15360] = 15360,
  [15361] = 15361,
  [15362] = 15297,
  [15363] = 14733,
  [15364] = 14735,
  [15365] = 14737,
  [15366] = 14732,
  [15367] = 14733,
  [15368] = 14733,
  [15369] = 15326,
  [15370] = 15005,
  [15371] = 14734,
  [15372] = 14734,
  [15373] = 14908,
  [15374] = 15166,
  [15375] = 14787,
  [15376] = 15198,
  [15377] = 14734,
  [15378] = 15155,
  [15379] = 14735,
  [15380] = 15122,
  [15381] = 14737,
  [15382] = 14735,
  [15383] = 15204,
  [15384] = 14737,
  [15385] = 15290,
  [15386] = 14737,
  [15387] = 14737,
  [15388] = 14808,
  [15389] = 15036,
  [15390] = 14787,
  [15391] = 15200,
  [15392] = 14787,
  [15393] = 15203,
  [15394] = 14737,
  [15395] = 15221,
  [15396] = 15340,
  [15397] = 14733,
  [15398] = 14068,
  [15399] = 14734,
  [15400] = 14734,
  [15401] = 15401,
  [15402] = 15402,
  [15403] = 15403,
  [15404] = 14735,
  [15405] = 14924,
  [15406] = 14737,
  [15407] = 14733,
  [15408] = 14741,
  [15409] = 14733,
  [15410] = 14733,
  [15411] = 14734,
  [15412] = 14735,
  [15413] = 14735,
  [15414] = 14734,
  [15415] = 14737,
  [15416] = 15360,
  [15417] = 14735,
  [15418] = 14741,
  [15419] = 15167,
  [15420] = 14735,
  [15421] = 14737,
  [15422] = 14733,
  [15423] = 14737,
  [15424] = 14734,
  [15425] = 15425,
  [15426] = 14990,
  [15427] = 14735,
  [15428] = 14787,
  [15429] = 14749,
  [15430] = 14737,
  [15431] = 14750,
  [15432] = 14733,
  [15433] = 14754,
  [15434] = 15434,
  [15435] = 14733,
  [15436] = 14733,
  [15437] = 14734,
  [15438] = 14734,
  [15439] = 14735,
  [15440] = 14737,
  [15441] = 14735,
  [15442] = 14741,
  [15443] = 14737,
  [15444] = 14741,
  [15445] = 14732,
  [15446] = 14733,
  [15447] = 14734,
  [15448] = 14741,
  [15449] = 14749,
  [15450] = 15181,
  [15451] = 14750,
  [15452] = 14735,
  [15453] = 14733,
  [15454] = 14733,
  [15455] = 14754,
  [15456] = 14737,
  [15457] = 14734,
  [15458] = 14734,
  [15459] = 15459,
  [15460] = 14735,
  [15461] = 14733,
  [15462] = 14770,
  [15463] = 14737,
  [15464] = 14734,
  [15465] = 15465,
  [15466] = 14771,
  [15467] = 14735,
  [15468] = 14737,
  [15469] = 15311,
  [15470] = 14732,
  [15471] = 14749,
  [15472] = 14750,
  [15473] = 15361,
  [15474] = 15474,
  [15475] = 14735,
  [15476] = 14733,
  [15477] = 14733,
  [15478] = 14734,
  [15479] = 13719,
  [15480] = 14734,
  [15481] = 15481,
  [15482] = 14735,
  [15483] = 14734,
  [15484] = 14735,
  [15485] = 14770,
  [15486] = 15486,
  [15487] = 14737,
  [15488] = 14771,
  [15489] = 14737,
  [15490] = 14741,
  [15491] = 15491,
  [15492] = 14737,
  [15493] = 15493,
  [15494] = 14735,
  [15495] = 14733,
  [15496] = 14787,
  [15497] = 14734,
  [15498] = 15498,
  [15499] = 14749,
  [15500] = 14735,
  [15501] = 14737,
  [15502] = 14749,
  [15503] = 14750,
  [15504] = 14733,
  [15505] = 15316,
  [15506] = 14750,
  [15507] = 14737,
  [15508] = 14801,
  [15509] = 14733,
  [15510] = 14754,
  [15511] = 14787,
  [15512] = 14734,
  [15513] = 14735,
  [15514] = 14733,
  [15515] = 15515,
  [15516] = 14732,
  [15517] = 14737,
  [15518] = 14734,
  [15519] = 14988,
  [15520] = 15035,
  [15521] = 15124,
  [15522] = 15135,
  [15523] = 14734,
  [15524] = 14735,
  [15525] = 14733,
  [15526] = 14770,
  [15527] = 14771,
  [15528] = 14737,
  [15529] = 14781,
  [15530] = 14902,
  [15531] = 15143,
  [15532] = 14770,
  [15533] = 15195,
  [15534] = 15534,
  [15535] = 15205,
  [15536] = 15210,
  [15537] = 14735,
  [15538] = 14770,
  [15539] = 15361,
  [15540] = 14749,
  [15541] = 14749,
  [15542] = 14733,
  [15543] = 14737,
  [15544] = 14787,
  [15545] = 14733,
  [15546] = 14750,
  [15547] = 15166,
  [15548] = 15316,
  [15549] = 15198,
  [15550] = 15122,
  [15551] = 15204,
  [15552] = 15290,
  [15553] = 15316,
  [15554] = 14734,
  [15555] = 14808,
  [15556] = 14735,
  [15557] = 15221,
  [15558] = 14734,
  [15559] = 14737,
  [15560] = 15401,
  [15561] = 14734,
  [15562] = 14733,
  [15563] = 14924,
  [15564] = 14754,
  [15565] = 14735,
  [15566] = 14733,
  [15567] = 14733,
  [15568] = 14737,
  [15569] = 14734,
  [15570] = 14754,
  [15571] = 14771,
  [15572] = 14735,
  [15573] = 14737,
  [15574] = 15574,
  [15575] = 14735,
  [15576] = 14733,
  [15577] = 14741,
  [15578] = 14750,
  [15579] = 14734,
  [15580] = 15580,
  [15581] = 14733,
  [15582] = 15582,
  [15583] = 14741,
  [15584] = 14735,
  [15585] = 15585,
  [15586] = 14737,
  [15587] = 14734,
  [15588] = 15588,
  [15589] = 14741,
  [15590] = 15590,
  [15591] = 14733,
  [15592] = 15592,
  [15593] = 14749,
  [15594] = 14735,
  [15595] = 14750,
  [15596] = 14734,
  [15597] = 14737,
  [15598] = 14771,
  [15599] = 14735,
  [15600] = 14737,
  [15601] = 14733,
  [15602] = 14737,
  [15603] = 14741,
  [15604] = 15604,
  [15605] = 14733,
  [15606] = 14754,
  [15607] = 14733,
  [15608] = 14734,
  [15609] = 14733,
  [15610] = 15610,
  [15611] = 14749,
  [15612] = 14750,
  [15613] = 15316,
  [15614] = 14733,
  [15615] = 14754,
  [15616] = 14735,
  [15617] = 14733,
  [15618] = 14737,
  [15619] = 14732,
  [15620] = 14734,
  [15621] = 14734,
  [15622] = 14754,
  [15623] = 14770,
  [15624] = 14771,
  [15625] = 14781,
  [15626] = 14902,
  [15627] = 14735,
  [15628] = 14735,
  [15629] = 14733,
  [15630] = 15001,
  [15631] = 15631,
  [15632] = 14815,
  [15633] = 14737,
  [15634] = 14749,
  [15635] = 14750,
  [15636] = 14734,
  [15637] = 15316,
  [15638] = 14737,
  [15639] = 15001,
  [15640] = 14815,
  [15641] = 14733,
  [15642] = 14787,
  [15643] = 14754,
  [15644] = 15001,
  [15645] = 14815,
  [15646] = 15166,
  [15647] = 14735,
  [15648] = 15198,
  [15649] = 15001,
  [15650] = 14815,
  [15651] = 14737,
  [15652] = 15001,
  [15653] = 14815,
  [15654] = 15001,
  [15655] = 14815,
  [15656] = 15001,
  [15657] = 14815,
  [15658] = 14733,
  [15659] = 14732,
  [15660] = 15001,
  [15661] = 14815,
  [15662] = 15001,
  [15663] = 14815,
  [15664] = 15001,
  [15665] = 14734,
  [15666] = 14815,
  [15667] = 15001,
  [15668] = 14815,
  [15669] = 14735,
  [15670] = 15221,
  [15671] = 15001,
  [15672] = 14815,
  [15673] = 15001,
  [15674] = 15401,
  [15675] = 14815,
  [15676] = 14737,
  [15677] = 14733,
  [15678] = 15401,
  [15679] = 15001,
  [15680] = 14815,
  [15681] = 15001,
  [15682] = 14815,
  [15683] = 14734,
  [15684] = 14732,
  [15685] = 15001,
  [15686] = 14732,
  [15687] = 14815,
  [15688] = 14734,
  [15689] = 14924,
  [15690] = 15001,
  [15691] = 14815,
  [15692] = 15001,
  [15693] = 14815,
  [15694] = 15001,
  [15695] = 15402,
  [15696] = 14815,
  [15697] = 14735,
  [15698] = 15001,
  [15699] = 14815,
  [15700] = 15001,
  [15701] = 14815,
  [15702] = 15001,
  [15703] = 14733,
  [15704] = 14815,
  [15705] = 14737,
  [15706] = 15001,
  [15707] = 14734,
  [15708] = 14815,
  [15709] = 15001,
  [15710] = 14815,
  [15711] = 14770,
  [15712] = 15001,
  [15713] = 14734,
  [15714] = 14815,
  [15715] = 15001,
  [15716] = 14771,
  [15717] = 14815,
  [15718] = 15718,
  [15719] = 14735,
  [15720] = 15001,
  [15721] = 14815,
  [15722] = 15001,
  [15723] = 14815,
  [15724] = 14737,
  [15725] = 15001,
  [15726] = 14815,
  [15727] = 14733,
  [15728] = 15001,
  [15729] = 14815,
  [15730] = 15001,
  [15731] = 14815,
  [15732] = 14735,
  [15733] = 14734,
  [15734] = 15001,
  [15735] = 14770,
  [15736] = 14815,
  [15737] = 14771,
  [15738] = 15001,
  [15739] = 14815,
  [15740] = 15001,
  [15741] = 14815,
  [15742] = 14735,
  [15743] = 15001,
  [15744] = 14815,
  [15745] = 14735,
  [15746] = 15001,
  [15747] = 14815,
  [15748] = 15001,
  [15749] = 14737,
  [15750] = 14815,
  [15751] = 14733,
  [15752] = 15001,
  [15753] = 14815,
  [15754] = 15001,
  [15755] = 14815,
  [15756] = 15001,
  [15757] = 14815,
  [15758] = 14734,
  [15759] = 15001,
  [15760] = 14815,
  [15761] = 15001,
  [15762] = 14815,
  [15763] = 15001,
  [15764] = 14735,
  [15765] = 14815,
  [15766] = 15001,
  [15767] = 14815,
  [15768] = 14733,
  [15769] = 15001,
  [15770] = 14737,
  [15771] = 14815,
  [15772] = 15001,
  [15773] = 14815,
  [15774] = 15001,
  [15775] = 14815,
  [15776] = 14737,
  [15777] = 15425,
  [15778] = 15001,
  [15779] = 14734,
  [15780] = 14815,
  [15781] = 15001,
  [15782] = 14815,
  [15783] = 14737,
  [15784] = 15001,
  [15785] = 14815,
  [15786] = 15001,
  [15787] = 14815,
  [15788] = 14735,
  [15789] = 14787,
  [15790] = 15001,
  [15791] = 14815,
  [15792] = 14741,
  [15793] = 15001,
  [15794] = 14815,
  [15795] = 14787,
  [15796] = 15001,
  [15797] = 14815,
  [15798] = 14733,
  [15799] = 15001,
  [15800] = 14815,
  [15801] = 14737,
  [15802] = 15001,
  [15803] = 14815,
  [15804] = 15001,
  [15805] = 14815,
  [15806] = 15001,
  [15807] = 14815,
  [15808] = 14734,
  [15809] = 15001,
  [15810] = 14815,
  [15811] = 15001,
  [15812] = 14815,
  [15813] = 15001,
  [15814] = 14735,
  [15815] = 14815,
  [15816] = 15001,
  [15817] = 14734,
  [15818] = 14815,
  [15819] = 15001,
  [15820] = 14815,
  [15821] = 14737,
  [15822] = 15001,
  [15823] = 14815,
  [15824] = 15001,
  [15825] = 14815,
  [15826] = 14732,
  [15827] = 14749,
  [15828] = 14733,
  [15829] = 14750,
  [15830] = 14734,
  [15831] = 14770,
  [15832] = 14733,
  [15833] = 14771,
  [15834] = 14734,
  [15835] = 14735,
  [15836] = 14735,
  [15837] = 15837,
  [15838] = 14733,
  [15839] = 14737,
  [15840] = 14737,
  [15841] = 14733,
  [15842] = 14735,
  [15843] = 14754,
  [15844] = 14734,
  [15845] = 14741,
  [15846] = 14733,
  [15847] = 14737,
  [15848] = 14733,
  [15849] = 14787,
  [15850] = 15850,
  [15851] = 15851,
  [15852] = 15851,
  [15853] = 15850,
  [15854] = 15854,
  [15855] = 15850,
  [15856] = 15854,
  [15857] = 15857,
  [15858] = 15858,
  [15859] = 15851,
  [15860] = 15850,
  [15861] = 15861,
  [15862] = 14241,
  [15863] = 15863,
  [15864] = 15864,
  [15865] = 15865,
  [15866] = 15854,
  [15867] = 15851,
  [15868] = 15850,
  [15869] = 15869,
  [15870] = 15851,
  [15871] = 15851,
  [15872] = 15850,
  [15873] = 15873,
  [15874] = 14241,
  [15875] = 15854,
  [15876] = 15858,
  [15877] = 15865,
  [15878] = 5967,
  [15879] = 15879,
  [15880] = 15854,
  [15881] = 15869,
  [15882] = 15882,
  [15883] = 15863,
  [15884] = 15851,
  [15885] = 15885,
  [15886] = 15850,
  [15887] = 15869,
  [15888] = 15888,
  [15889] = 15854,
  [15890] = 15890,
  [15891] = 15851,
  [15892] = 15851,
  [15893] = 15850,
  [15894] = 15851,
  [15895] = 15850,
  [15896] = 15850,
  [15897] = 15897,
  [15898] = 15854,
  [15899] = 15854,
  [15900] = 15850,
  [15901] = 15851,
  [15902] = 15850,
  [15903] = 15851,
  [15904] = 15854,
  [15905] = 15865,
  [15906] = 15851,
  [15907] = 15851,
  [15908] = 15863,
  [15909] = 15850,
  [15910] = 15910,
  [15911] = 15854,
  [15912] = 15851,
  [15913] = 15913,
  [15914] = 15851,
  [15915] = 15869,
  [15916] = 15850,
  [15917] = 15851,
  [15918] = 15850,
  [15919] = 15850,
  [15920] = 15850,
  [15921] = 8592,
  [15922] = 15922,
  [15923] = 15851,
  [15924] = 14128,
  [15925] = 15854,
  [15926] = 15850,
  [15927] = 15865,
  [15928] = 15928,
  [15929] = 8629,
  [15930] = 15854,
  [15931] = 15850,
  [15932] = 8669,
  [15933] = 15933,
  [15934] = 15851,
  [15935] = 15854,
  [15936] = 15936,
  [15937] = 15850,
  [15938] = 15851,
  [15939] = 15851,
  [15940] = 15850,
  [15941] = 15865,
  [15942] = 15854,
  [15943] = 15850,
  [15944] = 15851,
  [15945] = 8541,
  [15946] = 15869,
  [15947] = 15947,
  [15948] = 5356,
  [15949] = 15851,
  [15950] = 15865,
  [15951] = 15854,
  [15952] = 15952,
  [15953] = 15865,
  [15954] = 15869,
  [15955] = 15858,
  [15956] = 15956,
  [15957] = 15957,
  [15958] = 15958,
  [15959] = 15854,
  [15960] = 15854,
  [15961] = 15854,
  [15962] = 15854,
  [15963] = 15861,
  [15964] = 15851,
  [15965] = 15851,
  [15966] = 15851,
  [15967] = 15854,
  [15968] = 15850,
  [15969] = 15851,
  [15970] = 15869,
  [15971] = 15865,
  [15972] = 15850,
  [15973] = 15850,
  [15974] = 15850,
  [15975] = 15869,
  [15976] = 15858,
  [15977] = 15869,
  [15978] = 15854,
  [15979] = 15851,
  [15980] = 15863,
  [15981] = 15854,
  [15982] = 15851,
  [15983] = 15850,
  [15984] = 15984,
  [15985] = 15850,
  [15986] = 15986,
  [15987] = 15850,
  [15988] = 15869,
  [15989] = 15913,
  [15990] = 15854,
  [15991] = 15854,
  [15992] = 15850,
  [15993] = 15869,
  [15994] = 15854,
  [15995] = 15851,
  [15996] = 15851,
  [15997] = 15850,
  [15998] = 15869,
  [15999] = 15851,
  [16000] = 5687,
  [16001] = 15850,
  [16002] = 15865,
  [16003] = 15865,
  [16004] = 15851,
  [16005] = 15865,
  [16006] = 15854,
  [16007] = 15869,
  [16008] = 15869,
  [16009] = 16009,
  [16010] = 5361,
  [16011] = 15851,
  [16012] = 15869,
  [16013] = 15854,
  [16014] = 15850,
  [16015] = 16015,
  [16016] = 15858,
  [16017] = 5352,
  [16018] = 15854,
  [16019] = 15869,
  [16020] = 15854,
  [16021] = 15851,
  [16022] = 15851,
  [16023] = 15850,
  [16024] = 15850,
  [16025] = 8320,
  [16026] = 15865,
  [16027] = 15851,
  [16028] = 15869,
  [16029] = 15869,
  [16030] = 15850,
  [16031] = 16031,
  [16032] = 15854,
  [16033] = 15850,
  [16034] = 15869,
  [16035] = 15850,
  [16036] = 15888,
  [16037] = 15869,
  [16038] = 15854,
  [16039] = 15851,
  [16040] = 15854,
  [16041] = 15851,
  [16042] = 15850,
  [16043] = 15850,
  [16044] = 16044,
  [16045] = 15850,
  [16046] = 15851,
  [16047] = 15869,
  [16048] = 15854,
  [16049] = 14043,
  [16050] = 15865,
  [16051] = 16051,
  [16052] = 15850,
  [16053] = 15854,
  [16054] = 16054,
  [16055] = 15854,
  [16056] = 15850,
  [16057] = 15865,
  [16058] = 15928,
  [16059] = 15854,
  [16060] = 15947,
  [16061] = 15851,
  [16062] = 15851,
  [16063] = 5970,
  [16064] = 15850,
  [16065] = 15854,
  [16066] = 16066,
  [16067] = 16067,
  [16068] = 8476,
  [16069] = 15850,
  [16070] = 15863,
  [16071] = 16066,
  [16072] = 15851,
  [16073] = 5359,
  [16074] = 15865,
  [16075] = 15850,
  [16076] = 5687,
  [16077] = 15854,
  [16078] = 16078,
  [16079] = 16078,
  [16080] = 16080,
  [16081] = 16080,
  [16082] = 15865,
  [16083] = 15869,
  [16084] = 15854,
  [16085] = 15854,
  [16086] = 16086,
  [16087] = 15854,
  [16088] = 15854,
  [16089] = 15936,
  [16090] = 16090,
  [16091] = 15854,
  [16092] = 15854,
  [16093] = 15851,
  [16094] = 15850,
  [16095] = 16095,
  [16096] = 15854,
  [16097] = 8589,
  [16098] = 15851,
  [16099] = 15851,
  [16100] = 8434,
  [16101] = 15850,
  [16102] = 16102,
  [16103] = 15854,
  [16104] = 15851,
  [16105] = 16105,
  [16106] = 15851,
  [16107] = 16107,
  [16108] = 15850,
  [16109] = 15854,
  [16110] = 15850,
  [16111] = 15851,
  [16112] = 15851,
  [16113] = 15850,
  [16114] = 16114,
  [16115] = 15850,
  [16116] = 15854,
  [16117] = 15854,
  [16118] = 16118,
  [16119] = 15865,
  [16120] = 15851,
  [16121] = 15850,
  [16122] = 15851,
  [16123] = 15854,
  [16124] = 15869,
  [16125] = 16125,
  [16126] = 15854,
  [16127] = 15869,
  [16128] = 5354,
  [16129] = 15854,
  [16130] = 15865,
  [16131] = 15869,
  [16132] = 13684,
  [16133] = 15851,
  [16134] = 15869,
  [16135] = 15854,
  [16136] = 15850,
  [16137] = 8443,
  [16138] = 15854,
  [16139] = 5966,
  [16140] = 15854,
  [16141] = 15851,
  [16142] = 15850,
  [16143] = 15851,
  [16144] = 8560,
  [16145] = 15851,
  [16146] = 15850,
  [16147] = 15854,
  [16148] = 16148,
  [16149] = 16149,
  [16150] = 16150,
  [16151] = 16151,
  [16152] = 16152,
  [16153] = 16153,
  [16154] = 16154,
  [16155] = 16155,
  [16156] = 16156,
  [16157] = 16149,
  [16158] = 16148,
  [16159] = 16148,
  [16160] = 16160,
  [16161] = 16161,
  [16162] = 16162,
  [16163] = 16163,
  [16164] = 16149,
  [16165] = 16165,
  [16166] = 16166,
  [16167] = 16167,
  [16168] = 16168,
  [16169] = 16148,
  [16170] = 16151,
  [16171] = 16154,
  [16172] = 16156,
  [16173] = 16162,
  [16174] = 16174,
  [16175] = 16148,
  [16176] = 16176,
  [16177] = 16177,
  [16178] = 16150,
  [16179] = 16163,
  [16180] = 16167,
  [16181] = 16162,
  [16182] = 16174,
  [16183] = 16174,
  [16184] = 16167,
  [16185] = 16162,
  [16186] = 16155,
  [16187] = 16149,
  [16188] = 16148,
  [16189] = 16167,
  [16190] = 16166,
  [16191] = 16191,
  [16192] = 16162,
  [16193] = 16160,
  [16194] = 16166,
  [16195] = 16165,
  [16196] = 16155,
  [16197] = 16149,
  [16198] = 16168,
  [16199] = 16174,
  [16200] = 16151,
  [16201] = 16154,
  [16202] = 16156,
  [16203] = 16203,
  [16204] = 16162,
  [16205] = 16174,
  [16206] = 16162,
  [16207] = 16177,
  [16208] = 16150,
  [16209] = 16174,
  [16210] = 16160,
  [16211] = 16155,
  [16212] = 16162,
  [16213] = 16176,
  [16214] = 16149,
  [16215] = 16162,
  [16216] = 16148,
  [16217] = 16163,
  [16218] = 16148,
  [16219] = 16174,
  [16220] = 16160,
  [16221] = 16162,
  [16222] = 16160,
  [16223] = 16155,
  [16224] = 16191,
  [16225] = 16165,
  [16226] = 16176,
  [16227] = 16153,
  [16228] = 16168,
  [16229] = 16149,
  [16230] = 16151,
  [16231] = 16154,
  [16232] = 16156,
  [16233] = 16149,
  [16234] = 16155,
  [16235] = 16235,
  [16236] = 16149,
  [16237] = 16177,
  [16238] = 16150,
  [16239] = 16239,
  [16240] = 16148,
  [16241] = 16148,
  [16242] = 16242,
  [16243] = 16176,
  [16244] = 16160,
  [16245] = 16162,
  [16246] = 16246,
  [16247] = 16174,
  [16248] = 16155,
  [16249] = 16174,
  [16250] = 16149,
  [16251] = 16176,
  [16252] = 16174,
  [16253] = 16176,
  [16254] = 16153,
  [16255] = 16165,
  [16256] = 16242,
  [16257] = 16163,
  [16258] = 16168,
  [16259] = 16148,
  [16260] = 16151,
  [16261] = 16154,
  [16262] = 16156,
  [16263] = 16167,
  [16264] = 16153,
  [16265] = 16177,
  [16266] = 16150,
  [16267] = 16267,
  [16268] = 16162,
  [16269] = 16162,
  [16270] = 16174,
  [16271] = 16174,
  [16272] = 16148,
  [16273] = 16246,
  [16274] = 16246,
  [16275] = 16155,
  [16276] = 16276,
  [16277] = 16277,
  [16278] = 16155,
  [16279] = 16279,
  [16280] = 16176,
  [16281] = 16167,
  [16282] = 16165,
  [16283] = 16283,
  [16284] = 16162,
  [16285] = 16168,
  [16286] = 16166,
  [16287] = 16151,
  [16288] = 16154,
  [16289] = 16156,
  [16290] = 16191,
  [16291] = 16239,
  [16292] = 16177,
  [16293] = 16150,
  [16294] = 16163,
  [16295] = 16242,
  [16296] = 16246,
  [16297] = 16297,
  [16298] = 16167,
  [16299] = 16163,
  [16300] = 16177,
  [16301] = 16167,
  [16302] = 16155,
  [16303] = 16155,
  [16304] = 16150,
  [16305] = 16149,
  [16306] = 16191,
  [16307] = 16148,
  [16308] = 16153,
  [16309] = 16168,
  [16310] = 16148,
  [16311] = 16151,
  [16312] = 16154,
  [16313] = 16156,
  [16314] = 16148,
  [16315] = 16160,
  [16316] = 16177,
  [16317] = 16150,
  [16318] = 16161,
  [16319] = 16319,
  [16320] = 16160,
  [16321] = 16191,
  [16322] = 16239,
  [16323] = 16166,
  [16324] = 16162,
  [16325] = 16242,
  [16326] = 16149,
  [16327] = 16148,
  [16328] = 16155,
  [16329] = 16149,
  [16330] = 16155,
  [16331] = 16174,
  [16332] = 16155,
  [16333] = 16168,
  [16334] = 16151,
  [16335] = 16154,
  [16336] = 16156,
  [16337] = 16149,
  [16338] = 16338,
  [16339] = 16177,
  [16340] = 16150,
  [16341] = 16162,
  [16342] = 16342,
  [16343] = 16343,
  [16344] = 16174,
  [16345] = 16153,
  [16346] = 16149,
  [16347] = 16163,
  [16348] = 16235,
  [16349] = 16349,
  [16350] = 16350,
  [16351] = 16149,
  [16352] = 16155,
  [16353] = 16353,
  [16354] = 16149,
  [16355] = 16153,
  [16356] = 16168,
  [16357] = 16151,
  [16358] = 16154,
  [16359] = 16156,
  [16360] = 16167,
  [16361] = 16148,
  [16362] = 16177,
  [16363] = 16150,
  [16364] = 16160,
  [16365] = 16174,
  [16366] = 16162,
  [16367] = 16191,
  [16368] = 16174,
  [16369] = 16149,
  [16370] = 16167,
  [16371] = 16246,
  [16372] = 16148,
  [16373] = 16353,
  [16374] = 16162,
  [16375] = 16239,
  [16376] = 16168,
  [16377] = 16151,
  [16378] = 16154,
  [16379] = 16156,
  [16380] = 16166,
  [16381] = 16174,
  [16382] = 16177,
  [16383] = 16150,
  [16384] = 16384,
  [16385] = 16239,
  [16386] = 16386,
  [16387] = 16155,
  [16388] = 16176,
  [16389] = 16149,
  [16390] = 16165,
  [16391] = 16155,
  [16392] = 16392,
  [16393] = 16153,
  [16394] = 16394,
  [16395] = 16395,
  [16396] = 16148,
  [16397] = 16168,
  [16398] = 16151,
  [16399] = 16154,
  [16400] = 16156,
  [16401] = 16401,
  [16402] = 16151,
  [16403] = 16177,
  [16404] = 16150,
  [16405] = 16166,
  [16406] = 16297,
  [16407] = 16239,
  [16408] = 16148,
  [16409] = 16149,
  [16410] = 16162,
  [16411] = 16163,
  [16412] = 16148,
  [16413] = 16167,
  [16414] = 16163,
  [16415] = 16168,
  [16416] = 16155,
  [16417] = 16166,
  [16418] = 16168,
  [16419] = 16151,
  [16420] = 16154,
  [16421] = 16156,
  [16422] = 16155,
  [16423] = 16151,
  [16424] = 16177,
  [16425] = 16150,
  [16426] = 16176,
  [16427] = 16163,
  [16428] = 16167,
  [16429] = 16167,
  [16430] = 16154,
  [16431] = 16156,
  [16432] = 16167,
  [16433] = 16149,
  [16434] = 16434,
  [16435] = 16191,
  [16436] = 16155,
  [16437] = 16155,
  [16438] = 16149,
  [16439] = 16168,
  [16440] = 16151,
  [16441] = 16154,
  [16442] = 16156,
  [16443] = 16149,
  [16444] = 16239,
  [16445] = 16177,
  [16446] = 16150,
  [16447] = 16163,
  [16448] = 16174,
  [16449] = 16168,
  [16450] = 16149,
  [16451] = 16149,
  [16452] = 16160,
  [16453] = 16162,
  [16454] = 16162,
  [16455] = 16174,
  [16456] = 16174,
  [16457] = 16155,
  [16458] = 16148,
  [16459] = 16166,
  [16460] = 16168,
  [16461] = 16151,
  [16462] = 16154,
  [16463] = 16156,
  [16464] = 16162,
  [16465] = 16465,
  [16466] = 16177,
  [16467] = 16150,
  [16468] = 16242,
  [16469] = 16162,
  [16470] = 16162,
  [16471] = 16162,
  [16472] = 16246,
  [16473] = 16174,
  [16474] = 16160,
  [16475] = 16174,
  [16476] = 16246,
  [16477] = 16177,
  [16478] = 16174,
  [16479] = 16167,
  [16480] = 16149,
  [16481] = 16168,
  [16482] = 16151,
  [16483] = 16154,
  [16484] = 16156,
  [16485] = 16174,
  [16486] = 16150,
  [16487] = 16177,
  [16488] = 16150,
  [16489] = 16162,
  [16490] = 16166,
  [16491] = 16148,
  [16492] = 16148,
  [16493] = 16162,
  [16494] = 16174,
  [16495] = 16160,
  [16496] = 16148,
  [16497] = 16155,
  [16498] = 16434,
  [16499] = 16151,
  [16500] = 16155,
  [16501] = 16154,
  [16502] = 16168,
  [16503] = 16151,
  [16504] = 16154,
  [16505] = 16156,
  [16506] = 16242,
  [16507] = 16160,
  [16508] = 16177,
  [16509] = 16150,
  [16510] = 16297,
  [16511] = 16297,
  [16512] = 16191,
  [16513] = 16513,
  [16514] = 16155,
  [16515] = 16160,
  [16516] = 16149,
  [16517] = 16149,
  [16518] = 16155,
  [16519] = 16154,
  [16520] = 16149,
  [16521] = 16166,
  [16522] = 16155,
  [16523] = 16168,
  [16524] = 16151,
  [16525] = 16154,
  [16526] = 16156,
  [16527] = 16156,
  [16528] = 16149,
  [16529] = 16177,
  [16530] = 16150,
  [16531] = 16153,
  [16532] = 16166,
  [16533] = 16162,
  [16534] = 16155,
  [16535] = 16148,
  [16536] = 16162,
  [16537] = 16239,
  [16538] = 16174,
  [16539] = 16149,
  [16540] = 16148,
  [16541] = 16148,
  [16542] = 16239,
  [16543] = 16168,
  [16544] = 16151,
  [16545] = 16154,
  [16546] = 16156,
  [16547] = 16246,
  [16548] = 16162,
  [16549] = 16177,
  [16550] = 16150,
  [16551] = 16153,
  [16552] = 16552,
  [16553] = 16148,
  [16554] = 16176,
  [16555] = 16165,
  [16556] = 16392,
  [16557] = 16203,
  [16558] = 16166,
  [16559] = 16163,
  [16560] = 16167,
  [16561] = 16174,
  [16562] = 16155,
  [16563] = 16168,
  [16564] = 16151,
  [16565] = 16154,
  [16566] = 16156,
  [16567] = 16149,
  [16568] = 16242,
  [16569] = 16177,
  [16570] = 16150,
  [16571] = 16394,
  [16572] = 16160,
  [16573] = 16168,
  [16574] = 16155,
  [16575] = 16166,
  [16576] = 16149,
  [16577] = 16162,
  [16578] = 16162,
  [16579] = 16174,
  [16580] = 16151,
  [16581] = 16191,
  [16582] = 16148,
  [16583] = 16168,
  [16584] = 16151,
  [16585] = 16154,
  [16586] = 16156,
  [16587] = 16166,
  [16588] = 16154,
  [16589] = 16177,
  [16590] = 16150,
  [16591] = 16156,
  [16592] = 16162,
  [16593] = 16593,
  [16594] = 16166,
  [16595] = 16148,
  [16596] = 16162,
  [16597] = 16162,
  [16598] = 16174,
  [16599] = 16148,
  [16600] = 16155,
  [16601] = 16149,
  [16602] = 16242,
  [16603] = 16168,
  [16604] = 16151,
  [16605] = 16154,
  [16606] = 16156,
  [16607] = 16160,
  [16608] = 16155,
  [16609] = 16177,
  [16610] = 16150,
  [16611] = 16297,
  [16612] = 16155,
  [16613] = 16149,
  [16614] = 16149,
  [16615] = 16153,
  [16616] = 16155,
  [16617] = 16149,
  [16618] = 16242,
  [16619] = 16162,
  [16620] = 16162,
  [16621] = 16621,
  [16622] = 16174,
  [16623] = 16168,
  [16624] = 16151,
  [16625] = 16154,
  [16626] = 16156,
  [16627] = 16174,
  [16628] = 16148,
  [16629] = 16177,
  [16630] = 16150,
  [16631] = 16174,
  [16632] = 16163,
  [16633] = 16155,
  [16634] = 16149,
  [16635] = 16160,
  [16636] = 16153,
  [16637] = 16148,
  [16638] = 16177,
  [16639] = 16162,
  [16640] = 16150,
  [16641] = 16174,
  [16642] = 16176,
  [16643] = 16168,
  [16644] = 16151,
  [16645] = 16154,
  [16646] = 16156,
  [16647] = 16148,
  [16648] = 16153,
  [16649] = 16177,
  [16650] = 16150,
  [16651] = 16297,
  [16652] = 16297,
  [16653] = 16162,
  [16654] = 16174,
  [16655] = 16160,
  [16656] = 16155,
  [16657] = 16166,
  [16658] = 16150,
  [16659] = 16176,
  [16660] = 16163,
  [16661] = 16167,
  [16662] = 16297,
  [16663] = 16168,
  [16664] = 16151,
  [16665] = 16154,
  [16666] = 16156,
  [16667] = 16149,
  [16668] = 16176,
  [16669] = 16177,
  [16670] = 16150,
  [16671] = 16148,
  [16672] = 16155,
  [16673] = 16149,
  [16674] = 16162,
  [16675] = 16153,
  [16676] = 16174,
  [16677] = 16162,
  [16678] = 16174,
  [16679] = 16162,
  [16680] = 16174,
  [16681] = 16163,
  [16682] = 16168,
  [16683] = 16151,
  [16684] = 16154,
  [16685] = 16156,
  [16686] = 16166,
  [16687] = 16153,
  [16688] = 16177,
  [16689] = 16150,
  [16690] = 16155,
  [16691] = 16167,
  [16692] = 16160,
  [16693] = 5746,
  [16694] = 16166,
  [16695] = 16148,
  [16696] = 16162,
  [16697] = 16174,
  [16698] = 16149,
  [16699] = 16191,
  [16700] = 16174,
  [16701] = 16168,
  [16702] = 16151,
  [16703] = 16154,
  [16704] = 16156,
  [16705] = 16160,
  [16706] = 16239,
  [16707] = 16177,
  [16708] = 16150,
  [16709] = 16242,
  [16710] = 16297,
  [16711] = 16155,
  [16712] = 16155,
  [16713] = 16162,
  [16714] = 16153,
  [16715] = 16174,
  [16716] = 16160,
  [16717] = 16149,
  [16718] = 16162,
  [16719] = 16165,
  [16720] = 16168,
  [16721] = 16151,
  [16722] = 16154,
  [16723] = 16156,
  [16724] = 16246,
  [16725] = 16153,
  [16726] = 16177,
  [16727] = 16150,
  [16728] = 16246,
  [16729] = 16148,
  [16730] = 16168,
  [16731] = 16168,
  [16732] = 16148,
  [16733] = 16148,
  [16734] = 16151,
  [16735] = 16154,
  [16736] = 16156,
  [16737] = 16148,
  [16738] = 16153,
  [16739] = 16168,
  [16740] = 16151,
  [16741] = 16154,
  [16742] = 16156,
  [16743] = 16174,
  [16744] = 16162,
  [16745] = 16177,
  [16746] = 16150,
  [16747] = 16176,
  [16748] = 16163,
  [16749] = 16167,
  [16750] = 16174,
  [16751] = 16148,
  [16752] = 16297,
  [16753] = 16160,
  [16754] = 16155,
  [16755] = 16149,
  [16756] = 16148,
  [16757] = 16155,
  [16758] = 16168,
  [16759] = 16151,
  [16760] = 16154,
  [16761] = 16156,
  [16762] = 16149,
  [16763] = 16155,
  [16764] = 16150,
  [16765] = 16177,
  [16766] = 16162,
  [16767] = 16148,
  [16768] = 16150,
  [16769] = 16176,
  [16770] = 16155,
  [16771] = 16166,
  [16772] = 16239,
  [16773] = 16148,
  [16774] = 16162,
  [16775] = 16162,
  [16776] = 16168,
  [16777] = 16151,
  [16778] = 16154,
  [16779] = 16156,
  [16780] = 16174,
  [16781] = 16174,
  [16782] = 16150,
  [16783] = 16155,
  [16784] = 16297,
  [16785] = 16163,
  [16786] = 16149,
  [16787] = 16174,
  [16788] = 16160,
  [16789] = 16155,
  [16790] = 16149,
  [16791] = 16167,
  [16792] = 5352,
  [16793] = 16162,
  [16794] = 16168,
  [16795] = 16151,
  [16796] = 16154,
  [16797] = 16156,
  [16798] = 16174,
  [16799] = 5354,
  [16800] = 16150,
  [16801] = 16149,
  [16802] = 16191,
  [16803] = 16149,
  [16804] = 16165,
  [16805] = 16239,
  [16806] = 16160,
  [16807] = 16177,
  [16808] = 16242,
  [16809] = 16163,
  [16810] = 5356,
  [16811] = 16148,
  [16812] = 16168,
  [16813] = 16151,
  [16814] = 16154,
  [16815] = 16156,
  [16816] = 16153,
  [16817] = 16246,
  [16818] = 16150,
  [16819] = 16153,
  [16820] = 16153,
  [16821] = 16155,
  [16822] = 5359,
  [16823] = 16149,
  [16824] = 16165,
  [16825] = 16319,
  [16826] = 16148,
  [16827] = 16148,
  [16828] = 16163,
  [16829] = 5361,
  [16830] = 16168,
  [16831] = 16151,
  [16832] = 16154,
  [16833] = 16156,
  [16834] = 16168,
  [16835] = 16150,
  [16836] = 16836,
  [16837] = 16155,
  [16838] = 16176,
  [16839] = 16151,
  [16840] = 16154,
  [16841] = 16163,
  [16842] = 16155,
  [16843] = 16149,
  [16844] = 16167,
  [16845] = 16156,
  [16846] = 16162,
  [16847] = 16168,
  [16848] = 16151,
  [16849] = 16154,
  [16850] = 16156,
  [16851] = 16155,
  [16852] = 16174,
  [16853] = 16150,
  [16854] = 16155,
  [16855] = 16149,
  [16856] = 16166,
  [16857] = 16174,
  [16858] = 16176,
  [16859] = 5741,
  [16860] = 16160,
  [16861] = 16177,
  [16862] = 16166,
  [16863] = 16150,
  [16864] = 16163,
  [16865] = 16168,
  [16866] = 16151,
  [16867] = 16154,
  [16868] = 16156,
  [16869] = 16162,
  [16870] = 16148,
  [16871] = 16150,
  [16872] = 16162,
  [16873] = 16297,
  [16874] = 16174,
  [16875] = 16174,
  [16876] = 16149,
  [16877] = 16162,
  [16878] = 16174,
  [16879] = 8589,
  [16880] = 16149,
  [16881] = 16153,
  [16882] = 16153,
  [16883] = 16168,
  [16884] = 16151,
  [16885] = 16154,
  [16886] = 16156,
  [16887] = 16160,
  [16888] = 16163,
  [16889] = 16150,
  [16890] = 16155,
  [16891] = 16167,
  [16892] = 16148,
  [16893] = 16162,
  [16894] = 16149,
  [16895] = 16191,
  [16896] = 16148,
  [16897] = 16167,
  [16898] = 16166,
  [16899] = 16174,
  [16900] = 16246,
  [16901] = 16168,
  [16902] = 16151,
  [16903] = 16154,
  [16904] = 16156,
  [16905] = 16150,
  [16906] = 16162,
  [16907] = 16174,
  [16908] = 16162,
  [16909] = 16155,
  [16910] = 16155,
  [16911] = 16166,
  [16912] = 16149,
  [16913] = 16168,
  [16914] = 16151,
  [16915] = 16154,
  [16916] = 16156,
  [16917] = 16150,
  [16918] = 16191,
  [16919] = 16148,
  [16920] = 16153,
  [16921] = 16165,
  [16922] = 16174,
  [16923] = 16153,
  [16924] = 16155,
  [16925] = 16168,
  [16926] = 16151,
  [16927] = 16154,
  [16928] = 16156,
  [16929] = 16150,
  [16930] = 16168,
  [16931] = 16162,
  [16932] = 16149,
  [16933] = 16151,
  [16934] = 16154,
  [16935] = 16174,
  [16936] = 16148,
  [16937] = 16168,
  [16938] = 16151,
  [16939] = 16154,
  [16940] = 16156,
  [16941] = 16150,
  [16942] = 16156,
  [16943] = 16148,
  [16944] = 16162,
  [16945] = 16174,
  [16946] = 16162,
  [16947] = 16174,
  [16948] = 16168,
  [16949] = 16151,
  [16950] = 16154,
  [16951] = 16156,
  [16952] = 16150,
  [16953] = 16174,
  [16954] = 16177,
  [16955] = 16162,
  [16956] = 16176,
  [16957] = 16163,
  [16958] = 16958,
  [16959] = 16168,
  [16960] = 16151,
  [16961] = 16154,
  [16962] = 16156,
  [16963] = 16150,
  [16964] = 16167,
  [16965] = 16176,
  [16966] = 16150,
  [16967] = 16176,
  [16968] = 16155,
  [16969] = 16163,
  [16970] = 16168,
  [16971] = 16151,
  [16972] = 16154,
  [16973] = 16156,
  [16974] = 16150,
  [16975] = 16167,
  [16976] = 16174,
  [16977] = 16163,
  [16978] = 16155,
  [16979] = 16160,
  [16980] = 16149,
  [16981] = 16168,
  [16982] = 16151,
  [16983] = 16154,
  [16984] = 16156,
  [16985] = 16150,
  [16986] = 8629,
  [16987] = 16167,
  [16988] = 16148,
  [16989] = 16166,
  [16990] = 16239,
  [16991] = 16991,
  [16992] = 16168,
  [16993] = 16151,
  [16994] = 16154,
  [16995] = 16156,
  [16996] = 16150,
  [16997] = 16191,
  [16998] = 16283,
  [16999] = 16239,
  [17000] = 16166,
  [17001] = 16191,
  [17002] = 16239,
  [17003] = 16168,
  [17004] = 16151,
  [17005] = 16154,
  [17006] = 16156,
  [17007] = 16150,
  [17008] = 16242,
  [17009] = 16246,
  [17010] = 16242,
  [17011] = 16160,
  [17012] = 16149,
  [17013] = 16162,
  [17014] = 16168,
  [17015] = 16151,
  [17016] = 16154,
  [17017] = 16156,
  [17018] = 16150,
  [17019] = 16148,
  [17020] = 16174,
  [17021] = 16148,
  [17022] = 16242,
  [17023] = 16167,
  [17024] = 16150,
  [17025] = 16148,
  [17026] = 16155,
  [17027] = 16148,
  [17028] = 16246,
  [17029] = 16160,
  [17030] = 16150,
  [17031] = 16149,
  [17032] = 16148,
  [17033] = 16155,
  [17034] = 16155,
  [17035] = 16150,
  [17036] = 16149,
  [17037] = 16174,
  [17038] = 16165,
  [17039] = 16155,
  [17040] = 16162,
  [17041] = 16150,
  [17042] = 16246,
  [17043] = 16149,
  [17044] = 16353,
  [17045] = 16174,
  [17046] = 16168,
  [17047] = 16150,
  [17048] = 16162,
  [17049] = 16151,
  [17050] = 16154,
  [17051] = 16156,
  [17052] = 16176,
  [17053] = 16150,
  [17054] = 16174,
  [17055] = 16246,
  [17056] = 8434,
  [17057] = 16155,
  [17058] = 16177,
  [17059] = 16150,
  [17060] = 16150,
  [17061] = 16148,
  [17062] = 16166,
  [17063] = 16276,
  [17064] = 16149,
  [17065] = 16150,
  [17066] = 8476,
  [17067] = 16155,
  [17068] = 16149,
  [17069] = 16148,
  [17070] = 16513,
  [17071] = 16150,
  [17072] = 16153,
  [17073] = 16155,
  [17074] = 16239,
  [17075] = 16395,
  [17076] = 16242,
  [17077] = 16150,
  [17078] = 16401,
  [17079] = 16162,
  [17080] = 16148,
  [17081] = 16148,
  [17082] = 16167,
  [17083] = 16150,
  [17084] = 16162,
  [17085] = 16155,
  [17086] = 16166,
  [17087] = 16155,
  [17088] = 16163,
  [17089] = 16150,
  [17090] = 16162,
  [17091] = 16155,
  [17092] = 16163,
  [17093] = 16176,
  [17094] = 16174,
  [17095] = 16150,
  [17096] = 16168,
  [17097] = 8320,
  [17098] = 8443,
  [17099] = 16155,
  [17100] = 8560,
  [17101] = 16150,
  [17102] = 8592,
  [17103] = 16149,
  [17104] = 8669,
  [17105] = 16153,
  [17106] = 16162,
  [17107] = 16150,
  [17108] = 16163,
  [17109] = 16165,
  [17110] = 16162,
  [17111] = 16155,
  [17112] = 16160,
  [17113] = 16150,
  [17114] = 16167,
  [17115] = 16149,
  [17116] = 16167,
  [17117] = 16149,
  [17118] = 16242,
  [17119] = 16150,
  [17120] = 16168,
  [17121] = 16151,
  [17122] = 16149,
  [17123] = 16154,
  [17124] = 16151,
  [17125] = 16150,
  [17126] = 16155,
  [17127] = 16149,
  [17128] = 16162,
  [17129] = 16148,
  [17130] = 16154,
  [17131] = 16150,
  [17132] = 16156,
  [17133] = 16155,
  [17134] = 16156,
  [17135] = 16174,
  [17136] = 16174,
  [17137] = 16150,
  [17138] = 16149,
  [17139] = 16162,
  [17140] = 16177,
  [17141] = 16148,
  [17142] = 16150,
  [17143] = 16150,
  [17144] = 16166,
  [17145] = 16148,
  [17146] = 16174,
  [17147] = 16160,
  [17148] = 16167,
  [17149] = 16150,
  [17150] = 16149,
  [17151] = 16155,
  [17152] = 16162,
  [17153] = 16174,
  [17154] = 16191,
  [17155] = 16150,
  [17156] = 16155,
  [17157] = 16149,
  [17158] = 16160,
  [17159] = 16149,
  [17160] = 16155,
  [17161] = 16150,
  [17162] = 16162,
  [17163] = 16148,
  [17164] = 16162,
  [17165] = 16162,
  [17166] = 16162,
  [17167] = 16150,
  [17168] = 16174,
  [17169] = 16174,
  [17170] = 16155,
  [17171] = 16155,
  [17172] = 16297,
  [17173] = 16150,
  [17174] = 16297,
  [17175] = 16160,
  [17176] = 16148,
  [17177] = 16153,
  [17178] = 16162,
  [17179] = 16150,
  [17180] = 16297,
  [17181] = 16148,
  [17182] = 16148,
  [17183] = 16166,
  [17184] = 16297,
  [17185] = 16150,
  [17186] = 16165,
  [17187] = 16191,
  [17188] = 16239,
  [17189] = 16168,
  [17190] = 16297,
  [17191] = 16150,
  [17192] = 16151,
  [17193] = 16154,
  [17194] = 16156,
  [17195] = 16155,
  [17196] = 16149,
  [17197] = 16150,
  [17198] = 16148,
  [17199] = 16148,
  [17200] = 16153,
  [17201] = 16162,
  [17202] = 16153,
  [17203] = 16150,
  [17204] = 16153,
  [17205] = 16177,
  [17206] = 16150,
  [17207] = 16176,
  [17208] = 16163,
  [17209] = 16150,
  [17210] = 16148,
  [17211] = 16242,
  [17212] = 16162,
  [17213] = 16167,
  [17214] = 16174,
  [17215] = 16150,
  [17216] = 16167,
  [17217] = 16148,
  [17218] = 16176,
  [17219] = 16166,
  [17220] = 16174,
  [17221] = 16150,
  [17222] = 16155,
  [17223] = 16162,
  [17224] = 16166,
  [17225] = 16149,
  [17226] = 16297,
  [17227] = 16150,
  [17228] = 16148,
  [17229] = 16148,
  [17230] = 16465,
  [17231] = 16174,
  [17232] = 16149,
  [17233] = 16150,
  [17234] = 16155,
  [17235] = 16149,
  [17236] = 16155,
  [17237] = 16277,
  [17238] = 16149,
  [17239] = 16150,
  [17240] = 16160,
  [17241] = 16166,
  [17242] = 16153,
  [17243] = 16176,
  [17244] = 16162,
  [17245] = 16150,
  [17246] = 16162,
  [17247] = 16155,
  [17248] = 16174,
  [17249] = 16149,
  [17250] = 16163,
  [17251] = 16150,
  [17252] = 16160,
  [17253] = 16167,
  [17254] = 16148,
  [17255] = 16165,
  [17256] = 16148,
  [17257] = 16150,
  [17258] = 16162,
  [17259] = 16162,
  [17260] = 16174,
  [17261] = 16242,
  [17262] = 16297,
  [17263] = 16150,
  [17264] = 16168,
  [17265] = 16148,
  [17266] = 16151,
  [17267] = 16154,
  [17268] = 16153,
  [17269] = 16150,
  [17270] = 16156,
  [17271] = 16246,
  [17272] = 16176,
  [17273] = 16191,
  [17274] = 16155,
  [17275] = 16150,
  [17276] = 16177,
  [17277] = 16162,
  [17278] = 16148,
  [17279] = 17279,
  [17280] = 16150,
  [17281] = 16150,
  [17282] = 16174,
  [17283] = 16153,
  [17284] = 16162,
  [17285] = 16149,
  [17286] = 16246,
  [17287] = 16174,
  [17288] = 16148,
  [17289] = 16153,
  [17290] = 16176,
  [17291] = 16162,
  [17292] = 16148,
  [17293] = 16155,
  [17294] = 16153,
  [17295] = 16162,
  [17296] = 16166,
  [17297] = 16155,
  [17298] = 16149,
  [17299] = 16148,
  [17300] = 16297,
  [17301] = 16166,
  [17302] = 16155,
  [17303] = 16176,
  [17304] = 16174,
  [17305] = 16176,
  [17306] = 16176,
  [17307] = 16160,
  [17308] = 16162,
  [17309] = 16163,
  [17310] = 16167,
  [17311] = 16163,
  [17312] = 16148,
  [17313] = 16167,
  [17314] = 16174,
  [17315] = 16174,
  [17316] = 16191,
  [17317] = 16239,
  [17318] = 16242,
  [17319] = 16246,
  [17320] = 16165,
  [17321] = 16162,
  [17322] = 16395,
  [17323] = 16153,
  [17324] = 16174,
  [17325] = 16148,
  [17326] = 16168,
  [17327] = 16155,
  [17328] = 16160,
  [17329] = 16149,
  [17330] = 16151,
  [17331] = 16155,
  [17332] = 16149,
  [17333] = 16154,
  [17334] = 16149,
  [17335] = 16149,
  [17336] = 16156,
  [17337] = 16148,
  [17338] = 16163,
  [17339] = 16167,
  [17340] = 16155,
  [17341] = 16155,
  [17342] = 16148,
  [17343] = 16166,
  [17344] = 16177,
  [17345] = 17345,
  [17346] = 16161,
  [17347] = 16163,
  [17348] = 17348,
  [17349] = 16166,
  [17350] = 16279,
  [17351] = 16150,
  [17352] = 16160,
  [17353] = 16148,
  [17354] = 16149,
  [17355] = 16401,
  [17356] = 16162,
  [17357] = 16174,
  [17358] = 16395,
  [17359] = 16149,
  [17360] = 16239,
  [17361] = 16160,
  [17362] = 16167,
  [17363] = 16401,
  [17364] = 16163,
  [17365] = 16174,
  [17366] = 16163,
  [17367] = 17345,
  [17368] = 16155,
  [17369] = 16160,
  [17370] = 16148,
  [17371] = 16148,
  [17372] = 16162,
  [17373] = 16162,
  [17374] = 16163,
  [17375] = 17375,
  [17376] = 17345,
  [17377] = 16174,
  [17378] = 8541,
  [17379] = 16149,
  [17380] = 16162,
  [17381] = 16167,
  [17382] = 16167,
  [17383] = 16162,
  [17384] = 17384,
  [17385] = 17345,
  [17386] = 16165,
  [17387] = 16297,
  [17388] = 16174,
  [17389] = 16168,
  [17390] = 16191,
  [17391] = 16162,
  [17392] = 17345,
  [17393] = 16151,
  [17394] = 16153,
  [17395] = 16154,
  [17396] = 16156,
  [17397] = 16174,
  [17398] = 16168,
  [17399] = 17345,
  [17400] = 16166,
  [17401] = 17345,
  [17402] = 16153,
  [17403] = 16163,
  [17404] = 16174,
  [17405] = 16167,
  [17406] = 17345,
  [17407] = 16148,
  [17408] = 16148,
  [17409] = 16177,
  [17410] = 16150,
  [17411] = 16155,
  [17412] = 16191,
  [17413] = 17345,
  [17414] = 16155,
  [17415] = 16176,
  [17416] = 16149,
  [17417] = 16176,
  [17418] = 16163,
  [17419] = 16160,
  [17420] = 17345,
  [17421] = 16162,
  [17422] = 16167,
  [17423] = 16160,
  [17424] = 16279,
  [17425] = 16239,
  [17426] = 16239,
  [17427] = 17345,
  [17428] = 16166,
  [17429] = 16149,
  [17430] = 16242,
  [17431] = 16155,
  [17432] = 16149,
  [17433] = 16242,
  [17434] = 17345,
  [17435] = 16174,
  [17436] = 16148,
  [17437] = 16148,
  [17438] = 16155,
  [17439] = 16149,
  [17440] = 16151,
  [17441] = 17345,
  [17442] = 16166,
  [17443] = 16163,
  [17444] = 16153,
  [17445] = 16167,
  [17446] = 16166,
  [17447] = 16154,
  [17448] = 17345,
  [17449] = 16246,
  [17450] = 16166,
  [17451] = 16297,
  [17452] = 16148,
  [17453] = 16165,
  [17454] = 16297,
  [17455] = 17345,
  [17456] = 16297,
  [17457] = 16162,
  [17458] = 16168,
  [17459] = 16174,
  [17460] = 16246,
  [17461] = 16163,
  [17462] = 17345,
  [17463] = 16155,
  [17464] = 16160,
  [17465] = 16151,
  [17466] = 16154,
  [17467] = 16156,
  [17468] = 16156,
  [17469] = 17345,
  [17470] = 16176,
  [17471] = 16163,
  [17472] = 16167,
  [17473] = 16283,
  [17474] = 16177,
  [17475] = 16191,
  [17476] = 17345,
  [17477] = 16150,
  [17478] = 16155,
  [17479] = 16242,
  [17480] = 16239,
  [17481] = 16149,
  [17482] = 17345,
  [17483] = 16246,
  [17484] = 16242,
  [17485] = 16174,
  [17486] = 16162,
  [17487] = 16155,
  [17488] = 17345,
  [17489] = 16148,
  [17490] = 16174,
  [17491] = 17348,
  [17492] = 16155,
  [17493] = 16153,
  [17494] = 17345,
  [17495] = 16166,
  [17496] = 16155,
  [17497] = 16836,
  [17498] = 16153,
  [17499] = 16176,
  [17500] = 17345,
  [17501] = 16177,
  [17502] = 16246,
  [17503] = 16149,
  [17504] = 16149,
  [17505] = 16148,
  [17506] = 17345,
  [17507] = 16162,
  [17508] = 16174,
  [17509] = 16162,
  [17510] = 16242,
  [17511] = 16162,
  [17512] = 17345,
  [17513] = 16165,
  [17514] = 16162,
  [17515] = 16267,
  [17516] = 16176,
  [17517] = 16174,
  [17518] = 17345,
  [17519] = 16168,
  [17520] = 16163,
  [17521] = 16150,
  [17522] = 16167,
  [17523] = 16151,
  [17524] = 17345,
  [17525] = 16154,
  [17526] = 16156,
  [17527] = 16155,
  [17528] = 16155,
  [17529] = 16149,
  [17530] = 17345,
  [17531] = 16246,
  [17532] = 16174,
  [17533] = 16166,
  [17534] = 16177,
  [17535] = 16150,
  [17536] = 17345,
  [17537] = 16153,
  [17538] = 16163,
  [17539] = 16155,
  [17540] = 17540,
  [17541] = 16149,
  [17542] = 17345,
  [17543] = 16148,
  [17544] = 16166,
  [17545] = 16153,
  [17546] = 16148,
  [17547] = 16174,
  [17548] = 17345,
  [17549] = 16162,
  [17550] = 16162,
  [17551] = 16174,
  [17552] = 16174,
  [17553] = 16153,
  [17554] = 17345,
  [17555] = 16160,
  [17556] = 16163,
  [17557] = 16176,
  [17558] = 16155,
  [17559] = 16160,
  [17560] = 17345,
  [17561] = 16319,
  [17562] = 16149,
  [17563] = 16160,
  [17564] = 16166,
  [17565] = 16163,
  [17566] = 17345,
  [17567] = 16162,
  [17568] = 16148,
  [17569] = 16148,
  [17570] = 16155,
  [17571] = 16149,
  [17572] = 17345,
  [17573] = 16165,
  [17574] = 16155,
  [17575] = 16149,
  [17576] = 8541,
  [17577] = 16149,
  [17578] = 17345,
  [17579] = 16174,
  [17580] = 16168,
  [17581] = 16148,
  [17582] = 16151,
  [17583] = 16154,
  [17584] = 17345,
  [17585] = 16156,
  [17586] = 16167,
  [17587] = 16392,
  [17588] = 16149,
  [17589] = 16153,
  [17590] = 17345,
  [17591] = 16174,
  [17592] = 16177,
  [17593] = 16150,
  [17594] = 16155,
  [17595] = 16343,
  [17596] = 17345,
  [17597] = 16191,
  [17598] = 16149,
  [17599] = 16160,
  [17600] = 16148,
  [17601] = 16162,
  [17602] = 17345,
  [17603] = 16174,
  [17604] = 16174,
  [17605] = 16166,
  [17606] = 16191,
  [17607] = 16162,
  [17608] = 17345,
  [17609] = 16176,
  [17610] = 16239,
  [17611] = 16163,
  [17612] = 16167,
  [17613] = 17345,
  [17614] = 16153,
  [17615] = 16166,
  [17616] = 16167,
  [17617] = 16163,
  [17618] = 16174,
  [17619] = 17345,
  [17620] = 16203,
  [17621] = 16155,
  [17622] = 16350,
  [17623] = 16149,
  [17624] = 16242,
  [17625] = 17345,
  [17626] = 16155,
  [17627] = 16167,
  [17628] = 16166,
  [17629] = 17629,
  [17630] = 17630,
  [17631] = 17345,
  [17632] = 16176,
  [17633] = 16165,
  [17634] = 16162,
  [17635] = 16239,
  [17636] = 16166,
  [17637] = 17345,
  [17638] = 16246,
  [17639] = 16166,
  [17640] = 16168,
  [17641] = 16148,
  [17642] = 16174,
  [17643] = 17345,
  [17644] = 16151,
  [17645] = 16154,
  [17646] = 16156,
  [17647] = 16162,
  [17648] = 16174,
  [17649] = 17345,
  [17650] = 16162,
  [17651] = 16167,
  [17652] = 16148,
  [17653] = 16242,
  [17654] = 16160,
  [17655] = 17345,
  [17656] = 16149,
  [17657] = 16153,
  [17658] = 16153,
  [17659] = 16177,
  [17660] = 16150,
  [17661] = 17345,
  [17662] = 16163,
  [17663] = 16174,
  [17664] = 16149,
  [17665] = 16246,
  [17666] = 16176,
  [17667] = 17345,
  [17668] = 16148,
  [17669] = 16155,
  [17670] = 16153,
  [17671] = 16163,
  [17672] = 16297,
  [17673] = 17345,
  [17674] = 16167,
  [17675] = 16162,
  [17676] = 16162,
  [17677] = 16174,
  [17678] = 16149,
  [17679] = 17345,
  [17680] = 16167,
  [17681] = 16162,
  [17682] = 16176,
  [17683] = 16191,
  [17684] = 16239,
  [17685] = 17345,
  [17686] = 16242,
  [17687] = 16153,
  [17688] = 16246,
  [17689] = 16242,
  [17690] = 16148,
  [17691] = 17345,
  [17692] = 16165,
  [17693] = 16155,
  [17694] = 16246,
  [17695] = 16168,
  [17696] = 16174,
  [17697] = 17345,
  [17698] = 16148,
  [17699] = 16155,
  [17700] = 16151,
  [17701] = 16154,
  [17702] = 16153,
  [17703] = 17345,
  [17704] = 16156,
  [17705] = 16155,
  [17706] = 16149,
  [17707] = 16155,
  [17708] = 17345,
  [17709] = 16162,
  [17710] = 16177,
  [17711] = 16150,
  [17712] = 16176,
  [17713] = 17345,
  [17714] = 16149,
  [17715] = 16163,
  [17716] = 16155,
  [17717] = 16167,
  [17718] = 17345,
  [17719] = 16174,
  [17720] = 16162,
  [17721] = 16174,
  [17722] = 16155,
  [17723] = 17345,
  [17724] = 16149,
  [17725] = 16155,
  [17726] = 16165,
  [17727] = 16149,
  [17728] = 17345,
  [17729] = 16149,
  [17730] = 16174,
  [17731] = 16148,
  [17732] = 16174,
  [17733] = 17345,
  [17734] = 16163,
  [17735] = 16166,
  [17736] = 16160,
  [17737] = 16160,
  [17738] = 17345,
  [17739] = 16343,
  [17740] = 16162,
  [17741] = 16174,
  [17742] = 16166,
  [17743] = 17345,
  [17744] = 16392,
  [17745] = 16165,
  [17746] = 16162,
  [17747] = 16174,
  [17748] = 17345,
  [17749] = 16168,
  [17750] = 16162,
  [17751] = 16148,
  [17752] = 16174,
  [17753] = 17345,
  [17754] = 16151,
  [17755] = 16154,
  [17756] = 16156,
  [17757] = 17757,
  [17758] = 17345,
  [17759] = 17345,
  [17760] = 17345,
  [17761] = 17345,
  [17762] = 17345,
  [17763] = 17345,
  [17764] = 17345,
  [17765] = 17345,
  [17766] = 17345,
  [17767] = 17345,
  [17768] = 17345,
  [17769] = 17345,
  [17770] = 17345,
  [17771] = 17345,
  [17772] = 17345,
  [17773] = 17345,
  [17774] = 17345,
  [17775] = 17345,
  [17776] = 17345,
  [17777] = 17345,
  [17778] = 17345,
  [17779] = 17345,
  [17780] = 17345,
  [17781] = 17345,
  [17782] = 17345,
  [17783] = 17345,
  [17784] = 17345,
  [17785] = 17345,
  [17786] = 17345,
  [17787] = 17345,
  [17788] = 17345,
  [17789] = 17345,
  [17790] = 17345,
  [17791] = 17345,
  [17792] = 17345,
  [17793] = 17345,
  [17794] = 17345,
  [17795] = 17345,
  [17796] = 17345,
  [17797] = 17345,
  [17798] = 17345,
  [17799] = 17345,
  [17800] = 17345,
  [17801] = 17345,
  [17802] = 17345,
  [17803] = 17345,
  [17804] = 17345,
  [17805] = 17345,
  [17806] = 17345,
  [17807] = 17345,
  [17808] = 17345,
  [17809] = 17345,
  [17810] = 16160,
  [17811] = 16160,
  [17812] = 16148,
  [17813] = 16394,
  [17814] = 16155,
  [17815] = 16395,
  [17816] = 16160,
  [17817] = 16177,
  [17818] = 16148,
  [17819] = 16150,
  [17820] = 16163,
  [17821] = 16155,
  [17822] = 16153,
  [17823] = 16155,
  [17824] = 16401,
  [17825] = 16160,
  [17826] = 16149,
  [17827] = 16148,
  [17828] = 16160,
  [17829] = 16155,
  [17830] = 16149,
  [17831] = 16148,
  [17832] = 16163,
  [17833] = 16167,
  [17834] = 16836,
  [17835] = 16148,
  [17836] = 16155,
  [17837] = 16149,
  [17838] = 16167,
  [17839] = 16149,
  [17840] = 16149,
  [17841] = 16162,
  [17842] = 16155,
  [17843] = 16166,
  [17844] = 16149,
  [17845] = 16163,
  [17846] = 16162,
  [17847] = 16174,
  [17848] = 16162,
  [17849] = 16148,
  [17850] = 16160,
  [17851] = 16297,
  [17852] = 16156,
  [17853] = 16165,
  [17854] = 16166,
  [17855] = 16297,
  [17856] = 16174,
  [17857] = 16168,
  [17858] = 16168,
  [17859] = 16174,
  [17860] = 16151,
  [17861] = 16154,
  [17862] = 16153,
  [17863] = 16156,
  [17864] = 16176,
  [17865] = 16166,
  [17866] = 16153,
  [17867] = 16148,
  [17868] = 16149,
  [17869] = 16153,
  [17870] = 16177,
  [17871] = 16150,
  [17872] = 16163,
  [17873] = 16167,
  [17874] = 16176,
  [17875] = 16174,
  [17876] = 17876,
  [17877] = 17877,
  [17878] = 17878,
  [17879] = 17879,
};

static TSCharacterRange sym__alpha_identifier_character_set_1[] = {
  {'$', '$'}, {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5}, {0xba, 0xbb}, {0xc0, 0xd6},
  {0xd8, 0xf6}, {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee}, {0x370, 0x374}, {0x376, 0x377},
  {0x37a, 0x37d}, {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5}, {0x3f7, 0x481},
  {0x48a, 0x52f}, {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x620, 0x64a}, {0x66e, 0x66f},
  {0x671, 0x6d3}, {0x6d5, 0x6d5}, {0x6e5, 0x6e6}, {0x6ee, 0x6ef}, {0x6fa, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x710}, {0x712, 0x72f},
  {0x74d, 0x7a5}, {0x7b1, 0x7b1}, {0x7ca, 0x7ea}, {0x7f4, 0x7f5}, {0x7fa, 0x7fa}, {0x800, 0x815}, {0x81a, 0x81a}, {0x824, 0x824},
  {0x828, 0x828}, {0x840, 0x858}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x8a0, 0x8c9}, {0x904, 0x939}, {0x93d, 0x93d},
  {0x950, 0x950}, {0x958, 0x961}, {0x971, 0x980}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2},
  {0x9b6, 0x9b9}, {0x9bd, 0x9bd}, {0x9ce, 0x9ce}, {0x9dc, 0x9dd}, {0x9df, 0x9e1}, {0x9f0, 0x9f1}, {0x9fc, 0x9fc}, {0xa05, 0xa0a},
  {0xa0f, 0xa10}, {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33}, {0xa35, 0xa36}, {0xa38, 0xa39}, {0xa59, 0xa5c}, {0xa5e, 0xa5e},
  {0xa72, 0xa74}, {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9}, {0xabd, 0xabd},
  {0xad0, 0xad0}, {0xae0, 0xae1}, {0xaf9, 0xaf9}, {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33},
  {0xb35, 0xb39}, {0xb3d, 0xb3d}, {0xb5c, 0xb5d}, {0xb5f, 0xb61}, {0xb71, 0xb71}, {0xb83, 0xb83}, {0xb85, 0xb8a}, {0xb8e, 0xb90},
  {0xb92, 0xb95}, {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9}, {0xbd0, 0xbd0},
  {0xc05, 0xc0c}, {0xc0e, 0xc10}, {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3d, 0xc3d}, {0xc58, 0xc5a}, {0xc5d, 0xc5d}, {0xc60, 0xc61},
  {0xc80, 0xc80}, {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9}, {0xcbd, 0xcbd}, {0xcdd, 0xcde},
  {0xce0, 0xce1}, {0xcf1, 0xcf2}, {0xd04, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd3a}, {0xd3d, 0xd3d}, {0xd4e, 0xd4e}, {0xd54, 0xd56},
  {0xd5f, 0xd61}, {0xd7a, 0xd7f}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6}, {0xe01, 0xe30},
  {0xe32, 0xe33}, {0xe40, 0xe46}, {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xeb0},
  {0xeb2, 0xeb3}, {0xebd, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf40, 0xf47}, {0xf49, 0xf6c},
  {0xf88, 0xf8c}, {0x1000, 0x102a}, {0x103f, 0x103f}, {0x1050, 0x1055}, {0x105a, 0x105d}, {0x1061, 0x1061}, {0x1065, 0x1066}, {0x106e, 0x1070},
  {0x1075, 0x1081}, {0x108e, 0x108e}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248}, {0x124a, 0x124d},
  {0x1250, 0x1256}, {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5}, {0x12b8, 0x12be},
  {0x12c0, 0x12c0}, {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x1380, 0x138f}, {0x13a0, 0x13f5},
  {0x13f8, 0x13fd}, {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8}, {0x1700, 0x1711}, {0x171f, 0x1731},
  {0x1740, 0x1751}, {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1780, 0x17b3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dc}, {0x1820, 0x1878}, {0x1880, 0x1884},
  {0x1887, 0x18a8}, {0x18aa, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1950, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9},
  {0x1a00, 0x1a16}, {0x1a20, 0x1a54}, {0x1aa7, 0x1aa7}, {0x1b05, 0x1b33}, {0x1b45, 0x1b4c}, {0x1b83, 0x1ba0}, {0x1bae, 0x1baf}, {0x1bba, 0x1be5},
  {0x1c00, 0x1c23}, {0x1c4d, 0x1c4f}, {0x1c5a, 0x1c7d}, {0x1c80, 0x1c88}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1ce9, 0x1cec}, {0x1cee, 0x1cf3},
  {0x1cf5, 0x1cf6}, {0x1cfa, 0x1cfa}, {0x1d00, 0x1dbf}, {0x1e00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57},
  {0x1f59, 0x1f59}, {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4},
  {0x1fc6, 0x1fcc}, {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x2071, 0x2071}, {0x207f, 0x207f},
  {0x2090, 0x209c}, {0x2102, 0x2102}, {0x2107, 0x2107}, {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2119, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126},
  {0x2128, 0x2128}, {0x212a, 0x212d}, {0x212f, 0x2139}, {0x213c, 0x213f}, {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2160, 0x2188}, {0x2c00, 0x2ce4},
  {0x2ceb, 0x2cee}, {0x2cf2, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d}, {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d80, 0x2d96},
  {0x2da0, 0x2da6}, {0x2da8, 0x2dae}, {0x2db0, 0x2db6}, {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6}, {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde},
  {0x2e2f, 0x2e2f}, {0x3005, 0x3007}, {0x3021, 0x3029}, {0x3031, 0x3035}, {0x3038, 0x303c}, {0x3041, 0x3096}, {0x309d, 0x309f}, {0x30a1, 0x30fa},
  {0x30fc, 0x30ff}, {0x3105, 0x312f}, {0x3131, 0x318e}, {0x31a0, 0x31bf}, {0x31f0, 0x31ff}, {0x3400, 0x3400}, {0x4dbf, 0x4dbf}, {0x4e00, 0x4e00},
  {0x9fff, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa61f}, {0xa62a, 0xa62b}, {0xa640, 0xa66e}, {0xa67f, 0xa69d}, {0xa6a0, 0xa6ef},
  {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7ca}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d9}, {0xa7f2, 0xa801}, {0xa803, 0xa805},
  {0xa807, 0xa80a}, {0xa80c, 0xa822}, {0xa840, 0xa873}, {0xa882, 0xa8b3}, {0xa8f2, 0xa8f7}, {0xa8fb, 0xa8fb}, {0xa8fd, 0xa8fe}, {0xa90a, 0xa925},
  {0xa930, 0xa946}, {0xa960, 0xa97c}, {0xa984, 0xa9b2}, {0xa9cf, 0xa9cf}, {0xa9e0, 0xa9e4}, {0xa9e6, 0xa9ef}, {0xa9fa, 0xa9fe}, {0xaa00, 0xaa28},
  {0xaa40, 0xaa42}, {0xaa44, 0xaa4b}, {0xaa60, 0xaa76}, {0xaa7a, 0xaa7a}, {0xaa7e, 0xaaaf}, {0xaab1, 0xaab1}, {0xaab5, 0xaab6}, {0xaab9, 0xaabd},
  {0xaac0, 0xaac0}, {0xaac2, 0xaac2}, {0xaadb, 0xaadd}, {0xaae0, 0xaaea}, {0xaaf2, 0xaaf4}, {0xab01, 0xab06}, {0xab09, 0xab0e}, {0xab11, 0xab16},
  {0xab20, 0xab26}, {0xab28, 0xab2e}, {0xab30, 0xab5a}, {0xab5c, 0xab69}, {0xab70, 0xabe2}, {0xac00, 0xac00}, {0xd7a3, 0xd7a3}, {0xd7b0, 0xd7c6},
  {0xd7cb, 0xd7fb}, {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb1d}, {0xfb1f, 0xfb28}, {0xfb2a, 0xfb36},
  {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfd3d}, {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7},
  {0xfdf0, 0xfdfb}, {0xfe70, 0xfe74}, {0xfe76, 0xfefc}, {0xff21, 0xff3a}, {0xff41, 0xff5a}, {0xff66, 0xffbe}, {0xffc2, 0xffc7}, {0xffca, 0xffcf},
  {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a}, {0x1003c, 0x1003d}, {0x1003f, 0x1004d}, {0x10050, 0x1005d},
  {0x10080, 0x100fa}, {0x10140, 0x10174}, {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x10300, 0x1031f}, {0x1032d, 0x1034a}, {0x10350, 0x10375}, {0x10380, 0x1039d},
  {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x103d1, 0x103d5}, {0x10400, 0x1049d}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527}, {0x10530, 0x10563},
  {0x10570, 0x1057a}, {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc},
  {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767}, {0x10780, 0x10785}, {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808},
  {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c}, {0x1083f, 0x10855}, {0x10860, 0x10876}, {0x10880, 0x1089e}, {0x108e0, 0x108f2}, {0x108f4, 0x108f5},
  {0x10900, 0x10915},
};

static TSCharacterRange sym__alpha_identifier_character_set_2[] = {
  {'$', '$'}, {'0', '9'}, {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5}, {0xba, 0xbb},
  {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee}, {0x370, 0x374},
  {0x376, 0x377}, {0x37a, 0x37d}, {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5},
  {0x3f7, 0x481}, {0x48a, 0x52f}, {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x620, 0x64a},
  {0x66e, 0x66f}, {0x671, 0x6d3}, {0x6d5, 0x6d5}, {0x6e5, 0x6e6}, {0x6ee, 0x6ef}, {0x6fa, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x710},
  {0x712, 0x72f}, {0x74d, 0x7a5}, {0x7b1, 0x7b1}, {0x7ca, 0x7ea}, {0x7f4, 0x7f5}, {0x7fa, 0x7fa}, {0x800, 0x815}, {0x81a, 0x81a},
  {0x824, 0x824}, {0x828, 0x828}, {0x840, 0x858}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x8a0, 0x8c9}, {0x904, 0x939},
  {0x93d, 0x93d}, {0x950, 0x950}, {0x958, 0x961}, {0x971, 0x980}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0},
  {0x9b2, 0x9b2}, {0x9b6, 0x9b9}, {0x9bd, 0x9bd}, {0x9ce, 0x9ce}, {0x9dc, 0x9dd}, {0x9df, 0x9e1}, {0x9f0, 0x9f1}, {0x9fc, 0x9fc},
  {0xa05, 0xa0a}, {0xa0f, 0xa10}, {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33}, {0xa35, 0xa36}, {0xa38, 0xa39}, {0xa59, 0xa5c},
  {0xa5e, 0xa5e}, {0xa72, 0xa74}, {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9},
  {0xabd, 0xabd}, {0xad0, 0xad0}, {0xae0, 0xae1}, {0xaf9, 0xaf9}, {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30},
  {0xb32, 0xb33}, {0xb35, 0xb39}, {0xb3d, 0xb3d}, {0xb5c, 0xb5d}, {0xb5f, 0xb61}, {0xb71, 0xb71}, {0xb83, 0xb83}, {0xb85, 0xb8a},
  {0xb8e, 0xb90}, {0xb92, 0xb95}, {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9},
  {0xbd0, 0xbd0}, {0xc05, 0xc0c}, {0xc0e, 0xc10}, {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3d, 0xc3d}, {0xc58, 0xc5a}, {0xc5d, 0xc5d},
  {0xc60, 0xc61}, {0xc80, 0xc80}, {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9}, {0xcbd, 0xcbd},
  {0xcdd, 0xcde}, {0xce0, 0xce1}, {0xcf1, 0xcf2}, {0xd04, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd3a}, {0xd3d, 0xd3d}, {0xd4e, 0xd4e},
  {0xd54, 0xd56}, {0xd5f, 0xd61}, {0xd7a, 0xd7f}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6},
  {0xe01, 0xe30}, {0xe32, 0xe33}, {0xe40, 0xe46}, {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5},
  {0xea7, 0xeb0}, {0xeb2, 0xeb3}, {0xebd, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf40, 0xf47},
  {0xf49, 0xf6c}, {0xf88, 0xf8c}, {0x1000, 0x102a}, {0x103f, 0x103f}, {0x1050, 0x1055}, {0x105a, 0x105d}, {0x1061, 0x1061}, {0x1065, 0x1066},
  {0x106e, 0x1070}, {0x1075, 0x1081}, {0x108e, 0x108e}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248},
  {0x124a, 0x124d}, {0x1250, 0x1256}, {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5},
  {0x12b8, 0x12be}, {0x12c0, 0x12c0}, {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x1380, 0x138f},
  {0x13a0, 0x13f5}, {0x13f8, 0x13fd}, {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8}, {0x1700, 0x1711},
  {0x171f, 0x1731}, {0x1740, 0x1751}, {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1780, 0x17b3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dc}, {0x1820, 0x1878},
  {0x1880, 0x1884}, {0x1887, 0x18a8}, {0x18aa, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1950, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab},
  {0x19b0, 0x19c9}, {0x1a00, 0x1a16}, {0x1a20, 0x1a54}, {0x1aa7, 0x1aa7}, {0x1b05, 0x1b33}, {0x1b45, 0x1b4c}, {0x1b83, 0x1ba0}, {0x1bae, 0x1baf},
  {0x1bba, 0x1be5}, {0x1c00, 0x1c23}, {0x1c4d, 0x1c4f}, {0x1c5a, 0x1c7d}, {0x1c80, 0x1c88}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1ce9, 0x1cec},
  {0x1cee, 0x1cf3}, {0x1cf5, 0x1cf6}, {0x1cfa, 0x1cfa}, {0x1d00, 0x1dbf}, {0x1e00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d},
  {0x1f50, 0x1f57}, {0x1f59, 0x1f59}, {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe},
  {0x1fc2, 0x1fc4}, {0x1fc6, 0x1fcc}, {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x2071, 0x2071},
  {0x207f, 0x207f}, {0x2090, 0x209c}, {0x2102, 0x2102}, {0x2107, 0x2107}, {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2119, 0x211d}, {0x2124, 0x2124},
  {0x2126, 0x2126}, {0x2128, 0x2128}, {0x212a, 0x212d}, {0x212f, 0x2139}, {0x213c, 0x213f}, {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2160, 0x2188},
  {0x2c00, 0x2ce4}, {0x2ceb, 0x2cee}, {0x2cf2, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d}, {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f},
  {0x2d80, 0x2d96}, {0x2da0, 0x2da6}, {0x2da8, 0x2dae}, {0x2db0, 0x2db6}, {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6}, {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6},
  {0x2dd8, 0x2dde}, {0x2e2f, 0x2e2f}, {0x3005, 0x3007}, {0x3021, 0x3029}, {0x3031, 0x3035}, {0x3038, 0x303c}, {0x3041, 0x3096}, {0x309d, 0x309f},
  {0x30a1, 0x30fa}, {0x30fc, 0x30ff}, {0x3105, 0x312f}, {0x3131, 0x318e}, {0x31a0, 0x31bf}, {0x31f0, 0x31ff}, {0x3400, 0x3400}, {0x4dbf, 0x4dbf},
  {0x4e00, 0x4e00}, {0x9fff, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa61f}, {0xa62a, 0xa62b}, {0xa640, 0xa66e}, {0xa67f, 0xa69d},
  {0xa6a0, 0xa6ef}, {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7ca}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d9}, {0xa7f2, 0xa801},
  {0xa803, 0xa805}, {0xa807, 0xa80a}, {0xa80c, 0xa822}, {0xa840, 0xa873}, {0xa882, 0xa8b3}, {0xa8f2, 0xa8f7}, {0xa8fb, 0xa8fb}, {0xa8fd, 0xa8fe},
  {0xa90a, 0xa925}, {0xa930, 0xa946}, {0xa960, 0xa97c}, {0xa984, 0xa9b2}, {0xa9cf, 0xa9cf}, {0xa9e0, 0xa9e4}, {0xa9e6, 0xa9ef}, {0xa9fa, 0xa9fe},
  {0xaa00, 0xaa28}, {0xaa40, 0xaa42}, {0xaa44, 0xaa4b}, {0xaa60, 0xaa76}, {0xaa7a, 0xaa7a}, {0xaa7e, 0xaaaf}, {0xaab1, 0xaab1}, {0xaab5, 0xaab6},
  {0xaab9, 0xaabd}, {0xaac0, 0xaac0}, {0xaac2, 0xaac2}, {0xaadb, 0xaadd}, {0xaae0, 0xaaea}, {0xaaf2, 0xaaf4}, {0xab01, 0xab06}, {0xab09, 0xab0e},
  {0xab11, 0xab16}, {0xab20, 0xab26}, {0xab28, 0xab2e}, {0xab30, 0xab5a}, {0xab5c, 0xab69}, {0xab70, 0xabe2}, {0xac00, 0xac00}, {0xd7a3, 0xd7a3},
  {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb}, {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb1d}, {0xfb1f, 0xfb28},
  {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfd3d}, {0xfd50, 0xfd8f},
  {0xfd92, 0xfdc7}, {0xfdf0, 0xfdfb}, {0xfe70, 0xfe74}, {0xfe76, 0xfefc}, {0xff21, 0xff3a}, {0xff41, 0xff5a}, {0xff66, 0xffbe}, {0xffc2, 0xffc7},
  {0xffca, 0xffcf}, {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a}, {0x1003c, 0x1003d}, {0x1003f, 0x1004d},
  {0x10050, 0x1005d}, {0x10080, 0x100fa}, {0x10140, 0x10174}, {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x10300, 0x1031f}, {0x1032d, 0x1034a}, {0x10350, 0x10375},
  {0x10380, 0x1039d}, {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x103d1, 0x103d5}, {0x10400, 0x1049d}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527},
  {0x10530, 0x10563}, {0x10570, 0x1057a}, {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9},
  {0x105bb, 0x105bc}, {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767}, {0x10780, 0x10785}, {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805},
  {0x10808, 0x10808}, {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c}, {0x1083f, 0x10855}, {0x10860, 0x10876}, {0x10880, 0x1089e}, {0x108e0, 0x108f2},
  {0x108f4, 0x108f5}, {0x10900, 0x10915},
};

static TSCharacterRange sym__alpha_identifier_character_set_3[] = {
  {'!', '!'}, {'#', '&'}, {'*', '+'}, {'-', '-'}, {'/', ':'}, {'<', 'Z'}, {'\\', '\\'}, {'^', '_'},
  {'a', 'z'}, {'|', '|'}, {'~', '~'}, {0xa6, 0xa6}, {0xa9, 0xaa}, {0xac, 0xac}, {0xae, 0xae}, {0xb0, 0xb1},
  {0xb5, 0xb5}, {0xba, 0xbb}, {0xc0, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee}, {0x370, 0x374},
  {0x376, 0x377}, {0x37a, 0x37d}, {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x482},
  {0x48a, 0x52f}, {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x58d, 0x58e}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x606, 0x608},
  {0x60e, 0x60f}, {0x620, 0x64a}, {0x66e, 0x66f}, {0x671, 0x6d3}, {0x6d5, 0x6d5}, {0x6de, 0x6de}, {0x6e5, 0x6e6}, {0x6e9, 0x6e9},
  {0x6ee, 0x6ef}, {0x6fa, 0x6ff}, {0x710, 0x710}, {0x712, 0x72f}, {0x74d, 0x7a5}, {0x7b1, 0x7b1}, {0x7ca, 0x7ea}, {0x7f4, 0x7f6},
  {0x7fa, 0x7fa}, {0x800, 0x815}, {0x81a, 0x81a}, {0x824, 0x824}, {0x828, 0x828}, {0x840, 0x858}, {0x860, 0x86a}, {0x870, 0x887},
  {0x889, 0x88e}, {0x8a0, 0x8c9}, {0x904, 0x939}, {0x93d, 0x93d}, {0x950, 0x950}, {0x958, 0x961}, {0x971, 0x980}, {0x985, 0x98c},
  {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2}, {0x9b6, 0x9b9}, {0x9bd, 0x9bd}, {0x9ce, 0x9ce}, {0x9dc, 0x9dd},
  {0x9df, 0x9e1}, {0x9f0, 0x9f1}, {0x9fa, 0x9fa}, {0x9fc, 0x9fc}, {0xa05, 0xa0a}, {0xa0f, 0xa10}, {0xa13, 0xa28}, {0xa2a, 0xa30},
  {0xa32, 0xa33}, {0xa35, 0xa36}, {0xa38, 0xa39}, {0xa59, 0xa5c}, {0xa5e, 0xa5e}, {0xa72, 0xa74}, {0xa85, 0xa8d}, {0xa8f, 0xa91},
  {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9}, {0xabd, 0xabd}, {0xad0, 0xad0}, {0xae0, 0xae1}, {0xaf9, 0xaf9},
  {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33}, {0xb35, 0xb39}, {0xb3d, 0xb3d}, {0xb5c, 0xb5d},
  {0xb5f, 0xb61}, {0xb70, 0xb71}, {0xb83, 0xb83}, {0xb85, 0xb8a}, {0xb8e, 0xb90}, {0xb92, 0xb95}, {0xb99, 0xb9a}, {0xb9c, 0xb9c},
  {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9}, {0xbd0, 0xbd0}, {0xbf3, 0xbf8}, {0xbfa, 0xbfa}, {0xc05, 0xc0c},
  {0xc0e, 0xc10}, {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3d, 0xc3d}, {0xc58, 0xc5a}, {0xc5d, 0xc5d}, {0xc60, 0xc61}, {0xc7f, 0xc80},
  {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9}, {0xcbd, 0xcbd}, {0xcdd, 0xcde}, {0xce0, 0xce1},
  {0xcf1, 0xcf2}, {0xd04, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd3a}, {0xd3d, 0xd3d}, {0xd4e, 0xd4f}, {0xd54, 0xd56}, {0xd5f, 0xd61},
  {0xd79, 0xd7f}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6}, {0xe01, 0xe30}, {0xe32, 0xe33},
  {0xe40, 0xe46}, {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xeb0}, {0xeb2, 0xeb3},
  {0xebd, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6}, {0xedc, 0xedf}, {0xf00, 0xf03}, {0xf13, 0xf13}, {0xf15, 0xf17}, {0xf1a, 0xf1f},
  {0xf34, 0xf34}, {0xf36, 0xf36}, {0xf38, 0xf38}, {0xf40, 0xf47}, {0xf49, 0xf6c}, {0xf88, 0xf8c}, {0xfbe, 0xfc5}, {0xfc7, 0xfcc},
  {0xfce, 0xfcf}, {0xfd5, 0xfd8}, {0x1000, 0x102a}, {0x103f, 0x103f}, {0x1050, 0x1055}, {0x105a, 0x105d}, {0x1061, 0x1061}, {0x1065, 0x1066},
  {0x106e, 0x1070}, {0x1075, 0x1081}, {0x108e, 0x108e}, {0x109e, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248},
  {0x124a, 0x124d}, {0x1250, 0x1256}, {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5},
  {0x12b8, 0x12be}, {0x12c0, 0x12c0}, {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x1380, 0x1399},
  {0x13a0, 0x13f5}, {0x13f8, 0x13fd}, {0x1401, 0x166d}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8}, {0x1700, 0x1711},
  {0x171f, 0x1731}, {0x1740, 0x1751}, {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1780, 0x17b3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dc}, {0x1820, 0x1878},
  {0x1880, 0x1884}, {0x1887, 0x18a8}, {0x18aa, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1940, 0x1940}, {0x1950, 0x196d}, {0x1970, 0x1974},
  {0x1980, 0x19ab}, {0x19b0, 0x19c9}, {0x19de, 0x1a16}, {0x1a20, 0x1a54}, {0x1aa7, 0x1aa7}, {0x1b05, 0x1b33}, {0x1b45, 0x1b4c}, {0x1b61, 0x1b6a},
  {0x1b74, 0x1b7c}, {0x1b83, 0x1ba0}, {0x1bae, 0x1baf}, {0x1bba, 0x1be5}, {0x1c00, 0x1c23}, {0x1c4d, 0x1c4f}, {0x1c5a, 0x1c7d}, {0x1c80, 0x1c88},
  {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1ce9, 0x1cec}, {0x1cee, 0x1cf3}, {0x1cf5, 0x1cf6}, {0x1cfa, 0x1cfa}, {0x1d00, 0x1dbf}, {0x1e00, 0x1f15},
  {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57}, {0x1f59, 0x1f59}, {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d},
  {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4}, {0x1fc6, 0x1fcc}, {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec},
  {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x2044, 0x2044}, {0x2052, 0x2052}, {0x2071, 0x2071}, {0x207a, 0x207c}, {0x207f, 0x207f}, {0x208a, 0x208c},
  {0x2090, 0x209c}, {0x2100, 0x214f}, {0x2160, 0x2188}, {0x218a, 0x218b}, {0x2190, 0x2307}, {0x230c, 0x2328}, {0x232b, 0x2426}, {0x2440, 0x244a},
  {0x249c, 0x24e9}, {0x2500, 0x2767}, {0x2794, 0x27c4}, {0x27c7, 0x27e5}, {0x27f0, 0x2982}, {0x2999, 0x29d7}, {0x29dc, 0x29fb}, {0x29fe, 0x2b73},
  {0x2b76, 0x2b95}, {0x2b97, 0x2cee}, {0x2cf2, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d}, {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f},
  {0x2d80, 0x2d96}, {0x2da0, 0x2da6}, {0x2da8, 0x2dae}, {0x2db0, 0x2db6}, {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6}, {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6},
  {0x2dd8, 0x2dde}, {0x2e2f, 0x2e2f}, {0x2e50, 0x2e51}, {0x2e80, 0x2e99}, {0x2e9b, 0x2ef3}, {0x2f00, 0x2fd5}, {0x2ff0, 0x2fff}, {0x3004, 0x3007},
  {0x3012, 0x3013}, {0x3020, 0x3029}, {0x3031, 0x303c}, {0x303e, 0x303f}, {0x3041, 0x3096}, {0x309d, 0x309f}, {0x30a1, 0x30fa}, {0x30fc, 0x30ff},
  {0x3105, 0x312f}, {0x3131, 0x318e}, {0x3190, 0x3191}, {0x3196, 0x31e3}, {0x31ef, 0x321e}, {0x322a, 0x3247}, {0x3250, 0x3250}, {0x3260, 0x327f},
  {0x328a, 0x32b0}, {0x32c0, 0x3400}, {0x4dbf, 0x4e00}, {0x9fff, 0xa48c}, {0xa490, 0xa4c6}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa61f},
  {0xa62a, 0xa62b}, {0xa640, 0xa66e}, {0xa67f, 0xa69d}, {0xa6a0, 0xa6ef}, {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7ca}, {0xa7d0, 0xa7d1},
  {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d9}, {0xa7f2, 0xa801}, {0xa803, 0xa805}, {0xa807, 0xa80a}, {0xa80c, 0xa822}, {0xa828, 0xa82b}, {0xa836, 0xa837},
  {0xa839, 0xa839}, {0xa840, 0xa873}, {0xa882, 0xa8b3}, {0xa8f2, 0xa8f7}, {0xa8fb, 0xa8fb}, {0xa8fd, 0xa8fe}, {0xa90a, 0xa925}, {0xa930, 0xa946},
  {0xa960, 0xa97c}, {0xa984, 0xa9b2}, {0xa9cf, 0xa9cf}, {0xa9e0, 0xa9e4}, {0xa9e6, 0xa9ef}, {0xa9fa, 0xa9fe}, {0xaa00, 0xaa28}, {0xaa40, 0xaa42},
  {0xaa44, 0xaa4b}, {0xaa60, 0xaa7a}, {0xaa7e, 0xaaaf}, {0xaab1, 0xaab1}, {0xaab5, 0xaab6}, {0xaab9, 0xaabd}, {0xaac0, 0xaac0}, {0xaac2, 0xaac2},
  {0xaadb, 0xaadd}, {0xaae0, 0xaaea}, {0xaaf2, 0xaaf4}, {0xab01, 0xab06}, {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26}, {0xab28, 0xab2e},
  {0xab30, 0xab5a}, {0xab5c, 0xab69}, {0xab70, 0xabe2}, {0xac00, 0xac00}, {0xd7a3, 0xd7a3}, {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb}, {0xf900, 0xfa6d},
  {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb1d}, {0xfb1f, 0xfb36}, {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41},
  {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfd3d}, {0xfd40, 0xfd8f}, {0xfd92, 0xfdc7}, {0xfdcf, 0xfdcf}, {0xfdf0, 0xfdfb}, {0xfdfd, 0xfdff},
  {0xfe62, 0xfe62}, {0xfe64, 0xfe66}, {0xfe70, 0xfe74}, {0xfe76, 0xfefc}, {0xff0b, 0xff0b}, {0xff1c, 0xff1e}, {0xff21, 0xff3a}, {0xff41, 0xff5a},
  {0xff5c, 0xff5c}, {0xff5e, 0xff5e}, {0xff66, 0xffbe}, {0xffc2, 0xffc7}, {0xffca, 0xffcf}, {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0xffe2, 0xffe2},
  {0xffe4, 0xffe4}, {0xffe8, 0xffee}, {0xfffc, 0xfffd}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a}, {0x1003c, 0x1003d}, {0x1003f, 0x1004d},
  {0x10050, 0x1005d}, {0x10080, 0x100fa}, {0x10137, 0x10174}, {0x10179, 0x10189}, {0x1018c, 0x1018e}, {0x10190, 0x1019c}, {0x101a0, 0x101a0}, {0x101d0, 0x101fc},
  {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x10300, 0x1031f}, {0x1032d, 0x1034a}, {0x10350, 0x10375}, {0x10380, 0x1039d}, {0x103a0, 0x103c3}, {0x103c8, 0x103cf},
  {0x103d1, 0x103d5}, {0x10400, 0x1049d}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527}, {0x10530, 0x10563}, {0x10570, 0x1057a}, {0x1057c, 0x1058a},
  {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc}, {0x10600, 0x10736}, {0x10740, 0x10755},
  {0x10760, 0x10767}, {0x10780, 0x10785}, {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808}, {0x1080a, 0x10835}, {0x10837, 0x10838},
  {0x1083c, 0x1083c}, {0x1083f, 0x10855}, {0x10860, 0x10878}, {0x10880, 0x1089e}, {0x108e0, 0x108f2}, {0x108f4, 0x108f5}, {0x10900, 0x10915},
};

static TSCharacterRange sym__alpha_identifier_character_set_4[] = {
  {'!', '!'}, {'#', '#'}, {'%', '&'}, {'*', '+'}, {'-', '-'}, {'/', '/'}, {':', ':'}, {'<', '@'},
  {'\\', '\\'}, {'^', '^'}, {'|', '|'}, {'~', '~'}, {0xa6, 0xa6}, {0xa9, 0xa9}, {0xac, 0xac}, {0xae, 0xae},
  {0xb0, 0xb1}, {0xd7, 0xd7}, {0xf7, 0xf7}, {0x3f6, 0x3f6}, {0x482, 0x482}, {0x58d, 0x58e}, {0x606, 0x608}, {0x60e, 0x60f},
  {0x6de, 0x6de}, {0x6e9, 0x6e9}, {0x6fd, 0x6fe}, {0x7f6, 0x7f6}, {0x9fa, 0x9fa}, {0xb70, 0xb70}, {0xbf3, 0xbf8}, {0xbfa, 0xbfa},
  {0xc7f, 0xc7f}, {0xd4f, 0xd4f}, {0xd79, 0xd79}, {0xf01, 0xf03}, {0xf13, 0xf13}, {0xf15, 0xf17}, {0xf1a, 0xf1f}, {0xf34, 0xf34},
  {0xf36, 0xf36}, {0xf38, 0xf38}, {0xfbe, 0xfc5}, {0xfc7, 0xfcc}, {0xfce, 0xfcf}, {0xfd5, 0xfd8}, {0x109e, 0x109f}, {0x1390, 0x1399},
  {0x166d, 0x166d}, {0x1940, 0x1940}, {0x19de, 0x19ff}, {0x1b61, 0x1b6a}, {0x1b74, 0x1b7c}, {0x2044, 0x2044}, {0x2052, 0x2052}, {0x207a, 0x207c},
  {0x208a, 0x208c}, {0x2100, 0x2101}, {0x2103, 0x2106}, {0x2108, 0x2109}, {0x2114, 0x2114}, {0x2116, 0x2118}, {0x211e, 0x2123}, {0x2125, 0x2125},
  {0x2127, 0x2127}, {0x2129, 0x2129}, {0x212e, 0x212e}, {0x213a, 0x213b}, {0x2140, 0x2144}, {0x214a, 0x214d}, {0x214f, 0x214f}, {0x218a, 0x218b},
  {0x2190, 0x2307}, {0x230c, 0x2328}, {0x232b, 0x2426}, {0x2440, 0x244a}, {0x249c, 0x24e9}, {0x2500, 0x2767}, {0x2794, 0x27c4}, {0x27c7, 0x27e5},
  {0x27f0, 0x2982}, {0x2999, 0x29d7}, {0x29dc, 0x29fb}, {0x29fe, 0x2b73}, {0x2b76, 0x2b95}, {0x2b97, 0x2bff}, {0x2ce5, 0x2cea}, {0x2e50, 0x2e51},
  {0x2e80, 0x2e99}, {0x2e9b, 0x2ef3}, {0x2f00, 0x2fd5}, {0x2ff0, 0x2fff}, {0x3004, 0x3004}, {0x3012, 0x3013}, {0x3020, 0x3020}, {0x3036, 0x3037},
  {0x303e, 0x303f}, {0x3190, 0x3191}, {0x3196, 0x319f}, {0x31c0, 0x31e3}, {0x31ef, 0x31ef}, {0x3200, 0x321e}, {0x322a, 0x3247}, {0x3250, 0x3250},
  {0x3260, 0x327f}, {0x328a, 0x32b0}, {0x32c0, 0x33ff}, {0x4dc0, 0x4dff}, {0xa490, 0xa4c6}, {0xa828, 0xa82b}, {0xa836, 0xa837}, {0xa839, 0xa839},
  {0xaa77, 0xaa79}, {0xfb29, 0xfb29}, {0xfd40, 0xfd4f}, {0xfdcf, 0xfdcf}, {0xfdfd, 0xfdff}, {0xfe62, 0xfe62}, {0xfe64, 0xfe66}, {0xff0b, 0xff0b},
  {0xff1c, 0xff1e}, {0xff5c, 0xff5c}, {0xff5e, 0xff5e}, {0xffe2, 0xffe2}, {0xffe4, 0xffe4}, {0xffe8, 0xffee}, {0xfffc, 0xfffd}, {0x10137, 0x1013f},
  {0x10179, 0x10189}, {0x1018c, 0x1018e}, {0x10190, 0x1019c}, {0x101a0, 0x101a0}, {0x101d0, 0x101fc}, {0x10877, 0x10878},
};

static TSCharacterRange sym__interpolation_identifier_character_set_1[] = {
  {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5}, {0xba, 0xbb}, {0xc0, 0xd6}, {0xd8, 0xf6},
  {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee}, {0x370, 0x374}, {0x376, 0x377}, {0x37a, 0x37d},
  {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5}, {0x3f7, 0x481}, {0x48a, 0x52f},
  {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x620, 0x64a}, {0x66e, 0x66f}, {0x671, 0x6d3},
  {0x6d5, 0x6d5}, {0x6e5, 0x6e6}, {0x6ee, 0x6ef}, {0x6fa, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x710}, {0x712, 0x72f}, {0x74d, 0x7a5},
  {0x7b1, 0x7b1}, {0x7ca, 0x7ea}, {0x7f4, 0x7f5}, {0x7fa, 0x7fa}, {0x800, 0x815}, {0x81a, 0x81a}, {0x824, 0x824}, {0x828, 0x828},
  {0x840, 0x858}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x8a0, 0x8c9}, {0x904, 0x939}, {0x93d, 0x93d}, {0x950, 0x950},
  {0x958, 0x961}, {0x971, 0x980}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2}, {0x9b6, 0x9b9},
  {0x9bd, 0x9bd}, {0x9ce, 0x9ce}, {0x9dc, 0x9dd}, {0x9df, 0x9e1}, {0x9f0, 0x9f1}, {0x9fc, 0x9fc}, {0xa05, 0xa0a}, {0xa0f, 0xa10},
  {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33}, {0xa35, 0xa36}, {0xa38, 0xa39}, {0xa59, 0xa5c}, {0xa5e, 0xa5e}, {0xa72, 0xa74},
  {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9}, {0xabd, 0xabd}, {0xad0, 0xad0},
  {0xae0, 0xae1}, {0xaf9, 0xaf9}, {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33}, {0xb35, 0xb39},
  {0xb3d, 0xb3d}, {0xb5c, 0xb5d}, {0xb5f, 0xb61}, {0xb71, 0xb71}, {0xb83, 0xb83}, {0xb85, 0xb8a}, {0xb8e, 0xb90}, {0xb92, 0xb95},
  {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9}, {0xbd0, 0xbd0}, {0xc05, 0xc0c},
  {0xc0e, 0xc10}, {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3d, 0xc3d}, {0xc58, 0xc5a}, {0xc5d, 0xc5d}, {0xc60, 0xc61}, {0xc80, 0xc80},
  {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9}, {0xcbd, 0xcbd}, {0xcdd, 0xcde}, {0xce0, 0xce1},
  {0xcf1, 0xcf2}, {0xd04, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd3a}, {0xd3d, 0xd3d}, {0xd4e, 0xd4e}, {0xd54, 0xd56}, {0xd5f, 0xd61},
  {0xd7a, 0xd7f}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6}, {0xe01, 0xe30}, {0xe32, 0xe33},
  {0xe40, 0xe46}, {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xeb0}, {0xeb2, 0xeb3},
  {0xebd, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf40, 0xf47}, {0xf49, 0xf6c}, {0xf88, 0xf8c},
  {0x1000, 0x102a}, {0x103f, 0x103f}, {0x1050, 0x1055}, {0x105a, 0x105d}, {0x1061, 0x1061}, {0x1065, 0x1066}, {0x106e, 0x1070}, {0x1075, 0x1081},
  {0x108e, 0x108e}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248}, {0x124a, 0x124d}, {0x1250, 0x1256},
  {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5}, {0x12b8, 0x12be}, {0x12c0, 0x12c0},
  {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x1380, 0x138f}, {0x13a0, 0x13f5}, {0x13f8, 0x13fd},
  {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8}, {0x1700, 0x1711}, {0x171f, 0x1731}, {0x1740, 0x1751},
  {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1780, 0x17b3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dc}, {0x1820, 0x1878}, {0x1880, 0x1884}, {0x1887, 0x18a8},
  {0x18aa, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1950, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9}, {0x1a00, 0x1a16},
  {0x1a20, 0x1a54}, {0x1aa7, 0x1aa7}, {0x1b05, 0x1b33}, {0x1b45, 0x1b4c}, {0x1b83, 0x1ba0}, {0x1bae, 0x1baf}, {0x1bba, 0x1be5}, {0x1c00, 0x1c23},
  {0x1c4d, 0x1c4f}, {0x1c5a, 0x1c7d}, {0x1c80, 0x1c88}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1ce9, 0x1cec}, {0x1cee, 0x1cf3}, {0x1cf5, 0x1cf6},
  {0x1cfa, 0x1cfa}, {0x1d00, 0x1dbf}, {0x1e00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57}, {0x1f59, 0x1f59},
  {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4}, {0x1fc6, 0x1fcc},
  {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x2071, 0x2071}, {0x207f, 0x207f}, {0x2090, 0x209c},
  {0x2102, 0x2102}, {0x2107, 0x2107}, {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2119, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126}, {0x2128, 0x2128},
  {0x212a, 0x212d}, {0x212f, 0x2139}, {0x213c, 0x213f}, {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2160, 0x2188}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cee},
  {0x2cf2, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d}, {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d80, 0x2d96}, {0x2da0, 0x2da6},
  {0x2da8, 0x2dae}, {0x2db0, 0x2db6}, {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6}, {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x2e2f, 0x2e2f},
  {0x3005, 0x3007}, {0x3021, 0x3029}, {0x3031, 0x3035}, {0x3038, 0x303c}, {0x3041, 0x3096}, {0x309d, 0x309f}, {0x30a1, 0x30fa}, {0x30fc, 0x30ff},
  {0x3105, 0x312f}, {0x3131, 0x318e}, {0x31a0, 0x31bf}, {0x31f0, 0x31ff}, {0x3400, 0x3400}, {0x4dbf, 0x4dbf}, {0x4e00, 0x4e00}, {0x9fff, 0xa48c},
  {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa61f}, {0xa62a, 0xa62b}, {0xa640, 0xa66e}, {0xa67f, 0xa69d}, {0xa6a0, 0xa6ef}, {0xa717, 0xa71f},
  {0xa722, 0xa788}, {0xa78b, 0xa7ca}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d9}, {0xa7f2, 0xa801}, {0xa803, 0xa805}, {0xa807, 0xa80a},
  {0xa80c, 0xa822}, {0xa840, 0xa873}, {0xa882, 0xa8b3}, {0xa8f2, 0xa8f7}, {0xa8fb, 0xa8fb}, {0xa8fd, 0xa8fe}, {0xa90a, 0xa925}, {0xa930, 0xa946},
  {0xa960, 0xa97c}, {0xa984, 0xa9b2}, {0xa9cf, 0xa9cf}, {0xa9e0, 0xa9e4}, {0xa9e6, 0xa9ef}, {0xa9fa, 0xa9fe}, {0xaa00, 0xaa28}, {0xaa40, 0xaa42},
  {0xaa44, 0xaa4b}, {0xaa60, 0xaa76}, {0xaa7a, 0xaa7a}, {0xaa7e, 0xaaaf}, {0xaab1, 0xaab1}, {0xaab5, 0xaab6}, {0xaab9, 0xaabd}, {0xaac0, 0xaac0},
  {0xaac2, 0xaac2}, {0xaadb, 0xaadd}, {0xaae0, 0xaaea}, {0xaaf2, 0xaaf4}, {0xab01, 0xab06}, {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26},
  {0xab28, 0xab2e}, {0xab30, 0xab5a}, {0xab5c, 0xab69}, {0xab70, 0xabe2}, {0xac00, 0xac00}, {0xd7a3, 0xd7a3}, {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb},
  {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb1d}, {0xfb1f, 0xfb28}, {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c},
  {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfd3d}, {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7}, {0xfdf0, 0xfdfb},
  {0xfe70, 0xfe74}, {0xfe76, 0xfefc}, {0xff21, 0xff3a}, {0xff41, 0xff5a}, {0xff66, 0xffbe}, {0xffc2, 0xffc7}, {0xffca, 0xffcf}, {0xffd2, 0xffd7},
  {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a}, {0x1003c, 0x1003d}, {0x1003f, 0x1004d}, {0x10050, 0x1005d}, {0x10080, 0x100fa},
  {0x10140, 0x10174}, {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x10300, 0x1031f}, {0x1032d, 0x1034a}, {0x10350, 0x10375}, {0x10380, 0x1039d}, {0x103a0, 0x103c3},
  {0x103c8, 0x103cf}, {0x103d1, 0x103d5}, {0x10400, 0x1049d}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527}, {0x10530, 0x10563}, {0x10570, 0x1057a},
  {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc}, {0x10600, 0x10736},
  {0x10740, 0x10755}, {0x10760, 0x10767}, {0x10780, 0x10785}, {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808}, {0x1080a, 0x10835},
  {0x10837, 0x10838}, {0x1083c, 0x1083c}, {0x1083f, 0x10855}, {0x10860, 0x10876}, {0x10880, 0x1089e}, {0x108e0, 0x108f2}, {0x108f4, 0x108f5}, {0x10900, 0x10915},
};

static TSCharacterRange sym__interpolation_identifier_character_set_2[] = {
  {'0', '9'}, {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5}, {0xba, 0xbb}, {0xc0, 0xd6},
  {0xd8, 0xf6}, {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee}, {0x370, 0x374}, {0x376, 0x377},
  {0x37a, 0x37d}, {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5}, {0x3f7, 0x481},
  {0x48a, 0x52f}, {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x620, 0x64a}, {0x66e, 0x66f},
  {0x671, 0x6d3}, {0x6d5, 0x6d5}, {0x6e5, 0x6e6}, {0x6ee, 0x6ef}, {0x6fa, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x710}, {0x712, 0x72f},
  {0x74d, 0x7a5}, {0x7b1, 0x7b1}, {0x7ca, 0x7ea}, {0x7f4, 0x7f5}, {0x7fa, 0x7fa}, {0x800, 0x815}, {0x81a, 0x81a}, {0x824, 0x824},
  {0x828, 0x828}, {0x840, 0x858}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x8a0, 0x8c9}, {0x904, 0x939}, {0x93d, 0x93d},
  {0x950, 0x950}, {0x958, 0x961}, {0x971, 0x980}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2},
  {0x9b6, 0x9b9}, {0x9bd, 0x9bd}, {0x9ce, 0x9ce}, {0x9dc, 0x9dd}, {0x9df, 0x9e1}, {0x9f0, 0x9f1}, {0x9fc, 0x9fc}, {0xa05, 0xa0a},
  {0xa0f, 0xa10}, {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33}, {0xa35, 0xa36}, {0xa38, 0xa39}, {0xa59, 0xa5c}, {0xa5e, 0xa5e},
  {0xa72, 0xa74}, {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9}, {0xabd, 0xabd},
  {0xad0, 0xad0}, {0xae0, 0xae1}, {0xaf9, 0xaf9}, {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33},
  {0xb35, 0xb39}, {0xb3d, 0xb3d}, {0xb5c, 0xb5d}, {0xb5f, 0xb61}, {0xb71, 0xb71}, {0xb83, 0xb83}, {0xb85, 0xb8a}, {0xb8e, 0xb90},
  {0xb92, 0xb95}, {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9}, {0xbd0, 0xbd0},
  {0xc05, 0xc0c}, {0xc0e, 0xc10}, {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3d, 0xc3d}, {0xc58, 0xc5a}, {0xc5d, 0xc5d}, {0xc60, 0xc61},
  {0xc80, 0xc80}, {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9}, {0xcbd, 0xcbd}, {0xcdd, 0xcde},
  {0xce0, 0xce1}, {0xcf1, 0xcf2}, {0xd04, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd3a}, {0xd3d, 0xd3d}, {0xd4e, 0xd4e}, {0xd54, 0xd56},
  {0xd5f, 0xd61}, {0xd7a, 0xd7f}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6}, {0xe01, 0xe30},
  {0xe32, 0xe33}, {0xe40, 0xe46}, {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xeb0},
  {0xeb2, 0xeb3}, {0xebd, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf40, 0xf47}, {0xf49, 0xf6c},
  {0xf88, 0xf8c}, {0x1000, 0x102a}, {0x103f, 0x103f}, {0x1050, 0x1055}, {0x105a, 0x105d}, {0x1061, 0x1061}, {0x1065, 0x1066}, {0x106e, 0x1070},
  {0x1075, 0x1081}, {0x108e, 0x108e}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248}, {0x124a, 0x124d},
  {0x1250, 0x1256}, {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5}, {0x12b8, 0x12be},
  {0x12c0, 0x12c0}, {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x1380, 0x138f}, {0x13a0, 0x13f5},
  {0x13f8, 0x13fd}, {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8}, {0x1700, 0x1711}, {0x171f, 0x1731},
  {0x1740, 0x1751}, {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1780, 0x17b3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dc}, {0x1820, 0x1878}, {0x1880, 0x1884},
  {0x1887, 0x18a8}, {0x18aa, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1950, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9},
  {0x1a00, 0x1a16}, {0x1a20, 0x1a54}, {0x1aa7, 0x1aa7}, {0x1b05, 0x1b33}, {0x1b45, 0x1b4c}, {0x1b83, 0x1ba0}, {0x1bae, 0x1baf}, {0x1bba, 0x1be5},
  {0x1c00, 0x1c23}, {0x1c4d, 0x1c4f}, {0x1c5a, 0x1c7d}, {0x1c80, 0x1c88}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1ce9, 0x1cec}, {0x1cee, 0x1cf3},
  {0x1cf5, 0x1cf6}, {0x1cfa, 0x1cfa}, {0x1d00, 0x1dbf}, {0x1e00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57},
  {0x1f59, 0x1f59}, {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4},
  {0x1fc6, 0x1fcc}, {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x2071, 0x2071}, {0x207f, 0x207f},
  {0x2090, 0x209c}, {0x2102, 0x2102}, {0x2107, 0x2107}, {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2119, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126},
  {0x2128, 0x2128}, {0x212a, 0x212d}, {0x212f, 0x2139}, {0x213c, 0x213f}, {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2160, 0x2188}, {0x2c00, 0x2ce4},
  {0x2ceb, 0x2cee}, {0x2cf2, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d}, {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d80, 0x2d96},
  {0x2da0, 0x2da6}, {0x2da8, 0x2dae}, {0x2db0, 0x2db6}, {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6}, {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde},
  {0x2e2f, 0x2e2f}, {0x3005, 0x3007}, {0x3021, 0x3029}, {0x3031, 0x3035}, {0x3038, 0x303c}, {0x3041, 0x3096}, {0x309d, 0x309f}, {0x30a1, 0x30fa},
  {0x30fc, 0x30ff}, {0x3105, 0x312f}, {0x3131, 0x318e}, {0x31a0, 0x31bf}, {0x31f0, 0x31ff}, {0x3400, 0x3400}, {0x4dbf, 0x4dbf}, {0x4e00, 0x4e00},
  {0x9fff, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa61f}, {0xa62a, 0xa62b}, {0xa640, 0xa66e}, {0xa67f, 0xa69d}, {0xa6a0, 0xa6ef},
  {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7ca}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d9}, {0xa7f2, 0xa801}, {0xa803, 0xa805},
  {0xa807, 0xa80a}, {0xa80c, 0xa822}, {0xa840, 0xa873}, {0xa882, 0xa8b3}, {0xa8f2, 0xa8f7}, {0xa8fb, 0xa8fb}, {0xa8fd, 0xa8fe}, {0xa90a, 0xa925},
  {0xa930, 0xa946}, {0xa960, 0xa97c}, {0xa984, 0xa9b2}, {0xa9cf, 0xa9cf}, {0xa9e0, 0xa9e4}, {0xa9e6, 0xa9ef}, {0xa9fa, 0xa9fe}, {0xaa00, 0xaa28},
  {0xaa40, 0xaa42}, {0xaa44, 0xaa4b}, {0xaa60, 0xaa76}, {0xaa7a, 0xaa7a}, {0xaa7e, 0xaaaf}, {0xaab1, 0xaab1}, {0xaab5, 0xaab6}, {0xaab9, 0xaabd},
  {0xaac0, 0xaac0}, {0xaac2, 0xaac2}, {0xaadb, 0xaadd}, {0xaae0, 0xaaea}, {0xaaf2, 0xaaf4}, {0xab01, 0xab06}, {0xab09, 0xab0e}, {0xab11, 0xab16},
  {0xab20, 0xab26}, {0xab28, 0xab2e}, {0xab30, 0xab5a}, {0xab5c, 0xab69}, {0xab70, 0xabe2}, {0xac00, 0xac00}, {0xd7a3, 0xd7a3}, {0xd7b0, 0xd7c6},
  {0xd7cb, 0xd7fb}, {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb1d}, {0xfb1f, 0xfb28}, {0xfb2a, 0xfb36},
  {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfd3d}, {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7},
  {0xfdf0, 0xfdfb}, {0xfe70, 0xfe74}, {0xfe76, 0xfefc}, {0xff21, 0xff3a}, {0xff41, 0xff5a}, {0xff66, 0xffbe}, {0xffc2, 0xffc7}, {0xffca, 0xffcf},
  {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a}, {0x1003c, 0x1003d}, {0x1003f, 0x1004d}, {0x10050, 0x1005d},
  {0x10080, 0x100fa}, {0x10140, 0x10174}, {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x10300, 0x1031f}, {0x1032d, 0x1034a}, {0x10350, 0x10375}, {0x10380, 0x1039d},
  {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x103d1, 0x103d5}, {0x10400, 0x1049d}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527}, {0x10530, 0x10563},
  {0x10570, 0x1057a}, {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc},
  {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767}, {0x10780, 0x10785}, {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808},
  {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c}, {0x1083f, 0x10855}, {0x10860, 0x10876}, {0x10880, 0x1089e}, {0x108e0, 0x108f2}, {0x108f4, 0x108f5},
  {0x10900, 0x10915},
};

static TSCharacterRange sym_operator_identifier_character_set_1[] = {
  {'!', '!'}, {'#', '#'}, {'%', '&'}, {'+', '+'}, {'-', '-'}, {':', ':'}, {'<', '@'}, {'\\', '\\'},
  {'^', '^'}, {'|', '|'}, {'~', '~'}, {0xa6, 0xa6}, {0xa9, 0xa9}, {0xac, 0xac}, {0xae, 0xae}, {0xb0, 0xb1},
  {0xd7, 0xd7}, {0xf7, 0xf7}, {0x3f6, 0x3f6}, {0x482, 0x482}, {0x58d, 0x58e}, {0x606, 0x608}, {0x60e, 0x60f}, {0x6de, 0x6de},
  {0x6e9, 0x6e9}, {0x6fd, 0x6fe}, {0x7f6, 0x7f6}, {0x9fa, 0x9fa}, {0xb70, 0xb70}, {0xbf3, 0xbf8}, {0xbfa, 0xbfa}, {0xc7f, 0xc7f},
  {0xd4f, 0xd4f}, {0xd79, 0xd79}, {0xf01, 0xf03}, {0xf13, 0xf13}, {0xf15, 0xf17}, {0xf1a, 0xf1f}, {0xf34, 0xf34}, {0xf36, 0xf36},
  {0xf38, 0xf38}, {0xfbe, 0xfc5}, {0xfc7, 0xfcc}, {0xfce, 0xfcf}, {0xfd5, 0xfd8}, {0x109e, 0x109f}, {0x1390, 0x1399}, {0x166d, 0x166d},
  {0x1940, 0x1940}, {0x19de, 0x19ff}, {0x1b61, 0x1b6a}, {0x1b74, 0x1b7c}, {0x2044, 0x2044}, {0x2052, 0x2052}, {0x207a, 0x207c}, {0x208a, 0x208c},
  {0x2100, 0x2101}, {0x2103, 0x2106}, {0x2108, 0x2109}, {0x2114, 0x2114}, {0x2116, 0x2118}, {0x211e, 0x2123}, {0x2125, 0x2125}, {0x2127, 0x2127},
  {0x2129, 0x2129}, {0x212e, 0x212e}, {0x213a, 0x213b}, {0x2140, 0x2144}, {0x214a, 0x214d}, {0x214f, 0x214f}, {0x218a, 0x218b}, {0x2190, 0x2307},
  {0x230c, 0x2328}, {0x232b, 0x2426}, {0x2440, 0x244a}, {0x249c, 0x24e9}, {0x2500, 0x2767}, {0x2794, 0x27c4}, {0x27c7, 0x27e5}, {0x27f0, 0x2982},
  {0x2999, 0x29d7}, {0x29dc, 0x29fb}, {0x29fe, 0x2b73}, {0x2b76, 0x2b95}, {0x2b97, 0x2bff}, {0x2ce5, 0x2cea}, {0x2e50, 0x2e51}, {0x2e80, 0x2e99},
  {0x2e9b, 0x2ef3}, {0x2f00, 0x2fd5}, {0x2ff0, 0x2fff}, {0x3004, 0x3004}, {0x3012, 0x3013}, {0x3020, 0x3020}, {0x3036, 0x3037}, {0x303e, 0x303f},
  {0x3190, 0x3191}, {0x3196, 0x319f}, {0x31c0, 0x31e3}, {0x31ef, 0x31ef}, {0x3200, 0x321e}, {0x322a, 0x3247}, {0x3250, 0x3250}, {0x3260, 0x327f},
  {0x328a, 0x32b0}, {0x32c0, 0x33ff}, {0x4dc0, 0x4dff}, {0xa490, 0xa4c6}, {0xa828, 0xa82b}, {0xa836, 0xa837}, {0xa839, 0xa839}, {0xaa77, 0xaa79},
  {0xfb29, 0xfb29}, {0xfd40, 0xfd4f}, {0xfdcf, 0xfdcf}, {0xfdfd, 0xfdff}, {0xfe62, 0xfe62}, {0xfe64, 0xfe66}, {0xff0b, 0xff0b}, {0xff1c, 0xff1e},
  {0xff5c, 0xff5c}, {0xff5e, 0xff5e}, {0xffe2, 0xffe2}, {0xffe4, 0xffe4}, {0xffe8, 0xffee}, {0xfffc, 0xfffd}, {0x10137, 0x1013f}, {0x10179, 0x10189},
  {0x1018c, 0x1018e}, {0x10190, 0x1019c}, {0x101a0, 0x101a0}, {0x101d0, 0x101fc}, {0x10877, 0x10878},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '!', 107,
        '"', 141,
        '#', 100,
        '$', 112,
        '\'', 113,
        '(', 97,
        ')', 98,
        '*', 75,
        '+', 81,
        ',', 72,
        '-', 84,
        '.', 74,
        '/', 22,
        '0', 132,
        ':', 68,
        ';', 99,
        '<', 12,
        '=', 94,
        '>', 153,
        '?', 27,
        '@', 91,
        '[', 79,
        ']', 80,
        '`', 46,
        '{', 70,
        '|', 105,
        '}', 71,
        '~', 109,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(47);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(133);
      if (set_contains(sym__interpolation_identifier_character_set_2, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(1);
      if (lookahead == '*') ADVANCE(165);
      if (lookahead == '/') ADVANCE(163);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(164);
      if (lookahead != 0) ADVANCE(162);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '!', 108,
        '$', 112,
        '\'', 113,
        '(', 97,
        '+', 82,
        '-', 83,
        '.', 38,
        '/', 122,
        '0', 132,
        ':', 69,
        '=', 30,
        '[', 79,
        '`', 46,
        '{', 70,
        '~', 110,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(2);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(133);
      if (lookahead == '@' ||
          lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__interpolation_identifier_character_set_2, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '"', 141,
        '(', 97,
        ')', 98,
        '*', 76,
        ',', 72,
        '.', 73,
        '/', 122,
        ':', 69,
        '<', 123,
        '=', 96,
        '@', 92,
        '[', 79,
        ']', 80,
        '`', 46,
        '|', 106,
        '}', 71,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '"', 141,
        '(', 97,
        '*', 76,
        '.', 73,
        '/', 122,
        ':', 69,
        '=', 30,
        '@', 92,
        '`', 46,
        '|', 106,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(4);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 5:
      if (lookahead == '"') ADVANCE(142);
      END_STATE();
    case 6:
      if (lookahead == '"') ADVANCE(140);
      if (lookahead == '$') ADVANCE(111);
      if (lookahead == '/') ADVANCE(22);
      if (lookahead == '=') ADVANCE(32);
      if (lookahead == '{') ADVANCE(70);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(6);
      if (set_contains(sym__interpolation_identifier_character_set_1, 432, lookahead)) ADVANCE(117);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '#', 101,
        '(', 97,
        ')', 98,
        '*', 76,
        ',', 72,
        '.', 73,
        '/', 122,
        ':', 69,
        '<', 123,
        '=', 95,
        '?', 126,
        '@', 92,
        '[', 79,
        '`', 46,
        '{', 70,
        '|', 106,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '#', 101,
        '(', 97,
        '+', 82,
        '-', 85,
        '.', 73,
        '/', 122,
        '@', 92,
        '[', 79,
        '`', 46,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      if (lookahead == ':' ||
          lookahead == '=' ||
          lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '#', 101,
        '(', 97,
        ',', 72,
        '.', 73,
        '/', 122,
        ':', 69,
        '<', 120,
        '=', 30,
        '?', 126,
        '@', 92,
        '[', 79,
        ']', 80,
        '`', 46,
        '{', 70,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '#', 101,
        '(', 97,
        ',', 72,
        '.', 73,
        '/', 122,
        ':', 69,
        '<', 121,
        '=', 30,
        '?', 126,
        '@', 92,
        '[', 79,
        ']', 80,
        '`', 46,
        '{', 70,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(10);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '#', 101,
        '(', 97,
        '.', 73,
        '/', 122,
        ':', 69,
        '=', 95,
        '@', 92,
        '[', 79,
        '`', 46,
        '{', 70,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 12:
      if (lookahead == '%') ADVANCE(89);
      if (lookahead == '-') ADVANCE(143);
      if (lookahead == ':') ADVANCE(86);
      END_STATE();
    case 13:
      if (lookahead == '%') ADVANCE(89);
      if (lookahead == ':') ADVANCE(86);
      END_STATE();
    case 14:
      ADVANCE_MAP(
        '\'', 113,
        '(', 97,
        ')', 98,
        ',', 72,
        '-', 124,
        '.', 38,
        '/', 122,
        '0', 132,
        ':', 69,
        '@', 92,
        '[', 79,
        ']', 80,
        '`', 46,
        '{', 70,
        '}', 71,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(14);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(133);
      if (lookahead == '=' ||
          lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_3, 495, lookahead)) ADVANCE(115);
      END_STATE();
    case 15:
      if (lookahead == '\'') ADVANCE(139);
      END_STATE();
    case 16:
      if (lookahead == '\'') ADVANCE(139);
      if (lookahead == '\\') ADVANCE(34);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(15);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        '(', 97,
        ')', 98,
        '*', 76,
        ',', 72,
        '/', 122,
        ':', 69,
        '<', 123,
        '=', 95,
        '?', 126,
        '@', 92,
        '`', 46,
        '{', 70,
        '|', 106,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(17);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 18:
      ADVANCE_MAP(
        '(', 97,
        '+', 82,
        '-', 85,
        '/', 122,
        '@', 92,
        '[', 79,
        ']', 80,
        '`', 46,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(18);
      if (lookahead == ':' ||
          lookahead == '=' ||
          lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 19:
      ADVANCE_MAP(
        '(', 97,
        ',', 72,
        '/', 122,
        ':', 69,
        '<', 120,
        '=', 30,
        '?', 126,
        '@', 92,
        ']', 80,
        '`', 46,
        '{', 70,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(19);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 20:
      ADVANCE_MAP(
        '(', 97,
        ',', 72,
        '/', 122,
        ':', 69,
        '<', 121,
        '=', 30,
        '?', 126,
        '@', 92,
        ']', 80,
        '`', 46,
        '{', 70,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(20);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 21:
      ADVANCE_MAP(
        '(', 97,
        '.', 73,
        '/', 122,
        ':', 69,
        '=', 95,
        '@', 92,
        '[', 79,
        '`', 46,
        '{', 70,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(21);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 22:
      if (lookahead == '*') ADVANCE(159);
      if (lookahead == '/') ADVANCE(146);
      END_STATE();
    case 23:
      if (lookahead == ',') ADVANCE(72);
      if (lookahead == '/') ADVANCE(122);
      if (lookahead == ':') ADVANCE(69);
      if (lookahead == '<') ADVANCE(120);
      if (lookahead == ']') ADVANCE(80);
      if (lookahead == '`') ADVANCE(46);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(23);
      if (lookahead == '=' ||
          lookahead == '@' ||
          lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 24:
      if (lookahead == ',') ADVANCE(72);
      if (lookahead == '/') ADVANCE(122);
      if (lookahead == ':') ADVANCE(69);
      if (lookahead == '<') ADVANCE(121);
      if (lookahead == ']') ADVANCE(80);
      if (lookahead == '`') ADVANCE(46);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(24);
      if (lookahead == '=' ||
          lookahead == '@' ||
          lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 25:
      if (lookahead == '/') ADVANCE(154);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(25);
      if (lookahead != 0) ADVANCE(155);
      END_STATE();
    case 26:
      if (lookahead == ':') ADVANCE(88);
      END_STATE();
    case 27:
      if (lookahead == '=') ADVANCE(29);
      END_STATE();
    case 28:
      if (lookahead == '>') ADVANCE(77);
      END_STATE();
    case 29:
      if (lookahead == '>') ADVANCE(102);
      END_STATE();
    case 30:
      if (lookahead == '>') ADVANCE(78);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 31:
      if (lookahead == '>') ADVANCE(104);
      END_STATE();
    case 32:
      if (lookahead == '>') ADVANCE(31);
      END_STATE();
    case 33:
      if (lookahead == '`') ADVANCE(118);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(33);
      END_STATE();
    case 34:
      if (lookahead == 'u') ADVANCE(35);
      if (lookahead == 'x') ADVANCE(44);
      if (lookahead != 0) ADVANCE(15);
      END_STATE();
    case 35:
      if (lookahead == 'u') ADVANCE(45);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(43);
      END_STATE();
    case 36:
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 37:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(40);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(138);
      END_STATE();
    case 38:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(137);
      END_STATE();
    case 39:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(135);
      END_STATE();
    case 40:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(138);
      END_STATE();
    case 41:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(15);
      END_STATE();
    case 42:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(134);
      END_STATE();
    case 43:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(44);
      END_STATE();
    case 44:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(41);
      END_STATE();
    case 45:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(43);
      END_STATE();
    case 46:
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '`') ADVANCE(33);
      END_STATE();
    case 47:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '!', 107,
        '"', 141,
        '#', 100,
        '$', 112,
        '\'', 113,
        '(', 97,
        ')', 98,
        '*', 75,
        '+', 81,
        ',', 72,
        '-', 84,
        '.', 74,
        '/', 22,
        '0', 132,
        ':', 68,
        ';', 99,
        '<', 12,
        '=', 94,
        '>', 26,
        '?', 27,
        '@', 91,
        '[', 79,
        ']', 80,
        '`', 46,
        '{', 70,
        '|', 105,
        '}', 71,
        '~', 109,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(47);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(133);
      if (set_contains(sym__interpolation_identifier_character_set_2, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 48:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '!', 108,
        '"', 141,
        '$', 112,
        '\'', 113,
        '(', 97,
        ')', 98,
        '+', 82,
        ',', 72,
        '-', 83,
        '.', 74,
        '/', 122,
        '0', 132,
        ':', 69,
        ';', 99,
        '=', 95,
        '?', 126,
        '[', 79,
        '`', 46,
        '{', 70,
        '}', 71,
        '~', 110,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(48);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(133);
      if (lookahead == '@' ||
          lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__interpolation_identifier_character_set_2, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 49:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '!', 108,
        '#', 119,
        '$', 112,
        '\'', 113,
        '(', 97,
        '+', 82,
        '-', 83,
        '.', 38,
        '/', 122,
        '0', 132,
        '@', 92,
        '`', 46,
        '{', 70,
        '~', 110,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(49);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(133);
      if (lookahead == ':' ||
          lookahead == '=' ||
          lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__interpolation_identifier_character_set_2, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 50:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '!', 108,
        '$', 112,
        '\'', 113,
        '(', 97,
        ')', 98,
        '+', 82,
        ',', 72,
        '-', 83,
        '.', 74,
        '/', 122,
        '0', 132,
        ':', 69,
        ';', 99,
        '=', 96,
        '@', 92,
        '[', 79,
        '`', 46,
        '{', 70,
        '}', 71,
        '~', 110,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(50);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(133);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__interpolation_identifier_character_set_2, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 51:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '"', 141,
        '(', 97,
        ')', 98,
        '*', 76,
        ',', 72,
        '.', 73,
        '/', 122,
        ':', 69,
        ';', 99,
        '=', 96,
        '@', 92,
        '`', 46,
        '|', 106,
        '}', 71,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(51);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 52:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '"', 141,
        '(', 97,
        ')', 98,
        ',', 72,
        '.', 73,
        '/', 122,
        ':', 69,
        ';', 99,
        '=', 95,
        '?', 126,
        '@', 92,
        '[', 79,
        ']', 80,
        '`', 46,
        '{', 70,
        '}', 71,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(52);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 53:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '#', 100,
        '(', 97,
        ')', 98,
        '*', 75,
        ',', 72,
        '.', 73,
        '/', 22,
        ':', 68,
        ';', 99,
        '<', 13,
        '=', 93,
        '>', 26,
        '@', 91,
        '[', 79,
        ']', 80,
        '{', 70,
        '}', 71,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(53);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 54:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '#', 100,
        '(', 97,
        ')', 98,
        '*', 75,
        ',', 72,
        '.', 73,
        '/', 22,
        ':', 68,
        ';', 99,
        '<', 13,
        '=', 28,
        '>', 26,
        '?', 27,
        '@', 91,
        '[', 79,
        ']', 80,
        '{', 70,
        '}', 71,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(54);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 55:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '#', 101,
        '(', 97,
        ')', 98,
        '*', 76,
        ',', 72,
        '.', 73,
        '/', 122,
        ':', 69,
        ';', 99,
        '=', 95,
        '?', 126,
        '@', 92,
        '[', 79,
        '`', 46,
        '{', 70,
        '|', 106,
        '}', 71,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(55);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 56:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '#', 101,
        '(', 97,
        ')', 98,
        '*', 76,
        ',', 72,
        '.', 73,
        '/', 122,
        ':', 69,
        ';', 99,
        '=', 95,
        '?', 126,
        '@', 92,
        '[', 79,
        '`', 46,
        '{', 70,
        '}', 71,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(56);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 57:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '#', 101,
        '(', 97,
        ')', 98,
        ',', 72,
        '.', 73,
        '/', 122,
        ':', 69,
        ';', 99,
        '=', 96,
        '@', 92,
        '[', 79,
        '`', 46,
        '{', 70,
        '}', 71,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(57);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 58:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '#', 101,
        '(', 97,
        ')', 98,
        ',', 72,
        '.', 73,
        '/', 122,
        ':', 69,
        ';', 99,
        '=', 95,
        '?', 126,
        '@', 92,
        '[', 79,
        ']', 80,
        '`', 46,
        '{', 70,
        '}', 71,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(58);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 59:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '#', 101,
        '(', 97,
        '.', 73,
        '/', 122,
        ':', 69,
        ';', 99,
        '<', 125,
        '=', 95,
        '?', 126,
        '@', 92,
        '[', 79,
        '`', 46,
        '{', 70,
        '}', 71,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(59);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 60:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '\'', 16,
        '(', 97,
        ')', 98,
        ',', 72,
        '-', 124,
        '.', 74,
        '/', 122,
        '0', 132,
        ':', 69,
        ';', 99,
        '=', 30,
        '@', 92,
        '[', 79,
        '`', 46,
        '{', 70,
        '}', 71,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(60);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(133);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_3, 495, lookahead)) ADVANCE(115);
      END_STATE();
    case 61:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '(', 97,
        ')', 98,
        '*', 76,
        ',', 72,
        '/', 122,
        ':', 69,
        ';', 99,
        '=', 95,
        '?', 126,
        '@', 92,
        '[', 79,
        '`', 46,
        '{', 70,
        '}', 71,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(61);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 62:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '(', 97,
        ')', 98,
        '*', 76,
        ',', 72,
        '/', 122,
        ':', 69,
        ';', 99,
        '=', 95,
        '?', 126,
        '@', 92,
        '`', 46,
        '{', 70,
        '|', 106,
        '}', 71,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(62);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 63:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '(', 97,
        ')', 98,
        ',', 72,
        '.', 73,
        '/', 122,
        ':', 69,
        ';', 99,
        '=', 96,
        '@', 92,
        '[', 79,
        ']', 80,
        '`', 46,
        '{', 70,
        '}', 71,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(63);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 64:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        '(', 97,
        '/', 122,
        ':', 69,
        ';', 99,
        '<', 125,
        '=', 95,
        '?', 126,
        '@', 92,
        '`', 46,
        '{', 70,
        '}', 71,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(64);
      if (lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 65:
      if (eof) ADVANCE(67);
      ADVANCE_MAP(
        ')', 98,
        '*', 76,
        ',', 72,
        '/', 122,
        ';', 99,
        '=', 96,
        '[', 79,
        '`', 46,
        '{', 70,
        '}', 71,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(65);
      if (lookahead == ':' ||
          lookahead == '@' ||
          lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 66:
      if (eof) ADVANCE(67);
      if (lookahead == '/') ADVANCE(122);
      if (lookahead == ';') ADVANCE(99);
      if (lookahead == '<') ADVANCE(125);
      if (lookahead == '=') ADVANCE(96);
      if (lookahead == '`') ADVANCE(46);
      if (lookahead == '}') ADVANCE(71);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(66);
      if (lookahead == ':' ||
          lookahead == '@' ||
          lookahead == 0x3f6 ||
          (0x606 <= lookahead && lookahead <= 0x608) ||
          lookahead == 0x2044 ||
          lookahead == 0x2052 ||
          (0x207a <= lookahead && lookahead <= 0x207c) ||
          (0x208a <= lookahead && lookahead <= 0x208c) ||
          lookahead == 0x2118 ||
          (0x2140 <= lookahead && lookahead <= 0x2144) ||
          lookahead == 0x214b ||
          lookahead == 0x219a ||
          lookahead == 0x219b ||
          lookahead == 0x21a0 ||
          lookahead == 0x21a3 ||
          lookahead == 0x21a6 ||
          lookahead == 0x21ae ||
          lookahead == 0x21ce ||
          lookahead == 0x21cf ||
          lookahead == 0x21d2 ||
          lookahead == 0x21d4 ||
          (0x21f4 <= lookahead && lookahead <= 0x22ff) ||
          lookahead == 0x2320 ||
          lookahead == 0x2321 ||
          lookahead == 0x237c ||
          (0x239b <= lookahead && lookahead <= 0x23b3) ||
          (0x23dc <= lookahead && lookahead <= 0x23e1) ||
          lookahead == 0x25b7 ||
          lookahead == 0x25c1 ||
          (0x25f8 <= lookahead && lookahead <= 0x25ff) ||
          lookahead == 0x266f ||
          (0x27c0 <= lookahead && lookahead <= 0x27c4) ||
          (0x27c7 <= lookahead && lookahead <= 0x27e5) ||
          (0x27f0 <= lookahead && lookahead <= 0x27ff) ||
          (0x2900 <= lookahead && lookahead <= 0x2982) ||
          (0x2999 <= lookahead && lookahead <= 0x29d7) ||
          (0x29dc <= lookahead && lookahead <= 0x29fb) ||
          (0x29fe <= lookahead && lookahead <= 0x2aff) ||
          (0x2b30 <= lookahead && lookahead <= 0x2b44) ||
          (0x2b47 <= lookahead && lookahead <= 0x2b4c) ||
          lookahead == 0xfb29 ||
          lookahead == 0xfe62 ||
          (0xfe64 <= lookahead && lookahead <= 0xfe66) ||
          lookahead == 0xff0b ||
          (0xff1c <= lookahead && lookahead <= 0xff1e) ||
          lookahead == 0xff5c ||
          lookahead == 0xff5e ||
          lookahead == 0xffe2 ||
          (0xffe9 <= lookahead && lookahead <= 0xffec)) ADVANCE(36);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(128);
      if (set_contains(sym__alpha_identifier_character_set_1, 433, lookahead)) ADVANCE(115);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(137);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(anon_sym_EQ_GT);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(anon_sym_EQ_GT);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(129);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '.') ADVANCE(38);
      if (lookahead == '0') ADVANCE(132);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(133);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '.') ADVANCE(38);
      if (lookahead == '0') ADVANCE(132);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(133);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(anon_sym_LT_COLON);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(anon_sym_LT_COLON);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(129);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(anon_sym_GT_COLON);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(anon_sym_LT_PERCENT);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(anon_sym_LT_PERCENT);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(129);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(anon_sym_AT);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '>') ADVANCE(77);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '>') ADVANCE(78);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(anon_sym_POUND);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_QMARK_EQ_GT);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(anon_sym_QMARK_EQ_GT);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(129);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(anon_sym_EQ_GT_GT);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(anon_sym_TILDE);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      if (lookahead == '_') ADVANCE(114);
      if (set_contains(sym__alpha_identifier_character_set_2, 434, lookahead)) ADVANCE(115);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      if (lookahead == '\'') ADVANCE(139);
      if (lookahead == '\\') ADVANCE(34);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(15);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(sym__alpha_identifier);
      if (lookahead == '_') ADVANCE(114);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(116);
      if (set_contains(sym__alpha_identifier_character_set_3, 495, lookahead)) ADVANCE(115);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(sym__alpha_identifier);
      if (lookahead == '_') ADVANCE(114);
      if (set_contains(sym__alpha_identifier_character_set_2, 434, lookahead)) ADVANCE(115);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(sym__alpha_identifier);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(116);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(sym__interpolation_identifier);
      if (set_contains(sym__interpolation_identifier_character_set_2, 433, lookahead)) ADVANCE(117);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(sym__backquoted_id);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '!') ADVANCE(130);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '%') ADVANCE(90);
      if (lookahead == ':') ADVANCE(87);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '%') ADVANCE(90);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '*') ADVANCE(159);
      if (lookahead == '/') ADVANCE(146);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '-') ADVANCE(144);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '.') ADVANCE(38);
      if (lookahead == '0') ADVANCE(132);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(133);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == ':') ADVANCE(87);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '=') ADVANCE(127);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '>') ADVANCE(103);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(129);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(129);
      if (set_contains(sym_operator_identifier_character_set_1, 133, lookahead)) ADVANCE(129);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(129);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(130);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(145);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(sym_integer_literal);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(sym_integer_literal);
      ADVANCE_MAP(
        '.', 38,
        '_', 39,
        'E', 37,
        'e', 37,
        'L', 131,
        'l', 131,
        'X', 42,
        'x', 42,
        'D', 136,
        'F', 136,
        'd', 136,
        'f', 136,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(133);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(sym_integer_literal);
      ADVANCE_MAP(
        '.', 38,
        '_', 39,
        'E', 37,
        'e', 37,
        'L', 131,
        'l', 131,
        'D', 136,
        'F', 136,
        'd', 136,
        'f', 136,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(133);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(sym_integer_literal);
      if (lookahead == '_') ADVANCE(42);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(131);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(134);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(sym_integer_literal);
      if (lookahead == '_') ADVANCE(39);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(131);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(135);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(sym_floating_point_literal);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(sym_floating_point_literal);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(37);
      if (('D' <= lookahead && lookahead <= 'F') ||
          ('d' <= lookahead && lookahead <= 'f')) ADVANCE(136);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(137);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(sym_floating_point_literal);
      if (lookahead == 'D' ||
          lookahead == 'F' ||
          lookahead == 'd' ||
          lookahead == 'f') ADVANCE(136);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(138);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(sym_character_literal);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      if (lookahead == '"') ADVANCE(5);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(anon_sym_DQUOTE_DQUOTE_DQUOTE);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(anon_sym_LT_DASH);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(anon_sym_LT_DASH);
      if (set_contains(sym__alpha_identifier_character_set_4, 134, lookahead)) ADVANCE(129);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(aux_sym__shebang_token1);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(145);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(155);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(158);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(sym__comment_text);
      if (lookahead == '*') ADVANCE(152);
      if (lookahead == '/') ADVANCE(152);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(152);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(sym__comment_text);
      if (lookahead == '/') ADVANCE(149);
      if (lookahead == '>') ADVANCE(153);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(151);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(152);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(sym__comment_text);
      if (lookahead == '/') ADVANCE(149);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(151);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(152);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(sym__comment_text);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(152);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(sym_using_directive_key);
      if (lookahead == '*') ADVANCE(160);
      if (lookahead == '/') ADVANCE(147);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(155);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(sym_using_directive_key);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(155);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(sym_using_directive_value);
      if (lookahead == '*') ADVANCE(161);
      if (lookahead == '/') ADVANCE(148);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(158);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(sym_using_directive_value);
      if (lookahead == '/') ADVANCE(156);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(157);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(158);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(sym_using_directive_value);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(158);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(anon_sym_SLASH_STAR);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(anon_sym_SLASH_STAR);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(155);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(anon_sym_SLASH_STAR);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(158);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(aux_sym_block_comment_token1);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(aux_sym_block_comment_token1);
      if (lookahead == '*') ADVANCE(159);
      if (lookahead == '/') ADVANCE(146);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(aux_sym_block_comment_token1);
      if (lookahead == '*') ADVANCE(165);
      if (lookahead == '/') ADVANCE(163);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(164);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(162);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(aux_sym_block_comment_token1);
      if (lookahead == '/') ADVANCE(166);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(anon_sym_STAR_SLASH);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        '_', 1,
        'a', 2,
        'c', 3,
        'd', 4,
        'e', 5,
        'f', 6,
        'g', 7,
        'i', 8,
        'l', 9,
        'm', 10,
        'n', 11,
        'o', 12,
        'p', 13,
        'r', 14,
        's', 15,
        't', 16,
        'u', 17,
        'v', 18,
        'w', 19,
        'y', 20,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      ACCEPT_TOKEN(anon_sym__);
      END_STATE();
    case 2:
      if (lookahead == 'b') ADVANCE(21);
      if (lookahead == 's') ADVANCE(22);
      END_STATE();
    case 3:
      if (lookahead == 'a') ADVANCE(23);
      if (lookahead == 'l') ADVANCE(24);
      END_STATE();
    case 4:
      if (lookahead == 'e') ADVANCE(25);
      if (lookahead == 'o') ADVANCE(26);
      END_STATE();
    case 5:
      if (lookahead == 'l') ADVANCE(27);
      if (lookahead == 'n') ADVANCE(28);
      if (lookahead == 'x') ADVANCE(29);
      END_STATE();
    case 6:
      if (lookahead == 'a') ADVANCE(30);
      if (lookahead == 'i') ADVANCE(31);
      if (lookahead == 'o') ADVANCE(32);
      END_STATE();
    case 7:
      if (lookahead == 'i') ADVANCE(33);
      END_STATE();
    case 8:
      if (lookahead == 'f') ADVANCE(34);
      if (lookahead == 'm') ADVANCE(35);
      if (lookahead == 'n') ADVANCE(36);
      END_STATE();
    case 9:
      if (lookahead == 'a') ADVANCE(37);
      END_STATE();
    case 10:
      if (lookahead == 'a') ADVANCE(38);
      END_STATE();
    case 11:
      if (lookahead == 'e') ADVANCE(39);
      if (lookahead == 'u') ADVANCE(40);
      END_STATE();
    case 12:
      if (lookahead == 'b') ADVANCE(41);
      if (lookahead == 'p') ADVANCE(42);
      if (lookahead == 'v') ADVANCE(43);
      END_STATE();
    case 13:
      if (lookahead == 'a') ADVANCE(44);
      if (lookahead == 'r') ADVANCE(45);
      END_STATE();
    case 14:
      if (lookahead == 'e') ADVANCE(46);
      END_STATE();
    case 15:
      if (lookahead == 'e') ADVANCE(47);
      END_STATE();
    case 16:
      if (lookahead == 'h') ADVANCE(48);
      if (lookahead == 'r') ADVANCE(49);
      if (lookahead == 'y') ADVANCE(50);
      END_STATE();
    case 17:
      if (lookahead == 's') ADVANCE(51);
      END_STATE();
    case 18:
      if (lookahead == 'a') ADVANCE(52);
      END_STATE();
    case 19:
      if (lookahead == 'h') ADVANCE(53);
      if (lookahead == 'i') ADVANCE(54);
      END_STATE();
    case 20:
      if (lookahead == 'i') ADVANCE(55);
      END_STATE();
    case 21:
      if (lookahead == 's') ADVANCE(56);
      END_STATE();
    case 22:
      ACCEPT_TOKEN(anon_sym_as);
      END_STATE();
    case 23:
      if (lookahead == 's') ADVANCE(57);
      if (lookahead == 't') ADVANCE(58);
      END_STATE();
    case 24:
      if (lookahead == 'a') ADVANCE(59);
      END_STATE();
    case 25:
      if (lookahead == 'f') ADVANCE(60);
      if (lookahead == 'r') ADVANCE(61);
      END_STATE();
    case 26:
      ACCEPT_TOKEN(anon_sym_do);
      END_STATE();
    case 27:
      if (lookahead == 's') ADVANCE(62);
      END_STATE();
    case 28:
      if (lookahead == 'd') ADVANCE(63);
      if (lookahead == 'u') ADVANCE(64);
      END_STATE();
    case 29:
      if (lookahead == 'p') ADVANCE(65);
      if (lookahead == 't') ADVANCE(66);
      END_STATE();
    case 30:
      if (lookahead == 'l') ADVANCE(67);
      END_STATE();
    case 31:
      if (lookahead == 'n') ADVANCE(68);
      END_STATE();
    case 32:
      if (lookahead == 'r') ADVANCE(69);
      END_STATE();
    case 33:
      if (lookahead == 'v') ADVANCE(70);
      END_STATE();
    case 34:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 35:
      if (lookahead == 'p') ADVANCE(71);
      END_STATE();
    case 36:
      if (lookahead == 'f') ADVANCE(72);
      if (lookahead == 'l') ADVANCE(73);
      END_STATE();
    case 37:
      if (lookahead == 'z') ADVANCE(74);
      END_STATE();
    case 38:
      if (lookahead == 'c') ADVANCE(75);
      if (lookahead == 't') ADVANCE(76);
      END_STATE();
    case 39:
      if (lookahead == 'w') ADVANCE(77);
      END_STATE();
    case 40:
      if (lookahead == 'l') ADVANCE(78);
      END_STATE();
    case 41:
      if (lookahead == 'j') ADVANCE(79);
      END_STATE();
    case 42:
      if (lookahead == 'a') ADVANCE(80);
      if (lookahead == 'e') ADVANCE(81);
      END_STATE();
    case 43:
      if (lookahead == 'e') ADVANCE(82);
      END_STATE();
    case 44:
      if (lookahead == 'c') ADVANCE(83);
      END_STATE();
    case 45:
      if (lookahead == 'i') ADVANCE(84);
      if (lookahead == 'o') ADVANCE(85);
      END_STATE();
    case 46:
      if (lookahead == 't') ADVANCE(86);
      END_STATE();
    case 47:
      if (lookahead == 'a') ADVANCE(87);
      END_STATE();
    case 48:
      if (lookahead == 'e') ADVANCE(88);
      if (lookahead == 'i') ADVANCE(89);
      if (lookahead == 'r') ADVANCE(90);
      END_STATE();
    case 49:
      if (lookahead == 'a') ADVANCE(91);
      if (lookahead == 'u') ADVANCE(92);
      if (lookahead == 'y') ADVANCE(93);
      END_STATE();
    case 50:
      if (lookahead == 'p') ADVANCE(94);
      END_STATE();
    case 51:
      if (lookahead == 'i') ADVANCE(95);
      END_STATE();
    case 52:
      if (lookahead == 'l') ADVANCE(96);
      if (lookahead == 'r') ADVANCE(97);
      END_STATE();
    case 53:
      if (lookahead == 'i') ADVANCE(98);
      END_STATE();
    case 54:
      if (lookahead == 't') ADVANCE(99);
      END_STATE();
    case 55:
      if (lookahead == 'e') ADVANCE(100);
      END_STATE();
    case 56:
      if (lookahead == 't') ADVANCE(101);
      END_STATE();
    case 57:
      if (lookahead == 'e') ADVANCE(102);
      END_STATE();
    case 58:
      if (lookahead == 'c') ADVANCE(103);
      END_STATE();
    case 59:
      if (lookahead == 's') ADVANCE(104);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(anon_sym_def);
      END_STATE();
    case 61:
      if (lookahead == 'i') ADVANCE(105);
      END_STATE();
    case 62:
      if (lookahead == 'e') ADVANCE(106);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(anon_sym_end);
      END_STATE();
    case 64:
      if (lookahead == 'm') ADVANCE(107);
      END_STATE();
    case 65:
      if (lookahead == 'o') ADVANCE(108);
      END_STATE();
    case 66:
      if (lookahead == 'e') ADVANCE(109);
      END_STATE();
    case 67:
      if (lookahead == 's') ADVANCE(110);
      END_STATE();
    case 68:
      if (lookahead == 'a') ADVANCE(111);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 70:
      if (lookahead == 'e') ADVANCE(112);
      END_STATE();
    case 71:
      if (lookahead == 'l') ADVANCE(113);
      if (lookahead == 'o') ADVANCE(114);
      END_STATE();
    case 72:
      if (lookahead == 'i') ADVANCE(115);
      END_STATE();
    case 73:
      if (lookahead == 'i') ADVANCE(116);
      END_STATE();
    case 74:
      if (lookahead == 'y') ADVANCE(117);
      END_STATE();
    case 75:
      if (lookahead == 'r') ADVANCE(118);
      END_STATE();
    case 76:
      if (lookahead == 'c') ADVANCE(119);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(anon_sym_new);
      END_STATE();
    case 78:
      if (lookahead == 'l') ADVANCE(120);
      END_STATE();
    case 79:
      if (lookahead == 'e') ADVANCE(121);
      END_STATE();
    case 80:
      if (lookahead == 'q') ADVANCE(122);
      END_STATE();
    case 81:
      if (lookahead == 'n') ADVANCE(123);
      END_STATE();
    case 82:
      if (lookahead == 'r') ADVANCE(124);
      END_STATE();
    case 83:
      if (lookahead == 'k') ADVANCE(125);
      END_STATE();
    case 84:
      if (lookahead == 'v') ADVANCE(126);
      END_STATE();
    case 85:
      if (lookahead == 't') ADVANCE(127);
      END_STATE();
    case 86:
      if (lookahead == 'u') ADVANCE(128);
      END_STATE();
    case 87:
      if (lookahead == 'l') ADVANCE(129);
      END_STATE();
    case 88:
      if (lookahead == 'n') ADVANCE(130);
      END_STATE();
    case 89:
      if (lookahead == 's') ADVANCE(131);
      END_STATE();
    case 90:
      if (lookahead == 'o') ADVANCE(132);
      END_STATE();
    case 91:
      if (lookahead == 'i') ADVANCE(133);
      if (lookahead == 'n') ADVANCE(134);
      END_STATE();
    case 92:
      if (lookahead == 'e') ADVANCE(135);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(anon_sym_try);
      END_STATE();
    case 94:
      if (lookahead == 'e') ADVANCE(136);
      END_STATE();
    case 95:
      if (lookahead == 'n') ADVANCE(137);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_val);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(anon_sym_var);
      END_STATE();
    case 98:
      if (lookahead == 'l') ADVANCE(138);
      END_STATE();
    case 99:
      if (lookahead == 'h') ADVANCE(139);
      END_STATE();
    case 100:
      if (lookahead == 'l') ADVANCE(140);
      END_STATE();
    case 101:
      if (lookahead == 'r') ADVANCE(141);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 103:
      if (lookahead == 'h') ADVANCE(142);
      END_STATE();
    case 104:
      if (lookahead == 's') ADVANCE(143);
      END_STATE();
    case 105:
      if (lookahead == 'v') ADVANCE(144);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 108:
      if (lookahead == 'r') ADVANCE(145);
      END_STATE();
    case 109:
      if (lookahead == 'n') ADVANCE(146);
      END_STATE();
    case 110:
      if (lookahead == 'e') ADVANCE(147);
      END_STATE();
    case 111:
      if (lookahead == 'l') ADVANCE(148);
      END_STATE();
    case 112:
      if (lookahead == 'n') ADVANCE(149);
      END_STATE();
    case 113:
      if (lookahead == 'i') ADVANCE(150);
      END_STATE();
    case 114:
      if (lookahead == 'r') ADVANCE(151);
      END_STATE();
    case 115:
      if (lookahead == 'x') ADVANCE(152);
      END_STATE();
    case 116:
      if (lookahead == 'n') ADVANCE(153);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(anon_sym_lazy);
      END_STATE();
    case 118:
      if (lookahead == 'o') ADVANCE(154);
      END_STATE();
    case 119:
      if (lookahead == 'h') ADVANCE(155);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(sym_null_literal);
      END_STATE();
    case 121:
      if (lookahead == 'c') ADVANCE(156);
      END_STATE();
    case 122:
      if (lookahead == 'u') ADVANCE(157);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(anon_sym_open);
      END_STATE();
    case 124:
      if (lookahead == 'r') ADVANCE(158);
      END_STATE();
    case 125:
      if (lookahead == 'a') ADVANCE(159);
      END_STATE();
    case 126:
      if (lookahead == 'a') ADVANCE(160);
      END_STATE();
    case 127:
      if (lookahead == 'e') ADVANCE(161);
      END_STATE();
    case 128:
      if (lookahead == 'r') ADVANCE(162);
      END_STATE();
    case 129:
      if (lookahead == 'e') ADVANCE(163);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_then);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(anon_sym_this);
      END_STATE();
    case 132:
      if (lookahead == 'w') ADVANCE(164);
      END_STATE();
    case 133:
      if (lookahead == 't') ADVANCE(165);
      END_STATE();
    case 134:
      if (lookahead == 's') ADVANCE(166);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(anon_sym_type);
      END_STATE();
    case 137:
      if (lookahead == 'g') ADVANCE(167);
      END_STATE();
    case 138:
      if (lookahead == 'e') ADVANCE(168);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(anon_sym_with);
      END_STATE();
    case 140:
      if (lookahead == 'd') ADVANCE(169);
      END_STATE();
    case 141:
      if (lookahead == 'a') ADVANCE(170);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(anon_sym_catch);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(anon_sym_class);
      END_STATE();
    case 144:
      if (lookahead == 'e') ADVANCE(171);
      END_STATE();
    case 145:
      if (lookahead == 't') ADVANCE(172);
      END_STATE();
    case 146:
      if (lookahead == 'd') ADVANCE(173);
      if (lookahead == 's') ADVANCE(174);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_final);
      if (lookahead == 'l') ADVANCE(175);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_given);
      END_STATE();
    case 150:
      if (lookahead == 'c') ADVANCE(176);
      END_STATE();
    case 151:
      if (lookahead == 't') ADVANCE(177);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_infix);
      END_STATE();
    case 153:
      if (lookahead == 'e') ADVANCE(178);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(anon_sym_macro);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(anon_sym_match);
      END_STATE();
    case 156:
      if (lookahead == 't') ADVANCE(179);
      END_STATE();
    case 157:
      if (lookahead == 'e') ADVANCE(180);
      END_STATE();
    case 158:
      if (lookahead == 'i') ADVANCE(181);
      END_STATE();
    case 159:
      if (lookahead == 'g') ADVANCE(182);
      END_STATE();
    case 160:
      if (lookahead == 't') ADVANCE(183);
      END_STATE();
    case 161:
      if (lookahead == 'c') ADVANCE(184);
      END_STATE();
    case 162:
      if (lookahead == 'n') ADVANCE(185);
      END_STATE();
    case 163:
      if (lookahead == 'd') ADVANCE(186);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(anon_sym_throw);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(anon_sym_trait);
      END_STATE();
    case 166:
      if (lookahead == 'p') ADVANCE(187);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(anon_sym_using);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(anon_sym_yield);
      END_STATE();
    case 170:
      if (lookahead == 'c') ADVANCE(188);
      END_STATE();
    case 171:
      if (lookahead == 's') ADVANCE(189);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(anon_sym_export);
      END_STATE();
    case 173:
      if (lookahead == 's') ADVANCE(190);
      END_STATE();
    case 174:
      if (lookahead == 'i') ADVANCE(191);
      END_STATE();
    case 175:
      if (lookahead == 'y') ADVANCE(192);
      END_STATE();
    case 176:
      if (lookahead == 'i') ADVANCE(193);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(anon_sym_import);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(anon_sym_inline);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(anon_sym_object);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(anon_sym_opaque);
      END_STATE();
    case 181:
      if (lookahead == 'd') ADVANCE(194);
      END_STATE();
    case 182:
      if (lookahead == 'e') ADVANCE(195);
      END_STATE();
    case 183:
      if (lookahead == 'e') ADVANCE(196);
      END_STATE();
    case 184:
      if (lookahead == 't') ADVANCE(197);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(anon_sym_sealed);
      END_STATE();
    case 187:
      if (lookahead == 'a') ADVANCE(198);
      END_STATE();
    case 188:
      if (lookahead == 't') ADVANCE(199);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(anon_sym_derives);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_extends);
      END_STATE();
    case 191:
      if (lookahead == 'o') ADVANCE(200);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_finally);
      END_STATE();
    case 193:
      if (lookahead == 't') ADVANCE(201);
      END_STATE();
    case 194:
      if (lookahead == 'e') ADVANCE(202);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(anon_sym_package);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(anon_sym_private);
      END_STATE();
    case 197:
      if (lookahead == 'e') ADVANCE(203);
      END_STATE();
    case 198:
      if (lookahead == 'r') ADVANCE(204);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(anon_sym_abstract);
      END_STATE();
    case 200:
      if (lookahead == 'n') ADVANCE(205);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(anon_sym_implicit);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(anon_sym_override);
      END_STATE();
    case 203:
      if (lookahead == 'd') ADVANCE(206);
      END_STATE();
    case 204:
      if (lookahead == 'e') ADVANCE(207);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(anon_sym_extension);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(anon_sym_protected);
      END_STATE();
    case 207:
      if (lookahead == 'n') ADVANCE(208);
      END_STATE();
    case 208:
      if (lookahead == 't') ADVANCE(209);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(anon_sym_transparent);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 49, .external_lex_state = 2},
  [2] = {.lex_state = 50, .external_lex_state = 3},
  [3] = {.lex_state = 50, .external_lex_state = 3},
  [4] = {.lex_state = 50, .external_lex_state = 3},
  [5] = {.lex_state = 50, .external_lex_state = 3},
  [6] = {.lex_state = 50, .external_lex_state = 3},
  [7] = {.lex_state = 50, .external_lex_state = 3},
  [8] = {.lex_state = 50, .external_lex_state = 3},
  [9] = {.lex_state = 50, .external_lex_state = 3},
  [10] = {.lex_state = 50, .external_lex_state = 3},
  [11] = {.lex_state = 50, .external_lex_state = 3},
  [12] = {.lex_state = 50, .external_lex_state = 3},
  [13] = {.lex_state = 50, .external_lex_state = 3},
  [14] = {.lex_state = 50, .external_lex_state = 3},
  [15] = {.lex_state = 50, .external_lex_state = 3},
  [16] = {.lex_state = 50, .external_lex_state = 3},
  [17] = {.lex_state = 50, .external_lex_state = 3},
  [18] = {.lex_state = 50, .external_lex_state = 3},
  [19] = {.lex_state = 50, .external_lex_state = 3},
  [20] = {.lex_state = 50, .external_lex_state = 3},
  [21] = {.lex_state = 50, .external_lex_state = 3},
  [22] = {.lex_state = 50, .external_lex_state = 3},
  [23] = {.lex_state = 50, .external_lex_state = 3},
  [24] = {.lex_state = 50, .external_lex_state = 3},
  [25] = {.lex_state = 50, .external_lex_state = 3},
  [26] = {.lex_state = 50, .external_lex_state = 3},
  [27] = {.lex_state = 50, .external_lex_state = 3},
  [28] = {.lex_state = 50, .external_lex_state = 3},
  [29] = {.lex_state = 50, .external_lex_state = 3},
  [30] = {.lex_state = 50, .external_lex_state = 3},
  [31] = {.lex_state = 50, .external_lex_state = 3},
  [32] = {.lex_state = 50, .external_lex_state = 3},
  [33] = {.lex_state = 50, .external_lex_state = 3},
  [34] = {.lex_state = 50, .external_lex_state = 3},
  [35] = {.lex_state = 50, .external_lex_state = 3},
  [36] = {.lex_state = 50, .external_lex_state = 3},
  [37] = {.lex_state = 50, .external_lex_state = 3},
  [38] = {.lex_state = 50, .external_lex_state = 3},
  [39] = {.lex_state = 50, .external_lex_state = 3},
  [40] = {.lex_state = 50, .external_lex_state = 3},
  [41] = {.lex_state = 50, .external_lex_state = 3},
  [42] = {.lex_state = 50, .external_lex_state = 3},
  [43] = {.lex_state = 50, .external_lex_state = 3},
  [44] = {.lex_state = 50, .external_lex_state = 3},
  [45] = {.lex_state = 50, .external_lex_state = 3},
  [46] = {.lex_state = 50, .external_lex_state = 3},
  [47] = {.lex_state = 50, .external_lex_state = 3},
  [48] = {.lex_state = 50, .external_lex_state = 3},
  [49] = {.lex_state = 50, .external_lex_state = 3},
  [50] = {.lex_state = 50, .external_lex_state = 3},
  [51] = {.lex_state = 50, .external_lex_state = 3},
  [52] = {.lex_state = 50, .external_lex_state = 3},
  [53] = {.lex_state = 50, .external_lex_state = 3},
  [54] = {.lex_state = 50, .external_lex_state = 3},
  [55] = {.lex_state = 50, .external_lex_state = 3},
  [56] = {.lex_state = 50, .external_lex_state = 3},
  [57] = {.lex_state = 50, .external_lex_state = 3},
  [58] = {.lex_state = 50, .external_lex_state = 3},
  [59] = {.lex_state = 50, .external_lex_state = 3},
  [60] = {.lex_state = 50, .external_lex_state = 3},
  [61] = {.lex_state = 50, .external_lex_state = 3},
  [62] = {.lex_state = 50, .external_lex_state = 3},
  [63] = {.lex_state = 50, .external_lex_state = 3},
  [64] = {.lex_state = 50, .external_lex_state = 3},
  [65] = {.lex_state = 50, .external_lex_state = 3},
  [66] = {.lex_state = 50, .external_lex_state = 3},
  [67] = {.lex_state = 50, .external_lex_state = 3},
  [68] = {.lex_state = 50, .external_lex_state = 3},
  [69] = {.lex_state = 50, .external_lex_state = 3},
  [70] = {.lex_state = 50, .external_lex_state = 3},
  [71] = {.lex_state = 50, .external_lex_state = 3},
  [72] = {.lex_state = 50, .external_lex_state = 3},
  [73] = {.lex_state = 50, .external_lex_state = 3},
  [74] = {.lex_state = 50, .external_lex_state = 3},
  [75] = {.lex_state = 50, .external_lex_state = 3},
  [76] = {.lex_state = 50, .external_lex_state = 3},
  [77] = {.lex_state = 50, .external_lex_state = 3},
  [78] = {.lex_state = 50, .external_lex_state = 3},
  [79] = {.lex_state = 50, .external_lex_state = 3},
  [80] = {.lex_state = 50, .external_lex_state = 3},
  [81] = {.lex_state = 50, .external_lex_state = 3},
  [82] = {.lex_state = 50, .external_lex_state = 3},
  [83] = {.lex_state = 50, .external_lex_state = 3},
  [84] = {.lex_state = 50, .external_lex_state = 3},
  [85] = {.lex_state = 50, .external_lex_state = 3},
  [86] = {.lex_state = 50, .external_lex_state = 3},
  [87] = {.lex_state = 50, .external_lex_state = 3},
  [88] = {.lex_state = 50, .external_lex_state = 3},
  [89] = {.lex_state = 50, .external_lex_state = 3},
  [90] = {.lex_state = 50, .external_lex_state = 3},
  [91] = {.lex_state = 50, .external_lex_state = 3},
  [92] = {.lex_state = 50, .external_lex_state = 3},
  [93] = {.lex_state = 50, .external_lex_state = 3},
  [94] = {.lex_state = 50, .external_lex_state = 3},
  [95] = {.lex_state = 50, .external_lex_state = 3},
  [96] = {.lex_state = 50, .external_lex_state = 3},
  [97] = {.lex_state = 50, .external_lex_state = 3},
  [98] = {.lex_state = 50, .external_lex_state = 3},
  [99] = {.lex_state = 50, .external_lex_state = 3},
  [100] = {.lex_state = 50, .external_lex_state = 3},
  [101] = {.lex_state = 50, .external_lex_state = 3},
  [102] = {.lex_state = 50, .external_lex_state = 3},
  [103] = {.lex_state = 50, .external_lex_state = 3},
  [104] = {.lex_state = 50, .external_lex_state = 3},
  [105] = {.lex_state = 50, .external_lex_state = 3},
  [106] = {.lex_state = 50, .external_lex_state = 3},
  [107] = {.lex_state = 50, .external_lex_state = 3},
  [108] = {.lex_state = 50, .external_lex_state = 3},
  [109] = {.lex_state = 50, .external_lex_state = 3},
  [110] = {.lex_state = 50, .external_lex_state = 3},
  [111] = {.lex_state = 50, .external_lex_state = 3},
  [112] = {.lex_state = 50, .external_lex_state = 3},
  [113] = {.lex_state = 50, .external_lex_state = 3},
  [114] = {.lex_state = 50, .external_lex_state = 3},
  [115] = {.lex_state = 50, .external_lex_state = 3},
  [116] = {.lex_state = 50, .external_lex_state = 3},
  [117] = {.lex_state = 50, .external_lex_state = 3},
  [118] = {.lex_state = 50, .external_lex_state = 3},
  [119] = {.lex_state = 50, .external_lex_state = 3},
  [120] = {.lex_state = 50, .external_lex_state = 2},
  [121] = {.lex_state = 50, .external_lex_state = 2},
  [122] = {.lex_state = 50, .external_lex_state = 2},
  [123] = {.lex_state = 50, .external_lex_state = 2},
  [124] = {.lex_state = 50, .external_lex_state = 2},
  [125] = {.lex_state = 50, .external_lex_state = 2},
  [126] = {.lex_state = 50, .external_lex_state = 2},
  [127] = {.lex_state = 50, .external_lex_state = 2},
  [128] = {.lex_state = 50, .external_lex_state = 2},
  [129] = {.lex_state = 50, .external_lex_state = 2},
  [130] = {.lex_state = 50, .external_lex_state = 2},
  [131] = {.lex_state = 50, .external_lex_state = 2},
  [132] = {.lex_state = 50, .external_lex_state = 2},
  [133] = {.lex_state = 50, .external_lex_state = 2},
  [134] = {.lex_state = 50, .external_lex_state = 2},
  [135] = {.lex_state = 50, .external_lex_state = 2},
  [136] = {.lex_state = 50, .external_lex_state = 2},
  [137] = {.lex_state = 50, .external_lex_state = 2},
  [138] = {.lex_state = 50, .external_lex_state = 2},
  [139] = {.lex_state = 50, .external_lex_state = 2},
  [140] = {.lex_state = 50, .external_lex_state = 2},
  [141] = {.lex_state = 50, .external_lex_state = 2},
  [142] = {.lex_state = 50, .external_lex_state = 2},
  [143] = {.lex_state = 50, .external_lex_state = 2},
  [144] = {.lex_state = 50, .external_lex_state = 2},
  [145] = {.lex_state = 50, .external_lex_state = 2},
  [146] = {.lex_state = 50, .external_lex_state = 2},
  [147] = {.lex_state = 50, .external_lex_state = 2},
  [148] = {.lex_state = 50, .external_lex_state = 2},
  [149] = {.lex_state = 50, .external_lex_state = 2},
  [150] = {.lex_state = 50, .external_lex_state = 2},
  [151] = {.lex_state = 50, .external_lex_state = 4},
  [152] = {.lex_state = 50, .external_lex_state = 2},
  [153] = {.lex_state = 50, .external_lex_state = 2},
  [154] = {.lex_state = 50, .external_lex_state = 2},
  [155] = {.lex_state = 50, .external_lex_state = 2},
  [156] = {.lex_state = 50, .external_lex_state = 2},
  [157] = {.lex_state = 50, .external_lex_state = 2},
  [158] = {.lex_state = 50, .external_lex_state = 2},
  [159] = {.lex_state = 50, .external_lex_state = 2},
  [160] = {.lex_state = 50, .external_lex_state = 2},
  [161] = {.lex_state = 50, .external_lex_state = 2},
  [162] = {.lex_state = 50, .external_lex_state = 2},
  [163] = {.lex_state = 50, .external_lex_state = 2},
  [164] = {.lex_state = 50, .external_lex_state = 2},
  [165] = {.lex_state = 50, .external_lex_state = 2},
  [166] = {.lex_state = 50, .external_lex_state = 2},
  [167] = {.lex_state = 50, .external_lex_state = 2},
  [168] = {.lex_state = 50, .external_lex_state = 2},
  [169] = {.lex_state = 50, .external_lex_state = 2},
  [170] = {.lex_state = 50, .external_lex_state = 2},
  [171] = {.lex_state = 50, .external_lex_state = 2},
  [172] = {.lex_state = 50, .external_lex_state = 2},
  [173] = {.lex_state = 50, .external_lex_state = 2},
  [174] = {.lex_state = 50, .external_lex_state = 2},
  [175] = {.lex_state = 50, .external_lex_state = 2},
  [176] = {.lex_state = 50, .external_lex_state = 2},
  [177] = {.lex_state = 50, .external_lex_state = 2},
  [178] = {.lex_state = 50, .external_lex_state = 2},
  [179] = {.lex_state = 50, .external_lex_state = 2},
  [180] = {.lex_state = 50, .external_lex_state = 2},
  [181] = {.lex_state = 50, .external_lex_state = 2},
  [182] = {.lex_state = 50, .external_lex_state = 2},
  [183] = {.lex_state = 50, .external_lex_state = 2},
  [184] = {.lex_state = 50, .external_lex_state = 2},
  [185] = {.lex_state = 50, .external_lex_state = 2},
  [186] = {.lex_state = 50, .external_lex_state = 2},
  [187] = {.lex_state = 50, .external_lex_state = 2},
  [188] = {.lex_state = 50, .external_lex_state = 2},
  [189] = {.lex_state = 50, .external_lex_state = 2},
  [190] = {.lex_state = 50, .external_lex_state = 2},
  [191] = {.lex_state = 50, .external_lex_state = 2},
  [192] = {.lex_state = 50, .external_lex_state = 2},
  [193] = {.lex_state = 50, .external_lex_state = 2},
  [194] = {.lex_state = 50, .external_lex_state = 2},
  [195] = {.lex_state = 50, .external_lex_state = 2},
  [196] = {.lex_state = 50, .external_lex_state = 2},
  [197] = {.lex_state = 50, .external_lex_state = 2},
  [198] = {.lex_state = 50, .external_lex_state = 2},
  [199] = {.lex_state = 50, .external_lex_state = 2},
  [200] = {.lex_state = 50, .external_lex_state = 2},
  [201] = {.lex_state = 50, .external_lex_state = 2},
  [202] = {.lex_state = 50, .external_lex_state = 2},
  [203] = {.lex_state = 50, .external_lex_state = 2},
  [204] = {.lex_state = 50, .external_lex_state = 2},
  [205] = {.lex_state = 50, .external_lex_state = 2},
  [206] = {.lex_state = 50, .external_lex_state = 2},
  [207] = {.lex_state = 50, .external_lex_state = 2},
  [208] = {.lex_state = 50, .external_lex_state = 2},
  [209] = {.lex_state = 50, .external_lex_state = 3},
  [210] = {.lex_state = 50, .external_lex_state = 2},
  [211] = {.lex_state = 50, .external_lex_state = 2},
  [212] = {.lex_state = 50, .external_lex_state = 2},
  [213] = {.lex_state = 50, .external_lex_state = 2},
  [214] = {.lex_state = 50, .external_lex_state = 2},
  [215] = {.lex_state = 50, .external_lex_state = 2},
  [216] = {.lex_state = 50, .external_lex_state = 2},
  [217] = {.lex_state = 50, .external_lex_state = 2},
  [218] = {.lex_state = 50, .external_lex_state = 2},
  [219] = {.lex_state = 50, .external_lex_state = 2},
  [220] = {.lex_state = 50, .external_lex_state = 2},
  [221] = {.lex_state = 50, .external_lex_state = 4},
  [222] = {.lex_state = 50, .external_lex_state = 2},
  [223] = {.lex_state = 50, .external_lex_state = 2},
  [224] = {.lex_state = 50, .external_lex_state = 2},
  [225] = {.lex_state = 50, .external_lex_state = 2},
  [226] = {.lex_state = 50, .external_lex_state = 2},
  [227] = {.lex_state = 50, .external_lex_state = 2},
  [228] = {.lex_state = 50, .external_lex_state = 2},
  [229] = {.lex_state = 50, .external_lex_state = 2},
  [230] = {.lex_state = 50, .external_lex_state = 2},
  [231] = {.lex_state = 50, .external_lex_state = 2},
  [232] = {.lex_state = 50, .external_lex_state = 2},
  [233] = {.lex_state = 50, .external_lex_state = 2},
  [234] = {.lex_state = 50, .external_lex_state = 2},
  [235] = {.lex_state = 50, .external_lex_state = 2},
  [236] = {.lex_state = 50, .external_lex_state = 2},
  [237] = {.lex_state = 50, .external_lex_state = 2},
  [238] = {.lex_state = 50, .external_lex_state = 2},
  [239] = {.lex_state = 50, .external_lex_state = 2},
  [240] = {.lex_state = 50, .external_lex_state = 2},
  [241] = {.lex_state = 50, .external_lex_state = 2},
  [242] = {.lex_state = 50, .external_lex_state = 2},
  [243] = {.lex_state = 50, .external_lex_state = 2},
  [244] = {.lex_state = 50, .external_lex_state = 2},
  [245] = {.lex_state = 50, .external_lex_state = 2},
  [246] = {.lex_state = 50, .external_lex_state = 2},
  [247] = {.lex_state = 50, .external_lex_state = 2},
  [248] = {.lex_state = 50, .external_lex_state = 2},
  [249] = {.lex_state = 50, .external_lex_state = 2},
  [250] = {.lex_state = 50, .external_lex_state = 2},
  [251] = {.lex_state = 50, .external_lex_state = 2},
  [252] = {.lex_state = 50, .external_lex_state = 2},
  [253] = {.lex_state = 50, .external_lex_state = 2},
  [254] = {.lex_state = 50, .external_lex_state = 2},
  [255] = {.lex_state = 50, .external_lex_state = 2},
  [256] = {.lex_state = 50, .external_lex_state = 2},
  [257] = {.lex_state = 50, .external_lex_state = 2},
  [258] = {.lex_state = 50, .external_lex_state = 2},
  [259] = {.lex_state = 50, .external_lex_state = 2},
  [260] = {.lex_state = 50, .external_lex_state = 2},
  [261] = {.lex_state = 50, .external_lex_state = 2},
  [262] = {.lex_state = 50, .external_lex_state = 2},
  [263] = {.lex_state = 50, .external_lex_state = 2},
  [264] = {.lex_state = 50, .external_lex_state = 2},
  [265] = {.lex_state = 50, .external_lex_state = 4},
  [266] = {.lex_state = 50, .external_lex_state = 2},
  [267] = {.lex_state = 50, .external_lex_state = 2},
  [268] = {.lex_state = 50, .external_lex_state = 2},
  [269] = {.lex_state = 50, .external_lex_state = 2},
  [270] = {.lex_state = 50, .external_lex_state = 2},
  [271] = {.lex_state = 50, .external_lex_state = 2},
  [272] = {.lex_state = 50, .external_lex_state = 2},
  [273] = {.lex_state = 50, .external_lex_state = 2},
  [274] = {.lex_state = 50, .external_lex_state = 2},
  [275] = {.lex_state = 50, .external_lex_state = 2},
  [276] = {.lex_state = 50, .external_lex_state = 2},
  [277] = {.lex_state = 50, .external_lex_state = 2},
  [278] = {.lex_state = 50, .external_lex_state = 2},
  [279] = {.lex_state = 50, .external_lex_state = 2},
  [280] = {.lex_state = 50, .external_lex_state = 2},
  [281] = {.lex_state = 50, .external_lex_state = 2},
  [282] = {.lex_state = 50, .external_lex_state = 2},
  [283] = {.lex_state = 50, .external_lex_state = 2},
  [284] = {.lex_state = 50, .external_lex_state = 2},
  [285] = {.lex_state = 50, .external_lex_state = 2},
  [286] = {.lex_state = 50, .external_lex_state = 2},
  [287] = {.lex_state = 50, .external_lex_state = 2},
  [288] = {.lex_state = 50, .external_lex_state = 2},
  [289] = {.lex_state = 50, .external_lex_state = 2},
  [290] = {.lex_state = 50, .external_lex_state = 2},
  [291] = {.lex_state = 50, .external_lex_state = 2},
  [292] = {.lex_state = 50, .external_lex_state = 2},
  [293] = {.lex_state = 50, .external_lex_state = 2},
  [294] = {.lex_state = 50, .external_lex_state = 2},
  [295] = {.lex_state = 50, .external_lex_state = 2},
  [296] = {.lex_state = 50, .external_lex_state = 2},
  [297] = {.lex_state = 50, .external_lex_state = 2},
  [298] = {.lex_state = 50, .external_lex_state = 2},
  [299] = {.lex_state = 50, .external_lex_state = 2},
  [300] = {.lex_state = 50, .external_lex_state = 2},
  [301] = {.lex_state = 50, .external_lex_state = 2},
  [302] = {.lex_state = 50, .external_lex_state = 2},
  [303] = {.lex_state = 50, .external_lex_state = 2},
  [304] = {.lex_state = 50, .external_lex_state = 2},
  [305] = {.lex_state = 50, .external_lex_state = 2},
  [306] = {.lex_state = 50, .external_lex_state = 2},
  [307] = {.lex_state = 50, .external_lex_state = 2},
  [308] = {.lex_state = 50, .external_lex_state = 2},
  [309] = {.lex_state = 50, .external_lex_state = 2},
  [310] = {.lex_state = 50, .external_lex_state = 2},
  [311] = {.lex_state = 50, .external_lex_state = 2},
  [312] = {.lex_state = 50, .external_lex_state = 2},
  [313] = {.lex_state = 50, .external_lex_state = 2},
  [314] = {.lex_state = 50, .external_lex_state = 2},
  [315] = {.lex_state = 50, .external_lex_state = 2},
  [316] = {.lex_state = 50, .external_lex_state = 2},
  [317] = {.lex_state = 50, .external_lex_state = 2},
  [318] = {.lex_state = 50, .external_lex_state = 2},
  [319] = {.lex_state = 50, .external_lex_state = 2},
  [320] = {.lex_state = 50, .external_lex_state = 2},
  [321] = {.lex_state = 50, .external_lex_state = 2},
  [322] = {.lex_state = 50, .external_lex_state = 2},
  [323] = {.lex_state = 50, .external_lex_state = 2},
  [324] = {.lex_state = 50, .external_lex_state = 2},
  [325] = {.lex_state = 50, .external_lex_state = 2},
  [326] = {.lex_state = 50, .external_lex_state = 2},
  [327] = {.lex_state = 50, .external_lex_state = 2},
  [328] = {.lex_state = 50, .external_lex_state = 2},
  [329] = {.lex_state = 50, .external_lex_state = 2},
  [330] = {.lex_state = 50, .external_lex_state = 2},
  [331] = {.lex_state = 50, .external_lex_state = 2},
  [332] = {.lex_state = 50, .external_lex_state = 2},
  [333] = {.lex_state = 50, .external_lex_state = 2},
  [334] = {.lex_state = 50, .external_lex_state = 2},
  [335] = {.lex_state = 50, .external_lex_state = 2},
  [336] = {.lex_state = 50, .external_lex_state = 2},
  [337] = {.lex_state = 50, .external_lex_state = 2},
  [338] = {.lex_state = 50, .external_lex_state = 2},
  [339] = {.lex_state = 50, .external_lex_state = 2},
  [340] = {.lex_state = 50, .external_lex_state = 2},
  [341] = {.lex_state = 50, .external_lex_state = 2},
  [342] = {.lex_state = 50, .external_lex_state = 2},
  [343] = {.lex_state = 50, .external_lex_state = 2},
  [344] = {.lex_state = 50, .external_lex_state = 2},
  [345] = {.lex_state = 50, .external_lex_state = 2},
  [346] = {.lex_state = 50, .external_lex_state = 2},
  [347] = {.lex_state = 50, .external_lex_state = 2},
  [348] = {.lex_state = 50, .external_lex_state = 2},
  [349] = {.lex_state = 50, .external_lex_state = 2},
  [350] = {.lex_state = 50, .external_lex_state = 2},
  [351] = {.lex_state = 50, .external_lex_state = 2},
  [352] = {.lex_state = 50, .external_lex_state = 2},
  [353] = {.lex_state = 50, .external_lex_state = 2},
  [354] = {.lex_state = 50, .external_lex_state = 2},
  [355] = {.lex_state = 50, .external_lex_state = 2},
  [356] = {.lex_state = 50, .external_lex_state = 2},
  [357] = {.lex_state = 50, .external_lex_state = 2},
  [358] = {.lex_state = 50, .external_lex_state = 2},
  [359] = {.lex_state = 50, .external_lex_state = 2},
  [360] = {.lex_state = 50, .external_lex_state = 2},
  [361] = {.lex_state = 50, .external_lex_state = 2},
  [362] = {.lex_state = 50, .external_lex_state = 2},
  [363] = {.lex_state = 50, .external_lex_state = 2},
  [364] = {.lex_state = 50, .external_lex_state = 2},
  [365] = {.lex_state = 50, .external_lex_state = 2},
  [366] = {.lex_state = 50, .external_lex_state = 2},
  [367] = {.lex_state = 50, .external_lex_state = 2},
  [368] = {.lex_state = 50, .external_lex_state = 2},
  [369] = {.lex_state = 50, .external_lex_state = 2},
  [370] = {.lex_state = 50, .external_lex_state = 2},
  [371] = {.lex_state = 50, .external_lex_state = 2},
  [372] = {.lex_state = 50, .external_lex_state = 2},
  [373] = {.lex_state = 50, .external_lex_state = 2},
  [374] = {.lex_state = 50, .external_lex_state = 2},
  [375] = {.lex_state = 50, .external_lex_state = 2},
  [376] = {.lex_state = 50, .external_lex_state = 2},
  [377] = {.lex_state = 50, .external_lex_state = 2},
  [378] = {.lex_state = 50, .external_lex_state = 2},
  [379] = {.lex_state = 50, .external_lex_state = 2},
  [380] = {.lex_state = 50, .external_lex_state = 2},
  [381] = {.lex_state = 50, .external_lex_state = 2},
  [382] = {.lex_state = 50, .external_lex_state = 2},
  [383] = {.lex_state = 50, .external_lex_state = 2},
  [384] = {.lex_state = 50, .external_lex_state = 2},
  [385] = {.lex_state = 50, .external_lex_state = 2},
  [386] = {.lex_state = 50, .external_lex_state = 2},
  [387] = {.lex_state = 50, .external_lex_state = 2},
  [388] = {.lex_state = 50, .external_lex_state = 2},
  [389] = {.lex_state = 50, .external_lex_state = 2},
  [390] = {.lex_state = 50, .external_lex_state = 2},
  [391] = {.lex_state = 50, .external_lex_state = 2},
  [392] = {.lex_state = 50, .external_lex_state = 2},
  [393] = {.lex_state = 50, .external_lex_state = 2},
  [394] = {.lex_state = 50, .external_lex_state = 2},
  [395] = {.lex_state = 50, .external_lex_state = 2},
  [396] = {.lex_state = 50, .external_lex_state = 2},
  [397] = {.lex_state = 50, .external_lex_state = 2},
  [398] = {.lex_state = 50, .external_lex_state = 2},
  [399] = {.lex_state = 50, .external_lex_state = 2},
  [400] = {.lex_state = 50, .external_lex_state = 2},
  [401] = {.lex_state = 50, .external_lex_state = 2},
  [402] = {.lex_state = 50, .external_lex_state = 2},
  [403] = {.lex_state = 50, .external_lex_state = 2},
  [404] = {.lex_state = 50, .external_lex_state = 2},
  [405] = {.lex_state = 50, .external_lex_state = 2},
  [406] = {.lex_state = 50, .external_lex_state = 2},
  [407] = {.lex_state = 50, .external_lex_state = 2},
  [408] = {.lex_state = 50, .external_lex_state = 2},
  [409] = {.lex_state = 50, .external_lex_state = 2},
  [410] = {.lex_state = 50, .external_lex_state = 2},
  [411] = {.lex_state = 50, .external_lex_state = 2},
  [412] = {.lex_state = 50, .external_lex_state = 2},
  [413] = {.lex_state = 50, .external_lex_state = 2},
  [414] = {.lex_state = 50, .external_lex_state = 2},
  [415] = {.lex_state = 50, .external_lex_state = 2},
  [416] = {.lex_state = 50, .external_lex_state = 2},
  [417] = {.lex_state = 50, .external_lex_state = 2},
  [418] = {.lex_state = 50, .external_lex_state = 2},
  [419] = {.lex_state = 50, .external_lex_state = 2},
  [420] = {.lex_state = 50, .external_lex_state = 2},
  [421] = {.lex_state = 50, .external_lex_state = 2},
  [422] = {.lex_state = 50, .external_lex_state = 2},
  [423] = {.lex_state = 50, .external_lex_state = 2},
  [424] = {.lex_state = 50, .external_lex_state = 2},
  [425] = {.lex_state = 50, .external_lex_state = 4},
  [426] = {.lex_state = 50, .external_lex_state = 2},
  [427] = {.lex_state = 50, .external_lex_state = 2},
  [428] = {.lex_state = 50, .external_lex_state = 4},
  [429] = {.lex_state = 50, .external_lex_state = 2},
  [430] = {.lex_state = 50, .external_lex_state = 2},
  [431] = {.lex_state = 50, .external_lex_state = 2},
  [432] = {.lex_state = 50, .external_lex_state = 2},
  [433] = {.lex_state = 50, .external_lex_state = 2},
  [434] = {.lex_state = 50, .external_lex_state = 2},
  [435] = {.lex_state = 50, .external_lex_state = 2},
  [436] = {.lex_state = 50, .external_lex_state = 2},
  [437] = {.lex_state = 50, .external_lex_state = 2},
  [438] = {.lex_state = 50, .external_lex_state = 2},
  [439] = {.lex_state = 50, .external_lex_state = 2},
  [440] = {.lex_state = 50, .external_lex_state = 2},
  [441] = {.lex_state = 50, .external_lex_state = 2},
  [442] = {.lex_state = 50, .external_lex_state = 2},
  [443] = {.lex_state = 50, .external_lex_state = 2},
  [444] = {.lex_state = 50, .external_lex_state = 2},
  [445] = {.lex_state = 50, .external_lex_state = 2},
  [446] = {.lex_state = 50, .external_lex_state = 2},
  [447] = {.lex_state = 50, .external_lex_state = 2},
  [448] = {.lex_state = 50, .external_lex_state = 2},
  [449] = {.lex_state = 50, .external_lex_state = 4},
  [450] = {.lex_state = 50, .external_lex_state = 2},
  [451] = {.lex_state = 50, .external_lex_state = 4},
  [452] = {.lex_state = 50, .external_lex_state = 2},
  [453] = {.lex_state = 50, .external_lex_state = 2},
  [454] = {.lex_state = 50, .external_lex_state = 2},
  [455] = {.lex_state = 50, .external_lex_state = 2},
  [456] = {.lex_state = 50, .external_lex_state = 2},
  [457] = {.lex_state = 50, .external_lex_state = 2},
  [458] = {.lex_state = 50, .external_lex_state = 2},
  [459] = {.lex_state = 50, .external_lex_state = 2},
  [460] = {.lex_state = 50, .external_lex_state = 2},
  [461] = {.lex_state = 50, .external_lex_state = 2},
  [462] = {.lex_state = 50, .external_lex_state = 2},
  [463] = {.lex_state = 50, .external_lex_state = 2},
  [464] = {.lex_state = 50, .external_lex_state = 2},
  [465] = {.lex_state = 50, .external_lex_state = 2},
  [466] = {.lex_state = 50, .external_lex_state = 2},
  [467] = {.lex_state = 50, .external_lex_state = 2},
  [468] = {.lex_state = 50, .external_lex_state = 2},
  [469] = {.lex_state = 50, .external_lex_state = 2},
  [470] = {.lex_state = 50, .external_lex_state = 2},
  [471] = {.lex_state = 50, .external_lex_state = 2},
  [472] = {.lex_state = 50, .external_lex_state = 2},
  [473] = {.lex_state = 50, .external_lex_state = 2},
  [474] = {.lex_state = 50, .external_lex_state = 2},
  [475] = {.lex_state = 50, .external_lex_state = 2},
  [476] = {.lex_state = 50, .external_lex_state = 2},
  [477] = {.lex_state = 50, .external_lex_state = 2},
  [478] = {.lex_state = 50, .external_lex_state = 2},
  [479] = {.lex_state = 50, .external_lex_state = 2},
  [480] = {.lex_state = 50, .external_lex_state = 2},
  [481] = {.lex_state = 50, .external_lex_state = 2},
  [482] = {.lex_state = 50, .external_lex_state = 2},
  [483] = {.lex_state = 50, .external_lex_state = 2},
  [484] = {.lex_state = 50, .external_lex_state = 2},
  [485] = {.lex_state = 50, .external_lex_state = 2},
  [486] = {.lex_state = 50, .external_lex_state = 2},
  [487] = {.lex_state = 50, .external_lex_state = 2},
  [488] = {.lex_state = 50, .external_lex_state = 2},
  [489] = {.lex_state = 50, .external_lex_state = 2},
  [490] = {.lex_state = 50, .external_lex_state = 2},
  [491] = {.lex_state = 50, .external_lex_state = 2},
  [492] = {.lex_state = 50, .external_lex_state = 2},
  [493] = {.lex_state = 50, .external_lex_state = 2},
  [494] = {.lex_state = 50, .external_lex_state = 2},
  [495] = {.lex_state = 50, .external_lex_state = 2},
  [496] = {.lex_state = 50, .external_lex_state = 2},
  [497] = {.lex_state = 50, .external_lex_state = 2},
  [498] = {.lex_state = 50, .external_lex_state = 2},
  [499] = {.lex_state = 50, .external_lex_state = 2},
  [500] = {.lex_state = 50, .external_lex_state = 2},
  [501] = {.lex_state = 50, .external_lex_state = 2},
  [502] = {.lex_state = 50, .external_lex_state = 2},
  [503] = {.lex_state = 50, .external_lex_state = 2},
  [504] = {.lex_state = 50, .external_lex_state = 2},
  [505] = {.lex_state = 50, .external_lex_state = 2},
  [506] = {.lex_state = 50, .external_lex_state = 2},
  [507] = {.lex_state = 50, .external_lex_state = 2},
  [508] = {.lex_state = 50, .external_lex_state = 2},
  [509] = {.lex_state = 50, .external_lex_state = 2},
  [510] = {.lex_state = 50, .external_lex_state = 2},
  [511] = {.lex_state = 50, .external_lex_state = 2},
  [512] = {.lex_state = 50, .external_lex_state = 2},
  [513] = {.lex_state = 50, .external_lex_state = 2},
  [514] = {.lex_state = 50, .external_lex_state = 4},
  [515] = {.lex_state = 50, .external_lex_state = 2},
  [516] = {.lex_state = 50, .external_lex_state = 2},
  [517] = {.lex_state = 50, .external_lex_state = 4},
  [518] = {.lex_state = 50, .external_lex_state = 2},
  [519] = {.lex_state = 50, .external_lex_state = 2},
  [520] = {.lex_state = 50, .external_lex_state = 2},
  [521] = {.lex_state = 50, .external_lex_state = 5},
  [522] = {.lex_state = 50, .external_lex_state = 3},
  [523] = {.lex_state = 50, .external_lex_state = 3},
  [524] = {.lex_state = 50, .external_lex_state = 2},
  [525] = {.lex_state = 50, .external_lex_state = 2},
  [526] = {.lex_state = 50, .external_lex_state = 2},
  [527] = {.lex_state = 50, .external_lex_state = 2},
  [528] = {.lex_state = 50, .external_lex_state = 2},
  [529] = {.lex_state = 50, .external_lex_state = 6},
  [530] = {.lex_state = 50, .external_lex_state = 7},
  [531] = {.lex_state = 50, .external_lex_state = 8},
  [532] = {.lex_state = 50, .external_lex_state = 9},
  [533] = {.lex_state = 50, .external_lex_state = 10},
  [534] = {.lex_state = 50, .external_lex_state = 11},
  [535] = {.lex_state = 50, .external_lex_state = 12},
  [536] = {.lex_state = 50, .external_lex_state = 9},
  [537] = {.lex_state = 50, .external_lex_state = 6},
  [538] = {.lex_state = 50, .external_lex_state = 13},
  [539] = {.lex_state = 50, .external_lex_state = 6},
  [540] = {.lex_state = 50, .external_lex_state = 6},
  [541] = {.lex_state = 50, .external_lex_state = 14},
  [542] = {.lex_state = 50, .external_lex_state = 12},
  [543] = {.lex_state = 50, .external_lex_state = 15},
  [544] = {.lex_state = 50, .external_lex_state = 16},
  [545] = {.lex_state = 50, .external_lex_state = 7},
  [546] = {.lex_state = 50, .external_lex_state = 6},
  [547] = {.lex_state = 50, .external_lex_state = 7},
  [548] = {.lex_state = 50, .external_lex_state = 17},
  [549] = {.lex_state = 50, .external_lex_state = 8},
  [550] = {.lex_state = 50, .external_lex_state = 6},
  [551] = {.lex_state = 50, .external_lex_state = 13},
  [552] = {.lex_state = 50, .external_lex_state = 18},
  [553] = {.lex_state = 50, .external_lex_state = 19},
  [554] = {.lex_state = 50, .external_lex_state = 7},
  [555] = {.lex_state = 50, .external_lex_state = 8},
  [556] = {.lex_state = 50, .external_lex_state = 8},
  [557] = {.lex_state = 50, .external_lex_state = 14},
  [558] = {.lex_state = 50, .external_lex_state = 20},
  [559] = {.lex_state = 50, .external_lex_state = 15},
  [560] = {.lex_state = 50, .external_lex_state = 12},
  [561] = {.lex_state = 50, .external_lex_state = 11},
  [562] = {.lex_state = 50, .external_lex_state = 17},
  [563] = {.lex_state = 50, .external_lex_state = 21},
  [564] = {.lex_state = 50, .external_lex_state = 22},
  [565] = {.lex_state = 50, .external_lex_state = 11},
  [566] = {.lex_state = 50, .external_lex_state = 8},
  [567] = {.lex_state = 50, .external_lex_state = 7},
  [568] = {.lex_state = 50, .external_lex_state = 15},
  [569] = {.lex_state = 50, .external_lex_state = 20},
  [570] = {.lex_state = 50, .external_lex_state = 10},
  [571] = {.lex_state = 50, .external_lex_state = 8},
  [572] = {.lex_state = 50, .external_lex_state = 18},
  [573] = {.lex_state = 50, .external_lex_state = 13},
  [574] = {.lex_state = 50, .external_lex_state = 10},
  [575] = {.lex_state = 50, .external_lex_state = 19},
  [576] = {.lex_state = 50, .external_lex_state = 16},
  [577] = {.lex_state = 50, .external_lex_state = 7},
  [578] = {.lex_state = 50, .external_lex_state = 10},
  [579] = {.lex_state = 50, .external_lex_state = 11},
  [580] = {.lex_state = 50, .external_lex_state = 3},
  [581] = {.lex_state = 50, .external_lex_state = 3},
  [582] = {.lex_state = 50, .external_lex_state = 3},
  [583] = {.lex_state = 50, .external_lex_state = 3},
  [584] = {.lex_state = 50, .external_lex_state = 10},
  [585] = {.lex_state = 50, .external_lex_state = 3},
  [586] = {.lex_state = 50, .external_lex_state = 22},
  [587] = {.lex_state = 50, .external_lex_state = 3},
  [588] = {.lex_state = 50, .external_lex_state = 9},
  [589] = {.lex_state = 50, .external_lex_state = 3},
  [590] = {.lex_state = 50, .external_lex_state = 3},
  [591] = {.lex_state = 50, .external_lex_state = 3},
  [592] = {.lex_state = 50, .external_lex_state = 3},
  [593] = {.lex_state = 50, .external_lex_state = 3},
  [594] = {.lex_state = 50, .external_lex_state = 3},
  [595] = {.lex_state = 50, .external_lex_state = 3},
  [596] = {.lex_state = 50, .external_lex_state = 3},
  [597] = {.lex_state = 50, .external_lex_state = 3},
  [598] = {.lex_state = 50, .external_lex_state = 3},
  [599] = {.lex_state = 50, .external_lex_state = 3},
  [600] = {.lex_state = 50, .external_lex_state = 22},
  [601] = {.lex_state = 50, .external_lex_state = 3},
  [602] = {.lex_state = 50, .external_lex_state = 20},
  [603] = {.lex_state = 50, .external_lex_state = 19},
  [604] = {.lex_state = 50, .external_lex_state = 3},
  [605] = {.lex_state = 50, .external_lex_state = 3},
  [606] = {.lex_state = 50, .external_lex_state = 10},
  [607] = {.lex_state = 50, .external_lex_state = 3},
  [608] = {.lex_state = 50, .external_lex_state = 3},
  [609] = {.lex_state = 50, .external_lex_state = 3},
  [610] = {.lex_state = 50, .external_lex_state = 3},
  [611] = {.lex_state = 50, .external_lex_state = 2},
  [612] = {.lex_state = 50, .external_lex_state = 3},
  [613] = {.lex_state = 50, .external_lex_state = 3},
  [614] = {.lex_state = 50, .external_lex_state = 19},
  [615] = {.lex_state = 50, .external_lex_state = 11},
  [616] = {.lex_state = 50, .external_lex_state = 3},
  [617] = {.lex_state = 50, .external_lex_state = 3},
  [618] = {.lex_state = 50, .external_lex_state = 3},
  [619] = {.lex_state = 50, .external_lex_state = 18},
  [620] = {.lex_state = 50, .external_lex_state = 9},
  [621] = {.lex_state = 50, .external_lex_state = 3},
  [622] = {.lex_state = 50, .external_lex_state = 11},
  [623] = {.lex_state = 50, .external_lex_state = 3},
  [624] = {.lex_state = 50, .external_lex_state = 3},
  [625] = {.lex_state = 50, .external_lex_state = 21},
  [626] = {.lex_state = 50, .external_lex_state = 3},
  [627] = {.lex_state = 50, .external_lex_state = 3},
  [628] = {.lex_state = 50, .external_lex_state = 19},
  [629] = {.lex_state = 50, .external_lex_state = 3},
  [630] = {.lex_state = 50, .external_lex_state = 3},
  [631] = {.lex_state = 50, .external_lex_state = 2},
  [632] = {.lex_state = 50, .external_lex_state = 2},
  [633] = {.lex_state = 50, .external_lex_state = 2},
  [634] = {.lex_state = 50, .external_lex_state = 2},
  [635] = {.lex_state = 50, .external_lex_state = 2},
  [636] = {.lex_state = 50, .external_lex_state = 14},
  [637] = {.lex_state = 50, .external_lex_state = 2},
  [638] = {.lex_state = 50, .external_lex_state = 2},
  [639] = {.lex_state = 50, .external_lex_state = 2},
  [640] = {.lex_state = 50, .external_lex_state = 2},
  [641] = {.lex_state = 50, .external_lex_state = 2},
  [642] = {.lex_state = 50, .external_lex_state = 2},
  [643] = {.lex_state = 50, .external_lex_state = 2},
  [644] = {.lex_state = 50, .external_lex_state = 14},
  [645] = {.lex_state = 50, .external_lex_state = 2},
  [646] = {.lex_state = 50, .external_lex_state = 2},
  [647] = {.lex_state = 50, .external_lex_state = 2},
  [648] = {.lex_state = 50, .external_lex_state = 19},
  [649] = {.lex_state = 50, .external_lex_state = 2},
  [650] = {.lex_state = 50, .external_lex_state = 2},
  [651] = {.lex_state = 50, .external_lex_state = 2},
  [652] = {.lex_state = 50, .external_lex_state = 2},
  [653] = {.lex_state = 50, .external_lex_state = 2},
  [654] = {.lex_state = 50, .external_lex_state = 2},
  [655] = {.lex_state = 50, .external_lex_state = 2},
  [656] = {.lex_state = 50, .external_lex_state = 2},
  [657] = {.lex_state = 50, .external_lex_state = 2},
  [658] = {.lex_state = 50, .external_lex_state = 2},
  [659] = {.lex_state = 50, .external_lex_state = 2},
  [660] = {.lex_state = 50, .external_lex_state = 2},
  [661] = {.lex_state = 50, .external_lex_state = 22},
  [662] = {.lex_state = 50, .external_lex_state = 2},
  [663] = {.lex_state = 50, .external_lex_state = 2},
  [664] = {.lex_state = 50, .external_lex_state = 2},
  [665] = {.lex_state = 50, .external_lex_state = 2},
  [666] = {.lex_state = 50, .external_lex_state = 3},
  [667] = {.lex_state = 50, .external_lex_state = 2},
  [668] = {.lex_state = 50, .external_lex_state = 3},
  [669] = {.lex_state = 50, .external_lex_state = 2},
  [670] = {.lex_state = 50, .external_lex_state = 3},
  [671] = {.lex_state = 50, .external_lex_state = 3},
  [672] = {.lex_state = 50, .external_lex_state = 3},
  [673] = {.lex_state = 50, .external_lex_state = 3},
  [674] = {.lex_state = 50, .external_lex_state = 2},
  [675] = {.lex_state = 50, .external_lex_state = 3},
  [676] = {.lex_state = 50, .external_lex_state = 3},
  [677] = {.lex_state = 50, .external_lex_state = 3},
  [678] = {.lex_state = 50, .external_lex_state = 3},
  [679] = {.lex_state = 50, .external_lex_state = 3},
  [680] = {.lex_state = 50, .external_lex_state = 3},
  [681] = {.lex_state = 50, .external_lex_state = 2},
  [682] = {.lex_state = 50, .external_lex_state = 3},
  [683] = {.lex_state = 50, .external_lex_state = 3},
  [684] = {.lex_state = 50, .external_lex_state = 3},
  [685] = {.lex_state = 50, .external_lex_state = 3},
  [686] = {.lex_state = 50, .external_lex_state = 3},
  [687] = {.lex_state = 50, .external_lex_state = 3},
  [688] = {.lex_state = 50, .external_lex_state = 2},
  [689] = {.lex_state = 50, .external_lex_state = 3},
  [690] = {.lex_state = 50, .external_lex_state = 3},
  [691] = {.lex_state = 50, .external_lex_state = 3},
  [692] = {.lex_state = 50, .external_lex_state = 3},
  [693] = {.lex_state = 50, .external_lex_state = 3},
  [694] = {.lex_state = 50, .external_lex_state = 19},
  [695] = {.lex_state = 50, .external_lex_state = 2},
  [696] = {.lex_state = 50, .external_lex_state = 3},
  [697] = {.lex_state = 50, .external_lex_state = 19},
  [698] = {.lex_state = 50, .external_lex_state = 3},
  [699] = {.lex_state = 50, .external_lex_state = 3},
  [700] = {.lex_state = 50, .external_lex_state = 3},
  [701] = {.lex_state = 50, .external_lex_state = 3},
  [702] = {.lex_state = 50, .external_lex_state = 2},
  [703] = {.lex_state = 50, .external_lex_state = 3},
  [704] = {.lex_state = 50, .external_lex_state = 2},
  [705] = {.lex_state = 50, .external_lex_state = 3},
  [706] = {.lex_state = 50, .external_lex_state = 3},
  [707] = {.lex_state = 50, .external_lex_state = 3},
  [708] = {.lex_state = 50, .external_lex_state = 3},
  [709] = {.lex_state = 50, .external_lex_state = 3},
  [710] = {.lex_state = 50, .external_lex_state = 2},
  [711] = {.lex_state = 50, .external_lex_state = 3},
  [712] = {.lex_state = 50, .external_lex_state = 3},
  [713] = {.lex_state = 50, .external_lex_state = 3},
  [714] = {.lex_state = 50, .external_lex_state = 3},
  [715] = {.lex_state = 50, .external_lex_state = 3},
  [716] = {.lex_state = 50, .external_lex_state = 3},
  [717] = {.lex_state = 50, .external_lex_state = 2},
  [718] = {.lex_state = 50, .external_lex_state = 3},
  [719] = {.lex_state = 50, .external_lex_state = 3},
  [720] = {.lex_state = 50, .external_lex_state = 3},
  [721] = {.lex_state = 50, .external_lex_state = 3},
  [722] = {.lex_state = 50, .external_lex_state = 3},
  [723] = {.lex_state = 50, .external_lex_state = 2},
  [724] = {.lex_state = 50, .external_lex_state = 2},
  [725] = {.lex_state = 50, .external_lex_state = 3},
  [726] = {.lex_state = 50, .external_lex_state = 3},
  [727] = {.lex_state = 50, .external_lex_state = 3},
  [728] = {.lex_state = 50, .external_lex_state = 3},
  [729] = {.lex_state = 50, .external_lex_state = 3},
  [730] = {.lex_state = 50, .external_lex_state = 3},
  [731] = {.lex_state = 50, .external_lex_state = 3},
  [732] = {.lex_state = 50, .external_lex_state = 2},
  [733] = {.lex_state = 50, .external_lex_state = 3},
  [734] = {.lex_state = 50, .external_lex_state = 3},
  [735] = {.lex_state = 50, .external_lex_state = 3},
  [736] = {.lex_state = 50, .external_lex_state = 3},
  [737] = {.lex_state = 50, .external_lex_state = 3},
  [738] = {.lex_state = 50, .external_lex_state = 3},
  [739] = {.lex_state = 50, .external_lex_state = 3},
  [740] = {.lex_state = 50, .external_lex_state = 3},
  [741] = {.lex_state = 50, .external_lex_state = 2},
  [742] = {.lex_state = 50, .external_lex_state = 3},
  [743] = {.lex_state = 50, .external_lex_state = 3},
  [744] = {.lex_state = 50, .external_lex_state = 3},
  [745] = {.lex_state = 50, .external_lex_state = 3},
  [746] = {.lex_state = 50, .external_lex_state = 3},
  [747] = {.lex_state = 50, .external_lex_state = 3},
  [748] = {.lex_state = 50, .external_lex_state = 3},
  [749] = {.lex_state = 50, .external_lex_state = 3},
  [750] = {.lex_state = 50, .external_lex_state = 3},
  [751] = {.lex_state = 50, .external_lex_state = 2},
  [752] = {.lex_state = 50, .external_lex_state = 3},
  [753] = {.lex_state = 50, .external_lex_state = 3},
  [754] = {.lex_state = 50, .external_lex_state = 3},
  [755] = {.lex_state = 50, .external_lex_state = 3},
  [756] = {.lex_state = 50, .external_lex_state = 3},
  [757] = {.lex_state = 50, .external_lex_state = 3},
  [758] = {.lex_state = 50, .external_lex_state = 3},
  [759] = {.lex_state = 50, .external_lex_state = 3},
  [760] = {.lex_state = 50, .external_lex_state = 3},
  [761] = {.lex_state = 50, .external_lex_state = 3},
  [762] = {.lex_state = 50, .external_lex_state = 2},
  [763] = {.lex_state = 50, .external_lex_state = 3},
  [764] = {.lex_state = 50, .external_lex_state = 3},
  [765] = {.lex_state = 50, .external_lex_state = 3},
  [766] = {.lex_state = 50, .external_lex_state = 3},
  [767] = {.lex_state = 50, .external_lex_state = 3},
  [768] = {.lex_state = 50, .external_lex_state = 3},
  [769] = {.lex_state = 50, .external_lex_state = 3},
  [770] = {.lex_state = 50, .external_lex_state = 3},
  [771] = {.lex_state = 50, .external_lex_state = 3},
  [772] = {.lex_state = 50, .external_lex_state = 3},
  [773] = {.lex_state = 50, .external_lex_state = 2},
  [774] = {.lex_state = 50, .external_lex_state = 3},
  [775] = {.lex_state = 50, .external_lex_state = 3},
  [776] = {.lex_state = 50, .external_lex_state = 3},
  [777] = {.lex_state = 50, .external_lex_state = 3},
  [778] = {.lex_state = 50, .external_lex_state = 3},
  [779] = {.lex_state = 50, .external_lex_state = 3},
  [780] = {.lex_state = 50, .external_lex_state = 3},
  [781] = {.lex_state = 50, .external_lex_state = 3},
  [782] = {.lex_state = 50, .external_lex_state = 3},
  [783] = {.lex_state = 50, .external_lex_state = 3},
  [784] = {.lex_state = 50, .external_lex_state = 3},
  [785] = {.lex_state = 50, .external_lex_state = 3},
  [786] = {.lex_state = 50, .external_lex_state = 3},
  [787] = {.lex_state = 50, .external_lex_state = 3},
  [788] = {.lex_state = 50, .external_lex_state = 2},
  [789] = {.lex_state = 50, .external_lex_state = 3},
  [790] = {.lex_state = 50, .external_lex_state = 3},
  [791] = {.lex_state = 50, .external_lex_state = 3},
  [792] = {.lex_state = 50, .external_lex_state = 3},
  [793] = {.lex_state = 50, .external_lex_state = 3},
  [794] = {.lex_state = 50, .external_lex_state = 3},
  [795] = {.lex_state = 50, .external_lex_state = 3},
  [796] = {.lex_state = 50, .external_lex_state = 3},
  [797] = {.lex_state = 50, .external_lex_state = 22},
  [798] = {.lex_state = 50, .external_lex_state = 2},
  [799] = {.lex_state = 50, .external_lex_state = 2},
  [800] = {.lex_state = 50, .external_lex_state = 2},
  [801] = {.lex_state = 50, .external_lex_state = 2},
  [802] = {.lex_state = 50, .external_lex_state = 2},
  [803] = {.lex_state = 50, .external_lex_state = 2},
  [804] = {.lex_state = 50, .external_lex_state = 2},
  [805] = {.lex_state = 50, .external_lex_state = 2},
  [806] = {.lex_state = 50, .external_lex_state = 3},
  [807] = {.lex_state = 50, .external_lex_state = 3},
  [808] = {.lex_state = 50, .external_lex_state = 3},
  [809] = {.lex_state = 50, .external_lex_state = 3},
  [810] = {.lex_state = 50, .external_lex_state = 3},
  [811] = {.lex_state = 50, .external_lex_state = 3},
  [812] = {.lex_state = 50, .external_lex_state = 3},
  [813] = {.lex_state = 50, .external_lex_state = 3},
  [814] = {.lex_state = 50, .external_lex_state = 3},
  [815] = {.lex_state = 50, .external_lex_state = 3},
  [816] = {.lex_state = 50, .external_lex_state = 3},
  [817] = {.lex_state = 50, .external_lex_state = 3},
  [818] = {.lex_state = 50, .external_lex_state = 3},
  [819] = {.lex_state = 50, .external_lex_state = 3},
  [820] = {.lex_state = 50, .external_lex_state = 3},
  [821] = {.lex_state = 50, .external_lex_state = 3},
  [822] = {.lex_state = 50, .external_lex_state = 3},
  [823] = {.lex_state = 50, .external_lex_state = 3},
  [824] = {.lex_state = 50, .external_lex_state = 3},
  [825] = {.lex_state = 50, .external_lex_state = 3},
  [826] = {.lex_state = 50, .external_lex_state = 3},
  [827] = {.lex_state = 50, .external_lex_state = 3},
  [828] = {.lex_state = 50, .external_lex_state = 3},
  [829] = {.lex_state = 50, .external_lex_state = 3},
  [830] = {.lex_state = 50, .external_lex_state = 3},
  [831] = {.lex_state = 50, .external_lex_state = 3},
  [832] = {.lex_state = 50, .external_lex_state = 3},
  [833] = {.lex_state = 50, .external_lex_state = 3},
  [834] = {.lex_state = 50, .external_lex_state = 3},
  [835] = {.lex_state = 50, .external_lex_state = 3},
  [836] = {.lex_state = 50, .external_lex_state = 3},
  [837] = {.lex_state = 50, .external_lex_state = 3},
  [838] = {.lex_state = 50, .external_lex_state = 3},
  [839] = {.lex_state = 50, .external_lex_state = 3},
  [840] = {.lex_state = 50, .external_lex_state = 3},
  [841] = {.lex_state = 50, .external_lex_state = 3},
  [842] = {.lex_state = 50, .external_lex_state = 3},
  [843] = {.lex_state = 50, .external_lex_state = 3},
  [844] = {.lex_state = 50, .external_lex_state = 3},
  [845] = {.lex_state = 50, .external_lex_state = 3},
  [846] = {.lex_state = 50, .external_lex_state = 3},
  [847] = {.lex_state = 50, .external_lex_state = 3},
  [848] = {.lex_state = 50, .external_lex_state = 3},
  [849] = {.lex_state = 50, .external_lex_state = 3},
  [850] = {.lex_state = 50, .external_lex_state = 3},
  [851] = {.lex_state = 50, .external_lex_state = 3},
  [852] = {.lex_state = 50, .external_lex_state = 3},
  [853] = {.lex_state = 50, .external_lex_state = 3},
  [854] = {.lex_state = 50, .external_lex_state = 3},
  [855] = {.lex_state = 50, .external_lex_state = 3},
  [856] = {.lex_state = 50, .external_lex_state = 3},
  [857] = {.lex_state = 50, .external_lex_state = 3},
  [858] = {.lex_state = 50, .external_lex_state = 3},
  [859] = {.lex_state = 50, .external_lex_state = 3},
  [860] = {.lex_state = 50, .external_lex_state = 3},
  [861] = {.lex_state = 50, .external_lex_state = 3},
  [862] = {.lex_state = 50, .external_lex_state = 3},
  [863] = {.lex_state = 50, .external_lex_state = 3},
  [864] = {.lex_state = 50, .external_lex_state = 3},
  [865] = {.lex_state = 50, .external_lex_state = 3},
  [866] = {.lex_state = 50, .external_lex_state = 3},
  [867] = {.lex_state = 50, .external_lex_state = 3},
  [868] = {.lex_state = 50, .external_lex_state = 3},
  [869] = {.lex_state = 50, .external_lex_state = 3},
  [870] = {.lex_state = 50, .external_lex_state = 3},
  [871] = {.lex_state = 50, .external_lex_state = 3},
  [872] = {.lex_state = 50, .external_lex_state = 3},
  [873] = {.lex_state = 50, .external_lex_state = 3},
  [874] = {.lex_state = 50, .external_lex_state = 3},
  [875] = {.lex_state = 50, .external_lex_state = 3},
  [876] = {.lex_state = 50, .external_lex_state = 3},
  [877] = {.lex_state = 50, .external_lex_state = 3},
  [878] = {.lex_state = 50, .external_lex_state = 3},
  [879] = {.lex_state = 50, .external_lex_state = 3},
  [880] = {.lex_state = 50, .external_lex_state = 3},
  [881] = {.lex_state = 50, .external_lex_state = 3},
  [882] = {.lex_state = 50, .external_lex_state = 3},
  [883] = {.lex_state = 50, .external_lex_state = 3},
  [884] = {.lex_state = 50, .external_lex_state = 3},
  [885] = {.lex_state = 50, .external_lex_state = 3},
  [886] = {.lex_state = 50, .external_lex_state = 3},
  [887] = {.lex_state = 50, .external_lex_state = 3},
  [888] = {.lex_state = 50, .external_lex_state = 3},
  [889] = {.lex_state = 50, .external_lex_state = 3},
  [890] = {.lex_state = 50, .external_lex_state = 3},
  [891] = {.lex_state = 50, .external_lex_state = 3},
  [892] = {.lex_state = 50, .external_lex_state = 3},
  [893] = {.lex_state = 50, .external_lex_state = 3},
  [894] = {.lex_state = 50, .external_lex_state = 3},
  [895] = {.lex_state = 50, .external_lex_state = 3},
  [896] = {.lex_state = 50, .external_lex_state = 3},
  [897] = {.lex_state = 50, .external_lex_state = 3},
  [898] = {.lex_state = 50, .external_lex_state = 3},
  [899] = {.lex_state = 50, .external_lex_state = 3},
  [900] = {.lex_state = 50, .external_lex_state = 3},
  [901] = {.lex_state = 50, .external_lex_state = 3},
  [902] = {.lex_state = 50, .external_lex_state = 3},
  [903] = {.lex_state = 50, .external_lex_state = 3},
  [904] = {.lex_state = 50, .external_lex_state = 3},
  [905] = {.lex_state = 50, .external_lex_state = 3},
  [906] = {.lex_state = 50, .external_lex_state = 3},
  [907] = {.lex_state = 50, .external_lex_state = 3},
  [908] = {.lex_state = 50, .external_lex_state = 3},
  [909] = {.lex_state = 50, .external_lex_state = 3},
  [910] = {.lex_state = 50, .external_lex_state = 3},
  [911] = {.lex_state = 50, .external_lex_state = 3},
  [912] = {.lex_state = 50, .external_lex_state = 3},
  [913] = {.lex_state = 50, .external_lex_state = 3},
  [914] = {.lex_state = 50, .external_lex_state = 3},
  [915] = {.lex_state = 50, .external_lex_state = 3},
  [916] = {.lex_state = 50, .external_lex_state = 3},
  [917] = {.lex_state = 50, .external_lex_state = 3},
  [918] = {.lex_state = 50, .external_lex_state = 3},
  [919] = {.lex_state = 50, .external_lex_state = 3},
  [920] = {.lex_state = 50, .external_lex_state = 3},
  [921] = {.lex_state = 50, .external_lex_state = 3},
  [922] = {.lex_state = 50, .external_lex_state = 3},
  [923] = {.lex_state = 50, .external_lex_state = 3},
  [924] = {.lex_state = 50, .external_lex_state = 3},
  [925] = {.lex_state = 50, .external_lex_state = 3},
  [926] = {.lex_state = 50, .external_lex_state = 3},
  [927] = {.lex_state = 50, .external_lex_state = 3},
  [928] = {.lex_state = 50, .external_lex_state = 3},
  [929] = {.lex_state = 50, .external_lex_state = 3},
  [930] = {.lex_state = 50, .external_lex_state = 3},
  [931] = {.lex_state = 50, .external_lex_state = 3},
  [932] = {.lex_state = 50, .external_lex_state = 3},
  [933] = {.lex_state = 50, .external_lex_state = 3},
  [934] = {.lex_state = 50, .external_lex_state = 3},
  [935] = {.lex_state = 50, .external_lex_state = 3},
  [936] = {.lex_state = 50, .external_lex_state = 3},
  [937] = {.lex_state = 50, .external_lex_state = 3},
  [938] = {.lex_state = 50, .external_lex_state = 3},
  [939] = {.lex_state = 50, .external_lex_state = 3},
  [940] = {.lex_state = 50, .external_lex_state = 3},
  [941] = {.lex_state = 50, .external_lex_state = 3},
  [942] = {.lex_state = 50, .external_lex_state = 3},
  [943] = {.lex_state = 50, .external_lex_state = 3},
  [944] = {.lex_state = 50, .external_lex_state = 3},
  [945] = {.lex_state = 50, .external_lex_state = 3},
  [946] = {.lex_state = 50, .external_lex_state = 3},
  [947] = {.lex_state = 50, .external_lex_state = 3},
  [948] = {.lex_state = 50, .external_lex_state = 3},
  [949] = {.lex_state = 50, .external_lex_state = 3},
  [950] = {.lex_state = 50, .external_lex_state = 3},
  [951] = {.lex_state = 50, .external_lex_state = 3},
  [952] = {.lex_state = 50, .external_lex_state = 3},
  [953] = {.lex_state = 50, .external_lex_state = 3},
  [954] = {.lex_state = 50, .external_lex_state = 3},
  [955] = {.lex_state = 50, .external_lex_state = 3},
  [956] = {.lex_state = 50, .external_lex_state = 3},
  [957] = {.lex_state = 50, .external_lex_state = 3},
  [958] = {.lex_state = 50, .external_lex_state = 3},
  [959] = {.lex_state = 50, .external_lex_state = 3},
  [960] = {.lex_state = 50, .external_lex_state = 3},
  [961] = {.lex_state = 50, .external_lex_state = 3},
  [962] = {.lex_state = 50, .external_lex_state = 3},
  [963] = {.lex_state = 50, .external_lex_state = 3},
  [964] = {.lex_state = 50, .external_lex_state = 3},
  [965] = {.lex_state = 50, .external_lex_state = 3},
  [966] = {.lex_state = 50, .external_lex_state = 3},
  [967] = {.lex_state = 50, .external_lex_state = 3},
  [968] = {.lex_state = 50, .external_lex_state = 3},
  [969] = {.lex_state = 50, .external_lex_state = 3},
  [970] = {.lex_state = 50, .external_lex_state = 3},
  [971] = {.lex_state = 50, .external_lex_state = 3},
  [972] = {.lex_state = 50, .external_lex_state = 3},
  [973] = {.lex_state = 50, .external_lex_state = 3},
  [974] = {.lex_state = 50, .external_lex_state = 3},
  [975] = {.lex_state = 50, .external_lex_state = 3},
  [976] = {.lex_state = 50, .external_lex_state = 3},
  [977] = {.lex_state = 50, .external_lex_state = 3},
  [978] = {.lex_state = 50, .external_lex_state = 3},
  [979] = {.lex_state = 50, .external_lex_state = 3},
  [980] = {.lex_state = 50, .external_lex_state = 3},
  [981] = {.lex_state = 50, .external_lex_state = 3},
  [982] = {.lex_state = 50, .external_lex_state = 3},
  [983] = {.lex_state = 50, .external_lex_state = 3},
  [984] = {.lex_state = 50, .external_lex_state = 3},
  [985] = {.lex_state = 50, .external_lex_state = 3},
  [986] = {.lex_state = 50, .external_lex_state = 3},
  [987] = {.lex_state = 50, .external_lex_state = 3},
  [988] = {.lex_state = 50, .external_lex_state = 3},
  [989] = {.lex_state = 50, .external_lex_state = 3},
  [990] = {.lex_state = 50, .external_lex_state = 3},
  [991] = {.lex_state = 50, .external_lex_state = 3},
  [992] = {.lex_state = 50, .external_lex_state = 3},
  [993] = {.lex_state = 50, .external_lex_state = 3},
  [994] = {.lex_state = 50, .external_lex_state = 3},
  [995] = {.lex_state = 50, .external_lex_state = 3},
  [996] = {.lex_state = 50, .external_lex_state = 3},
  [997] = {.lex_state = 50, .external_lex_state = 3},
  [998] = {.lex_state = 50, .external_lex_state = 3},
  [999] = {.lex_state = 50, .external_lex_state = 3},
  [1000] = {.lex_state = 50, .external_lex_state = 3},
  [1001] = {.lex_state = 50, .external_lex_state = 3},
  [1002] = {.lex_state = 50, .external_lex_state = 3},
  [1003] = {.lex_state = 50, .external_lex_state = 3},
  [1004] = {.lex_state = 50, .external_lex_state = 3},
  [1005] = {.lex_state = 50, .external_lex_state = 3},
  [1006] = {.lex_state = 50, .external_lex_state = 3},
  [1007] = {.lex_state = 50, .external_lex_state = 3},
  [1008] = {.lex_state = 50, .external_lex_state = 3},
  [1009] = {.lex_state = 50, .external_lex_state = 3},
  [1010] = {.lex_state = 50, .external_lex_state = 3},
  [1011] = {.lex_state = 50, .external_lex_state = 3},
  [1012] = {.lex_state = 50, .external_lex_state = 3},
  [1013] = {.lex_state = 50, .external_lex_state = 3},
  [1014] = {.lex_state = 50, .external_lex_state = 3},
  [1015] = {.lex_state = 50, .external_lex_state = 3},
  [1016] = {.lex_state = 50, .external_lex_state = 3},
  [1017] = {.lex_state = 50, .external_lex_state = 3},
  [1018] = {.lex_state = 50, .external_lex_state = 3},
  [1019] = {.lex_state = 50, .external_lex_state = 3},
  [1020] = {.lex_state = 50, .external_lex_state = 3},
  [1021] = {.lex_state = 50, .external_lex_state = 3},
  [1022] = {.lex_state = 50, .external_lex_state = 3},
  [1023] = {.lex_state = 50, .external_lex_state = 3},
  [1024] = {.lex_state = 50, .external_lex_state = 3},
  [1025] = {.lex_state = 50, .external_lex_state = 3},
  [1026] = {.lex_state = 50, .external_lex_state = 3},
  [1027] = {.lex_state = 50, .external_lex_state = 3},
  [1028] = {.lex_state = 50, .external_lex_state = 3},
  [1029] = {.lex_state = 50, .external_lex_state = 3},
  [1030] = {.lex_state = 50, .external_lex_state = 3},
  [1031] = {.lex_state = 50, .external_lex_state = 3},
  [1032] = {.lex_state = 50, .external_lex_state = 3},
  [1033] = {.lex_state = 50, .external_lex_state = 3},
  [1034] = {.lex_state = 50, .external_lex_state = 3},
  [1035] = {.lex_state = 50, .external_lex_state = 3},
  [1036] = {.lex_state = 50, .external_lex_state = 3},
  [1037] = {.lex_state = 50, .external_lex_state = 3},
  [1038] = {.lex_state = 50, .external_lex_state = 3},
  [1039] = {.lex_state = 50, .external_lex_state = 3},
  [1040] = {.lex_state = 50, .external_lex_state = 3},
  [1041] = {.lex_state = 50, .external_lex_state = 3},
  [1042] = {.lex_state = 50, .external_lex_state = 3},
  [1043] = {.lex_state = 50, .external_lex_state = 3},
  [1044] = {.lex_state = 50, .external_lex_state = 3},
  [1045] = {.lex_state = 50, .external_lex_state = 3},
  [1046] = {.lex_state = 50, .external_lex_state = 3},
  [1047] = {.lex_state = 50, .external_lex_state = 3},
  [1048] = {.lex_state = 50, .external_lex_state = 3},
  [1049] = {.lex_state = 50, .external_lex_state = 3},
  [1050] = {.lex_state = 50, .external_lex_state = 3},
  [1051] = {.lex_state = 50, .external_lex_state = 3},
  [1052] = {.lex_state = 50, .external_lex_state = 3},
  [1053] = {.lex_state = 50, .external_lex_state = 3},
  [1054] = {.lex_state = 50, .external_lex_state = 3},
  [1055] = {.lex_state = 50, .external_lex_state = 3},
  [1056] = {.lex_state = 50, .external_lex_state = 3},
  [1057] = {.lex_state = 50, .external_lex_state = 3},
  [1058] = {.lex_state = 50, .external_lex_state = 3},
  [1059] = {.lex_state = 50, .external_lex_state = 3},
  [1060] = {.lex_state = 50, .external_lex_state = 3},
  [1061] = {.lex_state = 50, .external_lex_state = 3},
  [1062] = {.lex_state = 50, .external_lex_state = 3},
  [1063] = {.lex_state = 50, .external_lex_state = 3},
  [1064] = {.lex_state = 50, .external_lex_state = 3},
  [1065] = {.lex_state = 50, .external_lex_state = 3},
  [1066] = {.lex_state = 50, .external_lex_state = 3},
  [1067] = {.lex_state = 50, .external_lex_state = 3},
  [1068] = {.lex_state = 50, .external_lex_state = 3},
  [1069] = {.lex_state = 50, .external_lex_state = 3},
  [1070] = {.lex_state = 50, .external_lex_state = 3},
  [1071] = {.lex_state = 50, .external_lex_state = 3},
  [1072] = {.lex_state = 50, .external_lex_state = 3},
  [1073] = {.lex_state = 50, .external_lex_state = 3},
  [1074] = {.lex_state = 50, .external_lex_state = 3},
  [1075] = {.lex_state = 50, .external_lex_state = 3},
  [1076] = {.lex_state = 50, .external_lex_state = 3},
  [1077] = {.lex_state = 50, .external_lex_state = 3},
  [1078] = {.lex_state = 50, .external_lex_state = 3},
  [1079] = {.lex_state = 50, .external_lex_state = 3},
  [1080] = {.lex_state = 50, .external_lex_state = 3},
  [1081] = {.lex_state = 50, .external_lex_state = 3},
  [1082] = {.lex_state = 50, .external_lex_state = 3},
  [1083] = {.lex_state = 50, .external_lex_state = 3},
  [1084] = {.lex_state = 50, .external_lex_state = 3},
  [1085] = {.lex_state = 50, .external_lex_state = 3},
  [1086] = {.lex_state = 50, .external_lex_state = 3},
  [1087] = {.lex_state = 50, .external_lex_state = 3},
  [1088] = {.lex_state = 50, .external_lex_state = 3},
  [1089] = {.lex_state = 50, .external_lex_state = 3},
  [1090] = {.lex_state = 50, .external_lex_state = 3},
  [1091] = {.lex_state = 50, .external_lex_state = 3},
  [1092] = {.lex_state = 50, .external_lex_state = 3},
  [1093] = {.lex_state = 50, .external_lex_state = 3},
  [1094] = {.lex_state = 50, .external_lex_state = 3},
  [1095] = {.lex_state = 50, .external_lex_state = 3},
  [1096] = {.lex_state = 50, .external_lex_state = 3},
  [1097] = {.lex_state = 50, .external_lex_state = 3},
  [1098] = {.lex_state = 50, .external_lex_state = 3},
  [1099] = {.lex_state = 50, .external_lex_state = 3},
  [1100] = {.lex_state = 50, .external_lex_state = 3},
  [1101] = {.lex_state = 50, .external_lex_state = 3},
  [1102] = {.lex_state = 50, .external_lex_state = 3},
  [1103] = {.lex_state = 50, .external_lex_state = 3},
  [1104] = {.lex_state = 50, .external_lex_state = 3},
  [1105] = {.lex_state = 50, .external_lex_state = 3},
  [1106] = {.lex_state = 50, .external_lex_state = 3},
  [1107] = {.lex_state = 50, .external_lex_state = 3},
  [1108] = {.lex_state = 50, .external_lex_state = 3},
  [1109] = {.lex_state = 50, .external_lex_state = 3},
  [1110] = {.lex_state = 50, .external_lex_state = 3},
  [1111] = {.lex_state = 50, .external_lex_state = 3},
  [1112] = {.lex_state = 50, .external_lex_state = 3},
  [1113] = {.lex_state = 50, .external_lex_state = 3},
  [1114] = {.lex_state = 50, .external_lex_state = 3},
  [1115] = {.lex_state = 50, .external_lex_state = 3},
  [1116] = {.lex_state = 50, .external_lex_state = 3},
  [1117] = {.lex_state = 50, .external_lex_state = 3},
  [1118] = {.lex_state = 50, .external_lex_state = 3},
  [1119] = {.lex_state = 50, .external_lex_state = 3},
  [1120] = {.lex_state = 50, .external_lex_state = 3},
  [1121] = {.lex_state = 50, .external_lex_state = 3},
  [1122] = {.lex_state = 50, .external_lex_state = 3},
  [1123] = {.lex_state = 50, .external_lex_state = 3},
  [1124] = {.lex_state = 50, .external_lex_state = 3},
  [1125] = {.lex_state = 50, .external_lex_state = 3},
  [1126] = {.lex_state = 50, .external_lex_state = 3},
  [1127] = {.lex_state = 50, .external_lex_state = 3},
  [1128] = {.lex_state = 50, .external_lex_state = 3},
  [1129] = {.lex_state = 50, .external_lex_state = 3},
  [1130] = {.lex_state = 50, .external_lex_state = 3},
  [1131] = {.lex_state = 50, .external_lex_state = 3},
  [1132] = {.lex_state = 50, .external_lex_state = 3},
  [1133] = {.lex_state = 50, .external_lex_state = 3},
  [1134] = {.lex_state = 50, .external_lex_state = 3},
  [1135] = {.lex_state = 50, .external_lex_state = 3},
  [1136] = {.lex_state = 50, .external_lex_state = 3},
  [1137] = {.lex_state = 50, .external_lex_state = 3},
  [1138] = {.lex_state = 50, .external_lex_state = 3},
  [1139] = {.lex_state = 50, .external_lex_state = 3},
  [1140] = {.lex_state = 50, .external_lex_state = 3},
  [1141] = {.lex_state = 50, .external_lex_state = 3},
  [1142] = {.lex_state = 50, .external_lex_state = 3},
  [1143] = {.lex_state = 50, .external_lex_state = 3},
  [1144] = {.lex_state = 50, .external_lex_state = 3},
  [1145] = {.lex_state = 50, .external_lex_state = 3},
  [1146] = {.lex_state = 50, .external_lex_state = 3},
  [1147] = {.lex_state = 50, .external_lex_state = 3},
  [1148] = {.lex_state = 50, .external_lex_state = 3},
  [1149] = {.lex_state = 50, .external_lex_state = 3},
  [1150] = {.lex_state = 50, .external_lex_state = 3},
  [1151] = {.lex_state = 50, .external_lex_state = 3},
  [1152] = {.lex_state = 50, .external_lex_state = 3},
  [1153] = {.lex_state = 50, .external_lex_state = 3},
  [1154] = {.lex_state = 50, .external_lex_state = 3},
  [1155] = {.lex_state = 50, .external_lex_state = 3},
  [1156] = {.lex_state = 50, .external_lex_state = 3},
  [1157] = {.lex_state = 50, .external_lex_state = 3},
  [1158] = {.lex_state = 50, .external_lex_state = 3},
  [1159] = {.lex_state = 50, .external_lex_state = 3},
  [1160] = {.lex_state = 50, .external_lex_state = 3},
  [1161] = {.lex_state = 50, .external_lex_state = 3},
  [1162] = {.lex_state = 50, .external_lex_state = 3},
  [1163] = {.lex_state = 50, .external_lex_state = 3},
  [1164] = {.lex_state = 50, .external_lex_state = 3},
  [1165] = {.lex_state = 50, .external_lex_state = 3},
  [1166] = {.lex_state = 50, .external_lex_state = 3},
  [1167] = {.lex_state = 50, .external_lex_state = 3},
  [1168] = {.lex_state = 50, .external_lex_state = 3},
  [1169] = {.lex_state = 50, .external_lex_state = 3},
  [1170] = {.lex_state = 50, .external_lex_state = 3},
  [1171] = {.lex_state = 50, .external_lex_state = 3},
  [1172] = {.lex_state = 50, .external_lex_state = 3},
  [1173] = {.lex_state = 50, .external_lex_state = 3},
  [1174] = {.lex_state = 50, .external_lex_state = 3},
  [1175] = {.lex_state = 50, .external_lex_state = 3},
  [1176] = {.lex_state = 50, .external_lex_state = 3},
  [1177] = {.lex_state = 50, .external_lex_state = 3},
  [1178] = {.lex_state = 50, .external_lex_state = 3},
  [1179] = {.lex_state = 50, .external_lex_state = 3},
  [1180] = {.lex_state = 50, .external_lex_state = 3},
  [1181] = {.lex_state = 50, .external_lex_state = 3},
  [1182] = {.lex_state = 50, .external_lex_state = 3},
  [1183] = {.lex_state = 50, .external_lex_state = 3},
  [1184] = {.lex_state = 50, .external_lex_state = 3},
  [1185] = {.lex_state = 50, .external_lex_state = 3},
  [1186] = {.lex_state = 50, .external_lex_state = 3},
  [1187] = {.lex_state = 50, .external_lex_state = 3},
  [1188] = {.lex_state = 50, .external_lex_state = 3},
  [1189] = {.lex_state = 50, .external_lex_state = 3},
  [1190] = {.lex_state = 50, .external_lex_state = 3},
  [1191] = {.lex_state = 50, .external_lex_state = 3},
  [1192] = {.lex_state = 50, .external_lex_state = 3},
  [1193] = {.lex_state = 50, .external_lex_state = 3},
  [1194] = {.lex_state = 50, .external_lex_state = 3},
  [1195] = {.lex_state = 50, .external_lex_state = 3},
  [1196] = {.lex_state = 50, .external_lex_state = 3},
  [1197] = {.lex_state = 50, .external_lex_state = 3},
  [1198] = {.lex_state = 50, .external_lex_state = 3},
  [1199] = {.lex_state = 50, .external_lex_state = 3},
  [1200] = {.lex_state = 50, .external_lex_state = 3},
  [1201] = {.lex_state = 50, .external_lex_state = 3},
  [1202] = {.lex_state = 50, .external_lex_state = 3},
  [1203] = {.lex_state = 50, .external_lex_state = 3},
  [1204] = {.lex_state = 50, .external_lex_state = 3},
  [1205] = {.lex_state = 50, .external_lex_state = 3},
  [1206] = {.lex_state = 50, .external_lex_state = 3},
  [1207] = {.lex_state = 50, .external_lex_state = 3},
  [1208] = {.lex_state = 50, .external_lex_state = 3},
  [1209] = {.lex_state = 50, .external_lex_state = 3},
  [1210] = {.lex_state = 50, .external_lex_state = 17},
  [1211] = {.lex_state = 50, .external_lex_state = 3},
  [1212] = {.lex_state = 50, .external_lex_state = 3},
  [1213] = {.lex_state = 50, .external_lex_state = 3},
  [1214] = {.lex_state = 50, .external_lex_state = 3},
  [1215] = {.lex_state = 50, .external_lex_state = 3},
  [1216] = {.lex_state = 50, .external_lex_state = 3},
  [1217] = {.lex_state = 50, .external_lex_state = 3},
  [1218] = {.lex_state = 50, .external_lex_state = 3},
  [1219] = {.lex_state = 50, .external_lex_state = 3},
  [1220] = {.lex_state = 50, .external_lex_state = 3},
  [1221] = {.lex_state = 50, .external_lex_state = 17},
  [1222] = {.lex_state = 50, .external_lex_state = 3},
  [1223] = {.lex_state = 50, .external_lex_state = 3},
  [1224] = {.lex_state = 50, .external_lex_state = 3},
  [1225] = {.lex_state = 50, .external_lex_state = 3},
  [1226] = {.lex_state = 50, .external_lex_state = 3},
  [1227] = {.lex_state = 50, .external_lex_state = 3},
  [1228] = {.lex_state = 50, .external_lex_state = 3},
  [1229] = {.lex_state = 50, .external_lex_state = 3},
  [1230] = {.lex_state = 50, .external_lex_state = 3},
  [1231] = {.lex_state = 50, .external_lex_state = 3},
  [1232] = {.lex_state = 50, .external_lex_state = 3},
  [1233] = {.lex_state = 50, .external_lex_state = 3},
  [1234] = {.lex_state = 50, .external_lex_state = 3},
  [1235] = {.lex_state = 50, .external_lex_state = 3},
  [1236] = {.lex_state = 50, .external_lex_state = 3},
  [1237] = {.lex_state = 50, .external_lex_state = 3},
  [1238] = {.lex_state = 50, .external_lex_state = 3},
  [1239] = {.lex_state = 50, .external_lex_state = 3},
  [1240] = {.lex_state = 50, .external_lex_state = 3},
  [1241] = {.lex_state = 50, .external_lex_state = 3},
  [1242] = {.lex_state = 50, .external_lex_state = 3},
  [1243] = {.lex_state = 50, .external_lex_state = 3},
  [1244] = {.lex_state = 50, .external_lex_state = 3},
  [1245] = {.lex_state = 50, .external_lex_state = 3},
  [1246] = {.lex_state = 50, .external_lex_state = 3},
  [1247] = {.lex_state = 50, .external_lex_state = 3},
  [1248] = {.lex_state = 50, .external_lex_state = 3},
  [1249] = {.lex_state = 50, .external_lex_state = 3},
  [1250] = {.lex_state = 50, .external_lex_state = 3},
  [1251] = {.lex_state = 50, .external_lex_state = 3},
  [1252] = {.lex_state = 50, .external_lex_state = 3},
  [1253] = {.lex_state = 50, .external_lex_state = 3},
  [1254] = {.lex_state = 50, .external_lex_state = 3},
  [1255] = {.lex_state = 50, .external_lex_state = 3},
  [1256] = {.lex_state = 50, .external_lex_state = 3},
  [1257] = {.lex_state = 50, .external_lex_state = 3},
  [1258] = {.lex_state = 50, .external_lex_state = 3},
  [1259] = {.lex_state = 50, .external_lex_state = 3},
  [1260] = {.lex_state = 50, .external_lex_state = 3},
  [1261] = {.lex_state = 50, .external_lex_state = 3},
  [1262] = {.lex_state = 50, .external_lex_state = 3},
  [1263] = {.lex_state = 50, .external_lex_state = 3},
  [1264] = {.lex_state = 50, .external_lex_state = 3},
  [1265] = {.lex_state = 50, .external_lex_state = 3},
  [1266] = {.lex_state = 50, .external_lex_state = 3},
  [1267] = {.lex_state = 50, .external_lex_state = 3},
  [1268] = {.lex_state = 50, .external_lex_state = 3},
  [1269] = {.lex_state = 50, .external_lex_state = 3},
  [1270] = {.lex_state = 50, .external_lex_state = 3},
  [1271] = {.lex_state = 50, .external_lex_state = 3},
  [1272] = {.lex_state = 50, .external_lex_state = 3},
  [1273] = {.lex_state = 50, .external_lex_state = 3},
  [1274] = {.lex_state = 50, .external_lex_state = 3},
  [1275] = {.lex_state = 50, .external_lex_state = 3},
  [1276] = {.lex_state = 50, .external_lex_state = 3},
  [1277] = {.lex_state = 50, .external_lex_state = 3},
  [1278] = {.lex_state = 50, .external_lex_state = 3},
  [1279] = {.lex_state = 50, .external_lex_state = 3},
  [1280] = {.lex_state = 50, .external_lex_state = 3},
  [1281] = {.lex_state = 50, .external_lex_state = 3},
  [1282] = {.lex_state = 50, .external_lex_state = 3},
  [1283] = {.lex_state = 50, .external_lex_state = 3},
  [1284] = {.lex_state = 50, .external_lex_state = 3},
  [1285] = {.lex_state = 50, .external_lex_state = 3},
  [1286] = {.lex_state = 50, .external_lex_state = 3},
  [1287] = {.lex_state = 50, .external_lex_state = 3},
  [1288] = {.lex_state = 50, .external_lex_state = 3},
  [1289] = {.lex_state = 50, .external_lex_state = 3},
  [1290] = {.lex_state = 50, .external_lex_state = 3},
  [1291] = {.lex_state = 50, .external_lex_state = 3},
  [1292] = {.lex_state = 50, .external_lex_state = 3},
  [1293] = {.lex_state = 50, .external_lex_state = 3},
  [1294] = {.lex_state = 50, .external_lex_state = 3},
  [1295] = {.lex_state = 50, .external_lex_state = 3},
  [1296] = {.lex_state = 50, .external_lex_state = 3},
  [1297] = {.lex_state = 50, .external_lex_state = 3},
  [1298] = {.lex_state = 50, .external_lex_state = 3},
  [1299] = {.lex_state = 50, .external_lex_state = 3},
  [1300] = {.lex_state = 50, .external_lex_state = 3},
  [1301] = {.lex_state = 50, .external_lex_state = 3},
  [1302] = {.lex_state = 50, .external_lex_state = 3},
  [1303] = {.lex_state = 50, .external_lex_state = 3},
  [1304] = {.lex_state = 50, .external_lex_state = 3},
  [1305] = {.lex_state = 50, .external_lex_state = 3},
  [1306] = {.lex_state = 50, .external_lex_state = 3},
  [1307] = {.lex_state = 50, .external_lex_state = 3},
  [1308] = {.lex_state = 50, .external_lex_state = 3},
  [1309] = {.lex_state = 50, .external_lex_state = 3},
  [1310] = {.lex_state = 50, .external_lex_state = 3},
  [1311] = {.lex_state = 50, .external_lex_state = 3},
  [1312] = {.lex_state = 50, .external_lex_state = 3},
  [1313] = {.lex_state = 50, .external_lex_state = 3},
  [1314] = {.lex_state = 50, .external_lex_state = 3},
  [1315] = {.lex_state = 50, .external_lex_state = 3},
  [1316] = {.lex_state = 50, .external_lex_state = 16},
  [1317] = {.lex_state = 50, .external_lex_state = 3},
  [1318] = {.lex_state = 50, .external_lex_state = 3},
  [1319] = {.lex_state = 50, .external_lex_state = 3},
  [1320] = {.lex_state = 50, .external_lex_state = 3},
  [1321] = {.lex_state = 50, .external_lex_state = 3},
  [1322] = {.lex_state = 50, .external_lex_state = 3},
  [1323] = {.lex_state = 50, .external_lex_state = 3},
  [1324] = {.lex_state = 50, .external_lex_state = 3},
  [1325] = {.lex_state = 50, .external_lex_state = 3},
  [1326] = {.lex_state = 50, .external_lex_state = 3},
  [1327] = {.lex_state = 50, .external_lex_state = 3},
  [1328] = {.lex_state = 50, .external_lex_state = 3},
  [1329] = {.lex_state = 50, .external_lex_state = 3},
  [1330] = {.lex_state = 50, .external_lex_state = 3},
  [1331] = {.lex_state = 50, .external_lex_state = 3},
  [1332] = {.lex_state = 50, .external_lex_state = 3},
  [1333] = {.lex_state = 50, .external_lex_state = 3},
  [1334] = {.lex_state = 50, .external_lex_state = 3},
  [1335] = {.lex_state = 50, .external_lex_state = 3},
  [1336] = {.lex_state = 50, .external_lex_state = 3},
  [1337] = {.lex_state = 50, .external_lex_state = 3},
  [1338] = {.lex_state = 50, .external_lex_state = 3},
  [1339] = {.lex_state = 50, .external_lex_state = 3},
  [1340] = {.lex_state = 50, .external_lex_state = 3},
  [1341] = {.lex_state = 50, .external_lex_state = 3},
  [1342] = {.lex_state = 50, .external_lex_state = 3},
  [1343] = {.lex_state = 50, .external_lex_state = 3},
  [1344] = {.lex_state = 50, .external_lex_state = 3},
  [1345] = {.lex_state = 50, .external_lex_state = 3},
  [1346] = {.lex_state = 50, .external_lex_state = 3},
  [1347] = {.lex_state = 50, .external_lex_state = 3},
  [1348] = {.lex_state = 50, .external_lex_state = 3},
  [1349] = {.lex_state = 50, .external_lex_state = 3},
  [1350] = {.lex_state = 50, .external_lex_state = 3},
  [1351] = {.lex_state = 50, .external_lex_state = 3},
  [1352] = {.lex_state = 50, .external_lex_state = 3},
  [1353] = {.lex_state = 50, .external_lex_state = 3},
  [1354] = {.lex_state = 50, .external_lex_state = 3},
  [1355] = {.lex_state = 50, .external_lex_state = 3},
  [1356] = {.lex_state = 50, .external_lex_state = 3},
  [1357] = {.lex_state = 50, .external_lex_state = 3},
  [1358] = {.lex_state = 50, .external_lex_state = 3},
  [1359] = {.lex_state = 50, .external_lex_state = 3},
  [1360] = {.lex_state = 50, .external_lex_state = 3},
  [1361] = {.lex_state = 50, .external_lex_state = 3},
  [1362] = {.lex_state = 50, .external_lex_state = 3},
  [1363] = {.lex_state = 50, .external_lex_state = 3},
  [1364] = {.lex_state = 50, .external_lex_state = 3},
  [1365] = {.lex_state = 50, .external_lex_state = 3},
  [1366] = {.lex_state = 50, .external_lex_state = 3},
  [1367] = {.lex_state = 50, .external_lex_state = 3},
  [1368] = {.lex_state = 50, .external_lex_state = 3},
  [1369] = {.lex_state = 50, .external_lex_state = 16},
  [1370] = {.lex_state = 50, .external_lex_state = 3},
  [1371] = {.lex_state = 50, .external_lex_state = 3},
  [1372] = {.lex_state = 50, .external_lex_state = 3},
  [1373] = {.lex_state = 50, .external_lex_state = 3},
  [1374] = {.lex_state = 50, .external_lex_state = 3},
  [1375] = {.lex_state = 50, .external_lex_state = 3},
  [1376] = {.lex_state = 50, .external_lex_state = 3},
  [1377] = {.lex_state = 50, .external_lex_state = 3},
  [1378] = {.lex_state = 50, .external_lex_state = 3},
  [1379] = {.lex_state = 50, .external_lex_state = 3},
  [1380] = {.lex_state = 50, .external_lex_state = 3},
  [1381] = {.lex_state = 50, .external_lex_state = 3},
  [1382] = {.lex_state = 50, .external_lex_state = 3},
  [1383] = {.lex_state = 50, .external_lex_state = 3},
  [1384] = {.lex_state = 50, .external_lex_state = 3},
  [1385] = {.lex_state = 50, .external_lex_state = 3},
  [1386] = {.lex_state = 50, .external_lex_state = 3},
  [1387] = {.lex_state = 50, .external_lex_state = 3},
  [1388] = {.lex_state = 50, .external_lex_state = 3},
  [1389] = {.lex_state = 50, .external_lex_state = 3},
  [1390] = {.lex_state = 50, .external_lex_state = 3},
  [1391] = {.lex_state = 2, .external_lex_state = 2},
  [1392] = {.lex_state = 50, .external_lex_state = 3},
  [1393] = {.lex_state = 50, .external_lex_state = 3},
  [1394] = {.lex_state = 50, .external_lex_state = 3},
  [1395] = {.lex_state = 50, .external_lex_state = 3},
  [1396] = {.lex_state = 50, .external_lex_state = 3},
  [1397] = {.lex_state = 50, .external_lex_state = 3},
  [1398] = {.lex_state = 50, .external_lex_state = 3},
  [1399] = {.lex_state = 50, .external_lex_state = 3},
  [1400] = {.lex_state = 50, .external_lex_state = 3},
  [1401] = {.lex_state = 50, .external_lex_state = 3},
  [1402] = {.lex_state = 50, .external_lex_state = 3},
  [1403] = {.lex_state = 50, .external_lex_state = 3},
  [1404] = {.lex_state = 50, .external_lex_state = 3},
  [1405] = {.lex_state = 50, .external_lex_state = 3},
  [1406] = {.lex_state = 50, .external_lex_state = 3},
  [1407] = {.lex_state = 50, .external_lex_state = 3},
  [1408] = {.lex_state = 50, .external_lex_state = 3},
  [1409] = {.lex_state = 50, .external_lex_state = 3},
  [1410] = {.lex_state = 50, .external_lex_state = 3},
  [1411] = {.lex_state = 50, .external_lex_state = 3},
  [1412] = {.lex_state = 50, .external_lex_state = 3},
  [1413] = {.lex_state = 50, .external_lex_state = 3},
  [1414] = {.lex_state = 50, .external_lex_state = 3},
  [1415] = {.lex_state = 50, .external_lex_state = 3},
  [1416] = {.lex_state = 50, .external_lex_state = 3},
  [1417] = {.lex_state = 50, .external_lex_state = 3},
  [1418] = {.lex_state = 50, .external_lex_state = 3},
  [1419] = {.lex_state = 50, .external_lex_state = 3},
  [1420] = {.lex_state = 50, .external_lex_state = 3},
  [1421] = {.lex_state = 50, .external_lex_state = 3},
  [1422] = {.lex_state = 50, .external_lex_state = 3},
  [1423] = {.lex_state = 50, .external_lex_state = 3},
  [1424] = {.lex_state = 50, .external_lex_state = 3},
  [1425] = {.lex_state = 50, .external_lex_state = 3},
  [1426] = {.lex_state = 50, .external_lex_state = 3},
  [1427] = {.lex_state = 50, .external_lex_state = 3},
  [1428] = {.lex_state = 50, .external_lex_state = 3},
  [1429] = {.lex_state = 50, .external_lex_state = 3},
  [1430] = {.lex_state = 50, .external_lex_state = 3},
  [1431] = {.lex_state = 50, .external_lex_state = 3},
  [1432] = {.lex_state = 50, .external_lex_state = 3},
  [1433] = {.lex_state = 50, .external_lex_state = 3},
  [1434] = {.lex_state = 50, .external_lex_state = 3},
  [1435] = {.lex_state = 50, .external_lex_state = 3},
  [1436] = {.lex_state = 50, .external_lex_state = 3},
  [1437] = {.lex_state = 50, .external_lex_state = 3},
  [1438] = {.lex_state = 50, .external_lex_state = 3},
  [1439] = {.lex_state = 50, .external_lex_state = 3},
  [1440] = {.lex_state = 50, .external_lex_state = 3},
  [1441] = {.lex_state = 50, .external_lex_state = 3},
  [1442] = {.lex_state = 50, .external_lex_state = 3},
  [1443] = {.lex_state = 50, .external_lex_state = 3},
  [1444] = {.lex_state = 50, .external_lex_state = 3},
  [1445] = {.lex_state = 50, .external_lex_state = 3},
  [1446] = {.lex_state = 50, .external_lex_state = 3},
  [1447] = {.lex_state = 50, .external_lex_state = 3},
  [1448] = {.lex_state = 50, .external_lex_state = 3},
  [1449] = {.lex_state = 50, .external_lex_state = 3},
  [1450] = {.lex_state = 50, .external_lex_state = 3},
  [1451] = {.lex_state = 50, .external_lex_state = 3},
  [1452] = {.lex_state = 50, .external_lex_state = 3},
  [1453] = {.lex_state = 50, .external_lex_state = 3},
  [1454] = {.lex_state = 50, .external_lex_state = 3},
  [1455] = {.lex_state = 50, .external_lex_state = 3},
  [1456] = {.lex_state = 50, .external_lex_state = 3},
  [1457] = {.lex_state = 50, .external_lex_state = 3},
  [1458] = {.lex_state = 50, .external_lex_state = 3},
  [1459] = {.lex_state = 50, .external_lex_state = 3},
  [1460] = {.lex_state = 50, .external_lex_state = 3},
  [1461] = {.lex_state = 50, .external_lex_state = 3},
  [1462] = {.lex_state = 50, .external_lex_state = 3},
  [1463] = {.lex_state = 50, .external_lex_state = 3},
  [1464] = {.lex_state = 50, .external_lex_state = 3},
  [1465] = {.lex_state = 50, .external_lex_state = 3},
  [1466] = {.lex_state = 50, .external_lex_state = 3},
  [1467] = {.lex_state = 50, .external_lex_state = 3},
  [1468] = {.lex_state = 50, .external_lex_state = 3},
  [1469] = {.lex_state = 50, .external_lex_state = 3},
  [1470] = {.lex_state = 50, .external_lex_state = 3},
  [1471] = {.lex_state = 50, .external_lex_state = 3},
  [1472] = {.lex_state = 50, .external_lex_state = 3},
  [1473] = {.lex_state = 50, .external_lex_state = 3},
  [1474] = {.lex_state = 50, .external_lex_state = 3},
  [1475] = {.lex_state = 50, .external_lex_state = 3},
  [1476] = {.lex_state = 50, .external_lex_state = 3},
  [1477] = {.lex_state = 50, .external_lex_state = 3},
  [1478] = {.lex_state = 50, .external_lex_state = 3},
  [1479] = {.lex_state = 50, .external_lex_state = 3},
  [1480] = {.lex_state = 50, .external_lex_state = 3},
  [1481] = {.lex_state = 50, .external_lex_state = 3},
  [1482] = {.lex_state = 50, .external_lex_state = 3},
  [1483] = {.lex_state = 50, .external_lex_state = 3},
  [1484] = {.lex_state = 50, .external_lex_state = 3},
  [1485] = {.lex_state = 50, .external_lex_state = 3},
  [1486] = {.lex_state = 50, .external_lex_state = 3},
  [1487] = {.lex_state = 50, .external_lex_state = 3},
  [1488] = {.lex_state = 50, .external_lex_state = 3},
  [1489] = {.lex_state = 50, .external_lex_state = 3},
  [1490] = {.lex_state = 50, .external_lex_state = 3},
  [1491] = {.lex_state = 50, .external_lex_state = 3},
  [1492] = {.lex_state = 50, .external_lex_state = 3},
  [1493] = {.lex_state = 50, .external_lex_state = 3},
  [1494] = {.lex_state = 50, .external_lex_state = 3},
  [1495] = {.lex_state = 50, .external_lex_state = 3},
  [1496] = {.lex_state = 50, .external_lex_state = 3},
  [1497] = {.lex_state = 50, .external_lex_state = 3},
  [1498] = {.lex_state = 50, .external_lex_state = 3},
  [1499] = {.lex_state = 50, .external_lex_state = 3},
  [1500] = {.lex_state = 50, .external_lex_state = 3},
  [1501] = {.lex_state = 50, .external_lex_state = 3},
  [1502] = {.lex_state = 50, .external_lex_state = 3},
  [1503] = {.lex_state = 50, .external_lex_state = 3},
  [1504] = {.lex_state = 50, .external_lex_state = 3},
  [1505] = {.lex_state = 50, .external_lex_state = 3},
  [1506] = {.lex_state = 50, .external_lex_state = 3},
  [1507] = {.lex_state = 50, .external_lex_state = 3},
  [1508] = {.lex_state = 50, .external_lex_state = 3},
  [1509] = {.lex_state = 50, .external_lex_state = 3},
  [1510] = {.lex_state = 50, .external_lex_state = 3},
  [1511] = {.lex_state = 50, .external_lex_state = 3},
  [1512] = {.lex_state = 50, .external_lex_state = 3},
  [1513] = {.lex_state = 50, .external_lex_state = 3},
  [1514] = {.lex_state = 50, .external_lex_state = 3},
  [1515] = {.lex_state = 50, .external_lex_state = 3},
  [1516] = {.lex_state = 50, .external_lex_state = 3},
  [1517] = {.lex_state = 50, .external_lex_state = 3},
  [1518] = {.lex_state = 50, .external_lex_state = 3},
  [1519] = {.lex_state = 50, .external_lex_state = 3},
  [1520] = {.lex_state = 50, .external_lex_state = 3},
  [1521] = {.lex_state = 50, .external_lex_state = 3},
  [1522] = {.lex_state = 50, .external_lex_state = 3},
  [1523] = {.lex_state = 50, .external_lex_state = 3},
  [1524] = {.lex_state = 50, .external_lex_state = 3},
  [1525] = {.lex_state = 50, .external_lex_state = 3},
  [1526] = {.lex_state = 50, .external_lex_state = 3},
  [1527] = {.lex_state = 50, .external_lex_state = 3},
  [1528] = {.lex_state = 50, .external_lex_state = 3},
  [1529] = {.lex_state = 50, .external_lex_state = 3},
  [1530] = {.lex_state = 50, .external_lex_state = 3},
  [1531] = {.lex_state = 50, .external_lex_state = 3},
  [1532] = {.lex_state = 50, .external_lex_state = 3},
  [1533] = {.lex_state = 50, .external_lex_state = 3},
  [1534] = {.lex_state = 50, .external_lex_state = 3},
  [1535] = {.lex_state = 50, .external_lex_state = 3},
  [1536] = {.lex_state = 50, .external_lex_state = 3},
  [1537] = {.lex_state = 50, .external_lex_state = 3},
  [1538] = {.lex_state = 50, .external_lex_state = 3},
  [1539] = {.lex_state = 50, .external_lex_state = 3},
  [1540] = {.lex_state = 50, .external_lex_state = 3},
  [1541] = {.lex_state = 50, .external_lex_state = 3},
  [1542] = {.lex_state = 50, .external_lex_state = 3},
  [1543] = {.lex_state = 50, .external_lex_state = 3},
  [1544] = {.lex_state = 50, .external_lex_state = 3},
  [1545] = {.lex_state = 50, .external_lex_state = 3},
  [1546] = {.lex_state = 50, .external_lex_state = 3},
  [1547] = {.lex_state = 50, .external_lex_state = 3},
  [1548] = {.lex_state = 50, .external_lex_state = 3},
  [1549] = {.lex_state = 50, .external_lex_state = 3},
  [1550] = {.lex_state = 50, .external_lex_state = 3},
  [1551] = {.lex_state = 50, .external_lex_state = 3},
  [1552] = {.lex_state = 50, .external_lex_state = 3},
  [1553] = {.lex_state = 50, .external_lex_state = 3},
  [1554] = {.lex_state = 50, .external_lex_state = 3},
  [1555] = {.lex_state = 50, .external_lex_state = 3},
  [1556] = {.lex_state = 50, .external_lex_state = 3},
  [1557] = {.lex_state = 50, .external_lex_state = 3},
  [1558] = {.lex_state = 50, .external_lex_state = 3},
  [1559] = {.lex_state = 50, .external_lex_state = 3},
  [1560] = {.lex_state = 50, .external_lex_state = 3},
  [1561] = {.lex_state = 50, .external_lex_state = 3},
  [1562] = {.lex_state = 50, .external_lex_state = 3},
  [1563] = {.lex_state = 50, .external_lex_state = 3},
  [1564] = {.lex_state = 50, .external_lex_state = 3},
  [1565] = {.lex_state = 50, .external_lex_state = 3},
  [1566] = {.lex_state = 50, .external_lex_state = 3},
  [1567] = {.lex_state = 50, .external_lex_state = 3},
  [1568] = {.lex_state = 50, .external_lex_state = 3},
  [1569] = {.lex_state = 50, .external_lex_state = 3},
  [1570] = {.lex_state = 50, .external_lex_state = 3},
  [1571] = {.lex_state = 50, .external_lex_state = 3},
  [1572] = {.lex_state = 50, .external_lex_state = 3},
  [1573] = {.lex_state = 50, .external_lex_state = 3},
  [1574] = {.lex_state = 50, .external_lex_state = 3},
  [1575] = {.lex_state = 50, .external_lex_state = 3},
  [1576] = {.lex_state = 50, .external_lex_state = 3},
  [1577] = {.lex_state = 50, .external_lex_state = 3},
  [1578] = {.lex_state = 50, .external_lex_state = 3},
  [1579] = {.lex_state = 50, .external_lex_state = 3},
  [1580] = {.lex_state = 50, .external_lex_state = 3},
  [1581] = {.lex_state = 50, .external_lex_state = 3},
  [1582] = {.lex_state = 50, .external_lex_state = 3},
  [1583] = {.lex_state = 50, .external_lex_state = 3},
  [1584] = {.lex_state = 50, .external_lex_state = 3},
  [1585] = {.lex_state = 50, .external_lex_state = 3},
  [1586] = {.lex_state = 50, .external_lex_state = 3},
  [1587] = {.lex_state = 50, .external_lex_state = 3},
  [1588] = {.lex_state = 50, .external_lex_state = 3},
  [1589] = {.lex_state = 50, .external_lex_state = 3},
  [1590] = {.lex_state = 50, .external_lex_state = 3},
  [1591] = {.lex_state = 50, .external_lex_state = 3},
  [1592] = {.lex_state = 50, .external_lex_state = 3},
  [1593] = {.lex_state = 50, .external_lex_state = 3},
  [1594] = {.lex_state = 50, .external_lex_state = 3},
  [1595] = {.lex_state = 50, .external_lex_state = 3},
  [1596] = {.lex_state = 50, .external_lex_state = 3},
  [1597] = {.lex_state = 50, .external_lex_state = 3},
  [1598] = {.lex_state = 50, .external_lex_state = 3},
  [1599] = {.lex_state = 50, .external_lex_state = 3},
  [1600] = {.lex_state = 50, .external_lex_state = 3},
  [1601] = {.lex_state = 50, .external_lex_state = 3},
  [1602] = {.lex_state = 50, .external_lex_state = 3},
  [1603] = {.lex_state = 50, .external_lex_state = 3},
  [1604] = {.lex_state = 50, .external_lex_state = 3},
  [1605] = {.lex_state = 50, .external_lex_state = 3},
  [1606] = {.lex_state = 50, .external_lex_state = 3},
  [1607] = {.lex_state = 50, .external_lex_state = 3},
  [1608] = {.lex_state = 50, .external_lex_state = 3},
  [1609] = {.lex_state = 50, .external_lex_state = 3},
  [1610] = {.lex_state = 50, .external_lex_state = 3},
  [1611] = {.lex_state = 50, .external_lex_state = 3},
  [1612] = {.lex_state = 50, .external_lex_state = 3},
  [1613] = {.lex_state = 50, .external_lex_state = 3},
  [1614] = {.lex_state = 50, .external_lex_state = 3},
  [1615] = {.lex_state = 50, .external_lex_state = 3},
  [1616] = {.lex_state = 50, .external_lex_state = 3},
  [1617] = {.lex_state = 50, .external_lex_state = 3},
  [1618] = {.lex_state = 50, .external_lex_state = 3},
  [1619] = {.lex_state = 50, .external_lex_state = 3},
  [1620] = {.lex_state = 50, .external_lex_state = 3},
  [1621] = {.lex_state = 50, .external_lex_state = 3},
  [1622] = {.lex_state = 50, .external_lex_state = 3},
  [1623] = {.lex_state = 50, .external_lex_state = 3},
  [1624] = {.lex_state = 50, .external_lex_state = 3},
  [1625] = {.lex_state = 50, .external_lex_state = 3},
  [1626] = {.lex_state = 50, .external_lex_state = 3},
  [1627] = {.lex_state = 50, .external_lex_state = 3},
  [1628] = {.lex_state = 50, .external_lex_state = 3},
  [1629] = {.lex_state = 50, .external_lex_state = 3},
  [1630] = {.lex_state = 50, .external_lex_state = 3},
  [1631] = {.lex_state = 50, .external_lex_state = 3},
  [1632] = {.lex_state = 50, .external_lex_state = 3},
  [1633] = {.lex_state = 50, .external_lex_state = 3},
  [1634] = {.lex_state = 50, .external_lex_state = 3},
  [1635] = {.lex_state = 50, .external_lex_state = 3},
  [1636] = {.lex_state = 50, .external_lex_state = 3},
  [1637] = {.lex_state = 50, .external_lex_state = 3},
  [1638] = {.lex_state = 50, .external_lex_state = 3},
  [1639] = {.lex_state = 50, .external_lex_state = 3},
  [1640] = {.lex_state = 50, .external_lex_state = 3},
  [1641] = {.lex_state = 50, .external_lex_state = 3},
  [1642] = {.lex_state = 50, .external_lex_state = 3},
  [1643] = {.lex_state = 50, .external_lex_state = 3},
  [1644] = {.lex_state = 50, .external_lex_state = 3},
  [1645] = {.lex_state = 50, .external_lex_state = 3},
  [1646] = {.lex_state = 50, .external_lex_state = 3},
  [1647] = {.lex_state = 50, .external_lex_state = 3},
  [1648] = {.lex_state = 50, .external_lex_state = 3},
  [1649] = {.lex_state = 50, .external_lex_state = 3},
  [1650] = {.lex_state = 50, .external_lex_state = 3},
  [1651] = {.lex_state = 50, .external_lex_state = 2},
  [1652] = {.lex_state = 50, .external_lex_state = 2},
  [1653] = {.lex_state = 50, .external_lex_state = 2},
  [1654] = {.lex_state = 50, .external_lex_state = 2},
  [1655] = {.lex_state = 50, .external_lex_state = 2},
  [1656] = {.lex_state = 50, .external_lex_state = 2},
  [1657] = {.lex_state = 50, .external_lex_state = 2},
  [1658] = {.lex_state = 50, .external_lex_state = 2},
  [1659] = {.lex_state = 50, .external_lex_state = 2},
  [1660] = {.lex_state = 50, .external_lex_state = 2},
  [1661] = {.lex_state = 50, .external_lex_state = 2},
  [1662] = {.lex_state = 50, .external_lex_state = 2},
  [1663] = {.lex_state = 50, .external_lex_state = 2},
  [1664] = {.lex_state = 50, .external_lex_state = 2},
  [1665] = {.lex_state = 50, .external_lex_state = 2},
  [1666] = {.lex_state = 50, .external_lex_state = 2},
  [1667] = {.lex_state = 50, .external_lex_state = 2},
  [1668] = {.lex_state = 50, .external_lex_state = 2},
  [1669] = {.lex_state = 50, .external_lex_state = 2},
  [1670] = {.lex_state = 50, .external_lex_state = 2},
  [1671] = {.lex_state = 50, .external_lex_state = 2},
  [1672] = {.lex_state = 50, .external_lex_state = 2},
  [1673] = {.lex_state = 50, .external_lex_state = 2},
  [1674] = {.lex_state = 50, .external_lex_state = 2},
  [1675] = {.lex_state = 50, .external_lex_state = 2},
  [1676] = {.lex_state = 50, .external_lex_state = 2},
  [1677] = {.lex_state = 50, .external_lex_state = 2},
  [1678] = {.lex_state = 50, .external_lex_state = 2},
  [1679] = {.lex_state = 50, .external_lex_state = 2},
  [1680] = {.lex_state = 50, .external_lex_state = 2},
  [1681] = {.lex_state = 50, .external_lex_state = 2},
  [1682] = {.lex_state = 50, .external_lex_state = 2},
  [1683] = {.lex_state = 50, .external_lex_state = 2},
  [1684] = {.lex_state = 50, .external_lex_state = 2},
  [1685] = {.lex_state = 50, .external_lex_state = 2},
  [1686] = {.lex_state = 50, .external_lex_state = 2},
  [1687] = {.lex_state = 50, .external_lex_state = 2},
  [1688] = {.lex_state = 50, .external_lex_state = 2},
  [1689] = {.lex_state = 50, .external_lex_state = 2},
  [1690] = {.lex_state = 50, .external_lex_state = 2},
  [1691] = {.lex_state = 50, .external_lex_state = 2},
  [1692] = {.lex_state = 50, .external_lex_state = 2},
  [1693] = {.lex_state = 50, .external_lex_state = 2},
  [1694] = {.lex_state = 50, .external_lex_state = 2},
  [1695] = {.lex_state = 50, .external_lex_state = 2},
  [1696] = {.lex_state = 50, .external_lex_state = 2},
  [1697] = {.lex_state = 50, .external_lex_state = 2},
  [1698] = {.lex_state = 50, .external_lex_state = 2},
  [1699] = {.lex_state = 50, .external_lex_state = 2},
  [1700] = {.lex_state = 50, .external_lex_state = 2},
  [1701] = {.lex_state = 50, .external_lex_state = 2},
  [1702] = {.lex_state = 50, .external_lex_state = 2},
  [1703] = {.lex_state = 50, .external_lex_state = 2},
  [1704] = {.lex_state = 50, .external_lex_state = 2},
  [1705] = {.lex_state = 50, .external_lex_state = 2},
  [1706] = {.lex_state = 50, .external_lex_state = 2},
  [1707] = {.lex_state = 50, .external_lex_state = 2},
  [1708] = {.lex_state = 50, .external_lex_state = 2},
  [1709] = {.lex_state = 50, .external_lex_state = 2},
  [1710] = {.lex_state = 50, .external_lex_state = 2},
  [1711] = {.lex_state = 50, .external_lex_state = 2},
  [1712] = {.lex_state = 50, .external_lex_state = 2},
  [1713] = {.lex_state = 50, .external_lex_state = 2},
  [1714] = {.lex_state = 50, .external_lex_state = 2},
  [1715] = {.lex_state = 50, .external_lex_state = 2},
  [1716] = {.lex_state = 50, .external_lex_state = 2},
  [1717] = {.lex_state = 50, .external_lex_state = 2},
  [1718] = {.lex_state = 50, .external_lex_state = 2},
  [1719] = {.lex_state = 50, .external_lex_state = 2},
  [1720] = {.lex_state = 50, .external_lex_state = 2},
  [1721] = {.lex_state = 50, .external_lex_state = 21},
  [1722] = {.lex_state = 50, .external_lex_state = 2},
  [1723] = {.lex_state = 50, .external_lex_state = 2},
  [1724] = {.lex_state = 50, .external_lex_state = 2},
  [1725] = {.lex_state = 50, .external_lex_state = 2},
  [1726] = {.lex_state = 50, .external_lex_state = 2},
  [1727] = {.lex_state = 50, .external_lex_state = 2},
  [1728] = {.lex_state = 50, .external_lex_state = 2},
  [1729] = {.lex_state = 50, .external_lex_state = 2},
  [1730] = {.lex_state = 50, .external_lex_state = 2},
  [1731] = {.lex_state = 50, .external_lex_state = 2},
  [1732] = {.lex_state = 50, .external_lex_state = 2},
  [1733] = {.lex_state = 50, .external_lex_state = 2},
  [1734] = {.lex_state = 50, .external_lex_state = 2},
  [1735] = {.lex_state = 50, .external_lex_state = 2},
  [1736] = {.lex_state = 50, .external_lex_state = 2},
  [1737] = {.lex_state = 50, .external_lex_state = 2},
  [1738] = {.lex_state = 50, .external_lex_state = 2},
  [1739] = {.lex_state = 50, .external_lex_state = 2},
  [1740] = {.lex_state = 50, .external_lex_state = 2},
  [1741] = {.lex_state = 50, .external_lex_state = 2},
  [1742] = {.lex_state = 50, .external_lex_state = 2},
  [1743] = {.lex_state = 50, .external_lex_state = 2},
  [1744] = {.lex_state = 50, .external_lex_state = 2},
  [1745] = {.lex_state = 50, .external_lex_state = 2},
  [1746] = {.lex_state = 50, .external_lex_state = 2},
  [1747] = {.lex_state = 50, .external_lex_state = 2},
  [1748] = {.lex_state = 50, .external_lex_state = 2},
  [1749] = {.lex_state = 50, .external_lex_state = 2},
  [1750] = {.lex_state = 50, .external_lex_state = 2},
  [1751] = {.lex_state = 50, .external_lex_state = 2},
  [1752] = {.lex_state = 50, .external_lex_state = 2},
  [1753] = {.lex_state = 50, .external_lex_state = 2},
  [1754] = {.lex_state = 50, .external_lex_state = 2},
  [1755] = {.lex_state = 50, .external_lex_state = 2},
  [1756] = {.lex_state = 50, .external_lex_state = 2},
  [1757] = {.lex_state = 50, .external_lex_state = 2},
  [1758] = {.lex_state = 50, .external_lex_state = 21},
  [1759] = {.lex_state = 50, .external_lex_state = 2},
  [1760] = {.lex_state = 50, .external_lex_state = 2},
  [1761] = {.lex_state = 50, .external_lex_state = 2},
  [1762] = {.lex_state = 50, .external_lex_state = 2},
  [1763] = {.lex_state = 50, .external_lex_state = 2},
  [1764] = {.lex_state = 50, .external_lex_state = 2},
  [1765] = {.lex_state = 50, .external_lex_state = 2},
  [1766] = {.lex_state = 50, .external_lex_state = 2},
  [1767] = {.lex_state = 50, .external_lex_state = 2},
  [1768] = {.lex_state = 50, .external_lex_state = 2},
  [1769] = {.lex_state = 50, .external_lex_state = 2},
  [1770] = {.lex_state = 50, .external_lex_state = 2},
  [1771] = {.lex_state = 50, .external_lex_state = 2},
  [1772] = {.lex_state = 50, .external_lex_state = 2},
  [1773] = {.lex_state = 50, .external_lex_state = 2},
  [1774] = {.lex_state = 50, .external_lex_state = 2},
  [1775] = {.lex_state = 50, .external_lex_state = 2},
  [1776] = {.lex_state = 50, .external_lex_state = 2},
  [1777] = {.lex_state = 50, .external_lex_state = 2},
  [1778] = {.lex_state = 50, .external_lex_state = 2},
  [1779] = {.lex_state = 50, .external_lex_state = 2},
  [1780] = {.lex_state = 50, .external_lex_state = 2},
  [1781] = {.lex_state = 50, .external_lex_state = 2},
  [1782] = {.lex_state = 50, .external_lex_state = 2},
  [1783] = {.lex_state = 50, .external_lex_state = 2},
  [1784] = {.lex_state = 50, .external_lex_state = 2},
  [1785] = {.lex_state = 50, .external_lex_state = 2},
  [1786] = {.lex_state = 50, .external_lex_state = 2},
  [1787] = {.lex_state = 50, .external_lex_state = 2},
  [1788] = {.lex_state = 50, .external_lex_state = 2},
  [1789] = {.lex_state = 50, .external_lex_state = 2},
  [1790] = {.lex_state = 50, .external_lex_state = 2},
  [1791] = {.lex_state = 50, .external_lex_state = 2},
  [1792] = {.lex_state = 50, .external_lex_state = 2},
  [1793] = {.lex_state = 50, .external_lex_state = 2},
  [1794] = {.lex_state = 50, .external_lex_state = 2},
  [1795] = {.lex_state = 50, .external_lex_state = 2},
  [1796] = {.lex_state = 50, .external_lex_state = 2},
  [1797] = {.lex_state = 50, .external_lex_state = 2},
  [1798] = {.lex_state = 50, .external_lex_state = 2},
  [1799] = {.lex_state = 50, .external_lex_state = 2},
  [1800] = {.lex_state = 50, .external_lex_state = 2},
  [1801] = {.lex_state = 50, .external_lex_state = 2},
  [1802] = {.lex_state = 50, .external_lex_state = 2},
  [1803] = {.lex_state = 50, .external_lex_state = 2},
  [1804] = {.lex_state = 50, .external_lex_state = 2},
  [1805] = {.lex_state = 50, .external_lex_state = 2},
  [1806] = {.lex_state = 50, .external_lex_state = 2},
  [1807] = {.lex_state = 50, .external_lex_state = 2},
  [1808] = {.lex_state = 50, .external_lex_state = 2},
  [1809] = {.lex_state = 50, .external_lex_state = 2},
  [1810] = {.lex_state = 50, .external_lex_state = 2},
  [1811] = {.lex_state = 50, .external_lex_state = 2},
  [1812] = {.lex_state = 50, .external_lex_state = 2},
  [1813] = {.lex_state = 50, .external_lex_state = 2},
  [1814] = {.lex_state = 50, .external_lex_state = 2},
  [1815] = {.lex_state = 50, .external_lex_state = 2},
  [1816] = {.lex_state = 50, .external_lex_state = 2},
  [1817] = {.lex_state = 50, .external_lex_state = 2},
  [1818] = {.lex_state = 50, .external_lex_state = 2},
  [1819] = {.lex_state = 50, .external_lex_state = 2},
  [1820] = {.lex_state = 50, .external_lex_state = 2},
  [1821] = {.lex_state = 50, .external_lex_state = 2},
  [1822] = {.lex_state = 50, .external_lex_state = 2},
  [1823] = {.lex_state = 50, .external_lex_state = 2},
  [1824] = {.lex_state = 50, .external_lex_state = 2},
  [1825] = {.lex_state = 50, .external_lex_state = 2},
  [1826] = {.lex_state = 50, .external_lex_state = 2},
  [1827] = {.lex_state = 50, .external_lex_state = 2},
  [1828] = {.lex_state = 50, .external_lex_state = 2},
  [1829] = {.lex_state = 50, .external_lex_state = 2},
  [1830] = {.lex_state = 50, .external_lex_state = 2},
  [1831] = {.lex_state = 50, .external_lex_state = 2},
  [1832] = {.lex_state = 50, .external_lex_state = 2},
  [1833] = {.lex_state = 50, .external_lex_state = 2},
  [1834] = {.lex_state = 50, .external_lex_state = 2},
  [1835] = {.lex_state = 50, .external_lex_state = 2},
  [1836] = {.lex_state = 50, .external_lex_state = 2},
  [1837] = {.lex_state = 50, .external_lex_state = 2},
  [1838] = {.lex_state = 50, .external_lex_state = 2},
  [1839] = {.lex_state = 50, .external_lex_state = 2},
  [1840] = {.lex_state = 50, .external_lex_state = 2},
  [1841] = {.lex_state = 50, .external_lex_state = 2},
  [1842] = {.lex_state = 50, .external_lex_state = 2},
  [1843] = {.lex_state = 50, .external_lex_state = 2},
  [1844] = {.lex_state = 50, .external_lex_state = 2},
  [1845] = {.lex_state = 50, .external_lex_state = 2},
  [1846] = {.lex_state = 50, .external_lex_state = 2},
  [1847] = {.lex_state = 50, .external_lex_state = 2},
  [1848] = {.lex_state = 50, .external_lex_state = 2},
  [1849] = {.lex_state = 50, .external_lex_state = 2},
  [1850] = {.lex_state = 50, .external_lex_state = 2},
  [1851] = {.lex_state = 50, .external_lex_state = 2},
  [1852] = {.lex_state = 50, .external_lex_state = 2},
  [1853] = {.lex_state = 50, .external_lex_state = 2},
  [1854] = {.lex_state = 50, .external_lex_state = 2},
  [1855] = {.lex_state = 50, .external_lex_state = 2},
  [1856] = {.lex_state = 50, .external_lex_state = 2},
  [1857] = {.lex_state = 50, .external_lex_state = 2},
  [1858] = {.lex_state = 50, .external_lex_state = 2},
  [1859] = {.lex_state = 50, .external_lex_state = 2},
  [1860] = {.lex_state = 50, .external_lex_state = 2},
  [1861] = {.lex_state = 50, .external_lex_state = 2},
  [1862] = {.lex_state = 50, .external_lex_state = 2},
  [1863] = {.lex_state = 50, .external_lex_state = 2},
  [1864] = {.lex_state = 50, .external_lex_state = 2},
  [1865] = {.lex_state = 50, .external_lex_state = 2},
  [1866] = {.lex_state = 50, .external_lex_state = 2},
  [1867] = {.lex_state = 50, .external_lex_state = 2},
  [1868] = {.lex_state = 50, .external_lex_state = 2},
  [1869] = {.lex_state = 50, .external_lex_state = 2},
  [1870] = {.lex_state = 50, .external_lex_state = 2},
  [1871] = {.lex_state = 50, .external_lex_state = 2},
  [1872] = {.lex_state = 50, .external_lex_state = 2},
  [1873] = {.lex_state = 50, .external_lex_state = 2},
  [1874] = {.lex_state = 50, .external_lex_state = 2},
  [1875] = {.lex_state = 50, .external_lex_state = 2},
  [1876] = {.lex_state = 50, .external_lex_state = 2},
  [1877] = {.lex_state = 50, .external_lex_state = 2},
  [1878] = {.lex_state = 50, .external_lex_state = 2},
  [1879] = {.lex_state = 50, .external_lex_state = 2},
  [1880] = {.lex_state = 50, .external_lex_state = 2},
  [1881] = {.lex_state = 50, .external_lex_state = 2},
  [1882] = {.lex_state = 50, .external_lex_state = 2},
  [1883] = {.lex_state = 50, .external_lex_state = 2},
  [1884] = {.lex_state = 50, .external_lex_state = 2},
  [1885] = {.lex_state = 50, .external_lex_state = 2},
  [1886] = {.lex_state = 50, .external_lex_state = 2},
  [1887] = {.lex_state = 50, .external_lex_state = 2},
  [1888] = {.lex_state = 50, .external_lex_state = 2},
  [1889] = {.lex_state = 50, .external_lex_state = 2},
  [1890] = {.lex_state = 50, .external_lex_state = 2},
  [1891] = {.lex_state = 50, .external_lex_state = 2},
  [1892] = {.lex_state = 50, .external_lex_state = 2},
  [1893] = {.lex_state = 50, .external_lex_state = 2},
  [1894] = {.lex_state = 50, .external_lex_state = 2},
  [1895] = {.lex_state = 50, .external_lex_state = 2},
  [1896] = {.lex_state = 50, .external_lex_state = 2},
  [1897] = {.lex_state = 50, .external_lex_state = 2},
  [1898] = {.lex_state = 50, .external_lex_state = 2},
  [1899] = {.lex_state = 50, .external_lex_state = 2},
  [1900] = {.lex_state = 50, .external_lex_state = 2},
  [1901] = {.lex_state = 50, .external_lex_state = 2},
  [1902] = {.lex_state = 50, .external_lex_state = 2},
  [1903] = {.lex_state = 50, .external_lex_state = 2},
  [1904] = {.lex_state = 50, .external_lex_state = 2},
  [1905] = {.lex_state = 50, .external_lex_state = 2},
  [1906] = {.lex_state = 50, .external_lex_state = 2},
  [1907] = {.lex_state = 50, .external_lex_state = 2},
  [1908] = {.lex_state = 50, .external_lex_state = 2},
  [1909] = {.lex_state = 50, .external_lex_state = 2},
  [1910] = {.lex_state = 50, .external_lex_state = 2},
  [1911] = {.lex_state = 50, .external_lex_state = 2},
  [1912] = {.lex_state = 50, .external_lex_state = 2},
  [1913] = {.lex_state = 50, .external_lex_state = 2},
  [1914] = {.lex_state = 50, .external_lex_state = 2},
  [1915] = {.lex_state = 50, .external_lex_state = 2},
  [1916] = {.lex_state = 50, .external_lex_state = 2},
  [1917] = {.lex_state = 50, .external_lex_state = 2},
  [1918] = {.lex_state = 50, .external_lex_state = 2},
  [1919] = {.lex_state = 50, .external_lex_state = 2},
  [1920] = {.lex_state = 50, .external_lex_state = 2},
  [1921] = {.lex_state = 50, .external_lex_state = 2},
  [1922] = {.lex_state = 50, .external_lex_state = 2},
  [1923] = {.lex_state = 50, .external_lex_state = 2},
  [1924] = {.lex_state = 50, .external_lex_state = 2},
  [1925] = {.lex_state = 50, .external_lex_state = 2},
  [1926] = {.lex_state = 50, .external_lex_state = 2},
  [1927] = {.lex_state = 50, .external_lex_state = 2},
  [1928] = {.lex_state = 50, .external_lex_state = 2},
  [1929] = {.lex_state = 50, .external_lex_state = 2},
  [1930] = {.lex_state = 50, .external_lex_state = 2},
  [1931] = {.lex_state = 50, .external_lex_state = 2},
  [1932] = {.lex_state = 50, .external_lex_state = 2},
  [1933] = {.lex_state = 50, .external_lex_state = 2},
  [1934] = {.lex_state = 50, .external_lex_state = 2},
  [1935] = {.lex_state = 50, .external_lex_state = 2},
  [1936] = {.lex_state = 50, .external_lex_state = 2},
  [1937] = {.lex_state = 50, .external_lex_state = 2},
  [1938] = {.lex_state = 50, .external_lex_state = 2},
  [1939] = {.lex_state = 50, .external_lex_state = 2},
  [1940] = {.lex_state = 50, .external_lex_state = 2},
  [1941] = {.lex_state = 50, .external_lex_state = 2},
  [1942] = {.lex_state = 50, .external_lex_state = 2},
  [1943] = {.lex_state = 50, .external_lex_state = 2},
  [1944] = {.lex_state = 50, .external_lex_state = 2},
  [1945] = {.lex_state = 50, .external_lex_state = 2},
  [1946] = {.lex_state = 50, .external_lex_state = 2},
  [1947] = {.lex_state = 50, .external_lex_state = 2},
  [1948] = {.lex_state = 50, .external_lex_state = 2},
  [1949] = {.lex_state = 50, .external_lex_state = 2},
  [1950] = {.lex_state = 50, .external_lex_state = 2},
  [1951] = {.lex_state = 50, .external_lex_state = 2},
  [1952] = {.lex_state = 50, .external_lex_state = 2},
  [1953] = {.lex_state = 50, .external_lex_state = 2},
  [1954] = {.lex_state = 50, .external_lex_state = 2},
  [1955] = {.lex_state = 50, .external_lex_state = 2},
  [1956] = {.lex_state = 50, .external_lex_state = 2},
  [1957] = {.lex_state = 50, .external_lex_state = 2},
  [1958] = {.lex_state = 50, .external_lex_state = 2},
  [1959] = {.lex_state = 50, .external_lex_state = 2},
  [1960] = {.lex_state = 50, .external_lex_state = 2},
  [1961] = {.lex_state = 50, .external_lex_state = 2},
  [1962] = {.lex_state = 50, .external_lex_state = 2},
  [1963] = {.lex_state = 50, .external_lex_state = 2},
  [1964] = {.lex_state = 50, .external_lex_state = 2},
  [1965] = {.lex_state = 50, .external_lex_state = 2},
  [1966] = {.lex_state = 50, .external_lex_state = 2},
  [1967] = {.lex_state = 50, .external_lex_state = 2},
  [1968] = {.lex_state = 50, .external_lex_state = 2},
  [1969] = {.lex_state = 50, .external_lex_state = 2},
  [1970] = {.lex_state = 50, .external_lex_state = 2},
  [1971] = {.lex_state = 50, .external_lex_state = 2},
  [1972] = {.lex_state = 50, .external_lex_state = 2},
  [1973] = {.lex_state = 50, .external_lex_state = 2},
  [1974] = {.lex_state = 50, .external_lex_state = 2},
  [1975] = {.lex_state = 50, .external_lex_state = 2},
  [1976] = {.lex_state = 50, .external_lex_state = 2},
  [1977] = {.lex_state = 50, .external_lex_state = 2},
  [1978] = {.lex_state = 50, .external_lex_state = 2},
  [1979] = {.lex_state = 50, .external_lex_state = 2},
  [1980] = {.lex_state = 50, .external_lex_state = 2},
  [1981] = {.lex_state = 50, .external_lex_state = 2},
  [1982] = {.lex_state = 50, .external_lex_state = 2},
  [1983] = {.lex_state = 50, .external_lex_state = 2},
  [1984] = {.lex_state = 50, .external_lex_state = 2},
  [1985] = {.lex_state = 50, .external_lex_state = 2},
  [1986] = {.lex_state = 50, .external_lex_state = 2},
  [1987] = {.lex_state = 50, .external_lex_state = 2},
  [1988] = {.lex_state = 50, .external_lex_state = 2},
  [1989] = {.lex_state = 50, .external_lex_state = 2},
  [1990] = {.lex_state = 50, .external_lex_state = 2},
  [1991] = {.lex_state = 50, .external_lex_state = 2},
  [1992] = {.lex_state = 50, .external_lex_state = 2},
  [1993] = {.lex_state = 50, .external_lex_state = 2},
  [1994] = {.lex_state = 50, .external_lex_state = 2},
  [1995] = {.lex_state = 50, .external_lex_state = 2},
  [1996] = {.lex_state = 50, .external_lex_state = 2},
  [1997] = {.lex_state = 50, .external_lex_state = 2},
  [1998] = {.lex_state = 50, .external_lex_state = 2},
  [1999] = {.lex_state = 50, .external_lex_state = 2},
  [2000] = {.lex_state = 50, .external_lex_state = 2},
  [2001] = {.lex_state = 50, .external_lex_state = 2},
  [2002] = {.lex_state = 50, .external_lex_state = 2},
  [2003] = {.lex_state = 50, .external_lex_state = 2},
  [2004] = {.lex_state = 50, .external_lex_state = 2},
  [2005] = {.lex_state = 50, .external_lex_state = 2},
  [2006] = {.lex_state = 50, .external_lex_state = 2},
  [2007] = {.lex_state = 50, .external_lex_state = 2},
  [2008] = {.lex_state = 50, .external_lex_state = 2},
  [2009] = {.lex_state = 50, .external_lex_state = 2},
  [2010] = {.lex_state = 50, .external_lex_state = 2},
  [2011] = {.lex_state = 50, .external_lex_state = 2},
  [2012] = {.lex_state = 50, .external_lex_state = 2},
  [2013] = {.lex_state = 50, .external_lex_state = 2},
  [2014] = {.lex_state = 50, .external_lex_state = 2},
  [2015] = {.lex_state = 50, .external_lex_state = 2},
  [2016] = {.lex_state = 50, .external_lex_state = 2},
  [2017] = {.lex_state = 50, .external_lex_state = 2},
  [2018] = {.lex_state = 50, .external_lex_state = 2},
  [2019] = {.lex_state = 50, .external_lex_state = 2},
  [2020] = {.lex_state = 50, .external_lex_state = 2},
  [2021] = {.lex_state = 50, .external_lex_state = 2},
  [2022] = {.lex_state = 50, .external_lex_state = 2},
  [2023] = {.lex_state = 50, .external_lex_state = 2},
  [2024] = {.lex_state = 50, .external_lex_state = 2},
  [2025] = {.lex_state = 50, .external_lex_state = 2},
  [2026] = {.lex_state = 50, .external_lex_state = 2},
  [2027] = {.lex_state = 50, .external_lex_state = 2},
  [2028] = {.lex_state = 50, .external_lex_state = 2},
  [2029] = {.lex_state = 50, .external_lex_state = 2},
  [2030] = {.lex_state = 50, .external_lex_state = 2},
  [2031] = {.lex_state = 50, .external_lex_state = 2},
  [2032] = {.lex_state = 50, .external_lex_state = 2},
  [2033] = {.lex_state = 50, .external_lex_state = 2},
  [2034] = {.lex_state = 50, .external_lex_state = 2},
  [2035] = {.lex_state = 50, .external_lex_state = 2},
  [2036] = {.lex_state = 50, .external_lex_state = 2},
  [2037] = {.lex_state = 50, .external_lex_state = 2},
  [2038] = {.lex_state = 50, .external_lex_state = 2},
  [2039] = {.lex_state = 50, .external_lex_state = 2},
  [2040] = {.lex_state = 50, .external_lex_state = 2},
  [2041] = {.lex_state = 50, .external_lex_state = 2},
  [2042] = {.lex_state = 50, .external_lex_state = 2},
  [2043] = {.lex_state = 50, .external_lex_state = 2},
  [2044] = {.lex_state = 50, .external_lex_state = 2},
  [2045] = {.lex_state = 50, .external_lex_state = 2},
  [2046] = {.lex_state = 50, .external_lex_state = 2},
  [2047] = {.lex_state = 50, .external_lex_state = 2},
  [2048] = {.lex_state = 50, .external_lex_state = 2},
  [2049] = {.lex_state = 50, .external_lex_state = 2},
  [2050] = {.lex_state = 50, .external_lex_state = 2},
  [2051] = {.lex_state = 50, .external_lex_state = 2},
  [2052] = {.lex_state = 50, .external_lex_state = 2},
  [2053] = {.lex_state = 50, .external_lex_state = 2},
  [2054] = {.lex_state = 50, .external_lex_state = 2},
  [2055] = {.lex_state = 50, .external_lex_state = 2},
  [2056] = {.lex_state = 50, .external_lex_state = 2},
  [2057] = {.lex_state = 50, .external_lex_state = 2},
  [2058] = {.lex_state = 50, .external_lex_state = 2},
  [2059] = {.lex_state = 50, .external_lex_state = 2},
  [2060] = {.lex_state = 50, .external_lex_state = 2},
  [2061] = {.lex_state = 50, .external_lex_state = 2},
  [2062] = {.lex_state = 50, .external_lex_state = 2},
  [2063] = {.lex_state = 50, .external_lex_state = 2},
  [2064] = {.lex_state = 50, .external_lex_state = 2},
  [2065] = {.lex_state = 50, .external_lex_state = 2},
  [2066] = {.lex_state = 50, .external_lex_state = 2},
  [2067] = {.lex_state = 50, .external_lex_state = 2},
  [2068] = {.lex_state = 50, .external_lex_state = 2},
  [2069] = {.lex_state = 50, .external_lex_state = 2},
  [2070] = {.lex_state = 50, .external_lex_state = 2},
  [2071] = {.lex_state = 50, .external_lex_state = 2},
  [2072] = {.lex_state = 50, .external_lex_state = 2},
  [2073] = {.lex_state = 50, .external_lex_state = 2},
  [2074] = {.lex_state = 50, .external_lex_state = 2},
  [2075] = {.lex_state = 50, .external_lex_state = 2},
  [2076] = {.lex_state = 50, .external_lex_state = 2},
  [2077] = {.lex_state = 50, .external_lex_state = 2},
  [2078] = {.lex_state = 50, .external_lex_state = 2},
  [2079] = {.lex_state = 50, .external_lex_state = 2},
  [2080] = {.lex_state = 50, .external_lex_state = 2},
  [2081] = {.lex_state = 50, .external_lex_state = 2},
  [2082] = {.lex_state = 50, .external_lex_state = 2},
  [2083] = {.lex_state = 50, .external_lex_state = 2},
  [2084] = {.lex_state = 50, .external_lex_state = 2},
  [2085] = {.lex_state = 50, .external_lex_state = 2},
  [2086] = {.lex_state = 50, .external_lex_state = 2},
  [2087] = {.lex_state = 50, .external_lex_state = 2},
  [2088] = {.lex_state = 50, .external_lex_state = 2},
  [2089] = {.lex_state = 50, .external_lex_state = 2},
  [2090] = {.lex_state = 50, .external_lex_state = 2},
  [2091] = {.lex_state = 50, .external_lex_state = 2},
  [2092] = {.lex_state = 50, .external_lex_state = 2},
  [2093] = {.lex_state = 50, .external_lex_state = 2},
  [2094] = {.lex_state = 50, .external_lex_state = 2},
  [2095] = {.lex_state = 50, .external_lex_state = 2},
  [2096] = {.lex_state = 50, .external_lex_state = 2},
  [2097] = {.lex_state = 50, .external_lex_state = 2},
  [2098] = {.lex_state = 50, .external_lex_state = 2},
  [2099] = {.lex_state = 50, .external_lex_state = 2},
  [2100] = {.lex_state = 50, .external_lex_state = 2},
  [2101] = {.lex_state = 50, .external_lex_state = 2},
  [2102] = {.lex_state = 50, .external_lex_state = 2},
  [2103] = {.lex_state = 50, .external_lex_state = 2},
  [2104] = {.lex_state = 50, .external_lex_state = 2},
  [2105] = {.lex_state = 50, .external_lex_state = 2},
  [2106] = {.lex_state = 50, .external_lex_state = 2},
  [2107] = {.lex_state = 50, .external_lex_state = 2},
  [2108] = {.lex_state = 50, .external_lex_state = 2},
  [2109] = {.lex_state = 50, .external_lex_state = 2},
  [2110] = {.lex_state = 50, .external_lex_state = 2},
  [2111] = {.lex_state = 50, .external_lex_state = 2},
  [2112] = {.lex_state = 50, .external_lex_state = 2},
  [2113] = {.lex_state = 50, .external_lex_state = 2},
  [2114] = {.lex_state = 50, .external_lex_state = 2},
  [2115] = {.lex_state = 50, .external_lex_state = 2},
  [2116] = {.lex_state = 50, .external_lex_state = 2},
  [2117] = {.lex_state = 50, .external_lex_state = 2},
  [2118] = {.lex_state = 50, .external_lex_state = 2},
  [2119] = {.lex_state = 50, .external_lex_state = 2},
  [2120] = {.lex_state = 50, .external_lex_state = 2},
  [2121] = {.lex_state = 50, .external_lex_state = 2},
  [2122] = {.lex_state = 50, .external_lex_state = 2},
  [2123] = {.lex_state = 50, .external_lex_state = 2},
  [2124] = {.lex_state = 50, .external_lex_state = 2},
  [2125] = {.lex_state = 50, .external_lex_state = 2},
  [2126] = {.lex_state = 50, .external_lex_state = 2},
  [2127] = {.lex_state = 50, .external_lex_state = 2},
  [2128] = {.lex_state = 50, .external_lex_state = 2},
  [2129] = {.lex_state = 50, .external_lex_state = 2},
  [2130] = {.lex_state = 50, .external_lex_state = 2},
  [2131] = {.lex_state = 50, .external_lex_state = 2},
  [2132] = {.lex_state = 50, .external_lex_state = 2},
  [2133] = {.lex_state = 50, .external_lex_state = 2},
  [2134] = {.lex_state = 50, .external_lex_state = 2},
  [2135] = {.lex_state = 50, .external_lex_state = 2},
  [2136] = {.lex_state = 50, .external_lex_state = 2},
  [2137] = {.lex_state = 50, .external_lex_state = 2},
  [2138] = {.lex_state = 50, .external_lex_state = 2},
  [2139] = {.lex_state = 50, .external_lex_state = 2},
  [2140] = {.lex_state = 50, .external_lex_state = 2},
  [2141] = {.lex_state = 50, .external_lex_state = 2},
  [2142] = {.lex_state = 50, .external_lex_state = 2},
  [2143] = {.lex_state = 50, .external_lex_state = 2},
  [2144] = {.lex_state = 50, .external_lex_state = 2},
  [2145] = {.lex_state = 50, .external_lex_state = 2},
  [2146] = {.lex_state = 50, .external_lex_state = 2},
  [2147] = {.lex_state = 50, .external_lex_state = 2},
  [2148] = {.lex_state = 50, .external_lex_state = 2},
  [2149] = {.lex_state = 50, .external_lex_state = 2},
  [2150] = {.lex_state = 50, .external_lex_state = 2},
  [2151] = {.lex_state = 50, .external_lex_state = 2},
  [2152] = {.lex_state = 50, .external_lex_state = 2},
  [2153] = {.lex_state = 50, .external_lex_state = 2},
  [2154] = {.lex_state = 50, .external_lex_state = 2},
  [2155] = {.lex_state = 50, .external_lex_state = 2},
  [2156] = {.lex_state = 50, .external_lex_state = 2},
  [2157] = {.lex_state = 50, .external_lex_state = 2},
  [2158] = {.lex_state = 50, .external_lex_state = 2},
  [2159] = {.lex_state = 50, .external_lex_state = 2},
  [2160] = {.lex_state = 50, .external_lex_state = 2},
  [2161] = {.lex_state = 50, .external_lex_state = 2},
  [2162] = {.lex_state = 50, .external_lex_state = 2},
  [2163] = {.lex_state = 50, .external_lex_state = 2},
  [2164] = {.lex_state = 50, .external_lex_state = 2},
  [2165] = {.lex_state = 50, .external_lex_state = 2},
  [2166] = {.lex_state = 50, .external_lex_state = 2},
  [2167] = {.lex_state = 50, .external_lex_state = 2},
  [2168] = {.lex_state = 50, .external_lex_state = 2},
  [2169] = {.lex_state = 50, .external_lex_state = 2},
  [2170] = {.lex_state = 50, .external_lex_state = 2},
  [2171] = {.lex_state = 50, .external_lex_state = 2},
  [2172] = {.lex_state = 50, .external_lex_state = 2},
  [2173] = {.lex_state = 50, .external_lex_state = 2},
  [2174] = {.lex_state = 50, .external_lex_state = 2},
  [2175] = {.lex_state = 50, .external_lex_state = 2},
  [2176] = {.lex_state = 50, .external_lex_state = 2},
  [2177] = {.lex_state = 50, .external_lex_state = 2},
  [2178] = {.lex_state = 50, .external_lex_state = 2},
  [2179] = {.lex_state = 50, .external_lex_state = 2},
  [2180] = {.lex_state = 50, .external_lex_state = 2},
  [2181] = {.lex_state = 50, .external_lex_state = 2},
  [2182] = {.lex_state = 50, .external_lex_state = 2},
  [2183] = {.lex_state = 50, .external_lex_state = 2},
  [2184] = {.lex_state = 50, .external_lex_state = 2},
  [2185] = {.lex_state = 50, .external_lex_state = 2},
  [2186] = {.lex_state = 50, .external_lex_state = 2},
  [2187] = {.lex_state = 50, .external_lex_state = 2},
  [2188] = {.lex_state = 50, .external_lex_state = 2},
  [2189] = {.lex_state = 50, .external_lex_state = 2},
  [2190] = {.lex_state = 50, .external_lex_state = 2},
  [2191] = {.lex_state = 50, .external_lex_state = 2},
  [2192] = {.lex_state = 50, .external_lex_state = 2},
  [2193] = {.lex_state = 50, .external_lex_state = 2},
  [2194] = {.lex_state = 50, .external_lex_state = 2},
  [2195] = {.lex_state = 50, .external_lex_state = 2},
  [2196] = {.lex_state = 50, .external_lex_state = 2},
  [2197] = {.lex_state = 50, .external_lex_state = 2},
  [2198] = {.lex_state = 50, .external_lex_state = 2},
  [2199] = {.lex_state = 50, .external_lex_state = 2},
  [2200] = {.lex_state = 50, .external_lex_state = 2},
  [2201] = {.lex_state = 50, .external_lex_state = 2},
  [2202] = {.lex_state = 50, .external_lex_state = 2},
  [2203] = {.lex_state = 50, .external_lex_state = 2},
  [2204] = {.lex_state = 50, .external_lex_state = 2},
  [2205] = {.lex_state = 50, .external_lex_state = 2},
  [2206] = {.lex_state = 50, .external_lex_state = 2},
  [2207] = {.lex_state = 50, .external_lex_state = 2},
  [2208] = {.lex_state = 50, .external_lex_state = 2},
  [2209] = {.lex_state = 50, .external_lex_state = 2},
  [2210] = {.lex_state = 50, .external_lex_state = 2},
  [2211] = {.lex_state = 50, .external_lex_state = 2},
  [2212] = {.lex_state = 50, .external_lex_state = 2},
  [2213] = {.lex_state = 50, .external_lex_state = 2},
  [2214] = {.lex_state = 50, .external_lex_state = 2},
  [2215] = {.lex_state = 50, .external_lex_state = 2},
  [2216] = {.lex_state = 50, .external_lex_state = 2},
  [2217] = {.lex_state = 50, .external_lex_state = 2},
  [2218] = {.lex_state = 50, .external_lex_state = 2},
  [2219] = {.lex_state = 50, .external_lex_state = 2},
  [2220] = {.lex_state = 50, .external_lex_state = 2},
  [2221] = {.lex_state = 50, .external_lex_state = 2},
  [2222] = {.lex_state = 50, .external_lex_state = 2},
  [2223] = {.lex_state = 50, .external_lex_state = 2},
  [2224] = {.lex_state = 50, .external_lex_state = 2},
  [2225] = {.lex_state = 50, .external_lex_state = 2},
  [2226] = {.lex_state = 50, .external_lex_state = 2},
  [2227] = {.lex_state = 50, .external_lex_state = 2},
  [2228] = {.lex_state = 50, .external_lex_state = 2},
  [2229] = {.lex_state = 50, .external_lex_state = 2},
  [2230] = {.lex_state = 50, .external_lex_state = 2},
  [2231] = {.lex_state = 50, .external_lex_state = 2},
  [2232] = {.lex_state = 50, .external_lex_state = 2},
  [2233] = {.lex_state = 50, .external_lex_state = 2},
  [2234] = {.lex_state = 50, .external_lex_state = 2},
  [2235] = {.lex_state = 50, .external_lex_state = 2},
  [2236] = {.lex_state = 50, .external_lex_state = 2},
  [2237] = {.lex_state = 50, .external_lex_state = 2},
  [2238] = {.lex_state = 50, .external_lex_state = 2},
  [2239] = {.lex_state = 50, .external_lex_state = 2},
  [2240] = {.lex_state = 50, .external_lex_state = 2},
  [2241] = {.lex_state = 50, .external_lex_state = 2},
  [2242] = {.lex_state = 50, .external_lex_state = 2},
  [2243] = {.lex_state = 50, .external_lex_state = 2},
  [2244] = {.lex_state = 50, .external_lex_state = 2},
  [2245] = {.lex_state = 50, .external_lex_state = 2},
  [2246] = {.lex_state = 50, .external_lex_state = 2},
  [2247] = {.lex_state = 50, .external_lex_state = 2},
  [2248] = {.lex_state = 50, .external_lex_state = 2},
  [2249] = {.lex_state = 50, .external_lex_state = 2},
  [2250] = {.lex_state = 50, .external_lex_state = 2},
  [2251] = {.lex_state = 50, .external_lex_state = 2},
  [2252] = {.lex_state = 50, .external_lex_state = 2},
  [2253] = {.lex_state = 50, .external_lex_state = 2},
  [2254] = {.lex_state = 50, .external_lex_state = 2},
  [2255] = {.lex_state = 50, .external_lex_state = 2},
  [2256] = {.lex_state = 50, .external_lex_state = 2},
  [2257] = {.lex_state = 50, .external_lex_state = 2},
  [2258] = {.lex_state = 50, .external_lex_state = 2},
  [2259] = {.lex_state = 50, .external_lex_state = 2},
  [2260] = {.lex_state = 50, .external_lex_state = 2},
  [2261] = {.lex_state = 50, .external_lex_state = 2},
  [2262] = {.lex_state = 50, .external_lex_state = 2},
  [2263] = {.lex_state = 50, .external_lex_state = 2},
  [2264] = {.lex_state = 50, .external_lex_state = 2},
  [2265] = {.lex_state = 50, .external_lex_state = 2},
  [2266] = {.lex_state = 50, .external_lex_state = 2},
  [2267] = {.lex_state = 50, .external_lex_state = 2},
  [2268] = {.lex_state = 50, .external_lex_state = 2},
  [2269] = {.lex_state = 50, .external_lex_state = 2},
  [2270] = {.lex_state = 50, .external_lex_state = 2},
  [2271] = {.lex_state = 50, .external_lex_state = 2},
  [2272] = {.lex_state = 50, .external_lex_state = 2},
  [2273] = {.lex_state = 50, .external_lex_state = 2},
  [2274] = {.lex_state = 50, .external_lex_state = 2},
  [2275] = {.lex_state = 50, .external_lex_state = 2},
  [2276] = {.lex_state = 50, .external_lex_state = 2},
  [2277] = {.lex_state = 50, .external_lex_state = 2},
  [2278] = {.lex_state = 50, .external_lex_state = 2},
  [2279] = {.lex_state = 50, .external_lex_state = 2},
  [2280] = {.lex_state = 50, .external_lex_state = 2},
  [2281] = {.lex_state = 50, .external_lex_state = 2},
  [2282] = {.lex_state = 50, .external_lex_state = 2},
  [2283] = {.lex_state = 50, .external_lex_state = 2},
  [2284] = {.lex_state = 50, .external_lex_state = 2},
  [2285] = {.lex_state = 50, .external_lex_state = 2},
  [2286] = {.lex_state = 50, .external_lex_state = 2},
  [2287] = {.lex_state = 50, .external_lex_state = 2},
  [2288] = {.lex_state = 50, .external_lex_state = 2},
  [2289] = {.lex_state = 50, .external_lex_state = 2},
  [2290] = {.lex_state = 50, .external_lex_state = 2},
  [2291] = {.lex_state = 50, .external_lex_state = 2},
  [2292] = {.lex_state = 50, .external_lex_state = 2},
  [2293] = {.lex_state = 50, .external_lex_state = 2},
  [2294] = {.lex_state = 50, .external_lex_state = 2},
  [2295] = {.lex_state = 50, .external_lex_state = 2},
  [2296] = {.lex_state = 50, .external_lex_state = 2},
  [2297] = {.lex_state = 50, .external_lex_state = 2},
  [2298] = {.lex_state = 50, .external_lex_state = 2},
  [2299] = {.lex_state = 50, .external_lex_state = 2},
  [2300] = {.lex_state = 50, .external_lex_state = 2},
  [2301] = {.lex_state = 50, .external_lex_state = 2},
  [2302] = {.lex_state = 50, .external_lex_state = 2},
  [2303] = {.lex_state = 50, .external_lex_state = 2},
  [2304] = {.lex_state = 50, .external_lex_state = 2},
  [2305] = {.lex_state = 50, .external_lex_state = 2},
  [2306] = {.lex_state = 50, .external_lex_state = 2},
  [2307] = {.lex_state = 50, .external_lex_state = 2},
  [2308] = {.lex_state = 50, .external_lex_state = 2},
  [2309] = {.lex_state = 50, .external_lex_state = 2},
  [2310] = {.lex_state = 50, .external_lex_state = 2},
  [2311] = {.lex_state = 50, .external_lex_state = 2},
  [2312] = {.lex_state = 50, .external_lex_state = 2},
  [2313] = {.lex_state = 50, .external_lex_state = 2},
  [2314] = {.lex_state = 50, .external_lex_state = 2},
  [2315] = {.lex_state = 50, .external_lex_state = 2},
  [2316] = {.lex_state = 50, .external_lex_state = 2},
  [2317] = {.lex_state = 50, .external_lex_state = 2},
  [2318] = {.lex_state = 50, .external_lex_state = 2},
  [2319] = {.lex_state = 50, .external_lex_state = 2},
  [2320] = {.lex_state = 50, .external_lex_state = 2},
  [2321] = {.lex_state = 50, .external_lex_state = 2},
  [2322] = {.lex_state = 50, .external_lex_state = 2},
  [2323] = {.lex_state = 50, .external_lex_state = 2},
  [2324] = {.lex_state = 50, .external_lex_state = 2},
  [2325] = {.lex_state = 50, .external_lex_state = 2},
  [2326] = {.lex_state = 50, .external_lex_state = 2},
  [2327] = {.lex_state = 50, .external_lex_state = 2},
  [2328] = {.lex_state = 50, .external_lex_state = 2},
  [2329] = {.lex_state = 50, .external_lex_state = 2},
  [2330] = {.lex_state = 50, .external_lex_state = 2},
  [2331] = {.lex_state = 50, .external_lex_state = 2},
  [2332] = {.lex_state = 50, .external_lex_state = 2},
  [2333] = {.lex_state = 50, .external_lex_state = 2},
  [2334] = {.lex_state = 50, .external_lex_state = 2},
  [2335] = {.lex_state = 50, .external_lex_state = 2},
  [2336] = {.lex_state = 50, .external_lex_state = 2},
  [2337] = {.lex_state = 50, .external_lex_state = 2},
  [2338] = {.lex_state = 50, .external_lex_state = 2},
  [2339] = {.lex_state = 50, .external_lex_state = 2},
  [2340] = {.lex_state = 50, .external_lex_state = 2},
  [2341] = {.lex_state = 50, .external_lex_state = 2},
  [2342] = {.lex_state = 50, .external_lex_state = 2},
  [2343] = {.lex_state = 50, .external_lex_state = 2},
  [2344] = {.lex_state = 50, .external_lex_state = 2},
  [2345] = {.lex_state = 50, .external_lex_state = 2},
  [2346] = {.lex_state = 50, .external_lex_state = 2},
  [2347] = {.lex_state = 50, .external_lex_state = 2},
  [2348] = {.lex_state = 48, .external_lex_state = 19},
  [2349] = {.lex_state = 48, .external_lex_state = 22},
  [2350] = {.lex_state = 48, .external_lex_state = 19},
  [2351] = {.lex_state = 60, .external_lex_state = 3},
  [2352] = {.lex_state = 60, .external_lex_state = 3},
  [2353] = {.lex_state = 60, .external_lex_state = 3},
  [2354] = {.lex_state = 60, .external_lex_state = 3},
  [2355] = {.lex_state = 60, .external_lex_state = 3},
  [2356] = {.lex_state = 60, .external_lex_state = 3},
  [2357] = {.lex_state = 60, .external_lex_state = 3},
  [2358] = {.lex_state = 60, .external_lex_state = 3},
  [2359] = {.lex_state = 60, .external_lex_state = 3},
  [2360] = {.lex_state = 60, .external_lex_state = 3},
  [2361] = {.lex_state = 60, .external_lex_state = 3},
  [2362] = {.lex_state = 60, .external_lex_state = 3},
  [2363] = {.lex_state = 60, .external_lex_state = 3},
  [2364] = {.lex_state = 60, .external_lex_state = 3},
  [2365] = {.lex_state = 60, .external_lex_state = 3},
  [2366] = {.lex_state = 60, .external_lex_state = 3},
  [2367] = {.lex_state = 60, .external_lex_state = 3},
  [2368] = {.lex_state = 60, .external_lex_state = 3},
  [2369] = {.lex_state = 60, .external_lex_state = 3},
  [2370] = {.lex_state = 60, .external_lex_state = 3},
  [2371] = {.lex_state = 60, .external_lex_state = 3},
  [2372] = {.lex_state = 60, .external_lex_state = 3},
  [2373] = {.lex_state = 60, .external_lex_state = 3},
  [2374] = {.lex_state = 60, .external_lex_state = 3},
  [2375] = {.lex_state = 60, .external_lex_state = 3},
  [2376] = {.lex_state = 60, .external_lex_state = 3},
  [2377] = {.lex_state = 60, .external_lex_state = 3},
  [2378] = {.lex_state = 60, .external_lex_state = 3},
  [2379] = {.lex_state = 60, .external_lex_state = 3},
  [2380] = {.lex_state = 60, .external_lex_state = 3},
  [2381] = {.lex_state = 60, .external_lex_state = 3},
  [2382] = {.lex_state = 60, .external_lex_state = 3},
  [2383] = {.lex_state = 60, .external_lex_state = 3},
  [2384] = {.lex_state = 60, .external_lex_state = 3},
  [2385] = {.lex_state = 60, .external_lex_state = 3},
  [2386] = {.lex_state = 60, .external_lex_state = 3},
  [2387] = {.lex_state = 60, .external_lex_state = 3},
  [2388] = {.lex_state = 60, .external_lex_state = 3},
  [2389] = {.lex_state = 60, .external_lex_state = 3},
  [2390] = {.lex_state = 60, .external_lex_state = 3},
  [2391] = {.lex_state = 60, .external_lex_state = 3},
  [2392] = {.lex_state = 60, .external_lex_state = 3},
  [2393] = {.lex_state = 60, .external_lex_state = 3},
  [2394] = {.lex_state = 60, .external_lex_state = 3},
  [2395] = {.lex_state = 60, .external_lex_state = 3},
  [2396] = {.lex_state = 60, .external_lex_state = 3},
  [2397] = {.lex_state = 60, .external_lex_state = 3},
  [2398] = {.lex_state = 60, .external_lex_state = 3},
  [2399] = {.lex_state = 50, .external_lex_state = 2},
  [2400] = {.lex_state = 50, .external_lex_state = 4},
  [2401] = {.lex_state = 50, .external_lex_state = 3},
  [2402] = {.lex_state = 50, .external_lex_state = 2},
  [2403] = {.lex_state = 50, .external_lex_state = 2},
  [2404] = {.lex_state = 50, .external_lex_state = 4},
  [2405] = {.lex_state = 50, .external_lex_state = 4},
  [2406] = {.lex_state = 60, .external_lex_state = 2},
  [2407] = {.lex_state = 14, .external_lex_state = 2},
  [2408] = {.lex_state = 50, .external_lex_state = 2},
  [2409] = {.lex_state = 14, .external_lex_state = 2},
  [2410] = {.lex_state = 60, .external_lex_state = 2},
  [2411] = {.lex_state = 60, .external_lex_state = 2},
  [2412] = {.lex_state = 60, .external_lex_state = 2},
  [2413] = {.lex_state = 60, .external_lex_state = 2},
  [2414] = {.lex_state = 60, .external_lex_state = 2},
  [2415] = {.lex_state = 60, .external_lex_state = 2},
  [2416] = {.lex_state = 60, .external_lex_state = 2},
  [2417] = {.lex_state = 60, .external_lex_state = 2},
  [2418] = {.lex_state = 60, .external_lex_state = 2},
  [2419] = {.lex_state = 60, .external_lex_state = 2},
  [2420] = {.lex_state = 60, .external_lex_state = 2},
  [2421] = {.lex_state = 60, .external_lex_state = 2},
  [2422] = {.lex_state = 60, .external_lex_state = 2},
  [2423] = {.lex_state = 60, .external_lex_state = 2},
  [2424] = {.lex_state = 60, .external_lex_state = 2},
  [2425] = {.lex_state = 60, .external_lex_state = 2},
  [2426] = {.lex_state = 60, .external_lex_state = 2},
  [2427] = {.lex_state = 60, .external_lex_state = 2},
  [2428] = {.lex_state = 60, .external_lex_state = 2},
  [2429] = {.lex_state = 60, .external_lex_state = 2},
  [2430] = {.lex_state = 60, .external_lex_state = 2},
  [2431] = {.lex_state = 60, .external_lex_state = 2},
  [2432] = {.lex_state = 60, .external_lex_state = 2},
  [2433] = {.lex_state = 60, .external_lex_state = 2},
  [2434] = {.lex_state = 60, .external_lex_state = 2},
  [2435] = {.lex_state = 60, .external_lex_state = 2},
  [2436] = {.lex_state = 60, .external_lex_state = 2},
  [2437] = {.lex_state = 60, .external_lex_state = 2},
  [2438] = {.lex_state = 60, .external_lex_state = 2},
  [2439] = {.lex_state = 60, .external_lex_state = 2},
  [2440] = {.lex_state = 60, .external_lex_state = 2},
  [2441] = {.lex_state = 60, .external_lex_state = 2},
  [2442] = {.lex_state = 60, .external_lex_state = 2},
  [2443] = {.lex_state = 60, .external_lex_state = 2},
  [2444] = {.lex_state = 60, .external_lex_state = 2},
  [2445] = {.lex_state = 60, .external_lex_state = 2},
  [2446] = {.lex_state = 60, .external_lex_state = 2},
  [2447] = {.lex_state = 60, .external_lex_state = 2},
  [2448] = {.lex_state = 60, .external_lex_state = 2},
  [2449] = {.lex_state = 60, .external_lex_state = 2},
  [2450] = {.lex_state = 60, .external_lex_state = 2},
  [2451] = {.lex_state = 60, .external_lex_state = 2},
  [2452] = {.lex_state = 60, .external_lex_state = 2},
  [2453] = {.lex_state = 60, .external_lex_state = 2},
  [2454] = {.lex_state = 60, .external_lex_state = 2},
  [2455] = {.lex_state = 60, .external_lex_state = 2},
  [2456] = {.lex_state = 60, .external_lex_state = 2},
  [2457] = {.lex_state = 60, .external_lex_state = 2},
  [2458] = {.lex_state = 60, .external_lex_state = 2},
  [2459] = {.lex_state = 60, .external_lex_state = 2},
  [2460] = {.lex_state = 60, .external_lex_state = 2},
  [2461] = {.lex_state = 60, .external_lex_state = 2},
  [2462] = {.lex_state = 60, .external_lex_state = 2},
  [2463] = {.lex_state = 60, .external_lex_state = 2},
  [2464] = {.lex_state = 48, .external_lex_state = 6},
  [2465] = {.lex_state = 60, .external_lex_state = 2},
  [2466] = {.lex_state = 60, .external_lex_state = 2},
  [2467] = {.lex_state = 60, .external_lex_state = 2},
  [2468] = {.lex_state = 60, .external_lex_state = 2},
  [2469] = {.lex_state = 60, .external_lex_state = 2},
  [2470] = {.lex_state = 60, .external_lex_state = 2},
  [2471] = {.lex_state = 60, .external_lex_state = 2},
  [2472] = {.lex_state = 60, .external_lex_state = 2},
  [2473] = {.lex_state = 60, .external_lex_state = 2},
  [2474] = {.lex_state = 60, .external_lex_state = 2},
  [2475] = {.lex_state = 60, .external_lex_state = 2},
  [2476] = {.lex_state = 60, .external_lex_state = 2},
  [2477] = {.lex_state = 60, .external_lex_state = 2},
  [2478] = {.lex_state = 60, .external_lex_state = 2},
  [2479] = {.lex_state = 60, .external_lex_state = 2},
  [2480] = {.lex_state = 60, .external_lex_state = 2},
  [2481] = {.lex_state = 60, .external_lex_state = 2},
  [2482] = {.lex_state = 60, .external_lex_state = 2},
  [2483] = {.lex_state = 60, .external_lex_state = 2},
  [2484] = {.lex_state = 60, .external_lex_state = 2},
  [2485] = {.lex_state = 60, .external_lex_state = 2},
  [2486] = {.lex_state = 60, .external_lex_state = 2},
  [2487] = {.lex_state = 60, .external_lex_state = 2},
  [2488] = {.lex_state = 60, .external_lex_state = 2},
  [2489] = {.lex_state = 60, .external_lex_state = 2},
  [2490] = {.lex_state = 60, .external_lex_state = 2},
  [2491] = {.lex_state = 60, .external_lex_state = 2},
  [2492] = {.lex_state = 60, .external_lex_state = 2},
  [2493] = {.lex_state = 60, .external_lex_state = 2},
  [2494] = {.lex_state = 60, .external_lex_state = 2},
  [2495] = {.lex_state = 60, .external_lex_state = 2},
  [2496] = {.lex_state = 60, .external_lex_state = 2},
  [2497] = {.lex_state = 60, .external_lex_state = 2},
  [2498] = {.lex_state = 60, .external_lex_state = 2},
  [2499] = {.lex_state = 60, .external_lex_state = 2},
  [2500] = {.lex_state = 60, .external_lex_state = 2},
  [2501] = {.lex_state = 60, .external_lex_state = 2},
  [2502] = {.lex_state = 60, .external_lex_state = 2},
  [2503] = {.lex_state = 60, .external_lex_state = 2},
  [2504] = {.lex_state = 60, .external_lex_state = 2},
  [2505] = {.lex_state = 60, .external_lex_state = 2},
  [2506] = {.lex_state = 60, .external_lex_state = 2},
  [2507] = {.lex_state = 60, .external_lex_state = 2},
  [2508] = {.lex_state = 60, .external_lex_state = 2},
  [2509] = {.lex_state = 60, .external_lex_state = 2},
  [2510] = {.lex_state = 60, .external_lex_state = 2},
  [2511] = {.lex_state = 60, .external_lex_state = 2},
  [2512] = {.lex_state = 60, .external_lex_state = 2},
  [2513] = {.lex_state = 60, .external_lex_state = 2},
  [2514] = {.lex_state = 60, .external_lex_state = 2},
  [2515] = {.lex_state = 60, .external_lex_state = 2},
  [2516] = {.lex_state = 60, .external_lex_state = 2},
  [2517] = {.lex_state = 60, .external_lex_state = 2},
  [2518] = {.lex_state = 60, .external_lex_state = 2},
  [2519] = {.lex_state = 60, .external_lex_state = 2},
  [2520] = {.lex_state = 60, .external_lex_state = 2},
  [2521] = {.lex_state = 60, .external_lex_state = 2},
  [2522] = {.lex_state = 60, .external_lex_state = 2},
  [2523] = {.lex_state = 60, .external_lex_state = 2},
  [2524] = {.lex_state = 60, .external_lex_state = 2},
  [2525] = {.lex_state = 60, .external_lex_state = 2},
  [2526] = {.lex_state = 60, .external_lex_state = 2},
  [2527] = {.lex_state = 60, .external_lex_state = 2},
  [2528] = {.lex_state = 60, .external_lex_state = 2},
  [2529] = {.lex_state = 60, .external_lex_state = 2},
  [2530] = {.lex_state = 60, .external_lex_state = 2},
  [2531] = {.lex_state = 60, .external_lex_state = 2},
  [2532] = {.lex_state = 60, .external_lex_state = 2},
  [2533] = {.lex_state = 60, .external_lex_state = 2},
  [2534] = {.lex_state = 60, .external_lex_state = 2},
  [2535] = {.lex_state = 60, .external_lex_state = 2},
  [2536] = {.lex_state = 60, .external_lex_state = 2},
  [2537] = {.lex_state = 60, .external_lex_state = 2},
  [2538] = {.lex_state = 60, .external_lex_state = 2},
  [2539] = {.lex_state = 60, .external_lex_state = 2},
  [2540] = {.lex_state = 60, .external_lex_state = 2},
  [2541] = {.lex_state = 60, .external_lex_state = 2},
  [2542] = {.lex_state = 60, .external_lex_state = 2},
  [2543] = {.lex_state = 60, .external_lex_state = 2},
  [2544] = {.lex_state = 60, .external_lex_state = 2},
  [2545] = {.lex_state = 60, .external_lex_state = 2},
  [2546] = {.lex_state = 60, .external_lex_state = 2},
  [2547] = {.lex_state = 60, .external_lex_state = 2},
  [2548] = {.lex_state = 60, .external_lex_state = 2},
  [2549] = {.lex_state = 60, .external_lex_state = 2},
  [2550] = {.lex_state = 60, .external_lex_state = 2},
  [2551] = {.lex_state = 60, .external_lex_state = 2},
  [2552] = {.lex_state = 60, .external_lex_state = 2},
  [2553] = {.lex_state = 60, .external_lex_state = 2},
  [2554] = {.lex_state = 60, .external_lex_state = 2},
  [2555] = {.lex_state = 60, .external_lex_state = 2},
  [2556] = {.lex_state = 60, .external_lex_state = 2},
  [2557] = {.lex_state = 60, .external_lex_state = 2},
  [2558] = {.lex_state = 60, .external_lex_state = 2},
  [2559] = {.lex_state = 60, .external_lex_state = 2},
  [2560] = {.lex_state = 60, .external_lex_state = 2},
  [2561] = {.lex_state = 60, .external_lex_state = 2},
  [2562] = {.lex_state = 60, .external_lex_state = 2},
  [2563] = {.lex_state = 60, .external_lex_state = 2},
  [2564] = {.lex_state = 60, .external_lex_state = 2},
  [2565] = {.lex_state = 60, .external_lex_state = 2},
  [2566] = {.lex_state = 60, .external_lex_state = 2},
  [2567] = {.lex_state = 60, .external_lex_state = 2},
  [2568] = {.lex_state = 60, .external_lex_state = 2},
  [2569] = {.lex_state = 60, .external_lex_state = 2},
  [2570] = {.lex_state = 60, .external_lex_state = 2},
  [2571] = {.lex_state = 48, .external_lex_state = 8},
  [2572] = {.lex_state = 60, .external_lex_state = 2},
  [2573] = {.lex_state = 60, .external_lex_state = 2},
  [2574] = {.lex_state = 48, .external_lex_state = 7},
  [2575] = {.lex_state = 48, .external_lex_state = 12},
  [2576] = {.lex_state = 48, .external_lex_state = 10},
  [2577] = {.lex_state = 48, .external_lex_state = 11},
  [2578] = {.lex_state = 14, .external_lex_state = 2},
  [2579] = {.lex_state = 48, .external_lex_state = 9},
  [2580] = {.lex_state = 14, .external_lex_state = 2},
  [2581] = {.lex_state = 14, .external_lex_state = 2},
  [2582] = {.lex_state = 14, .external_lex_state = 2},
  [2583] = {.lex_state = 14, .external_lex_state = 2},
  [2584] = {.lex_state = 14, .external_lex_state = 2},
  [2585] = {.lex_state = 14, .external_lex_state = 2},
  [2586] = {.lex_state = 14, .external_lex_state = 2},
  [2587] = {.lex_state = 14, .external_lex_state = 2},
  [2588] = {.lex_state = 14, .external_lex_state = 2},
  [2589] = {.lex_state = 14, .external_lex_state = 2},
  [2590] = {.lex_state = 14, .external_lex_state = 2},
  [2591] = {.lex_state = 14, .external_lex_state = 2},
  [2592] = {.lex_state = 14, .external_lex_state = 2},
  [2593] = {.lex_state = 14, .external_lex_state = 2},
  [2594] = {.lex_state = 14, .external_lex_state = 2},
  [2595] = {.lex_state = 14, .external_lex_state = 2},
  [2596] = {.lex_state = 14, .external_lex_state = 2},
  [2597] = {.lex_state = 14, .external_lex_state = 2},
  [2598] = {.lex_state = 14, .external_lex_state = 2},
  [2599] = {.lex_state = 14, .external_lex_state = 2},
  [2600] = {.lex_state = 14, .external_lex_state = 2},
  [2601] = {.lex_state = 14, .external_lex_state = 2},
  [2602] = {.lex_state = 14, .external_lex_state = 2},
  [2603] = {.lex_state = 14, .external_lex_state = 2},
  [2604] = {.lex_state = 14, .external_lex_state = 2},
  [2605] = {.lex_state = 14, .external_lex_state = 2},
  [2606] = {.lex_state = 14, .external_lex_state = 2},
  [2607] = {.lex_state = 14, .external_lex_state = 2},
  [2608] = {.lex_state = 14, .external_lex_state = 2},
  [2609] = {.lex_state = 14, .external_lex_state = 2},
  [2610] = {.lex_state = 14, .external_lex_state = 2},
  [2611] = {.lex_state = 14, .external_lex_state = 2},
  [2612] = {.lex_state = 14, .external_lex_state = 2},
  [2613] = {.lex_state = 14, .external_lex_state = 2},
  [2614] = {.lex_state = 14, .external_lex_state = 2},
  [2615] = {.lex_state = 14, .external_lex_state = 2},
  [2616] = {.lex_state = 14, .external_lex_state = 2},
  [2617] = {.lex_state = 14, .external_lex_state = 2},
  [2618] = {.lex_state = 14, .external_lex_state = 2},
  [2619] = {.lex_state = 14, .external_lex_state = 2},
  [2620] = {.lex_state = 14, .external_lex_state = 2},
  [2621] = {.lex_state = 14, .external_lex_state = 2},
  [2622] = {.lex_state = 14, .external_lex_state = 2},
  [2623] = {.lex_state = 14, .external_lex_state = 2},
  [2624] = {.lex_state = 14, .external_lex_state = 2},
  [2625] = {.lex_state = 14, .external_lex_state = 2},
  [2626] = {.lex_state = 14, .external_lex_state = 2},
  [2627] = {.lex_state = 14, .external_lex_state = 2},
  [2628] = {.lex_state = 14, .external_lex_state = 2},
  [2629] = {.lex_state = 14, .external_lex_state = 2},
  [2630] = {.lex_state = 14, .external_lex_state = 2},
  [2631] = {.lex_state = 14, .external_lex_state = 2},
  [2632] = {.lex_state = 14, .external_lex_state = 2},
  [2633] = {.lex_state = 14, .external_lex_state = 2},
  [2634] = {.lex_state = 14, .external_lex_state = 2},
  [2635] = {.lex_state = 14, .external_lex_state = 2},
  [2636] = {.lex_state = 14, .external_lex_state = 2},
  [2637] = {.lex_state = 14, .external_lex_state = 2},
  [2638] = {.lex_state = 14, .external_lex_state = 2},
  [2639] = {.lex_state = 14, .external_lex_state = 2},
  [2640] = {.lex_state = 14, .external_lex_state = 2},
  [2641] = {.lex_state = 14, .external_lex_state = 2},
  [2642] = {.lex_state = 14, .external_lex_state = 2},
  [2643] = {.lex_state = 14, .external_lex_state = 2},
  [2644] = {.lex_state = 14, .external_lex_state = 2},
  [2645] = {.lex_state = 14, .external_lex_state = 2},
  [2646] = {.lex_state = 14, .external_lex_state = 2},
  [2647] = {.lex_state = 14, .external_lex_state = 2},
  [2648] = {.lex_state = 14, .external_lex_state = 2},
  [2649] = {.lex_state = 14, .external_lex_state = 2},
  [2650] = {.lex_state = 14, .external_lex_state = 2},
  [2651] = {.lex_state = 14, .external_lex_state = 2},
  [2652] = {.lex_state = 14, .external_lex_state = 2},
  [2653] = {.lex_state = 14, .external_lex_state = 2},
  [2654] = {.lex_state = 14, .external_lex_state = 2},
  [2655] = {.lex_state = 14, .external_lex_state = 2},
  [2656] = {.lex_state = 14, .external_lex_state = 2},
  [2657] = {.lex_state = 14, .external_lex_state = 2},
  [2658] = {.lex_state = 14, .external_lex_state = 2},
  [2659] = {.lex_state = 14, .external_lex_state = 2},
  [2660] = {.lex_state = 14, .external_lex_state = 2},
  [2661] = {.lex_state = 14, .external_lex_state = 2},
  [2662] = {.lex_state = 14, .external_lex_state = 2},
  [2663] = {.lex_state = 14, .external_lex_state = 2},
  [2664] = {.lex_state = 14, .external_lex_state = 2},
  [2665] = {.lex_state = 14, .external_lex_state = 2},
  [2666] = {.lex_state = 14, .external_lex_state = 2},
  [2667] = {.lex_state = 14, .external_lex_state = 2},
  [2668] = {.lex_state = 14, .external_lex_state = 2},
  [2669] = {.lex_state = 14, .external_lex_state = 2},
  [2670] = {.lex_state = 14, .external_lex_state = 2},
  [2671] = {.lex_state = 14, .external_lex_state = 2},
  [2672] = {.lex_state = 14, .external_lex_state = 2},
  [2673] = {.lex_state = 14, .external_lex_state = 2},
  [2674] = {.lex_state = 14, .external_lex_state = 2},
  [2675] = {.lex_state = 14, .external_lex_state = 2},
  [2676] = {.lex_state = 14, .external_lex_state = 2},
  [2677] = {.lex_state = 14, .external_lex_state = 2},
  [2678] = {.lex_state = 14, .external_lex_state = 2},
  [2679] = {.lex_state = 14, .external_lex_state = 2},
  [2680] = {.lex_state = 14, .external_lex_state = 2},
  [2681] = {.lex_state = 14, .external_lex_state = 2},
  [2682] = {.lex_state = 14, .external_lex_state = 2},
  [2683] = {.lex_state = 14, .external_lex_state = 2},
  [2684] = {.lex_state = 14, .external_lex_state = 2},
  [2685] = {.lex_state = 14, .external_lex_state = 2},
  [2686] = {.lex_state = 14, .external_lex_state = 2},
  [2687] = {.lex_state = 14, .external_lex_state = 2},
  [2688] = {.lex_state = 14, .external_lex_state = 2},
  [2689] = {.lex_state = 14, .external_lex_state = 2},
  [2690] = {.lex_state = 14, .external_lex_state = 2},
  [2691] = {.lex_state = 14, .external_lex_state = 2},
  [2692] = {.lex_state = 14, .external_lex_state = 2},
  [2693] = {.lex_state = 14, .external_lex_state = 2},
  [2694] = {.lex_state = 14, .external_lex_state = 2},
  [2695] = {.lex_state = 14, .external_lex_state = 2},
  [2696] = {.lex_state = 14, .external_lex_state = 2},
  [2697] = {.lex_state = 14, .external_lex_state = 2},
  [2698] = {.lex_state = 14, .external_lex_state = 2},
  [2699] = {.lex_state = 14, .external_lex_state = 2},
  [2700] = {.lex_state = 14, .external_lex_state = 2},
  [2701] = {.lex_state = 14, .external_lex_state = 2},
  [2702] = {.lex_state = 14, .external_lex_state = 2},
  [2703] = {.lex_state = 14, .external_lex_state = 2},
  [2704] = {.lex_state = 14, .external_lex_state = 2},
  [2705] = {.lex_state = 14, .external_lex_state = 2},
  [2706] = {.lex_state = 14, .external_lex_state = 2},
  [2707] = {.lex_state = 14, .external_lex_state = 2},
  [2708] = {.lex_state = 14, .external_lex_state = 2},
  [2709] = {.lex_state = 14, .external_lex_state = 2},
  [2710] = {.lex_state = 14, .external_lex_state = 2},
  [2711] = {.lex_state = 14, .external_lex_state = 2},
  [2712] = {.lex_state = 14, .external_lex_state = 2},
  [2713] = {.lex_state = 14, .external_lex_state = 2},
  [2714] = {.lex_state = 14, .external_lex_state = 2},
  [2715] = {.lex_state = 14, .external_lex_state = 2},
  [2716] = {.lex_state = 14, .external_lex_state = 2},
  [2717] = {.lex_state = 14, .external_lex_state = 2},
  [2718] = {.lex_state = 14, .external_lex_state = 2},
  [2719] = {.lex_state = 14, .external_lex_state = 2},
  [2720] = {.lex_state = 14, .external_lex_state = 2},
  [2721] = {.lex_state = 14, .external_lex_state = 2},
  [2722] = {.lex_state = 14, .external_lex_state = 2},
  [2723] = {.lex_state = 14, .external_lex_state = 2},
  [2724] = {.lex_state = 14, .external_lex_state = 2},
  [2725] = {.lex_state = 14, .external_lex_state = 2},
  [2726] = {.lex_state = 14, .external_lex_state = 2},
  [2727] = {.lex_state = 14, .external_lex_state = 2},
  [2728] = {.lex_state = 14, .external_lex_state = 2},
  [2729] = {.lex_state = 14, .external_lex_state = 2},
  [2730] = {.lex_state = 14, .external_lex_state = 2},
  [2731] = {.lex_state = 14, .external_lex_state = 2},
  [2732] = {.lex_state = 14, .external_lex_state = 2},
  [2733] = {.lex_state = 14, .external_lex_state = 2},
  [2734] = {.lex_state = 14, .external_lex_state = 2},
  [2735] = {.lex_state = 14, .external_lex_state = 2},
  [2736] = {.lex_state = 14, .external_lex_state = 2},
  [2737] = {.lex_state = 14, .external_lex_state = 2},
  [2738] = {.lex_state = 14, .external_lex_state = 2},
  [2739] = {.lex_state = 14, .external_lex_state = 2},
  [2740] = {.lex_state = 14, .external_lex_state = 2},
  [2741] = {.lex_state = 14, .external_lex_state = 2},
  [2742] = {.lex_state = 14, .external_lex_state = 2},
  [2743] = {.lex_state = 14, .external_lex_state = 2},
  [2744] = {.lex_state = 14, .external_lex_state = 2},
  [2745] = {.lex_state = 14, .external_lex_state = 2},
  [2746] = {.lex_state = 14, .external_lex_state = 2},
  [2747] = {.lex_state = 14, .external_lex_state = 2},
  [2748] = {.lex_state = 14, .external_lex_state = 2},
  [2749] = {.lex_state = 14, .external_lex_state = 2},
  [2750] = {.lex_state = 14, .external_lex_state = 2},
  [2751] = {.lex_state = 14, .external_lex_state = 2},
  [2752] = {.lex_state = 14, .external_lex_state = 2},
  [2753] = {.lex_state = 14, .external_lex_state = 2},
  [2754] = {.lex_state = 14, .external_lex_state = 2},
  [2755] = {.lex_state = 14, .external_lex_state = 2},
  [2756] = {.lex_state = 14, .external_lex_state = 2},
  [2757] = {.lex_state = 14, .external_lex_state = 2},
  [2758] = {.lex_state = 14, .external_lex_state = 2},
  [2759] = {.lex_state = 14, .external_lex_state = 2},
  [2760] = {.lex_state = 14, .external_lex_state = 2},
  [2761] = {.lex_state = 14, .external_lex_state = 2},
  [2762] = {.lex_state = 14, .external_lex_state = 2},
  [2763] = {.lex_state = 14, .external_lex_state = 2},
  [2764] = {.lex_state = 14, .external_lex_state = 2},
  [2765] = {.lex_state = 14, .external_lex_state = 2},
  [2766] = {.lex_state = 14, .external_lex_state = 2},
  [2767] = {.lex_state = 14, .external_lex_state = 2},
  [2768] = {.lex_state = 14, .external_lex_state = 2},
  [2769] = {.lex_state = 14, .external_lex_state = 2},
  [2770] = {.lex_state = 14, .external_lex_state = 2},
  [2771] = {.lex_state = 14, .external_lex_state = 2},
  [2772] = {.lex_state = 14, .external_lex_state = 2},
  [2773] = {.lex_state = 14, .external_lex_state = 2},
  [2774] = {.lex_state = 14, .external_lex_state = 2},
  [2775] = {.lex_state = 14, .external_lex_state = 2},
  [2776] = {.lex_state = 14, .external_lex_state = 2},
  [2777] = {.lex_state = 14, .external_lex_state = 2},
  [2778] = {.lex_state = 14, .external_lex_state = 2},
  [2779] = {.lex_state = 14, .external_lex_state = 2},
  [2780] = {.lex_state = 14, .external_lex_state = 2},
  [2781] = {.lex_state = 14, .external_lex_state = 2},
  [2782] = {.lex_state = 14, .external_lex_state = 2},
  [2783] = {.lex_state = 14, .external_lex_state = 2},
  [2784] = {.lex_state = 14, .external_lex_state = 2},
  [2785] = {.lex_state = 14, .external_lex_state = 2},
  [2786] = {.lex_state = 14, .external_lex_state = 2},
  [2787] = {.lex_state = 14, .external_lex_state = 2},
  [2788] = {.lex_state = 14, .external_lex_state = 2},
  [2789] = {.lex_state = 14, .external_lex_state = 2},
  [2790] = {.lex_state = 14, .external_lex_state = 2},
  [2791] = {.lex_state = 14, .external_lex_state = 2},
  [2792] = {.lex_state = 14, .external_lex_state = 2},
  [2793] = {.lex_state = 14, .external_lex_state = 2},
  [2794] = {.lex_state = 14, .external_lex_state = 2},
  [2795] = {.lex_state = 14, .external_lex_state = 2},
  [2796] = {.lex_state = 14, .external_lex_state = 2},
  [2797] = {.lex_state = 14, .external_lex_state = 2},
  [2798] = {.lex_state = 14, .external_lex_state = 2},
  [2799] = {.lex_state = 14, .external_lex_state = 2},
  [2800] = {.lex_state = 14, .external_lex_state = 2},
  [2801] = {.lex_state = 14, .external_lex_state = 2},
  [2802] = {.lex_state = 14, .external_lex_state = 2},
  [2803] = {.lex_state = 14, .external_lex_state = 2},
  [2804] = {.lex_state = 14, .external_lex_state = 2},
  [2805] = {.lex_state = 14, .external_lex_state = 2},
  [2806] = {.lex_state = 14, .external_lex_state = 2},
  [2807] = {.lex_state = 14, .external_lex_state = 2},
  [2808] = {.lex_state = 14, .external_lex_state = 2},
  [2809] = {.lex_state = 14, .external_lex_state = 2},
  [2810] = {.lex_state = 14, .external_lex_state = 2},
  [2811] = {.lex_state = 14, .external_lex_state = 2},
  [2812] = {.lex_state = 14, .external_lex_state = 2},
  [2813] = {.lex_state = 14, .external_lex_state = 2},
  [2814] = {.lex_state = 14, .external_lex_state = 2},
  [2815] = {.lex_state = 14, .external_lex_state = 2},
  [2816] = {.lex_state = 14, .external_lex_state = 2},
  [2817] = {.lex_state = 14, .external_lex_state = 2},
  [2818] = {.lex_state = 14, .external_lex_state = 2},
  [2819] = {.lex_state = 14, .external_lex_state = 2},
  [2820] = {.lex_state = 14, .external_lex_state = 2},
  [2821] = {.lex_state = 14, .external_lex_state = 2},
  [2822] = {.lex_state = 14, .external_lex_state = 2},
  [2823] = {.lex_state = 14, .external_lex_state = 2},
  [2824] = {.lex_state = 14, .external_lex_state = 2},
  [2825] = {.lex_state = 14, .external_lex_state = 2},
  [2826] = {.lex_state = 14, .external_lex_state = 2},
  [2827] = {.lex_state = 14, .external_lex_state = 2},
  [2828] = {.lex_state = 14, .external_lex_state = 2},
  [2829] = {.lex_state = 14, .external_lex_state = 2},
  [2830] = {.lex_state = 14, .external_lex_state = 2},
  [2831] = {.lex_state = 14, .external_lex_state = 2},
  [2832] = {.lex_state = 14, .external_lex_state = 2},
  [2833] = {.lex_state = 14, .external_lex_state = 2},
  [2834] = {.lex_state = 14, .external_lex_state = 2},
  [2835] = {.lex_state = 14, .external_lex_state = 2},
  [2836] = {.lex_state = 14, .external_lex_state = 2},
  [2837] = {.lex_state = 14, .external_lex_state = 2},
  [2838] = {.lex_state = 14, .external_lex_state = 2},
  [2839] = {.lex_state = 14, .external_lex_state = 2},
  [2840] = {.lex_state = 14, .external_lex_state = 2},
  [2841] = {.lex_state = 14, .external_lex_state = 2},
  [2842] = {.lex_state = 14, .external_lex_state = 2},
  [2843] = {.lex_state = 14, .external_lex_state = 2},
  [2844] = {.lex_state = 14, .external_lex_state = 2},
  [2845] = {.lex_state = 14, .external_lex_state = 2},
  [2846] = {.lex_state = 14, .external_lex_state = 2},
  [2847] = {.lex_state = 14, .external_lex_state = 2},
  [2848] = {.lex_state = 14, .external_lex_state = 2},
  [2849] = {.lex_state = 14, .external_lex_state = 2},
  [2850] = {.lex_state = 14, .external_lex_state = 2},
  [2851] = {.lex_state = 14, .external_lex_state = 2},
  [2852] = {.lex_state = 14, .external_lex_state = 2},
  [2853] = {.lex_state = 14, .external_lex_state = 2},
  [2854] = {.lex_state = 14, .external_lex_state = 2},
  [2855] = {.lex_state = 14, .external_lex_state = 2},
  [2856] = {.lex_state = 14, .external_lex_state = 2},
  [2857] = {.lex_state = 14, .external_lex_state = 2},
  [2858] = {.lex_state = 14, .external_lex_state = 2},
  [2859] = {.lex_state = 14, .external_lex_state = 2},
  [2860] = {.lex_state = 14, .external_lex_state = 2},
  [2861] = {.lex_state = 14, .external_lex_state = 2},
  [2862] = {.lex_state = 14, .external_lex_state = 2},
  [2863] = {.lex_state = 14, .external_lex_state = 2},
  [2864] = {.lex_state = 14, .external_lex_state = 2},
  [2865] = {.lex_state = 14, .external_lex_state = 2},
  [2866] = {.lex_state = 14, .external_lex_state = 2},
  [2867] = {.lex_state = 14, .external_lex_state = 2},
  [2868] = {.lex_state = 14, .external_lex_state = 2},
  [2869] = {.lex_state = 14, .external_lex_state = 2},
  [2870] = {.lex_state = 14, .external_lex_state = 2},
  [2871] = {.lex_state = 14, .external_lex_state = 2},
  [2872] = {.lex_state = 14, .external_lex_state = 2},
  [2873] = {.lex_state = 14, .external_lex_state = 2},
  [2874] = {.lex_state = 14, .external_lex_state = 2},
  [2875] = {.lex_state = 14, .external_lex_state = 2},
  [2876] = {.lex_state = 14, .external_lex_state = 2},
  [2877] = {.lex_state = 14, .external_lex_state = 2},
  [2878] = {.lex_state = 14, .external_lex_state = 2},
  [2879] = {.lex_state = 14, .external_lex_state = 2},
  [2880] = {.lex_state = 14, .external_lex_state = 2},
  [2881] = {.lex_state = 14, .external_lex_state = 2},
  [2882] = {.lex_state = 14, .external_lex_state = 2},
  [2883] = {.lex_state = 14, .external_lex_state = 2},
  [2884] = {.lex_state = 14, .external_lex_state = 2},
  [2885] = {.lex_state = 14, .external_lex_state = 2},
  [2886] = {.lex_state = 14, .external_lex_state = 2},
  [2887] = {.lex_state = 14, .external_lex_state = 2},
  [2888] = {.lex_state = 14, .external_lex_state = 2},
  [2889] = {.lex_state = 14, .external_lex_state = 2},
  [2890] = {.lex_state = 14, .external_lex_state = 2},
  [2891] = {.lex_state = 14, .external_lex_state = 2},
  [2892] = {.lex_state = 14, .external_lex_state = 2},
  [2893] = {.lex_state = 14, .external_lex_state = 2},
  [2894] = {.lex_state = 14, .external_lex_state = 2},
  [2895] = {.lex_state = 14, .external_lex_state = 2},
  [2896] = {.lex_state = 48, .external_lex_state = 14},
  [2897] = {.lex_state = 14, .external_lex_state = 2},
  [2898] = {.lex_state = 14, .external_lex_state = 2},
  [2899] = {.lex_state = 14, .external_lex_state = 2},
  [2900] = {.lex_state = 14, .external_lex_state = 2},
  [2901] = {.lex_state = 14, .external_lex_state = 2},
  [2902] = {.lex_state = 14, .external_lex_state = 2},
  [2903] = {.lex_state = 14, .external_lex_state = 2},
  [2904] = {.lex_state = 14, .external_lex_state = 2},
  [2905] = {.lex_state = 14, .external_lex_state = 2},
  [2906] = {.lex_state = 14, .external_lex_state = 2},
  [2907] = {.lex_state = 14, .external_lex_state = 2},
  [2908] = {.lex_state = 14, .external_lex_state = 2},
  [2909] = {.lex_state = 14, .external_lex_state = 2},
  [2910] = {.lex_state = 14, .external_lex_state = 2},
  [2911] = {.lex_state = 14, .external_lex_state = 2},
  [2912] = {.lex_state = 14, .external_lex_state = 2},
  [2913] = {.lex_state = 14, .external_lex_state = 2},
  [2914] = {.lex_state = 14, .external_lex_state = 2},
  [2915] = {.lex_state = 14, .external_lex_state = 2},
  [2916] = {.lex_state = 14, .external_lex_state = 2},
  [2917] = {.lex_state = 14, .external_lex_state = 2},
  [2918] = {.lex_state = 14, .external_lex_state = 2},
  [2919] = {.lex_state = 14, .external_lex_state = 2},
  [2920] = {.lex_state = 14, .external_lex_state = 2},
  [2921] = {.lex_state = 14, .external_lex_state = 2},
  [2922] = {.lex_state = 14, .external_lex_state = 2},
  [2923] = {.lex_state = 14, .external_lex_state = 2},
  [2924] = {.lex_state = 14, .external_lex_state = 2},
  [2925] = {.lex_state = 14, .external_lex_state = 2},
  [2926] = {.lex_state = 48, .external_lex_state = 15},
  [2927] = {.lex_state = 14, .external_lex_state = 2},
  [2928] = {.lex_state = 14, .external_lex_state = 2},
  [2929] = {.lex_state = 14, .external_lex_state = 2},
  [2930] = {.lex_state = 14, .external_lex_state = 2},
  [2931] = {.lex_state = 14, .external_lex_state = 2},
  [2932] = {.lex_state = 14, .external_lex_state = 2},
  [2933] = {.lex_state = 14, .external_lex_state = 2},
  [2934] = {.lex_state = 14, .external_lex_state = 2},
  [2935] = {.lex_state = 14, .external_lex_state = 2},
  [2936] = {.lex_state = 14, .external_lex_state = 2},
  [2937] = {.lex_state = 14, .external_lex_state = 2},
  [2938] = {.lex_state = 14, .external_lex_state = 2},
  [2939] = {.lex_state = 14, .external_lex_state = 2},
  [2940] = {.lex_state = 14, .external_lex_state = 2},
  [2941] = {.lex_state = 14, .external_lex_state = 2},
  [2942] = {.lex_state = 14, .external_lex_state = 2},
  [2943] = {.lex_state = 14, .external_lex_state = 2},
  [2944] = {.lex_state = 14, .external_lex_state = 2},
  [2945] = {.lex_state = 14, .external_lex_state = 2},
  [2946] = {.lex_state = 14, .external_lex_state = 2},
  [2947] = {.lex_state = 14, .external_lex_state = 2},
  [2948] = {.lex_state = 14, .external_lex_state = 2},
  [2949] = {.lex_state = 14, .external_lex_state = 2},
  [2950] = {.lex_state = 14, .external_lex_state = 2},
  [2951] = {.lex_state = 14, .external_lex_state = 2},
  [2952] = {.lex_state = 14, .external_lex_state = 2},
  [2953] = {.lex_state = 14, .external_lex_state = 2},
  [2954] = {.lex_state = 14, .external_lex_state = 2},
  [2955] = {.lex_state = 14, .external_lex_state = 2},
  [2956] = {.lex_state = 14, .external_lex_state = 2},
  [2957] = {.lex_state = 14, .external_lex_state = 2},
  [2958] = {.lex_state = 14, .external_lex_state = 2},
  [2959] = {.lex_state = 14, .external_lex_state = 2},
  [2960] = {.lex_state = 14, .external_lex_state = 2},
  [2961] = {.lex_state = 14, .external_lex_state = 2},
  [2962] = {.lex_state = 14, .external_lex_state = 2},
  [2963] = {.lex_state = 14, .external_lex_state = 2},
  [2964] = {.lex_state = 14, .external_lex_state = 2},
  [2965] = {.lex_state = 48, .external_lex_state = 13},
  [2966] = {.lex_state = 14, .external_lex_state = 2},
  [2967] = {.lex_state = 14, .external_lex_state = 2},
  [2968] = {.lex_state = 14, .external_lex_state = 2},
  [2969] = {.lex_state = 14, .external_lex_state = 2},
  [2970] = {.lex_state = 14, .external_lex_state = 2},
  [2971] = {.lex_state = 14, .external_lex_state = 2},
  [2972] = {.lex_state = 14, .external_lex_state = 2},
  [2973] = {.lex_state = 14, .external_lex_state = 2},
  [2974] = {.lex_state = 14, .external_lex_state = 2},
  [2975] = {.lex_state = 14, .external_lex_state = 2},
  [2976] = {.lex_state = 14, .external_lex_state = 2},
  [2977] = {.lex_state = 14, .external_lex_state = 2},
  [2978] = {.lex_state = 14, .external_lex_state = 2},
  [2979] = {.lex_state = 14, .external_lex_state = 2},
  [2980] = {.lex_state = 14, .external_lex_state = 2},
  [2981] = {.lex_state = 14, .external_lex_state = 2},
  [2982] = {.lex_state = 14, .external_lex_state = 2},
  [2983] = {.lex_state = 14, .external_lex_state = 2},
  [2984] = {.lex_state = 14, .external_lex_state = 2},
  [2985] = {.lex_state = 14, .external_lex_state = 2},
  [2986] = {.lex_state = 14, .external_lex_state = 2},
  [2987] = {.lex_state = 14, .external_lex_state = 2},
  [2988] = {.lex_state = 14, .external_lex_state = 2},
  [2989] = {.lex_state = 14, .external_lex_state = 2},
  [2990] = {.lex_state = 14, .external_lex_state = 2},
  [2991] = {.lex_state = 14, .external_lex_state = 2},
  [2992] = {.lex_state = 48, .external_lex_state = 6},
  [2993] = {.lex_state = 14, .external_lex_state = 2},
  [2994] = {.lex_state = 14, .external_lex_state = 2},
  [2995] = {.lex_state = 14, .external_lex_state = 2},
  [2996] = {.lex_state = 14, .external_lex_state = 2},
  [2997] = {.lex_state = 14, .external_lex_state = 2},
  [2998] = {.lex_state = 14, .external_lex_state = 2},
  [2999] = {.lex_state = 14, .external_lex_state = 2},
  [3000] = {.lex_state = 14, .external_lex_state = 2},
  [3001] = {.lex_state = 14, .external_lex_state = 2},
  [3002] = {.lex_state = 14, .external_lex_state = 2},
  [3003] = {.lex_state = 14, .external_lex_state = 2},
  [3004] = {.lex_state = 14, .external_lex_state = 2},
  [3005] = {.lex_state = 14, .external_lex_state = 2},
  [3006] = {.lex_state = 14, .external_lex_state = 2},
  [3007] = {.lex_state = 14, .external_lex_state = 2},
  [3008] = {.lex_state = 14, .external_lex_state = 2},
  [3009] = {.lex_state = 14, .external_lex_state = 2},
  [3010] = {.lex_state = 14, .external_lex_state = 2},
  [3011] = {.lex_state = 14, .external_lex_state = 2},
  [3012] = {.lex_state = 14, .external_lex_state = 2},
  [3013] = {.lex_state = 14, .external_lex_state = 2},
  [3014] = {.lex_state = 14, .external_lex_state = 2},
  [3015] = {.lex_state = 14, .external_lex_state = 2},
  [3016] = {.lex_state = 14, .external_lex_state = 2},
  [3017] = {.lex_state = 14, .external_lex_state = 2},
  [3018] = {.lex_state = 14, .external_lex_state = 2},
  [3019] = {.lex_state = 14, .external_lex_state = 2},
  [3020] = {.lex_state = 14, .external_lex_state = 2},
  [3021] = {.lex_state = 14, .external_lex_state = 2},
  [3022] = {.lex_state = 14, .external_lex_state = 2},
  [3023] = {.lex_state = 14, .external_lex_state = 2},
  [3024] = {.lex_state = 14, .external_lex_state = 2},
  [3025] = {.lex_state = 14, .external_lex_state = 2},
  [3026] = {.lex_state = 14, .external_lex_state = 2},
  [3027] = {.lex_state = 14, .external_lex_state = 2},
  [3028] = {.lex_state = 14, .external_lex_state = 2},
  [3029] = {.lex_state = 14, .external_lex_state = 2},
  [3030] = {.lex_state = 14, .external_lex_state = 2},
  [3031] = {.lex_state = 14, .external_lex_state = 2},
  [3032] = {.lex_state = 14, .external_lex_state = 2},
  [3033] = {.lex_state = 14, .external_lex_state = 2},
  [3034] = {.lex_state = 14, .external_lex_state = 2},
  [3035] = {.lex_state = 14, .external_lex_state = 2},
  [3036] = {.lex_state = 14, .external_lex_state = 2},
  [3037] = {.lex_state = 14, .external_lex_state = 2},
  [3038] = {.lex_state = 14, .external_lex_state = 2},
  [3039] = {.lex_state = 14, .external_lex_state = 2},
  [3040] = {.lex_state = 14, .external_lex_state = 2},
  [3041] = {.lex_state = 14, .external_lex_state = 2},
  [3042] = {.lex_state = 14, .external_lex_state = 2},
  [3043] = {.lex_state = 14, .external_lex_state = 2},
  [3044] = {.lex_state = 14, .external_lex_state = 2},
  [3045] = {.lex_state = 14, .external_lex_state = 2},
  [3046] = {.lex_state = 14, .external_lex_state = 2},
  [3047] = {.lex_state = 14, .external_lex_state = 2},
  [3048] = {.lex_state = 14, .external_lex_state = 2},
  [3049] = {.lex_state = 14, .external_lex_state = 2},
  [3050] = {.lex_state = 14, .external_lex_state = 2},
  [3051] = {.lex_state = 14, .external_lex_state = 2},
  [3052] = {.lex_state = 14, .external_lex_state = 2},
  [3053] = {.lex_state = 14, .external_lex_state = 2},
  [3054] = {.lex_state = 14, .external_lex_state = 2},
  [3055] = {.lex_state = 14, .external_lex_state = 2},
  [3056] = {.lex_state = 14, .external_lex_state = 2},
  [3057] = {.lex_state = 14, .external_lex_state = 2},
  [3058] = {.lex_state = 14, .external_lex_state = 2},
  [3059] = {.lex_state = 14, .external_lex_state = 2},
  [3060] = {.lex_state = 14, .external_lex_state = 2},
  [3061] = {.lex_state = 14, .external_lex_state = 2},
  [3062] = {.lex_state = 14, .external_lex_state = 2},
  [3063] = {.lex_state = 14, .external_lex_state = 2},
  [3064] = {.lex_state = 14, .external_lex_state = 2},
  [3065] = {.lex_state = 14, .external_lex_state = 2},
  [3066] = {.lex_state = 14, .external_lex_state = 2},
  [3067] = {.lex_state = 14, .external_lex_state = 2},
  [3068] = {.lex_state = 14, .external_lex_state = 2},
  [3069] = {.lex_state = 14, .external_lex_state = 2},
  [3070] = {.lex_state = 14, .external_lex_state = 2},
  [3071] = {.lex_state = 14, .external_lex_state = 2},
  [3072] = {.lex_state = 14, .external_lex_state = 2},
  [3073] = {.lex_state = 14, .external_lex_state = 2},
  [3074] = {.lex_state = 14, .external_lex_state = 2},
  [3075] = {.lex_state = 14, .external_lex_state = 2},
  [3076] = {.lex_state = 14, .external_lex_state = 2},
  [3077] = {.lex_state = 14, .external_lex_state = 2},
  [3078] = {.lex_state = 14, .external_lex_state = 2},
  [3079] = {.lex_state = 14, .external_lex_state = 2},
  [3080] = {.lex_state = 14, .external_lex_state = 2},
  [3081] = {.lex_state = 14, .external_lex_state = 2},
  [3082] = {.lex_state = 14, .external_lex_state = 2},
  [3083] = {.lex_state = 14, .external_lex_state = 2},
  [3084] = {.lex_state = 14, .external_lex_state = 2},
  [3085] = {.lex_state = 14, .external_lex_state = 2},
  [3086] = {.lex_state = 14, .external_lex_state = 2},
  [3087] = {.lex_state = 14, .external_lex_state = 2},
  [3088] = {.lex_state = 14, .external_lex_state = 2},
  [3089] = {.lex_state = 14, .external_lex_state = 2},
  [3090] = {.lex_state = 14, .external_lex_state = 2},
  [3091] = {.lex_state = 14, .external_lex_state = 2},
  [3092] = {.lex_state = 14, .external_lex_state = 2},
  [3093] = {.lex_state = 14, .external_lex_state = 2},
  [3094] = {.lex_state = 14, .external_lex_state = 2},
  [3095] = {.lex_state = 14, .external_lex_state = 2},
  [3096] = {.lex_state = 14, .external_lex_state = 2},
  [3097] = {.lex_state = 14, .external_lex_state = 2},
  [3098] = {.lex_state = 14, .external_lex_state = 2},
  [3099] = {.lex_state = 14, .external_lex_state = 2},
  [3100] = {.lex_state = 14, .external_lex_state = 2},
  [3101] = {.lex_state = 14, .external_lex_state = 2},
  [3102] = {.lex_state = 14, .external_lex_state = 2},
  [3103] = {.lex_state = 14, .external_lex_state = 2},
  [3104] = {.lex_state = 14, .external_lex_state = 2},
  [3105] = {.lex_state = 14, .external_lex_state = 2},
  [3106] = {.lex_state = 14, .external_lex_state = 2},
  [3107] = {.lex_state = 14, .external_lex_state = 2},
  [3108] = {.lex_state = 14, .external_lex_state = 2},
  [3109] = {.lex_state = 14, .external_lex_state = 2},
  [3110] = {.lex_state = 14, .external_lex_state = 2},
  [3111] = {.lex_state = 14, .external_lex_state = 2},
  [3112] = {.lex_state = 14, .external_lex_state = 2},
  [3113] = {.lex_state = 14, .external_lex_state = 2},
  [3114] = {.lex_state = 14, .external_lex_state = 2},
  [3115] = {.lex_state = 14, .external_lex_state = 2},
  [3116] = {.lex_state = 14, .external_lex_state = 2},
  [3117] = {.lex_state = 14, .external_lex_state = 2},
  [3118] = {.lex_state = 14, .external_lex_state = 2},
  [3119] = {.lex_state = 14, .external_lex_state = 2},
  [3120] = {.lex_state = 14, .external_lex_state = 2},
  [3121] = {.lex_state = 14, .external_lex_state = 2},
  [3122] = {.lex_state = 14, .external_lex_state = 2},
  [3123] = {.lex_state = 14, .external_lex_state = 2},
  [3124] = {.lex_state = 48, .external_lex_state = 18},
  [3125] = {.lex_state = 14, .external_lex_state = 2},
  [3126] = {.lex_state = 14, .external_lex_state = 2},
  [3127] = {.lex_state = 14, .external_lex_state = 2},
  [3128] = {.lex_state = 14, .external_lex_state = 2},
  [3129] = {.lex_state = 14, .external_lex_state = 2},
  [3130] = {.lex_state = 14, .external_lex_state = 2},
  [3131] = {.lex_state = 14, .external_lex_state = 2},
  [3132] = {.lex_state = 14, .external_lex_state = 2},
  [3133] = {.lex_state = 14, .external_lex_state = 2},
  [3134] = {.lex_state = 14, .external_lex_state = 2},
  [3135] = {.lex_state = 14, .external_lex_state = 2},
  [3136] = {.lex_state = 14, .external_lex_state = 2},
  [3137] = {.lex_state = 14, .external_lex_state = 2},
  [3138] = {.lex_state = 14, .external_lex_state = 2},
  [3139] = {.lex_state = 14, .external_lex_state = 2},
  [3140] = {.lex_state = 14, .external_lex_state = 2},
  [3141] = {.lex_state = 14, .external_lex_state = 2},
  [3142] = {.lex_state = 14, .external_lex_state = 2},
  [3143] = {.lex_state = 14, .external_lex_state = 2},
  [3144] = {.lex_state = 14, .external_lex_state = 2},
  [3145] = {.lex_state = 14, .external_lex_state = 2},
  [3146] = {.lex_state = 14, .external_lex_state = 2},
  [3147] = {.lex_state = 14, .external_lex_state = 2},
  [3148] = {.lex_state = 14, .external_lex_state = 2},
  [3149] = {.lex_state = 14, .external_lex_state = 2},
  [3150] = {.lex_state = 14, .external_lex_state = 2},
  [3151] = {.lex_state = 14, .external_lex_state = 2},
  [3152] = {.lex_state = 14, .external_lex_state = 2},
  [3153] = {.lex_state = 14, .external_lex_state = 2},
  [3154] = {.lex_state = 14, .external_lex_state = 2},
  [3155] = {.lex_state = 14, .external_lex_state = 2},
  [3156] = {.lex_state = 14, .external_lex_state = 2},
  [3157] = {.lex_state = 14, .external_lex_state = 2},
  [3158] = {.lex_state = 14, .external_lex_state = 2},
  [3159] = {.lex_state = 14, .external_lex_state = 2},
  [3160] = {.lex_state = 14, .external_lex_state = 2},
  [3161] = {.lex_state = 14, .external_lex_state = 2},
  [3162] = {.lex_state = 14, .external_lex_state = 2},
  [3163] = {.lex_state = 14, .external_lex_state = 2},
  [3164] = {.lex_state = 14, .external_lex_state = 2},
  [3165] = {.lex_state = 14, .external_lex_state = 2},
  [3166] = {.lex_state = 14, .external_lex_state = 2},
  [3167] = {.lex_state = 14, .external_lex_state = 2},
  [3168] = {.lex_state = 14, .external_lex_state = 2},
  [3169] = {.lex_state = 14, .external_lex_state = 2},
  [3170] = {.lex_state = 14, .external_lex_state = 2},
  [3171] = {.lex_state = 14, .external_lex_state = 2},
  [3172] = {.lex_state = 14, .external_lex_state = 2},
  [3173] = {.lex_state = 14, .external_lex_state = 2},
  [3174] = {.lex_state = 14, .external_lex_state = 2},
  [3175] = {.lex_state = 14, .external_lex_state = 2},
  [3176] = {.lex_state = 14, .external_lex_state = 2},
  [3177] = {.lex_state = 14, .external_lex_state = 2},
  [3178] = {.lex_state = 14, .external_lex_state = 2},
  [3179] = {.lex_state = 14, .external_lex_state = 2},
  [3180] = {.lex_state = 14, .external_lex_state = 2},
  [3181] = {.lex_state = 14, .external_lex_state = 2},
  [3182] = {.lex_state = 14, .external_lex_state = 2},
  [3183] = {.lex_state = 14, .external_lex_state = 2},
  [3184] = {.lex_state = 48, .external_lex_state = 7},
  [3185] = {.lex_state = 14, .external_lex_state = 2},
  [3186] = {.lex_state = 14, .external_lex_state = 2},
  [3187] = {.lex_state = 14, .external_lex_state = 2},
  [3188] = {.lex_state = 14, .external_lex_state = 2},
  [3189] = {.lex_state = 14, .external_lex_state = 2},
  [3190] = {.lex_state = 14, .external_lex_state = 2},
  [3191] = {.lex_state = 14, .external_lex_state = 2},
  [3192] = {.lex_state = 14, .external_lex_state = 2},
  [3193] = {.lex_state = 14, .external_lex_state = 2},
  [3194] = {.lex_state = 14, .external_lex_state = 2},
  [3195] = {.lex_state = 14, .external_lex_state = 2},
  [3196] = {.lex_state = 14, .external_lex_state = 2},
  [3197] = {.lex_state = 14, .external_lex_state = 2},
  [3198] = {.lex_state = 14, .external_lex_state = 2},
  [3199] = {.lex_state = 14, .external_lex_state = 2},
  [3200] = {.lex_state = 14, .external_lex_state = 2},
  [3201] = {.lex_state = 14, .external_lex_state = 2},
  [3202] = {.lex_state = 14, .external_lex_state = 2},
  [3203] = {.lex_state = 14, .external_lex_state = 2},
  [3204] = {.lex_state = 14, .external_lex_state = 2},
  [3205] = {.lex_state = 14, .external_lex_state = 2},
  [3206] = {.lex_state = 14, .external_lex_state = 2},
  [3207] = {.lex_state = 14, .external_lex_state = 2},
  [3208] = {.lex_state = 14, .external_lex_state = 2},
  [3209] = {.lex_state = 14, .external_lex_state = 2},
  [3210] = {.lex_state = 14, .external_lex_state = 2},
  [3211] = {.lex_state = 14, .external_lex_state = 2},
  [3212] = {.lex_state = 14, .external_lex_state = 2},
  [3213] = {.lex_state = 14, .external_lex_state = 2},
  [3214] = {.lex_state = 14, .external_lex_state = 2},
  [3215] = {.lex_state = 14, .external_lex_state = 2},
  [3216] = {.lex_state = 14, .external_lex_state = 2},
  [3217] = {.lex_state = 14, .external_lex_state = 2},
  [3218] = {.lex_state = 14, .external_lex_state = 2},
  [3219] = {.lex_state = 14, .external_lex_state = 2},
  [3220] = {.lex_state = 14, .external_lex_state = 2},
  [3221] = {.lex_state = 14, .external_lex_state = 2},
  [3222] = {.lex_state = 14, .external_lex_state = 2},
  [3223] = {.lex_state = 14, .external_lex_state = 2},
  [3224] = {.lex_state = 14, .external_lex_state = 2},
  [3225] = {.lex_state = 14, .external_lex_state = 2},
  [3226] = {.lex_state = 14, .external_lex_state = 2},
  [3227] = {.lex_state = 14, .external_lex_state = 2},
  [3228] = {.lex_state = 14, .external_lex_state = 2},
  [3229] = {.lex_state = 14, .external_lex_state = 2},
  [3230] = {.lex_state = 14, .external_lex_state = 2},
  [3231] = {.lex_state = 14, .external_lex_state = 2},
  [3232] = {.lex_state = 14, .external_lex_state = 2},
  [3233] = {.lex_state = 14, .external_lex_state = 2},
  [3234] = {.lex_state = 14, .external_lex_state = 2},
  [3235] = {.lex_state = 14, .external_lex_state = 2},
  [3236] = {.lex_state = 14, .external_lex_state = 2},
  [3237] = {.lex_state = 14, .external_lex_state = 2},
  [3238] = {.lex_state = 14, .external_lex_state = 2},
  [3239] = {.lex_state = 14, .external_lex_state = 2},
  [3240] = {.lex_state = 14, .external_lex_state = 2},
  [3241] = {.lex_state = 14, .external_lex_state = 2},
  [3242] = {.lex_state = 14, .external_lex_state = 2},
  [3243] = {.lex_state = 14, .external_lex_state = 2},
  [3244] = {.lex_state = 14, .external_lex_state = 2},
  [3245] = {.lex_state = 14, .external_lex_state = 2},
  [3246] = {.lex_state = 14, .external_lex_state = 2},
  [3247] = {.lex_state = 14, .external_lex_state = 2},
  [3248] = {.lex_state = 14, .external_lex_state = 2},
  [3249] = {.lex_state = 14, .external_lex_state = 2},
  [3250] = {.lex_state = 14, .external_lex_state = 2},
  [3251] = {.lex_state = 14, .external_lex_state = 2},
  [3252] = {.lex_state = 14, .external_lex_state = 2},
  [3253] = {.lex_state = 14, .external_lex_state = 2},
  [3254] = {.lex_state = 14, .external_lex_state = 2},
  [3255] = {.lex_state = 14, .external_lex_state = 2},
  [3256] = {.lex_state = 14, .external_lex_state = 2},
  [3257] = {.lex_state = 14, .external_lex_state = 2},
  [3258] = {.lex_state = 14, .external_lex_state = 2},
  [3259] = {.lex_state = 14, .external_lex_state = 2},
  [3260] = {.lex_state = 14, .external_lex_state = 2},
  [3261] = {.lex_state = 14, .external_lex_state = 2},
  [3262] = {.lex_state = 14, .external_lex_state = 2},
  [3263] = {.lex_state = 14, .external_lex_state = 2},
  [3264] = {.lex_state = 14, .external_lex_state = 2},
  [3265] = {.lex_state = 14, .external_lex_state = 2},
  [3266] = {.lex_state = 14, .external_lex_state = 2},
  [3267] = {.lex_state = 14, .external_lex_state = 2},
  [3268] = {.lex_state = 14, .external_lex_state = 2},
  [3269] = {.lex_state = 14, .external_lex_state = 2},
  [3270] = {.lex_state = 14, .external_lex_state = 2},
  [3271] = {.lex_state = 14, .external_lex_state = 2},
  [3272] = {.lex_state = 14, .external_lex_state = 2},
  [3273] = {.lex_state = 14, .external_lex_state = 2},
  [3274] = {.lex_state = 14, .external_lex_state = 2},
  [3275] = {.lex_state = 14, .external_lex_state = 2},
  [3276] = {.lex_state = 14, .external_lex_state = 2},
  [3277] = {.lex_state = 14, .external_lex_state = 2},
  [3278] = {.lex_state = 14, .external_lex_state = 2},
  [3279] = {.lex_state = 14, .external_lex_state = 2},
  [3280] = {.lex_state = 14, .external_lex_state = 2},
  [3281] = {.lex_state = 14, .external_lex_state = 2},
  [3282] = {.lex_state = 14, .external_lex_state = 2},
  [3283] = {.lex_state = 14, .external_lex_state = 2},
  [3284] = {.lex_state = 14, .external_lex_state = 2},
  [3285] = {.lex_state = 14, .external_lex_state = 2},
  [3286] = {.lex_state = 14, .external_lex_state = 2},
  [3287] = {.lex_state = 14, .external_lex_state = 2},
  [3288] = {.lex_state = 14, .external_lex_state = 2},
  [3289] = {.lex_state = 14, .external_lex_state = 2},
  [3290] = {.lex_state = 14, .external_lex_state = 2},
  [3291] = {.lex_state = 14, .external_lex_state = 2},
  [3292] = {.lex_state = 14, .external_lex_state = 2},
  [3293] = {.lex_state = 14, .external_lex_state = 2},
  [3294] = {.lex_state = 14, .external_lex_state = 2},
  [3295] = {.lex_state = 14, .external_lex_state = 2},
  [3296] = {.lex_state = 14, .external_lex_state = 2},
  [3297] = {.lex_state = 14, .external_lex_state = 2},
  [3298] = {.lex_state = 14, .external_lex_state = 2},
  [3299] = {.lex_state = 14, .external_lex_state = 2},
  [3300] = {.lex_state = 14, .external_lex_state = 2},
  [3301] = {.lex_state = 14, .external_lex_state = 2},
  [3302] = {.lex_state = 14, .external_lex_state = 2},
  [3303] = {.lex_state = 14, .external_lex_state = 2},
  [3304] = {.lex_state = 14, .external_lex_state = 2},
  [3305] = {.lex_state = 14, .external_lex_state = 2},
  [3306] = {.lex_state = 14, .external_lex_state = 2},
  [3307] = {.lex_state = 14, .external_lex_state = 2},
  [3308] = {.lex_state = 14, .external_lex_state = 2},
  [3309] = {.lex_state = 14, .external_lex_state = 2},
  [3310] = {.lex_state = 14, .external_lex_state = 2},
  [3311] = {.lex_state = 14, .external_lex_state = 2},
  [3312] = {.lex_state = 14, .external_lex_state = 2},
  [3313] = {.lex_state = 14, .external_lex_state = 2},
  [3314] = {.lex_state = 14, .external_lex_state = 2},
  [3315] = {.lex_state = 14, .external_lex_state = 2},
  [3316] = {.lex_state = 14, .external_lex_state = 2},
  [3317] = {.lex_state = 14, .external_lex_state = 2},
  [3318] = {.lex_state = 14, .external_lex_state = 2},
  [3319] = {.lex_state = 14, .external_lex_state = 2},
  [3320] = {.lex_state = 14, .external_lex_state = 2},
  [3321] = {.lex_state = 14, .external_lex_state = 2},
  [3322] = {.lex_state = 14, .external_lex_state = 2},
  [3323] = {.lex_state = 14, .external_lex_state = 2},
  [3324] = {.lex_state = 14, .external_lex_state = 2},
  [3325] = {.lex_state = 14, .external_lex_state = 2},
  [3326] = {.lex_state = 14, .external_lex_state = 2},
  [3327] = {.lex_state = 14, .external_lex_state = 2},
  [3328] = {.lex_state = 48, .external_lex_state = 20},
  [3329] = {.lex_state = 14, .external_lex_state = 2},
  [3330] = {.lex_state = 14, .external_lex_state = 2},
  [3331] = {.lex_state = 14, .external_lex_state = 2},
  [3332] = {.lex_state = 14, .external_lex_state = 2},
  [3333] = {.lex_state = 14, .external_lex_state = 2},
  [3334] = {.lex_state = 14, .external_lex_state = 2},
  [3335] = {.lex_state = 14, .external_lex_state = 2},
  [3336] = {.lex_state = 14, .external_lex_state = 2},
  [3337] = {.lex_state = 14, .external_lex_state = 2},
  [3338] = {.lex_state = 14, .external_lex_state = 2},
  [3339] = {.lex_state = 14, .external_lex_state = 2},
  [3340] = {.lex_state = 14, .external_lex_state = 2},
  [3341] = {.lex_state = 14, .external_lex_state = 2},
  [3342] = {.lex_state = 14, .external_lex_state = 2},
  [3343] = {.lex_state = 14, .external_lex_state = 2},
  [3344] = {.lex_state = 14, .external_lex_state = 2},
  [3345] = {.lex_state = 14, .external_lex_state = 2},
  [3346] = {.lex_state = 14, .external_lex_state = 2},
  [3347] = {.lex_state = 14, .external_lex_state = 2},
  [3348] = {.lex_state = 14, .external_lex_state = 2},
  [3349] = {.lex_state = 14, .external_lex_state = 2},
  [3350] = {.lex_state = 14, .external_lex_state = 2},
  [3351] = {.lex_state = 14, .external_lex_state = 2},
  [3352] = {.lex_state = 14, .external_lex_state = 2},
  [3353] = {.lex_state = 14, .external_lex_state = 2},
  [3354] = {.lex_state = 14, .external_lex_state = 2},
  [3355] = {.lex_state = 14, .external_lex_state = 2},
  [3356] = {.lex_state = 14, .external_lex_state = 2},
  [3357] = {.lex_state = 14, .external_lex_state = 2},
  [3358] = {.lex_state = 14, .external_lex_state = 2},
  [3359] = {.lex_state = 14, .external_lex_state = 2},
  [3360] = {.lex_state = 14, .external_lex_state = 2},
  [3361] = {.lex_state = 14, .external_lex_state = 2},
  [3362] = {.lex_state = 14, .external_lex_state = 2},
  [3363] = {.lex_state = 14, .external_lex_state = 2},
  [3364] = {.lex_state = 14, .external_lex_state = 2},
  [3365] = {.lex_state = 14, .external_lex_state = 2},
  [3366] = {.lex_state = 14, .external_lex_state = 2},
  [3367] = {.lex_state = 14, .external_lex_state = 2},
  [3368] = {.lex_state = 14, .external_lex_state = 2},
  [3369] = {.lex_state = 14, .external_lex_state = 2},
  [3370] = {.lex_state = 14, .external_lex_state = 2},
  [3371] = {.lex_state = 14, .external_lex_state = 2},
  [3372] = {.lex_state = 14, .external_lex_state = 2},
  [3373] = {.lex_state = 14, .external_lex_state = 2},
  [3374] = {.lex_state = 14, .external_lex_state = 2},
  [3375] = {.lex_state = 14, .external_lex_state = 2},
  [3376] = {.lex_state = 14, .external_lex_state = 2},
  [3377] = {.lex_state = 14, .external_lex_state = 2},
  [3378] = {.lex_state = 14, .external_lex_state = 2},
  [3379] = {.lex_state = 14, .external_lex_state = 2},
  [3380] = {.lex_state = 14, .external_lex_state = 2},
  [3381] = {.lex_state = 14, .external_lex_state = 2},
  [3382] = {.lex_state = 14, .external_lex_state = 2},
  [3383] = {.lex_state = 14, .external_lex_state = 2},
  [3384] = {.lex_state = 14, .external_lex_state = 2},
  [3385] = {.lex_state = 14, .external_lex_state = 2},
  [3386] = {.lex_state = 14, .external_lex_state = 2},
  [3387] = {.lex_state = 14, .external_lex_state = 2},
  [3388] = {.lex_state = 14, .external_lex_state = 2},
  [3389] = {.lex_state = 14, .external_lex_state = 2},
  [3390] = {.lex_state = 48, .external_lex_state = 8},
  [3391] = {.lex_state = 14, .external_lex_state = 2},
  [3392] = {.lex_state = 14, .external_lex_state = 2},
  [3393] = {.lex_state = 14, .external_lex_state = 2},
  [3394] = {.lex_state = 14, .external_lex_state = 2},
  [3395] = {.lex_state = 14, .external_lex_state = 2},
  [3396] = {.lex_state = 14, .external_lex_state = 2},
  [3397] = {.lex_state = 14, .external_lex_state = 2},
  [3398] = {.lex_state = 14, .external_lex_state = 2},
  [3399] = {.lex_state = 14, .external_lex_state = 2},
  [3400] = {.lex_state = 14, .external_lex_state = 2},
  [3401] = {.lex_state = 14, .external_lex_state = 2},
  [3402] = {.lex_state = 14, .external_lex_state = 2},
  [3403] = {.lex_state = 14, .external_lex_state = 2},
  [3404] = {.lex_state = 14, .external_lex_state = 2},
  [3405] = {.lex_state = 14, .external_lex_state = 2},
  [3406] = {.lex_state = 14, .external_lex_state = 2},
  [3407] = {.lex_state = 14, .external_lex_state = 2},
  [3408] = {.lex_state = 14, .external_lex_state = 2},
  [3409] = {.lex_state = 14, .external_lex_state = 2},
  [3410] = {.lex_state = 14, .external_lex_state = 2},
  [3411] = {.lex_state = 14, .external_lex_state = 2},
  [3412] = {.lex_state = 14, .external_lex_state = 2},
  [3413] = {.lex_state = 14, .external_lex_state = 2},
  [3414] = {.lex_state = 14, .external_lex_state = 2},
  [3415] = {.lex_state = 14, .external_lex_state = 2},
  [3416] = {.lex_state = 14, .external_lex_state = 2},
  [3417] = {.lex_state = 14, .external_lex_state = 2},
  [3418] = {.lex_state = 14, .external_lex_state = 2},
  [3419] = {.lex_state = 14, .external_lex_state = 2},
  [3420] = {.lex_state = 14, .external_lex_state = 2},
  [3421] = {.lex_state = 14, .external_lex_state = 2},
  [3422] = {.lex_state = 14, .external_lex_state = 2},
  [3423] = {.lex_state = 14, .external_lex_state = 2},
  [3424] = {.lex_state = 14, .external_lex_state = 2},
  [3425] = {.lex_state = 14, .external_lex_state = 2},
  [3426] = {.lex_state = 14, .external_lex_state = 2},
  [3427] = {.lex_state = 14, .external_lex_state = 2},
  [3428] = {.lex_state = 14, .external_lex_state = 2},
  [3429] = {.lex_state = 14, .external_lex_state = 2},
  [3430] = {.lex_state = 14, .external_lex_state = 2},
  [3431] = {.lex_state = 14, .external_lex_state = 2},
  [3432] = {.lex_state = 14, .external_lex_state = 2},
  [3433] = {.lex_state = 14, .external_lex_state = 2},
  [3434] = {.lex_state = 14, .external_lex_state = 2},
  [3435] = {.lex_state = 14, .external_lex_state = 2},
  [3436] = {.lex_state = 14, .external_lex_state = 2},
  [3437] = {.lex_state = 14, .external_lex_state = 2},
  [3438] = {.lex_state = 14, .external_lex_state = 2},
  [3439] = {.lex_state = 14, .external_lex_state = 2},
  [3440] = {.lex_state = 14, .external_lex_state = 2},
  [3441] = {.lex_state = 14, .external_lex_state = 2},
  [3442] = {.lex_state = 14, .external_lex_state = 2},
  [3443] = {.lex_state = 14, .external_lex_state = 2},
  [3444] = {.lex_state = 14, .external_lex_state = 2},
  [3445] = {.lex_state = 14, .external_lex_state = 2},
  [3446] = {.lex_state = 14, .external_lex_state = 2},
  [3447] = {.lex_state = 14, .external_lex_state = 2},
  [3448] = {.lex_state = 14, .external_lex_state = 2},
  [3449] = {.lex_state = 14, .external_lex_state = 2},
  [3450] = {.lex_state = 14, .external_lex_state = 2},
  [3451] = {.lex_state = 14, .external_lex_state = 2},
  [3452] = {.lex_state = 14, .external_lex_state = 2},
  [3453] = {.lex_state = 14, .external_lex_state = 2},
  [3454] = {.lex_state = 14, .external_lex_state = 2},
  [3455] = {.lex_state = 14, .external_lex_state = 2},
  [3456] = {.lex_state = 14, .external_lex_state = 2},
  [3457] = {.lex_state = 14, .external_lex_state = 2},
  [3458] = {.lex_state = 14, .external_lex_state = 2},
  [3459] = {.lex_state = 14, .external_lex_state = 2},
  [3460] = {.lex_state = 14, .external_lex_state = 2},
  [3461] = {.lex_state = 14, .external_lex_state = 2},
  [3462] = {.lex_state = 14, .external_lex_state = 2},
  [3463] = {.lex_state = 14, .external_lex_state = 2},
  [3464] = {.lex_state = 14, .external_lex_state = 2},
  [3465] = {.lex_state = 14, .external_lex_state = 2},
  [3466] = {.lex_state = 14, .external_lex_state = 2},
  [3467] = {.lex_state = 14, .external_lex_state = 2},
  [3468] = {.lex_state = 14, .external_lex_state = 2},
  [3469] = {.lex_state = 14, .external_lex_state = 2},
  [3470] = {.lex_state = 14, .external_lex_state = 2},
  [3471] = {.lex_state = 14, .external_lex_state = 2},
  [3472] = {.lex_state = 14, .external_lex_state = 2},
  [3473] = {.lex_state = 14, .external_lex_state = 2},
  [3474] = {.lex_state = 14, .external_lex_state = 2},
  [3475] = {.lex_state = 14, .external_lex_state = 2},
  [3476] = {.lex_state = 14, .external_lex_state = 2},
  [3477] = {.lex_state = 14, .external_lex_state = 2},
  [3478] = {.lex_state = 14, .external_lex_state = 2},
  [3479] = {.lex_state = 14, .external_lex_state = 2},
  [3480] = {.lex_state = 14, .external_lex_state = 2},
  [3481] = {.lex_state = 14, .external_lex_state = 2},
  [3482] = {.lex_state = 14, .external_lex_state = 2},
  [3483] = {.lex_state = 14, .external_lex_state = 2},
  [3484] = {.lex_state = 14, .external_lex_state = 2},
  [3485] = {.lex_state = 14, .external_lex_state = 2},
  [3486] = {.lex_state = 14, .external_lex_state = 2},
  [3487] = {.lex_state = 14, .external_lex_state = 2},
  [3488] = {.lex_state = 14, .external_lex_state = 2},
  [3489] = {.lex_state = 14, .external_lex_state = 2},
  [3490] = {.lex_state = 14, .external_lex_state = 2},
  [3491] = {.lex_state = 14, .external_lex_state = 2},
  [3492] = {.lex_state = 14, .external_lex_state = 2},
  [3493] = {.lex_state = 14, .external_lex_state = 2},
  [3494] = {.lex_state = 14, .external_lex_state = 2},
  [3495] = {.lex_state = 14, .external_lex_state = 2},
  [3496] = {.lex_state = 14, .external_lex_state = 2},
  [3497] = {.lex_state = 14, .external_lex_state = 2},
  [3498] = {.lex_state = 14, .external_lex_state = 2},
  [3499] = {.lex_state = 14, .external_lex_state = 2},
  [3500] = {.lex_state = 14, .external_lex_state = 2},
  [3501] = {.lex_state = 14, .external_lex_state = 2},
  [3502] = {.lex_state = 14, .external_lex_state = 2},
  [3503] = {.lex_state = 14, .external_lex_state = 2},
  [3504] = {.lex_state = 14, .external_lex_state = 2},
  [3505] = {.lex_state = 14, .external_lex_state = 2},
  [3506] = {.lex_state = 14, .external_lex_state = 2},
  [3507] = {.lex_state = 14, .external_lex_state = 2},
  [3508] = {.lex_state = 14, .external_lex_state = 2},
  [3509] = {.lex_state = 14, .external_lex_state = 2},
  [3510] = {.lex_state = 14, .external_lex_state = 2},
  [3511] = {.lex_state = 14, .external_lex_state = 2},
  [3512] = {.lex_state = 14, .external_lex_state = 2},
  [3513] = {.lex_state = 14, .external_lex_state = 2},
  [3514] = {.lex_state = 14, .external_lex_state = 2},
  [3515] = {.lex_state = 14, .external_lex_state = 2},
  [3516] = {.lex_state = 14, .external_lex_state = 2},
  [3517] = {.lex_state = 14, .external_lex_state = 2},
  [3518] = {.lex_state = 14, .external_lex_state = 2},
  [3519] = {.lex_state = 14, .external_lex_state = 2},
  [3520] = {.lex_state = 14, .external_lex_state = 2},
  [3521] = {.lex_state = 14, .external_lex_state = 2},
  [3522] = {.lex_state = 14, .external_lex_state = 2},
  [3523] = {.lex_state = 14, .external_lex_state = 2},
  [3524] = {.lex_state = 14, .external_lex_state = 2},
  [3525] = {.lex_state = 14, .external_lex_state = 2},
  [3526] = {.lex_state = 14, .external_lex_state = 2},
  [3527] = {.lex_state = 14, .external_lex_state = 2},
  [3528] = {.lex_state = 14, .external_lex_state = 2},
  [3529] = {.lex_state = 14, .external_lex_state = 2},
  [3530] = {.lex_state = 14, .external_lex_state = 2},
  [3531] = {.lex_state = 14, .external_lex_state = 2},
  [3532] = {.lex_state = 14, .external_lex_state = 2},
  [3533] = {.lex_state = 14, .external_lex_state = 2},
  [3534] = {.lex_state = 14, .external_lex_state = 2},
  [3535] = {.lex_state = 14, .external_lex_state = 2},
  [3536] = {.lex_state = 14, .external_lex_state = 2},
  [3537] = {.lex_state = 14, .external_lex_state = 2},
  [3538] = {.lex_state = 14, .external_lex_state = 2},
  [3539] = {.lex_state = 14, .external_lex_state = 2},
  [3540] = {.lex_state = 14, .external_lex_state = 2},
  [3541] = {.lex_state = 14, .external_lex_state = 2},
  [3542] = {.lex_state = 14, .external_lex_state = 2},
  [3543] = {.lex_state = 14, .external_lex_state = 2},
  [3544] = {.lex_state = 14, .external_lex_state = 2},
  [3545] = {.lex_state = 14, .external_lex_state = 2},
  [3546] = {.lex_state = 14, .external_lex_state = 2},
  [3547] = {.lex_state = 14, .external_lex_state = 2},
  [3548] = {.lex_state = 14, .external_lex_state = 2},
  [3549] = {.lex_state = 14, .external_lex_state = 2},
  [3550] = {.lex_state = 14, .external_lex_state = 2},
  [3551] = {.lex_state = 14, .external_lex_state = 2},
  [3552] = {.lex_state = 14, .external_lex_state = 2},
  [3553] = {.lex_state = 14, .external_lex_state = 2},
  [3554] = {.lex_state = 14, .external_lex_state = 2},
  [3555] = {.lex_state = 14, .external_lex_state = 2},
  [3556] = {.lex_state = 14, .external_lex_state = 2},
  [3557] = {.lex_state = 14, .external_lex_state = 2},
  [3558] = {.lex_state = 14, .external_lex_state = 2},
  [3559] = {.lex_state = 14, .external_lex_state = 2},
  [3560] = {.lex_state = 14, .external_lex_state = 2},
  [3561] = {.lex_state = 14, .external_lex_state = 2},
  [3562] = {.lex_state = 14, .external_lex_state = 2},
  [3563] = {.lex_state = 14, .external_lex_state = 2},
  [3564] = {.lex_state = 14, .external_lex_state = 2},
  [3565] = {.lex_state = 14, .external_lex_state = 2},
  [3566] = {.lex_state = 14, .external_lex_state = 2},
  [3567] = {.lex_state = 14, .external_lex_state = 2},
  [3568] = {.lex_state = 14, .external_lex_state = 2},
  [3569] = {.lex_state = 14, .external_lex_state = 2},
  [3570] = {.lex_state = 14, .external_lex_state = 2},
  [3571] = {.lex_state = 14, .external_lex_state = 2},
  [3572] = {.lex_state = 14, .external_lex_state = 2},
  [3573] = {.lex_state = 14, .external_lex_state = 2},
  [3574] = {.lex_state = 14, .external_lex_state = 2},
  [3575] = {.lex_state = 14, .external_lex_state = 2},
  [3576] = {.lex_state = 14, .external_lex_state = 2},
  [3577] = {.lex_state = 14, .external_lex_state = 2},
  [3578] = {.lex_state = 14, .external_lex_state = 2},
  [3579] = {.lex_state = 14, .external_lex_state = 2},
  [3580] = {.lex_state = 14, .external_lex_state = 2},
  [3581] = {.lex_state = 14, .external_lex_state = 2},
  [3582] = {.lex_state = 14, .external_lex_state = 2},
  [3583] = {.lex_state = 14, .external_lex_state = 2},
  [3584] = {.lex_state = 14, .external_lex_state = 2},
  [3585] = {.lex_state = 14, .external_lex_state = 2},
  [3586] = {.lex_state = 14, .external_lex_state = 2},
  [3587] = {.lex_state = 14, .external_lex_state = 2},
  [3588] = {.lex_state = 14, .external_lex_state = 2},
  [3589] = {.lex_state = 14, .external_lex_state = 2},
  [3590] = {.lex_state = 48, .external_lex_state = 16},
  [3591] = {.lex_state = 14, .external_lex_state = 2},
  [3592] = {.lex_state = 14, .external_lex_state = 2},
  [3593] = {.lex_state = 14, .external_lex_state = 2},
  [3594] = {.lex_state = 14, .external_lex_state = 2},
  [3595] = {.lex_state = 14, .external_lex_state = 2},
  [3596] = {.lex_state = 14, .external_lex_state = 2},
  [3597] = {.lex_state = 14, .external_lex_state = 2},
  [3598] = {.lex_state = 14, .external_lex_state = 2},
  [3599] = {.lex_state = 14, .external_lex_state = 2},
  [3600] = {.lex_state = 14, .external_lex_state = 2},
  [3601] = {.lex_state = 14, .external_lex_state = 2},
  [3602] = {.lex_state = 14, .external_lex_state = 2},
  [3603] = {.lex_state = 14, .external_lex_state = 2},
  [3604] = {.lex_state = 14, .external_lex_state = 2},
  [3605] = {.lex_state = 14, .external_lex_state = 2},
  [3606] = {.lex_state = 14, .external_lex_state = 2},
  [3607] = {.lex_state = 14, .external_lex_state = 2},
  [3608] = {.lex_state = 14, .external_lex_state = 2},
  [3609] = {.lex_state = 14, .external_lex_state = 2},
  [3610] = {.lex_state = 14, .external_lex_state = 2},
  [3611] = {.lex_state = 14, .external_lex_state = 2},
  [3612] = {.lex_state = 14, .external_lex_state = 2},
  [3613] = {.lex_state = 14, .external_lex_state = 2},
  [3614] = {.lex_state = 14, .external_lex_state = 2},
  [3615] = {.lex_state = 14, .external_lex_state = 2},
  [3616] = {.lex_state = 14, .external_lex_state = 2},
  [3617] = {.lex_state = 14, .external_lex_state = 2},
  [3618] = {.lex_state = 14, .external_lex_state = 2},
  [3619] = {.lex_state = 14, .external_lex_state = 2},
  [3620] = {.lex_state = 14, .external_lex_state = 2},
  [3621] = {.lex_state = 14, .external_lex_state = 2},
  [3622] = {.lex_state = 14, .external_lex_state = 2},
  [3623] = {.lex_state = 14, .external_lex_state = 2},
  [3624] = {.lex_state = 14, .external_lex_state = 2},
  [3625] = {.lex_state = 14, .external_lex_state = 2},
  [3626] = {.lex_state = 14, .external_lex_state = 2},
  [3627] = {.lex_state = 14, .external_lex_state = 2},
  [3628] = {.lex_state = 14, .external_lex_state = 2},
  [3629] = {.lex_state = 14, .external_lex_state = 2},
  [3630] = {.lex_state = 14, .external_lex_state = 2},
  [3631] = {.lex_state = 14, .external_lex_state = 2},
  [3632] = {.lex_state = 14, .external_lex_state = 2},
  [3633] = {.lex_state = 14, .external_lex_state = 2},
  [3634] = {.lex_state = 14, .external_lex_state = 2},
  [3635] = {.lex_state = 14, .external_lex_state = 2},
  [3636] = {.lex_state = 14, .external_lex_state = 2},
  [3637] = {.lex_state = 14, .external_lex_state = 2},
  [3638] = {.lex_state = 14, .external_lex_state = 2},
  [3639] = {.lex_state = 14, .external_lex_state = 2},
  [3640] = {.lex_state = 14, .external_lex_state = 2},
  [3641] = {.lex_state = 14, .external_lex_state = 2},
  [3642] = {.lex_state = 14, .external_lex_state = 2},
  [3643] = {.lex_state = 14, .external_lex_state = 2},
  [3644] = {.lex_state = 14, .external_lex_state = 2},
  [3645] = {.lex_state = 14, .external_lex_state = 2},
  [3646] = {.lex_state = 14, .external_lex_state = 2},
  [3647] = {.lex_state = 14, .external_lex_state = 2},
  [3648] = {.lex_state = 14, .external_lex_state = 2},
  [3649] = {.lex_state = 14, .external_lex_state = 2},
  [3650] = {.lex_state = 14, .external_lex_state = 2},
  [3651] = {.lex_state = 14, .external_lex_state = 2},
  [3652] = {.lex_state = 14, .external_lex_state = 2},
  [3653] = {.lex_state = 14, .external_lex_state = 2},
  [3654] = {.lex_state = 14, .external_lex_state = 2},
  [3655] = {.lex_state = 14, .external_lex_state = 2},
  [3656] = {.lex_state = 14, .external_lex_state = 2},
  [3657] = {.lex_state = 14, .external_lex_state = 2},
  [3658] = {.lex_state = 14, .external_lex_state = 2},
  [3659] = {.lex_state = 14, .external_lex_state = 2},
  [3660] = {.lex_state = 14, .external_lex_state = 2},
  [3661] = {.lex_state = 14, .external_lex_state = 2},
  [3662] = {.lex_state = 14, .external_lex_state = 2},
  [3663] = {.lex_state = 14, .external_lex_state = 2},
  [3664] = {.lex_state = 14, .external_lex_state = 2},
  [3665] = {.lex_state = 14, .external_lex_state = 2},
  [3666] = {.lex_state = 14, .external_lex_state = 2},
  [3667] = {.lex_state = 14, .external_lex_state = 2},
  [3668] = {.lex_state = 14, .external_lex_state = 2},
  [3669] = {.lex_state = 14, .external_lex_state = 2},
  [3670] = {.lex_state = 14, .external_lex_state = 2},
  [3671] = {.lex_state = 14, .external_lex_state = 2},
  [3672] = {.lex_state = 14, .external_lex_state = 2},
  [3673] = {.lex_state = 14, .external_lex_state = 2},
  [3674] = {.lex_state = 14, .external_lex_state = 2},
  [3675] = {.lex_state = 14, .external_lex_state = 2},
  [3676] = {.lex_state = 14, .external_lex_state = 2},
  [3677] = {.lex_state = 14, .external_lex_state = 2},
  [3678] = {.lex_state = 14, .external_lex_state = 2},
  [3679] = {.lex_state = 14, .external_lex_state = 2},
  [3680] = {.lex_state = 14, .external_lex_state = 2},
  [3681] = {.lex_state = 14, .external_lex_state = 2},
  [3682] = {.lex_state = 14, .external_lex_state = 2},
  [3683] = {.lex_state = 14, .external_lex_state = 2},
  [3684] = {.lex_state = 14, .external_lex_state = 2},
  [3685] = {.lex_state = 14, .external_lex_state = 2},
  [3686] = {.lex_state = 14, .external_lex_state = 2},
  [3687] = {.lex_state = 14, .external_lex_state = 2},
  [3688] = {.lex_state = 14, .external_lex_state = 2},
  [3689] = {.lex_state = 14, .external_lex_state = 2},
  [3690] = {.lex_state = 14, .external_lex_state = 2},
  [3691] = {.lex_state = 14, .external_lex_state = 2},
  [3692] = {.lex_state = 14, .external_lex_state = 2},
  [3693] = {.lex_state = 14, .external_lex_state = 2},
  [3694] = {.lex_state = 14, .external_lex_state = 2},
  [3695] = {.lex_state = 14, .external_lex_state = 2},
  [3696] = {.lex_state = 14, .external_lex_state = 2},
  [3697] = {.lex_state = 14, .external_lex_state = 2},
  [3698] = {.lex_state = 14, .external_lex_state = 2},
  [3699] = {.lex_state = 14, .external_lex_state = 2},
  [3700] = {.lex_state = 14, .external_lex_state = 2},
  [3701] = {.lex_state = 14, .external_lex_state = 2},
  [3702] = {.lex_state = 14, .external_lex_state = 2},
  [3703] = {.lex_state = 14, .external_lex_state = 2},
  [3704] = {.lex_state = 14, .external_lex_state = 2},
  [3705] = {.lex_state = 14, .external_lex_state = 2},
  [3706] = {.lex_state = 14, .external_lex_state = 2},
  [3707] = {.lex_state = 14, .external_lex_state = 2},
  [3708] = {.lex_state = 14, .external_lex_state = 2},
  [3709] = {.lex_state = 14, .external_lex_state = 2},
  [3710] = {.lex_state = 14, .external_lex_state = 2},
  [3711] = {.lex_state = 14, .external_lex_state = 2},
  [3712] = {.lex_state = 14, .external_lex_state = 2},
  [3713] = {.lex_state = 14, .external_lex_state = 2},
  [3714] = {.lex_state = 14, .external_lex_state = 2},
  [3715] = {.lex_state = 14, .external_lex_state = 2},
  [3716] = {.lex_state = 14, .external_lex_state = 2},
  [3717] = {.lex_state = 14, .external_lex_state = 2},
  [3718] = {.lex_state = 14, .external_lex_state = 2},
  [3719] = {.lex_state = 14, .external_lex_state = 2},
  [3720] = {.lex_state = 14, .external_lex_state = 2},
  [3721] = {.lex_state = 14, .external_lex_state = 2},
  [3722] = {.lex_state = 14, .external_lex_state = 2},
  [3723] = {.lex_state = 14, .external_lex_state = 2},
  [3724] = {.lex_state = 14, .external_lex_state = 2},
  [3725] = {.lex_state = 14, .external_lex_state = 2},
  [3726] = {.lex_state = 14, .external_lex_state = 2},
  [3727] = {.lex_state = 14, .external_lex_state = 2},
  [3728] = {.lex_state = 14, .external_lex_state = 2},
  [3729] = {.lex_state = 14, .external_lex_state = 2},
  [3730] = {.lex_state = 14, .external_lex_state = 2},
  [3731] = {.lex_state = 14, .external_lex_state = 2},
  [3732] = {.lex_state = 14, .external_lex_state = 2},
  [3733] = {.lex_state = 14, .external_lex_state = 2},
  [3734] = {.lex_state = 14, .external_lex_state = 2},
  [3735] = {.lex_state = 14, .external_lex_state = 2},
  [3736] = {.lex_state = 14, .external_lex_state = 2},
  [3737] = {.lex_state = 14, .external_lex_state = 2},
  [3738] = {.lex_state = 14, .external_lex_state = 2},
  [3739] = {.lex_state = 14, .external_lex_state = 2},
  [3740] = {.lex_state = 14, .external_lex_state = 2},
  [3741] = {.lex_state = 14, .external_lex_state = 2},
  [3742] = {.lex_state = 14, .external_lex_state = 2},
  [3743] = {.lex_state = 14, .external_lex_state = 2},
  [3744] = {.lex_state = 14, .external_lex_state = 2},
  [3745] = {.lex_state = 14, .external_lex_state = 2},
  [3746] = {.lex_state = 14, .external_lex_state = 2},
  [3747] = {.lex_state = 14, .external_lex_state = 2},
  [3748] = {.lex_state = 14, .external_lex_state = 2},
  [3749] = {.lex_state = 14, .external_lex_state = 2},
  [3750] = {.lex_state = 14, .external_lex_state = 2},
  [3751] = {.lex_state = 14, .external_lex_state = 2},
  [3752] = {.lex_state = 14, .external_lex_state = 2},
  [3753] = {.lex_state = 14, .external_lex_state = 2},
  [3754] = {.lex_state = 14, .external_lex_state = 2},
  [3755] = {.lex_state = 14, .external_lex_state = 2},
  [3756] = {.lex_state = 14, .external_lex_state = 2},
  [3757] = {.lex_state = 14, .external_lex_state = 2},
  [3758] = {.lex_state = 14, .external_lex_state = 2},
  [3759] = {.lex_state = 14, .external_lex_state = 2},
  [3760] = {.lex_state = 14, .external_lex_state = 2},
  [3761] = {.lex_state = 14, .external_lex_state = 2},
  [3762] = {.lex_state = 14, .external_lex_state = 2},
  [3763] = {.lex_state = 14, .external_lex_state = 2},
  [3764] = {.lex_state = 14, .external_lex_state = 2},
  [3765] = {.lex_state = 14, .external_lex_state = 2},
  [3766] = {.lex_state = 14, .external_lex_state = 2},
  [3767] = {.lex_state = 14, .external_lex_state = 2},
  [3768] = {.lex_state = 14, .external_lex_state = 2},
  [3769] = {.lex_state = 14, .external_lex_state = 2},
  [3770] = {.lex_state = 14, .external_lex_state = 2},
  [3771] = {.lex_state = 14, .external_lex_state = 2},
  [3772] = {.lex_state = 14, .external_lex_state = 2},
  [3773] = {.lex_state = 14, .external_lex_state = 2},
  [3774] = {.lex_state = 14, .external_lex_state = 2},
  [3775] = {.lex_state = 14, .external_lex_state = 2},
  [3776] = {.lex_state = 14, .external_lex_state = 2},
  [3777] = {.lex_state = 14, .external_lex_state = 2},
  [3778] = {.lex_state = 14, .external_lex_state = 2},
  [3779] = {.lex_state = 14, .external_lex_state = 2},
  [3780] = {.lex_state = 14, .external_lex_state = 2},
  [3781] = {.lex_state = 14, .external_lex_state = 2},
  [3782] = {.lex_state = 14, .external_lex_state = 2},
  [3783] = {.lex_state = 14, .external_lex_state = 2},
  [3784] = {.lex_state = 14, .external_lex_state = 2},
  [3785] = {.lex_state = 14, .external_lex_state = 2},
  [3786] = {.lex_state = 14, .external_lex_state = 2},
  [3787] = {.lex_state = 14, .external_lex_state = 2},
  [3788] = {.lex_state = 14, .external_lex_state = 2},
  [3789] = {.lex_state = 14, .external_lex_state = 2},
  [3790] = {.lex_state = 14, .external_lex_state = 2},
  [3791] = {.lex_state = 14, .external_lex_state = 2},
  [3792] = {.lex_state = 14, .external_lex_state = 2},
  [3793] = {.lex_state = 14, .external_lex_state = 2},
  [3794] = {.lex_state = 14, .external_lex_state = 2},
  [3795] = {.lex_state = 14, .external_lex_state = 2},
  [3796] = {.lex_state = 14, .external_lex_state = 2},
  [3797] = {.lex_state = 14, .external_lex_state = 2},
  [3798] = {.lex_state = 14, .external_lex_state = 2},
  [3799] = {.lex_state = 14, .external_lex_state = 2},
  [3800] = {.lex_state = 14, .external_lex_state = 2},
  [3801] = {.lex_state = 14, .external_lex_state = 2},
  [3802] = {.lex_state = 14, .external_lex_state = 2},
  [3803] = {.lex_state = 14, .external_lex_state = 2},
  [3804] = {.lex_state = 14, .external_lex_state = 2},
  [3805] = {.lex_state = 14, .external_lex_state = 2},
  [3806] = {.lex_state = 14, .external_lex_state = 2},
  [3807] = {.lex_state = 14, .external_lex_state = 2},
  [3808] = {.lex_state = 14, .external_lex_state = 2},
  [3809] = {.lex_state = 14, .external_lex_state = 2},
  [3810] = {.lex_state = 14, .external_lex_state = 2},
  [3811] = {.lex_state = 14, .external_lex_state = 2},
  [3812] = {.lex_state = 14, .external_lex_state = 2},
  [3813] = {.lex_state = 14, .external_lex_state = 2},
  [3814] = {.lex_state = 14, .external_lex_state = 2},
  [3815] = {.lex_state = 14, .external_lex_state = 2},
  [3816] = {.lex_state = 14, .external_lex_state = 2},
  [3817] = {.lex_state = 14, .external_lex_state = 2},
  [3818] = {.lex_state = 14, .external_lex_state = 2},
  [3819] = {.lex_state = 14, .external_lex_state = 2},
  [3820] = {.lex_state = 14, .external_lex_state = 2},
  [3821] = {.lex_state = 14, .external_lex_state = 2},
  [3822] = {.lex_state = 14, .external_lex_state = 2},
  [3823] = {.lex_state = 14, .external_lex_state = 2},
  [3824] = {.lex_state = 14, .external_lex_state = 2},
  [3825] = {.lex_state = 14, .external_lex_state = 2},
  [3826] = {.lex_state = 14, .external_lex_state = 2},
  [3827] = {.lex_state = 14, .external_lex_state = 2},
  [3828] = {.lex_state = 14, .external_lex_state = 2},
  [3829] = {.lex_state = 14, .external_lex_state = 2},
  [3830] = {.lex_state = 14, .external_lex_state = 2},
  [3831] = {.lex_state = 14, .external_lex_state = 2},
  [3832] = {.lex_state = 14, .external_lex_state = 2},
  [3833] = {.lex_state = 14, .external_lex_state = 2},
  [3834] = {.lex_state = 14, .external_lex_state = 2},
  [3835] = {.lex_state = 48, .external_lex_state = 17},
  [3836] = {.lex_state = 14, .external_lex_state = 2},
  [3837] = {.lex_state = 14, .external_lex_state = 2},
  [3838] = {.lex_state = 14, .external_lex_state = 2},
  [3839] = {.lex_state = 14, .external_lex_state = 2},
  [3840] = {.lex_state = 14, .external_lex_state = 2},
  [3841] = {.lex_state = 48, .external_lex_state = 11},
  [3842] = {.lex_state = 48, .external_lex_state = 19},
  [3843] = {.lex_state = 48, .external_lex_state = 10},
  [3844] = {.lex_state = 48, .external_lex_state = 22},
  [3845] = {.lex_state = 48, .external_lex_state = 21},
  [3846] = {.lex_state = 14, .external_lex_state = 3},
  [3847] = {.lex_state = 14, .external_lex_state = 3},
  [3848] = {.lex_state = 14, .external_lex_state = 3},
  [3849] = {.lex_state = 14, .external_lex_state = 3},
  [3850] = {.lex_state = 50, .external_lex_state = 6},
  [3851] = {.lex_state = 48, .external_lex_state = 2},
  [3852] = {.lex_state = 50, .external_lex_state = 6},
  [3853] = {.lex_state = 14, .external_lex_state = 3},
  [3854] = {.lex_state = 14, .external_lex_state = 3},
  [3855] = {.lex_state = 14, .external_lex_state = 3},
  [3856] = {.lex_state = 14, .external_lex_state = 3},
  [3857] = {.lex_state = 14, .external_lex_state = 3},
  [3858] = {.lex_state = 14, .external_lex_state = 3},
  [3859] = {.lex_state = 14, .external_lex_state = 3},
  [3860] = {.lex_state = 14, .external_lex_state = 3},
  [3861] = {.lex_state = 14, .external_lex_state = 3},
  [3862] = {.lex_state = 14, .external_lex_state = 3},
  [3863] = {.lex_state = 14, .external_lex_state = 3},
  [3864] = {.lex_state = 14, .external_lex_state = 3},
  [3865] = {.lex_state = 14, .external_lex_state = 3},
  [3866] = {.lex_state = 14, .external_lex_state = 3},
  [3867] = {.lex_state = 14, .external_lex_state = 3},
  [3868] = {.lex_state = 14, .external_lex_state = 3},
  [3869] = {.lex_state = 14, .external_lex_state = 3},
  [3870] = {.lex_state = 14, .external_lex_state = 3},
  [3871] = {.lex_state = 14, .external_lex_state = 3},
  [3872] = {.lex_state = 14, .external_lex_state = 3},
  [3873] = {.lex_state = 14, .external_lex_state = 3},
  [3874] = {.lex_state = 14, .external_lex_state = 3},
  [3875] = {.lex_state = 14, .external_lex_state = 3},
  [3876] = {.lex_state = 14, .external_lex_state = 3},
  [3877] = {.lex_state = 14, .external_lex_state = 3},
  [3878] = {.lex_state = 14, .external_lex_state = 3},
  [3879] = {.lex_state = 14, .external_lex_state = 3},
  [3880] = {.lex_state = 14, .external_lex_state = 3},
  [3881] = {.lex_state = 14, .external_lex_state = 3},
  [3882] = {.lex_state = 14, .external_lex_state = 3},
  [3883] = {.lex_state = 14, .external_lex_state = 3},
  [3884] = {.lex_state = 14, .external_lex_state = 3},
  [3885] = {.lex_state = 14, .external_lex_state = 3},
  [3886] = {.lex_state = 14, .external_lex_state = 3},
  [3887] = {.lex_state = 14, .external_lex_state = 3},
  [3888] = {.lex_state = 14, .external_lex_state = 3},
  [3889] = {.lex_state = 14, .external_lex_state = 3},
  [3890] = {.lex_state = 14, .external_lex_state = 3},
  [3891] = {.lex_state = 14, .external_lex_state = 3},
  [3892] = {.lex_state = 14, .external_lex_state = 3},
  [3893] = {.lex_state = 14, .external_lex_state = 3},
  [3894] = {.lex_state = 14, .external_lex_state = 3},
  [3895] = {.lex_state = 14, .external_lex_state = 3},
  [3896] = {.lex_state = 14, .external_lex_state = 3},
  [3897] = {.lex_state = 14, .external_lex_state = 3},
  [3898] = {.lex_state = 14, .external_lex_state = 3},
  [3899] = {.lex_state = 14, .external_lex_state = 3},
  [3900] = {.lex_state = 14, .external_lex_state = 3},
  [3901] = {.lex_state = 14, .external_lex_state = 3},
  [3902] = {.lex_state = 14, .external_lex_state = 3},
  [3903] = {.lex_state = 14, .external_lex_state = 3},
  [3904] = {.lex_state = 14, .external_lex_state = 3},
  [3905] = {.lex_state = 14, .external_lex_state = 3},
  [3906] = {.lex_state = 14, .external_lex_state = 3},
  [3907] = {.lex_state = 14, .external_lex_state = 3},
  [3908] = {.lex_state = 14, .external_lex_state = 3},
  [3909] = {.lex_state = 14, .external_lex_state = 3},
  [3910] = {.lex_state = 14, .external_lex_state = 3},
  [3911] = {.lex_state = 14, .external_lex_state = 3},
  [3912] = {.lex_state = 14, .external_lex_state = 3},
  [3913] = {.lex_state = 14, .external_lex_state = 3},
  [3914] = {.lex_state = 14, .external_lex_state = 3},
  [3915] = {.lex_state = 14, .external_lex_state = 3},
  [3916] = {.lex_state = 14, .external_lex_state = 3},
  [3917] = {.lex_state = 14, .external_lex_state = 3},
  [3918] = {.lex_state = 14, .external_lex_state = 3},
  [3919] = {.lex_state = 14, .external_lex_state = 3},
  [3920] = {.lex_state = 14, .external_lex_state = 3},
  [3921] = {.lex_state = 14, .external_lex_state = 3},
  [3922] = {.lex_state = 14, .external_lex_state = 3},
  [3923] = {.lex_state = 14, .external_lex_state = 3},
  [3924] = {.lex_state = 14, .external_lex_state = 3},
  [3925] = {.lex_state = 14, .external_lex_state = 3},
  [3926] = {.lex_state = 14, .external_lex_state = 3},
  [3927] = {.lex_state = 14, .external_lex_state = 3},
  [3928] = {.lex_state = 14, .external_lex_state = 3},
  [3929] = {.lex_state = 14, .external_lex_state = 3},
  [3930] = {.lex_state = 14, .external_lex_state = 3},
  [3931] = {.lex_state = 14, .external_lex_state = 3},
  [3932] = {.lex_state = 50, .external_lex_state = 7},
  [3933] = {.lex_state = 14, .external_lex_state = 3},
  [3934] = {.lex_state = 14, .external_lex_state = 3},
  [3935] = {.lex_state = 14, .external_lex_state = 3},
  [3936] = {.lex_state = 14, .external_lex_state = 3},
  [3937] = {.lex_state = 14, .external_lex_state = 3},
  [3938] = {.lex_state = 14, .external_lex_state = 3},
  [3939] = {.lex_state = 14, .external_lex_state = 3},
  [3940] = {.lex_state = 14, .external_lex_state = 3},
  [3941] = {.lex_state = 14, .external_lex_state = 3},
  [3942] = {.lex_state = 14, .external_lex_state = 3},
  [3943] = {.lex_state = 14, .external_lex_state = 3},
  [3944] = {.lex_state = 14, .external_lex_state = 3},
  [3945] = {.lex_state = 14, .external_lex_state = 3},
  [3946] = {.lex_state = 14, .external_lex_state = 3},
  [3947] = {.lex_state = 14, .external_lex_state = 3},
  [3948] = {.lex_state = 14, .external_lex_state = 3},
  [3949] = {.lex_state = 14, .external_lex_state = 3},
  [3950] = {.lex_state = 14, .external_lex_state = 3},
  [3951] = {.lex_state = 14, .external_lex_state = 2},
  [3952] = {.lex_state = 14, .external_lex_state = 3},
  [3953] = {.lex_state = 14, .external_lex_state = 3},
  [3954] = {.lex_state = 14, .external_lex_state = 3},
  [3955] = {.lex_state = 14, .external_lex_state = 3},
  [3956] = {.lex_state = 14, .external_lex_state = 3},
  [3957] = {.lex_state = 14, .external_lex_state = 3},
  [3958] = {.lex_state = 14, .external_lex_state = 3},
  [3959] = {.lex_state = 14, .external_lex_state = 3},
  [3960] = {.lex_state = 14, .external_lex_state = 2},
  [3961] = {.lex_state = 14, .external_lex_state = 3},
  [3962] = {.lex_state = 14, .external_lex_state = 3},
  [3963] = {.lex_state = 14, .external_lex_state = 3},
  [3964] = {.lex_state = 14, .external_lex_state = 3},
  [3965] = {.lex_state = 14, .external_lex_state = 3},
  [3966] = {.lex_state = 14, .external_lex_state = 3},
  [3967] = {.lex_state = 14, .external_lex_state = 3},
  [3968] = {.lex_state = 14, .external_lex_state = 3},
  [3969] = {.lex_state = 14, .external_lex_state = 3},
  [3970] = {.lex_state = 14, .external_lex_state = 3},
  [3971] = {.lex_state = 14, .external_lex_state = 3},
  [3972] = {.lex_state = 14, .external_lex_state = 3},
  [3973] = {.lex_state = 14, .external_lex_state = 3},
  [3974] = {.lex_state = 14, .external_lex_state = 3},
  [3975] = {.lex_state = 14, .external_lex_state = 3},
  [3976] = {.lex_state = 50, .external_lex_state = 8},
  [3977] = {.lex_state = 14, .external_lex_state = 3},
  [3978] = {.lex_state = 14, .external_lex_state = 3},
  [3979] = {.lex_state = 14, .external_lex_state = 3},
  [3980] = {.lex_state = 14, .external_lex_state = 3},
  [3981] = {.lex_state = 14, .external_lex_state = 3},
  [3982] = {.lex_state = 14, .external_lex_state = 3},
  [3983] = {.lex_state = 14, .external_lex_state = 3},
  [3984] = {.lex_state = 14, .external_lex_state = 3},
  [3985] = {.lex_state = 14, .external_lex_state = 3},
  [3986] = {.lex_state = 14, .external_lex_state = 3},
  [3987] = {.lex_state = 14, .external_lex_state = 3},
  [3988] = {.lex_state = 14, .external_lex_state = 3},
  [3989] = {.lex_state = 14, .external_lex_state = 3},
  [3990] = {.lex_state = 14, .external_lex_state = 3},
  [3991] = {.lex_state = 14, .external_lex_state = 3},
  [3992] = {.lex_state = 14, .external_lex_state = 3},
  [3993] = {.lex_state = 14, .external_lex_state = 3},
  [3994] = {.lex_state = 14, .external_lex_state = 3},
  [3995] = {.lex_state = 14, .external_lex_state = 3},
  [3996] = {.lex_state = 14, .external_lex_state = 3},
  [3997] = {.lex_state = 14, .external_lex_state = 3},
  [3998] = {.lex_state = 14, .external_lex_state = 3},
  [3999] = {.lex_state = 14, .external_lex_state = 3},
  [4000] = {.lex_state = 14, .external_lex_state = 3},
  [4001] = {.lex_state = 14, .external_lex_state = 3},
  [4002] = {.lex_state = 14, .external_lex_state = 3},
  [4003] = {.lex_state = 14, .external_lex_state = 3},
  [4004] = {.lex_state = 14, .external_lex_state = 3},
  [4005] = {.lex_state = 14, .external_lex_state = 3},
  [4006] = {.lex_state = 14, .external_lex_state = 3},
  [4007] = {.lex_state = 14, .external_lex_state = 3},
  [4008] = {.lex_state = 14, .external_lex_state = 2},
  [4009] = {.lex_state = 14, .external_lex_state = 3},
  [4010] = {.lex_state = 14, .external_lex_state = 3},
  [4011] = {.lex_state = 14, .external_lex_state = 3},
  [4012] = {.lex_state = 14, .external_lex_state = 2},
  [4013] = {.lex_state = 14, .external_lex_state = 3},
  [4014] = {.lex_state = 14, .external_lex_state = 3},
  [4015] = {.lex_state = 14, .external_lex_state = 3},
  [4016] = {.lex_state = 14, .external_lex_state = 3},
  [4017] = {.lex_state = 14, .external_lex_state = 3},
  [4018] = {.lex_state = 14, .external_lex_state = 3},
  [4019] = {.lex_state = 14, .external_lex_state = 3},
  [4020] = {.lex_state = 50, .external_lex_state = 8},
  [4021] = {.lex_state = 50, .external_lex_state = 7},
  [4022] = {.lex_state = 14, .external_lex_state = 3},
  [4023] = {.lex_state = 14, .external_lex_state = 3},
  [4024] = {.lex_state = 14, .external_lex_state = 3},
  [4025] = {.lex_state = 14, .external_lex_state = 4},
  [4026] = {.lex_state = 50, .external_lex_state = 10},
  [4027] = {.lex_state = 50, .external_lex_state = 10},
  [4028] = {.lex_state = 50, .external_lex_state = 11},
  [4029] = {.lex_state = 50, .external_lex_state = 9},
  [4030] = {.lex_state = 50, .external_lex_state = 11},
  [4031] = {.lex_state = 50, .external_lex_state = 12},
  [4032] = {.lex_state = 14, .external_lex_state = 4},
  [4033] = {.lex_state = 50, .external_lex_state = 12},
  [4034] = {.lex_state = 50, .external_lex_state = 9},
  [4035] = {.lex_state = 50, .external_lex_state = 6},
  [4036] = {.lex_state = 50, .external_lex_state = 14},
  [4037] = {.lex_state = 50, .external_lex_state = 13},
  [4038] = {.lex_state = 50, .external_lex_state = 15},
  [4039] = {.lex_state = 50, .external_lex_state = 14},
  [4040] = {.lex_state = 14, .external_lex_state = 2},
  [4041] = {.lex_state = 50, .external_lex_state = 15},
  [4042] = {.lex_state = 14, .external_lex_state = 2},
  [4043] = {.lex_state = 50, .external_lex_state = 19},
  [4044] = {.lex_state = 50, .external_lex_state = 19},
  [4045] = {.lex_state = 50, .external_lex_state = 13},
  [4046] = {.lex_state = 14, .external_lex_state = 2},
  [4047] = {.lex_state = 14, .external_lex_state = 2},
  [4048] = {.lex_state = 50, .external_lex_state = 6},
  [4049] = {.lex_state = 50, .external_lex_state = 18},
  [4050] = {.lex_state = 50, .external_lex_state = 20},
  [4051] = {.lex_state = 50, .external_lex_state = 17},
  [4052] = {.lex_state = 50, .external_lex_state = 17},
  [4053] = {.lex_state = 50, .external_lex_state = 20},
  [4054] = {.lex_state = 50, .external_lex_state = 8},
  [4055] = {.lex_state = 50, .external_lex_state = 8},
  [4056] = {.lex_state = 54},
  [4057] = {.lex_state = 50, .external_lex_state = 18},
  [4058] = {.lex_state = 50, .external_lex_state = 16},
  [4059] = {.lex_state = 50, .external_lex_state = 7},
  [4060] = {.lex_state = 50, .external_lex_state = 7},
  [4061] = {.lex_state = 50, .external_lex_state = 16},
  [4062] = {.lex_state = 54},
  [4063] = {.lex_state = 50, .external_lex_state = 11},
  [4064] = {.lex_state = 50, .external_lex_state = 11},
  [4065] = {.lex_state = 14, .external_lex_state = 2},
  [4066] = {.lex_state = 50, .external_lex_state = 10},
  [4067] = {.lex_state = 14, .external_lex_state = 2},
  [4068] = {.lex_state = 50, .external_lex_state = 21},
  [4069] = {.lex_state = 50, .external_lex_state = 3},
  [4070] = {.lex_state = 50, .external_lex_state = 21},
  [4071] = {.lex_state = 50, .external_lex_state = 22},
  [4072] = {.lex_state = 50, .external_lex_state = 22},
  [4073] = {.lex_state = 50, .external_lex_state = 3},
  [4074] = {.lex_state = 50, .external_lex_state = 10},
  [4075] = {.lex_state = 50, .external_lex_state = 19},
  [4076] = {.lex_state = 50, .external_lex_state = 2},
  [4077] = {.lex_state = 50, .external_lex_state = 19},
  [4078] = {.lex_state = 50, .external_lex_state = 2},
  [4079] = {.lex_state = 14, .external_lex_state = 2},
  [4080] = {.lex_state = 14, .external_lex_state = 2},
  [4081] = {.lex_state = 14, .external_lex_state = 2},
  [4082] = {.lex_state = 14, .external_lex_state = 2},
  [4083] = {.lex_state = 14, .external_lex_state = 2},
  [4084] = {.lex_state = 14, .external_lex_state = 2},
  [4085] = {.lex_state = 14, .external_lex_state = 2},
  [4086] = {.lex_state = 14, .external_lex_state = 2},
  [4087] = {.lex_state = 14, .external_lex_state = 2},
  [4088] = {.lex_state = 14, .external_lex_state = 2},
  [4089] = {.lex_state = 14, .external_lex_state = 2},
  [4090] = {.lex_state = 50, .external_lex_state = 2},
  [4091] = {.lex_state = 14, .external_lex_state = 2},
  [4092] = {.lex_state = 14, .external_lex_state = 2},
  [4093] = {.lex_state = 14, .external_lex_state = 2},
  [4094] = {.lex_state = 14, .external_lex_state = 2},
  [4095] = {.lex_state = 14, .external_lex_state = 2},
  [4096] = {.lex_state = 14, .external_lex_state = 2},
  [4097] = {.lex_state = 14, .external_lex_state = 2},
  [4098] = {.lex_state = 14, .external_lex_state = 2},
  [4099] = {.lex_state = 14, .external_lex_state = 2},
  [4100] = {.lex_state = 14, .external_lex_state = 2},
  [4101] = {.lex_state = 14, .external_lex_state = 2},
  [4102] = {.lex_state = 14, .external_lex_state = 2},
  [4103] = {.lex_state = 14, .external_lex_state = 2},
  [4104] = {.lex_state = 14, .external_lex_state = 2},
  [4105] = {.lex_state = 14, .external_lex_state = 2},
  [4106] = {.lex_state = 14, .external_lex_state = 2},
  [4107] = {.lex_state = 14, .external_lex_state = 2},
  [4108] = {.lex_state = 14, .external_lex_state = 2},
  [4109] = {.lex_state = 14, .external_lex_state = 2},
  [4110] = {.lex_state = 14, .external_lex_state = 2},
  [4111] = {.lex_state = 14, .external_lex_state = 2},
  [4112] = {.lex_state = 14, .external_lex_state = 2},
  [4113] = {.lex_state = 14, .external_lex_state = 2},
  [4114] = {.lex_state = 14, .external_lex_state = 2},
  [4115] = {.lex_state = 14, .external_lex_state = 2},
  [4116] = {.lex_state = 14, .external_lex_state = 2},
  [4117] = {.lex_state = 14, .external_lex_state = 2},
  [4118] = {.lex_state = 14, .external_lex_state = 2},
  [4119] = {.lex_state = 14, .external_lex_state = 2},
  [4120] = {.lex_state = 14, .external_lex_state = 2},
  [4121] = {.lex_state = 14, .external_lex_state = 2},
  [4122] = {.lex_state = 14, .external_lex_state = 2},
  [4123] = {.lex_state = 14, .external_lex_state = 2},
  [4124] = {.lex_state = 14, .external_lex_state = 2},
  [4125] = {.lex_state = 14, .external_lex_state = 2},
  [4126] = {.lex_state = 14, .external_lex_state = 2},
  [4127] = {.lex_state = 14, .external_lex_state = 2},
  [4128] = {.lex_state = 14, .external_lex_state = 2},
  [4129] = {.lex_state = 14, .external_lex_state = 2},
  [4130] = {.lex_state = 14, .external_lex_state = 2},
  [4131] = {.lex_state = 14, .external_lex_state = 2},
  [4132] = {.lex_state = 14, .external_lex_state = 2},
  [4133] = {.lex_state = 14, .external_lex_state = 2},
  [4134] = {.lex_state = 14, .external_lex_state = 2},
  [4135] = {.lex_state = 14, .external_lex_state = 2},
  [4136] = {.lex_state = 14, .external_lex_state = 2},
  [4137] = {.lex_state = 63, .external_lex_state = 23},
  [4138] = {.lex_state = 63, .external_lex_state = 23},
  [4139] = {.lex_state = 14, .external_lex_state = 2},
  [4140] = {.lex_state = 14, .external_lex_state = 2},
  [4141] = {.lex_state = 52, .external_lex_state = 23},
  [4142] = {.lex_state = 14, .external_lex_state = 2},
  [4143] = {.lex_state = 14, .external_lex_state = 2},
  [4144] = {.lex_state = 14, .external_lex_state = 2},
  [4145] = {.lex_state = 52, .external_lex_state = 24},
  [4146] = {.lex_state = 52, .external_lex_state = 23},
  [4147] = {.lex_state = 14, .external_lex_state = 2},
  [4148] = {.lex_state = 14, .external_lex_state = 2},
  [4149] = {.lex_state = 63, .external_lex_state = 23},
  [4150] = {.lex_state = 63, .external_lex_state = 23},
  [4151] = {.lex_state = 14, .external_lex_state = 2},
  [4152] = {.lex_state = 14, .external_lex_state = 2},
  [4153] = {.lex_state = 14, .external_lex_state = 2},
  [4154] = {.lex_state = 14, .external_lex_state = 2},
  [4155] = {.lex_state = 63, .external_lex_state = 23},
  [4156] = {.lex_state = 52, .external_lex_state = 23},
  [4157] = {.lex_state = 14, .external_lex_state = 2},
  [4158] = {.lex_state = 52, .external_lex_state = 23},
  [4159] = {.lex_state = 63, .external_lex_state = 23},
  [4160] = {.lex_state = 63, .external_lex_state = 23},
  [4161] = {.lex_state = 2, .external_lex_state = 2},
  [4162] = {.lex_state = 52, .external_lex_state = 23},
  [4163] = {.lex_state = 63, .external_lex_state = 23},
  [4164] = {.lex_state = 2, .external_lex_state = 2},
  [4165] = {.lex_state = 63, .external_lex_state = 23},
  [4166] = {.lex_state = 52, .external_lex_state = 24},
  [4167] = {.lex_state = 14, .external_lex_state = 2},
  [4168] = {.lex_state = 52, .external_lex_state = 24},
  [4169] = {.lex_state = 14, .external_lex_state = 2},
  [4170] = {.lex_state = 63, .external_lex_state = 23},
  [4171] = {.lex_state = 63, .external_lex_state = 23},
  [4172] = {.lex_state = 63, .external_lex_state = 23},
  [4173] = {.lex_state = 14, .external_lex_state = 2},
  [4174] = {.lex_state = 14, .external_lex_state = 2},
  [4175] = {.lex_state = 63, .external_lex_state = 23},
  [4176] = {.lex_state = 63, .external_lex_state = 23},
  [4177] = {.lex_state = 52, .external_lex_state = 23},
  [4178] = {.lex_state = 63, .external_lex_state = 23},
  [4179] = {.lex_state = 54},
  [4180] = {.lex_state = 14, .external_lex_state = 2},
  [4181] = {.lex_state = 14, .external_lex_state = 2},
  [4182] = {.lex_state = 14, .external_lex_state = 2},
  [4183] = {.lex_state = 14, .external_lex_state = 2},
  [4184] = {.lex_state = 14, .external_lex_state = 2},
  [4185] = {.lex_state = 14, .external_lex_state = 2},
  [4186] = {.lex_state = 14, .external_lex_state = 2},
  [4187] = {.lex_state = 14, .external_lex_state = 2},
  [4188] = {.lex_state = 14, .external_lex_state = 2},
  [4189] = {.lex_state = 14, .external_lex_state = 2},
  [4190] = {.lex_state = 14, .external_lex_state = 2},
  [4191] = {.lex_state = 14, .external_lex_state = 2},
  [4192] = {.lex_state = 14, .external_lex_state = 2},
  [4193] = {.lex_state = 14, .external_lex_state = 2},
  [4194] = {.lex_state = 14, .external_lex_state = 2},
  [4195] = {.lex_state = 14, .external_lex_state = 2},
  [4196] = {.lex_state = 14, .external_lex_state = 2},
  [4197] = {.lex_state = 14, .external_lex_state = 2},
  [4198] = {.lex_state = 14, .external_lex_state = 2},
  [4199] = {.lex_state = 14, .external_lex_state = 2},
  [4200] = {.lex_state = 14, .external_lex_state = 2},
  [4201] = {.lex_state = 14, .external_lex_state = 2},
  [4202] = {.lex_state = 14, .external_lex_state = 2},
  [4203] = {.lex_state = 14, .external_lex_state = 2},
  [4204] = {.lex_state = 14, .external_lex_state = 2},
  [4205] = {.lex_state = 14, .external_lex_state = 2},
  [4206] = {.lex_state = 14, .external_lex_state = 2},
  [4207] = {.lex_state = 14, .external_lex_state = 2},
  [4208] = {.lex_state = 14, .external_lex_state = 2},
  [4209] = {.lex_state = 14, .external_lex_state = 2},
  [4210] = {.lex_state = 14, .external_lex_state = 2},
  [4211] = {.lex_state = 14, .external_lex_state = 2},
  [4212] = {.lex_state = 14, .external_lex_state = 2},
  [4213] = {.lex_state = 14, .external_lex_state = 2},
  [4214] = {.lex_state = 14, .external_lex_state = 2},
  [4215] = {.lex_state = 14, .external_lex_state = 2},
  [4216] = {.lex_state = 14, .external_lex_state = 2},
  [4217] = {.lex_state = 14, .external_lex_state = 2},
  [4218] = {.lex_state = 14, .external_lex_state = 2},
  [4219] = {.lex_state = 14, .external_lex_state = 2},
  [4220] = {.lex_state = 14, .external_lex_state = 2},
  [4221] = {.lex_state = 14, .external_lex_state = 2},
  [4222] = {.lex_state = 14, .external_lex_state = 2},
  [4223] = {.lex_state = 14, .external_lex_state = 2},
  [4224] = {.lex_state = 14, .external_lex_state = 2},
  [4225] = {.lex_state = 14, .external_lex_state = 2},
  [4226] = {.lex_state = 14, .external_lex_state = 2},
  [4227] = {.lex_state = 14, .external_lex_state = 2},
  [4228] = {.lex_state = 14, .external_lex_state = 2},
  [4229] = {.lex_state = 14, .external_lex_state = 2},
  [4230] = {.lex_state = 14, .external_lex_state = 2},
  [4231] = {.lex_state = 14, .external_lex_state = 2},
  [4232] = {.lex_state = 14, .external_lex_state = 2},
  [4233] = {.lex_state = 14, .external_lex_state = 2},
  [4234] = {.lex_state = 14, .external_lex_state = 2},
  [4235] = {.lex_state = 14, .external_lex_state = 2},
  [4236] = {.lex_state = 14, .external_lex_state = 2},
  [4237] = {.lex_state = 14, .external_lex_state = 2},
  [4238] = {.lex_state = 14, .external_lex_state = 2},
  [4239] = {.lex_state = 14, .external_lex_state = 2},
  [4240] = {.lex_state = 14, .external_lex_state = 2},
  [4241] = {.lex_state = 14, .external_lex_state = 2},
  [4242] = {.lex_state = 14, .external_lex_state = 2},
  [4243] = {.lex_state = 14, .external_lex_state = 2},
  [4244] = {.lex_state = 50, .external_lex_state = 3},
  [4245] = {.lex_state = 54},
  [4246] = {.lex_state = 54, .external_lex_state = 25},
  [4247] = {.lex_state = 52, .external_lex_state = 24},
  [4248] = {.lex_state = 54, .external_lex_state = 25},
  [4249] = {.lex_state = 54},
  [4250] = {.lex_state = 54, .external_lex_state = 25},
  [4251] = {.lex_state = 54, .external_lex_state = 25},
  [4252] = {.lex_state = 54, .external_lex_state = 25},
  [4253] = {.lex_state = 52, .external_lex_state = 23},
  [4254] = {.lex_state = 63},
  [4255] = {.lex_state = 57, .external_lex_state = 26},
  [4256] = {.lex_state = 54},
  [4257] = {.lex_state = 63, .external_lex_state = 26},
  [4258] = {.lex_state = 63},
  [4259] = {.lex_state = 63},
  [4260] = {.lex_state = 63},
  [4261] = {.lex_state = 54},
  [4262] = {.lex_state = 54},
  [4263] = {.lex_state = 52, .external_lex_state = 23},
  [4264] = {.lex_state = 56, .external_lex_state = 26},
  [4265] = {.lex_state = 54},
  [4266] = {.lex_state = 54},
  [4267] = {.lex_state = 52, .external_lex_state = 27},
  [4268] = {.lex_state = 54},
  [4269] = {.lex_state = 63},
  [4270] = {.lex_state = 63},
  [4271] = {.lex_state = 63},
  [4272] = {.lex_state = 63},
  [4273] = {.lex_state = 63},
  [4274] = {.lex_state = 63},
  [4275] = {.lex_state = 54},
  [4276] = {.lex_state = 54},
  [4277] = {.lex_state = 54},
  [4278] = {.lex_state = 52, .external_lex_state = 28},
  [4279] = {.lex_state = 56, .external_lex_state = 26},
  [4280] = {.lex_state = 63},
  [4281] = {.lex_state = 63},
  [4282] = {.lex_state = 63},
  [4283] = {.lex_state = 63, .external_lex_state = 29},
  [4284] = {.lex_state = 63},
  [4285] = {.lex_state = 57, .external_lex_state = 29},
  [4286] = {.lex_state = 57, .external_lex_state = 26},
  [4287] = {.lex_state = 63},
  [4288] = {.lex_state = 63},
  [4289] = {.lex_state = 57, .external_lex_state = 26},
  [4290] = {.lex_state = 61, .external_lex_state = 26},
  [4291] = {.lex_state = 54},
  [4292] = {.lex_state = 58, .external_lex_state = 26},
  [4293] = {.lex_state = 56, .external_lex_state = 30},
  [4294] = {.lex_state = 54},
  [4295] = {.lex_state = 54},
  [4296] = {.lex_state = 54, .external_lex_state = 25},
  [4297] = {.lex_state = 63},
  [4298] = {.lex_state = 54, .external_lex_state = 25},
  [4299] = {.lex_state = 54, .external_lex_state = 25},
  [4300] = {.lex_state = 63},
  [4301] = {.lex_state = 54, .external_lex_state = 25},
  [4302] = {.lex_state = 63},
  [4303] = {.lex_state = 63},
  [4304] = {.lex_state = 63},
  [4305] = {.lex_state = 63},
  [4306] = {.lex_state = 63},
  [4307] = {.lex_state = 63},
  [4308] = {.lex_state = 63},
  [4309] = {.lex_state = 63},
  [4310] = {.lex_state = 63},
  [4311] = {.lex_state = 63},
  [4312] = {.lex_state = 63},
  [4313] = {.lex_state = 63},
  [4314] = {.lex_state = 63},
  [4315] = {.lex_state = 63},
  [4316] = {.lex_state = 63},
  [4317] = {.lex_state = 63},
  [4318] = {.lex_state = 54, .external_lex_state = 25},
  [4319] = {.lex_state = 54, .external_lex_state = 25},
  [4320] = {.lex_state = 63},
  [4321] = {.lex_state = 63},
  [4322] = {.lex_state = 54, .external_lex_state = 25},
  [4323] = {.lex_state = 63},
  [4324] = {.lex_state = 63},
  [4325] = {.lex_state = 54, .external_lex_state = 25},
  [4326] = {.lex_state = 63},
  [4327] = {.lex_state = 63},
  [4328] = {.lex_state = 63},
  [4329] = {.lex_state = 63},
  [4330] = {.lex_state = 63},
  [4331] = {.lex_state = 63},
  [4332] = {.lex_state = 54, .external_lex_state = 25},
  [4333] = {.lex_state = 63, .external_lex_state = 26},
  [4334] = {.lex_state = 63},
  [4335] = {.lex_state = 54, .external_lex_state = 25},
  [4336] = {.lex_state = 63},
  [4337] = {.lex_state = 63},
  [4338] = {.lex_state = 54, .external_lex_state = 25},
  [4339] = {.lex_state = 63},
  [4340] = {.lex_state = 63},
  [4341] = {.lex_state = 63},
  [4342] = {.lex_state = 63},
  [4343] = {.lex_state = 63},
  [4344] = {.lex_state = 63},
  [4345] = {.lex_state = 63},
  [4346] = {.lex_state = 63},
  [4347] = {.lex_state = 63},
  [4348] = {.lex_state = 52, .external_lex_state = 31},
  [4349] = {.lex_state = 63},
  [4350] = {.lex_state = 63},
  [4351] = {.lex_state = 63},
  [4352] = {.lex_state = 63},
  [4353] = {.lex_state = 54},
  [4354] = {.lex_state = 63},
  [4355] = {.lex_state = 54},
  [4356] = {.lex_state = 63},
  [4357] = {.lex_state = 63},
  [4358] = {.lex_state = 63},
  [4359] = {.lex_state = 63},
  [4360] = {.lex_state = 63},
  [4361] = {.lex_state = 54, .external_lex_state = 25},
  [4362] = {.lex_state = 54, .external_lex_state = 25},
  [4363] = {.lex_state = 54, .external_lex_state = 25},
  [4364] = {.lex_state = 63},
  [4365] = {.lex_state = 63},
  [4366] = {.lex_state = 63},
  [4367] = {.lex_state = 54},
  [4368] = {.lex_state = 54},
  [4369] = {.lex_state = 54},
  [4370] = {.lex_state = 57, .external_lex_state = 30},
  [4371] = {.lex_state = 63},
  [4372] = {.lex_state = 54},
  [4373] = {.lex_state = 63},
  [4374] = {.lex_state = 63},
  [4375] = {.lex_state = 63},
  [4376] = {.lex_state = 63, .external_lex_state = 30},
  [4377] = {.lex_state = 63},
  [4378] = {.lex_state = 56, .external_lex_state = 29},
  [4379] = {.lex_state = 61, .external_lex_state = 26},
  [4380] = {.lex_state = 61, .external_lex_state = 26},
  [4381] = {.lex_state = 54},
  [4382] = {.lex_state = 54, .external_lex_state = 25},
  [4383] = {.lex_state = 52, .external_lex_state = 26},
  [4384] = {.lex_state = 56, .external_lex_state = 26},
  [4385] = {.lex_state = 56, .external_lex_state = 30},
  [4386] = {.lex_state = 61, .external_lex_state = 26},
  [4387] = {.lex_state = 61, .external_lex_state = 26},
  [4388] = {.lex_state = 56, .external_lex_state = 32},
  [4389] = {.lex_state = 63, .external_lex_state = 30},
  [4390] = {.lex_state = 56, .external_lex_state = 33},
  [4391] = {.lex_state = 52, .external_lex_state = 26},
  [4392] = {.lex_state = 63},
  [4393] = {.lex_state = 57, .external_lex_state = 30},
  [4394] = {.lex_state = 61, .external_lex_state = 30},
  [4395] = {.lex_state = 56, .external_lex_state = 26},
  [4396] = {.lex_state = 57, .external_lex_state = 30},
  [4397] = {.lex_state = 58, .external_lex_state = 30},
  [4398] = {.lex_state = 56, .external_lex_state = 26},
  [4399] = {.lex_state = 56, .external_lex_state = 26},
  [4400] = {.lex_state = 63},
  [4401] = {.lex_state = 54},
  [4402] = {.lex_state = 63},
  [4403] = {.lex_state = 63},
  [4404] = {.lex_state = 52, .external_lex_state = 26},
  [4405] = {.lex_state = 63},
  [4406] = {.lex_state = 52, .external_lex_state = 27},
  [4407] = {.lex_state = 63},
  [4408] = {.lex_state = 63},
  [4409] = {.lex_state = 61, .external_lex_state = 30},
  [4410] = {.lex_state = 63},
  [4411] = {.lex_state = 52, .external_lex_state = 27},
  [4412] = {.lex_state = 56, .external_lex_state = 34},
  [4413] = {.lex_state = 61, .external_lex_state = 30},
  [4414] = {.lex_state = 63},
  [4415] = {.lex_state = 63},
  [4416] = {.lex_state = 58, .external_lex_state = 29},
  [4417] = {.lex_state = 63},
  [4418] = {.lex_state = 63},
  [4419] = {.lex_state = 63},
  [4420] = {.lex_state = 63},
  [4421] = {.lex_state = 63},
  [4422] = {.lex_state = 63},
  [4423] = {.lex_state = 63},
  [4424] = {.lex_state = 63},
  [4425] = {.lex_state = 63},
  [4426] = {.lex_state = 63, .external_lex_state = 34},
  [4427] = {.lex_state = 63},
  [4428] = {.lex_state = 63, .external_lex_state = 29},
  [4429] = {.lex_state = 63},
  [4430] = {.lex_state = 63},
  [4431] = {.lex_state = 63},
  [4432] = {.lex_state = 63},
  [4433] = {.lex_state = 63},
  [4434] = {.lex_state = 63},
  [4435] = {.lex_state = 61, .external_lex_state = 29},
  [4436] = {.lex_state = 63},
  [4437] = {.lex_state = 57, .external_lex_state = 34},
  [4438] = {.lex_state = 63},
  [4439] = {.lex_state = 61, .external_lex_state = 29},
  [4440] = {.lex_state = 56, .external_lex_state = 29},
  [4441] = {.lex_state = 63},
  [4442] = {.lex_state = 63},
  [4443] = {.lex_state = 63},
  [4444] = {.lex_state = 63},
  [4445] = {.lex_state = 63, .external_lex_state = 27},
  [4446] = {.lex_state = 63},
  [4447] = {.lex_state = 63, .external_lex_state = 27},
  [4448] = {.lex_state = 63, .external_lex_state = 27},
  [4449] = {.lex_state = 57, .external_lex_state = 29},
  [4450] = {.lex_state = 63, .external_lex_state = 32},
  [4451] = {.lex_state = 52, .external_lex_state = 35},
  [4452] = {.lex_state = 57, .external_lex_state = 32},
  [4453] = {.lex_state = 57, .external_lex_state = 33},
  [4454] = {.lex_state = 63, .external_lex_state = 33},
  [4455] = {.lex_state = 58, .external_lex_state = 26},
  [4456] = {.lex_state = 61, .external_lex_state = 29},
  [4457] = {.lex_state = 63},
  [4458] = {.lex_state = 57, .external_lex_state = 29},
  [4459] = {.lex_state = 63},
  [4460] = {.lex_state = 52, .external_lex_state = 36},
  [4461] = {.lex_state = 63},
  [4462] = {.lex_state = 52, .external_lex_state = 37},
  [4463] = {.lex_state = 63},
  [4464] = {.lex_state = 63},
  [4465] = {.lex_state = 63},
  [4466] = {.lex_state = 63},
  [4467] = {.lex_state = 56, .external_lex_state = 29},
  [4468] = {.lex_state = 56, .external_lex_state = 38},
  [4469] = {.lex_state = 56, .external_lex_state = 30},
  [4470] = {.lex_state = 52, .external_lex_state = 28},
  [4471] = {.lex_state = 52, .external_lex_state = 28},
  [4472] = {.lex_state = 58, .external_lex_state = 26},
  [4473] = {.lex_state = 52, .external_lex_state = 31},
  [4474] = {.lex_state = 58, .external_lex_state = 26},
  [4475] = {.lex_state = 56, .external_lex_state = 30},
  [4476] = {.lex_state = 56, .external_lex_state = 30},
  [4477] = {.lex_state = 56, .external_lex_state = 32},
  [4478] = {.lex_state = 63, .external_lex_state = 26},
  [4479] = {.lex_state = 56, .external_lex_state = 33},
  [4480] = {.lex_state = 63, .external_lex_state = 33},
  [4481] = {.lex_state = 61, .external_lex_state = 34},
  [4482] = {.lex_state = 52, .external_lex_state = 23},
  [4483] = {.lex_state = 52, .external_lex_state = 27},
  [4484] = {.lex_state = 52, .external_lex_state = 31},
  [4485] = {.lex_state = 52, .external_lex_state = 39},
  [4486] = {.lex_state = 57, .external_lex_state = 34},
  [4487] = {.lex_state = 63, .external_lex_state = 26},
  [4488] = {.lex_state = 63, .external_lex_state = 26},
  [4489] = {.lex_state = 52, .external_lex_state = 27},
  [4490] = {.lex_state = 56, .external_lex_state = 26},
  [4491] = {.lex_state = 63, .external_lex_state = 32},
  [4492] = {.lex_state = 57, .external_lex_state = 32},
  [4493] = {.lex_state = 61, .external_lex_state = 26},
  [4494] = {.lex_state = 57, .external_lex_state = 33},
  [4495] = {.lex_state = 58, .external_lex_state = 30},
  [4496] = {.lex_state = 63, .external_lex_state = 40},
  [4497] = {.lex_state = 52, .external_lex_state = 29},
  [4498] = {.lex_state = 58, .external_lex_state = 26},
  [4499] = {.lex_state = 58, .external_lex_state = 26},
  [4500] = {.lex_state = 58, .external_lex_state = 34},
  [4501] = {.lex_state = 56, .external_lex_state = 26},
  [4502] = {.lex_state = 56, .external_lex_state = 26},
  [4503] = {.lex_state = 56, .external_lex_state = 26},
  [4504] = {.lex_state = 56, .external_lex_state = 29},
  [4505] = {.lex_state = 63, .external_lex_state = 31},
  [4506] = {.lex_state = 52, .external_lex_state = 26},
  [4507] = {.lex_state = 52, .external_lex_state = 26},
  [4508] = {.lex_state = 56, .external_lex_state = 26},
  [4509] = {.lex_state = 56, .external_lex_state = 26},
  [4510] = {.lex_state = 58, .external_lex_state = 32},
  [4511] = {.lex_state = 63},
  [4512] = {.lex_state = 52, .external_lex_state = 23},
  [4513] = {.lex_state = 56, .external_lex_state = 40},
  [4514] = {.lex_state = 58, .external_lex_state = 33},
  [4515] = {.lex_state = 52, .external_lex_state = 30},
  [4516] = {.lex_state = 61, .external_lex_state = 26},
  [4517] = {.lex_state = 56, .external_lex_state = 41},
  [4518] = {.lex_state = 57, .external_lex_state = 40},
  [4519] = {.lex_state = 61, .external_lex_state = 30},
  [4520] = {.lex_state = 63, .external_lex_state = 28},
  [4521] = {.lex_state = 63, .external_lex_state = 34},
  [4522] = {.lex_state = 63, .external_lex_state = 28},
  [4523] = {.lex_state = 52, .external_lex_state = 30},
  [4524] = {.lex_state = 57, .external_lex_state = 32},
  [4525] = {.lex_state = 52, .external_lex_state = 30},
  [4526] = {.lex_state = 52, .external_lex_state = 27},
  [4527] = {.lex_state = 57, .external_lex_state = 33},
  [4528] = {.lex_state = 61, .external_lex_state = 32},
  [4529] = {.lex_state = 61, .external_lex_state = 34},
  [4530] = {.lex_state = 52, .external_lex_state = 27},
  [4531] = {.lex_state = 61, .external_lex_state = 33},
  [4532] = {.lex_state = 57, .external_lex_state = 41},
  [4533] = {.lex_state = 56, .external_lex_state = 26},
  [4534] = {.lex_state = 52, .external_lex_state = 29},
  [4535] = {.lex_state = 63, .external_lex_state = 41},
  [4536] = {.lex_state = 61, .external_lex_state = 34},
  [4537] = {.lex_state = 52, .external_lex_state = 29},
  [4538] = {.lex_state = 56, .external_lex_state = 34},
  [4539] = {.lex_state = 56, .external_lex_state = 26},
  [4540] = {.lex_state = 57, .external_lex_state = 38},
  [4541] = {.lex_state = 58, .external_lex_state = 29},
  [4542] = {.lex_state = 56, .external_lex_state = 26},
  [4543] = {.lex_state = 56, .external_lex_state = 26},
  [4544] = {.lex_state = 56, .external_lex_state = 26},
  [4545] = {.lex_state = 56, .external_lex_state = 26},
  [4546] = {.lex_state = 56, .external_lex_state = 26},
  [4547] = {.lex_state = 63, .external_lex_state = 38},
  [4548] = {.lex_state = 56, .external_lex_state = 30},
  [4549] = {.lex_state = 56, .external_lex_state = 29},
  [4550] = {.lex_state = 57, .external_lex_state = 34},
  [4551] = {.lex_state = 56, .external_lex_state = 26},
  [4552] = {.lex_state = 61, .external_lex_state = 29},
  [4553] = {.lex_state = 61, .external_lex_state = 29},
  [4554] = {.lex_state = 58, .external_lex_state = 40},
  [4555] = {.lex_state = 56, .external_lex_state = 29},
  [4556] = {.lex_state = 61, .external_lex_state = 30},
  [4557] = {.lex_state = 61, .external_lex_state = 32},
  [4558] = {.lex_state = 61, .external_lex_state = 33},
  [4559] = {.lex_state = 63, .external_lex_state = 31},
  [4560] = {.lex_state = 52, .external_lex_state = 42},
  [4561] = {.lex_state = 61, .external_lex_state = 32},
  [4562] = {.lex_state = 63, .external_lex_state = 26},
  [4563] = {.lex_state = 63, .external_lex_state = 31},
  [4564] = {.lex_state = 61, .external_lex_state = 33},
  [4565] = {.lex_state = 63, .external_lex_state = 28},
  [4566] = {.lex_state = 63, .external_lex_state = 29},
  [4567] = {.lex_state = 52, .external_lex_state = 33},
  [4568] = {.lex_state = 58, .external_lex_state = 43},
  [4569] = {.lex_state = 61, .external_lex_state = 34},
  [4570] = {.lex_state = 61, .external_lex_state = 34},
  [4571] = {.lex_state = 63, .external_lex_state = 35},
  [4572] = {.lex_state = 56, .external_lex_state = 34},
  [4573] = {.lex_state = 57, .external_lex_state = 26},
  [4574] = {.lex_state = 58, .external_lex_state = 30},
  [4575] = {.lex_state = 54},
  [4576] = {.lex_state = 61, .external_lex_state = 30},
  [4577] = {.lex_state = 61, .external_lex_state = 26},
  [4578] = {.lex_state = 61, .external_lex_state = 26},
  [4579] = {.lex_state = 61, .external_lex_state = 38},
  [4580] = {.lex_state = 52, .external_lex_state = 36},
  [4581] = {.lex_state = 61, .external_lex_state = 26},
  [4582] = {.lex_state = 52, .external_lex_state = 28},
  [4583] = {.lex_state = 52, .external_lex_state = 29},
  [4584] = {.lex_state = 61, .external_lex_state = 30},
  [4585] = {.lex_state = 52, .external_lex_state = 29},
  [4586] = {.lex_state = 63, .external_lex_state = 35},
  [4587] = {.lex_state = 61, .external_lex_state = 41},
  [4588] = {.lex_state = 58, .external_lex_state = 26},
  [4589] = {.lex_state = 63, .external_lex_state = 30},
  [4590] = {.lex_state = 56, .external_lex_state = 38},
  [4591] = {.lex_state = 58, .external_lex_state = 26},
  [4592] = {.lex_state = 61, .external_lex_state = 38},
  [4593] = {.lex_state = 58, .external_lex_state = 26},
  [4594] = {.lex_state = 52, .external_lex_state = 28},
  [4595] = {.lex_state = 58, .external_lex_state = 26},
  [4596] = {.lex_state = 58, .external_lex_state = 26},
  [4597] = {.lex_state = 52, .external_lex_state = 36},
  [4598] = {.lex_state = 58, .external_lex_state = 26},
  [4599] = {.lex_state = 58, .external_lex_state = 26},
  [4600] = {.lex_state = 52, .external_lex_state = 26},
  [4601] = {.lex_state = 58, .external_lex_state = 26},
  [4602] = {.lex_state = 63, .external_lex_state = 29},
  [4603] = {.lex_state = 57, .external_lex_state = 38},
  [4604] = {.lex_state = 56, .external_lex_state = 32},
  [4605] = {.lex_state = 56, .external_lex_state = 32},
  [4606] = {.lex_state = 56, .external_lex_state = 33},
  [4607] = {.lex_state = 63, .external_lex_state = 44},
  [4608] = {.lex_state = 56, .external_lex_state = 33},
  [4609] = {.lex_state = 61, .external_lex_state = 40},
  [4610] = {.lex_state = 56, .external_lex_state = 32},
  [4611] = {.lex_state = 56, .external_lex_state = 34},
  [4612] = {.lex_state = 61, .external_lex_state = 38},
  [4613] = {.lex_state = 52, .external_lex_state = 45},
  [4614] = {.lex_state = 63, .external_lex_state = 30},
  [4615] = {.lex_state = 63, .external_lex_state = 46},
  [4616] = {.lex_state = 63, .external_lex_state = 30},
  [4617] = {.lex_state = 56, .external_lex_state = 47},
  [4618] = {.lex_state = 58, .external_lex_state = 29},
  [4619] = {.lex_state = 58, .external_lex_state = 41},
  [4620] = {.lex_state = 58, .external_lex_state = 29},
  [4621] = {.lex_state = 56, .external_lex_state = 30},
  [4622] = {.lex_state = 52, .external_lex_state = 40},
  [4623] = {.lex_state = 56, .external_lex_state = 33},
  [4624] = {.lex_state = 57, .external_lex_state = 44},
  [4625] = {.lex_state = 58, .external_lex_state = 30},
  [4626] = {.lex_state = 58, .external_lex_state = 30},
  [4627] = {.lex_state = 63, .external_lex_state = 30},
  [4628] = {.lex_state = 52, .external_lex_state = 40},
  [4629] = {.lex_state = 57, .external_lex_state = 40},
  [4630] = {.lex_state = 56, .external_lex_state = 33},
  [4631] = {.lex_state = 52, .external_lex_state = 30},
  [4632] = {.lex_state = 56, .external_lex_state = 26},
  [4633] = {.lex_state = 52, .external_lex_state = 31},
  [4634] = {.lex_state = 52, .external_lex_state = 31},
  [4635] = {.lex_state = 57, .external_lex_state = 46},
  [4636] = {.lex_state = 61, .external_lex_state = 32},
  [4637] = {.lex_state = 63, .external_lex_state = 27},
  [4638] = {.lex_state = 63, .external_lex_state = 36},
  [4639] = {.lex_state = 58, .external_lex_state = 40},
  [4640] = {.lex_state = 57, .external_lex_state = 38},
  [4641] = {.lex_state = 63, .external_lex_state = 36},
  [4642] = {.lex_state = 61, .external_lex_state = 40},
  [4643] = {.lex_state = 63, .external_lex_state = 37},
  [4644] = {.lex_state = 63, .external_lex_state = 36},
  [4645] = {.lex_state = 63, .external_lex_state = 37},
  [4646] = {.lex_state = 58, .external_lex_state = 26},
  [4647] = {.lex_state = 56, .external_lex_state = 44},
  [4648] = {.lex_state = 57, .external_lex_state = 26},
  [4649] = {.lex_state = 63, .external_lex_state = 29},
  [4650] = {.lex_state = 52, .external_lex_state = 30},
  [4651] = {.lex_state = 63, .external_lex_state = 37},
  [4652] = {.lex_state = 63, .external_lex_state = 29},
  [4653] = {.lex_state = 56, .external_lex_state = 29},
  [4654] = {.lex_state = 57, .external_lex_state = 26},
  [4655] = {.lex_state = 56, .external_lex_state = 30},
  [4656] = {.lex_state = 63, .external_lex_state = 47},
  [4657] = {.lex_state = 57, .external_lex_state = 40},
  [4658] = {.lex_state = 52, .external_lex_state = 27},
  [4659] = {.lex_state = 56, .external_lex_state = 30},
  [4660] = {.lex_state = 57, .external_lex_state = 26},
  [4661] = {.lex_state = 56, .external_lex_state = 29},
  [4662] = {.lex_state = 56, .external_lex_state = 30},
  [4663] = {.lex_state = 57, .external_lex_state = 26},
  [4664] = {.lex_state = 56, .external_lex_state = 30},
  [4665] = {.lex_state = 52, .external_lex_state = 48},
  [4666] = {.lex_state = 57, .external_lex_state = 41},
  [4667] = {.lex_state = 56, .external_lex_state = 29},
  [4668] = {.lex_state = 61, .external_lex_state = 32},
  [4669] = {.lex_state = 52, .external_lex_state = 37},
  [4670] = {.lex_state = 52, .external_lex_state = 35},
  [4671] = {.lex_state = 57, .external_lex_state = 26},
  [4672] = {.lex_state = 56, .external_lex_state = 30},
  [4673] = {.lex_state = 63, .external_lex_state = 40},
  [4674] = {.lex_state = 56, .external_lex_state = 29},
  [4675] = {.lex_state = 57, .external_lex_state = 26},
  [4676] = {.lex_state = 58, .external_lex_state = 32},
  [4677] = {.lex_state = 58, .external_lex_state = 34},
  [4678] = {.lex_state = 58, .external_lex_state = 26},
  [4679] = {.lex_state = 52, .external_lex_state = 26},
  [4680] = {.lex_state = 52, .external_lex_state = 34},
  [4681] = {.lex_state = 58, .external_lex_state = 33},
  [4682] = {.lex_state = 57, .external_lex_state = 41},
  [4683] = {.lex_state = 58, .external_lex_state = 26},
  [4684] = {.lex_state = 56, .external_lex_state = 29},
  [4685] = {.lex_state = 52, .external_lex_state = 35},
  [4686] = {.lex_state = 52, .external_lex_state = 32},
  [4687] = {.lex_state = 56, .external_lex_state = 29},
  [4688] = {.lex_state = 58, .external_lex_state = 26},
  [4689] = {.lex_state = 52, .external_lex_state = 40},
  [4690] = {.lex_state = 61, .external_lex_state = 29},
  [4691] = {.lex_state = 61, .external_lex_state = 26},
  [4692] = {.lex_state = 57, .external_lex_state = 26},
  [4693] = {.lex_state = 57, .external_lex_state = 26},
  [4694] = {.lex_state = 61, .external_lex_state = 40},
  [4695] = {.lex_state = 52, .external_lex_state = 33},
  [4696] = {.lex_state = 57, .external_lex_state = 26},
  [4697] = {.lex_state = 52, .external_lex_state = 49},
  [4698] = {.lex_state = 58, .external_lex_state = 38},
  [4699] = {.lex_state = 52, .external_lex_state = 31},
  [4700] = {.lex_state = 56, .external_lex_state = 30},
  [4701] = {.lex_state = 57, .external_lex_state = 26},
  [4702] = {.lex_state = 58, .external_lex_state = 30},
  [4703] = {.lex_state = 61, .external_lex_state = 29},
  [4704] = {.lex_state = 56, .external_lex_state = 30},
  [4705] = {.lex_state = 56, .external_lex_state = 29},
  [4706] = {.lex_state = 56, .external_lex_state = 46},
  [4707] = {.lex_state = 52, .external_lex_state = 42},
  [4708] = {.lex_state = 52, .external_lex_state = 28},
  [4709] = {.lex_state = 61, .external_lex_state = 33},
  [4710] = {.lex_state = 52, .external_lex_state = 32},
  [4711] = {.lex_state = 57, .external_lex_state = 26},
  [4712] = {.lex_state = 57, .external_lex_state = 50},
  [4713] = {.lex_state = 56, .external_lex_state = 29},
  [4714] = {.lex_state = 52, .external_lex_state = 33},
  [4715] = {.lex_state = 56, .external_lex_state = 29},
  [4716] = {.lex_state = 57, .external_lex_state = 26},
  [4717] = {.lex_state = 56, .external_lex_state = 29},
  [4718] = {.lex_state = 56, .external_lex_state = 29},
  [4719] = {.lex_state = 56, .external_lex_state = 29},
  [4720] = {.lex_state = 56, .external_lex_state = 34},
  [4721] = {.lex_state = 56, .external_lex_state = 30},
  [4722] = {.lex_state = 56, .external_lex_state = 29},
  [4723] = {.lex_state = 56, .external_lex_state = 30},
  [4724] = {.lex_state = 61, .external_lex_state = 41},
  [4725] = {.lex_state = 56, .external_lex_state = 29},
  [4726] = {.lex_state = 57, .external_lex_state = 26},
  [4727] = {.lex_state = 57, .external_lex_state = 26},
  [4728] = {.lex_state = 61, .external_lex_state = 41},
  [4729] = {.lex_state = 56, .external_lex_state = 26},
  [4730] = {.lex_state = 56, .external_lex_state = 26},
  [4731] = {.lex_state = 58, .external_lex_state = 29},
  [4732] = {.lex_state = 63, .external_lex_state = 50},
  [4733] = {.lex_state = 61, .external_lex_state = 33},
  [4734] = {.lex_state = 56, .external_lex_state = 34},
  [4735] = {.lex_state = 52, .external_lex_state = 42},
  [4736] = {.lex_state = 58, .external_lex_state = 26},
  [4737] = {.lex_state = 52, .external_lex_state = 32},
  [4738] = {.lex_state = 56, .external_lex_state = 32},
  [4739] = {.lex_state = 56, .external_lex_state = 50},
  [4740] = {.lex_state = 52, .external_lex_state = 51},
  [4741] = {.lex_state = 57, .external_lex_state = 26},
  [4742] = {.lex_state = 56, .external_lex_state = 30},
  [4743] = {.lex_state = 52, .external_lex_state = 34},
  [4744] = {.lex_state = 56, .external_lex_state = 41},
  [4745] = {.lex_state = 56, .external_lex_state = 30},
  [4746] = {.lex_state = 52, .external_lex_state = 34},
  [4747] = {.lex_state = 63, .external_lex_state = 38},
  [4748] = {.lex_state = 57, .external_lex_state = 47},
  [4749] = {.lex_state = 52, .external_lex_state = 31},
  [4750] = {.lex_state = 57, .external_lex_state = 26},
  [4751] = {.lex_state = 56, .external_lex_state = 30},
  [4752] = {.lex_state = 52, .external_lex_state = 28},
  [4753] = {.lex_state = 56, .external_lex_state = 40},
  [4754] = {.lex_state = 63, .external_lex_state = 41},
  [4755] = {.lex_state = 63, .external_lex_state = 35},
  [4756] = {.lex_state = 56, .external_lex_state = 30},
  [4757] = {.lex_state = 58, .external_lex_state = 29},
  [4758] = {.lex_state = 63, .external_lex_state = 31},
  [4759] = {.lex_state = 63, .external_lex_state = 27},
  [4760] = {.lex_state = 56, .external_lex_state = 34},
  [4761] = {.lex_state = 52, .external_lex_state = 36},
  [4762] = {.lex_state = 56, .external_lex_state = 34},
  [4763] = {.lex_state = 63, .external_lex_state = 32},
  [4764] = {.lex_state = 52, .external_lex_state = 36},
  [4765] = {.lex_state = 56, .external_lex_state = 34},
  [4766] = {.lex_state = 58, .external_lex_state = 29},
  [4767] = {.lex_state = 56, .external_lex_state = 34},
  [4768] = {.lex_state = 63, .external_lex_state = 50},
  [4769] = {.lex_state = 52, .external_lex_state = 26},
  [4770] = {.lex_state = 56, .external_lex_state = 34},
  [4771] = {.lex_state = 58, .external_lex_state = 33},
  [4772] = {.lex_state = 63, .external_lex_state = 33},
  [4773] = {.lex_state = 56, .external_lex_state = 32},
  [4774] = {.lex_state = 56, .external_lex_state = 34},
  [4775] = {.lex_state = 58, .external_lex_state = 26},
  [4776] = {.lex_state = 52, .external_lex_state = 41},
  [4777] = {.lex_state = 52, .external_lex_state = 32},
  [4778] = {.lex_state = 52, .external_lex_state = 32},
  [4779] = {.lex_state = 56, .external_lex_state = 32},
  [4780] = {.lex_state = 56, .external_lex_state = 32},
  [4781] = {.lex_state = 56, .external_lex_state = 32},
  [4782] = {.lex_state = 56, .external_lex_state = 29},
  [4783] = {.lex_state = 56, .external_lex_state = 34},
  [4784] = {.lex_state = 56, .external_lex_state = 32},
  [4785] = {.lex_state = 56, .external_lex_state = 33},
  [4786] = {.lex_state = 56, .external_lex_state = 34},
  [4787] = {.lex_state = 56, .external_lex_state = 33},
  [4788] = {.lex_state = 56, .external_lex_state = 33},
  [4789] = {.lex_state = 57, .external_lex_state = 29},
  [4790] = {.lex_state = 56, .external_lex_state = 34},
  [4791] = {.lex_state = 52, .external_lex_state = 33},
  [4792] = {.lex_state = 52, .external_lex_state = 26},
  [4793] = {.lex_state = 56, .external_lex_state = 41},
  [4794] = {.lex_state = 52, .external_lex_state = 27},
  [4795] = {.lex_state = 52, .external_lex_state = 33},
  [4796] = {.lex_state = 52, .external_lex_state = 26},
  [4797] = {.lex_state = 63, .external_lex_state = 23},
  [4798] = {.lex_state = 52, .external_lex_state = 26},
  [4799] = {.lex_state = 56, .external_lex_state = 33},
  [4800] = {.lex_state = 63, .external_lex_state = 32},
  [4801] = {.lex_state = 56, .external_lex_state = 33},
  [4802] = {.lex_state = 58, .external_lex_state = 29},
  [4803] = {.lex_state = 58, .external_lex_state = 29},
  [4804] = {.lex_state = 52, .external_lex_state = 38},
  [4805] = {.lex_state = 58, .external_lex_state = 29},
  [4806] = {.lex_state = 61, .external_lex_state = 41},
  [4807] = {.lex_state = 56, .external_lex_state = 29},
  [4808] = {.lex_state = 56, .external_lex_state = 29},
  [4809] = {.lex_state = 52, .external_lex_state = 36},
  [4810] = {.lex_state = 57, .external_lex_state = 29},
  [4811] = {.lex_state = 58, .external_lex_state = 40},
  [4812] = {.lex_state = 61, .external_lex_state = 41},
  [4813] = {.lex_state = 56, .external_lex_state = 32},
  [4814] = {.lex_state = 56, .external_lex_state = 32},
  [4815] = {.lex_state = 56, .external_lex_state = 32},
  [4816] = {.lex_state = 61, .external_lex_state = 50},
  [4817] = {.lex_state = 56, .external_lex_state = 52},
  [4818] = {.lex_state = 56, .external_lex_state = 32},
  [4819] = {.lex_state = 56, .external_lex_state = 32},
  [4820] = {.lex_state = 57, .external_lex_state = 29},
  [4821] = {.lex_state = 56, .external_lex_state = 32},
  [4822] = {.lex_state = 56, .external_lex_state = 32},
  [4823] = {.lex_state = 61, .external_lex_state = 30},
  [4824] = {.lex_state = 58, .external_lex_state = 29},
  [4825] = {.lex_state = 57, .external_lex_state = 29},
  [4826] = {.lex_state = 61, .external_lex_state = 26},
  [4827] = {.lex_state = 57, .external_lex_state = 29},
  [4828] = {.lex_state = 57, .external_lex_state = 29},
  [4829] = {.lex_state = 57, .external_lex_state = 29},
  [4830] = {.lex_state = 56, .external_lex_state = 33},
  [4831] = {.lex_state = 55, .external_lex_state = 53},
  [4832] = {.lex_state = 57, .external_lex_state = 29},
  [4833] = {.lex_state = 56, .external_lex_state = 38},
  [4834] = {.lex_state = 57, .external_lex_state = 29},
  [4835] = {.lex_state = 56, .external_lex_state = 33},
  [4836] = {.lex_state = 56, .external_lex_state = 33},
  [4837] = {.lex_state = 63, .external_lex_state = 26},
  [4838] = {.lex_state = 61, .external_lex_state = 38},
  [4839] = {.lex_state = 61, .external_lex_state = 38},
  [4840] = {.lex_state = 57, .external_lex_state = 50},
  [4841] = {.lex_state = 61, .external_lex_state = 30},
  [4842] = {.lex_state = 61, .external_lex_state = 30},
  [4843] = {.lex_state = 61, .external_lex_state = 30},
  [4844] = {.lex_state = 63, .external_lex_state = 23},
  [4845] = {.lex_state = 63, .external_lex_state = 32},
  [4846] = {.lex_state = 56, .external_lex_state = 41},
  [4847] = {.lex_state = 58, .external_lex_state = 30},
  [4848] = {.lex_state = 52, .external_lex_state = 49},
  [4849] = {.lex_state = 56, .external_lex_state = 33},
  [4850] = {.lex_state = 57, .external_lex_state = 44},
  [4851] = {.lex_state = 58, .external_lex_state = 30},
  [4852] = {.lex_state = 58, .external_lex_state = 30},
  [4853] = {.lex_state = 57, .external_lex_state = 29},
  [4854] = {.lex_state = 52, .external_lex_state = 27},
  [4855] = {.lex_state = 58, .external_lex_state = 30},
  [4856] = {.lex_state = 58, .external_lex_state = 30},
  [4857] = {.lex_state = 63, .external_lex_state = 47},
  [4858] = {.lex_state = 58, .external_lex_state = 30},
  [4859] = {.lex_state = 56, .external_lex_state = 32},
  [4860] = {.lex_state = 57, .external_lex_state = 26},
  [4861] = {.lex_state = 58, .external_lex_state = 30},
  [4862] = {.lex_state = 58, .external_lex_state = 30},
  [4863] = {.lex_state = 56, .external_lex_state = 33},
  [4864] = {.lex_state = 57, .external_lex_state = 30},
  [4865] = {.lex_state = 56, .external_lex_state = 33},
  [4866] = {.lex_state = 57, .external_lex_state = 29},
  [4867] = {.lex_state = 52, .external_lex_state = 27},
  [4868] = {.lex_state = 57, .external_lex_state = 30},
  [4869] = {.lex_state = 57, .external_lex_state = 30},
  [4870] = {.lex_state = 56, .external_lex_state = 38},
  [4871] = {.lex_state = 56, .external_lex_state = 33},
  [4872] = {.lex_state = 56, .external_lex_state = 33},
  [4873] = {.lex_state = 58, .external_lex_state = 30},
  [4874] = {.lex_state = 58, .external_lex_state = 40},
  [4875] = {.lex_state = 56, .external_lex_state = 40},
  [4876] = {.lex_state = 56, .external_lex_state = 26},
  [4877] = {.lex_state = 61, .external_lex_state = 44},
  [4878] = {.lex_state = 61, .external_lex_state = 40},
  [4879] = {.lex_state = 61, .external_lex_state = 40},
  [4880] = {.lex_state = 58, .external_lex_state = 34},
  [4881] = {.lex_state = 63, .external_lex_state = 42},
  [4882] = {.lex_state = 57, .external_lex_state = 30},
  [4883] = {.lex_state = 52, .external_lex_state = 51},
  [4884] = {.lex_state = 63, .external_lex_state = 42},
  [4885] = {.lex_state = 63, .external_lex_state = 32},
  [4886] = {.lex_state = 56, .external_lex_state = 43},
  [4887] = {.lex_state = 56, .external_lex_state = 47},
  [4888] = {.lex_state = 63, .external_lex_state = 42},
  [4889] = {.lex_state = 61, .external_lex_state = 47},
  [4890] = {.lex_state = 58, .external_lex_state = 29},
  [4891] = {.lex_state = 52, .external_lex_state = 37},
  [4892] = {.lex_state = 58, .external_lex_state = 50},
  [4893] = {.lex_state = 57, .external_lex_state = 30},
  [4894] = {.lex_state = 57, .external_lex_state = 54},
  [4895] = {.lex_state = 63, .external_lex_state = 26},
  [4896] = {.lex_state = 63, .external_lex_state = 54},
  [4897] = {.lex_state = 57, .external_lex_state = 47},
  [4898] = {.lex_state = 52, .external_lex_state = 41},
  [4899] = {.lex_state = 61, .external_lex_state = 47},
  [4900] = {.lex_state = 58, .external_lex_state = 34},
  [4901] = {.lex_state = 56, .external_lex_state = 30},
  [4902] = {.lex_state = 57, .external_lex_state = 29},
  [4903] = {.lex_state = 57, .external_lex_state = 29},
  [4904] = {.lex_state = 57, .external_lex_state = 29},
  [4905] = {.lex_state = 58, .external_lex_state = 29},
  [4906] = {.lex_state = 58, .external_lex_state = 29},
  [4907] = {.lex_state = 63, .external_lex_state = 28},
  [4908] = {.lex_state = 63, .external_lex_state = 39},
  [4909] = {.lex_state = 63, .external_lex_state = 33},
  [4910] = {.lex_state = 63, .external_lex_state = 33},
  [4911] = {.lex_state = 52, .external_lex_state = 34},
  [4912] = {.lex_state = 52, .external_lex_state = 34},
  [4913] = {.lex_state = 57, .external_lex_state = 55},
  [4914] = {.lex_state = 63, .external_lex_state = 39},
  [4915] = {.lex_state = 63, .external_lex_state = 55},
  [4916] = {.lex_state = 58, .external_lex_state = 34},
  [4917] = {.lex_state = 58, .external_lex_state = 30},
  [4918] = {.lex_state = 52, .external_lex_state = 35},
  [4919] = {.lex_state = 58, .external_lex_state = 30},
  [4920] = {.lex_state = 58, .external_lex_state = 30},
  [4921] = {.lex_state = 63, .external_lex_state = 39},
  [4922] = {.lex_state = 52, .external_lex_state = 37},
  [4923] = {.lex_state = 52, .external_lex_state = 29},
  [4924] = {.lex_state = 58, .external_lex_state = 30},
  [4925] = {.lex_state = 58, .external_lex_state = 34},
  [4926] = {.lex_state = 58, .external_lex_state = 29},
  [4927] = {.lex_state = 52, .external_lex_state = 41},
  [4928] = {.lex_state = 58, .external_lex_state = 29},
  [4929] = {.lex_state = 61, .external_lex_state = 32},
  [4930] = {.lex_state = 57, .external_lex_state = 30},
  [4931] = {.lex_state = 57, .external_lex_state = 30},
  [4932] = {.lex_state = 57, .external_lex_state = 29},
  [4933] = {.lex_state = 61, .external_lex_state = 26},
  [4934] = {.lex_state = 58, .external_lex_state = 32},
  [4935] = {.lex_state = 58, .external_lex_state = 32},
  [4936] = {.lex_state = 58, .external_lex_state = 29},
  [4937] = {.lex_state = 58, .external_lex_state = 32},
  [4938] = {.lex_state = 58, .external_lex_state = 33},
  [4939] = {.lex_state = 58, .external_lex_state = 33},
  [4940] = {.lex_state = 56, .external_lex_state = 41},
  [4941] = {.lex_state = 56, .external_lex_state = 41},
  [4942] = {.lex_state = 57, .external_lex_state = 52},
  [4943] = {.lex_state = 58, .external_lex_state = 40},
  [4944] = {.lex_state = 58, .external_lex_state = 29},
  [4945] = {.lex_state = 58, .external_lex_state = 26},
  [4946] = {.lex_state = 56, .external_lex_state = 38},
  [4947] = {.lex_state = 61, .external_lex_state = 44},
  [4948] = {.lex_state = 56, .external_lex_state = 38},
  [4949] = {.lex_state = 63, .external_lex_state = 52},
  [4950] = {.lex_state = 63, .external_lex_state = 34},
  [4951] = {.lex_state = 61, .external_lex_state = 33},
  [4952] = {.lex_state = 56, .external_lex_state = 34},
  [4953] = {.lex_state = 58, .external_lex_state = 44},
  [4954] = {.lex_state = 52, .external_lex_state = 27},
  [4955] = {.lex_state = 58, .external_lex_state = 41},
  [4956] = {.lex_state = 56, .external_lex_state = 30},
  [4957] = {.lex_state = 52, .external_lex_state = 38},
  [4958] = {.lex_state = 61, .external_lex_state = 44},
  [4959] = {.lex_state = 58, .external_lex_state = 33},
  [4960] = {.lex_state = 56, .external_lex_state = 54},
  [4961] = {.lex_state = 61, .external_lex_state = 46},
  [4962] = {.lex_state = 61, .external_lex_state = 32},
  [4963] = {.lex_state = 57, .external_lex_state = 46},
  [4964] = {.lex_state = 56, .external_lex_state = 30},
  [4965] = {.lex_state = 61, .external_lex_state = 29},
  [4966] = {.lex_state = 61, .external_lex_state = 50},
  [4967] = {.lex_state = 52, .external_lex_state = 27},
  [4968] = {.lex_state = 61, .external_lex_state = 29},
  [4969] = {.lex_state = 56, .external_lex_state = 32},
  [4970] = {.lex_state = 58, .external_lex_state = 47},
  [4971] = {.lex_state = 61, .external_lex_state = 33},
  [4972] = {.lex_state = 61, .external_lex_state = 46},
  [4973] = {.lex_state = 56, .external_lex_state = 55},
  [4974] = {.lex_state = 56, .external_lex_state = 33},
  [4975] = {.lex_state = 57, .external_lex_state = 30},
  [4976] = {.lex_state = 52, .external_lex_state = 38},
  [4977] = {.lex_state = 61, .external_lex_state = 29},
  [4978] = {.lex_state = 56, .external_lex_state = 34},
  [4979] = {.lex_state = 57, .external_lex_state = 30},
  [4980] = {.lex_state = 57, .external_lex_state = 30},
  [4981] = {.lex_state = 57, .external_lex_state = 30},
  [4982] = {.lex_state = 57, .external_lex_state = 30},
  [4983] = {.lex_state = 57, .external_lex_state = 30},
  [4984] = {.lex_state = 56, .external_lex_state = 44},
  [4985] = {.lex_state = 57, .external_lex_state = 30},
  [4986] = {.lex_state = 57, .external_lex_state = 30},
  [4987] = {.lex_state = 57, .external_lex_state = 47},
  [4988] = {.lex_state = 63, .external_lex_state = 44},
  [4989] = {.lex_state = 57, .external_lex_state = 30},
  [4990] = {.lex_state = 61, .external_lex_state = 50},
  [4991] = {.lex_state = 52, .external_lex_state = 35},
  [4992] = {.lex_state = 52, .external_lex_state = 56},
  [4993] = {.lex_state = 52, .external_lex_state = 35},
  [4994] = {.lex_state = 61, .external_lex_state = 47},
  [4995] = {.lex_state = 52, .external_lex_state = 49},
  [4996] = {.lex_state = 52, .external_lex_state = 43},
  [4997] = {.lex_state = 52, .external_lex_state = 35},
  [4998] = {.lex_state = 52, .external_lex_state = 57},
  [4999] = {.lex_state = 57, .external_lex_state = 29},
  [5000] = {.lex_state = 63, .external_lex_state = 27},
  [5001] = {.lex_state = 58, .external_lex_state = 46},
  [5002] = {.lex_state = 56, .external_lex_state = 46},
  [5003] = {.lex_state = 63, .external_lex_state = 46},
  [5004] = {.lex_state = 63, .external_lex_state = 34},
  [5005] = {.lex_state = 58, .external_lex_state = 40},
  [5006] = {.lex_state = 52, .external_lex_state = 36},
  [5007] = {.lex_state = 63, .external_lex_state = 34},
  [5008] = {.lex_state = 57, .external_lex_state = 29},
  [5009] = {.lex_state = 57, .external_lex_state = 46},
  [5010] = {.lex_state = 61, .external_lex_state = 34},
  [5011] = {.lex_state = 52, .external_lex_state = 43},
  [5012] = {.lex_state = 61, .external_lex_state = 29},
  [5013] = {.lex_state = 52, .external_lex_state = 51},
  [5014] = {.lex_state = 63, .external_lex_state = 26},
  [5015] = {.lex_state = 56, .external_lex_state = 34},
  [5016] = {.lex_state = 63, .external_lex_state = 26},
  [5017] = {.lex_state = 52, .external_lex_state = 40},
  [5018] = {.lex_state = 52, .external_lex_state = 40},
  [5019] = {.lex_state = 63, .external_lex_state = 26},
  [5020] = {.lex_state = 56, .external_lex_state = 40},
  [5021] = {.lex_state = 52, .external_lex_state = 43},
  [5022] = {.lex_state = 58, .external_lex_state = 43},
  [5023] = {.lex_state = 63, .external_lex_state = 33},
  [5024] = {.lex_state = 56, .external_lex_state = 40},
  [5025] = {.lex_state = 56, .external_lex_state = 40},
  [5026] = {.lex_state = 52, .external_lex_state = 28},
  [5027] = {.lex_state = 55, .external_lex_state = 40},
  [5028] = {.lex_state = 58, .external_lex_state = 29},
  [5029] = {.lex_state = 63, .external_lex_state = 26},
  [5030] = {.lex_state = 58, .external_lex_state = 38},
  [5031] = {.lex_state = 52, .external_lex_state = 39},
  [5032] = {.lex_state = 52, .external_lex_state = 30},
  [5033] = {.lex_state = 52, .external_lex_state = 31},
  [5034] = {.lex_state = 57, .external_lex_state = 30},
  [5035] = {.lex_state = 56, .external_lex_state = 50},
  [5036] = {.lex_state = 61, .external_lex_state = 46},
  [5037] = {.lex_state = 52, .external_lex_state = 29},
  [5038] = {.lex_state = 56, .external_lex_state = 34},
  [5039] = {.lex_state = 57, .external_lex_state = 50},
  [5040] = {.lex_state = 58, .external_lex_state = 32},
  [5041] = {.lex_state = 63, .external_lex_state = 26},
  [5042] = {.lex_state = 56, .external_lex_state = 34},
  [5043] = {.lex_state = 52, .external_lex_state = 58},
  [5044] = {.lex_state = 57, .external_lex_state = 44},
  [5045] = {.lex_state = 52, .external_lex_state = 30},
  [5046] = {.lex_state = 61, .external_lex_state = 34},
  [5047] = {.lex_state = 63, .external_lex_state = 34},
  [5048] = {.lex_state = 58, .external_lex_state = 32},
  [5049] = {.lex_state = 56, .external_lex_state = 47},
  [5050] = {.lex_state = 56, .external_lex_state = 44},
  [5051] = {.lex_state = 52, .external_lex_state = 28},
  [5052] = {.lex_state = 61, .external_lex_state = 38},
  [5053] = {.lex_state = 61, .external_lex_state = 30},
  [5054] = {.lex_state = 57, .external_lex_state = 52},
  [5055] = {.lex_state = 61, .external_lex_state = 32},
  [5056] = {.lex_state = 61, .external_lex_state = 32},
  [5057] = {.lex_state = 61, .external_lex_state = 32},
  [5058] = {.lex_state = 63, .external_lex_state = 55},
  [5059] = {.lex_state = 61, .external_lex_state = 33},
  [5060] = {.lex_state = 58, .external_lex_state = 32},
  [5061] = {.lex_state = 61, .external_lex_state = 33},
  [5062] = {.lex_state = 61, .external_lex_state = 33},
  [5063] = {.lex_state = 61, .external_lex_state = 52},
  [5064] = {.lex_state = 61, .external_lex_state = 38},
  [5065] = {.lex_state = 61, .external_lex_state = 52},
  [5066] = {.lex_state = 58, .external_lex_state = 32},
  [5067] = {.lex_state = 56, .external_lex_state = 46},
  [5068] = {.lex_state = 58, .external_lex_state = 32},
  [5069] = {.lex_state = 58, .external_lex_state = 32},
  [5070] = {.lex_state = 58, .external_lex_state = 32},
  [5071] = {.lex_state = 58, .external_lex_state = 33},
  [5072] = {.lex_state = 58, .external_lex_state = 32},
  [5073] = {.lex_state = 58, .external_lex_state = 32},
  [5074] = {.lex_state = 58, .external_lex_state = 32},
  [5075] = {.lex_state = 58, .external_lex_state = 46},
  [5076] = {.lex_state = 52, .external_lex_state = 28},
  [5077] = {.lex_state = 52, .external_lex_state = 46},
  [5078] = {.lex_state = 58, .external_lex_state = 33},
  [5079] = {.lex_state = 58, .external_lex_state = 26},
  [5080] = {.lex_state = 58, .external_lex_state = 33},
  [5081] = {.lex_state = 58, .external_lex_state = 33},
  [5082] = {.lex_state = 58, .external_lex_state = 33},
  [5083] = {.lex_state = 58, .external_lex_state = 33},
  [5084] = {.lex_state = 58, .external_lex_state = 33},
  [5085] = {.lex_state = 58, .external_lex_state = 33},
  [5086] = {.lex_state = 57, .external_lex_state = 33},
  [5087] = {.lex_state = 58, .external_lex_state = 50},
  [5088] = {.lex_state = 63, .external_lex_state = 30},
  [5089] = {.lex_state = 56, .external_lex_state = 41},
  [5090] = {.lex_state = 52, .external_lex_state = 28},
  [5091] = {.lex_state = 61, .external_lex_state = 52},
  [5092] = {.lex_state = 57, .external_lex_state = 26},
  [5093] = {.lex_state = 58, .external_lex_state = 34},
  [5094] = {.lex_state = 58, .external_lex_state = 34},
  [5095] = {.lex_state = 58, .external_lex_state = 34},
  [5096] = {.lex_state = 56, .external_lex_state = 41},
  [5097] = {.lex_state = 56, .external_lex_state = 41},
  [5098] = {.lex_state = 56, .external_lex_state = 41},
  [5099] = {.lex_state = 56, .external_lex_state = 41},
  [5100] = {.lex_state = 56, .external_lex_state = 41},
  [5101] = {.lex_state = 56, .external_lex_state = 44},
  [5102] = {.lex_state = 56, .external_lex_state = 41},
  [5103] = {.lex_state = 56, .external_lex_state = 41},
  [5104] = {.lex_state = 58, .external_lex_state = 34},
  [5105] = {.lex_state = 63, .external_lex_state = 38},
  [5106] = {.lex_state = 63, .external_lex_state = 38},
  [5107] = {.lex_state = 61, .external_lex_state = 43},
  [5108] = {.lex_state = 63, .external_lex_state = 30},
  [5109] = {.lex_state = 58, .external_lex_state = 32},
  [5110] = {.lex_state = 63, .external_lex_state = 30},
  [5111] = {.lex_state = 63, .external_lex_state = 30},
  [5112] = {.lex_state = 58, .external_lex_state = 41},
  [5113] = {.lex_state = 61, .external_lex_state = 34},
  [5114] = {.lex_state = 57, .external_lex_state = 34},
  [5115] = {.lex_state = 58, .external_lex_state = 54},
  [5116] = {.lex_state = 58, .external_lex_state = 33},
  [5117] = {.lex_state = 56, .external_lex_state = 38},
  [5118] = {.lex_state = 61, .external_lex_state = 26},
  [5119] = {.lex_state = 58, .external_lex_state = 55},
  [5120] = {.lex_state = 56, .external_lex_state = 53},
  [5121] = {.lex_state = 56, .external_lex_state = 41},
  [5122] = {.lex_state = 56, .external_lex_state = 38},
  [5123] = {.lex_state = 56, .external_lex_state = 38},
  [5124] = {.lex_state = 52, .external_lex_state = 50},
  [5125] = {.lex_state = 56, .external_lex_state = 38},
  [5126] = {.lex_state = 56, .external_lex_state = 38},
  [5127] = {.lex_state = 56, .external_lex_state = 38},
  [5128] = {.lex_state = 56, .external_lex_state = 38},
  [5129] = {.lex_state = 56, .external_lex_state = 38},
  [5130] = {.lex_state = 58, .external_lex_state = 30},
  [5131] = {.lex_state = 56, .external_lex_state = 30},
  [5132] = {.lex_state = 58, .external_lex_state = 30},
  [5133] = {.lex_state = 57, .external_lex_state = 32},
  [5134] = {.lex_state = 61, .external_lex_state = 26},
  [5135] = {.lex_state = 58, .external_lex_state = 38},
  [5136] = {.lex_state = 61, .external_lex_state = 54},
  [5137] = {.lex_state = 57, .external_lex_state = 32},
  [5138] = {.lex_state = 52, .external_lex_state = 29},
  [5139] = {.lex_state = 56, .external_lex_state = 38},
  [5140] = {.lex_state = 58, .external_lex_state = 41},
  [5141] = {.lex_state = 57, .external_lex_state = 33},
  [5142] = {.lex_state = 52, .external_lex_state = 41},
  [5143] = {.lex_state = 52, .external_lex_state = 41},
  [5144] = {.lex_state = 58, .external_lex_state = 52},
  [5145] = {.lex_state = 57, .external_lex_state = 33},
  [5146] = {.lex_state = 57, .external_lex_state = 32},
  [5147] = {.lex_state = 56, .external_lex_state = 44},
  [5148] = {.lex_state = 61, .external_lex_state = 26},
  [5149] = {.lex_state = 52, .external_lex_state = 30},
  [5150] = {.lex_state = 52, .external_lex_state = 34},
  [5151] = {.lex_state = 52, .external_lex_state = 38},
  [5152] = {.lex_state = 52, .external_lex_state = 38},
  [5153] = {.lex_state = 58, .external_lex_state = 32},
  [5154] = {.lex_state = 58, .external_lex_state = 32},
  [5155] = {.lex_state = 56, .external_lex_state = 44},
  [5156] = {.lex_state = 61, .external_lex_state = 50},
  [5157] = {.lex_state = 52, .external_lex_state = 30},
  [5158] = {.lex_state = 58, .external_lex_state = 38},
  [5159] = {.lex_state = 61, .external_lex_state = 50},
  [5160] = {.lex_state = 52, .external_lex_state = 30},
  [5161] = {.lex_state = 52, .external_lex_state = 30},
  [5162] = {.lex_state = 58, .external_lex_state = 32},
  [5163] = {.lex_state = 56, .external_lex_state = 50},
  [5164] = {.lex_state = 58, .external_lex_state = 33},
  [5165] = {.lex_state = 58, .external_lex_state = 33},
  [5166] = {.lex_state = 58, .external_lex_state = 33},
  [5167] = {.lex_state = 56, .external_lex_state = 50},
  [5168] = {.lex_state = 58, .external_lex_state = 33},
  [5169] = {.lex_state = 52, .external_lex_state = 42},
  [5170] = {.lex_state = 56, .external_lex_state = 41},
  [5171] = {.lex_state = 56, .external_lex_state = 41},
  [5172] = {.lex_state = 56, .external_lex_state = 41},
  [5173] = {.lex_state = 52, .external_lex_state = 42},
  [5174] = {.lex_state = 56, .external_lex_state = 41},
  [5175] = {.lex_state = 56, .external_lex_state = 46},
  [5176] = {.lex_state = 56, .external_lex_state = 46},
  [5177] = {.lex_state = 56, .external_lex_state = 38},
  [5178] = {.lex_state = 56, .external_lex_state = 38},
  [5179] = {.lex_state = 56, .external_lex_state = 38},
  [5180] = {.lex_state = 56, .external_lex_state = 38},
  [5181] = {.lex_state = 61, .external_lex_state = 47},
  [5182] = {.lex_state = 52, .external_lex_state = 45},
  [5183] = {.lex_state = 61, .external_lex_state = 47},
  [5184] = {.lex_state = 52, .external_lex_state = 39},
  [5185] = {.lex_state = 52, .external_lex_state = 39},
  [5186] = {.lex_state = 61, .external_lex_state = 44},
  [5187] = {.lex_state = 61, .external_lex_state = 44},
  [5188] = {.lex_state = 57, .external_lex_state = 54},
  [5189] = {.lex_state = 52, .external_lex_state = 34},
  [5190] = {.lex_state = 58, .external_lex_state = 41},
  [5191] = {.lex_state = 58, .external_lex_state = 41},
  [5192] = {.lex_state = 58, .external_lex_state = 38},
  [5193] = {.lex_state = 58, .external_lex_state = 38},
  [5194] = {.lex_state = 56, .external_lex_state = 50},
  [5195] = {.lex_state = 56, .external_lex_state = 50},
  [5196] = {.lex_state = 58, .external_lex_state = 43},
  [5197] = {.lex_state = 56, .external_lex_state = 47},
  [5198] = {.lex_state = 63, .external_lex_state = 45},
  [5199] = {.lex_state = 57, .external_lex_state = 26},
  [5200] = {.lex_state = 52, .external_lex_state = 46},
  [5201] = {.lex_state = 56, .external_lex_state = 46},
  [5202] = {.lex_state = 63, .external_lex_state = 41},
  [5203] = {.lex_state = 63, .external_lex_state = 40},
  [5204] = {.lex_state = 58, .external_lex_state = 43},
  [5205] = {.lex_state = 63, .external_lex_state = 31},
  [5206] = {.lex_state = 63, .external_lex_state = 42},
  [5207] = {.lex_state = 52, .external_lex_state = 37},
  [5208] = {.lex_state = 63, .external_lex_state = 28},
  [5209] = {.lex_state = 52, .external_lex_state = 57},
  [5210] = {.lex_state = 52, .external_lex_state = 58},
  [5211] = {.lex_state = 52, .external_lex_state = 50},
  [5212] = {.lex_state = 63, .external_lex_state = 40},
  [5213] = {.lex_state = 57, .external_lex_state = 34},
  [5214] = {.lex_state = 58, .external_lex_state = 40},
  [5215] = {.lex_state = 57, .external_lex_state = 55},
  [5216] = {.lex_state = 63, .external_lex_state = 23},
  [5217] = {.lex_state = 52, .external_lex_state = 31},
  [5218] = {.lex_state = 52, .external_lex_state = 50},
  [5219] = {.lex_state = 63, .external_lex_state = 31},
  [5220] = {.lex_state = 57, .external_lex_state = 54},
  [5221] = {.lex_state = 61, .external_lex_state = 34},
  [5222] = {.lex_state = 52, .external_lex_state = 37},
  [5223] = {.lex_state = 63, .external_lex_state = 28},
  [5224] = {.lex_state = 58, .external_lex_state = 40},
  [5225] = {.lex_state = 63, .external_lex_state = 35},
  [5226] = {.lex_state = 63, .external_lex_state = 53},
  [5227] = {.lex_state = 61, .external_lex_state = 34},
  [5228] = {.lex_state = 63, .external_lex_state = 45},
  [5229] = {.lex_state = 61, .external_lex_state = 34},
  [5230] = {.lex_state = 58, .external_lex_state = 40},
  [5231] = {.lex_state = 57, .external_lex_state = 34},
  [5232] = {.lex_state = 63, .external_lex_state = 41},
  [5233] = {.lex_state = 52, .external_lex_state = 44},
  [5234] = {.lex_state = 52, .external_lex_state = 23},
  [5235] = {.lex_state = 58, .external_lex_state = 34},
  [5236] = {.lex_state = 52, .external_lex_state = 43},
  [5237] = {.lex_state = 58, .external_lex_state = 40},
  [5238] = {.lex_state = 56, .external_lex_state = 34},
  [5239] = {.lex_state = 61, .external_lex_state = 54},
  [5240] = {.lex_state = 52, .external_lex_state = 23},
  [5241] = {.lex_state = 63, .external_lex_state = 27},
  [5242] = {.lex_state = 52, .external_lex_state = 43},
  [5243] = {.lex_state = 57, .external_lex_state = 32},
  [5244] = {.lex_state = 63, .external_lex_state = 27},
  [5245] = {.lex_state = 57, .external_lex_state = 33},
  [5246] = {.lex_state = 52, .external_lex_state = 35},
  [5247] = {.lex_state = 63, .external_lex_state = 48},
  [5248] = {.lex_state = 63, .external_lex_state = 27},
  [5249] = {.lex_state = 63, .external_lex_state = 27},
  [5250] = {.lex_state = 63, .external_lex_state = 48},
  [5251] = {.lex_state = 63, .external_lex_state = 48},
  [5252] = {.lex_state = 61, .external_lex_state = 54},
  [5253] = {.lex_state = 52, .external_lex_state = 31},
  [5254] = {.lex_state = 52, .external_lex_state = 31},
  [5255] = {.lex_state = 61, .external_lex_state = 46},
  [5256] = {.lex_state = 57, .external_lex_state = 53},
  [5257] = {.lex_state = 63, .external_lex_state = 49},
  [5258] = {.lex_state = 52, .external_lex_state = 29},
  [5259] = {.lex_state = 7, .external_lex_state = 43},
  [5260] = {.lex_state = 63, .external_lex_state = 49},
  [5261] = {.lex_state = 61, .external_lex_state = 55},
  [5262] = {.lex_state = 57, .external_lex_state = 32},
  [5263] = {.lex_state = 61, .external_lex_state = 46},
  [5264] = {.lex_state = 57, .external_lex_state = 32},
  [5265] = {.lex_state = 63, .external_lex_state = 23},
  [5266] = {.lex_state = 63, .external_lex_state = 49},
  [5267] = {.lex_state = 63, .external_lex_state = 29},
  [5268] = {.lex_state = 52, .external_lex_state = 29},
  [5269] = {.lex_state = 63, .external_lex_state = 40},
  [5270] = {.lex_state = 57, .external_lex_state = 32},
  [5271] = {.lex_state = 52, .external_lex_state = 29},
  [5272] = {.lex_state = 52, .external_lex_state = 48},
  [5273] = {.lex_state = 61, .external_lex_state = 55},
  [5274] = {.lex_state = 57, .external_lex_state = 32},
  [5275] = {.lex_state = 57, .external_lex_state = 32},
  [5276] = {.lex_state = 63, .external_lex_state = 27},
  [5277] = {.lex_state = 57, .external_lex_state = 33},
  [5278] = {.lex_state = 58, .external_lex_state = 34},
  [5279] = {.lex_state = 61, .external_lex_state = 40},
  [5280] = {.lex_state = 63, .external_lex_state = 41},
  [5281] = {.lex_state = 58, .external_lex_state = 34},
  [5282] = {.lex_state = 57, .external_lex_state = 32},
  [5283] = {.lex_state = 56, .external_lex_state = 43},
  [5284] = {.lex_state = 58, .external_lex_state = 34},
  [5285] = {.lex_state = 58, .external_lex_state = 34},
  [5286] = {.lex_state = 57, .external_lex_state = 32},
  [5287] = {.lex_state = 58, .external_lex_state = 34},
  [5288] = {.lex_state = 58, .external_lex_state = 34},
  [5289] = {.lex_state = 57, .external_lex_state = 32},
  [5290] = {.lex_state = 58, .external_lex_state = 34},
  [5291] = {.lex_state = 58, .external_lex_state = 40},
  [5292] = {.lex_state = 57, .external_lex_state = 32},
  [5293] = {.lex_state = 63, .external_lex_state = 29},
  [5294] = {.lex_state = 52, .external_lex_state = 24},
  [5295] = {.lex_state = 52, .external_lex_state = 23},
  [5296] = {.lex_state = 56, .external_lex_state = 40},
  [5297] = {.lex_state = 52, .external_lex_state = 44},
  [5298] = {.lex_state = 55, .external_lex_state = 43},
  [5299] = {.lex_state = 59, .external_lex_state = 53},
  [5300] = {.lex_state = 57, .external_lex_state = 32},
  [5301] = {.lex_state = 57, .external_lex_state = 55},
  [5302] = {.lex_state = 61, .external_lex_state = 43},
  [5303] = {.lex_state = 56, .external_lex_state = 40},
  [5304] = {.lex_state = 61, .external_lex_state = 55},
  [5305] = {.lex_state = 60},
  [5306] = {.lex_state = 63, .external_lex_state = 27},
  [5307] = {.lex_state = 56, .external_lex_state = 40},
  [5308] = {.lex_state = 56, .external_lex_state = 40},
  [5309] = {.lex_state = 56, .external_lex_state = 40},
  [5310] = {.lex_state = 56, .external_lex_state = 40},
  [5311] = {.lex_state = 56, .external_lex_state = 40},
  [5312] = {.lex_state = 56, .external_lex_state = 40},
  [5313] = {.lex_state = 58, .external_lex_state = 44},
  [5314] = {.lex_state = 57, .external_lex_state = 33},
  [5315] = {.lex_state = 63, .external_lex_state = 54},
  [5316] = {.lex_state = 57, .external_lex_state = 33},
  [5317] = {.lex_state = 61, .external_lex_state = 40},
  [5318] = {.lex_state = 57, .external_lex_state = 33},
  [5319] = {.lex_state = 56, .external_lex_state = 32},
  [5320] = {.lex_state = 63, .external_lex_state = 36},
  [5321] = {.lex_state = 56, .external_lex_state = 40},
  [5322] = {.lex_state = 56, .external_lex_state = 33},
  [5323] = {.lex_state = 63, .external_lex_state = 27},
  [5324] = {.lex_state = 63, .external_lex_state = 52},
  [5325] = {.lex_state = 63, .external_lex_state = 37},
  [5326] = {.lex_state = 55, .external_lex_state = 40},
  [5327] = {.lex_state = 63, .external_lex_state = 29},
  [5328] = {.lex_state = 63, .external_lex_state = 30},
  [5329] = {.lex_state = 58, .external_lex_state = 43},
  [5330] = {.lex_state = 63, .external_lex_state = 37},
  [5331] = {.lex_state = 58, .external_lex_state = 43},
  [5332] = {.lex_state = 63, .external_lex_state = 27},
  [5333] = {.lex_state = 56, .external_lex_state = 41},
  [5334] = {.lex_state = 57, .external_lex_state = 34},
  [5335] = {.lex_state = 57, .external_lex_state = 33},
  [5336] = {.lex_state = 63, .external_lex_state = 45},
  [5337] = {.lex_state = 52, .external_lex_state = 23},
  [5338] = {.lex_state = 63, .external_lex_state = 27},
  [5339] = {.lex_state = 52},
  [5340] = {.lex_state = 63, .external_lex_state = 27},
  [5341] = {.lex_state = 56, .external_lex_state = 34},
  [5342] = {.lex_state = 63, .external_lex_state = 27},
  [5343] = {.lex_state = 56, .external_lex_state = 34},
  [5344] = {.lex_state = 56, .external_lex_state = 52},
  [5345] = {.lex_state = 63, .external_lex_state = 42},
  [5346] = {.lex_state = 52, .external_lex_state = 36},
  [5347] = {.lex_state = 52, .external_lex_state = 46},
  [5348] = {.lex_state = 63, .external_lex_state = 43},
  [5349] = {.lex_state = 52, .external_lex_state = 26},
  [5350] = {.lex_state = 58, .external_lex_state = 29},
  [5351] = {.lex_state = 58, .external_lex_state = 29},
  [5352] = {.lex_state = 63, .external_lex_state = 27},
  [5353] = {.lex_state = 52, .external_lex_state = 28},
  [5354] = {.lex_state = 63, .external_lex_state = 27},
  [5355] = {.lex_state = 56, .external_lex_state = 38},
  [5356] = {.lex_state = 63, .external_lex_state = 27},
  [5357] = {.lex_state = 61, .external_lex_state = 29},
  [5358] = {.lex_state = 56, .external_lex_state = 40},
  [5359] = {.lex_state = 63, .external_lex_state = 27},
  [5360] = {.lex_state = 56, .external_lex_state = 40},
  [5361] = {.lex_state = 63, .external_lex_state = 27},
  [5362] = {.lex_state = 56, .external_lex_state = 40},
  [5363] = {.lex_state = 52, .external_lex_state = 32},
  [5364] = {.lex_state = 63, .external_lex_state = 51},
  [5365] = {.lex_state = 63},
  [5366] = {.lex_state = 63, .external_lex_state = 40},
  [5367] = {.lex_state = 63, .external_lex_state = 30},
  [5368] = {.lex_state = 63},
  [5369] = {.lex_state = 63, .external_lex_state = 38},
  [5370] = {.lex_state = 63, .external_lex_state = 51},
  [5371] = {.lex_state = 63},
  [5372] = {.lex_state = 57, .external_lex_state = 34},
  [5373] = {.lex_state = 63},
  [5374] = {.lex_state = 63, .external_lex_state = 51},
  [5375] = {.lex_state = 56, .external_lex_state = 40},
  [5376] = {.lex_state = 52, .external_lex_state = 26},
  [5377] = {.lex_state = 52, .external_lex_state = 57},
  [5378] = {.lex_state = 57, .external_lex_state = 33},
  [5379] = {.lex_state = 52, .external_lex_state = 40},
  [5380] = {.lex_state = 52, .external_lex_state = 33},
  [5381] = {.lex_state = 57, .external_lex_state = 30},
  [5382] = {.lex_state = 57, .external_lex_state = 34},
  [5383] = {.lex_state = 52, .external_lex_state = 47},
  [5384] = {.lex_state = 61, .external_lex_state = 29},
  [5385] = {.lex_state = 63, .external_lex_state = 30},
  [5386] = {.lex_state = 57, .external_lex_state = 34},
  [5387] = {.lex_state = 57, .external_lex_state = 34},
  [5388] = {.lex_state = 63},
  [5389] = {.lex_state = 52, .external_lex_state = 40},
  [5390] = {.lex_state = 52, .external_lex_state = 47},
  [5391] = {.lex_state = 56, .external_lex_state = 54},
  [5392] = {.lex_state = 57, .external_lex_state = 34},
  [5393] = {.lex_state = 57, .external_lex_state = 34},
  [5394] = {.lex_state = 58, .external_lex_state = 40},
  [5395] = {.lex_state = 57, .external_lex_state = 34},
  [5396] = {.lex_state = 57, .external_lex_state = 34},
  [5397] = {.lex_state = 52, .external_lex_state = 47},
  [5398] = {.lex_state = 57, .external_lex_state = 34},
  [5399] = {.lex_state = 63},
  [5400] = {.lex_state = 52, .external_lex_state = 32},
  [5401] = {.lex_state = 57, .external_lex_state = 33},
  [5402] = {.lex_state = 56, .external_lex_state = 29},
  [5403] = {.lex_state = 57, .external_lex_state = 34},
  [5404] = {.lex_state = 57, .external_lex_state = 33},
  [5405] = {.lex_state = 52, .external_lex_state = 31},
  [5406] = {.lex_state = 58, .external_lex_state = 40},
  [5407] = {.lex_state = 63, .external_lex_state = 38},
  [5408] = {.lex_state = 57, .external_lex_state = 33},
  [5409] = {.lex_state = 58, .external_lex_state = 40},
  [5410] = {.lex_state = 57, .external_lex_state = 43},
  [5411] = {.lex_state = 57, .external_lex_state = 32},
  [5412] = {.lex_state = 58, .external_lex_state = 40},
  [5413] = {.lex_state = 58, .external_lex_state = 40},
  [5414] = {.lex_state = 63, .external_lex_state = 27},
  [5415] = {.lex_state = 58, .external_lex_state = 40},
  [5416] = {.lex_state = 61, .external_lex_state = 41},
  [5417] = {.lex_state = 58, .external_lex_state = 40},
  [5418] = {.lex_state = 63, .external_lex_state = 29},
  [5419] = {.lex_state = 61, .external_lex_state = 32},
  [5420] = {.lex_state = 58, .external_lex_state = 40},
  [5421] = {.lex_state = 56, .external_lex_state = 40},
  [5422] = {.lex_state = 57, .external_lex_state = 34},
  [5423] = {.lex_state = 57, .external_lex_state = 33},
  [5424] = {.lex_state = 55, .external_lex_state = 40},
  [5425] = {.lex_state = 58, .external_lex_state = 47},
  [5426] = {.lex_state = 63, .external_lex_state = 29},
  [5427] = {.lex_state = 57, .external_lex_state = 34},
  [5428] = {.lex_state = 63, .external_lex_state = 29},
  [5429] = {.lex_state = 61, .external_lex_state = 26},
  [5430] = {.lex_state = 63, .external_lex_state = 29},
  [5431] = {.lex_state = 52, .external_lex_state = 33},
  [5432] = {.lex_state = 61, .external_lex_state = 33},
  [5433] = {.lex_state = 57, .external_lex_state = 33},
  [5434] = {.lex_state = 57, .external_lex_state = 33},
  [5435] = {.lex_state = 56, .external_lex_state = 32},
  [5436] = {.lex_state = 56, .external_lex_state = 32},
  [5437] = {.lex_state = 61, .external_lex_state = 26},
  [5438] = {.lex_state = 56, .external_lex_state = 33},
  [5439] = {.lex_state = 56, .external_lex_state = 33},
  [5440] = {.lex_state = 52, .external_lex_state = 58},
  [5441] = {.lex_state = 57, .external_lex_state = 33},
  [5442] = {.lex_state = 63, .external_lex_state = 26},
  [5443] = {.lex_state = 52, .external_lex_state = 28},
  [5444] = {.lex_state = 59, .external_lex_state = 40},
  [5445] = {.lex_state = 56, .external_lex_state = 47},
  [5446] = {.lex_state = 56, .external_lex_state = 55},
  [5447] = {.lex_state = 61, .external_lex_state = 41},
  [5448] = {.lex_state = 57, .external_lex_state = 52},
  [5449] = {.lex_state = 61, .external_lex_state = 43},
  [5450] = {.lex_state = 55, .external_lex_state = 53},
  [5451] = {.lex_state = 63, .external_lex_state = 26},
  [5452] = {.lex_state = 57, .external_lex_state = 34},
  [5453] = {.lex_state = 56, .external_lex_state = 26},
  [5454] = {.lex_state = 57, .external_lex_state = 29},
  [5455] = {.lex_state = 63, .external_lex_state = 26},
  [5456] = {.lex_state = 57, .external_lex_state = 32},
  [5457] = {.lex_state = 52, .external_lex_state = 31},
  [5458] = {.lex_state = 56, .external_lex_state = 47},
  [5459] = {.lex_state = 63, .external_lex_state = 41},
  [5460] = {.lex_state = 52, .external_lex_state = 44},
  [5461] = {.lex_state = 58, .external_lex_state = 34},
  [5462] = {.lex_state = 57, .external_lex_state = 32},
  [5463] = {.lex_state = 61, .external_lex_state = 30},
  [5464] = {.lex_state = 58, .external_lex_state = 53},
  [5465] = {.lex_state = 63, .external_lex_state = 27},
  [5466] = {.lex_state = 52, .external_lex_state = 30},
  [5467] = {.lex_state = 52, .external_lex_state = 52},
  [5468] = {.lex_state = 57, .external_lex_state = 38},
  [5469] = {.lex_state = 56, .external_lex_state = 50},
  [5470] = {.lex_state = 57, .external_lex_state = 38},
  [5471] = {.lex_state = 57, .external_lex_state = 38},
  [5472] = {.lex_state = 57, .external_lex_state = 38},
  [5473] = {.lex_state = 57, .external_lex_state = 38},
  [5474] = {.lex_state = 57, .external_lex_state = 38},
  [5475] = {.lex_state = 58, .external_lex_state = 29},
  [5476] = {.lex_state = 63, .external_lex_state = 50},
  [5477] = {.lex_state = 52, .external_lex_state = 50},
  [5478] = {.lex_state = 52, .external_lex_state = 50},
  [5479] = {.lex_state = 63, .external_lex_state = 31},
  [5480] = {.lex_state = 57, .external_lex_state = 38},
  [5481] = {.lex_state = 58, .external_lex_state = 47},
  [5482] = {.lex_state = 52, .external_lex_state = 38},
  [5483] = {.lex_state = 56, .external_lex_state = 46},
  [5484] = {.lex_state = 58, .external_lex_state = 50},
  [5485] = {.lex_state = 58, .external_lex_state = 47},
  [5486] = {.lex_state = 56, .external_lex_state = 44},
  [5487] = {.lex_state = 56, .external_lex_state = 47},
  [5488] = {.lex_state = 56, .external_lex_state = 44},
  [5489] = {.lex_state = 55, .external_lex_state = 53},
  [5490] = {.lex_state = 61, .external_lex_state = 50},
  [5491] = {.lex_state = 56, .external_lex_state = 46},
  [5492] = {.lex_state = 55, .external_lex_state = 53},
  [5493] = {.lex_state = 56, .external_lex_state = 26},
  [5494] = {.lex_state = 58, .external_lex_state = 41},
  [5495] = {.lex_state = 58, .external_lex_state = 41},
  [5496] = {.lex_state = 58, .external_lex_state = 41},
  [5497] = {.lex_state = 58, .external_lex_state = 41},
  [5498] = {.lex_state = 56, .external_lex_state = 26},
  [5499] = {.lex_state = 56, .external_lex_state = 41},
  [5500] = {.lex_state = 63, .external_lex_state = 28},
  [5501] = {.lex_state = 61, .external_lex_state = 33},
  [5502] = {.lex_state = 58, .external_lex_state = 43},
  [5503] = {.lex_state = 58, .external_lex_state = 44},
  [5504] = {.lex_state = 58, .external_lex_state = 38},
  [5505] = {.lex_state = 58, .external_lex_state = 38},
  [5506] = {.lex_state = 58, .external_lex_state = 38},
  [5507] = {.lex_state = 58, .external_lex_state = 38},
  [5508] = {.lex_state = 52, .external_lex_state = 52},
  [5509] = {.lex_state = 56, .external_lex_state = 41},
  [5510] = {.lex_state = 56, .external_lex_state = 50},
  [5511] = {.lex_state = 56, .external_lex_state = 50},
  [5512] = {.lex_state = 56, .external_lex_state = 50},
  [5513] = {.lex_state = 52, .external_lex_state = 30},
  [5514] = {.lex_state = 58, .external_lex_state = 44},
  [5515] = {.lex_state = 56, .external_lex_state = 50},
  [5516] = {.lex_state = 58, .external_lex_state = 44},
  [5517] = {.lex_state = 56, .external_lex_state = 54},
  [5518] = {.lex_state = 57, .external_lex_state = 41},
  [5519] = {.lex_state = 56, .external_lex_state = 54},
  [5520] = {.lex_state = 57, .external_lex_state = 41},
  [5521] = {.lex_state = 56, .external_lex_state = 55},
  [5522] = {.lex_state = 56, .external_lex_state = 55},
  [5523] = {.lex_state = 58, .external_lex_state = 46},
  [5524] = {.lex_state = 63, .external_lex_state = 27},
  [5525] = {.lex_state = 58, .external_lex_state = 46},
  [5526] = {.lex_state = 63, .external_lex_state = 28},
  [5527] = {.lex_state = 57, .external_lex_state = 38},
  [5528] = {.lex_state = 57, .external_lex_state = 38},
  [5529] = {.lex_state = 52, .external_lex_state = 51},
  [5530] = {.lex_state = 52, .external_lex_state = 51},
  [5531] = {.lex_state = 56, .external_lex_state = 52},
  [5532] = {.lex_state = 56, .external_lex_state = 52},
  [5533] = {.lex_state = 52, .external_lex_state = 36},
  [5534] = {.lex_state = 56, .external_lex_state = 44},
  [5535] = {.lex_state = 61, .external_lex_state = 30},
  [5536] = {.lex_state = 57, .external_lex_state = 38},
  [5537] = {.lex_state = 58, .external_lex_state = 50},
  [5538] = {.lex_state = 58, .external_lex_state = 50},
  [5539] = {.lex_state = 52, .external_lex_state = 35},
  [5540] = {.lex_state = 63, .external_lex_state = 33},
  [5541] = {.lex_state = 61, .external_lex_state = 32},
  [5542] = {.lex_state = 58, .external_lex_state = 32},
  [5543] = {.lex_state = 52, .external_lex_state = 37},
  [5544] = {.lex_state = 61, .external_lex_state = 33},
  [5545] = {.lex_state = 61, .external_lex_state = 29},
  [5546] = {.lex_state = 56, .external_lex_state = 29},
  [5547] = {.lex_state = 57, .external_lex_state = 41},
  [5548] = {.lex_state = 63, .external_lex_state = 27},
  [5549] = {.lex_state = 63, .external_lex_state = 28},
  [5550] = {.lex_state = 58, .external_lex_state = 32},
  [5551] = {.lex_state = 54},
  [5552] = {.lex_state = 52, .external_lex_state = 38},
  [5553] = {.lex_state = 52, .external_lex_state = 24},
  [5554] = {.lex_state = 58, .external_lex_state = 43},
  [5555] = {.lex_state = 52, .external_lex_state = 47},
  [5556] = {.lex_state = 52, .external_lex_state = 24},
  [5557] = {.lex_state = 63, .external_lex_state = 35},
  [5558] = {.lex_state = 63, .external_lex_state = 49},
  [5559] = {.lex_state = 63, .external_lex_state = 36},
  [5560] = {.lex_state = 52, .external_lex_state = 47},
  [5561] = {.lex_state = 63, .external_lex_state = 32},
  [5562] = {.lex_state = 63, .external_lex_state = 51},
  [5563] = {.lex_state = 52, .external_lex_state = 55},
  [5564] = {.lex_state = 52, .external_lex_state = 53},
  [5565] = {.lex_state = 52, .external_lex_state = 39},
  [5566] = {.lex_state = 52, .external_lex_state = 55},
  [5567] = {.lex_state = 52, .external_lex_state = 48},
  [5568] = {.lex_state = 63, .external_lex_state = 27},
  [5569] = {.lex_state = 52, .external_lex_state = 48},
  [5570] = {.lex_state = 57, .external_lex_state = 40},
  [5571] = {.lex_state = 63, .external_lex_state = 28},
  [5572] = {.lex_state = 58, .external_lex_state = 46},
  [5573] = {.lex_state = 52, .external_lex_state = 41},
  [5574] = {.lex_state = 61, .external_lex_state = 50},
  [5575] = {.lex_state = 63, .external_lex_state = 28},
  [5576] = {.lex_state = 52, .external_lex_state = 23},
  [5577] = {.lex_state = 61, .external_lex_state = 44},
  [5578] = {.lex_state = 52, .external_lex_state = 32},
  [5579] = {.lex_state = 57, .external_lex_state = 41},
  [5580] = {.lex_state = 52, .external_lex_state = 24},
  [5581] = {.lex_state = 63, .external_lex_state = 35},
  [5582] = {.lex_state = 63, .external_lex_state = 36},
  [5583] = {.lex_state = 52, .external_lex_state = 40},
  [5584] = {.lex_state = 63, .external_lex_state = 28},
  [5585] = {.lex_state = 52, .external_lex_state = 39},
  [5586] = {.lex_state = 63, .external_lex_state = 31},
  [5587] = {.lex_state = 55, .external_lex_state = 53},
  [5588] = {.lex_state = 58, .external_lex_state = 43},
  [5589] = {.lex_state = 56, .external_lex_state = 40},
  [5590] = {.lex_state = 61, .external_lex_state = 34},
  [5591] = {.lex_state = 3},
  [5592] = {.lex_state = 52, .external_lex_state = 35},
  [5593] = {.lex_state = 63, .external_lex_state = 28},
  [5594] = {.lex_state = 52, .external_lex_state = 43},
  [5595] = {.lex_state = 52, .external_lex_state = 40},
  [5596] = {.lex_state = 63, .external_lex_state = 28},
  [5597] = {.lex_state = 56, .external_lex_state = 54},
  [5598] = {.lex_state = 58, .external_lex_state = 54},
  [5599] = {.lex_state = 52, .external_lex_state = 52},
  [5600] = {.lex_state = 63, .external_lex_state = 32},
  [5601] = {.lex_state = 57, .external_lex_state = 38},
  [5602] = {.lex_state = 56, .external_lex_state = 26},
  [5603] = {.lex_state = 58, .external_lex_state = 43},
  [5604] = {.lex_state = 63, .external_lex_state = 32},
  [5605] = {.lex_state = 63, .external_lex_state = 32},
  [5606] = {.lex_state = 56, .external_lex_state = 38},
  [5607] = {.lex_state = 52, .external_lex_state = 24},
  [5608] = {.lex_state = 57, .external_lex_state = 40},
  [5609] = {.lex_state = 52, .external_lex_state = 40},
  [5610] = {.lex_state = 57, .external_lex_state = 40},
  [5611] = {.lex_state = 57, .external_lex_state = 40},
  [5612] = {.lex_state = 56, .external_lex_state = 38},
  [5613] = {.lex_state = 61, .external_lex_state = 30},
  [5614] = {.lex_state = 61, .external_lex_state = 55},
  [5615] = {.lex_state = 58, .external_lex_state = 26},
  [5616] = {.lex_state = 63, .external_lex_state = 34},
  [5617] = {.lex_state = 61, .external_lex_state = 44},
  [5618] = {.lex_state = 57, .external_lex_state = 43},
  [5619] = {.lex_state = 56, .external_lex_state = 44},
  [5620] = {.lex_state = 58, .external_lex_state = 43},
  [5621] = {.lex_state = 58, .external_lex_state = 43},
  [5622] = {.lex_state = 63, .external_lex_state = 43},
  [5623] = {.lex_state = 58, .external_lex_state = 43},
  [5624] = {.lex_state = 63, .external_lex_state = 29},
  [5625] = {.lex_state = 52, .external_lex_state = 33},
  [5626] = {.lex_state = 52, .external_lex_state = 34},
  [5627] = {.lex_state = 63, .external_lex_state = 31},
  [5628] = {.lex_state = 63, .external_lex_state = 31},
  [5629] = {.lex_state = 63, .external_lex_state = 23},
  [5630] = {.lex_state = 63, .external_lex_state = 29},
  [5631] = {.lex_state = 63, .external_lex_state = 31},
  [5632] = {.lex_state = 56, .external_lex_state = 47},
  [5633] = {.lex_state = 56, .external_lex_state = 46},
  [5634] = {.lex_state = 63, .external_lex_state = 29},
  [5635] = {.lex_state = 52, .external_lex_state = 29},
  [5636] = {.lex_state = 63, .external_lex_state = 31},
  [5637] = {.lex_state = 57, .external_lex_state = 40},
  [5638] = {.lex_state = 63, .external_lex_state = 49},
  [5639] = {.lex_state = 52, .external_lex_state = 46},
  [5640] = {.lex_state = 57, .external_lex_state = 34},
  [5641] = {.lex_state = 63, .external_lex_state = 27},
  [5642] = {.lex_state = 56, .external_lex_state = 47},
  [5643] = {.lex_state = 52, .external_lex_state = 32},
  [5644] = {.lex_state = 57, .external_lex_state = 29},
  [5645] = {.lex_state = 63, .external_lex_state = 27},
  [5646] = {.lex_state = 55, .external_lex_state = 40},
  [5647] = {.lex_state = 52, .external_lex_state = 32},
  [5648] = {.lex_state = 63, .external_lex_state = 27},
  [5649] = {.lex_state = 52, .external_lex_state = 32},
  [5650] = {.lex_state = 58, .external_lex_state = 40},
  [5651] = {.lex_state = 52, .external_lex_state = 24},
  [5652] = {.lex_state = 58, .external_lex_state = 40},
  [5653] = {.lex_state = 58, .external_lex_state = 43},
  [5654] = {.lex_state = 7, .external_lex_state = 43},
  [5655] = {.lex_state = 63, .external_lex_state = 27},
  [5656] = {.lex_state = 56, .external_lex_state = 47},
  [5657] = {.lex_state = 56, .external_lex_state = 55},
  [5658] = {.lex_state = 63, .external_lex_state = 33},
  [5659] = {.lex_state = 56, .external_lex_state = 44},
  [5660] = {.lex_state = 63, .external_lex_state = 33},
  [5661] = {.lex_state = 61, .external_lex_state = 41},
  [5662] = {.lex_state = 63, .external_lex_state = 33},
  [5663] = {.lex_state = 58, .external_lex_state = 43},
  [5664] = {.lex_state = 63, .external_lex_state = 32},
  [5665] = {.lex_state = 58, .external_lex_state = 47},
  [5666] = {.lex_state = 56, .external_lex_state = 34},
  [5667] = {.lex_state = 58, .external_lex_state = 47},
  [5668] = {.lex_state = 57, .external_lex_state = 38},
  [5669] = {.lex_state = 52, .external_lex_state = 46},
  [5670] = {.lex_state = 52, .external_lex_state = 33},
  [5671] = {.lex_state = 56, .external_lex_state = 52},
  [5672] = {.lex_state = 63, .external_lex_state = 31},
  [5673] = {.lex_state = 56, .external_lex_state = 40},
  [5674] = {.lex_state = 57, .external_lex_state = 41},
  [5675] = {.lex_state = 56, .external_lex_state = 43},
  [5676] = {.lex_state = 52, .external_lex_state = 33},
  [5677] = {.lex_state = 63, .external_lex_state = 27},
  [5678] = {.lex_state = 57, .external_lex_state = 41},
  [5679] = {.lex_state = 63, .external_lex_state = 27},
  [5680] = {.lex_state = 52, .external_lex_state = 33},
  [5681] = {.lex_state = 63, .external_lex_state = 32},
  [5682] = {.lex_state = 57, .external_lex_state = 41},
  [5683] = {.lex_state = 63, .external_lex_state = 31},
  [5684] = {.lex_state = 63, .external_lex_state = 27},
  [5685] = {.lex_state = 63, .external_lex_state = 27},
  [5686] = {.lex_state = 63, .external_lex_state = 27},
  [5687] = {.lex_state = 63, .external_lex_state = 27},
  [5688] = {.lex_state = 63, .external_lex_state = 27},
  [5689] = {.lex_state = 61, .external_lex_state = 29},
  [5690] = {.lex_state = 63, .external_lex_state = 27},
  [5691] = {.lex_state = 63, .external_lex_state = 27},
  [5692] = {.lex_state = 63, .external_lex_state = 27},
  [5693] = {.lex_state = 63, .external_lex_state = 27},
  [5694] = {.lex_state = 63, .external_lex_state = 27},
  [5695] = {.lex_state = 63, .external_lex_state = 27},
  [5696] = {.lex_state = 63, .external_lex_state = 27},
  [5697] = {.lex_state = 63, .external_lex_state = 27},
  [5698] = {.lex_state = 63, .external_lex_state = 27},
  [5699] = {.lex_state = 57, .external_lex_state = 40},
  [5700] = {.lex_state = 63, .external_lex_state = 31},
  [5701] = {.lex_state = 52, .external_lex_state = 35},
  [5702] = {.lex_state = 57, .external_lex_state = 40},
  [5703] = {.lex_state = 63, .external_lex_state = 30},
  [5704] = {.lex_state = 56, .external_lex_state = 43},
  [5705] = {.lex_state = 55, .external_lex_state = 53},
  [5706] = {.lex_state = 52},
  [5707] = {.lex_state = 52, .external_lex_state = 36},
  [5708] = {.lex_state = 59, .external_lex_state = 40},
  [5709] = {.lex_state = 63, .external_lex_state = 53},
  [5710] = {.lex_state = 63, .external_lex_state = 47},
  [5711] = {.lex_state = 56, .external_lex_state = 40},
  [5712] = {.lex_state = 58, .external_lex_state = 55},
  [5713] = {.lex_state = 62, .external_lex_state = 40},
  [5714] = {.lex_state = 61, .external_lex_state = 46},
  [5715] = {.lex_state = 57, .external_lex_state = 32},
  [5716] = {.lex_state = 58, .external_lex_state = 43},
  [5717] = {.lex_state = 61, .external_lex_state = 52},
  [5718] = {.lex_state = 56, .external_lex_state = 44},
  [5719] = {.lex_state = 52, .external_lex_state = 37},
  [5720] = {.lex_state = 63, .external_lex_state = 56},
  [5721] = {.lex_state = 62, .external_lex_state = 40},
  [5722] = {.lex_state = 63, .external_lex_state = 46},
  [5723] = {.lex_state = 63, .external_lex_state = 27},
  [5724] = {.lex_state = 63, .external_lex_state = 30},
  [5725] = {.lex_state = 58, .external_lex_state = 41},
  [5726] = {.lex_state = 52, .external_lex_state = 36},
  [5727] = {.lex_state = 63, .external_lex_state = 56},
  [5728] = {.lex_state = 63, .external_lex_state = 57},
  [5729] = {.lex_state = 63, .external_lex_state = 27},
  [5730] = {.lex_state = 63, .external_lex_state = 27},
  [5731] = {.lex_state = 61, .external_lex_state = 29},
  [5732] = {.lex_state = 61, .external_lex_state = 40},
  [5733] = {.lex_state = 63, .external_lex_state = 56},
  [5734] = {.lex_state = 63, .external_lex_state = 27},
  [5735] = {.lex_state = 56, .external_lex_state = 44},
  [5736] = {.lex_state = 63, .external_lex_state = 27},
  [5737] = {.lex_state = 63, .external_lex_state = 27},
  [5738] = {.lex_state = 63, .external_lex_state = 31},
  [5739] = {.lex_state = 61, .external_lex_state = 52},
  [5740] = {.lex_state = 56, .external_lex_state = 44},
  [5741] = {.lex_state = 63, .external_lex_state = 27},
  [5742] = {.lex_state = 63, .external_lex_state = 57},
  [5743] = {.lex_state = 63, .external_lex_state = 28},
  [5744] = {.lex_state = 63, .external_lex_state = 28},
  [5745] = {.lex_state = 63, .external_lex_state = 47},
  [5746] = {.lex_state = 63, .external_lex_state = 27},
  [5747] = {.lex_state = 63, .external_lex_state = 57},
  [5748] = {.lex_state = 56, .external_lex_state = 41},
  [5749] = {.lex_state = 57, .external_lex_state = 30},
  [5750] = {.lex_state = 63, .external_lex_state = 28},
  [5751] = {.lex_state = 63, .external_lex_state = 28},
  [5752] = {.lex_state = 52, .external_lex_state = 45},
  [5753] = {.lex_state = 52, .external_lex_state = 35},
  [5754] = {.lex_state = 56, .external_lex_state = 44},
  [5755] = {.lex_state = 52, .external_lex_state = 45},
  [5756] = {.lex_state = 52, .external_lex_state = 54},
  [5757] = {.lex_state = 63, .external_lex_state = 27},
  [5758] = {.lex_state = 63, .external_lex_state = 27},
  [5759] = {.lex_state = 56, .external_lex_state = 44},
  [5760] = {.lex_state = 63, .external_lex_state = 42},
  [5761] = {.lex_state = 63, .external_lex_state = 58},
  [5762] = {.lex_state = 57, .external_lex_state = 41},
  [5763] = {.lex_state = 61, .external_lex_state = 43},
  [5764] = {.lex_state = 55, .external_lex_state = 40},
  [5765] = {.lex_state = 56, .external_lex_state = 46},
  [5766] = {.lex_state = 63, .external_lex_state = 27},
  [5767] = {.lex_state = 61, .external_lex_state = 43},
  [5768] = {.lex_state = 52, .external_lex_state = 26},
  [5769] = {.lex_state = 63, .external_lex_state = 27},
  [5770] = {.lex_state = 63, .external_lex_state = 58},
  [5771] = {.lex_state = 56, .external_lex_state = 53},
  [5772] = {.lex_state = 63, .external_lex_state = 58},
  [5773] = {.lex_state = 63, .external_lex_state = 50},
  [5774] = {.lex_state = 61, .external_lex_state = 53},
  [5775] = {.lex_state = 61, .external_lex_state = 41},
  [5776] = {.lex_state = 52, .external_lex_state = 24},
  [5777] = {.lex_state = 61, .external_lex_state = 26},
  [5778] = {.lex_state = 63, .external_lex_state = 28},
  [5779] = {.lex_state = 57, .external_lex_state = 43},
  [5780] = {.lex_state = 57, .external_lex_state = 40},
  [5781] = {.lex_state = 63, .external_lex_state = 47},
  [5782] = {.lex_state = 52, .external_lex_state = 26},
  [5783] = {.lex_state = 56, .external_lex_state = 43},
  [5784] = {.lex_state = 63, .external_lex_state = 34},
  [5785] = {.lex_state = 63, .external_lex_state = 47},
  [5786] = {.lex_state = 61, .external_lex_state = 41},
  [5787] = {.lex_state = 61, .external_lex_state = 41},
  [5788] = {.lex_state = 61, .external_lex_state = 26},
  [5789] = {.lex_state = 56, .external_lex_state = 44},
  [5790] = {.lex_state = 63, .external_lex_state = 27},
  [5791] = {.lex_state = 61, .external_lex_state = 53},
  [5792] = {.lex_state = 56, .external_lex_state = 30},
  [5793] = {.lex_state = 57, .external_lex_state = 40},
  [5794] = {.lex_state = 56, .external_lex_state = 38},
  [5795] = {.lex_state = 58, .external_lex_state = 41},
  [5796] = {.lex_state = 61, .external_lex_state = 29},
  [5797] = {.lex_state = 52, .external_lex_state = 55},
  [5798] = {.lex_state = 58, .external_lex_state = 41},
  [5799] = {.lex_state = 58, .external_lex_state = 41},
  [5800] = {.lex_state = 56, .external_lex_state = 47},
  [5801] = {.lex_state = 55, .external_lex_state = 43},
  [5802] = {.lex_state = 58, .external_lex_state = 41},
  [5803] = {.lex_state = 63, .external_lex_state = 27},
  [5804] = {.lex_state = 52, .external_lex_state = 35},
  [5805] = {.lex_state = 63, .external_lex_state = 27},
  [5806] = {.lex_state = 63, .external_lex_state = 27},
  [5807] = {.lex_state = 63, .external_lex_state = 30},
  [5808] = {.lex_state = 58, .external_lex_state = 41},
  [5809] = {.lex_state = 63, .external_lex_state = 39},
  [5810] = {.lex_state = 56, .external_lex_state = 46},
  [5811] = {.lex_state = 57, .external_lex_state = 29},
  [5812] = {.lex_state = 56, .external_lex_state = 47},
  [5813] = {.lex_state = 57, .external_lex_state = 41},
  [5814] = {.lex_state = 58, .external_lex_state = 41},
  [5815] = {.lex_state = 63, .external_lex_state = 28},
  [5816] = {.lex_state = 56, .external_lex_state = 50},
  [5817] = {.lex_state = 55, .external_lex_state = 40},
  [5818] = {.lex_state = 56, .external_lex_state = 32},
  [5819] = {.lex_state = 52, .external_lex_state = 26},
  [5820] = {.lex_state = 58, .external_lex_state = 41},
  [5821] = {.lex_state = 52, .external_lex_state = 49},
  [5822] = {.lex_state = 63, .external_lex_state = 28},
  [5823] = {.lex_state = 52, .external_lex_state = 56},
  [5824] = {.lex_state = 61, .external_lex_state = 29},
  [5825] = {.lex_state = 61, .external_lex_state = 30},
  [5826] = {.lex_state = 52, .external_lex_state = 26},
  [5827] = {.lex_state = 54},
  [5828] = {.lex_state = 61, .external_lex_state = 55},
  [5829] = {.lex_state = 63, .external_lex_state = 27},
  [5830] = {.lex_state = 63, .external_lex_state = 27},
  [5831] = {.lex_state = 63, .external_lex_state = 27},
  [5832] = {.lex_state = 52, .external_lex_state = 49},
  [5833] = {.lex_state = 63, .external_lex_state = 39},
  [5834] = {.lex_state = 52, .external_lex_state = 34},
  [5835] = {.lex_state = 57, .external_lex_state = 41},
  [5836] = {.lex_state = 61, .external_lex_state = 38},
  [5837] = {.lex_state = 57, .external_lex_state = 41},
  [5838] = {.lex_state = 57, .external_lex_state = 53},
  [5839] = {.lex_state = 57, .external_lex_state = 41},
  [5840] = {.lex_state = 63, .external_lex_state = 34},
  [5841] = {.lex_state = 63, .external_lex_state = 51},
  [5842] = {.lex_state = 62, .external_lex_state = 53},
  [5843] = {.lex_state = 63, .external_lex_state = 46},
  [5844] = {.lex_state = 57, .external_lex_state = 41},
  [5845] = {.lex_state = 58, .external_lex_state = 44},
  [5846] = {.lex_state = 63, .external_lex_state = 50},
  [5847] = {.lex_state = 57, .external_lex_state = 41},
  [5848] = {.lex_state = 55, .external_lex_state = 40},
  [5849] = {.lex_state = 52, .external_lex_state = 34},
  [5850] = {.lex_state = 57, .external_lex_state = 41},
  [5851] = {.lex_state = 62, .external_lex_state = 40},
  [5852] = {.lex_state = 57, .external_lex_state = 41},
  [5853] = {.lex_state = 52, .external_lex_state = 36},
  [5854] = {.lex_state = 63, .external_lex_state = 50},
  [5855] = {.lex_state = 56, .external_lex_state = 46},
  [5856] = {.lex_state = 63, .external_lex_state = 33},
  [5857] = {.lex_state = 56, .external_lex_state = 52},
  [5858] = {.lex_state = 52, .external_lex_state = 53},
  [5859] = {.lex_state = 61, .external_lex_state = 38},
  [5860] = {.lex_state = 52, .external_lex_state = 34},
  [5861] = {.lex_state = 58, .external_lex_state = 41},
  [5862] = {.lex_state = 58, .external_lex_state = 38},
  [5863] = {.lex_state = 61, .external_lex_state = 46},
  [5864] = {.lex_state = 63, .external_lex_state = 34},
  [5865] = {.lex_state = 57, .external_lex_state = 38},
  [5866] = {.lex_state = 52, .external_lex_state = 36},
  [5867] = {.lex_state = 61, .external_lex_state = 38},
  [5868] = {.lex_state = 58, .external_lex_state = 33},
  [5869] = {.lex_state = 63, .external_lex_state = 27},
  [5870] = {.lex_state = 63, .external_lex_state = 28},
  [5871] = {.lex_state = 61, .external_lex_state = 38},
  [5872] = {.lex_state = 63, .external_lex_state = 27},
  [5873] = {.lex_state = 52, .external_lex_state = 53},
  [5874] = {.lex_state = 63, .external_lex_state = 34},
  [5875] = {.lex_state = 63, .external_lex_state = 44},
  [5876] = {.lex_state = 56, .external_lex_state = 26},
  [5877] = {.lex_state = 57, .external_lex_state = 40},
  [5878] = {.lex_state = 63, .external_lex_state = 27},
  [5879] = {.lex_state = 63, .external_lex_state = 31},
  [5880] = {.lex_state = 63, .external_lex_state = 27},
  [5881] = {.lex_state = 63, .external_lex_state = 31},
  [5882] = {.lex_state = 63, .external_lex_state = 27},
  [5883] = {.lex_state = 52, .external_lex_state = 37},
  [5884] = {.lex_state = 57, .external_lex_state = 38},
  [5885] = {.lex_state = 59, .external_lex_state = 40},
  [5886] = {.lex_state = 58, .external_lex_state = 38},
  [5887] = {.lex_state = 52, .external_lex_state = 26},
  [5888] = {.lex_state = 61, .external_lex_state = 47},
  [5889] = {.lex_state = 56, .external_lex_state = 54},
  [5890] = {.lex_state = 56, .external_lex_state = 46},
  [5891] = {.lex_state = 58, .external_lex_state = 30},
  [5892] = {.lex_state = 62, .external_lex_state = 53},
  [5893] = {.lex_state = 61, .external_lex_state = 27},
  [5894] = {.lex_state = 58, .external_lex_state = 38},
  [5895] = {.lex_state = 63, .external_lex_state = 31},
  [5896] = {.lex_state = 58, .external_lex_state = 38},
  [5897] = {.lex_state = 63, .external_lex_state = 46},
  [5898] = {.lex_state = 58, .external_lex_state = 38},
  [5899] = {.lex_state = 56, .external_lex_state = 50},
  [5900] = {.lex_state = 58, .external_lex_state = 38},
  [5901] = {.lex_state = 58, .external_lex_state = 34},
  [5902] = {.lex_state = 63, .external_lex_state = 31},
  [5903] = {.lex_state = 57, .external_lex_state = 40},
  [5904] = {.lex_state = 52, .external_lex_state = 43},
  [5905] = {.lex_state = 58, .external_lex_state = 34},
  [5906] = {.lex_state = 58, .external_lex_state = 38},
  [5907] = {.lex_state = 63, .external_lex_state = 34},
  [5908] = {.lex_state = 58, .external_lex_state = 33},
  [5909] = {.lex_state = 52, .external_lex_state = 23},
  [5910] = {.lex_state = 63, .external_lex_state = 44},
  [5911] = {.lex_state = 62, .external_lex_state = 53},
  [5912] = {.lex_state = 58, .external_lex_state = 43},
  [5913] = {.lex_state = 63, .external_lex_state = 34},
  [5914] = {.lex_state = 61, .external_lex_state = 40},
  [5915] = {.lex_state = 58, .external_lex_state = 38},
  [5916] = {.lex_state = 57, .external_lex_state = 41},
  [5917] = {.lex_state = 61, .external_lex_state = 40},
  [5918] = {.lex_state = 52, .external_lex_state = 41},
  [5919] = {.lex_state = 61, .external_lex_state = 40},
  [5920] = {.lex_state = 57, .external_lex_state = 30},
  [5921] = {.lex_state = 57, .external_lex_state = 40},
  [5922] = {.lex_state = 61, .external_lex_state = 47},
  [5923] = {.lex_state = 57, .external_lex_state = 38},
  [5924] = {.lex_state = 57, .external_lex_state = 53},
  [5925] = {.lex_state = 61, .external_lex_state = 53},
  [5926] = {.lex_state = 57, .external_lex_state = 40},
  [5927] = {.lex_state = 57, .external_lex_state = 38},
  [5928] = {.lex_state = 56, .external_lex_state = 44},
  [5929] = {.lex_state = 57, .external_lex_state = 40},
  [5930] = {.lex_state = 56, .external_lex_state = 47},
  [5931] = {.lex_state = 56, .external_lex_state = 46},
  [5932] = {.lex_state = 57, .external_lex_state = 40},
  [5933] = {.lex_state = 63, .external_lex_state = 33},
  [5934] = {.lex_state = 63, .external_lex_state = 46},
  [5935] = {.lex_state = 58, .external_lex_state = 53},
  [5936] = {.lex_state = 52, .external_lex_state = 40},
  [5937] = {.lex_state = 52, .external_lex_state = 44},
  [5938] = {.lex_state = 55, .external_lex_state = 40},
  [5939] = {.lex_state = 56, .external_lex_state = 55},
  [5940] = {.lex_state = 52, .external_lex_state = 44},
  [5941] = {.lex_state = 57, .external_lex_state = 40},
  [5942] = {.lex_state = 52, .external_lex_state = 54},
  [5943] = {.lex_state = 56, .external_lex_state = 47},
  [5944] = {.lex_state = 56, .external_lex_state = 46},
  [5945] = {.lex_state = 59, .external_lex_state = 53},
  [5946] = {.lex_state = 56, .external_lex_state = 47},
  [5947] = {.lex_state = 56, .external_lex_state = 47},
  [5948] = {.lex_state = 56, .external_lex_state = 47},
  [5949] = {.lex_state = 61, .external_lex_state = 32},
  [5950] = {.lex_state = 56, .external_lex_state = 47},
  [5951] = {.lex_state = 56, .external_lex_state = 44},
  [5952] = {.lex_state = 56, .external_lex_state = 47},
  [5953] = {.lex_state = 57, .external_lex_state = 40},
  [5954] = {.lex_state = 56, .external_lex_state = 46},
  [5955] = {.lex_state = 56, .external_lex_state = 50},
  [5956] = {.lex_state = 58, .external_lex_state = 50},
  [5957] = {.lex_state = 56, .external_lex_state = 47},
  [5958] = {.lex_state = 61, .external_lex_state = 54},
  [5959] = {.lex_state = 56, .external_lex_state = 46},
  [5960] = {.lex_state = 56, .external_lex_state = 50},
  [5961] = {.lex_state = 56, .external_lex_state = 50},
  [5962] = {.lex_state = 61, .external_lex_state = 54},
  [5963] = {.lex_state = 56, .external_lex_state = 46},
  [5964] = {.lex_state = 63, .external_lex_state = 31},
  [5965] = {.lex_state = 56, .external_lex_state = 46},
  [5966] = {.lex_state = 63, .external_lex_state = 27},
  [5967] = {.lex_state = 63, .external_lex_state = 27},
  [5968] = {.lex_state = 56, .external_lex_state = 46},
  [5969] = {.lex_state = 52},
  [5970] = {.lex_state = 63, .external_lex_state = 27},
  [5971] = {.lex_state = 61, .external_lex_state = 34},
  [5972] = {.lex_state = 63, .external_lex_state = 31},
  [5973] = {.lex_state = 58, .external_lex_state = 43},
  [5974] = {.lex_state = 61, .external_lex_state = 30},
  [5975] = {.lex_state = 58, .external_lex_state = 38},
  [5976] = {.lex_state = 56, .external_lex_state = 44},
  [5977] = {.lex_state = 58, .external_lex_state = 52},
  [5978] = {.lex_state = 56, .external_lex_state = 50},
  [5979] = {.lex_state = 56, .external_lex_state = 50},
  [5980] = {.lex_state = 63, .external_lex_state = 32},
  [5981] = {.lex_state = 57, .external_lex_state = 38},
  [5982] = {.lex_state = 52, .external_lex_state = 54},
  [5983] = {.lex_state = 56, .external_lex_state = 50},
  [5984] = {.lex_state = 56, .external_lex_state = 43},
  [5985] = {.lex_state = 58, .external_lex_state = 46},
  [5986] = {.lex_state = 61, .external_lex_state = 30},
  [5987] = {.lex_state = 56, .external_lex_state = 50},
  [5988] = {.lex_state = 63, .external_lex_state = 31},
  [5989] = {.lex_state = 63, .external_lex_state = 44},
  [5990] = {.lex_state = 52, .external_lex_state = 29},
  [5991] = {.lex_state = 63, .external_lex_state = 28},
  [5992] = {.lex_state = 63, .external_lex_state = 44},
  [5993] = {.lex_state = 58, .external_lex_state = 43},
  [5994] = {.lex_state = 57, .external_lex_state = 46},
  [5995] = {.lex_state = 52, .external_lex_state = 45},
  [5996] = {.lex_state = 63, .external_lex_state = 55},
  [5997] = {.lex_state = 63, .external_lex_state = 41},
  [5998] = {.lex_state = 63, .external_lex_state = 36},
  [5999] = {.lex_state = 61, .external_lex_state = 33},
  [6000] = {.lex_state = 58, .external_lex_state = 43},
  [6001] = {.lex_state = 63, .external_lex_state = 27},
  [6002] = {.lex_state = 59, .external_lex_state = 40},
  [6003] = {.lex_state = 7, .external_lex_state = 43},
  [6004] = {.lex_state = 61, .external_lex_state = 50},
  [6005] = {.lex_state = 52, .external_lex_state = 48},
  [6006] = {.lex_state = 56, .external_lex_state = 26},
  [6007] = {.lex_state = 58, .external_lex_state = 53},
  [6008] = {.lex_state = 61, .external_lex_state = 50},
  [6009] = {.lex_state = 63, .external_lex_state = 37},
  [6010] = {.lex_state = 52, .external_lex_state = 27},
  [6011] = {.lex_state = 63, .external_lex_state = 57},
  [6012] = {.lex_state = 56, .external_lex_state = 26},
  [6013] = {.lex_state = 63, .external_lex_state = 55},
  [6014] = {.lex_state = 63, .external_lex_state = 28},
  [6015] = {.lex_state = 52, .external_lex_state = 26},
  [6016] = {.lex_state = 63, .external_lex_state = 28},
  [6017] = {.lex_state = 63, .external_lex_state = 58},
  [6018] = {.lex_state = 58, .external_lex_state = 55},
  [6019] = {.lex_state = 63, .external_lex_state = 31},
  [6020] = {.lex_state = 59, .external_lex_state = 53},
  [6021] = {.lex_state = 55, .external_lex_state = 40},
  [6022] = {.lex_state = 63, .external_lex_state = 28},
  [6023] = {.lex_state = 56, .external_lex_state = 26},
  [6024] = {.lex_state = 63, .external_lex_state = 28},
  [6025] = {.lex_state = 63, .external_lex_state = 28},
  [6026] = {.lex_state = 63, .external_lex_state = 28},
  [6027] = {.lex_state = 56, .external_lex_state = 26},
  [6028] = {.lex_state = 58, .external_lex_state = 50},
  [6029] = {.lex_state = 56, .external_lex_state = 26},
  [6030] = {.lex_state = 63},
  [6031] = {.lex_state = 56, .external_lex_state = 26},
  [6032] = {.lex_state = 58, .external_lex_state = 50},
  [6033] = {.lex_state = 61, .external_lex_state = 26},
  [6034] = {.lex_state = 63, .external_lex_state = 31},
  [6035] = {.lex_state = 63, .external_lex_state = 31},
  [6036] = {.lex_state = 52, .external_lex_state = 44},
  [6037] = {.lex_state = 63, .external_lex_state = 45},
  [6038] = {.lex_state = 62, .external_lex_state = 53},
  [6039] = {.lex_state = 61, .external_lex_state = 43},
  [6040] = {.lex_state = 63, .external_lex_state = 31},
  [6041] = {.lex_state = 56, .external_lex_state = 53},
  [6042] = {.lex_state = 63, .external_lex_state = 34},
  [6043] = {.lex_state = 63, .external_lex_state = 28},
  [6044] = {.lex_state = 56, .external_lex_state = 30},
  [6045] = {.lex_state = 58, .external_lex_state = 47},
  [6046] = {.lex_state = 63, .external_lex_state = 31},
  [6047] = {.lex_state = 63, .external_lex_state = 26},
  [6048] = {.lex_state = 55, .external_lex_state = 40},
  [6049] = {.lex_state = 56, .external_lex_state = 54},
  [6050] = {.lex_state = 63, .external_lex_state = 31},
  [6051] = {.lex_state = 56, .external_lex_state = 43},
  [6052] = {.lex_state = 61, .external_lex_state = 55},
  [6053] = {.lex_state = 56, .external_lex_state = 47},
  [6054] = {.lex_state = 56, .external_lex_state = 47},
  [6055] = {.lex_state = 63, .external_lex_state = 36},
  [6056] = {.lex_state = 63, .external_lex_state = 31},
  [6057] = {.lex_state = 63, .external_lex_state = 23},
  [6058] = {.lex_state = 56, .external_lex_state = 43},
  [6059] = {.lex_state = 58, .external_lex_state = 50},
  [6060] = {.lex_state = 57, .external_lex_state = 47},
  [6061] = {.lex_state = 63, .external_lex_state = 28},
  [6062] = {.lex_state = 63},
  [6063] = {.lex_state = 63, .external_lex_state = 31},
  [6064] = {.lex_state = 59, .external_lex_state = 53},
  [6065] = {.lex_state = 63, .external_lex_state = 31},
  [6066] = {.lex_state = 56, .external_lex_state = 43},
  [6067] = {.lex_state = 17, .external_lex_state = 43},
  [6068] = {.lex_state = 58, .external_lex_state = 44},
  [6069] = {.lex_state = 62, .external_lex_state = 53},
  [6070] = {.lex_state = 52, .external_lex_state = 39},
  [6071] = {.lex_state = 56, .external_lex_state = 55},
  [6072] = {.lex_state = 52, .external_lex_state = 26},
  [6073] = {.lex_state = 56, .external_lex_state = 43},
  [6074] = {.lex_state = 56, .external_lex_state = 43},
  [6075] = {.lex_state = 58, .external_lex_state = 26},
  [6076] = {.lex_state = 58, .external_lex_state = 50},
  [6077] = {.lex_state = 58, .external_lex_state = 50},
  [6078] = {.lex_state = 56, .external_lex_state = 43},
  [6079] = {.lex_state = 52, .external_lex_state = 23},
  [6080] = {.lex_state = 56, .external_lex_state = 43},
  [6081] = {.lex_state = 57, .external_lex_state = 47},
  [6082] = {.lex_state = 61, .external_lex_state = 54},
  [6083] = {.lex_state = 56, .external_lex_state = 55},
  [6084] = {.lex_state = 58, .external_lex_state = 50},
  [6085] = {.lex_state = 58, .external_lex_state = 50},
  [6086] = {.lex_state = 63, .external_lex_state = 23},
  [6087] = {.lex_state = 63, .external_lex_state = 31},
  [6088] = {.lex_state = 61, .external_lex_state = 32},
  [6089] = {.lex_state = 63, .external_lex_state = 28},
  [6090] = {.lex_state = 56, .external_lex_state = 32},
  [6091] = {.lex_state = 52, .external_lex_state = 57},
  [6092] = {.lex_state = 58, .external_lex_state = 50},
  [6093] = {.lex_state = 63, .external_lex_state = 23},
  [6094] = {.lex_state = 52, .external_lex_state = 58},
  [6095] = {.lex_state = 56, .external_lex_state = 55},
  [6096] = {.lex_state = 52, .external_lex_state = 45},
  [6097] = {.lex_state = 56, .external_lex_state = 52},
  [6098] = {.lex_state = 57, .external_lex_state = 47},
  [6099] = {.lex_state = 56, .external_lex_state = 52},
  [6100] = {.lex_state = 63, .external_lex_state = 26},
  [6101] = {.lex_state = 52, .external_lex_state = 48},
  [6102] = {.lex_state = 63, .external_lex_state = 52},
  [6103] = {.lex_state = 56, .external_lex_state = 52},
  [6104] = {.lex_state = 63, .external_lex_state = 37},
  [6105] = {.lex_state = 63, .external_lex_state = 28},
  [6106] = {.lex_state = 63, .external_lex_state = 36},
  [6107] = {.lex_state = 57, .external_lex_state = 47},
  [6108] = {.lex_state = 52, .external_lex_state = 27},
  [6109] = {.lex_state = 63, .external_lex_state = 55},
  [6110] = {.lex_state = 56, .external_lex_state = 54},
  [6111] = {.lex_state = 63, .external_lex_state = 31},
  [6112] = {.lex_state = 58, .external_lex_state = 54},
  [6113] = {.lex_state = 56, .external_lex_state = 55},
  [6114] = {.lex_state = 56, .external_lex_state = 43},
  [6115] = {.lex_state = 52, .external_lex_state = 42},
  [6116] = {.lex_state = 56, .external_lex_state = 52},
  [6117] = {.lex_state = 52, .external_lex_state = 58},
  [6118] = {.lex_state = 57, .external_lex_state = 47},
  [6119] = {.lex_state = 58, .external_lex_state = 53},
  [6120] = {.lex_state = 57, .external_lex_state = 46},
  [6121] = {.lex_state = 56, .external_lex_state = 52},
  [6122] = {.lex_state = 55, .external_lex_state = 43},
  [6123] = {.lex_state = 57, .external_lex_state = 47},
  [6124] = {.lex_state = 57, .external_lex_state = 47},
  [6125] = {.lex_state = 63, .external_lex_state = 31},
  [6126] = {.lex_state = 63, .external_lex_state = 55},
  [6127] = {.lex_state = 57, .external_lex_state = 47},
  [6128] = {.lex_state = 63, .external_lex_state = 45},
  [6129] = {.lex_state = 63, .external_lex_state = 31},
  [6130] = {.lex_state = 57, .external_lex_state = 47},
  [6131] = {.lex_state = 3},
  [6132] = {.lex_state = 61, .external_lex_state = 38},
  [6133] = {.lex_state = 63, .external_lex_state = 57},
  [6134] = {.lex_state = 58, .external_lex_state = 44},
  [6135] = {.lex_state = 55, .external_lex_state = 40},
  [6136] = {.lex_state = 58, .external_lex_state = 26},
  [6137] = {.lex_state = 58, .external_lex_state = 44},
  [6138] = {.lex_state = 63, .external_lex_state = 28},
  [6139] = {.lex_state = 63},
  [6140] = {.lex_state = 57, .external_lex_state = 50},
  [6141] = {.lex_state = 58, .external_lex_state = 26},
  [6142] = {.lex_state = 57, .external_lex_state = 44},
  [6143] = {.lex_state = 61, .external_lex_state = 44},
  [6144] = {.lex_state = 57, .external_lex_state = 50},
  [6145] = {.lex_state = 57, .external_lex_state = 50},
  [6146] = {.lex_state = 63, .external_lex_state = 28},
  [6147] = {.lex_state = 61, .external_lex_state = 30},
  [6148] = {.lex_state = 63, .external_lex_state = 24},
  [6149] = {.lex_state = 56, .external_lex_state = 52},
  [6150] = {.lex_state = 63, .external_lex_state = 28},
  [6151] = {.lex_state = 57, .external_lex_state = 50},
  [6152] = {.lex_state = 56, .external_lex_state = 53},
  [6153] = {.lex_state = 57, .external_lex_state = 50},
  [6154] = {.lex_state = 63, .external_lex_state = 37},
  [6155] = {.lex_state = 63, .external_lex_state = 28},
  [6156] = {.lex_state = 58, .external_lex_state = 44},
  [6157] = {.lex_state = 63, .external_lex_state = 28},
  [6158] = {.lex_state = 55, .external_lex_state = 53},
  [6159] = {.lex_state = 57, .external_lex_state = 47},
  [6160] = {.lex_state = 58, .external_lex_state = 44},
  [6161] = {.lex_state = 63},
  [6162] = {.lex_state = 57, .external_lex_state = 44},
  [6163] = {.lex_state = 63, .external_lex_state = 31},
  [6164] = {.lex_state = 63, .external_lex_state = 41},
  [6165] = {.lex_state = 62, .external_lex_state = 40},
  [6166] = {.lex_state = 52, .external_lex_state = 50},
  [6167] = {.lex_state = 57, .external_lex_state = 44},
  [6168] = {.lex_state = 63, .external_lex_state = 36},
  [6169] = {.lex_state = 63, .external_lex_state = 28},
  [6170] = {.lex_state = 56, .external_lex_state = 54},
  [6171] = {.lex_state = 61, .external_lex_state = 32},
  [6172] = {.lex_state = 57, .external_lex_state = 46},
  [6173] = {.lex_state = 52, .external_lex_state = 46},
  [6174] = {.lex_state = 63, .external_lex_state = 34},
  [6175] = {.lex_state = 52, .external_lex_state = 34},
  [6176] = {.lex_state = 63, .external_lex_state = 35},
  [6177] = {.lex_state = 61, .external_lex_state = 30},
  [6178] = {.lex_state = 58, .external_lex_state = 47},
  [6179] = {.lex_state = 55, .external_lex_state = 40},
  [6180] = {.lex_state = 63, .external_lex_state = 36},
  [6181] = {.lex_state = 57, .external_lex_state = 50},
  [6182] = {.lex_state = 61, .external_lex_state = 34},
  [6183] = {.lex_state = 63},
  [6184] = {.lex_state = 58, .external_lex_state = 44},
  [6185] = {.lex_state = 63, .external_lex_state = 36},
  [6186] = {.lex_state = 63, .external_lex_state = 23},
  [6187] = {.lex_state = 63, .external_lex_state = 38},
  [6188] = {.lex_state = 63, .external_lex_state = 28},
  [6189] = {.lex_state = 3},
  [6190] = {.lex_state = 63, .external_lex_state = 58},
  [6191] = {.lex_state = 58, .external_lex_state = 44},
  [6192] = {.lex_state = 63, .external_lex_state = 28},
  [6193] = {.lex_state = 57, .external_lex_state = 50},
  [6194] = {.lex_state = 58, .external_lex_state = 44},
  [6195] = {.lex_state = 55, .external_lex_state = 40},
  [6196] = {.lex_state = 63, .external_lex_state = 28},
  [6197] = {.lex_state = 58, .external_lex_state = 30},
  [6198] = {.lex_state = 56, .external_lex_state = 55},
  [6199] = {.lex_state = 59, .external_lex_state = 40},
  [6200] = {.lex_state = 63, .external_lex_state = 28},
  [6201] = {.lex_state = 63, .external_lex_state = 28},
  [6202] = {.lex_state = 63, .external_lex_state = 28},
  [6203] = {.lex_state = 63, .external_lex_state = 28},
  [6204] = {.lex_state = 52, .external_lex_state = 43},
  [6205] = {.lex_state = 63, .external_lex_state = 32},
  [6206] = {.lex_state = 56, .external_lex_state = 34},
  [6207] = {.lex_state = 58, .external_lex_state = 34},
  [6208] = {.lex_state = 63, .external_lex_state = 28},
  [6209] = {.lex_state = 63, .external_lex_state = 28},
  [6210] = {.lex_state = 59, .external_lex_state = 53},
  [6211] = {.lex_state = 55, .external_lex_state = 53},
  [6212] = {.lex_state = 63, .external_lex_state = 28},
  [6213] = {.lex_state = 63, .external_lex_state = 28},
  [6214] = {.lex_state = 58, .external_lex_state = 54},
  [6215] = {.lex_state = 63, .external_lex_state = 31},
  [6216] = {.lex_state = 57, .external_lex_state = 47},
  [6217] = {.lex_state = 56, .external_lex_state = 52},
  [6218] = {.lex_state = 63, .external_lex_state = 28},
  [6219] = {.lex_state = 63, .external_lex_state = 28},
  [6220] = {.lex_state = 63, .external_lex_state = 33},
  [6221] = {.lex_state = 58, .external_lex_state = 41},
  [6222] = {.lex_state = 56, .external_lex_state = 44},
  [6223] = {.lex_state = 52, .external_lex_state = 29},
  [6224] = {.lex_state = 63, .external_lex_state = 28},
  [6225] = {.lex_state = 63, .external_lex_state = 28},
  [6226] = {.lex_state = 63, .external_lex_state = 28},
  [6227] = {.lex_state = 61, .external_lex_state = 38},
  [6228] = {.lex_state = 56, .external_lex_state = 44},
  [6229] = {.lex_state = 57, .external_lex_state = 50},
  [6230] = {.lex_state = 58, .external_lex_state = 54},
  [6231] = {.lex_state = 52, .external_lex_state = 30},
  [6232] = {.lex_state = 61, .external_lex_state = 52},
  [6233] = {.lex_state = 58, .external_lex_state = 54},
  [6234] = {.lex_state = 61, .external_lex_state = 53},
  [6235] = {.lex_state = 63, .external_lex_state = 28},
  [6236] = {.lex_state = 63, .external_lex_state = 28},
  [6237] = {.lex_state = 63, .external_lex_state = 28},
  [6238] = {.lex_state = 63, .external_lex_state = 34},
  [6239] = {.lex_state = 57, .external_lex_state = 46},
  [6240] = {.lex_state = 58, .external_lex_state = 53},
  [6241] = {.lex_state = 63, .external_lex_state = 28},
  [6242] = {.lex_state = 63, .external_lex_state = 28},
  [6243] = {.lex_state = 3},
  [6244] = {.lex_state = 56, .external_lex_state = 53},
  [6245] = {.lex_state = 52, .external_lex_state = 29},
  [6246] = {.lex_state = 52, .external_lex_state = 39},
  [6247] = {.lex_state = 63, .external_lex_state = 28},
  [6248] = {.lex_state = 61, .external_lex_state = 34},
  [6249] = {.lex_state = 52, .external_lex_state = 23},
  [6250] = {.lex_state = 58, .external_lex_state = 46},
  [6251] = {.lex_state = 63, .external_lex_state = 35},
  [6252] = {.lex_state = 58, .external_lex_state = 55},
  [6253] = {.lex_state = 63, .external_lex_state = 28},
  [6254] = {.lex_state = 52, .external_lex_state = 32},
  [6255] = {.lex_state = 58, .external_lex_state = 47},
  [6256] = {.lex_state = 52, .external_lex_state = 30},
  [6257] = {.lex_state = 58, .external_lex_state = 55},
  [6258] = {.lex_state = 58, .external_lex_state = 47},
  [6259] = {.lex_state = 56, .external_lex_state = 50},
  [6260] = {.lex_state = 56, .external_lex_state = 50},
  [6261] = {.lex_state = 57, .external_lex_state = 47},
  [6262] = {.lex_state = 58, .external_lex_state = 47},
  [6263] = {.lex_state = 52, .external_lex_state = 40},
  [6264] = {.lex_state = 63, .external_lex_state = 28},
  [6265] = {.lex_state = 63, .external_lex_state = 48},
  [6266] = {.lex_state = 58, .external_lex_state = 46},
  [6267] = {.lex_state = 56, .external_lex_state = 54},
  [6268] = {.lex_state = 56, .external_lex_state = 30},
  [6269] = {.lex_state = 56, .external_lex_state = 54},
  [6270] = {.lex_state = 55, .external_lex_state = 40},
  [6271] = {.lex_state = 58, .external_lex_state = 32},
  [6272] = {.lex_state = 56, .external_lex_state = 54},
  [6273] = {.lex_state = 63, .external_lex_state = 28},
  [6274] = {.lex_state = 63, .external_lex_state = 52},
  [6275] = {.lex_state = 58, .external_lex_state = 46},
  [6276] = {.lex_state = 56, .external_lex_state = 54},
  [6277] = {.lex_state = 52, .external_lex_state = 39},
  [6278] = {.lex_state = 63, .external_lex_state = 23},
  [6279] = {.lex_state = 61, .external_lex_state = 55},
  [6280] = {.lex_state = 56, .external_lex_state = 55},
  [6281] = {.lex_state = 7, .external_lex_state = 43},
  [6282] = {.lex_state = 63, .external_lex_state = 36},
  [6283] = {.lex_state = 63, .external_lex_state = 35},
  [6284] = {.lex_state = 63, .external_lex_state = 38},
  [6285] = {.lex_state = 56, .external_lex_state = 54},
  [6286] = {.lex_state = 63, .external_lex_state = 35},
  [6287] = {.lex_state = 63, .external_lex_state = 28},
  [6288] = {.lex_state = 56, .external_lex_state = 52},
  [6289] = {.lex_state = 63, .external_lex_state = 51},
  [6290] = {.lex_state = 56, .external_lex_state = 30},
  [6291] = {.lex_state = 52, .external_lex_state = 43},
  [6292] = {.lex_state = 63, .external_lex_state = 28},
  [6293] = {.lex_state = 63, .external_lex_state = 36},
  [6294] = {.lex_state = 52, .external_lex_state = 29},
  [6295] = {.lex_state = 58, .external_lex_state = 29},
  [6296] = {.lex_state = 56, .external_lex_state = 44},
  [6297] = {.lex_state = 56, .external_lex_state = 54},
  [6298] = {.lex_state = 56, .external_lex_state = 54},
  [6299] = {.lex_state = 63},
  [6300] = {.lex_state = 63},
  [6301] = {.lex_state = 63, .external_lex_state = 28},
  [6302] = {.lex_state = 7, .external_lex_state = 43},
  [6303] = {.lex_state = 58, .external_lex_state = 46},
  [6304] = {.lex_state = 63, .external_lex_state = 36},
  [6305] = {.lex_state = 63, .external_lex_state = 36},
  [6306] = {.lex_state = 63, .external_lex_state = 36},
  [6307] = {.lex_state = 56, .external_lex_state = 46},
  [6308] = {.lex_state = 58, .external_lex_state = 47},
  [6309] = {.lex_state = 57, .external_lex_state = 40},
  [6310] = {.lex_state = 63, .external_lex_state = 36},
  [6311] = {.lex_state = 56, .external_lex_state = 46},
  [6312] = {.lex_state = 56, .external_lex_state = 29},
  [6313] = {.lex_state = 7, .external_lex_state = 43},
  [6314] = {.lex_state = 55, .external_lex_state = 53},
  [6315] = {.lex_state = 55, .external_lex_state = 53},
  [6316] = {.lex_state = 52, .external_lex_state = 24},
  [6317] = {.lex_state = 63, .external_lex_state = 35},
  [6318] = {.lex_state = 63, .external_lex_state = 36},
  [6319] = {.lex_state = 52, .external_lex_state = 44},
  [6320] = {.lex_state = 63, .external_lex_state = 35},
  [6321] = {.lex_state = 57, .external_lex_state = 50},
  [6322] = {.lex_state = 63, .external_lex_state = 28},
  [6323] = {.lex_state = 63, .external_lex_state = 28},
  [6324] = {.lex_state = 56, .external_lex_state = 47},
  [6325] = {.lex_state = 64, .external_lex_state = 40},
  [6326] = {.lex_state = 61, .external_lex_state = 26},
  [6327] = {.lex_state = 63, .external_lex_state = 40},
  [6328] = {.lex_state = 57, .external_lex_state = 32},
  [6329] = {.lex_state = 63, .external_lex_state = 28},
  [6330] = {.lex_state = 63, .external_lex_state = 28},
  [6331] = {.lex_state = 63, .external_lex_state = 28},
  [6332] = {.lex_state = 63, .external_lex_state = 54},
  [6333] = {.lex_state = 64, .external_lex_state = 53},
  [6334] = {.lex_state = 56, .external_lex_state = 52},
  [6335] = {.lex_state = 57, .external_lex_state = 50},
  [6336] = {.lex_state = 61, .external_lex_state = 46},
  [6337] = {.lex_state = 59, .external_lex_state = 40},
  [6338] = {.lex_state = 63, .external_lex_state = 48},
  [6339] = {.lex_state = 52, .external_lex_state = 47},
  [6340] = {.lex_state = 61, .external_lex_state = 46},
  [6341] = {.lex_state = 56, .external_lex_state = 52},
  [6342] = {.lex_state = 63, .external_lex_state = 40},
  [6343] = {.lex_state = 55, .external_lex_state = 53},
  [6344] = {.lex_state = 56, .external_lex_state = 43},
  [6345] = {.lex_state = 63, .external_lex_state = 40},
  [6346] = {.lex_state = 63, .external_lex_state = 33},
  [6347] = {.lex_state = 56, .external_lex_state = 43},
  [6348] = {.lex_state = 63, .external_lex_state = 40},
  [6349] = {.lex_state = 54},
  [6350] = {.lex_state = 56, .external_lex_state = 43},
  [6351] = {.lex_state = 57, .external_lex_state = 50},
  [6352] = {.lex_state = 63, .external_lex_state = 31},
  [6353] = {.lex_state = 52, .external_lex_state = 33},
  [6354] = {.lex_state = 58, .external_lex_state = 47},
  [6355] = {.lex_state = 63, .external_lex_state = 36},
  [6356] = {.lex_state = 63, .external_lex_state = 36},
  [6357] = {.lex_state = 57, .external_lex_state = 34},
  [6358] = {.lex_state = 63},
  [6359] = {.lex_state = 55, .external_lex_state = 53},
  [6360] = {.lex_state = 61, .external_lex_state = 46},
  [6361] = {.lex_state = 63, .external_lex_state = 49},
  [6362] = {.lex_state = 61, .external_lex_state = 46},
  [6363] = {.lex_state = 52, .external_lex_state = 50},
  [6364] = {.lex_state = 52, .external_lex_state = 43},
  [6365] = {.lex_state = 56, .external_lex_state = 29},
  [6366] = {.lex_state = 56, .external_lex_state = 52},
  [6367] = {.lex_state = 52, .external_lex_state = 32},
  [6368] = {.lex_state = 57, .external_lex_state = 44},
  [6369] = {.lex_state = 62, .external_lex_state = 43},
  [6370] = {.lex_state = 64, .external_lex_state = 40},
  [6371] = {.lex_state = 58, .external_lex_state = 52},
  [6372] = {.lex_state = 56, .external_lex_state = 55},
  [6373] = {.lex_state = 56, .external_lex_state = 26},
  [6374] = {.lex_state = 63, .external_lex_state = 31},
  [6375] = {.lex_state = 63, .external_lex_state = 23},
  [6376] = {.lex_state = 63, .external_lex_state = 54},
  [6377] = {.lex_state = 61, .external_lex_state = 47},
  [6378] = {.lex_state = 58, .external_lex_state = 52},
  [6379] = {.lex_state = 52, .external_lex_state = 34},
  [6380] = {.lex_state = 52, .external_lex_state = 43},
  [6381] = {.lex_state = 55, .external_lex_state = 53},
  [6382] = {.lex_state = 52, .external_lex_state = 23},
  [6383] = {.lex_state = 57, .external_lex_state = 46},
  [6384] = {.lex_state = 59, .external_lex_state = 40},
  [6385] = {.lex_state = 63, .external_lex_state = 31},
  [6386] = {.lex_state = 57, .external_lex_state = 46},
  [6387] = {.lex_state = 52, .external_lex_state = 41},
  [6388] = {.lex_state = 52, .external_lex_state = 30},
  [6389] = {.lex_state = 56, .external_lex_state = 43},
  [6390] = {.lex_state = 56, .external_lex_state = 55},
  [6391] = {.lex_state = 63, .external_lex_state = 31},
  [6392] = {.lex_state = 56, .external_lex_state = 55},
  [6393] = {.lex_state = 55, .external_lex_state = 43},
  [6394] = {.lex_state = 56, .external_lex_state = 52},
  [6395] = {.lex_state = 58, .external_lex_state = 50},
  [6396] = {.lex_state = 55, .external_lex_state = 53},
  [6397] = {.lex_state = 58, .external_lex_state = 52},
  [6398] = {.lex_state = 58, .external_lex_state = 44},
  [6399] = {.lex_state = 56, .external_lex_state = 55},
  [6400] = {.lex_state = 58, .external_lex_state = 46},
  [6401] = {.lex_state = 61, .external_lex_state = 29},
  [6402] = {.lex_state = 56, .external_lex_state = 55},
  [6403] = {.lex_state = 52, .external_lex_state = 23},
  [6404] = {.lex_state = 56, .external_lex_state = 55},
  [6405] = {.lex_state = 61, .external_lex_state = 29},
  [6406] = {.lex_state = 57, .external_lex_state = 47},
  [6407] = {.lex_state = 56, .external_lex_state = 55},
  [6408] = {.lex_state = 64, .external_lex_state = 53},
  [6409] = {.lex_state = 56, .external_lex_state = 26},
  [6410] = {.lex_state = 63, .external_lex_state = 38},
  [6411] = {.lex_state = 63, .external_lex_state = 31},
  [6412] = {.lex_state = 57, .external_lex_state = 47},
  [6413] = {.lex_state = 56, .external_lex_state = 52},
  [6414] = {.lex_state = 57, .external_lex_state = 47},
  [6415] = {.lex_state = 55, .external_lex_state = 43},
  [6416] = {.lex_state = 59, .external_lex_state = 53},
  [6417] = {.lex_state = 56, .external_lex_state = 46},
  [6418] = {.lex_state = 52, .external_lex_state = 38},
  [6419] = {.lex_state = 63, .external_lex_state = 31},
  [6420] = {.lex_state = 58, .external_lex_state = 44},
  [6421] = {.lex_state = 63, .external_lex_state = 28},
  [6422] = {.lex_state = 63, .external_lex_state = 31},
  [6423] = {.lex_state = 57, .external_lex_state = 44},
  [6424] = {.lex_state = 61, .external_lex_state = 47},
  [6425] = {.lex_state = 58, .external_lex_state = 40},
  [6426] = {.lex_state = 58, .external_lex_state = 38},
  [6427] = {.lex_state = 57, .external_lex_state = 50},
  [6428] = {.lex_state = 56, .external_lex_state = 52},
  [6429] = {.lex_state = 62, .external_lex_state = 40},
  [6430] = {.lex_state = 63, .external_lex_state = 28},
  [6431] = {.lex_state = 56, .external_lex_state = 30},
  [6432] = {.lex_state = 61, .external_lex_state = 31},
  [6433] = {.lex_state = 63, .external_lex_state = 31},
  [6434] = {.lex_state = 63},
  [6435] = {.lex_state = 58, .external_lex_state = 44},
  [6436] = {.lex_state = 61, .external_lex_state = 53},
  [6437] = {.lex_state = 57, .external_lex_state = 46},
  [6438] = {.lex_state = 55, .external_lex_state = 40},
  [6439] = {.lex_state = 55, .external_lex_state = 40},
  [6440] = {.lex_state = 52, .external_lex_state = 52},
  [6441] = {.lex_state = 61, .external_lex_state = 47},
  [6442] = {.lex_state = 63, .external_lex_state = 31},
  [6443] = {.lex_state = 55, .external_lex_state = 53},
  [6444] = {.lex_state = 57, .external_lex_state = 50},
  [6445] = {.lex_state = 58, .external_lex_state = 38},
  [6446] = {.lex_state = 55, .external_lex_state = 53},
  [6447] = {.lex_state = 52, .external_lex_state = 52},
  [6448] = {.lex_state = 63, .external_lex_state = 54},
  [6449] = {.lex_state = 57, .external_lex_state = 46},
  [6450] = {.lex_state = 63, .external_lex_state = 35},
  [6451] = {.lex_state = 56, .external_lex_state = 29},
  [6452] = {.lex_state = 57},
  [6453] = {.lex_state = 52, .external_lex_state = 23},
  [6454] = {.lex_state = 63, .external_lex_state = 35},
  [6455] = {.lex_state = 57, .external_lex_state = 50},
  [6456] = {.lex_state = 63, .external_lex_state = 31},
  [6457] = {.lex_state = 64, .external_lex_state = 53},
  [6458] = {.lex_state = 63, .external_lex_state = 31},
  [6459] = {.lex_state = 56, .external_lex_state = 26},
  [6460] = {.lex_state = 63, .external_lex_state = 31},
  [6461] = {.lex_state = 55, .external_lex_state = 53},
  [6462] = {.lex_state = 52, .external_lex_state = 54},
  [6463] = {.lex_state = 63, .external_lex_state = 31},
  [6464] = {.lex_state = 63, .external_lex_state = 36},
  [6465] = {.lex_state = 61, .external_lex_state = 41},
  [6466] = {.lex_state = 58, .external_lex_state = 46},
  [6467] = {.lex_state = 55, .external_lex_state = 53},
  [6468] = {.lex_state = 57, .external_lex_state = 50},
  [6469] = {.lex_state = 57, .external_lex_state = 47},
  [6470] = {.lex_state = 57, .external_lex_state = 44},
  [6471] = {.lex_state = 52, .external_lex_state = 33},
  [6472] = {.lex_state = 55, .external_lex_state = 40},
  [6473] = {.lex_state = 63, .external_lex_state = 35},
  [6474] = {.lex_state = 57, .external_lex_state = 46},
  [6475] = {.lex_state = 62, .external_lex_state = 40},
  [6476] = {.lex_state = 52, .external_lex_state = 41},
  [6477] = {.lex_state = 58, .external_lex_state = 46},
  [6478] = {.lex_state = 55, .external_lex_state = 40},
  [6479] = {.lex_state = 58, .external_lex_state = 50},
  [6480] = {.lex_state = 58, .external_lex_state = 55},
  [6481] = {.lex_state = 56, .external_lex_state = 43},
  [6482] = {.lex_state = 55, .external_lex_state = 40},
  [6483] = {.lex_state = 52, .external_lex_state = 54},
  [6484] = {.lex_state = 55, .external_lex_state = 40},
  [6485] = {.lex_state = 57, .external_lex_state = 44},
  [6486] = {.lex_state = 58, .external_lex_state = 41},
  [6487] = {.lex_state = 55, .external_lex_state = 40},
  [6488] = {.lex_state = 56, .external_lex_state = 26},
  [6489] = {.lex_state = 61, .external_lex_state = 28},
  [6490] = {.lex_state = 63, .external_lex_state = 35},
  [6491] = {.lex_state = 55, .external_lex_state = 43},
  [6492] = {.lex_state = 52, .external_lex_state = 41},
  [6493] = {.lex_state = 61, .external_lex_state = 40},
  [6494] = {.lex_state = 55, .external_lex_state = 40},
  [6495] = {.lex_state = 58, .external_lex_state = 46},
  [6496] = {.lex_state = 58, .external_lex_state = 43},
  [6497] = {.lex_state = 55, .external_lex_state = 53},
  [6498] = {.lex_state = 63, .external_lex_state = 23},
  [6499] = {.lex_state = 63, .external_lex_state = 35},
  [6500] = {.lex_state = 58, .external_lex_state = 46},
  [6501] = {.lex_state = 55, .external_lex_state = 40},
  [6502] = {.lex_state = 63, .external_lex_state = 41},
  [6503] = {.lex_state = 58, .external_lex_state = 44},
  [6504] = {.lex_state = 63, .external_lex_state = 31},
  [6505] = {.lex_state = 63, .external_lex_state = 35},
  [6506] = {.lex_state = 52, .external_lex_state = 41},
  [6507] = {.lex_state = 58, .external_lex_state = 47},
  [6508] = {.lex_state = 58, .external_lex_state = 46},
  [6509] = {.lex_state = 57, .external_lex_state = 44},
  [6510] = {.lex_state = 17, .external_lex_state = 43},
  [6511] = {.lex_state = 63, .external_lex_state = 52},
  [6512] = {.lex_state = 57, .external_lex_state = 44},
  [6513] = {.lex_state = 63, .external_lex_state = 37},
  [6514] = {.lex_state = 58, .external_lex_state = 46},
  [6515] = {.lex_state = 63, .external_lex_state = 31},
  [6516] = {.lex_state = 55, .external_lex_state = 40},
  [6517] = {.lex_state = 56, .external_lex_state = 53},
  [6518] = {.lex_state = 61, .external_lex_state = 54},
  [6519] = {.lex_state = 61, .external_lex_state = 50},
  [6520] = {.lex_state = 63, .external_lex_state = 31},
  [6521] = {.lex_state = 58, .external_lex_state = 46},
  [6522] = {.lex_state = 58, .external_lex_state = 46},
  [6523] = {.lex_state = 63, .external_lex_state = 31},
  [6524] = {.lex_state = 52, .external_lex_state = 42},
  [6525] = {.lex_state = 63, .external_lex_state = 40},
  [6526] = {.lex_state = 52, .external_lex_state = 53},
  [6527] = {.lex_state = 63, .external_lex_state = 35},
  [6528] = {.lex_state = 63, .external_lex_state = 36},
  [6529] = {.lex_state = 63, .external_lex_state = 41},
  [6530] = {.lex_state = 63, .external_lex_state = 26},
  [6531] = {.lex_state = 63, .external_lex_state = 31},
  [6532] = {.lex_state = 52, .external_lex_state = 56},
  [6533] = {.lex_state = 63, .external_lex_state = 31},
  [6534] = {.lex_state = 63, .external_lex_state = 31},
  [6535] = {.lex_state = 52, .external_lex_state = 53},
  [6536] = {.lex_state = 59, .external_lex_state = 40},
  [6537] = {.lex_state = 52, .external_lex_state = 27},
  [6538] = {.lex_state = 58, .external_lex_state = 53},
  [6539] = {.lex_state = 63, .external_lex_state = 31},
  [6540] = {.lex_state = 61, .external_lex_state = 32},
  [6541] = {.lex_state = 63, .external_lex_state = 35},
  [6542] = {.lex_state = 58, .external_lex_state = 47},
  [6543] = {.lex_state = 63, .external_lex_state = 35},
  [6544] = {.lex_state = 63, .external_lex_state = 31},
  [6545] = {.lex_state = 63, .external_lex_state = 41},
  [6546] = {.lex_state = 57, .external_lex_state = 44},
  [6547] = {.lex_state = 63, .external_lex_state = 24},
  [6548] = {.lex_state = 55, .external_lex_state = 40},
  [6549] = {.lex_state = 63, .external_lex_state = 38},
  [6550] = {.lex_state = 58, .external_lex_state = 50},
  [6551] = {.lex_state = 57, .external_lex_state = 44},
  [6552] = {.lex_state = 61, .external_lex_state = 52},
  [6553] = {.lex_state = 52, .external_lex_state = 38},
  [6554] = {.lex_state = 63, .external_lex_state = 23},
  [6555] = {.lex_state = 57, .external_lex_state = 44},
  [6556] = {.lex_state = 58, .external_lex_state = 47},
  [6557] = {.lex_state = 57, .external_lex_state = 46},
  [6558] = {.lex_state = 57, .external_lex_state = 44},
  [6559] = {.lex_state = 57, .external_lex_state = 32},
  [6560] = {.lex_state = 57, .external_lex_state = 44},
  [6561] = {.lex_state = 63, .external_lex_state = 35},
  [6562] = {.lex_state = 56, .external_lex_state = 54},
  [6563] = {.lex_state = 57, .external_lex_state = 44},
  [6564] = {.lex_state = 63, .external_lex_state = 35},
  [6565] = {.lex_state = 61, .external_lex_state = 47},
  [6566] = {.lex_state = 17, .external_lex_state = 43},
  [6567] = {.lex_state = 63, .external_lex_state = 38},
  [6568] = {.lex_state = 56, .external_lex_state = 26},
  [6569] = {.lex_state = 57, .external_lex_state = 44},
  [6570] = {.lex_state = 61, .external_lex_state = 32},
  [6571] = {.lex_state = 63, .external_lex_state = 31},
  [6572] = {.lex_state = 61, .external_lex_state = 34},
  [6573] = {.lex_state = 56, .external_lex_state = 54},
  [6574] = {.lex_state = 61, .external_lex_state = 41},
  [6575] = {.lex_state = 61, .external_lex_state = 32},
  [6576] = {.lex_state = 58, .external_lex_state = 26},
  [6577] = {.lex_state = 63, .external_lex_state = 27},
  [6578] = {.lex_state = 63, .external_lex_state = 38},
  [6579] = {.lex_state = 57, .external_lex_state = 50},
  [6580] = {.lex_state = 52, .external_lex_state = 46},
  [6581] = {.lex_state = 56, .external_lex_state = 54},
  [6582] = {.lex_state = 58, .external_lex_state = 47},
  [6583] = {.lex_state = 58, .external_lex_state = 52},
  [6584] = {.lex_state = 61, .external_lex_state = 43},
  [6585] = {.lex_state = 57, .external_lex_state = 46},
  [6586] = {.lex_state = 63, .external_lex_state = 31},
  [6587] = {.lex_state = 63, .external_lex_state = 23},
  [6588] = {.lex_state = 63, .external_lex_state = 26},
  [6589] = {.lex_state = 52, .external_lex_state = 55},
  [6590] = {.lex_state = 63, .external_lex_state = 40},
  [6591] = {.lex_state = 63, .external_lex_state = 32},
  [6592] = {.lex_state = 57, .external_lex_state = 46},
  [6593] = {.lex_state = 62, .external_lex_state = 40},
  [6594] = {.lex_state = 63, .external_lex_state = 54},
  [6595] = {.lex_state = 61, .external_lex_state = 44},
  [6596] = {.lex_state = 57, .external_lex_state = 47},
  [6597] = {.lex_state = 57, .external_lex_state = 46},
  [6598] = {.lex_state = 62, .external_lex_state = 40},
  [6599] = {.lex_state = 57, .external_lex_state = 46},
  [6600] = {.lex_state = 56, .external_lex_state = 26},
  [6601] = {.lex_state = 57, .external_lex_state = 46},
  [6602] = {.lex_state = 63, .external_lex_state = 31},
  [6603] = {.lex_state = 56, .external_lex_state = 26},
  [6604] = {.lex_state = 57, .external_lex_state = 46},
  [6605] = {.lex_state = 52, .external_lex_state = 38},
  [6606] = {.lex_state = 62, .external_lex_state = 43},
  [6607] = {.lex_state = 52, .external_lex_state = 38},
  [6608] = {.lex_state = 57, .external_lex_state = 50},
  [6609] = {.lex_state = 52, .external_lex_state = 55},
  [6610] = {.lex_state = 52, .external_lex_state = 29},
  [6611] = {.lex_state = 64, .external_lex_state = 40},
  [6612] = {.lex_state = 63, .external_lex_state = 52},
  [6613] = {.lex_state = 63, .external_lex_state = 31},
  [6614] = {.lex_state = 57, .external_lex_state = 44},
  [6615] = {.lex_state = 61, .external_lex_state = 34},
  [6616] = {.lex_state = 58, .external_lex_state = 50},
  [6617] = {.lex_state = 63, .external_lex_state = 31},
  [6618] = {.lex_state = 58, .external_lex_state = 50},
  [6619] = {.lex_state = 52, .external_lex_state = 56},
  [6620] = {.lex_state = 56, .external_lex_state = 55},
  [6621] = {.lex_state = 61, .external_lex_state = 40},
  [6622] = {.lex_state = 52, .external_lex_state = 42},
  [6623] = {.lex_state = 52, .external_lex_state = 57},
  [6624] = {.lex_state = 58, .external_lex_state = 44},
  [6625] = {.lex_state = 52, .external_lex_state = 47},
  [6626] = {.lex_state = 56, .external_lex_state = 26},
  [6627] = {.lex_state = 9, .external_lex_state = 43},
  [6628] = {.lex_state = 63, .external_lex_state = 31},
  [6629] = {.lex_state = 52, .external_lex_state = 23},
  [6630] = {.lex_state = 57, .external_lex_state = 34},
  [6631] = {.lex_state = 61, .external_lex_state = 44},
  [6632] = {.lex_state = 58, .external_lex_state = 47},
  [6633] = {.lex_state = 63, .external_lex_state = 41},
  [6634] = {.lex_state = 56, .external_lex_state = 50},
  [6635] = {.lex_state = 61, .external_lex_state = 33},
  [6636] = {.lex_state = 63, .external_lex_state = 32},
  [6637] = {.lex_state = 61, .external_lex_state = 50},
  [6638] = {.lex_state = 63, .external_lex_state = 40},
  [6639] = {.lex_state = 56, .external_lex_state = 40},
  [6640] = {.lex_state = 63, .external_lex_state = 31},
  [6641] = {.lex_state = 63, .external_lex_state = 31},
  [6642] = {.lex_state = 63, .external_lex_state = 31},
  [6643] = {.lex_state = 61, .external_lex_state = 44},
  [6644] = {.lex_state = 61, .external_lex_state = 34},
  [6645] = {.lex_state = 52, .external_lex_state = 30},
  [6646] = {.lex_state = 63},
  [6647] = {.lex_state = 63, .external_lex_state = 31},
  [6648] = {.lex_state = 63, .external_lex_state = 31},
  [6649] = {.lex_state = 63, .external_lex_state = 31},
  [6650] = {.lex_state = 63, .external_lex_state = 31},
  [6651] = {.lex_state = 63, .external_lex_state = 31},
  [6652] = {.lex_state = 63, .external_lex_state = 23},
  [6653] = {.lex_state = 58, .external_lex_state = 47},
  [6654] = {.lex_state = 57, .external_lex_state = 46},
  [6655] = {.lex_state = 52, .external_lex_state = 29},
  [6656] = {.lex_state = 56, .external_lex_state = 54},
  [6657] = {.lex_state = 52, .external_lex_state = 30},
  [6658] = {.lex_state = 56, .external_lex_state = 29},
  [6659] = {.lex_state = 52, .external_lex_state = 40},
  [6660] = {.lex_state = 55, .external_lex_state = 43},
  [6661] = {.lex_state = 57, .external_lex_state = 54},
  [6662] = {.lex_state = 52, .external_lex_state = 52},
  [6663] = {.lex_state = 52, .external_lex_state = 46},
  [6664] = {.lex_state = 51},
  [6665] = {.lex_state = 51},
  [6666] = {.lex_state = 52, .external_lex_state = 44},
  [6667] = {.lex_state = 52, .external_lex_state = 40},
  [6668] = {.lex_state = 63, .external_lex_state = 36},
  [6669] = {.lex_state = 51},
  [6670] = {.lex_state = 18},
  [6671] = {.lex_state = 51},
  [6672] = {.lex_state = 52, .external_lex_state = 44},
  [6673] = {.lex_state = 52, .external_lex_state = 44},
  [6674] = {.lex_state = 18},
  [6675] = {.lex_state = 63, .external_lex_state = 35},
  [6676] = {.lex_state = 63, .external_lex_state = 50},
  [6677] = {.lex_state = 62, .external_lex_state = 53},
  [6678] = {.lex_state = 63, .external_lex_state = 35},
  [6679] = {.lex_state = 59, .external_lex_state = 40},
  [6680] = {.lex_state = 52, .external_lex_state = 31},
  [6681] = {.lex_state = 55, .external_lex_state = 43},
  [6682] = {.lex_state = 63, .external_lex_state = 24},
  [6683] = {.lex_state = 63, .external_lex_state = 35},
  [6684] = {.lex_state = 63, .external_lex_state = 30},
  [6685] = {.lex_state = 61, .external_lex_state = 54},
  [6686] = {.lex_state = 52, .external_lex_state = 56},
  [6687] = {.lex_state = 63, .external_lex_state = 39},
  [6688] = {.lex_state = 52, .external_lex_state = 28},
  [6689] = {.lex_state = 63, .external_lex_state = 30},
  [6690] = {.lex_state = 61, .external_lex_state = 54},
  [6691] = {.lex_state = 52, .external_lex_state = 23},
  [6692] = {.lex_state = 63, .external_lex_state = 35},
  [6693] = {.lex_state = 52, .external_lex_state = 51},
  [6694] = {.lex_state = 51},
  [6695] = {.lex_state = 51},
  [6696] = {.lex_state = 61, .external_lex_state = 54},
  [6697] = {.lex_state = 7, .external_lex_state = 43},
  [6698] = {.lex_state = 61, .external_lex_state = 46},
  [6699] = {.lex_state = 57, .external_lex_state = 26},
  [6700] = {.lex_state = 52, .external_lex_state = 41},
  [6701] = {.lex_state = 63, .external_lex_state = 35},
  [6702] = {.lex_state = 18},
  [6703] = {.lex_state = 7, .external_lex_state = 43},
  [6704] = {.lex_state = 63, .external_lex_state = 35},
  [6705] = {.lex_state = 63, .external_lex_state = 23},
  [6706] = {.lex_state = 63, .external_lex_state = 35},
  [6707] = {.lex_state = 59, .external_lex_state = 40},
  [6708] = {.lex_state = 18},
  [6709] = {.lex_state = 63, .external_lex_state = 35},
  [6710] = {.lex_state = 63, .external_lex_state = 35},
  [6711] = {.lex_state = 52, .external_lex_state = 40},
  [6712] = {.lex_state = 56, .external_lex_state = 52},
  [6713] = {.lex_state = 57, .external_lex_state = 40},
  [6714] = {.lex_state = 61, .external_lex_state = 40},
  [6715] = {.lex_state = 55, .external_lex_state = 43},
  [6716] = {.lex_state = 51},
  [6717] = {.lex_state = 51},
  [6718] = {.lex_state = 63, .external_lex_state = 35},
  [6719] = {.lex_state = 18},
  [6720] = {.lex_state = 63, .external_lex_state = 35},
  [6721] = {.lex_state = 59, .external_lex_state = 40},
  [6722] = {.lex_state = 18},
  [6723] = {.lex_state = 63, .external_lex_state = 35},
  [6724] = {.lex_state = 63, .external_lex_state = 35},
  [6725] = {.lex_state = 56, .external_lex_state = 34},
  [6726] = {.lex_state = 55, .external_lex_state = 43},
  [6727] = {.lex_state = 56, .external_lex_state = 32},
  [6728] = {.lex_state = 55, .external_lex_state = 43},
  [6729] = {.lex_state = 52, .external_lex_state = 52},
  [6730] = {.lex_state = 63, .external_lex_state = 35},
  [6731] = {.lex_state = 63, .external_lex_state = 35},
  [6732] = {.lex_state = 18},
  [6733] = {.lex_state = 55, .external_lex_state = 43},
  [6734] = {.lex_state = 64, .external_lex_state = 40},
  [6735] = {.lex_state = 18},
  [6736] = {.lex_state = 56, .external_lex_state = 52},
  [6737] = {.lex_state = 63, .external_lex_state = 35},
  [6738] = {.lex_state = 7, .external_lex_state = 43},
  [6739] = {.lex_state = 63, .external_lex_state = 35},
  [6740] = {.lex_state = 55, .external_lex_state = 43},
  [6741] = {.lex_state = 61, .external_lex_state = 55},
  [6742] = {.lex_state = 58, .external_lex_state = 54},
  [6743] = {.lex_state = 52, .external_lex_state = 38},
  [6744] = {.lex_state = 63, .external_lex_state = 31},
  [6745] = {.lex_state = 63},
  [6746] = {.lex_state = 61, .external_lex_state = 55},
  [6747] = {.lex_state = 52, .external_lex_state = 48},
  [6748] = {.lex_state = 63, .external_lex_state = 29},
  [6749] = {.lex_state = 64, .external_lex_state = 40},
  [6750] = {.lex_state = 58, .external_lex_state = 40},
  [6751] = {.lex_state = 61, .external_lex_state = 55},
  [6752] = {.lex_state = 63, .external_lex_state = 43},
  [6753] = {.lex_state = 59, .external_lex_state = 40},
  [6754] = {.lex_state = 63, .external_lex_state = 43},
  [6755] = {.lex_state = 61, .external_lex_state = 50},
  [6756] = {.lex_state = 51},
  [6757] = {.lex_state = 52, .external_lex_state = 53},
  [6758] = {.lex_state = 61, .external_lex_state = 27},
  [6759] = {.lex_state = 56, .external_lex_state = 34},
  [6760] = {.lex_state = 61, .external_lex_state = 27},
  [6761] = {.lex_state = 61, .external_lex_state = 27},
  [6762] = {.lex_state = 55, .external_lex_state = 43},
  [6763] = {.lex_state = 52, .external_lex_state = 49},
  [6764] = {.lex_state = 58, .external_lex_state = 54},
  [6765] = {.lex_state = 58, .external_lex_state = 54},
  [6766] = {.lex_state = 58, .external_lex_state = 54},
  [6767] = {.lex_state = 63, .external_lex_state = 35},
  [6768] = {.lex_state = 17, .external_lex_state = 43},
  [6769] = {.lex_state = 63, .external_lex_state = 35},
  [6770] = {.lex_state = 63, .external_lex_state = 24},
  [6771] = {.lex_state = 52, .external_lex_state = 46},
  [6772] = {.lex_state = 58, .external_lex_state = 54},
  [6773] = {.lex_state = 17, .external_lex_state = 43},
  [6774] = {.lex_state = 58, .external_lex_state = 54},
  [6775] = {.lex_state = 52, .external_lex_state = 46},
  [6776] = {.lex_state = 58, .external_lex_state = 54},
  [6777] = {.lex_state = 52, .external_lex_state = 46},
  [6778] = {.lex_state = 58, .external_lex_state = 54},
  [6779] = {.lex_state = 52},
  [6780] = {.lex_state = 61, .external_lex_state = 40},
  [6781] = {.lex_state = 52, .external_lex_state = 38},
  [6782] = {.lex_state = 63, .external_lex_state = 35},
  [6783] = {.lex_state = 63, .external_lex_state = 30},
  [6784] = {.lex_state = 63, .external_lex_state = 37},
  [6785] = {.lex_state = 63, .external_lex_state = 27},
  [6786] = {.lex_state = 58, .external_lex_state = 26},
  [6787] = {.lex_state = 58, .external_lex_state = 55},
  [6788] = {.lex_state = 63, .external_lex_state = 35},
  [6789] = {.lex_state = 63, .external_lex_state = 35},
  [6790] = {.lex_state = 63, .external_lex_state = 37},
  [6791] = {.lex_state = 63, .external_lex_state = 35},
  [6792] = {.lex_state = 56, .external_lex_state = 29},
  [6793] = {.lex_state = 63, .external_lex_state = 29},
  [6794] = {.lex_state = 56, .external_lex_state = 26},
  [6795] = {.lex_state = 63, .external_lex_state = 35},
  [6796] = {.lex_state = 61, .external_lex_state = 50},
  [6797] = {.lex_state = 61, .external_lex_state = 40},
  [6798] = {.lex_state = 58, .external_lex_state = 29},
  [6799] = {.lex_state = 63, .external_lex_state = 37},
  [6800] = {.lex_state = 63, .external_lex_state = 29},
  [6801] = {.lex_state = 63, .external_lex_state = 35},
  [6802] = {.lex_state = 63, .external_lex_state = 35},
  [6803] = {.lex_state = 63, .external_lex_state = 37},
  [6804] = {.lex_state = 63, .external_lex_state = 35},
  [6805] = {.lex_state = 61, .external_lex_state = 34},
  [6806] = {.lex_state = 63, .external_lex_state = 23},
  [6807] = {.lex_state = 52, .external_lex_state = 45},
  [6808] = {.lex_state = 63, .external_lex_state = 35},
  [6809] = {.lex_state = 63, .external_lex_state = 35},
  [6810] = {.lex_state = 63, .external_lex_state = 36},
  [6811] = {.lex_state = 63, .external_lex_state = 37},
  [6812] = {.lex_state = 63, .external_lex_state = 37},
  [6813] = {.lex_state = 63, .external_lex_state = 36},
  [6814] = {.lex_state = 57, .external_lex_state = 26},
  [6815] = {.lex_state = 63, .external_lex_state = 40},
  [6816] = {.lex_state = 63, .external_lex_state = 36},
  [6817] = {.lex_state = 57, .external_lex_state = 52},
  [6818] = {.lex_state = 57, .external_lex_state = 54},
  [6819] = {.lex_state = 58, .external_lex_state = 55},
  [6820] = {.lex_state = 7, .external_lex_state = 43},
  [6821] = {.lex_state = 52, .external_lex_state = 45},
  [6822] = {.lex_state = 52, .external_lex_state = 26},
  [6823] = {.lex_state = 58, .external_lex_state = 55},
  [6824] = {.lex_state = 63, .external_lex_state = 24},
  [6825] = {.lex_state = 58, .external_lex_state = 55},
  [6826] = {.lex_state = 63, .external_lex_state = 46},
  [6827] = {.lex_state = 58, .external_lex_state = 55},
  [6828] = {.lex_state = 63, .external_lex_state = 29},
  [6829] = {.lex_state = 63, .external_lex_state = 27},
  [6830] = {.lex_state = 58, .external_lex_state = 55},
  [6831] = {.lex_state = 58, .external_lex_state = 29},
  [6832] = {.lex_state = 58, .external_lex_state = 55},
  [6833] = {.lex_state = 58, .external_lex_state = 55},
  [6834] = {.lex_state = 58, .external_lex_state = 29},
  [6835] = {.lex_state = 62, .external_lex_state = 43},
  [6836] = {.lex_state = 63, .external_lex_state = 35},
  [6837] = {.lex_state = 61, .external_lex_state = 34},
  [6838] = {.lex_state = 56, .external_lex_state = 30},
  [6839] = {.lex_state = 61, .external_lex_state = 44},
  [6840] = {.lex_state = 62, .external_lex_state = 43},
  [6841] = {.lex_state = 63, .external_lex_state = 35},
  [6842] = {.lex_state = 55, .external_lex_state = 40},
  [6843] = {.lex_state = 63, .external_lex_state = 35},
  [6844] = {.lex_state = 55, .external_lex_state = 40},
  [6845] = {.lex_state = 56, .external_lex_state = 34},
  [6846] = {.lex_state = 62, .external_lex_state = 53},
  [6847] = {.lex_state = 63, .external_lex_state = 36},
  [6848] = {.lex_state = 54},
  [6849] = {.lex_state = 52, .external_lex_state = 53},
  [6850] = {.lex_state = 56, .external_lex_state = 53},
  [6851] = {.lex_state = 64, .external_lex_state = 53},
  [6852] = {.lex_state = 63, .external_lex_state = 37},
  [6853] = {.lex_state = 56, .external_lex_state = 32},
  [6854] = {.lex_state = 63, .external_lex_state = 44},
  [6855] = {.lex_state = 64, .external_lex_state = 53},
  [6856] = {.lex_state = 57, .external_lex_state = 55},
  [6857] = {.lex_state = 56, .external_lex_state = 30},
  [6858] = {.lex_state = 7, .external_lex_state = 43},
  [6859] = {.lex_state = 56, .external_lex_state = 30},
  [6860] = {.lex_state = 56, .external_lex_state = 30},
  [6861] = {.lex_state = 63, .external_lex_state = 44},
  [6862] = {.lex_state = 59, .external_lex_state = 40},
  [6863] = {.lex_state = 56, .external_lex_state = 30},
  [6864] = {.lex_state = 56, .external_lex_state = 30},
  [6865] = {.lex_state = 63, .external_lex_state = 47},
  [6866] = {.lex_state = 52, .external_lex_state = 28},
  [6867] = {.lex_state = 56, .external_lex_state = 30},
  [6868] = {.lex_state = 7, .external_lex_state = 43},
  [6869] = {.lex_state = 52, .external_lex_state = 40},
  [6870] = {.lex_state = 7, .external_lex_state = 43},
  [6871] = {.lex_state = 56, .external_lex_state = 30},
  [6872] = {.lex_state = 7, .external_lex_state = 43},
  [6873] = {.lex_state = 7, .external_lex_state = 43},
  [6874] = {.lex_state = 63, .external_lex_state = 36},
  [6875] = {.lex_state = 7, .external_lex_state = 43},
  [6876] = {.lex_state = 63, .external_lex_state = 44},
  [6877] = {.lex_state = 63, .external_lex_state = 36},
  [6878] = {.lex_state = 63, .external_lex_state = 35},
  [6879] = {.lex_state = 63, .external_lex_state = 30},
  [6880] = {.lex_state = 63, .external_lex_state = 35},
  [6881] = {.lex_state = 63, .external_lex_state = 35},
  [6882] = {.lex_state = 63, .external_lex_state = 36},
  [6883] = {.lex_state = 55, .external_lex_state = 40},
  [6884] = {.lex_state = 63, .external_lex_state = 36},
  [6885] = {.lex_state = 63, .external_lex_state = 36},
  [6886] = {.lex_state = 63, .external_lex_state = 36},
  [6887] = {.lex_state = 63, .external_lex_state = 36},
  [6888] = {.lex_state = 63, .external_lex_state = 36},
  [6889] = {.lex_state = 63, .external_lex_state = 35},
  [6890] = {.lex_state = 52, .external_lex_state = 40},
  [6891] = {.lex_state = 58, .external_lex_state = 54},
  [6892] = {.lex_state = 51},
  [6893] = {.lex_state = 63, .external_lex_state = 36},
  [6894] = {.lex_state = 63, .external_lex_state = 36},
  [6895] = {.lex_state = 63, .external_lex_state = 36},
  [6896] = {.lex_state = 63, .external_lex_state = 36},
  [6897] = {.lex_state = 57, .external_lex_state = 55},
  [6898] = {.lex_state = 63, .external_lex_state = 35},
  [6899] = {.lex_state = 57, .external_lex_state = 55},
  [6900] = {.lex_state = 63, .external_lex_state = 35},
  [6901] = {.lex_state = 51},
  [6902] = {.lex_state = 63, .external_lex_state = 36},
  [6903] = {.lex_state = 63, .external_lex_state = 36},
  [6904] = {.lex_state = 63, .external_lex_state = 35},
  [6905] = {.lex_state = 63, .external_lex_state = 35},
  [6906] = {.lex_state = 63, .external_lex_state = 36},
  [6907] = {.lex_state = 63, .external_lex_state = 36},
  [6908] = {.lex_state = 63, .external_lex_state = 35},
  [6909] = {.lex_state = 51},
  [6910] = {.lex_state = 63, .external_lex_state = 37},
  [6911] = {.lex_state = 63, .external_lex_state = 23},
  [6912] = {.lex_state = 63, .external_lex_state = 27},
  [6913] = {.lex_state = 63, .external_lex_state = 37},
  [6914] = {.lex_state = 58, .external_lex_state = 32},
  [6915] = {.lex_state = 63, .external_lex_state = 37},
  [6916] = {.lex_state = 57, .external_lex_state = 55},
  [6917] = {.lex_state = 63, .external_lex_state = 37},
  [6918] = {.lex_state = 63, .external_lex_state = 37},
  [6919] = {.lex_state = 63, .external_lex_state = 37},
  [6920] = {.lex_state = 63, .external_lex_state = 37},
  [6921] = {.lex_state = 63, .external_lex_state = 37},
  [6922] = {.lex_state = 63, .external_lex_state = 37},
  [6923] = {.lex_state = 56, .external_lex_state = 53},
  [6924] = {.lex_state = 57, .external_lex_state = 55},
  [6925] = {.lex_state = 52, .external_lex_state = 34},
  [6926] = {.lex_state = 63, .external_lex_state = 37},
  [6927] = {.lex_state = 63, .external_lex_state = 37},
  [6928] = {.lex_state = 63, .external_lex_state = 37},
  [6929] = {.lex_state = 56, .external_lex_state = 54},
  [6930] = {.lex_state = 57, .external_lex_state = 55},
  [6931] = {.lex_state = 61, .external_lex_state = 27},
  [6932] = {.lex_state = 63, .external_lex_state = 37},
  [6933] = {.lex_state = 63, .external_lex_state = 37},
  [6934] = {.lex_state = 55, .external_lex_state = 43},
  [6935] = {.lex_state = 63, .external_lex_state = 37},
  [6936] = {.lex_state = 55, .external_lex_state = 43},
  [6937] = {.lex_state = 63, .external_lex_state = 37},
  [6938] = {.lex_state = 56, .external_lex_state = 34},
  [6939] = {.lex_state = 55, .external_lex_state = 43},
  [6940] = {.lex_state = 7, .external_lex_state = 43},
  [6941] = {.lex_state = 51},
  [6942] = {.lex_state = 52, .external_lex_state = 26},
  [6943] = {.lex_state = 61, .external_lex_state = 27},
  [6944] = {.lex_state = 57, .external_lex_state = 55},
  [6945] = {.lex_state = 63, .external_lex_state = 56},
  [6946] = {.lex_state = 61, .external_lex_state = 52},
  [6947] = {.lex_state = 57, .external_lex_state = 54},
  [6948] = {.lex_state = 58, .external_lex_state = 55},
  [6949] = {.lex_state = 61, .external_lex_state = 26},
  [6950] = {.lex_state = 63, .external_lex_state = 53},
  [6951] = {.lex_state = 52, .external_lex_state = 47},
  [6952] = {.lex_state = 61, .external_lex_state = 27},
  [6953] = {.lex_state = 63, .external_lex_state = 36},
  [6954] = {.lex_state = 57, .external_lex_state = 55},
  [6955] = {.lex_state = 56, .external_lex_state = 55},
  [6956] = {.lex_state = 57, .external_lex_state = 54},
  [6957] = {.lex_state = 52, .external_lex_state = 47},
  [6958] = {.lex_state = 51},
  [6959] = {.lex_state = 58, .external_lex_state = 30},
  [6960] = {.lex_state = 18},
  [6961] = {.lex_state = 63, .external_lex_state = 47},
  [6962] = {.lex_state = 61, .external_lex_state = 27},
  [6963] = {.lex_state = 57, .external_lex_state = 54},
  [6964] = {.lex_state = 52, .external_lex_state = 47},
  [6965] = {.lex_state = 61, .external_lex_state = 27},
  [6966] = {.lex_state = 63, .external_lex_state = 57},
  [6967] = {.lex_state = 57, .external_lex_state = 54},
  [6968] = {.lex_state = 63, .external_lex_state = 36},
  [6969] = {.lex_state = 63, .external_lex_state = 36},
  [6970] = {.lex_state = 9, .external_lex_state = 43},
  [6971] = {.lex_state = 52, .external_lex_state = 34},
  [6972] = {.lex_state = 52, .external_lex_state = 40},
  [6973] = {.lex_state = 63, .external_lex_state = 37},
  [6974] = {.lex_state = 57, .external_lex_state = 52},
  [6975] = {.lex_state = 52, .external_lex_state = 32},
  [6976] = {.lex_state = 63, .external_lex_state = 36},
  [6977] = {.lex_state = 57, .external_lex_state = 52},
  [6978] = {.lex_state = 52, .external_lex_state = 32},
  [6979] = {.lex_state = 63, .external_lex_state = 36},
  [6980] = {.lex_state = 63, .external_lex_state = 36},
  [6981] = {.lex_state = 57, .external_lex_state = 52},
  [6982] = {.lex_state = 55, .external_lex_state = 43},
  [6983] = {.lex_state = 63, .external_lex_state = 56},
  [6984] = {.lex_state = 57, .external_lex_state = 55},
  [6985] = {.lex_state = 63, .external_lex_state = 36},
  [6986] = {.lex_state = 56, .external_lex_state = 30},
  [6987] = {.lex_state = 58, .external_lex_state = 52},
  [6988] = {.lex_state = 52, .external_lex_state = 32},
  [6989] = {.lex_state = 61, .external_lex_state = 27},
  [6990] = {.lex_state = 61, .external_lex_state = 27},
  [6991] = {.lex_state = 63, .external_lex_state = 37},
  [6992] = {.lex_state = 63, .external_lex_state = 37},
  [6993] = {.lex_state = 63, .external_lex_state = 36},
  [6994] = {.lex_state = 64, .external_lex_state = 40},
  [6995] = {.lex_state = 61, .external_lex_state = 29},
  [6996] = {.lex_state = 61, .external_lex_state = 43},
  [6997] = {.lex_state = 63, .external_lex_state = 23},
  [6998] = {.lex_state = 56, .external_lex_state = 52},
  [6999] = {.lex_state = 63, .external_lex_state = 37},
  [7000] = {.lex_state = 57, .external_lex_state = 52},
  [7001] = {.lex_state = 63, .external_lex_state = 37},
  [7002] = {.lex_state = 63, .external_lex_state = 37},
  [7003] = {.lex_state = 52, .external_lex_state = 24},
  [7004] = {.lex_state = 61, .external_lex_state = 52},
  [7005] = {.lex_state = 57, .external_lex_state = 54},
  [7006] = {.lex_state = 52, .external_lex_state = 27},
  [7007] = {.lex_state = 61, .external_lex_state = 52},
  [7008] = {.lex_state = 61, .external_lex_state = 52},
  [7009] = {.lex_state = 63, .external_lex_state = 36},
  [7010] = {.lex_state = 63, .external_lex_state = 36},
  [7011] = {.lex_state = 63, .external_lex_state = 58},
  [7012] = {.lex_state = 63, .external_lex_state = 36},
  [7013] = {.lex_state = 63, .external_lex_state = 53},
  [7014] = {.lex_state = 58, .external_lex_state = 52},
  [7015] = {.lex_state = 63, .external_lex_state = 38},
  [7016] = {.lex_state = 56, .external_lex_state = 30},
  [7017] = {.lex_state = 58, .external_lex_state = 52},
  [7018] = {.lex_state = 63, .external_lex_state = 36},
  [7019] = {.lex_state = 63, .external_lex_state = 35},
  [7020] = {.lex_state = 58, .external_lex_state = 52},
  [7021] = {.lex_state = 63, .external_lex_state = 46},
  [7022] = {.lex_state = 61, .external_lex_state = 35},
  [7023] = {.lex_state = 63, .external_lex_state = 36},
  [7024] = {.lex_state = 63, .external_lex_state = 35},
  [7025] = {.lex_state = 63, .external_lex_state = 40},
  [7026] = {.lex_state = 63, .external_lex_state = 35},
  [7027] = {.lex_state = 58, .external_lex_state = 52},
  [7028] = {.lex_state = 63, .external_lex_state = 23},
  [7029] = {.lex_state = 58, .external_lex_state = 52},
  [7030] = {.lex_state = 63, .external_lex_state = 37},
  [7031] = {.lex_state = 59, .external_lex_state = 40},
  [7032] = {.lex_state = 58, .external_lex_state = 52},
  [7033] = {.lex_state = 63, .external_lex_state = 28},
  [7034] = {.lex_state = 58, .external_lex_state = 52},
  [7035] = {.lex_state = 63, .external_lex_state = 35},
  [7036] = {.lex_state = 63, .external_lex_state = 35},
  [7037] = {.lex_state = 63, .external_lex_state = 37},
  [7038] = {.lex_state = 63, .external_lex_state = 50},
  [7039] = {.lex_state = 63, .external_lex_state = 47},
  [7040] = {.lex_state = 58, .external_lex_state = 53},
  [7041] = {.lex_state = 61, .external_lex_state = 27},
  [7042] = {.lex_state = 58, .external_lex_state = 26},
  [7043] = {.lex_state = 61, .external_lex_state = 32},
  [7044] = {.lex_state = 58, .external_lex_state = 26},
  [7045] = {.lex_state = 63, .external_lex_state = 35},
  [7046] = {.lex_state = 58, .external_lex_state = 26},
  [7047] = {.lex_state = 63, .external_lex_state = 36},
  [7048] = {.lex_state = 58, .external_lex_state = 53},
  [7049] = {.lex_state = 52, .external_lex_state = 31},
  [7050] = {.lex_state = 52, .external_lex_state = 48},
  [7051] = {.lex_state = 58, .external_lex_state = 26},
  [7052] = {.lex_state = 63, .external_lex_state = 38},
  [7053] = {.lex_state = 56, .external_lex_state = 53},
  [7054] = {.lex_state = 63, .external_lex_state = 46},
  [7055] = {.lex_state = 61, .external_lex_state = 32},
  [7056] = {.lex_state = 61, .external_lex_state = 29},
  [7057] = {.lex_state = 63, .external_lex_state = 37},
  [7058] = {.lex_state = 63, .external_lex_state = 28},
  [7059] = {.lex_state = 63, .external_lex_state = 50},
  [7060] = {.lex_state = 57, .external_lex_state = 26},
  [7061] = {.lex_state = 56, .external_lex_state = 29},
  [7062] = {.lex_state = 58, .external_lex_state = 52},
  [7063] = {.lex_state = 52, .external_lex_state = 33},
  [7064] = {.lex_state = 56, .external_lex_state = 53},
  [7065] = {.lex_state = 63, .external_lex_state = 50},
  [7066] = {.lex_state = 63, .external_lex_state = 46},
  [7067] = {.lex_state = 63, .external_lex_state = 50},
  [7068] = {.lex_state = 57, .external_lex_state = 52},
  [7069] = {.lex_state = 57, .external_lex_state = 54},
  [7070] = {.lex_state = 54},
  [7071] = {.lex_state = 52, .external_lex_state = 32},
  [7072] = {.lex_state = 56, .external_lex_state = 53},
  [7073] = {.lex_state = 52, .external_lex_state = 30},
  [7074] = {.lex_state = 52, .external_lex_state = 37},
  [7075] = {.lex_state = 56, .external_lex_state = 43},
  [7076] = {.lex_state = 63, .external_lex_state = 39},
  [7077] = {.lex_state = 58, .external_lex_state = 30},
  [7078] = {.lex_state = 52, .external_lex_state = 30},
  [7079] = {.lex_state = 56, .external_lex_state = 29},
  [7080] = {.lex_state = 59, .external_lex_state = 53},
  [7081] = {.lex_state = 58, .external_lex_state = 53},
  [7082] = {.lex_state = 57, .external_lex_state = 52},
  [7083] = {.lex_state = 52, .external_lex_state = 33},
  [7084] = {.lex_state = 52, .external_lex_state = 53},
  [7085] = {.lex_state = 63, .external_lex_state = 37},
  [7086] = {.lex_state = 63, .external_lex_state = 43},
  [7087] = {.lex_state = 52, .external_lex_state = 34},
  [7088] = {.lex_state = 56, .external_lex_state = 29},
  [7089] = {.lex_state = 58, .external_lex_state = 53},
  [7090] = {.lex_state = 7, .external_lex_state = 43},
  [7091] = {.lex_state = 56, .external_lex_state = 29},
  [7092] = {.lex_state = 52, .external_lex_state = 40},
  [7093] = {.lex_state = 57, .external_lex_state = 54},
  [7094] = {.lex_state = 56, .external_lex_state = 29},
  [7095] = {.lex_state = 58, .external_lex_state = 53},
  [7096] = {.lex_state = 59, .external_lex_state = 53},
  [7097] = {.lex_state = 58, .external_lex_state = 47},
  [7098] = {.lex_state = 56, .external_lex_state = 29},
  [7099] = {.lex_state = 58, .external_lex_state = 53},
  [7100] = {.lex_state = 57, .external_lex_state = 26},
  [7101] = {.lex_state = 58, .external_lex_state = 47},
  [7102] = {.lex_state = 56, .external_lex_state = 29},
  [7103] = {.lex_state = 63, .external_lex_state = 36},
  [7104] = {.lex_state = 51},
  [7105] = {.lex_state = 63, .external_lex_state = 36},
  [7106] = {.lex_state = 63, .external_lex_state = 36},
  [7107] = {.lex_state = 63, .external_lex_state = 23},
  [7108] = {.lex_state = 52, .external_lex_state = 54},
  [7109] = {.lex_state = 58, .external_lex_state = 50},
  [7110] = {.lex_state = 58, .external_lex_state = 53},
  [7111] = {.lex_state = 52, .external_lex_state = 51},
  [7112] = {.lex_state = 57, .external_lex_state = 26},
  [7113] = {.lex_state = 58, .external_lex_state = 50},
  [7114] = {.lex_state = 58, .external_lex_state = 53},
  [7115] = {.lex_state = 57, .external_lex_state = 26},
  [7116] = {.lex_state = 56, .external_lex_state = 53},
  [7117] = {.lex_state = 57, .external_lex_state = 40},
  [7118] = {.lex_state = 61, .external_lex_state = 41},
  [7119] = {.lex_state = 57, .external_lex_state = 52},
  [7120] = {.lex_state = 63, .external_lex_state = 23},
  [7121] = {.lex_state = 57, .external_lex_state = 52},
  [7122] = {.lex_state = 57, .external_lex_state = 54},
  [7123] = {.lex_state = 59, .external_lex_state = 40},
  [7124] = {.lex_state = 52, .external_lex_state = 50},
  [7125] = {.lex_state = 57, .external_lex_state = 52},
  [7126] = {.lex_state = 59, .external_lex_state = 53},
  [7127] = {.lex_state = 52, .external_lex_state = 40},
  [7128] = {.lex_state = 58, .external_lex_state = 53},
  [7129] = {.lex_state = 56, .external_lex_state = 29},
  [7130] = {.lex_state = 57, .external_lex_state = 52},
  [7131] = {.lex_state = 63, .external_lex_state = 40},
  [7132] = {.lex_state = 61, .external_lex_state = 41},
  [7133] = {.lex_state = 57, .external_lex_state = 52},
  [7134] = {.lex_state = 63, .external_lex_state = 53},
  [7135] = {.lex_state = 63, .external_lex_state = 36},
  [7136] = {.lex_state = 55, .external_lex_state = 40},
  [7137] = {.lex_state = 63, .external_lex_state = 53},
  [7138] = {.lex_state = 57, .external_lex_state = 52},
  [7139] = {.lex_state = 63, .external_lex_state = 36},
  [7140] = {.lex_state = 63, .external_lex_state = 36},
  [7141] = {.lex_state = 52, .external_lex_state = 49},
  [7142] = {.lex_state = 52, .external_lex_state = 50},
  [7143] = {.lex_state = 57, .external_lex_state = 52},
  [7144] = {.lex_state = 58, .external_lex_state = 54},
  [7145] = {.lex_state = 52, .external_lex_state = 50},
  [7146] = {.lex_state = 63, .external_lex_state = 42},
  [7147] = {.lex_state = 55, .external_lex_state = 40},
  [7148] = {.lex_state = 58, .external_lex_state = 54},
  [7149] = {.lex_state = 52, .external_lex_state = 50},
  [7150] = {.lex_state = 58, .external_lex_state = 54},
  [7151] = {.lex_state = 52, .external_lex_state = 40},
  [7152] = {.lex_state = 55, .external_lex_state = 40},
  [7153] = {.lex_state = 55, .external_lex_state = 43},
  [7154] = {.lex_state = 55, .external_lex_state = 40},
  [7155] = {.lex_state = 55, .external_lex_state = 40},
  [7156] = {.lex_state = 58, .external_lex_state = 54},
  [7157] = {.lex_state = 55, .external_lex_state = 40},
  [7158] = {.lex_state = 55, .external_lex_state = 40},
  [7159] = {.lex_state = 57, .external_lex_state = 55},
  [7160] = {.lex_state = 59, .external_lex_state = 53},
  [7161] = {.lex_state = 52, .external_lex_state = 51},
  [7162] = {.lex_state = 62, .external_lex_state = 40},
  [7163] = {.lex_state = 63, .external_lex_state = 37},
  [7164] = {.lex_state = 61, .external_lex_state = 43},
  [7165] = {.lex_state = 58, .external_lex_state = 55},
  [7166] = {.lex_state = 63, .external_lex_state = 37},
  [7167] = {.lex_state = 55, .external_lex_state = 53},
  [7168] = {.lex_state = 61, .external_lex_state = 43},
  [7169] = {.lex_state = 58, .external_lex_state = 55},
  [7170] = {.lex_state = 61, .external_lex_state = 43},
  [7171] = {.lex_state = 63, .external_lex_state = 37},
  [7172] = {.lex_state = 55, .external_lex_state = 53},
  [7173] = {.lex_state = 58, .external_lex_state = 55},
  [7174] = {.lex_state = 57, .external_lex_state = 55},
  [7175] = {.lex_state = 58, .external_lex_state = 55},
  [7176] = {.lex_state = 55, .external_lex_state = 40},
  [7177] = {.lex_state = 4},
  [7178] = {.lex_state = 59, .external_lex_state = 53},
  [7179] = {.lex_state = 52, .external_lex_state = 55},
  [7180] = {.lex_state = 52, .external_lex_state = 45},
  [7181] = {.lex_state = 56, .external_lex_state = 30},
  [7182] = {.lex_state = 56, .external_lex_state = 30},
  [7183] = {.lex_state = 56, .external_lex_state = 30},
  [7184] = {.lex_state = 63, .external_lex_state = 44},
  [7185] = {.lex_state = 56, .external_lex_state = 26},
  [7186] = {.lex_state = 56, .external_lex_state = 26},
  [7187] = {.lex_state = 56, .external_lex_state = 30},
  [7188] = {.lex_state = 59, .external_lex_state = 53},
  [7189] = {.lex_state = 57, .external_lex_state = 55},
  [7190] = {.lex_state = 57, .external_lex_state = 55},
  [7191] = {.lex_state = 57, .external_lex_state = 55},
  [7192] = {.lex_state = 63, .external_lex_state = 23},
  [7193] = {.lex_state = 59, .external_lex_state = 53},
  [7194] = {.lex_state = 59, .external_lex_state = 40},
  [7195] = {.lex_state = 59, .external_lex_state = 40},
  [7196] = {.lex_state = 61, .external_lex_state = 47},
  [7197] = {.lex_state = 54},
  [7198] = {.lex_state = 52, .external_lex_state = 54},
  [7199] = {.lex_state = 59, .external_lex_state = 53},
  [7200] = {.lex_state = 58, .external_lex_state = 52},
  [7201] = {.lex_state = 58, .external_lex_state = 52},
  [7202] = {.lex_state = 58, .external_lex_state = 52},
  [7203] = {.lex_state = 56, .external_lex_state = 32},
  [7204] = {.lex_state = 58, .external_lex_state = 52},
  [7205] = {.lex_state = 56, .external_lex_state = 32},
  [7206] = {.lex_state = 52, .external_lex_state = 44},
  [7207] = {.lex_state = 62, .external_lex_state = 40},
  [7208] = {.lex_state = 57, .external_lex_state = 26},
  [7209] = {.lex_state = 61, .external_lex_state = 26},
  [7210] = {.lex_state = 58, .external_lex_state = 26},
  [7211] = {.lex_state = 61, .external_lex_state = 26},
  [7212] = {.lex_state = 61, .external_lex_state = 26},
  [7213] = {.lex_state = 57, .external_lex_state = 55},
  [7214] = {.lex_state = 63, .external_lex_state = 46},
  [7215] = {.lex_state = 56, .external_lex_state = 43},
  [7216] = {.lex_state = 52, .external_lex_state = 53},
  [7217] = {.lex_state = 59, .external_lex_state = 53},
  [7218] = {.lex_state = 57, .external_lex_state = 54},
  [7219] = {.lex_state = 61, .external_lex_state = 30},
  [7220] = {.lex_state = 63, .external_lex_state = 37},
  [7221] = {.lex_state = 52, .external_lex_state = 48},
  [7222] = {.lex_state = 61, .external_lex_state = 54},
  [7223] = {.lex_state = 63, .external_lex_state = 37},
  [7224] = {.lex_state = 63, .external_lex_state = 37},
  [7225] = {.lex_state = 63, .external_lex_state = 36},
  [7226] = {.lex_state = 63, .external_lex_state = 39},
  [7227] = {.lex_state = 59, .external_lex_state = 40},
  [7228] = {.lex_state = 57, .external_lex_state = 52},
  [7229] = {.lex_state = 63, .external_lex_state = 36},
  [7230] = {.lex_state = 59, .external_lex_state = 40},
  [7231] = {.lex_state = 63, .external_lex_state = 36},
  [7232] = {.lex_state = 59, .external_lex_state = 40},
  [7233] = {.lex_state = 7, .external_lex_state = 43},
  [7234] = {.lex_state = 59, .external_lex_state = 40},
  [7235] = {.lex_state = 57, .external_lex_state = 52},
  [7236] = {.lex_state = 63, .external_lex_state = 36},
  [7237] = {.lex_state = 59, .external_lex_state = 40},
  [7238] = {.lex_state = 57, .external_lex_state = 52},
  [7239] = {.lex_state = 61, .external_lex_state = 27},
  [7240] = {.lex_state = 63, .external_lex_state = 36},
  [7241] = {.lex_state = 59, .external_lex_state = 40},
  [7242] = {.lex_state = 55, .external_lex_state = 40},
  [7243] = {.lex_state = 59, .external_lex_state = 40},
  [7244] = {.lex_state = 61, .external_lex_state = 40},
  [7245] = {.lex_state = 56, .external_lex_state = 40},
  [7246] = {.lex_state = 52, .external_lex_state = 53},
  [7247] = {.lex_state = 58, .external_lex_state = 26},
  [7248] = {.lex_state = 18},
  [7249] = {.lex_state = 62, .external_lex_state = 40},
  [7250] = {.lex_state = 58, .external_lex_state = 26},
  [7251] = {.lex_state = 52, .external_lex_state = 55},
  [7252] = {.lex_state = 57, .external_lex_state = 55},
  [7253] = {.lex_state = 62, .external_lex_state = 40},
  [7254] = {.lex_state = 58, .external_lex_state = 26},
  [7255] = {.lex_state = 58, .external_lex_state = 26},
  [7256] = {.lex_state = 63, .external_lex_state = 44},
  [7257] = {.lex_state = 58, .external_lex_state = 26},
  [7258] = {.lex_state = 57, .external_lex_state = 26},
  [7259] = {.lex_state = 58, .external_lex_state = 53},
  [7260] = {.lex_state = 58, .external_lex_state = 26},
  [7261] = {.lex_state = 58, .external_lex_state = 53},
  [7262] = {.lex_state = 58, .external_lex_state = 26},
  [7263] = {.lex_state = 61, .external_lex_state = 27},
  [7264] = {.lex_state = 58, .external_lex_state = 53},
  [7265] = {.lex_state = 61, .external_lex_state = 53},
  [7266] = {.lex_state = 57, .external_lex_state = 54},
  [7267] = {.lex_state = 59, .external_lex_state = 40},
  [7268] = {.lex_state = 52, .external_lex_state = 34},
  [7269] = {.lex_state = 61, .external_lex_state = 36},
  [7270] = {.lex_state = 56, .external_lex_state = 29},
  [7271] = {.lex_state = 59, .external_lex_state = 53},
  [7272] = {.lex_state = 58, .external_lex_state = 30},
  [7273] = {.lex_state = 52, .external_lex_state = 49},
  [7274] = {.lex_state = 58, .external_lex_state = 30},
  [7275] = {.lex_state = 52, .external_lex_state = 42},
  [7276] = {.lex_state = 61, .external_lex_state = 47},
  [7277] = {.lex_state = 59, .external_lex_state = 53},
  [7278] = {.lex_state = 52, .external_lex_state = 29},
  [7279] = {.lex_state = 59, .external_lex_state = 53},
  [7280] = {.lex_state = 58, .external_lex_state = 53},
  [7281] = {.lex_state = 61, .external_lex_state = 38},
  [7282] = {.lex_state = 63, .external_lex_state = 35},
  [7283] = {.lex_state = 63, .external_lex_state = 47},
  [7284] = {.lex_state = 57, .external_lex_state = 54},
  [7285] = {.lex_state = 57, .external_lex_state = 54},
  [7286] = {.lex_state = 61, .external_lex_state = 30},
  [7287] = {.lex_state = 63, .external_lex_state = 47},
  [7288] = {.lex_state = 61, .external_lex_state = 44},
  [7289] = {.lex_state = 61, .external_lex_state = 37},
  [7290] = {.lex_state = 52, .external_lex_state = 43},
  [7291] = {.lex_state = 63, .external_lex_state = 47},
  [7292] = {.lex_state = 51},
  [7293] = {.lex_state = 51},
  [7294] = {.lex_state = 63, .external_lex_state = 46},
  [7295] = {.lex_state = 63, .external_lex_state = 35},
  [7296] = {.lex_state = 58, .external_lex_state = 29},
  [7297] = {.lex_state = 52, .external_lex_state = 34},
  [7298] = {.lex_state = 4},
  [7299] = {.lex_state = 61, .external_lex_state = 55},
  [7300] = {.lex_state = 63, .external_lex_state = 35},
  [7301] = {.lex_state = 51},
  [7302] = {.lex_state = 58, .external_lex_state = 44},
  [7303] = {.lex_state = 63, .external_lex_state = 41},
  [7304] = {.lex_state = 61, .external_lex_state = 38},
  [7305] = {.lex_state = 61, .external_lex_state = 40},
  [7306] = {.lex_state = 58, .external_lex_state = 44},
  [7307] = {.lex_state = 57, .external_lex_state = 54},
  [7308] = {.lex_state = 18},
  [7309] = {.lex_state = 51},
  [7310] = {.lex_state = 63, .external_lex_state = 43},
  [7311] = {.lex_state = 52, .external_lex_state = 29},
  [7312] = {.lex_state = 61, .external_lex_state = 53},
  [7313] = {.lex_state = 63, .external_lex_state = 37},
  [7314] = {.lex_state = 64, .external_lex_state = 40},
  [7315] = {.lex_state = 59, .external_lex_state = 53},
  [7316] = {.lex_state = 56, .external_lex_state = 53},
  [7317] = {.lex_state = 18},
  [7318] = {.lex_state = 64, .external_lex_state = 40},
  [7319] = {.lex_state = 56, .external_lex_state = 29},
  [7320] = {.lex_state = 56, .external_lex_state = 54},
  [7321] = {.lex_state = 56, .external_lex_state = 29},
  [7322] = {.lex_state = 56, .external_lex_state = 54},
  [7323] = {.lex_state = 63, .external_lex_state = 41},
  [7324] = {.lex_state = 63, .external_lex_state = 36},
  [7325] = {.lex_state = 56, .external_lex_state = 29},
  [7326] = {.lex_state = 63, .external_lex_state = 37},
  [7327] = {.lex_state = 57, .external_lex_state = 54},
  [7328] = {.lex_state = 63, .external_lex_state = 37},
  [7329] = {.lex_state = 52, .external_lex_state = 43},
  [7330] = {.lex_state = 63, .external_lex_state = 37},
  [7331] = {.lex_state = 63, .external_lex_state = 23},
  [7332] = {.lex_state = 57, .external_lex_state = 26},
  [7333] = {.lex_state = 63, .external_lex_state = 37},
  [7334] = {.lex_state = 63, .external_lex_state = 23},
  [7335] = {.lex_state = 63, .external_lex_state = 42},
  [7336] = {.lex_state = 63, .external_lex_state = 37},
  [7337] = {.lex_state = 56, .external_lex_state = 55},
  [7338] = {.lex_state = 63, .external_lex_state = 50},
  [7339] = {.lex_state = 63, .external_lex_state = 37},
  [7340] = {.lex_state = 56, .external_lex_state = 55},
  [7341] = {.lex_state = 56, .external_lex_state = 53},
  [7342] = {.lex_state = 10, .external_lex_state = 43},
  [7343] = {.lex_state = 63, .external_lex_state = 35},
  [7344] = {.lex_state = 56, .external_lex_state = 43},
  [7345] = {.lex_state = 56, .external_lex_state = 53},
  [7346] = {.lex_state = 52, .external_lex_state = 47},
  [7347] = {.lex_state = 57, .external_lex_state = 55},
  [7348] = {.lex_state = 56, .external_lex_state = 53},
  [7349] = {.lex_state = 52, .external_lex_state = 31},
  [7350] = {.lex_state = 57, .external_lex_state = 54},
  [7351] = {.lex_state = 56, .external_lex_state = 53},
  [7352] = {.lex_state = 58, .external_lex_state = 46},
  [7353] = {.lex_state = 56, .external_lex_state = 53},
  [7354] = {.lex_state = 58, .external_lex_state = 46},
  [7355] = {.lex_state = 56, .external_lex_state = 53},
  [7356] = {.lex_state = 63, .external_lex_state = 24},
  [7357] = {.lex_state = 56, .external_lex_state = 29},
  [7358] = {.lex_state = 63, .external_lex_state = 24},
  [7359] = {.lex_state = 63, .external_lex_state = 37},
  [7360] = {.lex_state = 57, .external_lex_state = 26},
  [7361] = {.lex_state = 56, .external_lex_state = 53},
  [7362] = {.lex_state = 57, .external_lex_state = 26},
  [7363] = {.lex_state = 61, .external_lex_state = 27},
  [7364] = {.lex_state = 61, .external_lex_state = 46},
  [7365] = {.lex_state = 57, .external_lex_state = 26},
  [7366] = {.lex_state = 52, .external_lex_state = 32},
  [7367] = {.lex_state = 57, .external_lex_state = 26},
  [7368] = {.lex_state = 55, .external_lex_state = 40},
  [7369] = {.lex_state = 57, .external_lex_state = 26},
  [7370] = {.lex_state = 63, .external_lex_state = 36},
  [7371] = {.lex_state = 63, .external_lex_state = 31},
  [7372] = {.lex_state = 55, .external_lex_state = 40},
  [7373] = {.lex_state = 57, .external_lex_state = 26},
  [7374] = {.lex_state = 55, .external_lex_state = 40},
  [7375] = {.lex_state = 52, .external_lex_state = 41},
  [7376] = {.lex_state = 57, .external_lex_state = 26},
  [7377] = {.lex_state = 52, .external_lex_state = 56},
  [7378] = {.lex_state = 58, .external_lex_state = 34},
  [7379] = {.lex_state = 63, .external_lex_state = 36},
  [7380] = {.lex_state = 63, .external_lex_state = 36},
  [7381] = {.lex_state = 63, .external_lex_state = 39},
  [7382] = {.lex_state = 52, .external_lex_state = 42},
  [7383] = {.lex_state = 63, .external_lex_state = 44},
  [7384] = {.lex_state = 63, .external_lex_state = 36},
  [7385] = {.lex_state = 52, .external_lex_state = 28},
  [7386] = {.lex_state = 57, .external_lex_state = 26},
  [7387] = {.lex_state = 62, .external_lex_state = 43},
  [7388] = {.lex_state = 56, .external_lex_state = 34},
  [7389] = {.lex_state = 55, .external_lex_state = 40},
  [7390] = {.lex_state = 63},
  [7391] = {.lex_state = 58, .external_lex_state = 29},
  [7392] = {.lex_state = 63, .external_lex_state = 37},
  [7393] = {.lex_state = 52, .external_lex_state = 40},
  [7394] = {.lex_state = 63, .external_lex_state = 52},
  [7395] = {.lex_state = 63},
  [7396] = {.lex_state = 63, .external_lex_state = 45},
  [7397] = {.lex_state = 63, .external_lex_state = 42},
  [7398] = {.lex_state = 57, .external_lex_state = 43},
  [7399] = {.lex_state = 55, .external_lex_state = 40},
  [7400] = {.lex_state = 63, .external_lex_state = 32},
  [7401] = {.lex_state = 63},
  [7402] = {.lex_state = 63, .external_lex_state = 42},
  [7403] = {.lex_state = 63, .external_lex_state = 23},
  [7404] = {.lex_state = 63, .external_lex_state = 23},
  [7405] = {.lex_state = 61, .external_lex_state = 50},
  [7406] = {.lex_state = 52, .external_lex_state = 32},
  [7407] = {.lex_state = 56, .external_lex_state = 32},
  [7408] = {.lex_state = 63, .external_lex_state = 52},
  [7409] = {.lex_state = 63},
  [7410] = {.lex_state = 63, .external_lex_state = 23},
  [7411] = {.lex_state = 63, .external_lex_state = 42},
  [7412] = {.lex_state = 11, .external_lex_state = 43},
  [7413] = {.lex_state = 63},
  [7414] = {.lex_state = 63},
  [7415] = {.lex_state = 52, .external_lex_state = 36},
  [7416] = {.lex_state = 63, .external_lex_state = 52},
  [7417] = {.lex_state = 52, .external_lex_state = 56},
  [7418] = {.lex_state = 63},
  [7419] = {.lex_state = 7, .external_lex_state = 43},
  [7420] = {.lex_state = 52, .external_lex_state = 54},
  [7421] = {.lex_state = 10, .external_lex_state = 43},
  [7422] = {.lex_state = 56, .external_lex_state = 32},
  [7423] = {.lex_state = 56, .external_lex_state = 32},
  [7424] = {.lex_state = 63},
  [7425] = {.lex_state = 52, .external_lex_state = 51},
  [7426] = {.lex_state = 63, .external_lex_state = 42},
  [7427] = {.lex_state = 52, .external_lex_state = 27},
  [7428] = {.lex_state = 57, .external_lex_state = 43},
  [7429] = {.lex_state = 56, .external_lex_state = 32},
  [7430] = {.lex_state = 52, .external_lex_state = 54},
  [7431] = {.lex_state = 63, .external_lex_state = 32},
  [7432] = {.lex_state = 63},
  [7433] = {.lex_state = 52, .external_lex_state = 54},
  [7434] = {.lex_state = 52, .external_lex_state = 57},
  [7435] = {.lex_state = 56, .external_lex_state = 53},
  [7436] = {.lex_state = 63},
  [7437] = {.lex_state = 61, .external_lex_state = 46},
  [7438] = {.lex_state = 56, .external_lex_state = 53},
  [7439] = {.lex_state = 63, .external_lex_state = 23},
  [7440] = {.lex_state = 57, .external_lex_state = 29},
  [7441] = {.lex_state = 63},
  [7442] = {.lex_state = 57, .external_lex_state = 43},
  [7443] = {.lex_state = 63},
  [7444] = {.lex_state = 63, .external_lex_state = 23},
  [7445] = {.lex_state = 63},
  [7446] = {.lex_state = 52, .external_lex_state = 27},
  [7447] = {.lex_state = 61, .external_lex_state = 30},
  [7448] = {.lex_state = 63, .external_lex_state = 54},
  [7449] = {.lex_state = 63},
  [7450] = {.lex_state = 18},
  [7451] = {.lex_state = 57, .external_lex_state = 53},
  [7452] = {.lex_state = 63, .external_lex_state = 42},
  [7453] = {.lex_state = 52, .external_lex_state = 57},
  [7454] = {.lex_state = 62, .external_lex_state = 43},
  [7455] = {.lex_state = 63},
  [7456] = {.lex_state = 63, .external_lex_state = 23},
  [7457] = {.lex_state = 63, .external_lex_state = 23},
  [7458] = {.lex_state = 63, .external_lex_state = 23},
  [7459] = {.lex_state = 63, .external_lex_state = 42},
  [7460] = {.lex_state = 52, .external_lex_state = 40},
  [7461] = {.lex_state = 63},
  [7462] = {.lex_state = 56, .external_lex_state = 32},
  [7463] = {.lex_state = 63, .external_lex_state = 34},
  [7464] = {.lex_state = 63},
  [7465] = {.lex_state = 58, .external_lex_state = 32},
  [7466] = {.lex_state = 63, .external_lex_state = 23},
  [7467] = {.lex_state = 61, .external_lex_state = 55},
  [7468] = {.lex_state = 63},
  [7469] = {.lex_state = 19, .external_lex_state = 43},
  [7470] = {.lex_state = 7, .external_lex_state = 43},
  [7471] = {.lex_state = 63},
  [7472] = {.lex_state = 63},
  [7473] = {.lex_state = 63, .external_lex_state = 42},
  [7474] = {.lex_state = 61, .external_lex_state = 31},
  [7475] = {.lex_state = 63},
  [7476] = {.lex_state = 63, .external_lex_state = 42},
  [7477] = {.lex_state = 63, .external_lex_state = 23},
  [7478] = {.lex_state = 63, .external_lex_state = 42},
  [7479] = {.lex_state = 63, .external_lex_state = 42},
  [7480] = {.lex_state = 52, .external_lex_state = 34},
  [7481] = {.lex_state = 63, .external_lex_state = 35},
  [7482] = {.lex_state = 63},
  [7483] = {.lex_state = 61, .external_lex_state = 28},
  [7484] = {.lex_state = 52, .external_lex_state = 55},
  [7485] = {.lex_state = 63, .external_lex_state = 42},
  [7486] = {.lex_state = 57, .external_lex_state = 29},
  [7487] = {.lex_state = 63},
  [7488] = {.lex_state = 63, .external_lex_state = 42},
  [7489] = {.lex_state = 17, .external_lex_state = 43},
  [7490] = {.lex_state = 63, .external_lex_state = 42},
  [7491] = {.lex_state = 63, .external_lex_state = 42},
  [7492] = {.lex_state = 52, .external_lex_state = 27},
  [7493] = {.lex_state = 63, .external_lex_state = 42},
  [7494] = {.lex_state = 52, .external_lex_state = 55},
  [7495] = {.lex_state = 63},
  [7496] = {.lex_state = 52, .external_lex_state = 34},
  [7497] = {.lex_state = 63, .external_lex_state = 23},
  [7498] = {.lex_state = 63, .external_lex_state = 23},
  [7499] = {.lex_state = 63},
  [7500] = {.lex_state = 63, .external_lex_state = 42},
  [7501] = {.lex_state = 52, .external_lex_state = 50},
  [7502] = {.lex_state = 63, .external_lex_state = 42},
  [7503] = {.lex_state = 52, .external_lex_state = 55},
  [7504] = {.lex_state = 63, .external_lex_state = 42},
  [7505] = {.lex_state = 63, .external_lex_state = 42},
  [7506] = {.lex_state = 63},
  [7507] = {.lex_state = 63, .external_lex_state = 23},
  [7508] = {.lex_state = 52, .external_lex_state = 27},
  [7509] = {.lex_state = 52, .external_lex_state = 27},
  [7510] = {.lex_state = 63},
  [7511] = {.lex_state = 52, .external_lex_state = 27},
  [7512] = {.lex_state = 63, .external_lex_state = 42},
  [7513] = {.lex_state = 63, .external_lex_state = 42},
  [7514] = {.lex_state = 63},
  [7515] = {.lex_state = 63},
  [7516] = {.lex_state = 63},
  [7517] = {.lex_state = 58, .external_lex_state = 59},
  [7518] = {.lex_state = 62, .external_lex_state = 40},
  [7519] = {.lex_state = 63, .external_lex_state = 42},
  [7520] = {.lex_state = 63, .external_lex_state = 42},
  [7521] = {.lex_state = 61, .external_lex_state = 31},
  [7522] = {.lex_state = 63},
  [7523] = {.lex_state = 63, .external_lex_state = 23},
  [7524] = {.lex_state = 63},
  [7525] = {.lex_state = 63, .external_lex_state = 42},
  [7526] = {.lex_state = 9, .external_lex_state = 43},
  [7527] = {.lex_state = 58, .external_lex_state = 40},
  [7528] = {.lex_state = 63},
  [7529] = {.lex_state = 18},
  [7530] = {.lex_state = 52, .external_lex_state = 58},
  [7531] = {.lex_state = 63},
  [7532] = {.lex_state = 63},
  [7533] = {.lex_state = 63},
  [7534] = {.lex_state = 19, .external_lex_state = 43},
  [7535] = {.lex_state = 63, .external_lex_state = 52},
  [7536] = {.lex_state = 63},
  [7537] = {.lex_state = 52, .external_lex_state = 40},
  [7538] = {.lex_state = 63},
  [7539] = {.lex_state = 63},
  [7540] = {.lex_state = 63},
  [7541] = {.lex_state = 63},
  [7542] = {.lex_state = 56, .external_lex_state = 30},
  [7543] = {.lex_state = 63},
  [7544] = {.lex_state = 57},
  [7545] = {.lex_state = 57, .external_lex_state = 53},
  [7546] = {.lex_state = 63},
  [7547] = {.lex_state = 63, .external_lex_state = 23},
  [7548] = {.lex_state = 63},
  [7549] = {.lex_state = 58, .external_lex_state = 29},
  [7550] = {.lex_state = 63},
  [7551] = {.lex_state = 63, .external_lex_state = 42},
  [7552] = {.lex_state = 63},
  [7553] = {.lex_state = 63, .external_lex_state = 23},
  [7554] = {.lex_state = 61, .external_lex_state = 30},
  [7555] = {.lex_state = 63},
  [7556] = {.lex_state = 62, .external_lex_state = 40},
  [7557] = {.lex_state = 63, .external_lex_state = 55},
  [7558] = {.lex_state = 63},
  [7559] = {.lex_state = 57, .external_lex_state = 29},
  [7560] = {.lex_state = 57, .external_lex_state = 30},
  [7561] = {.lex_state = 63},
  [7562] = {.lex_state = 58, .external_lex_state = 52},
  [7563] = {.lex_state = 63, .external_lex_state = 23},
  [7564] = {.lex_state = 58, .external_lex_state = 30},
  [7565] = {.lex_state = 63},
  [7566] = {.lex_state = 57, .external_lex_state = 43},
  [7567] = {.lex_state = 57, .external_lex_state = 30},
  [7568] = {.lex_state = 63},
  [7569] = {.lex_state = 63, .external_lex_state = 23},
  [7570] = {.lex_state = 57, .external_lex_state = 53},
  [7571] = {.lex_state = 61, .external_lex_state = 30},
  [7572] = {.lex_state = 63, .external_lex_state = 39},
  [7573] = {.lex_state = 63, .external_lex_state = 39},
  [7574] = {.lex_state = 63},
  [7575] = {.lex_state = 62, .external_lex_state = 40},
  [7576] = {.lex_state = 63, .external_lex_state = 28},
  [7577] = {.lex_state = 57, .external_lex_state = 30},
  [7578] = {.lex_state = 61, .external_lex_state = 30},
  [7579] = {.lex_state = 63},
  [7580] = {.lex_state = 63, .external_lex_state = 28},
  [7581] = {.lex_state = 52, .external_lex_state = 27},
  [7582] = {.lex_state = 63},
  [7583] = {.lex_state = 17, .external_lex_state = 43},
  [7584] = {.lex_state = 63},
  [7585] = {.lex_state = 63, .external_lex_state = 34},
  [7586] = {.lex_state = 63, .external_lex_state = 42},
  [7587] = {.lex_state = 57, .external_lex_state = 30},
  [7588] = {.lex_state = 63},
  [7589] = {.lex_state = 58, .external_lex_state = 52},
  [7590] = {.lex_state = 52, .external_lex_state = 27},
  [7591] = {.lex_state = 52, .external_lex_state = 27},
  [7592] = {.lex_state = 63},
  [7593] = {.lex_state = 57, .external_lex_state = 53},
  [7594] = {.lex_state = 63},
  [7595] = {.lex_state = 52, .external_lex_state = 27},
  [7596] = {.lex_state = 63},
  [7597] = {.lex_state = 63, .external_lex_state = 42},
  [7598] = {.lex_state = 63, .external_lex_state = 23},
  [7599] = {.lex_state = 57, .external_lex_state = 53},
  [7600] = {.lex_state = 58, .external_lex_state = 34},
  [7601] = {.lex_state = 63, .external_lex_state = 55},
  [7602] = {.lex_state = 57, .external_lex_state = 53},
  [7603] = {.lex_state = 63, .external_lex_state = 39},
  [7604] = {.lex_state = 57, .external_lex_state = 30},
  [7605] = {.lex_state = 58, .external_lex_state = 30},
  [7606] = {.lex_state = 61, .external_lex_state = 31},
  [7607] = {.lex_state = 57, .external_lex_state = 53},
  [7608] = {.lex_state = 58, .external_lex_state = 30},
  [7609] = {.lex_state = 63, .external_lex_state = 39},
  [7610] = {.lex_state = 58, .external_lex_state = 30},
  [7611] = {.lex_state = 58, .external_lex_state = 30},
  [7612] = {.lex_state = 57, .external_lex_state = 53},
  [7613] = {.lex_state = 58, .external_lex_state = 30},
  [7614] = {.lex_state = 57, .external_lex_state = 53},
  [7615] = {.lex_state = 58, .external_lex_state = 30},
  [7616] = {.lex_state = 57, .external_lex_state = 43},
  [7617] = {.lex_state = 58, .external_lex_state = 30},
  [7618] = {.lex_state = 52, .external_lex_state = 27},
  [7619] = {.lex_state = 63, .external_lex_state = 23},
  [7620] = {.lex_state = 63},
  [7621] = {.lex_state = 63, .external_lex_state = 23},
  [7622] = {.lex_state = 63, .external_lex_state = 55},
  [7623] = {.lex_state = 63, .external_lex_state = 42},
  [7624] = {.lex_state = 63, .external_lex_state = 55},
  [7625] = {.lex_state = 63, .external_lex_state = 42},
  [7626] = {.lex_state = 63, .external_lex_state = 42},
  [7627] = {.lex_state = 57, .external_lex_state = 53},
  [7628] = {.lex_state = 61, .external_lex_state = 31},
  [7629] = {.lex_state = 61, .external_lex_state = 31},
  [7630] = {.lex_state = 62, .external_lex_state = 40},
  [7631] = {.lex_state = 61, .external_lex_state = 44},
  [7632] = {.lex_state = 63, .external_lex_state = 23},
  [7633] = {.lex_state = 63, .external_lex_state = 26},
  [7634] = {.lex_state = 52, .external_lex_state = 52},
  [7635] = {.lex_state = 63, .external_lex_state = 42},
  [7636] = {.lex_state = 58, .external_lex_state = 29},
  [7637] = {.lex_state = 61, .external_lex_state = 31},
  [7638] = {.lex_state = 63, .external_lex_state = 39},
  [7639] = {.lex_state = 63, .external_lex_state = 48},
  [7640] = {.lex_state = 63, .external_lex_state = 42},
  [7641] = {.lex_state = 63, .external_lex_state = 42},
  [7642] = {.lex_state = 52, .external_lex_state = 46},
  [7643] = {.lex_state = 63, .external_lex_state = 23},
  [7644] = {.lex_state = 63, .external_lex_state = 42},
  [7645] = {.lex_state = 63, .external_lex_state = 39},
  [7646] = {.lex_state = 63},
  [7647] = {.lex_state = 58, .external_lex_state = 30},
  [7648] = {.lex_state = 63, .external_lex_state = 39},
  [7649] = {.lex_state = 58, .external_lex_state = 34},
  [7650] = {.lex_state = 58, .external_lex_state = 40},
  [7651] = {.lex_state = 63, .external_lex_state = 39},
  [7652] = {.lex_state = 58, .external_lex_state = 29},
  [7653] = {.lex_state = 64, .external_lex_state = 53},
  [7654] = {.lex_state = 63, .external_lex_state = 39},
  [7655] = {.lex_state = 52, .external_lex_state = 23},
  [7656] = {.lex_state = 63, .external_lex_state = 23},
  [7657] = {.lex_state = 58, .external_lex_state = 29},
  [7658] = {.lex_state = 63, .external_lex_state = 39},
  [7659] = {.lex_state = 57, .external_lex_state = 53},
  [7660] = {.lex_state = 52},
  [7661] = {.lex_state = 63, .external_lex_state = 39},
  [7662] = {.lex_state = 63, .external_lex_state = 23},
  [7663] = {.lex_state = 63, .external_lex_state = 39},
  [7664] = {.lex_state = 63, .external_lex_state = 23},
  [7665] = {.lex_state = 63, .external_lex_state = 23},
  [7666] = {.lex_state = 63, .external_lex_state = 39},
  [7667] = {.lex_state = 63, .external_lex_state = 39},
  [7668] = {.lex_state = 61, .external_lex_state = 32},
  [7669] = {.lex_state = 57, .external_lex_state = 43},
  [7670] = {.lex_state = 63, .external_lex_state = 45},
  [7671] = {.lex_state = 18},
  [7672] = {.lex_state = 63, .external_lex_state = 39},
  [7673] = {.lex_state = 52, .external_lex_state = 52},
  [7674] = {.lex_state = 3},
  [7675] = {.lex_state = 52, .external_lex_state = 26},
  [7676] = {.lex_state = 63, .external_lex_state = 39},
  [7677] = {.lex_state = 63, .external_lex_state = 39},
  [7678] = {.lex_state = 63, .external_lex_state = 39},
  [7679] = {.lex_state = 52, .external_lex_state = 52},
  [7680] = {.lex_state = 9, .external_lex_state = 43},
  [7681] = {.lex_state = 63, .external_lex_state = 39},
  [7682] = {.lex_state = 63, .external_lex_state = 39},
  [7683] = {.lex_state = 3},
  [7684] = {.lex_state = 52, .external_lex_state = 52},
  [7685] = {.lex_state = 63, .external_lex_state = 23},
  [7686] = {.lex_state = 63},
  [7687] = {.lex_state = 63},
  [7688] = {.lex_state = 61, .external_lex_state = 53},
  [7689] = {.lex_state = 63, .external_lex_state = 39},
  [7690] = {.lex_state = 63, .external_lex_state = 39},
  [7691] = {.lex_state = 63, .external_lex_state = 52},
  [7692] = {.lex_state = 63, .external_lex_state = 48},
  [7693] = {.lex_state = 61, .external_lex_state = 28},
  [7694] = {.lex_state = 63, .external_lex_state = 55},
  [7695] = {.lex_state = 58, .external_lex_state = 29},
  [7696] = {.lex_state = 63, .external_lex_state = 39},
  [7697] = {.lex_state = 18},
  [7698] = {.lex_state = 63, .external_lex_state = 39},
  [7699] = {.lex_state = 58, .external_lex_state = 32},
  [7700] = {.lex_state = 52, .external_lex_state = 27},
  [7701] = {.lex_state = 3},
  [7702] = {.lex_state = 63, .external_lex_state = 39},
  [7703] = {.lex_state = 61, .external_lex_state = 53},
  [7704] = {.lex_state = 63, .external_lex_state = 39},
  [7705] = {.lex_state = 57, .external_lex_state = 30},
  [7706] = {.lex_state = 3},
  [7707] = {.lex_state = 61, .external_lex_state = 53},
  [7708] = {.lex_state = 63, .external_lex_state = 28},
  [7709] = {.lex_state = 63},
  [7710] = {.lex_state = 63},
  [7711] = {.lex_state = 52, .external_lex_state = 53},
  [7712] = {.lex_state = 61, .external_lex_state = 28},
  [7713] = {.lex_state = 18},
  [7714] = {.lex_state = 61, .external_lex_state = 28},
  [7715] = {.lex_state = 61, .external_lex_state = 28},
  [7716] = {.lex_state = 52, .external_lex_state = 26},
  [7717] = {.lex_state = 61, .external_lex_state = 53},
  [7718] = {.lex_state = 63, .external_lex_state = 39},
  [7719] = {.lex_state = 63, .external_lex_state = 35},
  [7720] = {.lex_state = 52, .external_lex_state = 53},
  [7721] = {.lex_state = 18},
  [7722] = {.lex_state = 52, .external_lex_state = 53},
  [7723] = {.lex_state = 61, .external_lex_state = 31},
  [7724] = {.lex_state = 63, .external_lex_state = 39},
  [7725] = {.lex_state = 61, .external_lex_state = 54},
  [7726] = {.lex_state = 59, .external_lex_state = 40},
  [7727] = {.lex_state = 18},
  [7728] = {.lex_state = 52, .external_lex_state = 26},
  [7729] = {.lex_state = 61, .external_lex_state = 31},
  [7730] = {.lex_state = 61, .external_lex_state = 31},
  [7731] = {.lex_state = 63},
  [7732] = {.lex_state = 56, .external_lex_state = 32},
  [7733] = {.lex_state = 63, .external_lex_state = 23},
  [7734] = {.lex_state = 56, .external_lex_state = 40},
  [7735] = {.lex_state = 63, .external_lex_state = 23},
  [7736] = {.lex_state = 59, .external_lex_state = 40},
  [7737] = {.lex_state = 3},
  [7738] = {.lex_state = 62, .external_lex_state = 40},
  [7739] = {.lex_state = 63, .external_lex_state = 39},
  [7740] = {.lex_state = 57, .external_lex_state = 43},
  [7741] = {.lex_state = 57, .external_lex_state = 43},
  [7742] = {.lex_state = 59, .external_lex_state = 40},
  [7743] = {.lex_state = 63, .external_lex_state = 23},
  [7744] = {.lex_state = 58, .external_lex_state = 55},
  [7745] = {.lex_state = 63, .external_lex_state = 42},
  [7746] = {.lex_state = 56, .external_lex_state = 29},
  [7747] = {.lex_state = 63, .external_lex_state = 39},
  [7748] = {.lex_state = 59, .external_lex_state = 40},
  [7749] = {.lex_state = 59, .external_lex_state = 40},
  [7750] = {.lex_state = 57, .external_lex_state = 53},
  [7751] = {.lex_state = 52, .external_lex_state = 50},
  [7752] = {.lex_state = 59, .external_lex_state = 40},
  [7753] = {.lex_state = 63, .external_lex_state = 49},
  [7754] = {.lex_state = 63, .external_lex_state = 45},
  [7755] = {.lex_state = 63},
  [7756] = {.lex_state = 63, .external_lex_state = 23},
  [7757] = {.lex_state = 63, .external_lex_state = 42},
  [7758] = {.lex_state = 58, .external_lex_state = 53},
  [7759] = {.lex_state = 59, .external_lex_state = 40},
  [7760] = {.lex_state = 57, .external_lex_state = 43},
  [7761] = {.lex_state = 58, .external_lex_state = 53},
  [7762] = {.lex_state = 59, .external_lex_state = 40},
  [7763] = {.lex_state = 4},
  [7764] = {.lex_state = 59, .external_lex_state = 40},
  [7765] = {.lex_state = 52, .external_lex_state = 23},
  [7766] = {.lex_state = 57, .external_lex_state = 43},
  [7767] = {.lex_state = 57, .external_lex_state = 29},
  [7768] = {.lex_state = 63, .external_lex_state = 42},
  [7769] = {.lex_state = 52, .external_lex_state = 38},
  [7770] = {.lex_state = 63, .external_lex_state = 23},
  [7771] = {.lex_state = 63, .external_lex_state = 39},
  [7772] = {.lex_state = 4},
  [7773] = {.lex_state = 63, .external_lex_state = 39},
  [7774] = {.lex_state = 52, .external_lex_state = 53},
  [7775] = {.lex_state = 63, .external_lex_state = 42},
  [7776] = {.lex_state = 63, .external_lex_state = 42},
  [7777] = {.lex_state = 63},
  [7778] = {.lex_state = 64, .external_lex_state = 40},
  [7779] = {.lex_state = 4},
  [7780] = {.lex_state = 56, .external_lex_state = 34},
  [7781] = {.lex_state = 61, .external_lex_state = 44},
  [7782] = {.lex_state = 57, .external_lex_state = 43},
  [7783] = {.lex_state = 63, .external_lex_state = 39},
  [7784] = {.lex_state = 63, .external_lex_state = 39},
  [7785] = {.lex_state = 59, .external_lex_state = 53},
  [7786] = {.lex_state = 63, .external_lex_state = 49},
  [7787] = {.lex_state = 59, .external_lex_state = 53},
  [7788] = {.lex_state = 57, .external_lex_state = 29},
  [7789] = {.lex_state = 52, .external_lex_state = 27},
  [7790] = {.lex_state = 63, .external_lex_state = 39},
  [7791] = {.lex_state = 59, .external_lex_state = 40},
  [7792] = {.lex_state = 59, .external_lex_state = 40},
  [7793] = {.lex_state = 63, .external_lex_state = 23},
  [7794] = {.lex_state = 63, .external_lex_state = 34},
  [7795] = {.lex_state = 63, .external_lex_state = 23},
  [7796] = {.lex_state = 52, .external_lex_state = 35},
  [7797] = {.lex_state = 55, .external_lex_state = 43},
  [7798] = {.lex_state = 63, .external_lex_state = 34},
  [7799] = {.lex_state = 63, .external_lex_state = 39},
  [7800] = {.lex_state = 63},
  [7801] = {.lex_state = 63, .external_lex_state = 23},
  [7802] = {.lex_state = 63, .external_lex_state = 23},
  [7803] = {.lex_state = 63, .external_lex_state = 39},
  [7804] = {.lex_state = 57, .external_lex_state = 29},
  [7805] = {.lex_state = 63, .external_lex_state = 39},
  [7806] = {.lex_state = 63, .external_lex_state = 23},
  [7807] = {.lex_state = 63, .external_lex_state = 39},
  [7808] = {.lex_state = 63, .external_lex_state = 26},
  [7809] = {.lex_state = 56, .external_lex_state = 34},
  [7810] = {.lex_state = 63},
  [7811] = {.lex_state = 63, .external_lex_state = 23},
  [7812] = {.lex_state = 58, .external_lex_state = 40},
  [7813] = {.lex_state = 63, .external_lex_state = 44},
  [7814] = {.lex_state = 63, .external_lex_state = 48},
  [7815] = {.lex_state = 63, .external_lex_state = 23},
  [7816] = {.lex_state = 63, .external_lex_state = 39},
  [7817] = {.lex_state = 62, .external_lex_state = 53},
  [7818] = {.lex_state = 55, .external_lex_state = 43},
  [7819] = {.lex_state = 52, .external_lex_state = 44},
  [7820] = {.lex_state = 57, .external_lex_state = 30},
  [7821] = {.lex_state = 52},
  [7822] = {.lex_state = 52, .external_lex_state = 56},
  [7823] = {.lex_state = 62, .external_lex_state = 53},
  [7824] = {.lex_state = 56, .external_lex_state = 34},
  [7825] = {.lex_state = 9, .external_lex_state = 43},
  [7826] = {.lex_state = 62, .external_lex_state = 53},
  [7827] = {.lex_state = 63, .external_lex_state = 26},
  [7828] = {.lex_state = 64, .external_lex_state = 40},
  [7829] = {.lex_state = 63, .external_lex_state = 39},
  [7830] = {.lex_state = 61, .external_lex_state = 29},
  [7831] = {.lex_state = 63},
  [7832] = {.lex_state = 63},
  [7833] = {.lex_state = 61, .external_lex_state = 47},
  [7834] = {.lex_state = 61, .external_lex_state = 43},
  [7835] = {.lex_state = 56, .external_lex_state = 34},
  [7836] = {.lex_state = 63, .external_lex_state = 26},
  [7837] = {.lex_state = 59, .external_lex_state = 40},
  [7838] = {.lex_state = 58, .external_lex_state = 34},
  [7839] = {.lex_state = 52, .external_lex_state = 46},
  [7840] = {.lex_state = 56, .external_lex_state = 34},
  [7841] = {.lex_state = 63, .external_lex_state = 23},
  [7842] = {.lex_state = 63, .external_lex_state = 39},
  [7843] = {.lex_state = 58, .external_lex_state = 34},
  [7844] = {.lex_state = 52, .external_lex_state = 30},
  [7845] = {.lex_state = 56, .external_lex_state = 40},
  [7846] = {.lex_state = 63, .external_lex_state = 44},
  [7847] = {.lex_state = 58, .external_lex_state = 30},
  [7848] = {.lex_state = 58, .external_lex_state = 30},
  [7849] = {.lex_state = 58, .external_lex_state = 30},
  [7850] = {.lex_state = 58, .external_lex_state = 30},
  [7851] = {.lex_state = 52, .external_lex_state = 43},
  [7852] = {.lex_state = 56, .external_lex_state = 30},
  [7853] = {.lex_state = 63},
  [7854] = {.lex_state = 63, .external_lex_state = 23},
  [7855] = {.lex_state = 56, .external_lex_state = 32},
  [7856] = {.lex_state = 58, .external_lex_state = 40},
  [7857] = {.lex_state = 19, .external_lex_state = 43},
  [7858] = {.lex_state = 61, .external_lex_state = 52},
  [7859] = {.lex_state = 52, .external_lex_state = 40},
  [7860] = {.lex_state = 63, .external_lex_state = 23},
  [7861] = {.lex_state = 63, .external_lex_state = 46},
  [7862] = {.lex_state = 63, .external_lex_state = 55},
  [7863] = {.lex_state = 57, .external_lex_state = 30},
  [7864] = {.lex_state = 52, .external_lex_state = 40},
  [7865] = {.lex_state = 57, .external_lex_state = 30},
  [7866] = {.lex_state = 52, .external_lex_state = 24},
  [7867] = {.lex_state = 52, .external_lex_state = 49},
  [7868] = {.lex_state = 57, .external_lex_state = 30},
  [7869] = {.lex_state = 63},
  [7870] = {.lex_state = 63, .external_lex_state = 31},
  [7871] = {.lex_state = 58, .external_lex_state = 29},
  [7872] = {.lex_state = 56, .external_lex_state = 40},
  [7873] = {.lex_state = 63, .external_lex_state = 23},
  [7874] = {.lex_state = 57, .external_lex_state = 43},
  [7875] = {.lex_state = 56, .external_lex_state = 34},
  [7876] = {.lex_state = 57, .external_lex_state = 30},
  [7877] = {.lex_state = 61, .external_lex_state = 47},
  [7878] = {.lex_state = 61, .external_lex_state = 32},
  [7879] = {.lex_state = 63, .external_lex_state = 39},
  [7880] = {.lex_state = 52, .external_lex_state = 27},
  [7881] = {.lex_state = 57, .external_lex_state = 30},
  [7882] = {.lex_state = 57},
  [7883] = {.lex_state = 63, .external_lex_state = 42},
  [7884] = {.lex_state = 63, .external_lex_state = 39},
  [7885] = {.lex_state = 63},
  [7886] = {.lex_state = 56, .external_lex_state = 29},
  [7887] = {.lex_state = 64, .external_lex_state = 40},
  [7888] = {.lex_state = 63, .external_lex_state = 42},
  [7889] = {.lex_state = 57, .external_lex_state = 30},
  [7890] = {.lex_state = 52, .external_lex_state = 36},
  [7891] = {.lex_state = 63, .external_lex_state = 54},
  [7892] = {.lex_state = 64, .external_lex_state = 40},
  [7893] = {.lex_state = 61, .external_lex_state = 29},
  [7894] = {.lex_state = 63, .external_lex_state = 23},
  [7895] = {.lex_state = 63, .external_lex_state = 36},
  [7896] = {.lex_state = 54},
  [7897] = {.lex_state = 52, .external_lex_state = 23},
  [7898] = {.lex_state = 56, .external_lex_state = 30},
  [7899] = {.lex_state = 57, .external_lex_state = 30},
  [7900] = {.lex_state = 52, .external_lex_state = 26},
  [7901] = {.lex_state = 58, .external_lex_state = 55},
  [7902] = {.lex_state = 52, .external_lex_state = 56},
  [7903] = {.lex_state = 52, .external_lex_state = 58},
  [7904] = {.lex_state = 57, .external_lex_state = 30},
  [7905] = {.lex_state = 61, .external_lex_state = 31},
  [7906] = {.lex_state = 63, .external_lex_state = 46},
  [7907] = {.lex_state = 57, .external_lex_state = 30},
  [7908] = {.lex_state = 63, .external_lex_state = 54},
  [7909] = {.lex_state = 63, .external_lex_state = 51},
  [7910] = {.lex_state = 56, .external_lex_state = 53},
  [7911] = {.lex_state = 61, .external_lex_state = 31},
  [7912] = {.lex_state = 58, .external_lex_state = 32},
  [7913] = {.lex_state = 58, .external_lex_state = 32},
  [7914] = {.lex_state = 63},
  [7915] = {.lex_state = 61, .external_lex_state = 31},
  [7916] = {.lex_state = 61, .external_lex_state = 42},
  [7917] = {.lex_state = 63, .external_lex_state = 26},
  [7918] = {.lex_state = 63},
  [7919] = {.lex_state = 57, .external_lex_state = 53},
  [7920] = {.lex_state = 61, .external_lex_state = 40},
  [7921] = {.lex_state = 61, .external_lex_state = 31},
  [7922] = {.lex_state = 61, .external_lex_state = 54},
  [7923] = {.lex_state = 52, .external_lex_state = 35},
  [7924] = {.lex_state = 63, .external_lex_state = 39},
  [7925] = {.lex_state = 63, .external_lex_state = 39},
  [7926] = {.lex_state = 57, .external_lex_state = 53},
  [7927] = {.lex_state = 52, .external_lex_state = 27},
  [7928] = {.lex_state = 61, .external_lex_state = 31},
  [7929] = {.lex_state = 52, .external_lex_state = 54},
  [7930] = {.lex_state = 61, .external_lex_state = 28},
  [7931] = {.lex_state = 57, .external_lex_state = 53},
  [7932] = {.lex_state = 52, .external_lex_state = 57},
  [7933] = {.lex_state = 56, .external_lex_state = 32},
  [7934] = {.lex_state = 63, .external_lex_state = 51},
  [7935] = {.lex_state = 63},
  [7936] = {.lex_state = 56, .external_lex_state = 32},
  [7937] = {.lex_state = 63, .external_lex_state = 47},
  [7938] = {.lex_state = 61, .external_lex_state = 52},
  [7939] = {.lex_state = 64, .external_lex_state = 53},
  [7940] = {.lex_state = 56, .external_lex_state = 34},
  [7941] = {.lex_state = 61, .external_lex_state = 40},
  [7942] = {.lex_state = 3},
  [7943] = {.lex_state = 63},
  [7944] = {.lex_state = 56, .external_lex_state = 29},
  [7945] = {.lex_state = 52, .external_lex_state = 38},
  [7946] = {.lex_state = 57, .external_lex_state = 43},
  [7947] = {.lex_state = 63},
  [7948] = {.lex_state = 58, .external_lex_state = 54},
  [7949] = {.lex_state = 52, .external_lex_state = 43},
  [7950] = {.lex_state = 61, .external_lex_state = 28},
  [7951] = {.lex_state = 63, .external_lex_state = 24},
  [7952] = {.lex_state = 56, .external_lex_state = 32},
  [7953] = {.lex_state = 63, .external_lex_state = 47},
  [7954] = {.lex_state = 57, .external_lex_state = 29},
  [7955] = {.lex_state = 57, .external_lex_state = 53},
  [7956] = {.lex_state = 57, .external_lex_state = 29},
  [7957] = {.lex_state = 63},
  [7958] = {.lex_state = 52, .external_lex_state = 47},
  [7959] = {.lex_state = 63, .external_lex_state = 23},
  [7960] = {.lex_state = 61, .external_lex_state = 28},
  [7961] = {.lex_state = 56, .external_lex_state = 32},
  [7962] = {.lex_state = 63},
  [7963] = {.lex_state = 61, .external_lex_state = 34},
  [7964] = {.lex_state = 58, .external_lex_state = 29},
  [7965] = {.lex_state = 61, .external_lex_state = 26},
  [7966] = {.lex_state = 57, .external_lex_state = 43},
  [7967] = {.lex_state = 61, .external_lex_state = 46},
  [7968] = {.lex_state = 63},
  [7969] = {.lex_state = 61, .external_lex_state = 26},
  [7970] = {.lex_state = 57, .external_lex_state = 30},
  [7971] = {.lex_state = 63, .external_lex_state = 37},
  [7972] = {.lex_state = 63, .external_lex_state = 23},
  [7973] = {.lex_state = 52, .external_lex_state = 27},
  [7974] = {.lex_state = 58, .external_lex_state = 29},
  [7975] = {.lex_state = 57, .external_lex_state = 29},
  [7976] = {.lex_state = 63},
  [7977] = {.lex_state = 58, .external_lex_state = 29},
  [7978] = {.lex_state = 58, .external_lex_state = 29},
  [7979] = {.lex_state = 63, .external_lex_state = 32},
  [7980] = {.lex_state = 62, .external_lex_state = 53},
  [7981] = {.lex_state = 61, .external_lex_state = 28},
  [7982] = {.lex_state = 52, .external_lex_state = 47},
  [7983] = {.lex_state = 52, .external_lex_state = 37},
  [7984] = {.lex_state = 63, .external_lex_state = 36},
  [7985] = {.lex_state = 63, .external_lex_state = 50},
  [7986] = {.lex_state = 63, .external_lex_state = 54},
  [7987] = {.lex_state = 63},
  [7988] = {.lex_state = 61, .external_lex_state = 28},
  [7989] = {.lex_state = 52, .external_lex_state = 28},
  [7990] = {.lex_state = 63, .external_lex_state = 26},
  [7991] = {.lex_state = 61, .external_lex_state = 28},
  [7992] = {.lex_state = 56, .external_lex_state = 32},
  [7993] = {.lex_state = 57, .external_lex_state = 29},
  [7994] = {.lex_state = 51},
  [7995] = {.lex_state = 56, .external_lex_state = 40},
  [7996] = {.lex_state = 62, .external_lex_state = 43},
  [7997] = {.lex_state = 57, .external_lex_state = 53},
  [7998] = {.lex_state = 63, .external_lex_state = 52},
  [7999] = {.lex_state = 61, .external_lex_state = 39},
  [8000] = {.lex_state = 52, .external_lex_state = 29},
  [8001] = {.lex_state = 62, .external_lex_state = 40},
  [8002] = {.lex_state = 63, .external_lex_state = 24},
  [8003] = {.lex_state = 63, .external_lex_state = 42},
  [8004] = {.lex_state = 56, .external_lex_state = 32},
  [8005] = {.lex_state = 9, .external_lex_state = 43},
  [8006] = {.lex_state = 63},
  [8007] = {.lex_state = 57, .external_lex_state = 29},
  [8008] = {.lex_state = 61, .external_lex_state = 29},
  [8009] = {.lex_state = 63},
  [8010] = {.lex_state = 63, .external_lex_state = 50},
  [8011] = {.lex_state = 61, .external_lex_state = 23},
  [8012] = {.lex_state = 61, .external_lex_state = 28},
  [8013] = {.lex_state = 52, .external_lex_state = 31},
  [8014] = {.lex_state = 61, .external_lex_state = 50},
  [8015] = {.lex_state = 57, .external_lex_state = 29},
  [8016] = {.lex_state = 52, .external_lex_state = 39},
  [8017] = {.lex_state = 52},
  [8018] = {.lex_state = 57, .external_lex_state = 29},
  [8019] = {.lex_state = 56, .external_lex_state = 34},
  [8020] = {.lex_state = 63, .external_lex_state = 31},
  [8021] = {.lex_state = 61, .external_lex_state = 34},
  [8022] = {.lex_state = 63},
  [8023] = {.lex_state = 56, .external_lex_state = 43},
  [8024] = {.lex_state = 57, .external_lex_state = 29},
  [8025] = {.lex_state = 57, .external_lex_state = 29},
  [8026] = {.lex_state = 63, .external_lex_state = 23},
  [8027] = {.lex_state = 52, .external_lex_state = 27},
  [8028] = {.lex_state = 57, .external_lex_state = 29},
  [8029] = {.lex_state = 56, .external_lex_state = 34},
  [8030] = {.lex_state = 59, .external_lex_state = 40},
  [8031] = {.lex_state = 63, .external_lex_state = 23},
  [8032] = {.lex_state = 61, .external_lex_state = 43},
  [8033] = {.lex_state = 63, .external_lex_state = 45},
  [8034] = {.lex_state = 59, .external_lex_state = 40},
  [8035] = {.lex_state = 63},
  [8036] = {.lex_state = 61, .external_lex_state = 28},
  [8037] = {.lex_state = 59, .external_lex_state = 40},
  [8038] = {.lex_state = 63, .external_lex_state = 23},
  [8039] = {.lex_state = 52, .external_lex_state = 41},
  [8040] = {.lex_state = 52, .external_lex_state = 35},
  [8041] = {.lex_state = 57},
  [8042] = {.lex_state = 63},
  [8043] = {.lex_state = 57, .external_lex_state = 29},
  [8044] = {.lex_state = 63, .external_lex_state = 48},
  [8045] = {.lex_state = 57, .external_lex_state = 43},
  [8046] = {.lex_state = 58, .external_lex_state = 54},
  [8047] = {.lex_state = 63, .external_lex_state = 32},
  [8048] = {.lex_state = 52, .external_lex_state = 49},
  [8049] = {.lex_state = 63, .external_lex_state = 42},
  [8050] = {.lex_state = 61, .external_lex_state = 55},
  [8051] = {.lex_state = 63, .external_lex_state = 42},
  [8052] = {.lex_state = 63, .external_lex_state = 42},
  [8053] = {.lex_state = 63, .external_lex_state = 23},
  [8054] = {.lex_state = 52, .external_lex_state = 30},
  [8055] = {.lex_state = 57, .external_lex_state = 43},
  [8056] = {.lex_state = 63, .external_lex_state = 31},
  [8057] = {.lex_state = 21, .external_lex_state = 43},
  [8058] = {.lex_state = 63, .external_lex_state = 42},
  [8059] = {.lex_state = 58, .external_lex_state = 26},
  [8060] = {.lex_state = 61, .external_lex_state = 28},
  [8061] = {.lex_state = 56, .external_lex_state = 32},
  [8062] = {.lex_state = 52, .external_lex_state = 36},
  [8063] = {.lex_state = 52, .external_lex_state = 27},
  [8064] = {.lex_state = 63, .external_lex_state = 42},
  [8065] = {.lex_state = 58, .external_lex_state = 26},
  [8066] = {.lex_state = 63, .external_lex_state = 23},
  [8067] = {.lex_state = 63},
  [8068] = {.lex_state = 57},
  [8069] = {.lex_state = 52, .external_lex_state = 58},
  [8070] = {.lex_state = 52, .external_lex_state = 41},
  [8071] = {.lex_state = 56, .external_lex_state = 34},
  [8072] = {.lex_state = 58, .external_lex_state = 29},
  [8073] = {.lex_state = 63, .external_lex_state = 54},
  [8074] = {.lex_state = 52, .external_lex_state = 29},
  [8075] = {.lex_state = 57, .external_lex_state = 43},
  [8076] = {.lex_state = 56, .external_lex_state = 34},
  [8077] = {.lex_state = 52, .external_lex_state = 44},
  [8078] = {.lex_state = 61, .external_lex_state = 29},
  [8079] = {.lex_state = 52, .external_lex_state = 55},
  [8080] = {.lex_state = 56, .external_lex_state = 34},
  [8081] = {.lex_state = 58, .external_lex_state = 29},
  [8082] = {.lex_state = 63, .external_lex_state = 54},
  [8083] = {.lex_state = 56, .external_lex_state = 34},
  [8084] = {.lex_state = 63},
  [8085] = {.lex_state = 52, .external_lex_state = 32},
  [8086] = {.lex_state = 52, .external_lex_state = 51},
  [8087] = {.lex_state = 63, .external_lex_state = 39},
  [8088] = {.lex_state = 52, .external_lex_state = 31},
  [8089] = {.lex_state = 57, .external_lex_state = 34},
  [8090] = {.lex_state = 63, .external_lex_state = 43},
  [8091] = {.lex_state = 61, .external_lex_state = 43},
  [8092] = {.lex_state = 63, .external_lex_state = 45},
  [8093] = {.lex_state = 63, .external_lex_state = 51},
  [8094] = {.lex_state = 61, .external_lex_state = 36},
  [8095] = {.lex_state = 57, .external_lex_state = 32},
  [8096] = {.lex_state = 61, .external_lex_state = 36},
  [8097] = {.lex_state = 52},
  [8098] = {.lex_state = 17, .external_lex_state = 43},
  [8099] = {.lex_state = 63, .external_lex_state = 51},
  [8100] = {.lex_state = 17, .external_lex_state = 43},
  [8101] = {.lex_state = 63, .external_lex_state = 39},
  [8102] = {.lex_state = 63, .external_lex_state = 49},
  [8103] = {.lex_state = 63, .external_lex_state = 51},
  [8104] = {.lex_state = 17, .external_lex_state = 43},
  [8105] = {.lex_state = 63, .external_lex_state = 53},
  [8106] = {.lex_state = 63, .external_lex_state = 48},
  [8107] = {.lex_state = 63, .external_lex_state = 51},
  [8108] = {.lex_state = 52, .external_lex_state = 28},
  [8109] = {.lex_state = 52, .external_lex_state = 28},
  [8110] = {.lex_state = 52, .external_lex_state = 28},
  [8111] = {.lex_state = 63, .external_lex_state = 58},
  [8112] = {.lex_state = 58, .external_lex_state = 32},
  [8113] = {.lex_state = 52, .external_lex_state = 28},
  [8114] = {.lex_state = 62, .external_lex_state = 43},
  [8115] = {.lex_state = 61, .external_lex_state = 36},
  [8116] = {.lex_state = 63, .external_lex_state = 51},
  [8117] = {.lex_state = 61, .external_lex_state = 36},
  [8118] = {.lex_state = 62, .external_lex_state = 43},
  [8119] = {.lex_state = 63, .external_lex_state = 51},
  [8120] = {.lex_state = 52, .external_lex_state = 31},
  [8121] = {.lex_state = 62, .external_lex_state = 43},
  [8122] = {.lex_state = 63, .external_lex_state = 29},
  [8123] = {.lex_state = 58, .external_lex_state = 30},
  [8124] = {.lex_state = 52, .external_lex_state = 23},
  [8125] = {.lex_state = 63, .external_lex_state = 45},
  [8126] = {.lex_state = 58, .external_lex_state = 32},
  [8127] = {.lex_state = 65, .external_lex_state = 27},
  [8128] = {.lex_state = 58, .external_lex_state = 32},
  [8129] = {.lex_state = 63, .external_lex_state = 51},
  [8130] = {.lex_state = 56, .external_lex_state = 40},
  [8131] = {.lex_state = 52, .external_lex_state = 53},
  [8132] = {.lex_state = 63, .external_lex_state = 51},
  [8133] = {.lex_state = 63, .external_lex_state = 27},
  [8134] = {.lex_state = 61, .external_lex_state = 35},
  [8135] = {.lex_state = 61, .external_lex_state = 35},
  [8136] = {.lex_state = 63, .external_lex_state = 51},
  [8137] = {.lex_state = 63},
  [8138] = {.lex_state = 63, .external_lex_state = 51},
  [8139] = {.lex_state = 63, .external_lex_state = 49},
  [8140] = {.lex_state = 63, .external_lex_state = 49},
  [8141] = {.lex_state = 54},
  [8142] = {.lex_state = 63, .external_lex_state = 49},
  [8143] = {.lex_state = 57, .external_lex_state = 34},
  [8144] = {.lex_state = 63, .external_lex_state = 45},
  [8145] = {.lex_state = 57},
  [8146] = {.lex_state = 63, .external_lex_state = 45},
  [8147] = {.lex_state = 52, .external_lex_state = 32},
  [8148] = {.lex_state = 9, .external_lex_state = 43},
  [8149] = {.lex_state = 10, .external_lex_state = 43},
  [8150] = {.lex_state = 57, .external_lex_state = 32},
  [8151] = {.lex_state = 63, .external_lex_state = 49},
  [8152] = {.lex_state = 10, .external_lex_state = 43},
  [8153] = {.lex_state = 61, .external_lex_state = 35},
  [8154] = {.lex_state = 63, .external_lex_state = 49},
  [8155] = {.lex_state = 61, .external_lex_state = 35},
  [8156] = {.lex_state = 63, .external_lex_state = 45},
  [8157] = {.lex_state = 63, .external_lex_state = 45},
  [8158] = {.lex_state = 63},
  [8159] = {.lex_state = 63, .external_lex_state = 48},
  [8160] = {.lex_state = 63, .external_lex_state = 48},
  [8161] = {.lex_state = 61, .external_lex_state = 51},
  [8162] = {.lex_state = 63, .external_lex_state = 45},
  [8163] = {.lex_state = 63, .external_lex_state = 23},
  [8164] = {.lex_state = 52, .external_lex_state = 26},
  [8165] = {.lex_state = 62, .external_lex_state = 43},
  [8166] = {.lex_state = 63, .external_lex_state = 48},
  [8167] = {.lex_state = 63, .external_lex_state = 48},
  [8168] = {.lex_state = 58, .external_lex_state = 40},
  [8169] = {.lex_state = 52, .external_lex_state = 44},
  [8170] = {.lex_state = 57, .external_lex_state = 34},
  [8171] = {.lex_state = 63, .external_lex_state = 48},
  [8172] = {.lex_state = 61, .external_lex_state = 36},
  [8173] = {.lex_state = 63, .external_lex_state = 49},
  [8174] = {.lex_state = 58, .external_lex_state = 34},
  [8175] = {.lex_state = 63, .external_lex_state = 49},
  [8176] = {.lex_state = 61, .external_lex_state = 36},
  [8177] = {.lex_state = 63, .external_lex_state = 48},
  [8178] = {.lex_state = 58, .external_lex_state = 30},
  [8179] = {.lex_state = 63, .external_lex_state = 48},
  [8180] = {.lex_state = 57, .external_lex_state = 34},
  [8181] = {.lex_state = 63, .external_lex_state = 48},
  [8182] = {.lex_state = 63, .external_lex_state = 45},
  [8183] = {.lex_state = 52, .external_lex_state = 55},
  [8184] = {.lex_state = 63, .external_lex_state = 45},
  [8185] = {.lex_state = 17, .external_lex_state = 43},
  [8186] = {.lex_state = 9, .external_lex_state = 43},
  [8187] = {.lex_state = 63, .external_lex_state = 51},
  [8188] = {.lex_state = 52, .external_lex_state = 46},
  [8189] = {.lex_state = 61, .external_lex_state = 36},
  [8190] = {.lex_state = 52, .external_lex_state = 28},
  [8191] = {.lex_state = 63, .external_lex_state = 49},
  [8192] = {.lex_state = 57},
  [8193] = {.lex_state = 63, .external_lex_state = 48},
  [8194] = {.lex_state = 63},
  [8195] = {.lex_state = 63},
  [8196] = {.lex_state = 63},
  [8197] = {.lex_state = 52, .external_lex_state = 23},
  [8198] = {.lex_state = 56, .external_lex_state = 34},
  [8199] = {.lex_state = 20, .external_lex_state = 43},
  [8200] = {.lex_state = 63, .external_lex_state = 51},
  [8201] = {.lex_state = 57, .external_lex_state = 34},
  [8202] = {.lex_state = 58, .external_lex_state = 34},
  [8203] = {.lex_state = 57, .external_lex_state = 34},
  [8204] = {.lex_state = 63, .external_lex_state = 48},
  [8205] = {.lex_state = 63, .external_lex_state = 48},
  [8206] = {.lex_state = 63, .external_lex_state = 51},
  [8207] = {.lex_state = 61, .external_lex_state = 48},
  [8208] = {.lex_state = 61, .external_lex_state = 43},
  [8209] = {.lex_state = 63, .external_lex_state = 51},
  [8210] = {.lex_state = 63, .external_lex_state = 45},
  [8211] = {.lex_state = 63, .external_lex_state = 51},
  [8212] = {.lex_state = 52, .external_lex_state = 54},
  [8213] = {.lex_state = 62, .external_lex_state = 53},
  [8214] = {.lex_state = 61, .external_lex_state = 52},
  [8215] = {.lex_state = 58, .external_lex_state = 32},
  [8216] = {.lex_state = 52, .external_lex_state = 42},
  [8217] = {.lex_state = 63, .external_lex_state = 49},
  [8218] = {.lex_state = 63, .external_lex_state = 45},
  [8219] = {.lex_state = 20, .external_lex_state = 43},
  [8220] = {.lex_state = 63, .external_lex_state = 51},
  [8221] = {.lex_state = 57, .external_lex_state = 34},
  [8222] = {.lex_state = 63, .external_lex_state = 45},
  [8223] = {.lex_state = 63, .external_lex_state = 49},
  [8224] = {.lex_state = 63, .external_lex_state = 49},
  [8225] = {.lex_state = 62, .external_lex_state = 40},
  [8226] = {.lex_state = 52, .external_lex_state = 30},
  [8227] = {.lex_state = 11, .external_lex_state = 43},
  [8228] = {.lex_state = 63, .external_lex_state = 49},
  [8229] = {.lex_state = 63, .external_lex_state = 45},
  [8230] = {.lex_state = 52, .external_lex_state = 23},
  [8231] = {.lex_state = 61, .external_lex_state = 40},
  [8232] = {.lex_state = 63, .external_lex_state = 30},
  [8233] = {.lex_state = 52, .external_lex_state = 23},
  [8234] = {.lex_state = 56, .external_lex_state = 40},
  [8235] = {.lex_state = 63, .external_lex_state = 45},
  [8236] = {.lex_state = 61, .external_lex_state = 37},
  [8237] = {.lex_state = 63, .external_lex_state = 48},
  [8238] = {.lex_state = 63},
  [8239] = {.lex_state = 63, .external_lex_state = 45},
  [8240] = {.lex_state = 52, .external_lex_state = 40},
  [8241] = {.lex_state = 63, .external_lex_state = 48},
  [8242] = {.lex_state = 56, .external_lex_state = 34},
  [8243] = {.lex_state = 61, .external_lex_state = 36},
  [8244] = {.lex_state = 63, .external_lex_state = 49},
  [8245] = {.lex_state = 63, .external_lex_state = 49},
  [8246] = {.lex_state = 52, .external_lex_state = 23},
  [8247] = {.lex_state = 52, .external_lex_state = 28},
  [8248] = {.lex_state = 61, .external_lex_state = 37},
  [8249] = {.lex_state = 61, .external_lex_state = 52},
  [8250] = {.lex_state = 52, .external_lex_state = 39},
  [8251] = {.lex_state = 58, .external_lex_state = 34},
  [8252] = {.lex_state = 52, .external_lex_state = 23},
  [8253] = {.lex_state = 63, .external_lex_state = 29},
  [8254] = {.lex_state = 56, .external_lex_state = 40},
  [8255] = {.lex_state = 59, .external_lex_state = 40},
  [8256] = {.lex_state = 63, .external_lex_state = 27},
  [8257] = {.lex_state = 52, .external_lex_state = 23},
  [8258] = {.lex_state = 63, .external_lex_state = 45},
  [8259] = {.lex_state = 56, .external_lex_state = 40},
  [8260] = {.lex_state = 63, .external_lex_state = 49},
  [8261] = {.lex_state = 61, .external_lex_state = 37},
  [8262] = {.lex_state = 63, .external_lex_state = 40},
  [8263] = {.lex_state = 63, .external_lex_state = 51},
  [8264] = {.lex_state = 52, .external_lex_state = 44},
  [8265] = {.lex_state = 56, .external_lex_state = 40},
  [8266] = {.lex_state = 63, .external_lex_state = 49},
  [8267] = {.lex_state = 63, .external_lex_state = 29},
  [8268] = {.lex_state = 61, .external_lex_state = 34},
  [8269] = {.lex_state = 56, .external_lex_state = 32},
  [8270] = {.lex_state = 61, .external_lex_state = 35},
  [8271] = {.lex_state = 52, .external_lex_state = 48},
  [8272] = {.lex_state = 63, .external_lex_state = 30},
  [8273] = {.lex_state = 63, .external_lex_state = 49},
  [8274] = {.lex_state = 63, .external_lex_state = 29},
  [8275] = {.lex_state = 58, .external_lex_state = 34},
  [8276] = {.lex_state = 56, .external_lex_state = 32},
  [8277] = {.lex_state = 63, .external_lex_state = 35},
  [8278] = {.lex_state = 63, .external_lex_state = 49},
  [8279] = {.lex_state = 52, .external_lex_state = 28},
  [8280] = {.lex_state = 63, .external_lex_state = 45},
  [8281] = {.lex_state = 52, .external_lex_state = 34},
  [8282] = {.lex_state = 63, .external_lex_state = 56},
  [8283] = {.lex_state = 52, .external_lex_state = 40},
  [8284] = {.lex_state = 63, .external_lex_state = 54},
  [8285] = {.lex_state = 58, .external_lex_state = 34},
  [8286] = {.lex_state = 52, .external_lex_state = 31},
  [8287] = {.lex_state = 57},
  [8288] = {.lex_state = 52, .external_lex_state = 52},
  [8289] = {.lex_state = 52, .external_lex_state = 31},
  [8290] = {.lex_state = 63, .external_lex_state = 49},
  [8291] = {.lex_state = 52, .external_lex_state = 23},
  [8292] = {.lex_state = 63, .external_lex_state = 27},
  [8293] = {.lex_state = 65, .external_lex_state = 27},
  [8294] = {.lex_state = 61, .external_lex_state = 30},
  [8295] = {.lex_state = 52, .external_lex_state = 31},
  [8296] = {.lex_state = 52, .external_lex_state = 23},
  [8297] = {.lex_state = 63, .external_lex_state = 49},
  [8298] = {.lex_state = 61, .external_lex_state = 37},
  [8299] = {.lex_state = 52, .external_lex_state = 34},
  [8300] = {.lex_state = 63, .external_lex_state = 45},
  [8301] = {.lex_state = 61, .external_lex_state = 37},
  [8302] = {.lex_state = 61, .external_lex_state = 35},
  [8303] = {.lex_state = 57, .external_lex_state = 32},
  [8304] = {.lex_state = 58, .external_lex_state = 34},
  [8305] = {.lex_state = 52, .external_lex_state = 31},
  [8306] = {.lex_state = 52, .external_lex_state = 32},
  [8307] = {.lex_state = 63, .external_lex_state = 55},
  [8308] = {.lex_state = 64, .external_lex_state = 53},
  [8309] = {.lex_state = 52, .external_lex_state = 31},
  [8310] = {.lex_state = 61, .external_lex_state = 53},
  [8311] = {.lex_state = 59, .external_lex_state = 40},
  [8312] = {.lex_state = 52, .external_lex_state = 31},
  [8313] = {.lex_state = 63, .external_lex_state = 45},
  [8314] = {.lex_state = 63, .external_lex_state = 49},
  [8315] = {.lex_state = 63, .external_lex_state = 52},
  [8316] = {.lex_state = 63, .external_lex_state = 51},
  [8317] = {.lex_state = 63, .external_lex_state = 39},
  [8318] = {.lex_state = 63, .external_lex_state = 36},
  [8319] = {.lex_state = 63, .external_lex_state = 37},
  [8320] = {.lex_state = 3},
  [8321] = {.lex_state = 63, .external_lex_state = 49},
  [8322] = {.lex_state = 52, .external_lex_state = 28},
  [8323] = {.lex_state = 63, .external_lex_state = 49},
  [8324] = {.lex_state = 11, .external_lex_state = 43},
  [8325] = {.lex_state = 52},
  [8326] = {.lex_state = 63, .external_lex_state = 45},
  [8327] = {.lex_state = 63, .external_lex_state = 49},
  [8328] = {.lex_state = 63, .external_lex_state = 54},
  [8329] = {.lex_state = 52, .external_lex_state = 31},
  [8330] = {.lex_state = 58, .external_lex_state = 40},
  [8331] = {.lex_state = 52, .external_lex_state = 31},
  [8332] = {.lex_state = 57, .external_lex_state = 34},
  [8333] = {.lex_state = 52, .external_lex_state = 23},
  [8334] = {.lex_state = 65, .external_lex_state = 27},
  [8335] = {.lex_state = 63, .external_lex_state = 51},
  [8336] = {.lex_state = 52, .external_lex_state = 55},
  [8337] = {.lex_state = 52, .external_lex_state = 46},
  [8338] = {.lex_state = 52, .external_lex_state = 36},
  [8339] = {.lex_state = 63},
  [8340] = {.lex_state = 63, .external_lex_state = 43},
  [8341] = {.lex_state = 52, .external_lex_state = 28},
  [8342] = {.lex_state = 58, .external_lex_state = 32},
  [8343] = {.lex_state = 63},
  [8344] = {.lex_state = 61, .external_lex_state = 34},
  [8345] = {.lex_state = 63, .external_lex_state = 49},
  [8346] = {.lex_state = 61, .external_lex_state = 37},
  [8347] = {.lex_state = 63, .external_lex_state = 49},
  [8348] = {.lex_state = 52, .external_lex_state = 35},
  [8349] = {.lex_state = 62, .external_lex_state = 40},
  [8350] = {.lex_state = 52, .external_lex_state = 37},
  [8351] = {.lex_state = 61, .external_lex_state = 35},
  [8352] = {.lex_state = 52, .external_lex_state = 31},
  [8353] = {.lex_state = 63, .external_lex_state = 45},
  [8354] = {.lex_state = 63, .external_lex_state = 45},
  [8355] = {.lex_state = 63, .external_lex_state = 48},
  [8356] = {.lex_state = 9, .external_lex_state = 43},
  [8357] = {.lex_state = 63, .external_lex_state = 26},
  [8358] = {.lex_state = 63, .external_lex_state = 48},
  [8359] = {.lex_state = 57, .external_lex_state = 32},
  [8360] = {.lex_state = 9, .external_lex_state = 43},
  [8361] = {.lex_state = 64, .external_lex_state = 40},
  [8362] = {.lex_state = 56, .external_lex_state = 40},
  [8363] = {.lex_state = 52, .external_lex_state = 30},
  [8364] = {.lex_state = 61, .external_lex_state = 54},
  [8365] = {.lex_state = 61, .external_lex_state = 37},
  [8366] = {.lex_state = 64, .external_lex_state = 40},
  [8367] = {.lex_state = 63, .external_lex_state = 40},
  [8368] = {.lex_state = 61, .external_lex_state = 37},
  [8369] = {.lex_state = 61, .external_lex_state = 32},
  [8370] = {.lex_state = 57},
  [8371] = {.lex_state = 58, .external_lex_state = 59},
  [8372] = {.lex_state = 63, .external_lex_state = 49},
  [8373] = {.lex_state = 63, .external_lex_state = 48},
  [8374] = {.lex_state = 63, .external_lex_state = 52},
  [8375] = {.lex_state = 63, .external_lex_state = 48},
  [8376] = {.lex_state = 63, .external_lex_state = 36},
  [8377] = {.lex_state = 58, .external_lex_state = 32},
  [8378] = {.lex_state = 63, .external_lex_state = 45},
  [8379] = {.lex_state = 57, .external_lex_state = 32},
  [8380] = {.lex_state = 63, .external_lex_state = 48},
  [8381] = {.lex_state = 61, .external_lex_state = 34},
  [8382] = {.lex_state = 20, .external_lex_state = 43},
  [8383] = {.lex_state = 52, .external_lex_state = 23},
  [8384] = {.lex_state = 52, .external_lex_state = 28},
  [8385] = {.lex_state = 63, .external_lex_state = 51},
  [8386] = {.lex_state = 57, .external_lex_state = 34},
  [8387] = {.lex_state = 63, .external_lex_state = 45},
  [8388] = {.lex_state = 57, .external_lex_state = 32},
  [8389] = {.lex_state = 61, .external_lex_state = 32},
  [8390] = {.lex_state = 63},
  [8391] = {.lex_state = 63, .external_lex_state = 29},
  [8392] = {.lex_state = 63, .external_lex_state = 30},
  [8393] = {.lex_state = 52, .external_lex_state = 23},
  [8394] = {.lex_state = 61, .external_lex_state = 32},
  [8395] = {.lex_state = 52, .external_lex_state = 31},
  [8396] = {.lex_state = 52, .external_lex_state = 28},
  [8397] = {.lex_state = 65, .external_lex_state = 27},
  [8398] = {.lex_state = 63, .external_lex_state = 51},
  [8399] = {.lex_state = 63, .external_lex_state = 51},
  [8400] = {.lex_state = 63, .external_lex_state = 45},
  [8401] = {.lex_state = 18},
  [8402] = {.lex_state = 63, .external_lex_state = 35},
  [8403] = {.lex_state = 57, .external_lex_state = 32},
  [8404] = {.lex_state = 63, .external_lex_state = 48},
  [8405] = {.lex_state = 52, .external_lex_state = 23},
  [8406] = {.lex_state = 61, .external_lex_state = 34},
  [8407] = {.lex_state = 63, .external_lex_state = 49},
  [8408] = {.lex_state = 63, .external_lex_state = 51},
  [8409] = {.lex_state = 57, .external_lex_state = 32},
  [8410] = {.lex_state = 52, .external_lex_state = 50},
  [8411] = {.lex_state = 63, .external_lex_state = 51},
  [8412] = {.lex_state = 63, .external_lex_state = 30},
  [8413] = {.lex_state = 52, .external_lex_state = 30},
  [8414] = {.lex_state = 52, .external_lex_state = 23},
  [8415] = {.lex_state = 61, .external_lex_state = 54},
  [8416] = {.lex_state = 64, .external_lex_state = 40},
  [8417] = {.lex_state = 61, .external_lex_state = 36},
  [8418] = {.lex_state = 63, .external_lex_state = 48},
  [8419] = {.lex_state = 63, .external_lex_state = 45},
  [8420] = {.lex_state = 63, .external_lex_state = 27},
  [8421] = {.lex_state = 52, .external_lex_state = 23},
  [8422] = {.lex_state = 52, .external_lex_state = 28},
  [8423] = {.lex_state = 63, .external_lex_state = 24},
  [8424] = {.lex_state = 63, .external_lex_state = 45},
  [8425] = {.lex_state = 56, .external_lex_state = 40},
  [8426] = {.lex_state = 63, .external_lex_state = 49},
  [8427] = {.lex_state = 63, .external_lex_state = 51},
  [8428] = {.lex_state = 52, .external_lex_state = 29},
  [8429] = {.lex_state = 63, .external_lex_state = 51},
  [8430] = {.lex_state = 63, .external_lex_state = 26},
  [8431] = {.lex_state = 9, .external_lex_state = 43},
  [8432] = {.lex_state = 57, .external_lex_state = 32},
  [8433] = {.lex_state = 63, .external_lex_state = 48},
  [8434] = {.lex_state = 3},
  [8435] = {.lex_state = 63},
  [8436] = {.lex_state = 63, .external_lex_state = 45},
  [8437] = {.lex_state = 63, .external_lex_state = 45},
  [8438] = {.lex_state = 52, .external_lex_state = 47},
  [8439] = {.lex_state = 61, .external_lex_state = 30},
  [8440] = {.lex_state = 63, .external_lex_state = 49},
  [8441] = {.lex_state = 9, .external_lex_state = 43},
  [8442] = {.lex_state = 63, .external_lex_state = 48},
  [8443] = {.lex_state = 3},
  [8444] = {.lex_state = 63, .external_lex_state = 43},
  [8445] = {.lex_state = 63, .external_lex_state = 48},
  [8446] = {.lex_state = 58, .external_lex_state = 32},
  [8447] = {.lex_state = 61, .external_lex_state = 35},
  [8448] = {.lex_state = 63, .external_lex_state = 48},
  [8449] = {.lex_state = 57},
  [8450] = {.lex_state = 9, .external_lex_state = 43},
  [8451] = {.lex_state = 63, .external_lex_state = 48},
  [8452] = {.lex_state = 58, .external_lex_state = 32},
  [8453] = {.lex_state = 9, .external_lex_state = 43},
  [8454] = {.lex_state = 63, .external_lex_state = 56},
  [8455] = {.lex_state = 52, .external_lex_state = 28},
  [8456] = {.lex_state = 63, .external_lex_state = 57},
  [8457] = {.lex_state = 57, .external_lex_state = 34},
  [8458] = {.lex_state = 58, .external_lex_state = 40},
  [8459] = {.lex_state = 61, .external_lex_state = 37},
  [8460] = {.lex_state = 9, .external_lex_state = 43},
  [8461] = {.lex_state = 54},
  [8462] = {.lex_state = 61, .external_lex_state = 37},
  [8463] = {.lex_state = 58, .external_lex_state = 34},
  [8464] = {.lex_state = 57, .external_lex_state = 32},
  [8465] = {.lex_state = 58, .external_lex_state = 32},
  [8466] = {.lex_state = 57, .external_lex_state = 34},
  [8467] = {.lex_state = 63, .external_lex_state = 45},
  [8468] = {.lex_state = 52, .external_lex_state = 53},
  [8469] = {.lex_state = 9, .external_lex_state = 43},
  [8470] = {.lex_state = 52, .external_lex_state = 28},
  [8471] = {.lex_state = 57, .external_lex_state = 34},
  [8472] = {.lex_state = 63, .external_lex_state = 49},
  [8473] = {.lex_state = 63, .external_lex_state = 51},
  [8474] = {.lex_state = 52, .external_lex_state = 58},
  [8475] = {.lex_state = 52},
  [8476] = {.lex_state = 3},
  [8477] = {.lex_state = 52, .external_lex_state = 31},
  [8478] = {.lex_state = 57},
  [8479] = {.lex_state = 63},
  [8480] = {.lex_state = 63, .external_lex_state = 48},
  [8481] = {.lex_state = 57, .external_lex_state = 34},
  [8482] = {.lex_state = 63, .external_lex_state = 48},
  [8483] = {.lex_state = 9, .external_lex_state = 43},
  [8484] = {.lex_state = 63, .external_lex_state = 36},
  [8485] = {.lex_state = 61, .external_lex_state = 26},
  [8486] = {.lex_state = 63, .external_lex_state = 51},
  [8487] = {.lex_state = 63, .external_lex_state = 51},
  [8488] = {.lex_state = 61, .external_lex_state = 36},
  [8489] = {.lex_state = 57, .external_lex_state = 32},
  [8490] = {.lex_state = 63, .external_lex_state = 51},
  [8491] = {.lex_state = 61, .external_lex_state = 35},
  [8492] = {.lex_state = 63, .external_lex_state = 35},
  [8493] = {.lex_state = 63, .external_lex_state = 51},
  [8494] = {.lex_state = 64, .external_lex_state = 40},
  [8495] = {.lex_state = 63, .external_lex_state = 42},
  [8496] = {.lex_state = 63, .external_lex_state = 51},
  [8497] = {.lex_state = 58, .external_lex_state = 34},
  [8498] = {.lex_state = 52, .external_lex_state = 54},
  [8499] = {.lex_state = 63, .external_lex_state = 57},
  [8500] = {.lex_state = 63},
  [8501] = {.lex_state = 58, .external_lex_state = 32},
  [8502] = {.lex_state = 63},
  [8503] = {.lex_state = 52, .external_lex_state = 23},
  [8504] = {.lex_state = 63, .external_lex_state = 37},
  [8505] = {.lex_state = 63, .external_lex_state = 49},
  [8506] = {.lex_state = 63, .external_lex_state = 48},
  [8507] = {.lex_state = 63, .external_lex_state = 48},
  [8508] = {.lex_state = 63, .external_lex_state = 49},
  [8509] = {.lex_state = 61, .external_lex_state = 37},
  [8510] = {.lex_state = 52, .external_lex_state = 28},
  [8511] = {.lex_state = 63, .external_lex_state = 48},
  [8512] = {.lex_state = 61, .external_lex_state = 53},
  [8513] = {.lex_state = 58, .external_lex_state = 32},
  [8514] = {.lex_state = 58, .external_lex_state = 40},
  [8515] = {.lex_state = 63, .external_lex_state = 48},
  [8516] = {.lex_state = 63, .external_lex_state = 48},
  [8517] = {.lex_state = 61, .external_lex_state = 36},
  [8518] = {.lex_state = 63, .external_lex_state = 48},
  [8519] = {.lex_state = 61, .external_lex_state = 37},
  [8520] = {.lex_state = 58, .external_lex_state = 32},
  [8521] = {.lex_state = 61, .external_lex_state = 37},
  [8522] = {.lex_state = 63, .external_lex_state = 51},
  [8523] = {.lex_state = 57, .external_lex_state = 32},
  [8524] = {.lex_state = 63, .external_lex_state = 48},
  [8525] = {.lex_state = 58, .external_lex_state = 32},
  [8526] = {.lex_state = 63, .external_lex_state = 51},
  [8527] = {.lex_state = 64, .external_lex_state = 40},
  [8528] = {.lex_state = 52, .external_lex_state = 50},
  [8529] = {.lex_state = 63, .external_lex_state = 45},
  [8530] = {.lex_state = 10, .external_lex_state = 43},
  [8531] = {.lex_state = 58, .external_lex_state = 34},
  [8532] = {.lex_state = 63, .external_lex_state = 42},
  [8533] = {.lex_state = 63, .external_lex_state = 49},
  [8534] = {.lex_state = 56, .external_lex_state = 40},
  [8535] = {.lex_state = 63, .external_lex_state = 51},
  [8536] = {.lex_state = 63, .external_lex_state = 51},
  [8537] = {.lex_state = 61, .external_lex_state = 35},
  [8538] = {.lex_state = 63, .external_lex_state = 48},
  [8539] = {.lex_state = 63},
  [8540] = {.lex_state = 57, .external_lex_state = 32},
  [8541] = {.lex_state = 3},
  [8542] = {.lex_state = 63, .external_lex_state = 49},
  [8543] = {.lex_state = 58, .external_lex_state = 40},
  [8544] = {.lex_state = 63, .external_lex_state = 48},
  [8545] = {.lex_state = 57, .external_lex_state = 34},
  [8546] = {.lex_state = 56, .external_lex_state = 40},
  [8547] = {.lex_state = 63, .external_lex_state = 51},
  [8548] = {.lex_state = 58, .external_lex_state = 40},
  [8549] = {.lex_state = 63, .external_lex_state = 51},
  [8550] = {.lex_state = 63, .external_lex_state = 51},
  [8551] = {.lex_state = 52, .external_lex_state = 31},
  [8552] = {.lex_state = 63, .external_lex_state = 49},
  [8553] = {.lex_state = 63, .external_lex_state = 45},
  [8554] = {.lex_state = 58, .external_lex_state = 40},
  [8555] = {.lex_state = 63, .external_lex_state = 49},
  [8556] = {.lex_state = 63, .external_lex_state = 45},
  [8557] = {.lex_state = 63, .external_lex_state = 43},
  [8558] = {.lex_state = 61, .external_lex_state = 49},
  [8559] = {.lex_state = 63, .external_lex_state = 51},
  [8560] = {.lex_state = 3},
  [8561] = {.lex_state = 63, .external_lex_state = 53},
  [8562] = {.lex_state = 58, .external_lex_state = 34},
  [8563] = {.lex_state = 64, .external_lex_state = 40},
  [8564] = {.lex_state = 63, .external_lex_state = 51},
  [8565] = {.lex_state = 63, .external_lex_state = 49},
  [8566] = {.lex_state = 62, .external_lex_state = 53},
  [8567] = {.lex_state = 58, .external_lex_state = 40},
  [8568] = {.lex_state = 63, .external_lex_state = 48},
  [8569] = {.lex_state = 56, .external_lex_state = 32},
  [8570] = {.lex_state = 63, .external_lex_state = 45},
  [8571] = {.lex_state = 63, .external_lex_state = 53},
  [8572] = {.lex_state = 52, .external_lex_state = 57},
  [8573] = {.lex_state = 63, .external_lex_state = 48},
  [8574] = {.lex_state = 58, .external_lex_state = 40},
  [8575] = {.lex_state = 57, .external_lex_state = 34},
  [8576] = {.lex_state = 63, .external_lex_state = 51},
  [8577] = {.lex_state = 63, .external_lex_state = 49},
  [8578] = {.lex_state = 57, .external_lex_state = 32},
  [8579] = {.lex_state = 63, .external_lex_state = 53},
  [8580] = {.lex_state = 58, .external_lex_state = 40},
  [8581] = {.lex_state = 52, .external_lex_state = 52},
  [8582] = {.lex_state = 57},
  [8583] = {.lex_state = 63, .external_lex_state = 45},
  [8584] = {.lex_state = 58, .external_lex_state = 40},
  [8585] = {.lex_state = 63, .external_lex_state = 48},
  [8586] = {.lex_state = 63, .external_lex_state = 45},
  [8587] = {.lex_state = 9, .external_lex_state = 43},
  [8588] = {.lex_state = 63, .external_lex_state = 48},
  [8589] = {.lex_state = 3},
  [8590] = {.lex_state = 63, .external_lex_state = 48},
  [8591] = {.lex_state = 64, .external_lex_state = 53},
  [8592] = {.lex_state = 3},
  [8593] = {.lex_state = 63, .external_lex_state = 40},
  [8594] = {.lex_state = 58, .external_lex_state = 34},
  [8595] = {.lex_state = 56, .external_lex_state = 34},
  [8596] = {.lex_state = 63, .external_lex_state = 48},
  [8597] = {.lex_state = 57, .external_lex_state = 32},
  [8598] = {.lex_state = 61, .external_lex_state = 35},
  [8599] = {.lex_state = 63, .external_lex_state = 45},
  [8600] = {.lex_state = 63, .external_lex_state = 49},
  [8601] = {.lex_state = 63, .external_lex_state = 45},
  [8602] = {.lex_state = 61, .external_lex_state = 26},
  [8603] = {.lex_state = 63, .external_lex_state = 45},
  [8604] = {.lex_state = 61, .external_lex_state = 32},
  [8605] = {.lex_state = 62, .external_lex_state = 40},
  [8606] = {.lex_state = 61, .external_lex_state = 29},
  [8607] = {.lex_state = 63, .external_lex_state = 48},
  [8608] = {.lex_state = 63, .external_lex_state = 49},
  [8609] = {.lex_state = 63, .external_lex_state = 49},
  [8610] = {.lex_state = 63, .external_lex_state = 49},
  [8611] = {.lex_state = 63, .external_lex_state = 45},
  [8612] = {.lex_state = 63, .external_lex_state = 58},
  [8613] = {.lex_state = 63, .external_lex_state = 49},
  [8614] = {.lex_state = 61, .external_lex_state = 40},
  [8615] = {.lex_state = 57, .external_lex_state = 34},
  [8616] = {.lex_state = 65, .external_lex_state = 27},
  [8617] = {.lex_state = 63, .external_lex_state = 53},
  [8618] = {.lex_state = 52, .external_lex_state = 29},
  [8619] = {.lex_state = 52, .external_lex_state = 31},
  [8620] = {.lex_state = 56, .external_lex_state = 40},
  [8621] = {.lex_state = 63, .external_lex_state = 45},
  [8622] = {.lex_state = 57},
  [8623] = {.lex_state = 63, .external_lex_state = 55},
  [8624] = {.lex_state = 64, .external_lex_state = 53},
  [8625] = {.lex_state = 63, .external_lex_state = 30},
  [8626] = {.lex_state = 56, .external_lex_state = 40},
  [8627] = {.lex_state = 63, .external_lex_state = 45},
  [8628] = {.lex_state = 61, .external_lex_state = 45},
  [8629] = {.lex_state = 3},
  [8630] = {.lex_state = 62, .external_lex_state = 40},
  [8631] = {.lex_state = 52, .external_lex_state = 26},
  [8632] = {.lex_state = 63, .external_lex_state = 45},
  [8633] = {.lex_state = 9, .external_lex_state = 43},
  [8634] = {.lex_state = 61, .external_lex_state = 36},
  [8635] = {.lex_state = 57},
  [8636] = {.lex_state = 63, .external_lex_state = 49},
  [8637] = {.lex_state = 10, .external_lex_state = 43},
  [8638] = {.lex_state = 57},
  [8639] = {.lex_state = 61, .external_lex_state = 55},
  [8640] = {.lex_state = 58, .external_lex_state = 29},
  [8641] = {.lex_state = 61, .external_lex_state = 35},
  [8642] = {.lex_state = 61, .external_lex_state = 35},
  [8643] = {.lex_state = 56, .external_lex_state = 40},
  [8644] = {.lex_state = 63, .external_lex_state = 51},
  [8645] = {.lex_state = 52, .external_lex_state = 31},
  [8646] = {.lex_state = 63, .external_lex_state = 27},
  [8647] = {.lex_state = 19, .external_lex_state = 43},
  [8648] = {.lex_state = 63, .external_lex_state = 30},
  [8649] = {.lex_state = 64, .external_lex_state = 53},
  [8650] = {.lex_state = 57},
  [8651] = {.lex_state = 52, .external_lex_state = 31},
  [8652] = {.lex_state = 57, .external_lex_state = 32},
  [8653] = {.lex_state = 63, .external_lex_state = 56},
  [8654] = {.lex_state = 61, .external_lex_state = 35},
  [8655] = {.lex_state = 52, .external_lex_state = 29},
  [8656] = {.lex_state = 52},
  [8657] = {.lex_state = 52, .external_lex_state = 31},
  [8658] = {.lex_state = 52, .external_lex_state = 28},
  [8659] = {.lex_state = 19, .external_lex_state = 43},
  [8660] = {.lex_state = 63, .external_lex_state = 48},
  [8661] = {.lex_state = 57},
  [8662] = {.lex_state = 54},
  [8663] = {.lex_state = 52, .external_lex_state = 28},
  [8664] = {.lex_state = 61, .external_lex_state = 36},
  [8665] = {.lex_state = 56, .external_lex_state = 40},
  [8666] = {.lex_state = 63, .external_lex_state = 45},
  [8667] = {.lex_state = 63, .external_lex_state = 49},
  [8668] = {.lex_state = 63, .external_lex_state = 53},
  [8669] = {.lex_state = 3},
  [8670] = {.lex_state = 63, .external_lex_state = 45},
  [8671] = {.lex_state = 58, .external_lex_state = 29},
  [8672] = {.lex_state = 52, .external_lex_state = 24},
  [8673] = {.lex_state = 58, .external_lex_state = 40},
  [8674] = {.lex_state = 62, .external_lex_state = 40},
  [8675] = {.lex_state = 63, .external_lex_state = 29},
  [8676] = {.lex_state = 52, .external_lex_state = 29},
  [8677] = {.lex_state = 58, .external_lex_state = 40},
  [8678] = {.lex_state = 63, .external_lex_state = 48},
  [8679] = {.lex_state = 52, .external_lex_state = 37},
  [8680] = {.lex_state = 58, .external_lex_state = 34},
  [8681] = {.lex_state = 52, .external_lex_state = 23},
  [8682] = {.lex_state = 61, .external_lex_state = 29},
  [8683] = {.lex_state = 63, .external_lex_state = 45},
  [8684] = {.lex_state = 63, .external_lex_state = 48},
  [8685] = {.lex_state = 63, .external_lex_state = 40},
  [8686] = {.lex_state = 63, .external_lex_state = 45},
  [8687] = {.lex_state = 52, .external_lex_state = 57},
  [8688] = {.lex_state = 63, .external_lex_state = 51},
  [8689] = {.lex_state = 61, .external_lex_state = 37},
  [8690] = {.lex_state = 52, .external_lex_state = 28},
  [8691] = {.lex_state = 21, .external_lex_state = 43},
  [8692] = {.lex_state = 61, .external_lex_state = 36},
  [8693] = {.lex_state = 57, .external_lex_state = 32},
  [8694] = {.lex_state = 63, .external_lex_state = 43},
  [8695] = {.lex_state = 52, .external_lex_state = 24},
  [8696] = {.lex_state = 52, .external_lex_state = 47},
  [8697] = {.lex_state = 62, .external_lex_state = 40},
  [8698] = {.lex_state = 61, .external_lex_state = 55},
  [8699] = {.lex_state = 62, .external_lex_state = 43},
  [8700] = {.lex_state = 63, .external_lex_state = 56},
  [8701] = {.lex_state = 52, .external_lex_state = 58},
  [8702] = {.lex_state = 57, .external_lex_state = 34},
  [8703] = {.lex_state = 58, .external_lex_state = 34},
  [8704] = {.lex_state = 57},
  [8705] = {.lex_state = 56, .external_lex_state = 40},
  [8706] = {.lex_state = 63, .external_lex_state = 51},
  [8707] = {.lex_state = 63, .external_lex_state = 43},
  [8708] = {.lex_state = 63, .external_lex_state = 51},
  [8709] = {.lex_state = 63, .external_lex_state = 51},
  [8710] = {.lex_state = 52, .external_lex_state = 45},
  [8711] = {.lex_state = 52, .external_lex_state = 30},
  [8712] = {.lex_state = 56, .external_lex_state = 40},
  [8713] = {.lex_state = 63, .external_lex_state = 57},
  [8714] = {.lex_state = 63, .external_lex_state = 27},
  [8715] = {.lex_state = 63},
  [8716] = {.lex_state = 63, .external_lex_state = 27},
  [8717] = {.lex_state = 61, .external_lex_state = 58},
  [8718] = {.lex_state = 63, .external_lex_state = 27},
  [8719] = {.lex_state = 63},
  [8720] = {.lex_state = 57, .external_lex_state = 40},
  [8721] = {.lex_state = 52, .external_lex_state = 35},
  [8722] = {.lex_state = 63, .external_lex_state = 57},
  [8723] = {.lex_state = 21},
  [8724] = {.lex_state = 63},
  [8725] = {.lex_state = 52, .external_lex_state = 40},
  [8726] = {.lex_state = 63},
  [8727] = {.lex_state = 52, .external_lex_state = 30},
  [8728] = {.lex_state = 63, .external_lex_state = 24},
  [8729] = {.lex_state = 63, .external_lex_state = 24},
  [8730] = {.lex_state = 63},
  [8731] = {.lex_state = 61, .external_lex_state = 32},
  [8732] = {.lex_state = 63, .external_lex_state = 53},
  [8733] = {.lex_state = 63, .external_lex_state = 24},
  [8734] = {.lex_state = 63, .external_lex_state = 56},
  [8735] = {.lex_state = 63},
  [8736] = {.lex_state = 61, .external_lex_state = 23},
  [8737] = {.lex_state = 52, .external_lex_state = 36},
  [8738] = {.lex_state = 9, .external_lex_state = 43},
  [8739] = {.lex_state = 61, .external_lex_state = 39},
  [8740] = {.lex_state = 52, .external_lex_state = 36},
  [8741] = {.lex_state = 63},
  [8742] = {.lex_state = 9, .external_lex_state = 43},
  [8743] = {.lex_state = 52, .external_lex_state = 35},
  [8744] = {.lex_state = 52, .external_lex_state = 36},
  [8745] = {.lex_state = 52, .external_lex_state = 35},
  [8746] = {.lex_state = 52, .external_lex_state = 35},
  [8747] = {.lex_state = 63, .external_lex_state = 27},
  [8748] = {.lex_state = 63},
  [8749] = {.lex_state = 63, .external_lex_state = 27},
  [8750] = {.lex_state = 52, .external_lex_state = 40},
  [8751] = {.lex_state = 52, .external_lex_state = 36},
  [8752] = {.lex_state = 3},
  [8753] = {.lex_state = 52, .external_lex_state = 36},
  [8754] = {.lex_state = 63, .external_lex_state = 27},
  [8755] = {.lex_state = 63},
  [8756] = {.lex_state = 52, .external_lex_state = 35},
  [8757] = {.lex_state = 63, .external_lex_state = 57},
  [8758] = {.lex_state = 63},
  [8759] = {.lex_state = 52, .external_lex_state = 51},
  [8760] = {.lex_state = 61, .external_lex_state = 42},
  [8761] = {.lex_state = 62, .external_lex_state = 53},
  [8762] = {.lex_state = 63, .external_lex_state = 57},
  [8763] = {.lex_state = 63, .external_lex_state = 58},
  [8764] = {.lex_state = 63, .external_lex_state = 57},
  [8765] = {.lex_state = 52, .external_lex_state = 36},
  [8766] = {.lex_state = 63, .external_lex_state = 58},
  [8767] = {.lex_state = 63},
  [8768] = {.lex_state = 63, .external_lex_state = 58},
  [8769] = {.lex_state = 63, .external_lex_state = 34},
  [8770] = {.lex_state = 65, .external_lex_state = 28},
  [8771] = {.lex_state = 63},
  [8772] = {.lex_state = 65, .external_lex_state = 28},
  [8773] = {.lex_state = 65, .external_lex_state = 28},
  [8774] = {.lex_state = 52, .external_lex_state = 30},
  [8775] = {.lex_state = 52, .external_lex_state = 43},
  [8776] = {.lex_state = 52, .external_lex_state = 40},
  [8777] = {.lex_state = 52, .external_lex_state = 35},
  [8778] = {.lex_state = 63},
  [8779] = {.lex_state = 63, .external_lex_state = 27},
  [8780] = {.lex_state = 52, .external_lex_state = 59},
  [8781] = {.lex_state = 52, .external_lex_state = 35},
  [8782] = {.lex_state = 63, .external_lex_state = 58},
  [8783] = {.lex_state = 52, .external_lex_state = 36},
  [8784] = {.lex_state = 63, .external_lex_state = 27},
  [8785] = {.lex_state = 63, .external_lex_state = 27},
  [8786] = {.lex_state = 63, .external_lex_state = 56},
  [8787] = {.lex_state = 52, .external_lex_state = 32},
  [8788] = {.lex_state = 52, .external_lex_state = 35},
  [8789] = {.lex_state = 63, .external_lex_state = 56},
  [8790] = {.lex_state = 63},
  [8791] = {.lex_state = 61, .external_lex_state = 23},
  [8792] = {.lex_state = 63, .external_lex_state = 53},
  [8793] = {.lex_state = 63, .external_lex_state = 58},
  [8794] = {.lex_state = 63, .external_lex_state = 58},
  [8795] = {.lex_state = 63, .external_lex_state = 56},
  [8796] = {.lex_state = 63, .external_lex_state = 29},
  [8797] = {.lex_state = 52, .external_lex_state = 34},
  [8798] = {.lex_state = 63},
  [8799] = {.lex_state = 63, .external_lex_state = 56},
  [8800] = {.lex_state = 63, .external_lex_state = 57},
  [8801] = {.lex_state = 52, .external_lex_state = 35},
  [8802] = {.lex_state = 63, .external_lex_state = 56},
  [8803] = {.lex_state = 58, .external_lex_state = 59},
  [8804] = {.lex_state = 63, .external_lex_state = 56},
  [8805] = {.lex_state = 63, .external_lex_state = 56},
  [8806] = {.lex_state = 63, .external_lex_state = 56},
  [8807] = {.lex_state = 61, .external_lex_state = 23},
  [8808] = {.lex_state = 63},
  [8809] = {.lex_state = 58, .external_lex_state = 59},
  [8810] = {.lex_state = 63, .external_lex_state = 58},
  [8811] = {.lex_state = 57, .external_lex_state = 40},
  [8812] = {.lex_state = 52, .external_lex_state = 37},
  [8813] = {.lex_state = 63, .external_lex_state = 56},
  [8814] = {.lex_state = 52, .external_lex_state = 53},
  [8815] = {.lex_state = 63, .external_lex_state = 57},
  [8816] = {.lex_state = 63, .external_lex_state = 56},
  [8817] = {.lex_state = 63, .external_lex_state = 56},
  [8818] = {.lex_state = 63, .external_lex_state = 56},
  [8819] = {.lex_state = 63},
  [8820] = {.lex_state = 52, .external_lex_state = 35},
  [8821] = {.lex_state = 61, .external_lex_state = 23},
  [8822] = {.lex_state = 52, .external_lex_state = 37},
  [8823] = {.lex_state = 61, .external_lex_state = 29},
  [8824] = {.lex_state = 63, .external_lex_state = 58},
  [8825] = {.lex_state = 63, .external_lex_state = 56},
  [8826] = {.lex_state = 63, .external_lex_state = 56},
  [8827] = {.lex_state = 52, .external_lex_state = 35},
  [8828] = {.lex_state = 63},
  [8829] = {.lex_state = 61, .external_lex_state = 23},
  [8830] = {.lex_state = 63, .external_lex_state = 58},
  [8831] = {.lex_state = 63, .external_lex_state = 56},
  [8832] = {.lex_state = 63, .external_lex_state = 56},
  [8833] = {.lex_state = 61, .external_lex_state = 23},
  [8834] = {.lex_state = 52, .external_lex_state = 37},
  [8835] = {.lex_state = 63, .external_lex_state = 58},
  [8836] = {.lex_state = 63},
  [8837] = {.lex_state = 63},
  [8838] = {.lex_state = 63, .external_lex_state = 57},
  [8839] = {.lex_state = 52, .external_lex_state = 36},
  [8840] = {.lex_state = 57, .external_lex_state = 40},
  [8841] = {.lex_state = 63, .external_lex_state = 37},
  [8842] = {.lex_state = 63, .external_lex_state = 58},
  [8843] = {.lex_state = 63},
  [8844] = {.lex_state = 63, .external_lex_state = 57},
  [8845] = {.lex_state = 63, .external_lex_state = 57},
  [8846] = {.lex_state = 52, .external_lex_state = 37},
  [8847] = {.lex_state = 63},
  [8848] = {.lex_state = 63, .external_lex_state = 42},
  [8849] = {.lex_state = 63, .external_lex_state = 57},
  [8850] = {.lex_state = 63, .external_lex_state = 57},
  [8851] = {.lex_state = 52, .external_lex_state = 37},
  [8852] = {.lex_state = 63, .external_lex_state = 57},
  [8853] = {.lex_state = 63, .external_lex_state = 57},
  [8854] = {.lex_state = 63, .external_lex_state = 57},
  [8855] = {.lex_state = 63},
  [8856] = {.lex_state = 52, .external_lex_state = 43},
  [8857] = {.lex_state = 52},
  [8858] = {.lex_state = 52, .external_lex_state = 35},
  [8859] = {.lex_state = 63, .external_lex_state = 57},
  [8860] = {.lex_state = 63},
  [8861] = {.lex_state = 63, .external_lex_state = 57},
  [8862] = {.lex_state = 52, .external_lex_state = 35},
  [8863] = {.lex_state = 52, .external_lex_state = 35},
  [8864] = {.lex_state = 63, .external_lex_state = 45},
  [8865] = {.lex_state = 63, .external_lex_state = 57},
  [8866] = {.lex_state = 63, .external_lex_state = 57},
  [8867] = {.lex_state = 52, .external_lex_state = 35},
  [8868] = {.lex_state = 58, .external_lex_state = 59},
  [8869] = {.lex_state = 63},
  [8870] = {.lex_state = 63, .external_lex_state = 57},
  [8871] = {.lex_state = 63, .external_lex_state = 57},
  [8872] = {.lex_state = 63, .external_lex_state = 34},
  [8873] = {.lex_state = 63},
  [8874] = {.lex_state = 63, .external_lex_state = 57},
  [8875] = {.lex_state = 63, .external_lex_state = 57},
  [8876] = {.lex_state = 57, .external_lex_state = 40},
  [8877] = {.lex_state = 63},
  [8878] = {.lex_state = 61, .external_lex_state = 29},
  [8879] = {.lex_state = 63},
  [8880] = {.lex_state = 63},
  [8881] = {.lex_state = 63},
  [8882] = {.lex_state = 63},
  [8883] = {.lex_state = 63, .external_lex_state = 56},
  [8884] = {.lex_state = 63},
  [8885] = {.lex_state = 63, .external_lex_state = 24},
  [8886] = {.lex_state = 63},
  [8887] = {.lex_state = 52, .external_lex_state = 24},
  [8888] = {.lex_state = 61, .external_lex_state = 39},
  [8889] = {.lex_state = 63},
  [8890] = {.lex_state = 63},
  [8891] = {.lex_state = 52, .external_lex_state = 36},
  [8892] = {.lex_state = 52, .external_lex_state = 36},
  [8893] = {.lex_state = 63},
  [8894] = {.lex_state = 63, .external_lex_state = 58},
  [8895] = {.lex_state = 63, .external_lex_state = 57},
  [8896] = {.lex_state = 63},
  [8897] = {.lex_state = 62, .external_lex_state = 43},
  [8898] = {.lex_state = 63, .external_lex_state = 58},
  [8899] = {.lex_state = 63, .external_lex_state = 31},
  [8900] = {.lex_state = 63},
  [8901] = {.lex_state = 52, .external_lex_state = 36},
  [8902] = {.lex_state = 63, .external_lex_state = 58},
  [8903] = {.lex_state = 52, .external_lex_state = 24},
  [8904] = {.lex_state = 63},
  [8905] = {.lex_state = 63, .external_lex_state = 58},
  [8906] = {.lex_state = 63, .external_lex_state = 56},
  [8907] = {.lex_state = 63},
  [8908] = {.lex_state = 63, .external_lex_state = 58},
  [8909] = {.lex_state = 63, .external_lex_state = 58},
  [8910] = {.lex_state = 63, .external_lex_state = 56},
  [8911] = {.lex_state = 61, .external_lex_state = 42},
  [8912] = {.lex_state = 63},
  [8913] = {.lex_state = 63, .external_lex_state = 58},
  [8914] = {.lex_state = 63},
  [8915] = {.lex_state = 63},
  [8916] = {.lex_state = 63, .external_lex_state = 43},
  [8917] = {.lex_state = 63, .external_lex_state = 58},
  [8918] = {.lex_state = 63, .external_lex_state = 57},
  [8919] = {.lex_state = 63, .external_lex_state = 58},
  [8920] = {.lex_state = 63},
  [8921] = {.lex_state = 61, .external_lex_state = 42},
  [8922] = {.lex_state = 63, .external_lex_state = 58},
  [8923] = {.lex_state = 63, .external_lex_state = 58},
  [8924] = {.lex_state = 63},
  [8925] = {.lex_state = 63, .external_lex_state = 56},
  [8926] = {.lex_state = 64, .external_lex_state = 40},
  [8927] = {.lex_state = 63},
  [8928] = {.lex_state = 62, .external_lex_state = 40},
  [8929] = {.lex_state = 63, .external_lex_state = 32},
  [8930] = {.lex_state = 63},
  [8931] = {.lex_state = 63, .external_lex_state = 58},
  [8932] = {.lex_state = 52, .external_lex_state = 32},
  [8933] = {.lex_state = 63, .external_lex_state = 58},
  [8934] = {.lex_state = 63, .external_lex_state = 56},
  [8935] = {.lex_state = 61, .external_lex_state = 42},
  [8936] = {.lex_state = 63},
  [8937] = {.lex_state = 63, .external_lex_state = 56},
  [8938] = {.lex_state = 61, .external_lex_state = 32},
  [8939] = {.lex_state = 63},
  [8940] = {.lex_state = 63, .external_lex_state = 42},
  [8941] = {.lex_state = 63, .external_lex_state = 58},
  [8942] = {.lex_state = 63},
  [8943] = {.lex_state = 52, .external_lex_state = 54},
  [8944] = {.lex_state = 63, .external_lex_state = 58},
  [8945] = {.lex_state = 52, .external_lex_state = 32},
  [8946] = {.lex_state = 63, .external_lex_state = 28},
  [8947] = {.lex_state = 63},
  [8948] = {.lex_state = 61, .external_lex_state = 42},
  [8949] = {.lex_state = 52, .external_lex_state = 32},
  [8950] = {.lex_state = 63},
  [8951] = {.lex_state = 61, .external_lex_state = 42},
  [8952] = {.lex_state = 63, .external_lex_state = 32},
  [8953] = {.lex_state = 63, .external_lex_state = 34},
  [8954] = {.lex_state = 63},
  [8955] = {.lex_state = 63, .external_lex_state = 42},
  [8956] = {.lex_state = 63, .external_lex_state = 42},
  [8957] = {.lex_state = 63, .external_lex_state = 56},
  [8958] = {.lex_state = 63},
  [8959] = {.lex_state = 52, .external_lex_state = 39},
  [8960] = {.lex_state = 63},
  [8961] = {.lex_state = 63, .external_lex_state = 32},
  [8962] = {.lex_state = 63},
  [8963] = {.lex_state = 63},
  [8964] = {.lex_state = 63},
  [8965] = {.lex_state = 63, .external_lex_state = 57},
  [8966] = {.lex_state = 63},
  [8967] = {.lex_state = 63, .external_lex_state = 57},
  [8968] = {.lex_state = 63},
  [8969] = {.lex_state = 58, .external_lex_state = 40},
  [8970] = {.lex_state = 63},
  [8971] = {.lex_state = 57, .external_lex_state = 40},
  [8972] = {.lex_state = 63},
  [8973] = {.lex_state = 52, .external_lex_state = 54},
  [8974] = {.lex_state = 63},
  [8975] = {.lex_state = 63},
  [8976] = {.lex_state = 63, .external_lex_state = 57},
  [8977] = {.lex_state = 63},
  [8978] = {.lex_state = 63, .external_lex_state = 56},
  [8979] = {.lex_state = 63},
  [8980] = {.lex_state = 63},
  [8981] = {.lex_state = 63, .external_lex_state = 57},
  [8982] = {.lex_state = 58, .external_lex_state = 40},
  [8983] = {.lex_state = 63, .external_lex_state = 57},
  [8984] = {.lex_state = 63},
  [8985] = {.lex_state = 63, .external_lex_state = 56},
  [8986] = {.lex_state = 63},
  [8987] = {.lex_state = 63},
  [8988] = {.lex_state = 63},
  [8989] = {.lex_state = 63},
  [8990] = {.lex_state = 57, .external_lex_state = 40},
  [8991] = {.lex_state = 63},
  [8992] = {.lex_state = 63},
  [8993] = {.lex_state = 63, .external_lex_state = 56},
  [8994] = {.lex_state = 63},
  [8995] = {.lex_state = 17, .external_lex_state = 43},
  [8996] = {.lex_state = 63},
  [8997] = {.lex_state = 63, .external_lex_state = 39},
  [8998] = {.lex_state = 63, .external_lex_state = 23},
  [8999] = {.lex_state = 52, .external_lex_state = 23},
  [9000] = {.lex_state = 63},
  [9001] = {.lex_state = 63, .external_lex_state = 58},
  [9002] = {.lex_state = 63},
  [9003] = {.lex_state = 64, .external_lex_state = 53},
  [9004] = {.lex_state = 63},
  [9005] = {.lex_state = 63},
  [9006] = {.lex_state = 63, .external_lex_state = 56},
  [9007] = {.lex_state = 63},
  [9008] = {.lex_state = 63},
  [9009] = {.lex_state = 63},
  [9010] = {.lex_state = 63, .external_lex_state = 58},
  [9011] = {.lex_state = 52, .external_lex_state = 37},
  [9012] = {.lex_state = 52, .external_lex_state = 37},
  [9013] = {.lex_state = 63},
  [9014] = {.lex_state = 63, .external_lex_state = 31},
  [9015] = {.lex_state = 63},
  [9016] = {.lex_state = 52, .external_lex_state = 24},
  [9017] = {.lex_state = 63},
  [9018] = {.lex_state = 63, .external_lex_state = 28},
  [9019] = {.lex_state = 52, .external_lex_state = 37},
  [9020] = {.lex_state = 63, .external_lex_state = 28},
  [9021] = {.lex_state = 63, .external_lex_state = 32},
  [9022] = {.lex_state = 52, .external_lex_state = 39},
  [9023] = {.lex_state = 63},
  [9024] = {.lex_state = 63, .external_lex_state = 51},
  [9025] = {.lex_state = 63, .external_lex_state = 58},
  [9026] = {.lex_state = 52, .external_lex_state = 55},
  [9027] = {.lex_state = 63, .external_lex_state = 58},
  [9028] = {.lex_state = 17, .external_lex_state = 43},
  [9029] = {.lex_state = 61, .external_lex_state = 39},
  [9030] = {.lex_state = 61, .external_lex_state = 39},
  [9031] = {.lex_state = 63, .external_lex_state = 27},
  [9032] = {.lex_state = 61, .external_lex_state = 39},
  [9033] = {.lex_state = 61, .external_lex_state = 23},
  [9034] = {.lex_state = 63, .external_lex_state = 58},
  [9035] = {.lex_state = 10, .external_lex_state = 43},
  [9036] = {.lex_state = 61, .external_lex_state = 39},
  [9037] = {.lex_state = 63, .external_lex_state = 58},
  [9038] = {.lex_state = 63, .external_lex_state = 58},
  [9039] = {.lex_state = 52, .external_lex_state = 55},
  [9040] = {.lex_state = 61, .external_lex_state = 39},
  [9041] = {.lex_state = 52, .external_lex_state = 45},
  [9042] = {.lex_state = 63},
  [9043] = {.lex_state = 52, .external_lex_state = 56},
  [9044] = {.lex_state = 64, .external_lex_state = 53},
  [9045] = {.lex_state = 63, .external_lex_state = 24},
  [9046] = {.lex_state = 64, .external_lex_state = 40},
  [9047] = {.lex_state = 63, .external_lex_state = 57},
  [9048] = {.lex_state = 52, .external_lex_state = 59},
  [9049] = {.lex_state = 10, .external_lex_state = 43},
  [9050] = {.lex_state = 63},
  [9051] = {.lex_state = 63, .external_lex_state = 57},
  [9052] = {.lex_state = 63, .external_lex_state = 34},
  [9053] = {.lex_state = 63, .external_lex_state = 58},
  [9054] = {.lex_state = 63, .external_lex_state = 24},
  [9055] = {.lex_state = 63, .external_lex_state = 23},
  [9056] = {.lex_state = 63, .external_lex_state = 58},
  [9057] = {.lex_state = 64, .external_lex_state = 40},
  [9058] = {.lex_state = 63, .external_lex_state = 58},
  [9059] = {.lex_state = 63, .external_lex_state = 24},
  [9060] = {.lex_state = 63, .external_lex_state = 58},
  [9061] = {.lex_state = 63, .external_lex_state = 58},
  [9062] = {.lex_state = 63},
  [9063] = {.lex_state = 65, .external_lex_state = 31},
  [9064] = {.lex_state = 65, .external_lex_state = 31},
  [9065] = {.lex_state = 65, .external_lex_state = 31},
  [9066] = {.lex_state = 62, .external_lex_state = 40},
  [9067] = {.lex_state = 63, .external_lex_state = 39},
  [9068] = {.lex_state = 61, .external_lex_state = 30},
  [9069] = {.lex_state = 57, .external_lex_state = 40},
  [9070] = {.lex_state = 57, .external_lex_state = 40},
  [9071] = {.lex_state = 63, .external_lex_state = 24},
  [9072] = {.lex_state = 52, .external_lex_state = 36},
  [9073] = {.lex_state = 10, .external_lex_state = 43},
  [9074] = {.lex_state = 61, .external_lex_state = 42},
  [9075] = {.lex_state = 63},
  [9076] = {.lex_state = 61, .external_lex_state = 42},
  [9077] = {.lex_state = 52, .external_lex_state = 37},
  [9078] = {.lex_state = 58, .external_lex_state = 59},
  [9079] = {.lex_state = 62, .external_lex_state = 40},
  [9080] = {.lex_state = 63, .external_lex_state = 48},
  [9081] = {.lex_state = 64, .external_lex_state = 40},
  [9082] = {.lex_state = 63, .external_lex_state = 58},
  [9083] = {.lex_state = 63, .external_lex_state = 58},
  [9084] = {.lex_state = 52, .external_lex_state = 34},
  [9085] = {.lex_state = 63, .external_lex_state = 24},
  [9086] = {.lex_state = 61, .external_lex_state = 30},
  [9087] = {.lex_state = 61, .external_lex_state = 42},
  [9088] = {.lex_state = 63},
  [9089] = {.lex_state = 10, .external_lex_state = 43},
  [9090] = {.lex_state = 52, .external_lex_state = 34},
  [9091] = {.lex_state = 63, .external_lex_state = 48},
  [9092] = {.lex_state = 52, .external_lex_state = 34},
  [9093] = {.lex_state = 63, .external_lex_state = 45},
  [9094] = {.lex_state = 52, .external_lex_state = 36},
  [9095] = {.lex_state = 52, .external_lex_state = 36},
  [9096] = {.lex_state = 52, .external_lex_state = 36},
  [9097] = {.lex_state = 63},
  [9098] = {.lex_state = 62, .external_lex_state = 40},
  [9099] = {.lex_state = 63, .external_lex_state = 58},
  [9100] = {.lex_state = 63, .external_lex_state = 23},
  [9101] = {.lex_state = 52, .external_lex_state = 37},
  [9102] = {.lex_state = 57, .external_lex_state = 40},
  [9103] = {.lex_state = 63, .external_lex_state = 58},
  [9104] = {.lex_state = 63, .external_lex_state = 58},
  [9105] = {.lex_state = 63, .external_lex_state = 58},
  [9106] = {.lex_state = 63, .external_lex_state = 34},
  [9107] = {.lex_state = 63},
  [9108] = {.lex_state = 52, .external_lex_state = 53},
  [9109] = {.lex_state = 62, .external_lex_state = 43},
  [9110] = {.lex_state = 62, .external_lex_state = 24},
  [9111] = {.lex_state = 57, .external_lex_state = 40},
  [9112] = {.lex_state = 52, .external_lex_state = 36},
  [9113] = {.lex_state = 63, .external_lex_state = 24},
  [9114] = {.lex_state = 63, .external_lex_state = 57},
  [9115] = {.lex_state = 63, .external_lex_state = 28},
  [9116] = {.lex_state = 63, .external_lex_state = 30},
  [9117] = {.lex_state = 52, .external_lex_state = 37},
  [9118] = {.lex_state = 63, .external_lex_state = 58},
  [9119] = {.lex_state = 52, .external_lex_state = 37},
  [9120] = {.lex_state = 52, .external_lex_state = 37},
  [9121] = {.lex_state = 61, .external_lex_state = 23},
  [9122] = {.lex_state = 52, .external_lex_state = 43},
  [9123] = {.lex_state = 56, .external_lex_state = 43},
  [9124] = {.lex_state = 63, .external_lex_state = 56},
  [9125] = {.lex_state = 63},
  [9126] = {.lex_state = 63, .external_lex_state = 49},
  [9127] = {.lex_state = 63, .external_lex_state = 56},
  [9128] = {.lex_state = 61, .external_lex_state = 27},
  [9129] = {.lex_state = 63, .external_lex_state = 56},
  [9130] = {.lex_state = 63, .external_lex_state = 24},
  [9131] = {.lex_state = 64, .external_lex_state = 40},
  [9132] = {.lex_state = 63, .external_lex_state = 29},
  [9133] = {.lex_state = 63, .external_lex_state = 57},
  [9134] = {.lex_state = 63},
  [9135] = {.lex_state = 19, .external_lex_state = 43},
  [9136] = {.lex_state = 63, .external_lex_state = 57},
  [9137] = {.lex_state = 63, .external_lex_state = 49},
  [9138] = {.lex_state = 63, .external_lex_state = 24},
  [9139] = {.lex_state = 63, .external_lex_state = 57},
  [9140] = {.lex_state = 58, .external_lex_state = 34},
  [9141] = {.lex_state = 63, .external_lex_state = 57},
  [9142] = {.lex_state = 58, .external_lex_state = 34},
  [9143] = {.lex_state = 63},
  [9144] = {.lex_state = 52},
  [9145] = {.lex_state = 63, .external_lex_state = 23},
  [9146] = {.lex_state = 52},
  [9147] = {.lex_state = 52},
  [9148] = {.lex_state = 63},
  [9149] = {.lex_state = 63, .external_lex_state = 24},
  [9150] = {.lex_state = 63, .external_lex_state = 57},
  [9151] = {.lex_state = 61, .external_lex_state = 42},
  [9152] = {.lex_state = 63, .external_lex_state = 24},
  [9153] = {.lex_state = 63},
  [9154] = {.lex_state = 52, .external_lex_state = 40},
  [9155] = {.lex_state = 63},
  [9156] = {.lex_state = 63, .external_lex_state = 30},
  [9157] = {.lex_state = 56, .external_lex_state = 43},
  [9158] = {.lex_state = 63, .external_lex_state = 27},
  [9159] = {.lex_state = 63, .external_lex_state = 27},
  [9160] = {.lex_state = 61, .external_lex_state = 42},
  [9161] = {.lex_state = 61, .external_lex_state = 42},
  [9162] = {.lex_state = 61, .external_lex_state = 42},
  [9163] = {.lex_state = 63, .external_lex_state = 27},
  [9164] = {.lex_state = 63},
  [9165] = {.lex_state = 57, .external_lex_state = 40},
  [9166] = {.lex_state = 63, .external_lex_state = 27},
  [9167] = {.lex_state = 63, .external_lex_state = 27},
  [9168] = {.lex_state = 64, .external_lex_state = 40},
  [9169] = {.lex_state = 61, .external_lex_state = 40},
  [9170] = {.lex_state = 63, .external_lex_state = 27},
  [9171] = {.lex_state = 10, .external_lex_state = 43},
  [9172] = {.lex_state = 61, .external_lex_state = 53},
  [9173] = {.lex_state = 63, .external_lex_state = 27},
  [9174] = {.lex_state = 63, .external_lex_state = 34},
  [9175] = {.lex_state = 61, .external_lex_state = 40},
  [9176] = {.lex_state = 65, .external_lex_state = 31},
  [9177] = {.lex_state = 65, .external_lex_state = 31},
  [9178] = {.lex_state = 61, .external_lex_state = 23},
  [9179] = {.lex_state = 61, .external_lex_state = 23},
  [9180] = {.lex_state = 63},
  [9181] = {.lex_state = 61, .external_lex_state = 40},
  [9182] = {.lex_state = 61},
  [9183] = {.lex_state = 63, .external_lex_state = 56},
  [9184] = {.lex_state = 63, .external_lex_state = 27},
  [9185] = {.lex_state = 63, .external_lex_state = 56},
  [9186] = {.lex_state = 63, .external_lex_state = 56},
  [9187] = {.lex_state = 52, .external_lex_state = 23},
  [9188] = {.lex_state = 63, .external_lex_state = 27},
  [9189] = {.lex_state = 63, .external_lex_state = 27},
  [9190] = {.lex_state = 63, .external_lex_state = 27},
  [9191] = {.lex_state = 19, .external_lex_state = 43},
  [9192] = {.lex_state = 63, .external_lex_state = 27},
  [9193] = {.lex_state = 63, .external_lex_state = 27},
  [9194] = {.lex_state = 63, .external_lex_state = 57},
  [9195] = {.lex_state = 52, .external_lex_state = 59},
  [9196] = {.lex_state = 61, .external_lex_state = 23},
  [9197] = {.lex_state = 52, .external_lex_state = 26},
  [9198] = {.lex_state = 52},
  [9199] = {.lex_state = 63},
  [9200] = {.lex_state = 63, .external_lex_state = 27},
  [9201] = {.lex_state = 63, .external_lex_state = 27},
  [9202] = {.lex_state = 63, .external_lex_state = 27},
  [9203] = {.lex_state = 52},
  [9204] = {.lex_state = 52, .external_lex_state = 35},
  [9205] = {.lex_state = 62, .external_lex_state = 53},
  [9206] = {.lex_state = 52, .external_lex_state = 24},
  [9207] = {.lex_state = 63, .external_lex_state = 27},
  [9208] = {.lex_state = 63, .external_lex_state = 27},
  [9209] = {.lex_state = 56, .external_lex_state = 43},
  [9210] = {.lex_state = 61, .external_lex_state = 23},
  [9211] = {.lex_state = 61, .external_lex_state = 42},
  [9212] = {.lex_state = 61, .external_lex_state = 53},
  [9213] = {.lex_state = 63},
  [9214] = {.lex_state = 10, .external_lex_state = 43},
  [9215] = {.lex_state = 63, .external_lex_state = 57},
  [9216] = {.lex_state = 10, .external_lex_state = 43},
  [9217] = {.lex_state = 10, .external_lex_state = 43},
  [9218] = {.lex_state = 61, .external_lex_state = 34},
  [9219] = {.lex_state = 10, .external_lex_state = 43},
  [9220] = {.lex_state = 52, .external_lex_state = 36},
  [9221] = {.lex_state = 63, .external_lex_state = 27},
  [9222] = {.lex_state = 63},
  [9223] = {.lex_state = 10, .external_lex_state = 43},
  [9224] = {.lex_state = 63},
  [9225] = {.lex_state = 65, .external_lex_state = 28},
  [9226] = {.lex_state = 63, .external_lex_state = 27},
  [9227] = {.lex_state = 52, .external_lex_state = 26},
  [9228] = {.lex_state = 10, .external_lex_state = 43},
  [9229] = {.lex_state = 63, .external_lex_state = 27},
  [9230] = {.lex_state = 63, .external_lex_state = 57},
  [9231] = {.lex_state = 63, .external_lex_state = 57},
  [9232] = {.lex_state = 63, .external_lex_state = 57},
  [9233] = {.lex_state = 61, .external_lex_state = 23},
  [9234] = {.lex_state = 10, .external_lex_state = 43},
  [9235] = {.lex_state = 52, .external_lex_state = 35},
  [9236] = {.lex_state = 63},
  [9237] = {.lex_state = 57, .external_lex_state = 40},
  [9238] = {.lex_state = 63, .external_lex_state = 32},
  [9239] = {.lex_state = 52},
  [9240] = {.lex_state = 52, .external_lex_state = 37},
  [9241] = {.lex_state = 63, .external_lex_state = 31},
  [9242] = {.lex_state = 63, .external_lex_state = 56},
  [9243] = {.lex_state = 52},
  [9244] = {.lex_state = 63, .external_lex_state = 56},
  [9245] = {.lex_state = 63},
  [9246] = {.lex_state = 52},
  [9247] = {.lex_state = 63, .external_lex_state = 56},
  [9248] = {.lex_state = 52},
  [9249] = {.lex_state = 57, .external_lex_state = 40},
  [9250] = {.lex_state = 52},
  [9251] = {.lex_state = 10, .external_lex_state = 43},
  [9252] = {.lex_state = 52, .external_lex_state = 29},
  [9253] = {.lex_state = 63},
  [9254] = {.lex_state = 52, .external_lex_state = 48},
  [9255] = {.lex_state = 52},
  [9256] = {.lex_state = 58, .external_lex_state = 32},
  [9257] = {.lex_state = 52},
  [9258] = {.lex_state = 21},
  [9259] = {.lex_state = 63, .external_lex_state = 56},
  [9260] = {.lex_state = 63, .external_lex_state = 56},
  [9261] = {.lex_state = 63, .external_lex_state = 56},
  [9262] = {.lex_state = 63},
  [9263] = {.lex_state = 61, .external_lex_state = 39},
  [9264] = {.lex_state = 61, .external_lex_state = 56},
  [9265] = {.lex_state = 56, .external_lex_state = 40},
  [9266] = {.lex_state = 63},
  [9267] = {.lex_state = 63, .external_lex_state = 56},
  [9268] = {.lex_state = 52, .external_lex_state = 52},
  [9269] = {.lex_state = 61, .external_lex_state = 39},
  [9270] = {.lex_state = 63, .external_lex_state = 56},
  [9271] = {.lex_state = 61, .external_lex_state = 39},
  [9272] = {.lex_state = 61, .external_lex_state = 39},
  [9273] = {.lex_state = 21},
  [9274] = {.lex_state = 61, .external_lex_state = 57},
  [9275] = {.lex_state = 52},
  [9276] = {.lex_state = 63},
  [9277] = {.lex_state = 52, .external_lex_state = 36},
  [9278] = {.lex_state = 61, .external_lex_state = 34},
  [9279] = {.lex_state = 63, .external_lex_state = 57},
  [9280] = {.lex_state = 52, .external_lex_state = 35},
  [9281] = {.lex_state = 61, .external_lex_state = 39},
  [9282] = {.lex_state = 20, .external_lex_state = 43},
  [9283] = {.lex_state = 63},
  [9284] = {.lex_state = 61, .external_lex_state = 39},
  [9285] = {.lex_state = 62, .external_lex_state = 23},
  [9286] = {.lex_state = 63, .external_lex_state = 57},
  [9287] = {.lex_state = 61, .external_lex_state = 23},
  [9288] = {.lex_state = 63, .external_lex_state = 43},
  [9289] = {.lex_state = 20, .external_lex_state = 43},
  [9290] = {.lex_state = 52, .external_lex_state = 49},
  [9291] = {.lex_state = 63, .external_lex_state = 31},
  [9292] = {.lex_state = 63},
  [9293] = {.lex_state = 63, .external_lex_state = 32},
  [9294] = {.lex_state = 63, .external_lex_state = 56},
  [9295] = {.lex_state = 56, .external_lex_state = 40},
  [9296] = {.lex_state = 63, .external_lex_state = 56},
  [9297] = {.lex_state = 57, .external_lex_state = 40},
  [9298] = {.lex_state = 63, .external_lex_state = 27},
  [9299] = {.lex_state = 63},
  [9300] = {.lex_state = 63, .external_lex_state = 56},
  [9301] = {.lex_state = 63, .external_lex_state = 57},
  [9302] = {.lex_state = 63, .external_lex_state = 57},
  [9303] = {.lex_state = 63, .external_lex_state = 28},
  [9304] = {.lex_state = 52, .external_lex_state = 52},
  [9305] = {.lex_state = 63},
  [9306] = {.lex_state = 61, .external_lex_state = 39},
  [9307] = {.lex_state = 63, .external_lex_state = 56},
  [9308] = {.lex_state = 57, .external_lex_state = 40},
  [9309] = {.lex_state = 63, .external_lex_state = 27},
  [9310] = {.lex_state = 63, .external_lex_state = 56},
  [9311] = {.lex_state = 63},
  [9312] = {.lex_state = 63, .external_lex_state = 27},
  [9313] = {.lex_state = 63, .external_lex_state = 31},
  [9314] = {.lex_state = 52, .external_lex_state = 29},
  [9315] = {.lex_state = 63, .external_lex_state = 27},
  [9316] = {.lex_state = 57, .external_lex_state = 40},
  [9317] = {.lex_state = 65, .external_lex_state = 28},
  [9318] = {.lex_state = 61, .external_lex_state = 40},
  [9319] = {.lex_state = 63},
  [9320] = {.lex_state = 57, .external_lex_state = 40},
  [9321] = {.lex_state = 63, .external_lex_state = 58},
  [9322] = {.lex_state = 63, .external_lex_state = 27},
  [9323] = {.lex_state = 63, .external_lex_state = 58},
  [9324] = {.lex_state = 58, .external_lex_state = 32},
  [9325] = {.lex_state = 63, .external_lex_state = 51},
  [9326] = {.lex_state = 63},
  [9327] = {.lex_state = 61, .external_lex_state = 49},
  [9328] = {.lex_state = 63, .external_lex_state = 24},
  [9329] = {.lex_state = 62, .external_lex_state = 43},
  [9330] = {.lex_state = 52, .external_lex_state = 45},
  [9331] = {.lex_state = 63},
  [9332] = {.lex_state = 63, .external_lex_state = 36},
  [9333] = {.lex_state = 3},
  [9334] = {.lex_state = 63, .external_lex_state = 24},
  [9335] = {.lex_state = 63, .external_lex_state = 35},
  [9336] = {.lex_state = 52, .external_lex_state = 48},
  [9337] = {.lex_state = 63, .external_lex_state = 58},
  [9338] = {.lex_state = 63, .external_lex_state = 49},
  [9339] = {.lex_state = 63, .external_lex_state = 24},
  [9340] = {.lex_state = 63, .external_lex_state = 45},
  [9341] = {.lex_state = 19, .external_lex_state = 43},
  [9342] = {.lex_state = 62, .external_lex_state = 40},
  [9343] = {.lex_state = 63, .external_lex_state = 36},
  [9344] = {.lex_state = 63, .external_lex_state = 35},
  [9345] = {.lex_state = 63, .external_lex_state = 24},
  [9346] = {.lex_state = 63, .external_lex_state = 28},
  [9347] = {.lex_state = 63, .external_lex_state = 34},
  [9348] = {.lex_state = 19, .external_lex_state = 43},
  [9349] = {.lex_state = 63, .external_lex_state = 28},
  [9350] = {.lex_state = 61, .external_lex_state = 32},
  [9351] = {.lex_state = 63, .external_lex_state = 40},
  [9352] = {.lex_state = 52, .external_lex_state = 23},
  [9353] = {.lex_state = 63},
  [9354] = {.lex_state = 19, .external_lex_state = 43},
  [9355] = {.lex_state = 63, .external_lex_state = 37},
  [9356] = {.lex_state = 63, .external_lex_state = 24},
  [9357] = {.lex_state = 63, .external_lex_state = 28},
  [9358] = {.lex_state = 61, .external_lex_state = 51},
  [9359] = {.lex_state = 63, .external_lex_state = 51},
  [9360] = {.lex_state = 61, .external_lex_state = 45},
  [9361] = {.lex_state = 63, .external_lex_state = 28},
  [9362] = {.lex_state = 65, .external_lex_state = 37},
  [9363] = {.lex_state = 61, .external_lex_state = 49},
  [9364] = {.lex_state = 52, .external_lex_state = 32},
  [9365] = {.lex_state = 63, .external_lex_state = 28},
  [9366] = {.lex_state = 52, .external_lex_state = 56},
  [9367] = {.lex_state = 63, .external_lex_state = 28},
  [9368] = {.lex_state = 63, .external_lex_state = 28},
  [9369] = {.lex_state = 63},
  [9370] = {.lex_state = 63},
  [9371] = {.lex_state = 63, .external_lex_state = 28},
  [9372] = {.lex_state = 52, .external_lex_state = 58},
  [9373] = {.lex_state = 63},
  [9374] = {.lex_state = 63, .external_lex_state = 28},
  [9375] = {.lex_state = 63, .external_lex_state = 28},
  [9376] = {.lex_state = 63, .external_lex_state = 28},
  [9377] = {.lex_state = 63, .external_lex_state = 28},
  [9378] = {.lex_state = 63, .external_lex_state = 24},
  [9379] = {.lex_state = 52, .external_lex_state = 30},
  [9380] = {.lex_state = 61, .external_lex_state = 49},
  [9381] = {.lex_state = 63, .external_lex_state = 28},
  [9382] = {.lex_state = 63, .external_lex_state = 28},
  [9383] = {.lex_state = 61, .external_lex_state = 51},
  [9384] = {.lex_state = 63, .external_lex_state = 24},
  [9385] = {.lex_state = 63, .external_lex_state = 28},
  [9386] = {.lex_state = 61, .external_lex_state = 48},
  [9387] = {.lex_state = 63, .external_lex_state = 28},
  [9388] = {.lex_state = 14, .external_lex_state = 2},
  [9389] = {.lex_state = 61, .external_lex_state = 48},
  [9390] = {.lex_state = 61, .external_lex_state = 48},
  [9391] = {.lex_state = 63},
  [9392] = {.lex_state = 63},
  [9393] = {.lex_state = 61, .external_lex_state = 49},
  [9394] = {.lex_state = 63},
  [9395] = {.lex_state = 63},
  [9396] = {.lex_state = 62, .external_lex_state = 40},
  [9397] = {.lex_state = 63, .external_lex_state = 24},
  [9398] = {.lex_state = 63, .external_lex_state = 24},
  [9399] = {.lex_state = 63, .external_lex_state = 23},
  [9400] = {.lex_state = 63},
  [9401] = {.lex_state = 61, .external_lex_state = 48},
  [9402] = {.lex_state = 58, .external_lex_state = 59},
  [9403] = {.lex_state = 3},
  [9404] = {.lex_state = 61, .external_lex_state = 48},
  [9405] = {.lex_state = 63},
  [9406] = {.lex_state = 65, .external_lex_state = 35},
  [9407] = {.lex_state = 58, .external_lex_state = 59},
  [9408] = {.lex_state = 3},
  [9409] = {.lex_state = 63},
  [9410] = {.lex_state = 63},
  [9411] = {.lex_state = 63, .external_lex_state = 57},
  [9412] = {.lex_state = 63, .external_lex_state = 40},
  [9413] = {.lex_state = 58, .external_lex_state = 59},
  [9414] = {.lex_state = 61, .external_lex_state = 48},
  [9415] = {.lex_state = 52, .external_lex_state = 45},
  [9416] = {.lex_state = 63, .external_lex_state = 24},
  [9417] = {.lex_state = 58, .external_lex_state = 59},
  [9418] = {.lex_state = 63, .external_lex_state = 35},
  [9419] = {.lex_state = 63},
  [9420] = {.lex_state = 52, .external_lex_state = 48},
  [9421] = {.lex_state = 63, .external_lex_state = 40},
  [9422] = {.lex_state = 63, .external_lex_state = 36},
  [9423] = {.lex_state = 61, .external_lex_state = 48},
  [9424] = {.lex_state = 63},
  [9425] = {.lex_state = 63, .external_lex_state = 40},
  [9426] = {.lex_state = 17, .external_lex_state = 43},
  [9427] = {.lex_state = 61, .external_lex_state = 48},
  [9428] = {.lex_state = 63},
  [9429] = {.lex_state = 65, .external_lex_state = 36},
  [9430] = {.lex_state = 52, .external_lex_state = 40},
  [9431] = {.lex_state = 52, .external_lex_state = 42},
  [9432] = {.lex_state = 21, .external_lex_state = 43},
  [9433] = {.lex_state = 63, .external_lex_state = 51},
  [9434] = {.lex_state = 63, .external_lex_state = 28},
  [9435] = {.lex_state = 63, .external_lex_state = 31},
  [9436] = {.lex_state = 58, .external_lex_state = 59},
  [9437] = {.lex_state = 58, .external_lex_state = 59},
  [9438] = {.lex_state = 58, .external_lex_state = 59},
  [9439] = {.lex_state = 63, .external_lex_state = 31},
  [9440] = {.lex_state = 58, .external_lex_state = 59},
  [9441] = {.lex_state = 63, .external_lex_state = 31},
  [9442] = {.lex_state = 63},
  [9443] = {.lex_state = 65, .external_lex_state = 36},
  [9444] = {.lex_state = 58, .external_lex_state = 59},
  [9445] = {.lex_state = 58, .external_lex_state = 59},
  [9446] = {.lex_state = 63, .external_lex_state = 31},
  [9447] = {.lex_state = 61, .external_lex_state = 48},
  [9448] = {.lex_state = 65, .external_lex_state = 36},
  [9449] = {.lex_state = 58, .external_lex_state = 59},
  [9450] = {.lex_state = 63, .external_lex_state = 23},
  [9451] = {.lex_state = 58, .external_lex_state = 59},
  [9452] = {.lex_state = 63},
  [9453] = {.lex_state = 63, .external_lex_state = 56},
  [9454] = {.lex_state = 64, .external_lex_state = 53},
  [9455] = {.lex_state = 61, .external_lex_state = 49},
  [9456] = {.lex_state = 64, .external_lex_state = 40},
  [9457] = {.lex_state = 52, .external_lex_state = 23},
  [9458] = {.lex_state = 63, .external_lex_state = 28},
  [9459] = {.lex_state = 63, .external_lex_state = 28},
  [9460] = {.lex_state = 63, .external_lex_state = 24},
  [9461] = {.lex_state = 61, .external_lex_state = 51},
  [9462] = {.lex_state = 61, .external_lex_state = 48},
  [9463] = {.lex_state = 3},
  [9464] = {.lex_state = 63, .external_lex_state = 28},
  [9465] = {.lex_state = 63},
  [9466] = {.lex_state = 61, .external_lex_state = 40},
  [9467] = {.lex_state = 63, .external_lex_state = 28},
  [9468] = {.lex_state = 61, .external_lex_state = 48},
  [9469] = {.lex_state = 52, .external_lex_state = 42},
  [9470] = {.lex_state = 61, .external_lex_state = 48},
  [9471] = {.lex_state = 52, .external_lex_state = 42},
  [9472] = {.lex_state = 63, .external_lex_state = 35},
  [9473] = {.lex_state = 52, .external_lex_state = 57},
  [9474] = {.lex_state = 63, .external_lex_state = 28},
  [9475] = {.lex_state = 52, .external_lex_state = 42},
  [9476] = {.lex_state = 63},
  [9477] = {.lex_state = 64, .external_lex_state = 40},
  [9478] = {.lex_state = 63},
  [9479] = {.lex_state = 63},
  [9480] = {.lex_state = 17},
  [9481] = {.lex_state = 63, .external_lex_state = 28},
  [9482] = {.lex_state = 63, .external_lex_state = 28},
  [9483] = {.lex_state = 63},
  [9484] = {.lex_state = 63},
  [9485] = {.lex_state = 61, .external_lex_state = 49},
  [9486] = {.lex_state = 63},
  [9487] = {.lex_state = 52, .external_lex_state = 42},
  [9488] = {.lex_state = 63, .external_lex_state = 24},
  [9489] = {.lex_state = 63, .external_lex_state = 23},
  [9490] = {.lex_state = 63, .external_lex_state = 24},
  [9491] = {.lex_state = 63, .external_lex_state = 24},
  [9492] = {.lex_state = 52, .external_lex_state = 42},
  [9493] = {.lex_state = 10, .external_lex_state = 43},
  [9494] = {.lex_state = 63, .external_lex_state = 24},
  [9495] = {.lex_state = 52, .external_lex_state = 34},
  [9496] = {.lex_state = 63, .external_lex_state = 39},
  [9497] = {.lex_state = 14, .external_lex_state = 2},
  [9498] = {.lex_state = 63, .external_lex_state = 45},
  [9499] = {.lex_state = 63, .external_lex_state = 40},
  [9500] = {.lex_state = 63},
  [9501] = {.lex_state = 63},
  [9502] = {.lex_state = 61, .external_lex_state = 32},
  [9503] = {.lex_state = 63, .external_lex_state = 24},
  [9504] = {.lex_state = 61, .external_lex_state = 24},
  [9505] = {.lex_state = 63, .external_lex_state = 36},
  [9506] = {.lex_state = 63, .external_lex_state = 48},
  [9507] = {.lex_state = 63, .external_lex_state = 24},
  [9508] = {.lex_state = 63, .external_lex_state = 24},
  [9509] = {.lex_state = 53, .external_lex_state = 23},
  [9510] = {.lex_state = 63, .external_lex_state = 31},
  [9511] = {.lex_state = 52, .external_lex_state = 30},
  [9512] = {.lex_state = 63, .external_lex_state = 24},
  [9513] = {.lex_state = 52, .external_lex_state = 24},
  [9514] = {.lex_state = 63},
  [9515] = {.lex_state = 61, .external_lex_state = 45},
  [9516] = {.lex_state = 14, .external_lex_state = 2},
  [9517] = {.lex_state = 63, .external_lex_state = 51},
  [9518] = {.lex_state = 63, .external_lex_state = 51},
  [9519] = {.lex_state = 64, .external_lex_state = 40},
  [9520] = {.lex_state = 17, .external_lex_state = 43},
  [9521] = {.lex_state = 61, .external_lex_state = 31},
  [9522] = {.lex_state = 21, .external_lex_state = 43},
  [9523] = {.lex_state = 61, .external_lex_state = 49},
  [9524] = {.lex_state = 65, .external_lex_state = 35},
  [9525] = {.lex_state = 52, .external_lex_state = 59},
  [9526] = {.lex_state = 63, .external_lex_state = 24},
  [9527] = {.lex_state = 52, .external_lex_state = 59},
  [9528] = {.lex_state = 63, .external_lex_state = 24},
  [9529] = {.lex_state = 63},
  [9530] = {.lex_state = 63, .external_lex_state = 24},
  [9531] = {.lex_state = 63},
  [9532] = {.lex_state = 63},
  [9533] = {.lex_state = 52, .external_lex_state = 23},
  [9534] = {.lex_state = 63, .external_lex_state = 24},
  [9535] = {.lex_state = 63, .external_lex_state = 24},
  [9536] = {.lex_state = 63, .external_lex_state = 31},
  [9537] = {.lex_state = 62, .external_lex_state = 23},
  [9538] = {.lex_state = 63, .external_lex_state = 31},
  [9539] = {.lex_state = 61, .external_lex_state = 51},
  [9540] = {.lex_state = 63, .external_lex_state = 23},
  [9541] = {.lex_state = 63},
  [9542] = {.lex_state = 63, .external_lex_state = 31},
  [9543] = {.lex_state = 58, .external_lex_state = 59},
  [9544] = {.lex_state = 63},
  [9545] = {.lex_state = 63, .external_lex_state = 24},
  [9546] = {.lex_state = 63, .external_lex_state = 24},
  [9547] = {.lex_state = 63, .external_lex_state = 34},
  [9548] = {.lex_state = 63, .external_lex_state = 48},
  [9549] = {.lex_state = 62},
  [9550] = {.lex_state = 61, .external_lex_state = 51},
  [9551] = {.lex_state = 63, .external_lex_state = 31},
  [9552] = {.lex_state = 63},
  [9553] = {.lex_state = 63, .external_lex_state = 28},
  [9554] = {.lex_state = 63, .external_lex_state = 35},
  [9555] = {.lex_state = 61, .external_lex_state = 51},
  [9556] = {.lex_state = 52, .external_lex_state = 39},
  [9557] = {.lex_state = 63, .external_lex_state = 28},
  [9558] = {.lex_state = 52, .external_lex_state = 39},
  [9559] = {.lex_state = 20, .external_lex_state = 43},
  [9560] = {.lex_state = 52, .external_lex_state = 39},
  [9561] = {.lex_state = 63},
  [9562] = {.lex_state = 56, .external_lex_state = 43},
  [9563] = {.lex_state = 63, .external_lex_state = 49},
  [9564] = {.lex_state = 58, .external_lex_state = 43},
  [9565] = {.lex_state = 63, .external_lex_state = 36},
  [9566] = {.lex_state = 52, .external_lex_state = 39},
  [9567] = {.lex_state = 52, .external_lex_state = 39},
  [9568] = {.lex_state = 52, .external_lex_state = 42},
  [9569] = {.lex_state = 52, .external_lex_state = 39},
  [9570] = {.lex_state = 61, .external_lex_state = 28},
  [9571] = {.lex_state = 63, .external_lex_state = 23},
  [9572] = {.lex_state = 61, .external_lex_state = 49},
  [9573] = {.lex_state = 65, .external_lex_state = 37},
  [9574] = {.lex_state = 61, .external_lex_state = 51},
  [9575] = {.lex_state = 61, .external_lex_state = 49},
  [9576] = {.lex_state = 61, .external_lex_state = 45},
  [9577] = {.lex_state = 61, .external_lex_state = 45},
  [9578] = {.lex_state = 61, .external_lex_state = 49},
  [9579] = {.lex_state = 52, .external_lex_state = 42},
  [9580] = {.lex_state = 63, .external_lex_state = 23},
  [9581] = {.lex_state = 61, .external_lex_state = 51},
  [9582] = {.lex_state = 61, .external_lex_state = 51},
  [9583] = {.lex_state = 61, .external_lex_state = 45},
  [9584] = {.lex_state = 63, .external_lex_state = 31},
  [9585] = {.lex_state = 63},
  [9586] = {.lex_state = 52, .external_lex_state = 42},
  [9587] = {.lex_state = 61, .external_lex_state = 51},
  [9588] = {.lex_state = 65, .external_lex_state = 37},
  [9589] = {.lex_state = 61, .external_lex_state = 51},
  [9590] = {.lex_state = 52, .external_lex_state = 39},
  [9591] = {.lex_state = 61, .external_lex_state = 45},
  [9592] = {.lex_state = 61, .external_lex_state = 51},
  [9593] = {.lex_state = 65, .external_lex_state = 37},
  [9594] = {.lex_state = 63, .external_lex_state = 31},
  [9595] = {.lex_state = 63, .external_lex_state = 31},
  [9596] = {.lex_state = 63},
  [9597] = {.lex_state = 52, .external_lex_state = 23},
  [9598] = {.lex_state = 63},
  [9599] = {.lex_state = 61, .external_lex_state = 49},
  [9600] = {.lex_state = 61, .external_lex_state = 40},
  [9601] = {.lex_state = 63, .external_lex_state = 49},
  [9602] = {.lex_state = 63, .external_lex_state = 49},
  [9603] = {.lex_state = 63, .external_lex_state = 31},
  [9604] = {.lex_state = 63, .external_lex_state = 57},
  [9605] = {.lex_state = 63, .external_lex_state = 31},
  [9606] = {.lex_state = 20, .external_lex_state = 43},
  [9607] = {.lex_state = 63, .external_lex_state = 27},
  [9608] = {.lex_state = 52, .external_lex_state = 42},
  [9609] = {.lex_state = 63, .external_lex_state = 31},
  [9610] = {.lex_state = 63},
  [9611] = {.lex_state = 63, .external_lex_state = 31},
  [9612] = {.lex_state = 52, .external_lex_state = 40},
  [9613] = {.lex_state = 14, .external_lex_state = 2},
  [9614] = {.lex_state = 63, .external_lex_state = 31},
  [9615] = {.lex_state = 63, .external_lex_state = 31},
  [9616] = {.lex_state = 63, .external_lex_state = 27},
  [9617] = {.lex_state = 63},
  [9618] = {.lex_state = 10, .external_lex_state = 43},
  [9619] = {.lex_state = 52, .external_lex_state = 39},
  [9620] = {.lex_state = 52, .external_lex_state = 39},
  [9621] = {.lex_state = 63},
  [9622] = {.lex_state = 63, .external_lex_state = 24},
  [9623] = {.lex_state = 14, .external_lex_state = 2},
  [9624] = {.lex_state = 63, .external_lex_state = 24},
  [9625] = {.lex_state = 14, .external_lex_state = 2},
  [9626] = {.lex_state = 63, .external_lex_state = 24},
  [9627] = {.lex_state = 61, .external_lex_state = 49},
  [9628] = {.lex_state = 63, .external_lex_state = 31},
  [9629] = {.lex_state = 63},
  [9630] = {.lex_state = 63, .external_lex_state = 27},
  [9631] = {.lex_state = 63},
  [9632] = {.lex_state = 63, .external_lex_state = 24},
  [9633] = {.lex_state = 63, .external_lex_state = 31},
  [9634] = {.lex_state = 61, .external_lex_state = 34},
  [9635] = {.lex_state = 63, .external_lex_state = 24},
  [9636] = {.lex_state = 61, .external_lex_state = 48},
  [9637] = {.lex_state = 63, .external_lex_state = 31},
  [9638] = {.lex_state = 52, .external_lex_state = 39},
  [9639] = {.lex_state = 63, .external_lex_state = 23},
  [9640] = {.lex_state = 63, .external_lex_state = 31},
  [9641] = {.lex_state = 63, .external_lex_state = 28},
  [9642] = {.lex_state = 63, .external_lex_state = 23},
  [9643] = {.lex_state = 63, .external_lex_state = 23},
  [9644] = {.lex_state = 63, .external_lex_state = 31},
  [9645] = {.lex_state = 63, .external_lex_state = 23},
  [9646] = {.lex_state = 63, .external_lex_state = 23},
  [9647] = {.lex_state = 63, .external_lex_state = 24},
  [9648] = {.lex_state = 63, .external_lex_state = 28},
  [9649] = {.lex_state = 63, .external_lex_state = 28},
  [9650] = {.lex_state = 63, .external_lex_state = 32},
  [9651] = {.lex_state = 52, .external_lex_state = 39},
  [9652] = {.lex_state = 65, .external_lex_state = 36},
  [9653] = {.lex_state = 63, .external_lex_state = 58},
  [9654] = {.lex_state = 63, .external_lex_state = 28},
  [9655] = {.lex_state = 61, .external_lex_state = 34},
  [9656] = {.lex_state = 63},
  [9657] = {.lex_state = 63, .external_lex_state = 31},
  [9658] = {.lex_state = 14, .external_lex_state = 2},
  [9659] = {.lex_state = 63, .external_lex_state = 31},
  [9660] = {.lex_state = 52, .external_lex_state = 32},
  [9661] = {.lex_state = 65, .external_lex_state = 36},
  [9662] = {.lex_state = 63},
  [9663] = {.lex_state = 63},
  [9664] = {.lex_state = 52, .external_lex_state = 29},
  [9665] = {.lex_state = 63, .external_lex_state = 32},
  [9666] = {.lex_state = 63},
  [9667] = {.lex_state = 63, .external_lex_state = 31},
  [9668] = {.lex_state = 58, .external_lex_state = 43},
  [9669] = {.lex_state = 52, .external_lex_state = 34},
  [9670] = {.lex_state = 63},
  [9671] = {.lex_state = 63, .external_lex_state = 28},
  [9672] = {.lex_state = 65, .external_lex_state = 37},
  [9673] = {.lex_state = 61, .external_lex_state = 45},
  [9674] = {.lex_state = 63},
  [9675] = {.lex_state = 63, .external_lex_state = 28},
  [9676] = {.lex_state = 63, .external_lex_state = 31},
  [9677] = {.lex_state = 61, .external_lex_state = 49},
  [9678] = {.lex_state = 61, .external_lex_state = 45},
  [9679] = {.lex_state = 63, .external_lex_state = 28},
  [9680] = {.lex_state = 63},
  [9681] = {.lex_state = 52, .external_lex_state = 29},
  [9682] = {.lex_state = 63, .external_lex_state = 24},
  [9683] = {.lex_state = 61, .external_lex_state = 45},
  [9684] = {.lex_state = 63, .external_lex_state = 31},
  [9685] = {.lex_state = 63, .external_lex_state = 28},
  [9686] = {.lex_state = 63},
  [9687] = {.lex_state = 63, .external_lex_state = 28},
  [9688] = {.lex_state = 63, .external_lex_state = 31},
  [9689] = {.lex_state = 63, .external_lex_state = 31},
  [9690] = {.lex_state = 64, .external_lex_state = 53},
  [9691] = {.lex_state = 63, .external_lex_state = 40},
  [9692] = {.lex_state = 52, .external_lex_state = 42},
  [9693] = {.lex_state = 52, .external_lex_state = 42},
  [9694] = {.lex_state = 52, .external_lex_state = 42},
  [9695] = {.lex_state = 21, .external_lex_state = 43},
  [9696] = {.lex_state = 63, .external_lex_state = 31},
  [9697] = {.lex_state = 52, .external_lex_state = 42},
  [9698] = {.lex_state = 63, .external_lex_state = 31},
  [9699] = {.lex_state = 61, .external_lex_state = 51},
  [9700] = {.lex_state = 61, .external_lex_state = 48},
  [9701] = {.lex_state = 63, .external_lex_state = 31},
  [9702] = {.lex_state = 64, .external_lex_state = 40},
  [9703] = {.lex_state = 14, .external_lex_state = 2},
  [9704] = {.lex_state = 19, .external_lex_state = 43},
  [9705] = {.lex_state = 61, .external_lex_state = 51},
  [9706] = {.lex_state = 61, .external_lex_state = 49},
  [9707] = {.lex_state = 63, .external_lex_state = 28},
  [9708] = {.lex_state = 63, .external_lex_state = 56},
  [9709] = {.lex_state = 52, .external_lex_state = 27},
  [9710] = {.lex_state = 63, .external_lex_state = 31},
  [9711] = {.lex_state = 52, .external_lex_state = 24},
  [9712] = {.lex_state = 65, .external_lex_state = 35},
  [9713] = {.lex_state = 65, .external_lex_state = 35},
  [9714] = {.lex_state = 65, .external_lex_state = 35},
  [9715] = {.lex_state = 63, .external_lex_state = 31},
  [9716] = {.lex_state = 61, .external_lex_state = 45},
  [9717] = {.lex_state = 63, .external_lex_state = 31},
  [9718] = {.lex_state = 61, .external_lex_state = 45},
  [9719] = {.lex_state = 3},
  [9720] = {.lex_state = 21, .external_lex_state = 43},
  [9721] = {.lex_state = 61, .external_lex_state = 45},
  [9722] = {.lex_state = 52, .external_lex_state = 39},
  [9723] = {.lex_state = 63},
  [9724] = {.lex_state = 52, .external_lex_state = 39},
  [9725] = {.lex_state = 52, .external_lex_state = 39},
  [9726] = {.lex_state = 61, .external_lex_state = 45},
  [9727] = {.lex_state = 63, .external_lex_state = 24},
  [9728] = {.lex_state = 63},
  [9729] = {.lex_state = 63},
  [9730] = {.lex_state = 61, .external_lex_state = 45},
  [9731] = {.lex_state = 62, .external_lex_state = 43},
  [9732] = {.lex_state = 61, .external_lex_state = 27},
  [9733] = {.lex_state = 61, .external_lex_state = 57},
  [9734] = {.lex_state = 61, .external_lex_state = 27},
  [9735] = {.lex_state = 56, .external_lex_state = 43},
  [9736] = {.lex_state = 62, .external_lex_state = 24},
  [9737] = {.lex_state = 63, .external_lex_state = 36},
  [9738] = {.lex_state = 65, .external_lex_state = 42},
  [9739] = {.lex_state = 51},
  [9740] = {.lex_state = 62, .external_lex_state = 24},
  [9741] = {.lex_state = 56, .external_lex_state = 43},
  [9742] = {.lex_state = 65, .external_lex_state = 42},
  [9743] = {.lex_state = 61, .external_lex_state = 58},
  [9744] = {.lex_state = 65, .external_lex_state = 42},
  [9745] = {.lex_state = 63, .external_lex_state = 37},
  [9746] = {.lex_state = 63, .external_lex_state = 36},
  [9747] = {.lex_state = 61, .external_lex_state = 56},
  [9748] = {.lex_state = 63, .external_lex_state = 35},
  [9749] = {.lex_state = 63},
  [9750] = {.lex_state = 56, .external_lex_state = 43},
  [9751] = {.lex_state = 63, .external_lex_state = 35},
  [9752] = {.lex_state = 63, .external_lex_state = 28},
  [9753] = {.lex_state = 63, .external_lex_state = 35},
  [9754] = {.lex_state = 52, .external_lex_state = 45},
  [9755] = {.lex_state = 62, .external_lex_state = 23},
  [9756] = {.lex_state = 56, .external_lex_state = 43},
  [9757] = {.lex_state = 62, .external_lex_state = 23},
  [9758] = {.lex_state = 63, .external_lex_state = 40},
  [9759] = {.lex_state = 61, .external_lex_state = 56},
  [9760] = {.lex_state = 61, .external_lex_state = 57},
  [9761] = {.lex_state = 63, .external_lex_state = 35},
  [9762] = {.lex_state = 63, .external_lex_state = 36},
  [9763] = {.lex_state = 51},
  [9764] = {.lex_state = 63, .external_lex_state = 36},
  [9765] = {.lex_state = 63, .external_lex_state = 35},
  [9766] = {.lex_state = 56, .external_lex_state = 43},
  [9767] = {.lex_state = 62, .external_lex_state = 23},
  [9768] = {.lex_state = 52, .external_lex_state = 24},
  [9769] = {.lex_state = 63, .external_lex_state = 58},
  [9770] = {.lex_state = 63, .external_lex_state = 58},
  [9771] = {.lex_state = 61, .external_lex_state = 58},
  [9772] = {.lex_state = 63, .external_lex_state = 57},
  [9773] = {.lex_state = 52, .external_lex_state = 48},
  [9774] = {.lex_state = 52, .external_lex_state = 24},
  [9775] = {.lex_state = 20, .external_lex_state = 43},
  [9776] = {.lex_state = 56, .external_lex_state = 43},
  [9777] = {.lex_state = 61, .external_lex_state = 58},
  [9778] = {.lex_state = 61, .external_lex_state = 27},
  [9779] = {.lex_state = 56, .external_lex_state = 43},
  [9780] = {.lex_state = 65, .external_lex_state = 42},
  [9781] = {.lex_state = 52, .external_lex_state = 48},
  [9782] = {.lex_state = 61, .external_lex_state = 27},
  [9783] = {.lex_state = 11, .external_lex_state = 43},
  [9784] = {.lex_state = 63, .external_lex_state = 36},
  [9785] = {.lex_state = 11, .external_lex_state = 43},
  [9786] = {.lex_state = 63, .external_lex_state = 36},
  [9787] = {.lex_state = 56, .external_lex_state = 43},
  [9788] = {.lex_state = 52, .external_lex_state = 48},
  [9789] = {.lex_state = 63, .external_lex_state = 57},
  [9790] = {.lex_state = 52, .external_lex_state = 51},
  [9791] = {.lex_state = 63, .external_lex_state = 24},
  [9792] = {.lex_state = 56, .external_lex_state = 43},
  [9793] = {.lex_state = 52, .external_lex_state = 48},
  [9794] = {.lex_state = 63, .external_lex_state = 23},
  [9795] = {.lex_state = 63, .external_lex_state = 40},
  [9796] = {.lex_state = 56, .external_lex_state = 43},
  [9797] = {.lex_state = 63, .external_lex_state = 36},
  [9798] = {.lex_state = 61, .external_lex_state = 27},
  [9799] = {.lex_state = 51},
  [9800] = {.lex_state = 63, .external_lex_state = 36},
  [9801] = {.lex_state = 64, .external_lex_state = 24},
  [9802] = {.lex_state = 52, .external_lex_state = 48},
  [9803] = {.lex_state = 61, .external_lex_state = 40},
  [9804] = {.lex_state = 63, .external_lex_state = 58},
  [9805] = {.lex_state = 56, .external_lex_state = 43},
  [9806] = {.lex_state = 61, .external_lex_state = 57},
  [9807] = {.lex_state = 52, .external_lex_state = 48},
  [9808] = {.lex_state = 52, .external_lex_state = 56},
  [9809] = {.lex_state = 56, .external_lex_state = 43},
  [9810] = {.lex_state = 61, .external_lex_state = 27},
  [9811] = {.lex_state = 52, .external_lex_state = 51},
  [9812] = {.lex_state = 51},
  [9813] = {.lex_state = 56, .external_lex_state = 43},
  [9814] = {.lex_state = 63, .external_lex_state = 36},
  [9815] = {.lex_state = 63, .external_lex_state = 35},
  [9816] = {.lex_state = 61, .external_lex_state = 57},
  [9817] = {.lex_state = 52, .external_lex_state = 24},
  [9818] = {.lex_state = 63, .external_lex_state = 36},
  [9819] = {.lex_state = 56, .external_lex_state = 43},
  [9820] = {.lex_state = 61, .external_lex_state = 27},
  [9821] = {.lex_state = 63, .external_lex_state = 57},
  [9822] = {.lex_state = 63, .external_lex_state = 35},
  [9823] = {.lex_state = 19, .external_lex_state = 43},
  [9824] = {.lex_state = 56, .external_lex_state = 43},
  [9825] = {.lex_state = 63, .external_lex_state = 35},
  [9826] = {.lex_state = 4},
  [9827] = {.lex_state = 63, .external_lex_state = 35},
  [9828] = {.lex_state = 51},
  [9829] = {.lex_state = 61, .external_lex_state = 27},
  [9830] = {.lex_state = 62, .external_lex_state = 24},
  [9831] = {.lex_state = 11, .external_lex_state = 43},
  [9832] = {.lex_state = 63, .external_lex_state = 48},
  [9833] = {.lex_state = 61, .external_lex_state = 57},
  [9834] = {.lex_state = 56, .external_lex_state = 43},
  [9835] = {.lex_state = 52, .external_lex_state = 24},
  [9836] = {.lex_state = 51},
  [9837] = {.lex_state = 63, .external_lex_state = 35},
  [9838] = {.lex_state = 52, .external_lex_state = 24},
  [9839] = {.lex_state = 63, .external_lex_state = 35},
  [9840] = {.lex_state = 56, .external_lex_state = 43},
  [9841] = {.lex_state = 51},
  [9842] = {.lex_state = 52, .external_lex_state = 34},
  [9843] = {.lex_state = 61, .external_lex_state = 56},
  [9844] = {.lex_state = 63, .external_lex_state = 36},
  [9845] = {.lex_state = 56, .external_lex_state = 43},
  [9846] = {.lex_state = 65, .external_lex_state = 39},
  [9847] = {.lex_state = 51},
  [9848] = {.lex_state = 11, .external_lex_state = 43},
  [9849] = {.lex_state = 52, .external_lex_state = 48},
  [9850] = {.lex_state = 52, .external_lex_state = 45},
  [9851] = {.lex_state = 63, .external_lex_state = 35},
  [9852] = {.lex_state = 52, .external_lex_state = 24},
  [9853] = {.lex_state = 61, .external_lex_state = 27},
  [9854] = {.lex_state = 56, .external_lex_state = 43},
  [9855] = {.lex_state = 61, .external_lex_state = 57},
  [9856] = {.lex_state = 63, .external_lex_state = 35},
  [9857] = {.lex_state = 61, .external_lex_state = 57},
  [9858] = {.lex_state = 61, .external_lex_state = 27},
  [9859] = {.lex_state = 61},
  [9860] = {.lex_state = 63, .external_lex_state = 35},
  [9861] = {.lex_state = 64, .external_lex_state = 40},
  [9862] = {.lex_state = 65, .external_lex_state = 39},
  [9863] = {.lex_state = 63, .external_lex_state = 37},
  [9864] = {.lex_state = 61, .external_lex_state = 56},
  [9865] = {.lex_state = 62, .external_lex_state = 24},
  [9866] = {.lex_state = 61},
  [9867] = {.lex_state = 11, .external_lex_state = 43},
  [9868] = {.lex_state = 65, .external_lex_state = 39},
  [9869] = {.lex_state = 61, .external_lex_state = 56},
  [9870] = {.lex_state = 61, .external_lex_state = 56},
  [9871] = {.lex_state = 53, .external_lex_state = 23},
  [9872] = {.lex_state = 63, .external_lex_state = 57},
  [9873] = {.lex_state = 52, .external_lex_state = 56},
  [9874] = {.lex_state = 63, .external_lex_state = 35},
  [9875] = {.lex_state = 52, .external_lex_state = 48},
  [9876] = {.lex_state = 52, .external_lex_state = 24},
  [9877] = {.lex_state = 4},
  [9878] = {.lex_state = 52, .external_lex_state = 43},
  [9879] = {.lex_state = 63, .external_lex_state = 28},
  [9880] = {.lex_state = 63, .external_lex_state = 31},
  [9881] = {.lex_state = 52, .external_lex_state = 48},
  [9882] = {.lex_state = 63, .external_lex_state = 35},
  [9883] = {.lex_state = 63, .external_lex_state = 35},
  [9884] = {.lex_state = 63, .external_lex_state = 35},
  [9885] = {.lex_state = 63},
  [9886] = {.lex_state = 61, .external_lex_state = 58},
  [9887] = {.lex_state = 52, .external_lex_state = 51},
  [9888] = {.lex_state = 61, .external_lex_state = 58},
  [9889] = {.lex_state = 61, .external_lex_state = 27},
  [9890] = {.lex_state = 52, .external_lex_state = 45},
  [9891] = {.lex_state = 52, .external_lex_state = 51},
  [9892] = {.lex_state = 62, .external_lex_state = 24},
  [9893] = {.lex_state = 52, .external_lex_state = 45},
  [9894] = {.lex_state = 52, .external_lex_state = 59},
  [9895] = {.lex_state = 52},
  [9896] = {.lex_state = 52, .external_lex_state = 51},
  [9897] = {.lex_state = 65, .external_lex_state = 23},
  [9898] = {.lex_state = 52, .external_lex_state = 45},
  [9899] = {.lex_state = 51},
  [9900] = {.lex_state = 63, .external_lex_state = 35},
  [9901] = {.lex_state = 61, .external_lex_state = 58},
  [9902] = {.lex_state = 51},
  [9903] = {.lex_state = 61, .external_lex_state = 36},
  [9904] = {.lex_state = 51},
  [9905] = {.lex_state = 63, .external_lex_state = 35},
  [9906] = {.lex_state = 52, .external_lex_state = 51},
  [9907] = {.lex_state = 52},
  [9908] = {.lex_state = 52, .external_lex_state = 24},
  [9909] = {.lex_state = 52, .external_lex_state = 51},
  [9910] = {.lex_state = 63, .external_lex_state = 35},
  [9911] = {.lex_state = 52, .external_lex_state = 51},
  [9912] = {.lex_state = 65, .external_lex_state = 23},
  [9913] = {.lex_state = 52, .external_lex_state = 24},
  [9914] = {.lex_state = 61, .external_lex_state = 56},
  [9915] = {.lex_state = 52, .external_lex_state = 24},
  [9916] = {.lex_state = 63, .external_lex_state = 27},
  [9917] = {.lex_state = 61, .external_lex_state = 56},
  [9918] = {.lex_state = 52, .external_lex_state = 24},
  [9919] = {.lex_state = 52, .external_lex_state = 24},
  [9920] = {.lex_state = 63, .external_lex_state = 31},
  [9921] = {.lex_state = 62, .external_lex_state = 24},
  [9922] = {.lex_state = 52, .external_lex_state = 51},
  [9923] = {.lex_state = 62, .external_lex_state = 24},
  [9924] = {.lex_state = 52, .external_lex_state = 49},
  [9925] = {.lex_state = 52, .external_lex_state = 49},
  [9926] = {.lex_state = 61, .external_lex_state = 57},
  [9927] = {.lex_state = 52, .external_lex_state = 49},
  [9928] = {.lex_state = 52, .external_lex_state = 40},
  [9929] = {.lex_state = 52, .external_lex_state = 45},
  [9930] = {.lex_state = 61, .external_lex_state = 57},
  [9931] = {.lex_state = 51},
  [9932] = {.lex_state = 61, .external_lex_state = 57},
  [9933] = {.lex_state = 61},
  [9934] = {.lex_state = 52, .external_lex_state = 49},
  [9935] = {.lex_state = 11, .external_lex_state = 43},
  [9936] = {.lex_state = 19, .external_lex_state = 43},
  [9937] = {.lex_state = 63, .external_lex_state = 35},
  [9938] = {.lex_state = 61, .external_lex_state = 58},
  [9939] = {.lex_state = 61, .external_lex_state = 35},
  [9940] = {.lex_state = 61, .external_lex_state = 56},
  [9941] = {.lex_state = 52, .external_lex_state = 45},
  [9942] = {.lex_state = 52, .external_lex_state = 49},
  [9943] = {.lex_state = 63, .external_lex_state = 35},
  [9944] = {.lex_state = 52, .external_lex_state = 49},
  [9945] = {.lex_state = 62, .external_lex_state = 23},
  [9946] = {.lex_state = 11, .external_lex_state = 43},
  [9947] = {.lex_state = 52, .external_lex_state = 51},
  [9948] = {.lex_state = 52, .external_lex_state = 24},
  [9949] = {.lex_state = 52, .external_lex_state = 49},
  [9950] = {.lex_state = 61, .external_lex_state = 58},
  [9951] = {.lex_state = 61, .external_lex_state = 58},
  [9952] = {.lex_state = 52, .external_lex_state = 48},
  [9953] = {.lex_state = 61, .external_lex_state = 58},
  [9954] = {.lex_state = 51},
  [9955] = {.lex_state = 63, .external_lex_state = 36},
  [9956] = {.lex_state = 61, .external_lex_state = 58},
  [9957] = {.lex_state = 52, .external_lex_state = 49},
  [9958] = {.lex_state = 63, .external_lex_state = 35},
  [9959] = {.lex_state = 52, .external_lex_state = 48},
  [9960] = {.lex_state = 52, .external_lex_state = 45},
  [9961] = {.lex_state = 63, .external_lex_state = 36},
  [9962] = {.lex_state = 51},
  [9963] = {.lex_state = 51},
  [9964] = {.lex_state = 63, .external_lex_state = 27},
  [9965] = {.lex_state = 63, .external_lex_state = 36},
  [9966] = {.lex_state = 61, .external_lex_state = 56},
  [9967] = {.lex_state = 63, .external_lex_state = 36},
  [9968] = {.lex_state = 3},
  [9969] = {.lex_state = 65, .external_lex_state = 42},
  [9970] = {.lex_state = 63, .external_lex_state = 36},
  [9971] = {.lex_state = 20, .external_lex_state = 43},
  [9972] = {.lex_state = 63, .external_lex_state = 56},
  [9973] = {.lex_state = 61},
  [9974] = {.lex_state = 63, .external_lex_state = 36},
  [9975] = {.lex_state = 63, .external_lex_state = 31},
  [9976] = {.lex_state = 63, .external_lex_state = 35},
  [9977] = {.lex_state = 51},
  [9978] = {.lex_state = 63, .external_lex_state = 36},
  [9979] = {.lex_state = 52, .external_lex_state = 51},
  [9980] = {.lex_state = 62, .external_lex_state = 24},
  [9981] = {.lex_state = 63, .external_lex_state = 36},
  [9982] = {.lex_state = 58, .external_lex_state = 59},
  [9983] = {.lex_state = 63, .external_lex_state = 36},
  [9984] = {.lex_state = 52, .external_lex_state = 23},
  [9985] = {.lex_state = 52, .external_lex_state = 24},
  [9986] = {.lex_state = 11, .external_lex_state = 43},
  [9987] = {.lex_state = 63, .external_lex_state = 39},
  [9988] = {.lex_state = 63, .external_lex_state = 37},
  [9989] = {.lex_state = 63, .external_lex_state = 23},
  [9990] = {.lex_state = 51},
  [9991] = {.lex_state = 63, .external_lex_state = 35},
  [9992] = {.lex_state = 63, .external_lex_state = 36},
  [9993] = {.lex_state = 63, .external_lex_state = 36},
  [9994] = {.lex_state = 56, .external_lex_state = 43},
  [9995] = {.lex_state = 63, .external_lex_state = 36},
  [9996] = {.lex_state = 52, .external_lex_state = 45},
  [9997] = {.lex_state = 63, .external_lex_state = 36},
  [9998] = {.lex_state = 11, .external_lex_state = 43},
  [9999] = {.lex_state = 63, .external_lex_state = 36},
  [10000] = {.lex_state = 62, .external_lex_state = 23},
  [10001] = {.lex_state = 63, .external_lex_state = 36},
  [10002] = {.lex_state = 63, .external_lex_state = 36},
  [10003] = {.lex_state = 62, .external_lex_state = 24},
  [10004] = {.lex_state = 62, .external_lex_state = 24},
  [10005] = {.lex_state = 62, .external_lex_state = 24},
  [10006] = {.lex_state = 58, .external_lex_state = 59},
  [10007] = {.lex_state = 63, .external_lex_state = 36},
  [10008] = {.lex_state = 63, .external_lex_state = 36},
  [10009] = {.lex_state = 52, .external_lex_state = 49},
  [10010] = {.lex_state = 52, .external_lex_state = 45},
  [10011] = {.lex_state = 63, .external_lex_state = 58},
  [10012] = {.lex_state = 52, .external_lex_state = 45},
  [10013] = {.lex_state = 52, .external_lex_state = 32},
  [10014] = {.lex_state = 63, .external_lex_state = 35},
  [10015] = {.lex_state = 64, .external_lex_state = 23},
  [10016] = {.lex_state = 52, .external_lex_state = 59},
  [10017] = {.lex_state = 62, .external_lex_state = 23},
  [10018] = {.lex_state = 63, .external_lex_state = 23},
  [10019] = {.lex_state = 51},
  [10020] = {.lex_state = 51},
  [10021] = {.lex_state = 63, .external_lex_state = 36},
  [10022] = {.lex_state = 62, .external_lex_state = 23},
  [10023] = {.lex_state = 63, .external_lex_state = 36},
  [10024] = {.lex_state = 51},
  [10025] = {.lex_state = 52, .external_lex_state = 49},
  [10026] = {.lex_state = 52, .external_lex_state = 49},
  [10027] = {.lex_state = 62, .external_lex_state = 23},
  [10028] = {.lex_state = 65, .external_lex_state = 23},
  [10029] = {.lex_state = 62, .external_lex_state = 23},
  [10030] = {.lex_state = 65, .external_lex_state = 23},
  [10031] = {.lex_state = 65, .external_lex_state = 23},
  [10032] = {.lex_state = 63, .external_lex_state = 36},
  [10033] = {.lex_state = 62, .external_lex_state = 23},
  [10034] = {.lex_state = 52, .external_lex_state = 48},
  [10035] = {.lex_state = 63, .external_lex_state = 36},
  [10036] = {.lex_state = 62, .external_lex_state = 23},
  [10037] = {.lex_state = 63, .external_lex_state = 36},
  [10038] = {.lex_state = 52, .external_lex_state = 51},
  [10039] = {.lex_state = 63, .external_lex_state = 37},
  [10040] = {.lex_state = 61, .external_lex_state = 56},
  [10041] = {.lex_state = 52, .external_lex_state = 40},
  [10042] = {.lex_state = 63, .external_lex_state = 36},
  [10043] = {.lex_state = 52, .external_lex_state = 24},
  [10044] = {.lex_state = 21},
  [10045] = {.lex_state = 61},
  [10046] = {.lex_state = 11, .external_lex_state = 43},
  [10047] = {.lex_state = 11, .external_lex_state = 43},
  [10048] = {.lex_state = 61, .external_lex_state = 56},
  [10049] = {.lex_state = 61, .external_lex_state = 56},
  [10050] = {.lex_state = 11, .external_lex_state = 43},
  [10051] = {.lex_state = 11, .external_lex_state = 43},
  [10052] = {.lex_state = 62, .external_lex_state = 24},
  [10053] = {.lex_state = 56, .external_lex_state = 43},
  [10054] = {.lex_state = 61},
  [10055] = {.lex_state = 61},
  [10056] = {.lex_state = 52, .external_lex_state = 48},
  [10057] = {.lex_state = 65, .external_lex_state = 39},
  [10058] = {.lex_state = 63, .external_lex_state = 23},
  [10059] = {.lex_state = 61},
  [10060] = {.lex_state = 11, .external_lex_state = 43},
  [10061] = {.lex_state = 52, .external_lex_state = 32},
  [10062] = {.lex_state = 62, .external_lex_state = 24},
  [10063] = {.lex_state = 61, .external_lex_state = 57},
  [10064] = {.lex_state = 11, .external_lex_state = 43},
  [10065] = {.lex_state = 52, .external_lex_state = 28},
  [10066] = {.lex_state = 11, .external_lex_state = 43},
  [10067] = {.lex_state = 61},
  [10068] = {.lex_state = 63, .external_lex_state = 35},
  [10069] = {.lex_state = 61, .external_lex_state = 40},
  [10070] = {.lex_state = 52, .external_lex_state = 45},
  [10071] = {.lex_state = 52, .external_lex_state = 45},
  [10072] = {.lex_state = 11, .external_lex_state = 43},
  [10073] = {.lex_state = 61, .external_lex_state = 56},
  [10074] = {.lex_state = 51},
  [10075] = {.lex_state = 63, .external_lex_state = 28},
  [10076] = {.lex_state = 61, .external_lex_state = 57},
  [10077] = {.lex_state = 63, .external_lex_state = 35},
  [10078] = {.lex_state = 61},
  [10079] = {.lex_state = 20, .external_lex_state = 43},
  [10080] = {.lex_state = 63, .external_lex_state = 35},
  [10081] = {.lex_state = 61},
  [10082] = {.lex_state = 62, .external_lex_state = 24},
  [10083] = {.lex_state = 61},
  [10084] = {.lex_state = 62, .external_lex_state = 23},
  [10085] = {.lex_state = 61},
  [10086] = {.lex_state = 63, .external_lex_state = 35},
  [10087] = {.lex_state = 52, .external_lex_state = 49},
  [10088] = {.lex_state = 56, .external_lex_state = 43},
  [10089] = {.lex_state = 61},
  [10090] = {.lex_state = 63, .external_lex_state = 35},
  [10091] = {.lex_state = 64, .external_lex_state = 40},
  [10092] = {.lex_state = 63, .external_lex_state = 36},
  [10093] = {.lex_state = 61, .external_lex_state = 57},
  [10094] = {.lex_state = 3},
  [10095] = {.lex_state = 63, .external_lex_state = 56},
  [10096] = {.lex_state = 20, .external_lex_state = 43},
  [10097] = {.lex_state = 63, .external_lex_state = 45},
  [10098] = {.lex_state = 63},
  [10099] = {.lex_state = 63, .external_lex_state = 42},
  [10100] = {.lex_state = 63, .external_lex_state = 35},
  [10101] = {.lex_state = 56, .external_lex_state = 43},
  [10102] = {.lex_state = 63},
  [10103] = {.lex_state = 61, .external_lex_state = 58},
  [10104] = {.lex_state = 52, .external_lex_state = 51},
  [10105] = {.lex_state = 63},
  [10106] = {.lex_state = 52, .external_lex_state = 34},
  [10107] = {.lex_state = 52, .external_lex_state = 48},
  [10108] = {.lex_state = 62, .external_lex_state = 23},
  [10109] = {.lex_state = 52, .external_lex_state = 51},
  [10110] = {.lex_state = 52, .external_lex_state = 31},
  [10111] = {.lex_state = 52, .external_lex_state = 49},
  [10112] = {.lex_state = 61, .external_lex_state = 27},
  [10113] = {.lex_state = 56, .external_lex_state = 43},
  [10114] = {.lex_state = 61, .external_lex_state = 27},
  [10115] = {.lex_state = 61, .external_lex_state = 27},
  [10116] = {.lex_state = 65, .external_lex_state = 39},
  [10117] = {.lex_state = 61, .external_lex_state = 58},
  [10118] = {.lex_state = 62, .external_lex_state = 23},
  [10119] = {.lex_state = 61, .external_lex_state = 58},
  [10120] = {.lex_state = 63, .external_lex_state = 35},
  [10121] = {.lex_state = 61, .external_lex_state = 57},
  [10122] = {.lex_state = 52, .external_lex_state = 45},
  [10123] = {.lex_state = 52, .external_lex_state = 49},
  [10124] = {.lex_state = 63, .external_lex_state = 35},
  [10125] = {.lex_state = 63, .external_lex_state = 35},
  [10126] = {.lex_state = 54, .external_lex_state = 25},
  [10127] = {.lex_state = 63, .external_lex_state = 25},
  [10128] = {.lex_state = 65, .external_lex_state = 49},
  [10129] = {.lex_state = 3},
  [10130] = {.lex_state = 63},
  [10131] = {.lex_state = 63, .external_lex_state = 25},
  [10132] = {.lex_state = 61, .external_lex_state = 28},
  [10133] = {.lex_state = 62, .external_lex_state = 23},
  [10134] = {.lex_state = 20, .external_lex_state = 43},
  [10135] = {.lex_state = 56, .external_lex_state = 43},
  [10136] = {.lex_state = 56, .external_lex_state = 43},
  [10137] = {.lex_state = 56, .external_lex_state = 43},
  [10138] = {.lex_state = 63, .external_lex_state = 45},
  [10139] = {.lex_state = 52, .external_lex_state = 58},
  [10140] = {.lex_state = 52, .external_lex_state = 56},
  [10141] = {.lex_state = 65, .external_lex_state = 45},
  [10142] = {.lex_state = 63, .external_lex_state = 23},
  [10143] = {.lex_state = 3},
  [10144] = {.lex_state = 65, .external_lex_state = 45},
  [10145] = {.lex_state = 65, .external_lex_state = 45},
  [10146] = {.lex_state = 56, .external_lex_state = 43},
  [10147] = {.lex_state = 56, .external_lex_state = 43},
  [10148] = {.lex_state = 63, .external_lex_state = 23},
  [10149] = {.lex_state = 17},
  [10150] = {.lex_state = 56, .external_lex_state = 43},
  [10151] = {.lex_state = 61, .external_lex_state = 28},
  [10152] = {.lex_state = 61, .external_lex_state = 28},
  [10153] = {.lex_state = 3},
  [10154] = {.lex_state = 62, .external_lex_state = 23},
  [10155] = {.lex_state = 63, .external_lex_state = 25},
  [10156] = {.lex_state = 63, .external_lex_state = 23},
  [10157] = {.lex_state = 61, .external_lex_state = 24},
  [10158] = {.lex_state = 3},
  [10159] = {.lex_state = 17},
  [10160] = {.lex_state = 63, .external_lex_state = 25},
  [10161] = {.lex_state = 63, .external_lex_state = 25},
  [10162] = {.lex_state = 52, .external_lex_state = 57},
  [10163] = {.lex_state = 4},
  [10164] = {.lex_state = 21, .external_lex_state = 43},
  [10165] = {.lex_state = 62, .external_lex_state = 23},
  [10166] = {.lex_state = 52, .external_lex_state = 58},
  [10167] = {.lex_state = 21, .external_lex_state = 43},
  [10168] = {.lex_state = 63, .external_lex_state = 23},
  [10169] = {.lex_state = 61, .external_lex_state = 28},
  [10170] = {.lex_state = 61, .external_lex_state = 28},
  [10171] = {.lex_state = 61, .external_lex_state = 28},
  [10172] = {.lex_state = 3},
  [10173] = {.lex_state = 62, .external_lex_state = 23},
  [10174] = {.lex_state = 63, .external_lex_state = 56},
  [10175] = {.lex_state = 62},
  [10176] = {.lex_state = 61, .external_lex_state = 28},
  [10177] = {.lex_state = 61, .external_lex_state = 28},
  [10178] = {.lex_state = 61, .external_lex_state = 28},
  [10179] = {.lex_state = 63, .external_lex_state = 36},
  [10180] = {.lex_state = 19, .external_lex_state = 43},
  [10181] = {.lex_state = 52, .external_lex_state = 56},
  [10182] = {.lex_state = 52, .external_lex_state = 56},
  [10183] = {.lex_state = 19},
  [10184] = {.lex_state = 62, .external_lex_state = 23},
  [10185] = {.lex_state = 63, .external_lex_state = 48},
  [10186] = {.lex_state = 52, .external_lex_state = 56},
  [10187] = {.lex_state = 61, .external_lex_state = 24},
  [10188] = {.lex_state = 21, .external_lex_state = 43},
  [10189] = {.lex_state = 63, .external_lex_state = 25},
  [10190] = {.lex_state = 52, .external_lex_state = 56},
  [10191] = {.lex_state = 52, .external_lex_state = 23},
  [10192] = {.lex_state = 54, .external_lex_state = 60},
  [10193] = {.lex_state = 62, .external_lex_state = 23},
  [10194] = {.lex_state = 61, .external_lex_state = 31},
  [10195] = {.lex_state = 56, .external_lex_state = 43},
  [10196] = {.lex_state = 61, .external_lex_state = 24},
  [10197] = {.lex_state = 17},
  [10198] = {.lex_state = 52, .external_lex_state = 56},
  [10199] = {.lex_state = 63, .external_lex_state = 23},
  [10200] = {.lex_state = 63, .external_lex_state = 25},
  [10201] = {.lex_state = 17},
  [10202] = {.lex_state = 61, .external_lex_state = 28},
  [10203] = {.lex_state = 62, .external_lex_state = 23},
  [10204] = {.lex_state = 17},
  [10205] = {.lex_state = 52, .external_lex_state = 57},
  [10206] = {.lex_state = 52},
  [10207] = {.lex_state = 52, .external_lex_state = 58},
  [10208] = {.lex_state = 63, .external_lex_state = 25},
  [10209] = {.lex_state = 65, .external_lex_state = 51},
  [10210] = {.lex_state = 56, .external_lex_state = 43},
  [10211] = {.lex_state = 52, .external_lex_state = 59},
  [10212] = {.lex_state = 63, .external_lex_state = 23},
  [10213] = {.lex_state = 17},
  [10214] = {.lex_state = 63, .external_lex_state = 36},
  [10215] = {.lex_state = 61, .external_lex_state = 31},
  [10216] = {.lex_state = 52, .external_lex_state = 57},
  [10217] = {.lex_state = 63, .external_lex_state = 39},
  [10218] = {.lex_state = 63, .external_lex_state = 25},
  [10219] = {.lex_state = 56, .external_lex_state = 43},
  [10220] = {.lex_state = 52, .external_lex_state = 56},
  [10221] = {.lex_state = 52, .external_lex_state = 56},
  [10222] = {.lex_state = 4},
  [10223] = {.lex_state = 65, .external_lex_state = 49},
  [10224] = {.lex_state = 52, .external_lex_state = 35},
  [10225] = {.lex_state = 61, .external_lex_state = 31},
  [10226] = {.lex_state = 3},
  [10227] = {.lex_state = 52, .external_lex_state = 59},
  [10228] = {.lex_state = 61, .external_lex_state = 28},
  [10229] = {.lex_state = 52, .external_lex_state = 27},
  [10230] = {.lex_state = 63, .external_lex_state = 28},
  [10231] = {.lex_state = 61, .external_lex_state = 24},
  [10232] = {.lex_state = 63, .external_lex_state = 31},
  [10233] = {.lex_state = 56, .external_lex_state = 43},
  [10234] = {.lex_state = 65, .external_lex_state = 45},
  [10235] = {.lex_state = 52, .external_lex_state = 58},
  [10236] = {.lex_state = 52, .external_lex_state = 59},
  [10237] = {.lex_state = 52, .external_lex_state = 27},
  [10238] = {.lex_state = 52, .external_lex_state = 58},
  [10239] = {.lex_state = 61, .external_lex_state = 31},
  [10240] = {.lex_state = 65, .external_lex_state = 51},
  [10241] = {.lex_state = 63, .external_lex_state = 49},
  [10242] = {.lex_state = 65, .external_lex_state = 48},
  [10243] = {.lex_state = 63, .external_lex_state = 25},
  [10244] = {.lex_state = 63, .external_lex_state = 23},
  [10245] = {.lex_state = 3},
  [10246] = {.lex_state = 52, .external_lex_state = 58},
  [10247] = {.lex_state = 63},
  [10248] = {.lex_state = 52, .external_lex_state = 27},
  [10249] = {.lex_state = 63, .external_lex_state = 25},
  [10250] = {.lex_state = 52, .external_lex_state = 58},
  [10251] = {.lex_state = 65, .external_lex_state = 51},
  [10252] = {.lex_state = 65, .external_lex_state = 51},
  [10253] = {.lex_state = 3},
  [10254] = {.lex_state = 63, .external_lex_state = 23},
  [10255] = {.lex_state = 56, .external_lex_state = 43},
  [10256] = {.lex_state = 63, .external_lex_state = 23},
  [10257] = {.lex_state = 63, .external_lex_state = 23},
  [10258] = {.lex_state = 4},
  [10259] = {.lex_state = 52, .external_lex_state = 57},
  [10260] = {.lex_state = 62},
  [10261] = {.lex_state = 4},
  [10262] = {.lex_state = 65, .external_lex_state = 48},
  [10263] = {.lex_state = 63, .external_lex_state = 23},
  [10264] = {.lex_state = 52, .external_lex_state = 57},
  [10265] = {.lex_state = 63, .external_lex_state = 39},
  [10266] = {.lex_state = 62},
  [10267] = {.lex_state = 63, .external_lex_state = 25},
  [10268] = {.lex_state = 52, .external_lex_state = 27},
  [10269] = {.lex_state = 62, .external_lex_state = 23},
  [10270] = {.lex_state = 56, .external_lex_state = 43},
  [10271] = {.lex_state = 63, .external_lex_state = 23},
  [10272] = {.lex_state = 52, .external_lex_state = 57},
  [10273] = {.lex_state = 63, .external_lex_state = 24},
  [10274] = {.lex_state = 61, .external_lex_state = 23},
  [10275] = {.lex_state = 56, .external_lex_state = 43},
  [10276] = {.lex_state = 63, .external_lex_state = 25},
  [10277] = {.lex_state = 61, .external_lex_state = 31},
  [10278] = {.lex_state = 52, .external_lex_state = 56},
  [10279] = {.lex_state = 63, .external_lex_state = 23},
  [10280] = {.lex_state = 65, .external_lex_state = 48},
  [10281] = {.lex_state = 3},
  [10282] = {.lex_state = 3},
  [10283] = {.lex_state = 52, .external_lex_state = 23},
  [10284] = {.lex_state = 63, .external_lex_state = 25},
  [10285] = {.lex_state = 19, .external_lex_state = 43},
  [10286] = {.lex_state = 56, .external_lex_state = 43},
  [10287] = {.lex_state = 65, .external_lex_state = 51},
  [10288] = {.lex_state = 61, .external_lex_state = 24},
  [10289] = {.lex_state = 65, .external_lex_state = 45},
  [10290] = {.lex_state = 63, .external_lex_state = 23},
  [10291] = {.lex_state = 51},
  [10292] = {.lex_state = 56, .external_lex_state = 43},
  [10293] = {.lex_state = 52, .external_lex_state = 27},
  [10294] = {.lex_state = 63, .external_lex_state = 25},
  [10295] = {.lex_state = 17},
  [10296] = {.lex_state = 21, .external_lex_state = 43},
  [10297] = {.lex_state = 61, .external_lex_state = 31},
  [10298] = {.lex_state = 63},
  [10299] = {.lex_state = 52, .external_lex_state = 58},
  [10300] = {.lex_state = 17},
  [10301] = {.lex_state = 52, .external_lex_state = 27},
  [10302] = {.lex_state = 63, .external_lex_state = 24},
  [10303] = {.lex_state = 65},
  [10304] = {.lex_state = 63, .external_lex_state = 25},
  [10305] = {.lex_state = 63, .external_lex_state = 42},
  [10306] = {.lex_state = 63, .external_lex_state = 23},
  [10307] = {.lex_state = 63, .external_lex_state = 39},
  [10308] = {.lex_state = 17},
  [10309] = {.lex_state = 52, .external_lex_state = 58},
  [10310] = {.lex_state = 17},
  [10311] = {.lex_state = 17},
  [10312] = {.lex_state = 17},
  [10313] = {.lex_state = 61, .external_lex_state = 24},
  [10314] = {.lex_state = 63, .external_lex_state = 28},
  [10315] = {.lex_state = 56, .external_lex_state = 43},
  [10316] = {.lex_state = 61, .external_lex_state = 24},
  [10317] = {.lex_state = 63, .external_lex_state = 25},
  [10318] = {.lex_state = 63, .external_lex_state = 25},
  [10319] = {.lex_state = 62},
  [10320] = {.lex_state = 17},
  [10321] = {.lex_state = 56, .external_lex_state = 43},
  [10322] = {.lex_state = 17},
  [10323] = {.lex_state = 63, .external_lex_state = 25},
  [10324] = {.lex_state = 4},
  [10325] = {.lex_state = 63, .external_lex_state = 39},
  [10326] = {.lex_state = 65, .external_lex_state = 49},
  [10327] = {.lex_state = 20, .external_lex_state = 43},
  [10328] = {.lex_state = 61, .external_lex_state = 24},
  [10329] = {.lex_state = 62},
  [10330] = {.lex_state = 61, .external_lex_state = 31},
  [10331] = {.lex_state = 65},
  [10332] = {.lex_state = 63, .external_lex_state = 23},
  [10333] = {.lex_state = 62},
  [10334] = {.lex_state = 56, .external_lex_state = 43},
  [10335] = {.lex_state = 62},
  [10336] = {.lex_state = 63, .external_lex_state = 25},
  [10337] = {.lex_state = 62},
  [10338] = {.lex_state = 62},
  [10339] = {.lex_state = 62},
  [10340] = {.lex_state = 62},
  [10341] = {.lex_state = 52, .external_lex_state = 57},
  [10342] = {.lex_state = 63, .external_lex_state = 31},
  [10343] = {.lex_state = 63, .external_lex_state = 23},
  [10344] = {.lex_state = 61, .external_lex_state = 31},
  [10345] = {.lex_state = 62},
  [10346] = {.lex_state = 63, .external_lex_state = 23},
  [10347] = {.lex_state = 63, .external_lex_state = 25},
  [10348] = {.lex_state = 52, .external_lex_state = 57},
  [10349] = {.lex_state = 61, .external_lex_state = 24},
  [10350] = {.lex_state = 61, .external_lex_state = 24},
  [10351] = {.lex_state = 63, .external_lex_state = 24},
  [10352] = {.lex_state = 52, .external_lex_state = 58},
  [10353] = {.lex_state = 63},
  [10354] = {.lex_state = 52, .external_lex_state = 27},
  [10355] = {.lex_state = 65, .external_lex_state = 48},
  [10356] = {.lex_state = 52, .external_lex_state = 57},
  [10357] = {.lex_state = 62, .external_lex_state = 23},
  [10358] = {.lex_state = 52, .external_lex_state = 56},
  [10359] = {.lex_state = 62, .external_lex_state = 23},
  [10360] = {.lex_state = 54, .external_lex_state = 27},
  [10361] = {.lex_state = 61, .external_lex_state = 24},
  [10362] = {.lex_state = 61, .external_lex_state = 24},
  [10363] = {.lex_state = 52, .external_lex_state = 27},
  [10364] = {.lex_state = 63, .external_lex_state = 23},
  [10365] = {.lex_state = 63, .external_lex_state = 42},
  [10366] = {.lex_state = 52, .external_lex_state = 27},
  [10367] = {.lex_state = 63, .external_lex_state = 35},
  [10368] = {.lex_state = 52, .external_lex_state = 27},
  [10369] = {.lex_state = 65, .external_lex_state = 49},
  [10370] = {.lex_state = 61, .external_lex_state = 28},
  [10371] = {.lex_state = 56, .external_lex_state = 43},
  [10372] = {.lex_state = 52, .external_lex_state = 27},
  [10373] = {.lex_state = 52, .external_lex_state = 59},
  [10374] = {.lex_state = 52, .external_lex_state = 27},
  [10375] = {.lex_state = 61, .external_lex_state = 31},
  [10376] = {.lex_state = 52, .external_lex_state = 58},
  [10377] = {.lex_state = 56, .external_lex_state = 43},
  [10378] = {.lex_state = 63, .external_lex_state = 23},
  [10379] = {.lex_state = 61, .external_lex_state = 31},
  [10380] = {.lex_state = 52, .external_lex_state = 58},
  [10381] = {.lex_state = 52, .external_lex_state = 58},
  [10382] = {.lex_state = 63, .external_lex_state = 23},
  [10383] = {.lex_state = 63, .external_lex_state = 23},
  [10384] = {.lex_state = 63, .external_lex_state = 23},
  [10385] = {.lex_state = 52, .external_lex_state = 58},
  [10386] = {.lex_state = 63, .external_lex_state = 36},
  [10387] = {.lex_state = 63, .external_lex_state = 23},
  [10388] = {.lex_state = 61, .external_lex_state = 31},
  [10389] = {.lex_state = 62},
  [10390] = {.lex_state = 63, .external_lex_state = 23},
  [10391] = {.lex_state = 63, .external_lex_state = 25},
  [10392] = {.lex_state = 61, .external_lex_state = 31},
  [10393] = {.lex_state = 62, .external_lex_state = 23},
  [10394] = {.lex_state = 65, .external_lex_state = 48},
  [10395] = {.lex_state = 56, .external_lex_state = 43},
  [10396] = {.lex_state = 21, .external_lex_state = 43},
  [10397] = {.lex_state = 52, .external_lex_state = 57},
  [10398] = {.lex_state = 52, .external_lex_state = 57},
  [10399] = {.lex_state = 62, .external_lex_state = 23},
  [10400] = {.lex_state = 52, .external_lex_state = 27},
  [10401] = {.lex_state = 61, .external_lex_state = 31},
  [10402] = {.lex_state = 63, .external_lex_state = 23},
  [10403] = {.lex_state = 63, .external_lex_state = 25},
  [10404] = {.lex_state = 3},
  [10405] = {.lex_state = 56, .external_lex_state = 43},
  [10406] = {.lex_state = 52},
  [10407] = {.lex_state = 63, .external_lex_state = 25},
  [10408] = {.lex_state = 65},
  [10409] = {.lex_state = 52, .external_lex_state = 57},
  [10410] = {.lex_state = 52, .external_lex_state = 27},
  [10411] = {.lex_state = 52, .external_lex_state = 57},
  [10412] = {.lex_state = 52, .external_lex_state = 57},
  [10413] = {.lex_state = 65},
  [10414] = {.lex_state = 63, .external_lex_state = 24},
  [10415] = {.lex_state = 3},
  [10416] = {.lex_state = 63},
  [10417] = {.lex_state = 61, .external_lex_state = 28},
  [10418] = {.lex_state = 62, .external_lex_state = 23},
  [10419] = {.lex_state = 52, .external_lex_state = 56},
  [10420] = {.lex_state = 21, .external_lex_state = 43},
  [10421] = {.lex_state = 61, .external_lex_state = 31},
  [10422] = {.lex_state = 52, .external_lex_state = 56},
  [10423] = {.lex_state = 52, .external_lex_state = 56},
  [10424] = {.lex_state = 63, .external_lex_state = 35},
  [10425] = {.lex_state = 56, .external_lex_state = 43},
  [10426] = {.lex_state = 61, .external_lex_state = 28},
  [10427] = {.lex_state = 64, .external_lex_state = 23},
  [10428] = {.lex_state = 63, .external_lex_state = 23},
  [10429] = {.lex_state = 65, .external_lex_state = 49},
  [10430] = {.lex_state = 63, .external_lex_state = 35},
  [10431] = {.lex_state = 56, .external_lex_state = 43},
  [10432] = {.lex_state = 63, .external_lex_state = 51},
  [10433] = {.lex_state = 63, .external_lex_state = 24},
  [10434] = {.lex_state = 63, .external_lex_state = 25},
  [10435] = {.lex_state = 52, .external_lex_state = 56},
  [10436] = {.lex_state = 3},
  [10437] = {.lex_state = 63, .external_lex_state = 23},
  [10438] = {.lex_state = 52, .external_lex_state = 36},
  [10439] = {.lex_state = 63, .external_lex_state = 23},
  [10440] = {.lex_state = 8},
  [10441] = {.lex_state = 61, .external_lex_state = 24},
  [10442] = {.lex_state = 61, .external_lex_state = 24},
  [10443] = {.lex_state = 62, .external_lex_state = 23},
  [10444] = {.lex_state = 65, .external_lex_state = 57},
  [10445] = {.lex_state = 52, .external_lex_state = 31},
  [10446] = {.lex_state = 52, .external_lex_state = 59},
  [10447] = {.lex_state = 61, .external_lex_state = 36},
  [10448] = {.lex_state = 65, .external_lex_state = 57},
  [10449] = {.lex_state = 52, .external_lex_state = 31},
  [10450] = {.lex_state = 61, .external_lex_state = 35},
  [10451] = {.lex_state = 52, .external_lex_state = 31},
  [10452] = {.lex_state = 51},
  [10453] = {.lex_state = 52, .external_lex_state = 31},
  [10454] = {.lex_state = 52, .external_lex_state = 28},
  [10455] = {.lex_state = 52, .external_lex_state = 23},
  [10456] = {.lex_state = 65},
  [10457] = {.lex_state = 51},
  [10458] = {.lex_state = 63, .external_lex_state = 45},
  [10459] = {.lex_state = 3},
  [10460] = {.lex_state = 64, .external_lex_state = 24},
  [10461] = {.lex_state = 63, .external_lex_state = 35},
  [10462] = {.lex_state = 52, .external_lex_state = 23},
  [10463] = {.lex_state = 65},
  [10464] = {.lex_state = 52, .external_lex_state = 23},
  [10465] = {.lex_state = 52, .external_lex_state = 23},
  [10466] = {.lex_state = 64, .external_lex_state = 24},
  [10467] = {.lex_state = 61, .external_lex_state = 36},
  [10468] = {.lex_state = 61, .external_lex_state = 36},
  [10469] = {.lex_state = 52, .external_lex_state = 31},
  [10470] = {.lex_state = 51},
  [10471] = {.lex_state = 63, .external_lex_state = 57},
  [10472] = {.lex_state = 51},
  [10473] = {.lex_state = 52, .external_lex_state = 28},
  [10474] = {.lex_state = 63, .external_lex_state = 35},
  [10475] = {.lex_state = 65, .external_lex_state = 27},
  [10476] = {.lex_state = 52, .external_lex_state = 28},
  [10477] = {.lex_state = 61, .external_lex_state = 36},
  [10478] = {.lex_state = 52, .external_lex_state = 23},
  [10479] = {.lex_state = 20},
  [10480] = {.lex_state = 61, .external_lex_state = 35},
  [10481] = {.lex_state = 61, .external_lex_state = 36},
  [10482] = {.lex_state = 65},
  [10483] = {.lex_state = 52, .external_lex_state = 28},
  [10484] = {.lex_state = 52, .external_lex_state = 28},
  [10485] = {.lex_state = 65, .external_lex_state = 57},
  [10486] = {.lex_state = 52},
  [10487] = {.lex_state = 63, .external_lex_state = 27},
  [10488] = {.lex_state = 52, .external_lex_state = 23},
  [10489] = {.lex_state = 61, .external_lex_state = 35},
  [10490] = {.lex_state = 52, .external_lex_state = 28},
  [10491] = {.lex_state = 20, .external_lex_state = 43},
  [10492] = {.lex_state = 65},
  [10493] = {.lex_state = 65, .external_lex_state = 58},
  [10494] = {.lex_state = 51},
  [10495] = {.lex_state = 52, .external_lex_state = 28},
  [10496] = {.lex_state = 52, .external_lex_state = 23},
  [10497] = {.lex_state = 51},
  [10498] = {.lex_state = 64, .external_lex_state = 24},
  [10499] = {.lex_state = 64, .external_lex_state = 23},
  [10500] = {.lex_state = 65, .external_lex_state = 56},
  [10501] = {.lex_state = 64, .external_lex_state = 24},
  [10502] = {.lex_state = 52, .external_lex_state = 23},
  [10503] = {.lex_state = 65, .external_lex_state = 58},
  [10504] = {.lex_state = 63, .external_lex_state = 24},
  [10505] = {.lex_state = 65, .external_lex_state = 56},
  [10506] = {.lex_state = 61, .external_lex_state = 35},
  [10507] = {.lex_state = 61, .external_lex_state = 35},
  [10508] = {.lex_state = 65, .external_lex_state = 58},
  [10509] = {.lex_state = 51},
  [10510] = {.lex_state = 64, .external_lex_state = 24},
  [10511] = {.lex_state = 64, .external_lex_state = 24},
  [10512] = {.lex_state = 64, .external_lex_state = 24},
  [10513] = {.lex_state = 65, .external_lex_state = 56},
  [10514] = {.lex_state = 51, .external_lex_state = 23},
  [10515] = {.lex_state = 65, .external_lex_state = 27},
  [10516] = {.lex_state = 63, .external_lex_state = 24},
  [10517] = {.lex_state = 51, .external_lex_state = 23},
  [10518] = {.lex_state = 51, .external_lex_state = 23},
  [10519] = {.lex_state = 61, .external_lex_state = 35},
  [10520] = {.lex_state = 61, .external_lex_state = 36},
  [10521] = {.lex_state = 65, .external_lex_state = 27},
  [10522] = {.lex_state = 54, .external_lex_state = 31},
  [10523] = {.lex_state = 51},
  [10524] = {.lex_state = 51},
  [10525] = {.lex_state = 63, .external_lex_state = 36},
  [10526] = {.lex_state = 51},
  [10527] = {.lex_state = 61, .external_lex_state = 36},
  [10528] = {.lex_state = 64, .external_lex_state = 23},
  [10529] = {.lex_state = 63, .external_lex_state = 23},
  [10530] = {.lex_state = 61, .external_lex_state = 35},
  [10531] = {.lex_state = 51},
  [10532] = {.lex_state = 51},
  [10533] = {.lex_state = 63, .external_lex_state = 51},
  [10534] = {.lex_state = 52, .external_lex_state = 23},
  [10535] = {.lex_state = 63, .external_lex_state = 24},
  [10536] = {.lex_state = 63, .external_lex_state = 45},
  [10537] = {.lex_state = 64, .external_lex_state = 23},
  [10538] = {.lex_state = 61, .external_lex_state = 36},
  [10539] = {.lex_state = 54, .external_lex_state = 28},
  [10540] = {.lex_state = 63, .external_lex_state = 24},
  [10541] = {.lex_state = 64, .external_lex_state = 23},
  [10542] = {.lex_state = 54, .external_lex_state = 61},
  [10543] = {.lex_state = 65, .external_lex_state = 58},
  [10544] = {.lex_state = 65},
  [10545] = {.lex_state = 52, .external_lex_state = 23},
  [10546] = {.lex_state = 64, .external_lex_state = 23},
  [10547] = {.lex_state = 52, .external_lex_state = 28},
  [10548] = {.lex_state = 61, .external_lex_state = 36},
  [10549] = {.lex_state = 64, .external_lex_state = 23},
  [10550] = {.lex_state = 52, .external_lex_state = 59},
  [10551] = {.lex_state = 61, .external_lex_state = 35},
  [10552] = {.lex_state = 64, .external_lex_state = 23},
  [10553] = {.lex_state = 61, .external_lex_state = 36},
  [10554] = {.lex_state = 64, .external_lex_state = 23},
  [10555] = {.lex_state = 63, .external_lex_state = 48},
  [10556] = {.lex_state = 64, .external_lex_state = 23},
  [10557] = {.lex_state = 63, .external_lex_state = 24},
  [10558] = {.lex_state = 64, .external_lex_state = 24},
  [10559] = {.lex_state = 61, .external_lex_state = 35},
  [10560] = {.lex_state = 64, .external_lex_state = 24},
  [10561] = {.lex_state = 65},
  [10562] = {.lex_state = 54, .external_lex_state = 62},
  [10563] = {.lex_state = 51, .external_lex_state = 24},
  [10564] = {.lex_state = 54, .external_lex_state = 62},
  [10565] = {.lex_state = 52, .external_lex_state = 31},
  [10566] = {.lex_state = 4},
  [10567] = {.lex_state = 61, .external_lex_state = 35},
  [10568] = {.lex_state = 61, .external_lex_state = 35},
  [10569] = {.lex_state = 64, .external_lex_state = 23},
  [10570] = {.lex_state = 64, .external_lex_state = 23},
  [10571] = {.lex_state = 64, .external_lex_state = 23},
  [10572] = {.lex_state = 20, .external_lex_state = 43},
  [10573] = {.lex_state = 51, .external_lex_state = 24},
  [10574] = {.lex_state = 61, .external_lex_state = 36},
  [10575] = {.lex_state = 52, .external_lex_state = 31},
  [10576] = {.lex_state = 52, .external_lex_state = 31},
  [10577] = {.lex_state = 51},
  [10578] = {.lex_state = 63, .external_lex_state = 58},
  [10579] = {.lex_state = 51},
  [10580] = {.lex_state = 52, .external_lex_state = 23},
  [10581] = {.lex_state = 51},
  [10582] = {.lex_state = 63, .external_lex_state = 24},
  [10583] = {.lex_state = 51},
  [10584] = {.lex_state = 64, .external_lex_state = 24},
  [10585] = {.lex_state = 61, .external_lex_state = 36},
  [10586] = {.lex_state = 63},
  [10587] = {.lex_state = 64, .external_lex_state = 24},
  [10588] = {.lex_state = 51, .external_lex_state = 24},
  [10589] = {.lex_state = 52, .external_lex_state = 31},
  [10590] = {.lex_state = 65, .external_lex_state = 27},
  [10591] = {.lex_state = 62},
  [10592] = {.lex_state = 3},
  [10593] = {.lex_state = 63, .external_lex_state = 48},
  [10594] = {.lex_state = 64, .external_lex_state = 23},
  [10595] = {.lex_state = 21, .external_lex_state = 43},
  [10596] = {.lex_state = 65, .external_lex_state = 57},
  [10597] = {.lex_state = 52},
  [10598] = {.lex_state = 63, .external_lex_state = 45},
  [10599] = {.lex_state = 63, .external_lex_state = 23},
  [10600] = {.lex_state = 51},
  [10601] = {.lex_state = 65, .external_lex_state = 57},
  [10602] = {.lex_state = 61, .external_lex_state = 35},
  [10603] = {.lex_state = 4},
  [10604] = {.lex_state = 64, .external_lex_state = 23},
  [10605] = {.lex_state = 63, .external_lex_state = 48},
  [10606] = {.lex_state = 65, .external_lex_state = 56},
  [10607] = {.lex_state = 61, .external_lex_state = 36},
  [10608] = {.lex_state = 51},
  [10609] = {.lex_state = 63, .external_lex_state = 51},
  [10610] = {.lex_state = 61, .external_lex_state = 36},
  [10611] = {.lex_state = 65},
  [10612] = {.lex_state = 21, .external_lex_state = 43},
  [10613] = {.lex_state = 51, .external_lex_state = 24},
  [10614] = {.lex_state = 63, .external_lex_state = 23},
  [10615] = {.lex_state = 65, .external_lex_state = 56},
  [10616] = {.lex_state = 63, .external_lex_state = 56},
  [10617] = {.lex_state = 63, .external_lex_state = 23},
  [10618] = {.lex_state = 52, .external_lex_state = 31},
  [10619] = {.lex_state = 63, .external_lex_state = 23},
  [10620] = {.lex_state = 21},
  [10621] = {.lex_state = 63, .external_lex_state = 23},
  [10622] = {.lex_state = 52, .external_lex_state = 28},
  [10623] = {.lex_state = 63, .external_lex_state = 24},
  [10624] = {.lex_state = 21},
  [10625] = {.lex_state = 65},
  [10626] = {.lex_state = 52, .external_lex_state = 31},
  [10627] = {.lex_state = 65},
  [10628] = {.lex_state = 61, .external_lex_state = 35},
  [10629] = {.lex_state = 65},
  [10630] = {.lex_state = 63, .external_lex_state = 24},
  [10631] = {.lex_state = 63, .external_lex_state = 36},
  [10632] = {.lex_state = 4},
  [10633] = {.lex_state = 63, .external_lex_state = 49},
  [10634] = {.lex_state = 64, .external_lex_state = 24},
  [10635] = {.lex_state = 51, .external_lex_state = 24},
  [10636] = {.lex_state = 65},
  [10637] = {.lex_state = 52, .external_lex_state = 28},
  [10638] = {.lex_state = 52, .external_lex_state = 23},
  [10639] = {.lex_state = 52, .external_lex_state = 28},
  [10640] = {.lex_state = 52, .external_lex_state = 28},
  [10641] = {.lex_state = 52, .external_lex_state = 28},
  [10642] = {.lex_state = 63, .external_lex_state = 48},
  [10643] = {.lex_state = 63, .external_lex_state = 45},
  [10644] = {.lex_state = 65, .external_lex_state = 58},
  [10645] = {.lex_state = 61, .external_lex_state = 35},
  [10646] = {.lex_state = 52, .external_lex_state = 23},
  [10647] = {.lex_state = 52, .external_lex_state = 31},
  [10648] = {.lex_state = 52, .external_lex_state = 28},
  [10649] = {.lex_state = 52, .external_lex_state = 31},
  [10650] = {.lex_state = 51, .external_lex_state = 23},
  [10651] = {.lex_state = 51, .external_lex_state = 23},
  [10652] = {.lex_state = 65, .external_lex_state = 27},
  [10653] = {.lex_state = 65},
  [10654] = {.lex_state = 52, .external_lex_state = 23},
  [10655] = {.lex_state = 63, .external_lex_state = 49},
  [10656] = {.lex_state = 3},
  [10657] = {.lex_state = 64, .external_lex_state = 24},
  [10658] = {.lex_state = 4},
  [10659] = {.lex_state = 64, .external_lex_state = 24},
  [10660] = {.lex_state = 53, .external_lex_state = 40},
  [10661] = {.lex_state = 3},
  [10662] = {.lex_state = 52, .external_lex_state = 31},
  [10663] = {.lex_state = 64, .external_lex_state = 23},
  [10664] = {.lex_state = 63, .external_lex_state = 56},
  [10665] = {.lex_state = 3},
  [10666] = {.lex_state = 63, .external_lex_state = 23},
  [10667] = {.lex_state = 51},
  [10668] = {.lex_state = 54, .external_lex_state = 25},
  [10669] = {.lex_state = 21},
  [10670] = {.lex_state = 51, .external_lex_state = 23},
  [10671] = {.lex_state = 51, .external_lex_state = 24},
  [10672] = {.lex_state = 52, .external_lex_state = 36},
  [10673] = {.lex_state = 54, .external_lex_state = 25},
  [10674] = {.lex_state = 21},
  [10675] = {.lex_state = 51, .external_lex_state = 23},
  [10676] = {.lex_state = 64, .external_lex_state = 23},
  [10677] = {.lex_state = 4},
  [10678] = {.lex_state = 54, .external_lex_state = 25},
  [10679] = {.lex_state = 51, .external_lex_state = 23},
  [10680] = {.lex_state = 21},
  [10681] = {.lex_state = 19},
  [10682] = {.lex_state = 19},
  [10683] = {.lex_state = 63, .external_lex_state = 24},
  [10684] = {.lex_state = 51},
  [10685] = {.lex_state = 51, .external_lex_state = 23},
  [10686] = {.lex_state = 52, .external_lex_state = 35},
  [10687] = {.lex_state = 21},
  [10688] = {.lex_state = 63},
  [10689] = {.lex_state = 54, .external_lex_state = 62},
  [10690] = {.lex_state = 21},
  [10691] = {.lex_state = 51, .external_lex_state = 23},
  [10692] = {.lex_state = 4},
  [10693] = {.lex_state = 51, .external_lex_state = 23},
  [10694] = {.lex_state = 60, .external_lex_state = 27},
  [10695] = {.lex_state = 64, .external_lex_state = 23},
  [10696] = {.lex_state = 63},
  [10697] = {.lex_state = 19},
  [10698] = {.lex_state = 51, .external_lex_state = 23},
  [10699] = {.lex_state = 19},
  [10700] = {.lex_state = 51, .external_lex_state = 24},
  [10701] = {.lex_state = 51, .external_lex_state = 24},
  [10702] = {.lex_state = 19},
  [10703] = {.lex_state = 63},
  [10704] = {.lex_state = 19},
  [10705] = {.lex_state = 52, .external_lex_state = 35},
  [10706] = {.lex_state = 65, .external_lex_state = 31},
  [10707] = {.lex_state = 63},
  [10708] = {.lex_state = 51},
  [10709] = {.lex_state = 61, .external_lex_state = 23},
  [10710] = {.lex_state = 51, .external_lex_state = 23},
  [10711] = {.lex_state = 52, .external_lex_state = 35},
  [10712] = {.lex_state = 63},
  [10713] = {.lex_state = 65, .external_lex_state = 24},
  [10714] = {.lex_state = 51, .external_lex_state = 23},
  [10715] = {.lex_state = 64, .external_lex_state = 23},
  [10716] = {.lex_state = 52},
  [10717] = {.lex_state = 65, .external_lex_state = 24},
  [10718] = {.lex_state = 65, .external_lex_state = 24},
  [10719] = {.lex_state = 52, .external_lex_state = 36},
  [10720] = {.lex_state = 63, .external_lex_state = 57},
  [10721] = {.lex_state = 63},
  [10722] = {.lex_state = 63, .external_lex_state = 56},
  [10723] = {.lex_state = 52, .external_lex_state = 36},
  [10724] = {.lex_state = 64, .external_lex_state = 23},
  [10725] = {.lex_state = 52, .external_lex_state = 36},
  [10726] = {.lex_state = 63, .external_lex_state = 58},
  [10727] = {.lex_state = 19},
  [10728] = {.lex_state = 51, .external_lex_state = 23},
  [10729] = {.lex_state = 53, .external_lex_state = 40},
  [10730] = {.lex_state = 54, .external_lex_state = 25},
  [10731] = {.lex_state = 63, .external_lex_state = 28},
  [10732] = {.lex_state = 18},
  [10733] = {.lex_state = 51, .external_lex_state = 23},
  [10734] = {.lex_state = 61, .external_lex_state = 23},
  [10735] = {.lex_state = 4},
  [10736] = {.lex_state = 65, .external_lex_state = 31},
  [10737] = {.lex_state = 4},
  [10738] = {.lex_state = 65, .external_lex_state = 28},
  [10739] = {.lex_state = 63, .external_lex_state = 31},
  [10740] = {.lex_state = 51, .external_lex_state = 23},
  [10741] = {.lex_state = 54, .external_lex_state = 25},
  [10742] = {.lex_state = 51},
  [10743] = {.lex_state = 51, .external_lex_state = 24},
  [10744] = {.lex_state = 51, .external_lex_state = 24},
  [10745] = {.lex_state = 4},
  [10746] = {.lex_state = 21},
  [10747] = {.lex_state = 52, .external_lex_state = 35},
  [10748] = {.lex_state = 21},
  [10749] = {.lex_state = 63, .external_lex_state = 57},
  [10750] = {.lex_state = 63, .external_lex_state = 56},
  [10751] = {.lex_state = 54, .external_lex_state = 35},
  [10752] = {.lex_state = 51},
  [10753] = {.lex_state = 3},
  [10754] = {.lex_state = 3},
  [10755] = {.lex_state = 63, .external_lex_state = 58},
  [10756] = {.lex_state = 54, .external_lex_state = 27},
  [10757] = {.lex_state = 61, .external_lex_state = 23},
  [10758] = {.lex_state = 64, .external_lex_state = 23},
  [10759] = {.lex_state = 54, .external_lex_state = 62},
  [10760] = {.lex_state = 21},
  [10761] = {.lex_state = 52, .external_lex_state = 35},
  [10762] = {.lex_state = 54, .external_lex_state = 36},
  [10763] = {.lex_state = 54, .external_lex_state = 62},
  [10764] = {.lex_state = 4},
  [10765] = {.lex_state = 65, .external_lex_state = 31},
  [10766] = {.lex_state = 64, .external_lex_state = 23},
  [10767] = {.lex_state = 63, .external_lex_state = 27},
  [10768] = {.lex_state = 51},
  [10769] = {.lex_state = 63},
  [10770] = {.lex_state = 8},
  [10771] = {.lex_state = 21},
  [10772] = {.lex_state = 51, .external_lex_state = 23},
  [10773] = {.lex_state = 65, .external_lex_state = 24},
  [10774] = {.lex_state = 64, .external_lex_state = 23},
  [10775] = {.lex_state = 61, .external_lex_state = 23},
  [10776] = {.lex_state = 54, .external_lex_state = 25},
  [10777] = {.lex_state = 18},
  [10778] = {.lex_state = 52, .external_lex_state = 35},
  [10779] = {.lex_state = 21},
  [10780] = {.lex_state = 3},
  [10781] = {.lex_state = 21},
  [10782] = {.lex_state = 63},
  [10783] = {.lex_state = 51},
  [10784] = {.lex_state = 64, .external_lex_state = 23},
  [10785] = {.lex_state = 52, .external_lex_state = 35},
  [10786] = {.lex_state = 21},
  [10787] = {.lex_state = 21},
  [10788] = {.lex_state = 51, .external_lex_state = 24},
  [10789] = {.lex_state = 21},
  [10790] = {.lex_state = 51},
  [10791] = {.lex_state = 21},
  [10792] = {.lex_state = 65, .external_lex_state = 28},
  [10793] = {.lex_state = 21},
  [10794] = {.lex_state = 3},
  [10795] = {.lex_state = 65, .external_lex_state = 28},
  [10796] = {.lex_state = 63},
  [10797] = {.lex_state = 65, .external_lex_state = 28},
  [10798] = {.lex_state = 51, .external_lex_state = 23},
  [10799] = {.lex_state = 21},
  [10800] = {.lex_state = 21},
  [10801] = {.lex_state = 21},
  [10802] = {.lex_state = 3},
  [10803] = {.lex_state = 52, .external_lex_state = 35},
  [10804] = {.lex_state = 63},
  [10805] = {.lex_state = 21},
  [10806] = {.lex_state = 52, .external_lex_state = 36},
  [10807] = {.lex_state = 53, .external_lex_state = 23},
  [10808] = {.lex_state = 3},
  [10809] = {.lex_state = 54, .external_lex_state = 25},
  [10810] = {.lex_state = 63},
  [10811] = {.lex_state = 21},
  [10812] = {.lex_state = 21},
  [10813] = {.lex_state = 54, .external_lex_state = 25},
  [10814] = {.lex_state = 54, .external_lex_state = 27},
  [10815] = {.lex_state = 51, .external_lex_state = 24},
  [10816] = {.lex_state = 51},
  [10817] = {.lex_state = 21},
  [10818] = {.lex_state = 3},
  [10819] = {.lex_state = 51, .external_lex_state = 23},
  [10820] = {.lex_state = 21},
  [10821] = {.lex_state = 51, .external_lex_state = 23},
  [10822] = {.lex_state = 21},
  [10823] = {.lex_state = 21},
  [10824] = {.lex_state = 21},
  [10825] = {.lex_state = 65, .external_lex_state = 31},
  [10826] = {.lex_state = 63, .external_lex_state = 56},
  [10827] = {.lex_state = 61, .external_lex_state = 23},
  [10828] = {.lex_state = 21},
  [10829] = {.lex_state = 54, .external_lex_state = 60},
  [10830] = {.lex_state = 63},
  [10831] = {.lex_state = 51, .external_lex_state = 24},
  [10832] = {.lex_state = 65, .external_lex_state = 31},
  [10833] = {.lex_state = 8},
  [10834] = {.lex_state = 52, .external_lex_state = 36},
  [10835] = {.lex_state = 54, .external_lex_state = 62},
  [10836] = {.lex_state = 19},
  [10837] = {.lex_state = 54, .external_lex_state = 60},
  [10838] = {.lex_state = 63, .external_lex_state = 27},
  [10839] = {.lex_state = 54, .external_lex_state = 27},
  [10840] = {.lex_state = 21},
  [10841] = {.lex_state = 21},
  [10842] = {.lex_state = 3},
  [10843] = {.lex_state = 54, .external_lex_state = 63},
  [10844] = {.lex_state = 52, .external_lex_state = 35},
  [10845] = {.lex_state = 3},
  [10846] = {.lex_state = 52, .external_lex_state = 35},
  [10847] = {.lex_state = 3},
  [10848] = {.lex_state = 63},
  [10849] = {.lex_state = 51, .external_lex_state = 23},
  [10850] = {.lex_state = 51, .external_lex_state = 24},
  [10851] = {.lex_state = 52, .external_lex_state = 59},
  [10852] = {.lex_state = 51, .external_lex_state = 23},
  [10853] = {.lex_state = 60, .external_lex_state = 27},
  [10854] = {.lex_state = 21},
  [10855] = {.lex_state = 21},
  [10856] = {.lex_state = 3},
  [10857] = {.lex_state = 3},
  [10858] = {.lex_state = 52, .external_lex_state = 35},
  [10859] = {.lex_state = 52, .external_lex_state = 36},
  [10860] = {.lex_state = 8},
  [10861] = {.lex_state = 64, .external_lex_state = 23},
  [10862] = {.lex_state = 21},
  [10863] = {.lex_state = 3},
  [10864] = {.lex_state = 61, .external_lex_state = 23},
  [10865] = {.lex_state = 8},
  [10866] = {.lex_state = 61, .external_lex_state = 23},
  [10867] = {.lex_state = 61, .external_lex_state = 23},
  [10868] = {.lex_state = 51, .external_lex_state = 24},
  [10869] = {.lex_state = 52, .external_lex_state = 35},
  [10870] = {.lex_state = 64, .external_lex_state = 23},
  [10871] = {.lex_state = 51},
  [10872] = {.lex_state = 52, .external_lex_state = 36},
  [10873] = {.lex_state = 52, .external_lex_state = 36},
  [10874] = {.lex_state = 21},
  [10875] = {.lex_state = 54, .external_lex_state = 23},
  [10876] = {.lex_state = 21},
  [10877] = {.lex_state = 52, .external_lex_state = 36},
  [10878] = {.lex_state = 21},
  [10879] = {.lex_state = 21},
  [10880] = {.lex_state = 4},
  [10881] = {.lex_state = 21},
  [10882] = {.lex_state = 21},
  [10883] = {.lex_state = 61, .external_lex_state = 23},
  [10884] = {.lex_state = 21},
  [10885] = {.lex_state = 53, .external_lex_state = 40},
  [10886] = {.lex_state = 54, .external_lex_state = 25},
  [10887] = {.lex_state = 21},
  [10888] = {.lex_state = 63},
  [10889] = {.lex_state = 63},
  [10890] = {.lex_state = 53, .external_lex_state = 53},
  [10891] = {.lex_state = 63},
  [10892] = {.lex_state = 51, .external_lex_state = 23},
  [10893] = {.lex_state = 51, .external_lex_state = 23},
  [10894] = {.lex_state = 51, .external_lex_state = 23},
  [10895] = {.lex_state = 54, .external_lex_state = 63},
  [10896] = {.lex_state = 3},
  [10897] = {.lex_state = 61, .external_lex_state = 23},
  [10898] = {.lex_state = 65, .external_lex_state = 24},
  [10899] = {.lex_state = 64, .external_lex_state = 23},
  [10900] = {.lex_state = 21},
  [10901] = {.lex_state = 54, .external_lex_state = 25},
  [10902] = {.lex_state = 51},
  [10903] = {.lex_state = 3},
  [10904] = {.lex_state = 3},
  [10905] = {.lex_state = 52, .external_lex_state = 35},
  [10906] = {.lex_state = 51, .external_lex_state = 24},
  [10907] = {.lex_state = 52, .external_lex_state = 36},
  [10908] = {.lex_state = 61, .external_lex_state = 23},
  [10909] = {.lex_state = 21},
  [10910] = {.lex_state = 21},
  [10911] = {.lex_state = 21},
  [10912] = {.lex_state = 61, .external_lex_state = 23},
  [10913] = {.lex_state = 51, .external_lex_state = 24},
  [10914] = {.lex_state = 64, .external_lex_state = 23},
  [10915] = {.lex_state = 19},
  [10916] = {.lex_state = 19},
  [10917] = {.lex_state = 19},
  [10918] = {.lex_state = 52, .external_lex_state = 36},
  [10919] = {.lex_state = 52, .external_lex_state = 36},
  [10920] = {.lex_state = 54, .external_lex_state = 25},
  [10921] = {.lex_state = 54, .external_lex_state = 25},
  [10922] = {.lex_state = 65, .external_lex_state = 28},
  [10923] = {.lex_state = 4},
  [10924] = {.lex_state = 21},
  [10925] = {.lex_state = 21},
  [10926] = {.lex_state = 19},
  [10927] = {.lex_state = 63},
  [10928] = {.lex_state = 3},
  [10929] = {.lex_state = 61, .external_lex_state = 23},
  [10930] = {.lex_state = 19},
  [10931] = {.lex_state = 64, .external_lex_state = 23},
  [10932] = {.lex_state = 63, .external_lex_state = 23},
  [10933] = {.lex_state = 19},
  [10934] = {.lex_state = 54, .external_lex_state = 27},
  [10935] = {.lex_state = 63},
  [10936] = {.lex_state = 61, .external_lex_state = 23},
  [10937] = {.lex_state = 52, .external_lex_state = 35},
  [10938] = {.lex_state = 51, .external_lex_state = 24},
  [10939] = {.lex_state = 51, .external_lex_state = 24},
  [10940] = {.lex_state = 51, .external_lex_state = 24},
  [10941] = {.lex_state = 54, .external_lex_state = 25},
  [10942] = {.lex_state = 63},
  [10943] = {.lex_state = 51, .external_lex_state = 24},
  [10944] = {.lex_state = 51, .external_lex_state = 24},
  [10945] = {.lex_state = 51},
  [10946] = {.lex_state = 52, .external_lex_state = 36},
  [10947] = {.lex_state = 51, .external_lex_state = 23},
  [10948] = {.lex_state = 52, .external_lex_state = 59},
  [10949] = {.lex_state = 54, .external_lex_state = 25},
  [10950] = {.lex_state = 20},
  [10951] = {.lex_state = 51},
  [10952] = {.lex_state = 54, .external_lex_state = 27},
  [10953] = {.lex_state = 66, .external_lex_state = 24},
  [10954] = {.lex_state = 51},
  [10955] = {.lex_state = 60, .external_lex_state = 27},
  [10956] = {.lex_state = 54, .external_lex_state = 27},
  [10957] = {.lex_state = 54, .external_lex_state = 31},
  [10958] = {.lex_state = 51},
  [10959] = {.lex_state = 65, .external_lex_state = 36},
  [10960] = {.lex_state = 51},
  [10961] = {.lex_state = 54, .external_lex_state = 63},
  [10962] = {.lex_state = 20},
  [10963] = {.lex_state = 51},
  [10964] = {.lex_state = 54, .external_lex_state = 63},
  [10965] = {.lex_state = 3},
  [10966] = {.lex_state = 51},
  [10967] = {.lex_state = 20},
  [10968] = {.lex_state = 65, .external_lex_state = 35},
  [10969] = {.lex_state = 51},
  [10970] = {.lex_state = 3},
  [10971] = {.lex_state = 3},
  [10972] = {.lex_state = 51, .external_lex_state = 23},
  [10973] = {.lex_state = 4},
  [10974] = {.lex_state = 20},
  [10975] = {.lex_state = 4},
  [10976] = {.lex_state = 51, .external_lex_state = 23},
  [10977] = {.lex_state = 53, .external_lex_state = 23},
  [10978] = {.lex_state = 51},
  [10979] = {.lex_state = 54, .external_lex_state = 63},
  [10980] = {.lex_state = 51, .external_lex_state = 24},
  [10981] = {.lex_state = 3},
  [10982] = {.lex_state = 54, .external_lex_state = 27},
  [10983] = {.lex_state = 54, .external_lex_state = 27},
  [10984] = {.lex_state = 21},
  [10985] = {.lex_state = 4},
  [10986] = {.lex_state = 51},
  [10987] = {.lex_state = 60, .external_lex_state = 31},
  [10988] = {.lex_state = 51},
  [10989] = {.lex_state = 60, .external_lex_state = 31},
  [10990] = {.lex_state = 51, .external_lex_state = 23},
  [10991] = {.lex_state = 52, .external_lex_state = 64},
  [10992] = {.lex_state = 65, .external_lex_state = 36},
  [10993] = {.lex_state = 3},
  [10994] = {.lex_state = 51, .external_lex_state = 23},
  [10995] = {.lex_state = 51},
  [10996] = {.lex_state = 63, .external_lex_state = 31},
  [10997] = {.lex_state = 3},
  [10998] = {.lex_state = 51, .external_lex_state = 23},
  [10999] = {.lex_state = 8},
  [11000] = {.lex_state = 8},
  [11001] = {.lex_state = 54, .external_lex_state = 28},
  [11002] = {.lex_state = 3},
  [11003] = {.lex_state = 3},
  [11004] = {.lex_state = 51},
  [11005] = {.lex_state = 66, .external_lex_state = 23},
  [11006] = {.lex_state = 20},
  [11007] = {.lex_state = 63, .external_lex_state = 36},
  [11008] = {.lex_state = 20},
  [11009] = {.lex_state = 20},
  [11010] = {.lex_state = 54, .external_lex_state = 27},
  [11011] = {.lex_state = 54, .external_lex_state = 61},
  [11012] = {.lex_state = 54, .external_lex_state = 28},
  [11013] = {.lex_state = 51},
  [11014] = {.lex_state = 51},
  [11015] = {.lex_state = 51},
  [11016] = {.lex_state = 3},
  [11017] = {.lex_state = 54, .external_lex_state = 31},
  [11018] = {.lex_state = 60, .external_lex_state = 28},
  [11019] = {.lex_state = 51, .external_lex_state = 23},
  [11020] = {.lex_state = 3},
  [11021] = {.lex_state = 8},
  [11022] = {.lex_state = 54, .external_lex_state = 31},
  [11023] = {.lex_state = 54, .external_lex_state = 27},
  [11024] = {.lex_state = 51},
  [11025] = {.lex_state = 54, .external_lex_state = 27},
  [11026] = {.lex_state = 54, .external_lex_state = 27},
  [11027] = {.lex_state = 3},
  [11028] = {.lex_state = 60, .external_lex_state = 28},
  [11029] = {.lex_state = 63, .external_lex_state = 28},
  [11030] = {.lex_state = 8},
  [11031] = {.lex_state = 66, .external_lex_state = 23},
  [11032] = {.lex_state = 66, .external_lex_state = 23},
  [11033] = {.lex_state = 54, .external_lex_state = 27},
  [11034] = {.lex_state = 54, .external_lex_state = 37},
  [11035] = {.lex_state = 54, .external_lex_state = 28},
  [11036] = {.lex_state = 3},
  [11037] = {.lex_state = 53, .external_lex_state = 53},
  [11038] = {.lex_state = 3},
  [11039] = {.lex_state = 51, .external_lex_state = 23},
  [11040] = {.lex_state = 51, .external_lex_state = 23},
  [11041] = {.lex_state = 51, .external_lex_state = 23},
  [11042] = {.lex_state = 3},
  [11043] = {.lex_state = 54, .external_lex_state = 63},
  [11044] = {.lex_state = 65, .external_lex_state = 35},
  [11045] = {.lex_state = 8},
  [11046] = {.lex_state = 20},
  [11047] = {.lex_state = 20},
  [11048] = {.lex_state = 63},
  [11049] = {.lex_state = 8},
  [11050] = {.lex_state = 8},
  [11051] = {.lex_state = 3},
  [11052] = {.lex_state = 54, .external_lex_state = 27},
  [11053] = {.lex_state = 20},
  [11054] = {.lex_state = 51, .external_lex_state = 23},
  [11055] = {.lex_state = 3},
  [11056] = {.lex_state = 3},
  [11057] = {.lex_state = 51, .external_lex_state = 23},
  [11058] = {.lex_state = 8},
  [11059] = {.lex_state = 66, .external_lex_state = 24},
  [11060] = {.lex_state = 20},
  [11061] = {.lex_state = 20},
  [11062] = {.lex_state = 54, .external_lex_state = 60},
  [11063] = {.lex_state = 53, .external_lex_state = 24},
  [11064] = {.lex_state = 63, .external_lex_state = 23},
  [11065] = {.lex_state = 51, .external_lex_state = 23},
  [11066] = {.lex_state = 51, .external_lex_state = 23},
  [11067] = {.lex_state = 51, .external_lex_state = 23},
  [11068] = {.lex_state = 65, .external_lex_state = 36},
  [11069] = {.lex_state = 63, .external_lex_state = 31},
  [11070] = {.lex_state = 20},
  [11071] = {.lex_state = 8},
  [11072] = {.lex_state = 51},
  [11073] = {.lex_state = 51, .external_lex_state = 23},
  [11074] = {.lex_state = 54, .external_lex_state = 62},
  [11075] = {.lex_state = 54, .external_lex_state = 28},
  [11076] = {.lex_state = 66, .external_lex_state = 23},
  [11077] = {.lex_state = 4},
  [11078] = {.lex_state = 54, .external_lex_state = 62},
  [11079] = {.lex_state = 8},
  [11080] = {.lex_state = 65, .external_lex_state = 35},
  [11081] = {.lex_state = 51},
  [11082] = {.lex_state = 51},
  [11083] = {.lex_state = 63, .external_lex_state = 23},
  [11084] = {.lex_state = 51, .external_lex_state = 24},
  [11085] = {.lex_state = 63, .external_lex_state = 28},
  [11086] = {.lex_state = 65, .external_lex_state = 36},
  [11087] = {.lex_state = 63},
  [11088] = {.lex_state = 3},
  [11089] = {.lex_state = 3},
  [11090] = {.lex_state = 65, .external_lex_state = 35},
  [11091] = {.lex_state = 65, .external_lex_state = 35},
  [11092] = {.lex_state = 51, .external_lex_state = 23},
  [11093] = {.lex_state = 63},
  [11094] = {.lex_state = 54, .external_lex_state = 23},
  [11095] = {.lex_state = 3},
  [11096] = {.lex_state = 21},
  [11097] = {.lex_state = 54, .external_lex_state = 60},
  [11098] = {.lex_state = 65, .external_lex_state = 36},
  [11099] = {.lex_state = 51},
  [11100] = {.lex_state = 54, .external_lex_state = 23},
  [11101] = {.lex_state = 8},
  [11102] = {.lex_state = 3},
  [11103] = {.lex_state = 8},
  [11104] = {.lex_state = 51, .external_lex_state = 23},
  [11105] = {.lex_state = 66, .external_lex_state = 24},
  [11106] = {.lex_state = 51},
  [11107] = {.lex_state = 54, .external_lex_state = 27},
  [11108] = {.lex_state = 66, .external_lex_state = 23},
  [11109] = {.lex_state = 63, .external_lex_state = 35},
  [11110] = {.lex_state = 66, .external_lex_state = 24},
  [11111] = {.lex_state = 53, .external_lex_state = 24},
  [11112] = {.lex_state = 54, .external_lex_state = 27},
  [11113] = {.lex_state = 54, .external_lex_state = 31},
  [11114] = {.lex_state = 51, .external_lex_state = 23},
  [11115] = {.lex_state = 53, .external_lex_state = 53},
  [11116] = {.lex_state = 18},
  [11117] = {.lex_state = 51, .external_lex_state = 23},
  [11118] = {.lex_state = 54, .external_lex_state = 61},
  [11119] = {.lex_state = 62},
  [11120] = {.lex_state = 20},
  [11121] = {.lex_state = 51},
  [11122] = {.lex_state = 3},
  [11123] = {.lex_state = 51},
  [11124] = {.lex_state = 3},
  [11125] = {.lex_state = 66, .external_lex_state = 24},
  [11126] = {.lex_state = 51},
  [11127] = {.lex_state = 51},
  [11128] = {.lex_state = 3},
  [11129] = {.lex_state = 51},
  [11130] = {.lex_state = 3},
  [11131] = {.lex_state = 54, .external_lex_state = 27},
  [11132] = {.lex_state = 51},
  [11133] = {.lex_state = 8},
  [11134] = {.lex_state = 63},
  [11135] = {.lex_state = 54, .external_lex_state = 27},
  [11136] = {.lex_state = 51},
  [11137] = {.lex_state = 54, .external_lex_state = 31},
  [11138] = {.lex_state = 51},
  [11139] = {.lex_state = 54, .external_lex_state = 27},
  [11140] = {.lex_state = 63},
  [11141] = {.lex_state = 63, .external_lex_state = 23},
  [11142] = {.lex_state = 54, .external_lex_state = 27},
  [11143] = {.lex_state = 54, .external_lex_state = 60},
  [11144] = {.lex_state = 54, .external_lex_state = 27},
  [11145] = {.lex_state = 54, .external_lex_state = 27},
  [11146] = {.lex_state = 54, .external_lex_state = 27},
  [11147] = {.lex_state = 54, .external_lex_state = 27},
  [11148] = {.lex_state = 54, .external_lex_state = 27},
  [11149] = {.lex_state = 60, .external_lex_state = 35},
  [11150] = {.lex_state = 60, .external_lex_state = 35},
  [11151] = {.lex_state = 23},
  [11152] = {.lex_state = 54, .external_lex_state = 62},
  [11153] = {.lex_state = 23},
  [11154] = {.lex_state = 23},
  [11155] = {.lex_state = 54, .external_lex_state = 35},
  [11156] = {.lex_state = 63},
  [11157] = {.lex_state = 63},
  [11158] = {.lex_state = 51},
  [11159] = {.lex_state = 63, .external_lex_state = 35},
  [11160] = {.lex_state = 63},
  [11161] = {.lex_state = 53, .external_lex_state = 40},
  [11162] = {.lex_state = 54, .external_lex_state = 36},
  [11163] = {.lex_state = 54, .external_lex_state = 60},
  [11164] = {.lex_state = 65, .external_lex_state = 23},
  [11165] = {.lex_state = 65, .external_lex_state = 23},
  [11166] = {.lex_state = 54, .external_lex_state = 60},
  [11167] = {.lex_state = 53, .external_lex_state = 40},
  [11168] = {.lex_state = 21},
  [11169] = {.lex_state = 54, .external_lex_state = 42},
  [11170] = {.lex_state = 63},
  [11171] = {.lex_state = 4},
  [11172] = {.lex_state = 4},
  [11173] = {.lex_state = 54, .external_lex_state = 63},
  [11174] = {.lex_state = 54, .external_lex_state = 62},
  [11175] = {.lex_state = 63, .external_lex_state = 35},
  [11176] = {.lex_state = 54, .external_lex_state = 62},
  [11177] = {.lex_state = 54, .external_lex_state = 36},
  [11178] = {.lex_state = 18},
  [11179] = {.lex_state = 18},
  [11180] = {.lex_state = 53, .external_lex_state = 23},
  [11181] = {.lex_state = 18},
  [11182] = {.lex_state = 54, .external_lex_state = 27},
  [11183] = {.lex_state = 51},
  [11184] = {.lex_state = 51},
  [11185] = {.lex_state = 53, .external_lex_state = 23},
  [11186] = {.lex_state = 63},
  [11187] = {.lex_state = 54, .external_lex_state = 28},
  [11188] = {.lex_state = 51},
  [11189] = {.lex_state = 23},
  [11190] = {.lex_state = 23},
  [11191] = {.lex_state = 54, .external_lex_state = 31},
  [11192] = {.lex_state = 51},
  [11193] = {.lex_state = 53, .external_lex_state = 23},
  [11194] = {.lex_state = 54, .external_lex_state = 62},
  [11195] = {.lex_state = 51},
  [11196] = {.lex_state = 63, .external_lex_state = 36},
  [11197] = {.lex_state = 51},
  [11198] = {.lex_state = 51},
  [11199] = {.lex_state = 53, .external_lex_state = 23},
  [11200] = {.lex_state = 54, .external_lex_state = 39},
  [11201] = {.lex_state = 53, .external_lex_state = 23},
  [11202] = {.lex_state = 54, .external_lex_state = 31},
  [11203] = {.lex_state = 4},
  [11204] = {.lex_state = 54, .external_lex_state = 31},
  [11205] = {.lex_state = 4},
  [11206] = {.lex_state = 4},
  [11207] = {.lex_state = 54, .external_lex_state = 31},
  [11208] = {.lex_state = 54, .external_lex_state = 31},
  [11209] = {.lex_state = 54, .external_lex_state = 31},
  [11210] = {.lex_state = 54, .external_lex_state = 31},
  [11211] = {.lex_state = 54, .external_lex_state = 60},
  [11212] = {.lex_state = 54, .external_lex_state = 31},
  [11213] = {.lex_state = 54, .external_lex_state = 60},
  [11214] = {.lex_state = 54, .external_lex_state = 61},
  [11215] = {.lex_state = 54, .external_lex_state = 27},
  [11216] = {.lex_state = 53, .external_lex_state = 23},
  [11217] = {.lex_state = 54, .external_lex_state = 27},
  [11218] = {.lex_state = 54, .external_lex_state = 27},
  [11219] = {.lex_state = 54, .external_lex_state = 27},
  [11220] = {.lex_state = 66, .external_lex_state = 23},
  [11221] = {.lex_state = 54, .external_lex_state = 27},
  [11222] = {.lex_state = 66, .external_lex_state = 23},
  [11223] = {.lex_state = 66, .external_lex_state = 23},
  [11224] = {.lex_state = 54, .external_lex_state = 61},
  [11225] = {.lex_state = 51},
  [11226] = {.lex_state = 51},
  [11227] = {.lex_state = 54, .external_lex_state = 28},
  [11228] = {.lex_state = 60, .external_lex_state = 27},
  [11229] = {.lex_state = 54, .external_lex_state = 28},
  [11230] = {.lex_state = 54, .external_lex_state = 28},
  [11231] = {.lex_state = 54, .external_lex_state = 28},
  [11232] = {.lex_state = 54, .external_lex_state = 28},
  [11233] = {.lex_state = 54, .external_lex_state = 28},
  [11234] = {.lex_state = 54, .external_lex_state = 28},
  [11235] = {.lex_state = 54, .external_lex_state = 28},
  [11236] = {.lex_state = 63},
  [11237] = {.lex_state = 51},
  [11238] = {.lex_state = 54, .external_lex_state = 60},
  [11239] = {.lex_state = 51},
  [11240] = {.lex_state = 51},
  [11241] = {.lex_state = 63},
  [11242] = {.lex_state = 51},
  [11243] = {.lex_state = 51},
  [11244] = {.lex_state = 53, .external_lex_state = 23},
  [11245] = {.lex_state = 63},
  [11246] = {.lex_state = 63},
  [11247] = {.lex_state = 53, .external_lex_state = 53},
  [11248] = {.lex_state = 53, .external_lex_state = 53},
  [11249] = {.lex_state = 53, .external_lex_state = 53},
  [11250] = {.lex_state = 53, .external_lex_state = 53},
  [11251] = {.lex_state = 53, .external_lex_state = 53},
  [11252] = {.lex_state = 53, .external_lex_state = 53},
  [11253] = {.lex_state = 60, .external_lex_state = 31},
  [11254] = {.lex_state = 51},
  [11255] = {.lex_state = 54, .external_lex_state = 63},
  [11256] = {.lex_state = 60, .external_lex_state = 36},
  [11257] = {.lex_state = 63},
  [11258] = {.lex_state = 63},
  [11259] = {.lex_state = 51},
  [11260] = {.lex_state = 60, .external_lex_state = 36},
  [11261] = {.lex_state = 63},
  [11262] = {.lex_state = 63},
  [11263] = {.lex_state = 54, .external_lex_state = 27},
  [11264] = {.lex_state = 51},
  [11265] = {.lex_state = 51},
  [11266] = {.lex_state = 51},
  [11267] = {.lex_state = 54, .external_lex_state = 35},
  [11268] = {.lex_state = 51},
  [11269] = {.lex_state = 54, .external_lex_state = 35},
  [11270] = {.lex_state = 51},
  [11271] = {.lex_state = 63},
  [11272] = {.lex_state = 54, .external_lex_state = 28},
  [11273] = {.lex_state = 54, .external_lex_state = 28},
  [11274] = {.lex_state = 54, .external_lex_state = 28},
  [11275] = {.lex_state = 4},
  [11276] = {.lex_state = 54, .external_lex_state = 28},
  [11277] = {.lex_state = 51},
  [11278] = {.lex_state = 51},
  [11279] = {.lex_state = 51},
  [11280] = {.lex_state = 51},
  [11281] = {.lex_state = 51},
  [11282] = {.lex_state = 54, .external_lex_state = 27},
  [11283] = {.lex_state = 53, .external_lex_state = 23},
  [11284] = {.lex_state = 53, .external_lex_state = 23},
  [11285] = {.lex_state = 54, .external_lex_state = 60},
  [11286] = {.lex_state = 54, .external_lex_state = 36},
  [11287] = {.lex_state = 54, .external_lex_state = 36},
  [11288] = {.lex_state = 51},
  [11289] = {.lex_state = 51},
  [11290] = {.lex_state = 53, .external_lex_state = 40},
  [11291] = {.lex_state = 66, .external_lex_state = 23},
  [11292] = {.lex_state = 66, .external_lex_state = 23},
  [11293] = {.lex_state = 54, .external_lex_state = 40},
  [11294] = {.lex_state = 51},
  [11295] = {.lex_state = 51},
  [11296] = {.lex_state = 54, .external_lex_state = 35},
  [11297] = {.lex_state = 51},
  [11298] = {.lex_state = 53, .external_lex_state = 23},
  [11299] = {.lex_state = 53, .external_lex_state = 23},
  [11300] = {.lex_state = 51},
  [11301] = {.lex_state = 54, .external_lex_state = 53},
  [11302] = {.lex_state = 53, .external_lex_state = 23},
  [11303] = {.lex_state = 53, .external_lex_state = 23},
  [11304] = {.lex_state = 53, .external_lex_state = 23},
  [11305] = {.lex_state = 53, .external_lex_state = 40},
  [11306] = {.lex_state = 54, .external_lex_state = 40},
  [11307] = {.lex_state = 53, .external_lex_state = 40},
  [11308] = {.lex_state = 51},
  [11309] = {.lex_state = 51},
  [11310] = {.lex_state = 53, .external_lex_state = 40},
  [11311] = {.lex_state = 54, .external_lex_state = 31},
  [11312] = {.lex_state = 53, .external_lex_state = 40},
  [11313] = {.lex_state = 53, .external_lex_state = 40},
  [11314] = {.lex_state = 63},
  [11315] = {.lex_state = 53, .external_lex_state = 40},
  [11316] = {.lex_state = 65, .external_lex_state = 23},
  [11317] = {.lex_state = 65, .external_lex_state = 23},
  [11318] = {.lex_state = 65, .external_lex_state = 23},
  [11319] = {.lex_state = 54, .external_lex_state = 53},
  [11320] = {.lex_state = 63},
  [11321] = {.lex_state = 63, .external_lex_state = 36},
  [11322] = {.lex_state = 60, .external_lex_state = 28},
  [11323] = {.lex_state = 18},
  [11324] = {.lex_state = 51},
  [11325] = {.lex_state = 51},
  [11326] = {.lex_state = 54, .external_lex_state = 27},
  [11327] = {.lex_state = 63},
  [11328] = {.lex_state = 63},
  [11329] = {.lex_state = 63},
  [11330] = {.lex_state = 63},
  [11331] = {.lex_state = 63},
  [11332] = {.lex_state = 63},
  [11333] = {.lex_state = 63},
  [11334] = {.lex_state = 63},
  [11335] = {.lex_state = 63},
  [11336] = {.lex_state = 63},
  [11337] = {.lex_state = 63},
  [11338] = {.lex_state = 63},
  [11339] = {.lex_state = 63},
  [11340] = {.lex_state = 63},
  [11341] = {.lex_state = 63},
  [11342] = {.lex_state = 63},
  [11343] = {.lex_state = 63},
  [11344] = {.lex_state = 63},
  [11345] = {.lex_state = 63},
  [11346] = {.lex_state = 63},
  [11347] = {.lex_state = 54, .external_lex_state = 31},
  [11348] = {.lex_state = 63},
  [11349] = {.lex_state = 63},
  [11350] = {.lex_state = 63},
  [11351] = {.lex_state = 63},
  [11352] = {.lex_state = 63},
  [11353] = {.lex_state = 63},
  [11354] = {.lex_state = 63},
  [11355] = {.lex_state = 63},
  [11356] = {.lex_state = 63},
  [11357] = {.lex_state = 63},
  [11358] = {.lex_state = 54, .external_lex_state = 31},
  [11359] = {.lex_state = 63},
  [11360] = {.lex_state = 63},
  [11361] = {.lex_state = 63},
  [11362] = {.lex_state = 63},
  [11363] = {.lex_state = 63},
  [11364] = {.lex_state = 63},
  [11365] = {.lex_state = 63},
  [11366] = {.lex_state = 63},
  [11367] = {.lex_state = 54, .external_lex_state = 31},
  [11368] = {.lex_state = 63},
  [11369] = {.lex_state = 63},
  [11370] = {.lex_state = 63},
  [11371] = {.lex_state = 63},
  [11372] = {.lex_state = 63},
  [11373] = {.lex_state = 63},
  [11374] = {.lex_state = 63},
  [11375] = {.lex_state = 63},
  [11376] = {.lex_state = 63},
  [11377] = {.lex_state = 63},
  [11378] = {.lex_state = 63},
  [11379] = {.lex_state = 63},
  [11380] = {.lex_state = 63},
  [11381] = {.lex_state = 63},
  [11382] = {.lex_state = 63},
  [11383] = {.lex_state = 63},
  [11384] = {.lex_state = 63},
  [11385] = {.lex_state = 63},
  [11386] = {.lex_state = 63},
  [11387] = {.lex_state = 63},
  [11388] = {.lex_state = 63},
  [11389] = {.lex_state = 63},
  [11390] = {.lex_state = 63},
  [11391] = {.lex_state = 63},
  [11392] = {.lex_state = 63},
  [11393] = {.lex_state = 63},
  [11394] = {.lex_state = 63},
  [11395] = {.lex_state = 63},
  [11396] = {.lex_state = 63},
  [11397] = {.lex_state = 63},
  [11398] = {.lex_state = 63},
  [11399] = {.lex_state = 63},
  [11400] = {.lex_state = 63},
  [11401] = {.lex_state = 63},
  [11402] = {.lex_state = 63},
  [11403] = {.lex_state = 63},
  [11404] = {.lex_state = 63},
  [11405] = {.lex_state = 63},
  [11406] = {.lex_state = 63},
  [11407] = {.lex_state = 63},
  [11408] = {.lex_state = 63},
  [11409] = {.lex_state = 63},
  [11410] = {.lex_state = 63},
  [11411] = {.lex_state = 63},
  [11412] = {.lex_state = 63},
  [11413] = {.lex_state = 63},
  [11414] = {.lex_state = 63},
  [11415] = {.lex_state = 63},
  [11416] = {.lex_state = 63},
  [11417] = {.lex_state = 63},
  [11418] = {.lex_state = 63},
  [11419] = {.lex_state = 63},
  [11420] = {.lex_state = 63},
  [11421] = {.lex_state = 63},
  [11422] = {.lex_state = 63},
  [11423] = {.lex_state = 63},
  [11424] = {.lex_state = 63},
  [11425] = {.lex_state = 63},
  [11426] = {.lex_state = 63},
  [11427] = {.lex_state = 63},
  [11428] = {.lex_state = 63},
  [11429] = {.lex_state = 63},
  [11430] = {.lex_state = 63},
  [11431] = {.lex_state = 63},
  [11432] = {.lex_state = 63},
  [11433] = {.lex_state = 63},
  [11434] = {.lex_state = 63},
  [11435] = {.lex_state = 63},
  [11436] = {.lex_state = 63},
  [11437] = {.lex_state = 63},
  [11438] = {.lex_state = 63},
  [11439] = {.lex_state = 63},
  [11440] = {.lex_state = 63},
  [11441] = {.lex_state = 63},
  [11442] = {.lex_state = 63},
  [11443] = {.lex_state = 63},
  [11444] = {.lex_state = 63},
  [11445] = {.lex_state = 63},
  [11446] = {.lex_state = 63},
  [11447] = {.lex_state = 63},
  [11448] = {.lex_state = 63},
  [11449] = {.lex_state = 63},
  [11450] = {.lex_state = 63},
  [11451] = {.lex_state = 63},
  [11452] = {.lex_state = 63},
  [11453] = {.lex_state = 63},
  [11454] = {.lex_state = 63},
  [11455] = {.lex_state = 63},
  [11456] = {.lex_state = 63},
  [11457] = {.lex_state = 63},
  [11458] = {.lex_state = 53, .external_lex_state = 40},
  [11459] = {.lex_state = 60, .external_lex_state = 27},
  [11460] = {.lex_state = 63},
  [11461] = {.lex_state = 24},
  [11462] = {.lex_state = 53, .external_lex_state = 40},
  [11463] = {.lex_state = 24},
  [11464] = {.lex_state = 54, .external_lex_state = 37},
  [11465] = {.lex_state = 53, .external_lex_state = 40},
  [11466] = {.lex_state = 54, .external_lex_state = 60},
  [11467] = {.lex_state = 53, .external_lex_state = 40},
  [11468] = {.lex_state = 18},
  [11469] = {.lex_state = 54, .external_lex_state = 61},
  [11470] = {.lex_state = 54, .external_lex_state = 31},
  [11471] = {.lex_state = 63},
  [11472] = {.lex_state = 53, .external_lex_state = 53},
  [11473] = {.lex_state = 53, .external_lex_state = 40},
  [11474] = {.lex_state = 54, .external_lex_state = 61},
  [11475] = {.lex_state = 54, .external_lex_state = 62},
  [11476] = {.lex_state = 54, .external_lex_state = 62},
  [11477] = {.lex_state = 54, .external_lex_state = 31},
  [11478] = {.lex_state = 54, .external_lex_state = 28},
  [11479] = {.lex_state = 54, .external_lex_state = 49},
  [11480] = {.lex_state = 60, .external_lex_state = 31},
  [11481] = {.lex_state = 53, .external_lex_state = 40},
  [11482] = {.lex_state = 4},
  [11483] = {.lex_state = 54, .external_lex_state = 62},
  [11484] = {.lex_state = 54, .external_lex_state = 60},
  [11485] = {.lex_state = 4},
  [11486] = {.lex_state = 54, .external_lex_state = 28},
  [11487] = {.lex_state = 54, .external_lex_state = 60},
  [11488] = {.lex_state = 54, .external_lex_state = 60},
  [11489] = {.lex_state = 54, .external_lex_state = 28},
  [11490] = {.lex_state = 54, .external_lex_state = 28},
  [11491] = {.lex_state = 54, .external_lex_state = 28},
  [11492] = {.lex_state = 54, .external_lex_state = 28},
  [11493] = {.lex_state = 54, .external_lex_state = 28},
  [11494] = {.lex_state = 60, .external_lex_state = 23},
  [11495] = {.lex_state = 24},
  [11496] = {.lex_state = 4},
  [11497] = {.lex_state = 54, .external_lex_state = 60},
  [11498] = {.lex_state = 60, .external_lex_state = 23},
  [11499] = {.lex_state = 4},
  [11500] = {.lex_state = 4},
  [11501] = {.lex_state = 54, .external_lex_state = 31},
  [11502] = {.lex_state = 4},
  [11503] = {.lex_state = 4},
  [11504] = {.lex_state = 53, .external_lex_state = 53},
  [11505] = {.lex_state = 54, .external_lex_state = 28},
  [11506] = {.lex_state = 54, .external_lex_state = 31},
  [11507] = {.lex_state = 53, .external_lex_state = 40},
  [11508] = {.lex_state = 54, .external_lex_state = 31},
  [11509] = {.lex_state = 54, .external_lex_state = 63},
  [11510] = {.lex_state = 60, .external_lex_state = 27},
  [11511] = {.lex_state = 54, .external_lex_state = 51},
  [11512] = {.lex_state = 54, .external_lex_state = 60},
  [11513] = {.lex_state = 54, .external_lex_state = 35},
  [11514] = {.lex_state = 53, .external_lex_state = 53},
  [11515] = {.lex_state = 54, .external_lex_state = 31},
  [11516] = {.lex_state = 4},
  [11517] = {.lex_state = 4},
  [11518] = {.lex_state = 53, .external_lex_state = 53},
  [11519] = {.lex_state = 53, .external_lex_state = 53},
  [11520] = {.lex_state = 54, .external_lex_state = 61},
  [11521] = {.lex_state = 54, .external_lex_state = 36},
  [11522] = {.lex_state = 54, .external_lex_state = 36},
  [11523] = {.lex_state = 54, .external_lex_state = 36},
  [11524] = {.lex_state = 53, .external_lex_state = 40},
  [11525] = {.lex_state = 54, .external_lex_state = 36},
  [11526] = {.lex_state = 4},
  [11527] = {.lex_state = 4},
  [11528] = {.lex_state = 54, .external_lex_state = 60},
  [11529] = {.lex_state = 4},
  [11530] = {.lex_state = 4},
  [11531] = {.lex_state = 4},
  [11532] = {.lex_state = 52, .external_lex_state = 64},
  [11533] = {.lex_state = 54, .external_lex_state = 31},
  [11534] = {.lex_state = 54, .external_lex_state = 31},
  [11535] = {.lex_state = 4},
  [11536] = {.lex_state = 54, .external_lex_state = 31},
  [11537] = {.lex_state = 54, .external_lex_state = 31},
  [11538] = {.lex_state = 54, .external_lex_state = 31},
  [11539] = {.lex_state = 52, .external_lex_state = 64},
  [11540] = {.lex_state = 52, .external_lex_state = 64},
  [11541] = {.lex_state = 52, .external_lex_state = 64},
  [11542] = {.lex_state = 60, .external_lex_state = 27},
  [11543] = {.lex_state = 63},
  [11544] = {.lex_state = 4},
  [11545] = {.lex_state = 53, .external_lex_state = 53},
  [11546] = {.lex_state = 52, .external_lex_state = 64},
  [11547] = {.lex_state = 54, .external_lex_state = 63},
  [11548] = {.lex_state = 54, .external_lex_state = 35},
  [11549] = {.lex_state = 54, .external_lex_state = 60},
  [11550] = {.lex_state = 54, .external_lex_state = 63},
  [11551] = {.lex_state = 60, .external_lex_state = 27},
  [11552] = {.lex_state = 60, .external_lex_state = 27},
  [11553] = {.lex_state = 60, .external_lex_state = 27},
  [11554] = {.lex_state = 54, .external_lex_state = 45},
  [11555] = {.lex_state = 60, .external_lex_state = 27},
  [11556] = {.lex_state = 53, .external_lex_state = 53},
  [11557] = {.lex_state = 60, .external_lex_state = 27},
  [11558] = {.lex_state = 53, .external_lex_state = 40},
  [11559] = {.lex_state = 60, .external_lex_state = 27},
  [11560] = {.lex_state = 60, .external_lex_state = 27},
  [11561] = {.lex_state = 60, .external_lex_state = 27},
  [11562] = {.lex_state = 60, .external_lex_state = 27},
  [11563] = {.lex_state = 60, .external_lex_state = 27},
  [11564] = {.lex_state = 60, .external_lex_state = 27},
  [11565] = {.lex_state = 60, .external_lex_state = 27},
  [11566] = {.lex_state = 60, .external_lex_state = 27},
  [11567] = {.lex_state = 60, .external_lex_state = 27},
  [11568] = {.lex_state = 60, .external_lex_state = 27},
  [11569] = {.lex_state = 60, .external_lex_state = 36},
  [11570] = {.lex_state = 53, .external_lex_state = 53},
  [11571] = {.lex_state = 52, .external_lex_state = 64},
  [11572] = {.lex_state = 60, .external_lex_state = 27},
  [11573] = {.lex_state = 60, .external_lex_state = 27},
  [11574] = {.lex_state = 54, .external_lex_state = 40},
  [11575] = {.lex_state = 60, .external_lex_state = 27},
  [11576] = {.lex_state = 4},
  [11577] = {.lex_state = 53, .external_lex_state = 40},
  [11578] = {.lex_state = 60, .external_lex_state = 27},
  [11579] = {.lex_state = 54, .external_lex_state = 40},
  [11580] = {.lex_state = 53, .external_lex_state = 40},
  [11581] = {.lex_state = 54, .external_lex_state = 35},
  [11582] = {.lex_state = 60, .external_lex_state = 27},
  [11583] = {.lex_state = 54, .external_lex_state = 53},
  [11584] = {.lex_state = 63},
  [11585] = {.lex_state = 53, .external_lex_state = 40},
  [11586] = {.lex_state = 53, .external_lex_state = 40},
  [11587] = {.lex_state = 54, .external_lex_state = 23},
  [11588] = {.lex_state = 53, .external_lex_state = 40},
  [11589] = {.lex_state = 53, .external_lex_state = 40},
  [11590] = {.lex_state = 54, .external_lex_state = 37},
  [11591] = {.lex_state = 54, .external_lex_state = 37},
  [11592] = {.lex_state = 4},
  [11593] = {.lex_state = 53, .external_lex_state = 40},
  [11594] = {.lex_state = 4},
  [11595] = {.lex_state = 53, .external_lex_state = 40},
  [11596] = {.lex_state = 53, .external_lex_state = 53},
  [11597] = {.lex_state = 54, .external_lex_state = 62},
  [11598] = {.lex_state = 4},
  [11599] = {.lex_state = 54, .external_lex_state = 62},
  [11600] = {.lex_state = 4},
  [11601] = {.lex_state = 54, .external_lex_state = 62},
  [11602] = {.lex_state = 63},
  [11603] = {.lex_state = 54, .external_lex_state = 62},
  [11604] = {.lex_state = 53, .external_lex_state = 40},
  [11605] = {.lex_state = 54, .external_lex_state = 62},
  [11606] = {.lex_state = 4},
  [11607] = {.lex_state = 4},
  [11608] = {.lex_state = 4},
  [11609] = {.lex_state = 4},
  [11610] = {.lex_state = 4},
  [11611] = {.lex_state = 53, .external_lex_state = 40},
  [11612] = {.lex_state = 53, .external_lex_state = 40},
  [11613] = {.lex_state = 53, .external_lex_state = 40},
  [11614] = {.lex_state = 63},
  [11615] = {.lex_state = 54, .external_lex_state = 40},
  [11616] = {.lex_state = 53, .external_lex_state = 40},
  [11617] = {.lex_state = 53, .external_lex_state = 40},
  [11618] = {.lex_state = 53, .external_lex_state = 53},
  [11619] = {.lex_state = 54, .external_lex_state = 60},
  [11620] = {.lex_state = 60, .external_lex_state = 35},
  [11621] = {.lex_state = 60, .external_lex_state = 27},
  [11622] = {.lex_state = 60, .external_lex_state = 27},
  [11623] = {.lex_state = 60, .external_lex_state = 27},
  [11624] = {.lex_state = 60, .external_lex_state = 27},
  [11625] = {.lex_state = 60, .external_lex_state = 27},
  [11626] = {.lex_state = 60, .external_lex_state = 27},
  [11627] = {.lex_state = 60, .external_lex_state = 27},
  [11628] = {.lex_state = 63},
  [11629] = {.lex_state = 54, .external_lex_state = 63},
  [11630] = {.lex_state = 54, .external_lex_state = 62},
  [11631] = {.lex_state = 53, .external_lex_state = 40},
  [11632] = {.lex_state = 54, .external_lex_state = 60},
  [11633] = {.lex_state = 60, .external_lex_state = 37},
  [11634] = {.lex_state = 54, .external_lex_state = 31},
  [11635] = {.lex_state = 54, .external_lex_state = 53},
  [11636] = {.lex_state = 60, .external_lex_state = 37},
  [11637] = {.lex_state = 54, .external_lex_state = 35},
  [11638] = {.lex_state = 53, .external_lex_state = 23},
  [11639] = {.lex_state = 63},
  [11640] = {.lex_state = 54, .external_lex_state = 60},
  [11641] = {.lex_state = 54, .external_lex_state = 60},
  [11642] = {.lex_state = 54, .external_lex_state = 62},
  [11643] = {.lex_state = 54, .external_lex_state = 60},
  [11644] = {.lex_state = 54, .external_lex_state = 62},
  [11645] = {.lex_state = 54, .external_lex_state = 61},
  [11646] = {.lex_state = 54, .external_lex_state = 62},
  [11647] = {.lex_state = 54, .external_lex_state = 60},
  [11648] = {.lex_state = 54, .external_lex_state = 62},
  [11649] = {.lex_state = 54, .external_lex_state = 60},
  [11650] = {.lex_state = 54, .external_lex_state = 61},
  [11651] = {.lex_state = 54, .external_lex_state = 36},
  [11652] = {.lex_state = 54, .external_lex_state = 62},
  [11653] = {.lex_state = 53, .external_lex_state = 40},
  [11654] = {.lex_state = 54, .external_lex_state = 31},
  [11655] = {.lex_state = 54, .external_lex_state = 62},
  [11656] = {.lex_state = 4},
  [11657] = {.lex_state = 4},
  [11658] = {.lex_state = 54, .external_lex_state = 35},
  [11659] = {.lex_state = 54, .external_lex_state = 37},
  [11660] = {.lex_state = 63},
  [11661] = {.lex_state = 63},
  [11662] = {.lex_state = 63},
  [11663] = {.lex_state = 54},
  [11664] = {.lex_state = 54, .external_lex_state = 28},
  [11665] = {.lex_state = 54, .external_lex_state = 31},
  [11666] = {.lex_state = 63},
  [11667] = {.lex_state = 63},
  [11668] = {.lex_state = 54, .external_lex_state = 62},
  [11669] = {.lex_state = 63},
  [11670] = {.lex_state = 54, .external_lex_state = 36},
  [11671] = {.lex_state = 54, .external_lex_state = 35},
  [11672] = {.lex_state = 54, .external_lex_state = 61},
  [11673] = {.lex_state = 54, .external_lex_state = 28},
  [11674] = {.lex_state = 63, .external_lex_state = 25},
  [11675] = {.lex_state = 54, .external_lex_state = 31},
  [11676] = {.lex_state = 53, .external_lex_state = 40},
  [11677] = {.lex_state = 54, .external_lex_state = 28},
  [11678] = {.lex_state = 54, .external_lex_state = 36},
  [11679] = {.lex_state = 54, .external_lex_state = 36},
  [11680] = {.lex_state = 54, .external_lex_state = 28},
  [11681] = {.lex_state = 54, .external_lex_state = 53},
  [11682] = {.lex_state = 54, .external_lex_state = 36},
  [11683] = {.lex_state = 54, .external_lex_state = 28},
  [11684] = {.lex_state = 54, .external_lex_state = 36},
  [11685] = {.lex_state = 54, .external_lex_state = 36},
  [11686] = {.lex_state = 54, .external_lex_state = 28},
  [11687] = {.lex_state = 54, .external_lex_state = 36},
  [11688] = {.lex_state = 54, .external_lex_state = 28},
  [11689] = {.lex_state = 54, .external_lex_state = 36},
  [11690] = {.lex_state = 53, .external_lex_state = 40},
  [11691] = {.lex_state = 52, .external_lex_state = 64},
  [11692] = {.lex_state = 52, .external_lex_state = 64},
  [11693] = {.lex_state = 52, .external_lex_state = 64},
  [11694] = {.lex_state = 53, .external_lex_state = 40},
  [11695] = {.lex_state = 54, .external_lex_state = 62},
  [11696] = {.lex_state = 24},
  [11697] = {.lex_state = 24},
  [11698] = {.lex_state = 54, .external_lex_state = 35},
  [11699] = {.lex_state = 4},
  [11700] = {.lex_state = 60, .external_lex_state = 28},
  [11701] = {.lex_state = 54, .external_lex_state = 35},
  [11702] = {.lex_state = 54, .external_lex_state = 35},
  [11703] = {.lex_state = 54, .external_lex_state = 35},
  [11704] = {.lex_state = 52, .external_lex_state = 64},
  [11705] = {.lex_state = 63},
  [11706] = {.lex_state = 52, .external_lex_state = 64},
  [11707] = {.lex_state = 54, .external_lex_state = 31},
  [11708] = {.lex_state = 52, .external_lex_state = 64},
  [11709] = {.lex_state = 52, .external_lex_state = 64},
  [11710] = {.lex_state = 52, .external_lex_state = 64},
  [11711] = {.lex_state = 54, .external_lex_state = 35},
  [11712] = {.lex_state = 52},
  [11713] = {.lex_state = 53, .external_lex_state = 40},
  [11714] = {.lex_state = 54, .external_lex_state = 28},
  [11715] = {.lex_state = 54, .external_lex_state = 35},
  [11716] = {.lex_state = 54, .external_lex_state = 35},
  [11717] = {.lex_state = 54, .external_lex_state = 31},
  [11718] = {.lex_state = 54, .external_lex_state = 48},
  [11719] = {.lex_state = 53, .external_lex_state = 40},
  [11720] = {.lex_state = 63},
  [11721] = {.lex_state = 63},
  [11722] = {.lex_state = 63},
  [11723] = {.lex_state = 63},
  [11724] = {.lex_state = 63},
  [11725] = {.lex_state = 63},
  [11726] = {.lex_state = 63},
  [11727] = {.lex_state = 63},
  [11728] = {.lex_state = 63},
  [11729] = {.lex_state = 63},
  [11730] = {.lex_state = 63},
  [11731] = {.lex_state = 63},
  [11732] = {.lex_state = 63},
  [11733] = {.lex_state = 63},
  [11734] = {.lex_state = 63},
  [11735] = {.lex_state = 63},
  [11736] = {.lex_state = 63},
  [11737] = {.lex_state = 63},
  [11738] = {.lex_state = 63},
  [11739] = {.lex_state = 63},
  [11740] = {.lex_state = 63},
  [11741] = {.lex_state = 63},
  [11742] = {.lex_state = 63},
  [11743] = {.lex_state = 63},
  [11744] = {.lex_state = 63},
  [11745] = {.lex_state = 63},
  [11746] = {.lex_state = 63},
  [11747] = {.lex_state = 63},
  [11748] = {.lex_state = 63},
  [11749] = {.lex_state = 63},
  [11750] = {.lex_state = 63},
  [11751] = {.lex_state = 63},
  [11752] = {.lex_state = 63},
  [11753] = {.lex_state = 63},
  [11754] = {.lex_state = 63},
  [11755] = {.lex_state = 63},
  [11756] = {.lex_state = 63},
  [11757] = {.lex_state = 63},
  [11758] = {.lex_state = 63},
  [11759] = {.lex_state = 63},
  [11760] = {.lex_state = 63},
  [11761] = {.lex_state = 63},
  [11762] = {.lex_state = 63},
  [11763] = {.lex_state = 63},
  [11764] = {.lex_state = 63},
  [11765] = {.lex_state = 63},
  [11766] = {.lex_state = 63},
  [11767] = {.lex_state = 63},
  [11768] = {.lex_state = 63},
  [11769] = {.lex_state = 63},
  [11770] = {.lex_state = 63},
  [11771] = {.lex_state = 63},
  [11772] = {.lex_state = 63},
  [11773] = {.lex_state = 63},
  [11774] = {.lex_state = 63},
  [11775] = {.lex_state = 63},
  [11776] = {.lex_state = 63},
  [11777] = {.lex_state = 63},
  [11778] = {.lex_state = 63},
  [11779] = {.lex_state = 63},
  [11780] = {.lex_state = 63},
  [11781] = {.lex_state = 63},
  [11782] = {.lex_state = 63},
  [11783] = {.lex_state = 63},
  [11784] = {.lex_state = 54, .external_lex_state = 28},
  [11785] = {.lex_state = 60, .external_lex_state = 28},
  [11786] = {.lex_state = 63},
  [11787] = {.lex_state = 54, .external_lex_state = 63},
  [11788] = {.lex_state = 54, .external_lex_state = 53},
  [11789] = {.lex_state = 63},
  [11790] = {.lex_state = 53, .external_lex_state = 53},
  [11791] = {.lex_state = 54, .external_lex_state = 42},
  [11792] = {.lex_state = 63},
  [11793] = {.lex_state = 54, .external_lex_state = 42},
  [11794] = {.lex_state = 54, .external_lex_state = 63},
  [11795] = {.lex_state = 63},
  [11796] = {.lex_state = 54, .external_lex_state = 35},
  [11797] = {.lex_state = 54, .external_lex_state = 39},
  [11798] = {.lex_state = 54, .external_lex_state = 39},
  [11799] = {.lex_state = 54, .external_lex_state = 39},
  [11800] = {.lex_state = 63},
  [11801] = {.lex_state = 54, .external_lex_state = 63},
  [11802] = {.lex_state = 63},
  [11803] = {.lex_state = 63},
  [11804] = {.lex_state = 54, .external_lex_state = 61},
  [11805] = {.lex_state = 63},
  [11806] = {.lex_state = 54, .external_lex_state = 63},
  [11807] = {.lex_state = 53, .external_lex_state = 53},
  [11808] = {.lex_state = 54, .external_lex_state = 36},
  [11809] = {.lex_state = 54, .external_lex_state = 65},
  [11810] = {.lex_state = 54, .external_lex_state = 63},
  [11811] = {.lex_state = 54, .external_lex_state = 36},
  [11812] = {.lex_state = 63},
  [11813] = {.lex_state = 54, .external_lex_state = 36},
  [11814] = {.lex_state = 54, .external_lex_state = 35},
  [11815] = {.lex_state = 63},
  [11816] = {.lex_state = 54, .external_lex_state = 61},
  [11817] = {.lex_state = 54, .external_lex_state = 60},
  [11818] = {.lex_state = 54, .external_lex_state = 63},
  [11819] = {.lex_state = 54, .external_lex_state = 61},
  [11820] = {.lex_state = 63},
  [11821] = {.lex_state = 60, .external_lex_state = 28},
  [11822] = {.lex_state = 63},
  [11823] = {.lex_state = 63},
  [11824] = {.lex_state = 53, .external_lex_state = 53},
  [11825] = {.lex_state = 54, .external_lex_state = 35},
  [11826] = {.lex_state = 54, .external_lex_state = 61},
  [11827] = {.lex_state = 60, .external_lex_state = 28},
  [11828] = {.lex_state = 63},
  [11829] = {.lex_state = 63},
  [11830] = {.lex_state = 54, .external_lex_state = 63},
  [11831] = {.lex_state = 63},
  [11832] = {.lex_state = 63},
  [11833] = {.lex_state = 54, .external_lex_state = 63},
  [11834] = {.lex_state = 63},
  [11835] = {.lex_state = 63},
  [11836] = {.lex_state = 63},
  [11837] = {.lex_state = 54, .external_lex_state = 61},
  [11838] = {.lex_state = 54, .external_lex_state = 42},
  [11839] = {.lex_state = 63},
  [11840] = {.lex_state = 63},
  [11841] = {.lex_state = 54, .external_lex_state = 61},
  [11842] = {.lex_state = 54, .external_lex_state = 61},
  [11843] = {.lex_state = 51},
  [11844] = {.lex_state = 51},
  [11845] = {.lex_state = 63},
  [11846] = {.lex_state = 63},
  [11847] = {.lex_state = 63},
  [11848] = {.lex_state = 54, .external_lex_state = 61},
  [11849] = {.lex_state = 63},
  [11850] = {.lex_state = 60, .external_lex_state = 31},
  [11851] = {.lex_state = 54, .external_lex_state = 61},
  [11852] = {.lex_state = 60, .external_lex_state = 31},
  [11853] = {.lex_state = 63},
  [11854] = {.lex_state = 54, .external_lex_state = 61},
  [11855] = {.lex_state = 54, .external_lex_state = 61},
  [11856] = {.lex_state = 53},
  [11857] = {.lex_state = 60, .external_lex_state = 31},
  [11858] = {.lex_state = 63},
  [11859] = {.lex_state = 63},
  [11860] = {.lex_state = 54, .external_lex_state = 61},
  [11861] = {.lex_state = 60, .external_lex_state = 31},
  [11862] = {.lex_state = 60, .external_lex_state = 31},
  [11863] = {.lex_state = 60, .external_lex_state = 31},
  [11864] = {.lex_state = 53},
  [11865] = {.lex_state = 60, .external_lex_state = 31},
  [11866] = {.lex_state = 63},
  [11867] = {.lex_state = 60, .external_lex_state = 31},
  [11868] = {.lex_state = 54, .external_lex_state = 35},
  [11869] = {.lex_state = 60, .external_lex_state = 31},
  [11870] = {.lex_state = 54, .external_lex_state = 61},
  [11871] = {.lex_state = 63},
  [11872] = {.lex_state = 54, .external_lex_state = 63},
  [11873] = {.lex_state = 54, .external_lex_state = 66},
  [11874] = {.lex_state = 60, .external_lex_state = 28},
  [11875] = {.lex_state = 53},
  [11876] = {.lex_state = 63},
  [11877] = {.lex_state = 53, .external_lex_state = 53},
  [11878] = {.lex_state = 53},
  [11879] = {.lex_state = 63},
  [11880] = {.lex_state = 63},
  [11881] = {.lex_state = 63},
  [11882] = {.lex_state = 54, .external_lex_state = 35},
  [11883] = {.lex_state = 60, .external_lex_state = 31},
  [11884] = {.lex_state = 63},
  [11885] = {.lex_state = 54, .external_lex_state = 23},
  [11886] = {.lex_state = 63},
  [11887] = {.lex_state = 63},
  [11888] = {.lex_state = 63},
  [11889] = {.lex_state = 63},
  [11890] = {.lex_state = 53},
  [11891] = {.lex_state = 60, .external_lex_state = 28},
  [11892] = {.lex_state = 60, .external_lex_state = 28},
  [11893] = {.lex_state = 60, .external_lex_state = 28},
  [11894] = {.lex_state = 60, .external_lex_state = 28},
  [11895] = {.lex_state = 60, .external_lex_state = 28},
  [11896] = {.lex_state = 60, .external_lex_state = 28},
  [11897] = {.lex_state = 53},
  [11898] = {.lex_state = 53},
  [11899] = {.lex_state = 53},
  [11900] = {.lex_state = 53},
  [11901] = {.lex_state = 60, .external_lex_state = 31},
  [11902] = {.lex_state = 63},
  [11903] = {.lex_state = 63},
  [11904] = {.lex_state = 53, .external_lex_state = 53},
  [11905] = {.lex_state = 60, .external_lex_state = 31},
  [11906] = {.lex_state = 60, .external_lex_state = 31},
  [11907] = {.lex_state = 54, .external_lex_state = 36},
  [11908] = {.lex_state = 54, .external_lex_state = 24},
  [11909] = {.lex_state = 54, .external_lex_state = 61},
  [11910] = {.lex_state = 63},
  [11911] = {.lex_state = 63},
  [11912] = {.lex_state = 63},
  [11913] = {.lex_state = 63},
  [11914] = {.lex_state = 53, .external_lex_state = 53},
  [11915] = {.lex_state = 54, .external_lex_state = 65},
  [11916] = {.lex_state = 54, .external_lex_state = 36},
  [11917] = {.lex_state = 63},
  [11918] = {.lex_state = 63},
  [11919] = {.lex_state = 53, .external_lex_state = 53},
  [11920] = {.lex_state = 53, .external_lex_state = 53},
  [11921] = {.lex_state = 63},
  [11922] = {.lex_state = 63},
  [11923] = {.lex_state = 63},
  [11924] = {.lex_state = 63},
  [11925] = {.lex_state = 51},
  [11926] = {.lex_state = 51},
  [11927] = {.lex_state = 63},
  [11928] = {.lex_state = 60, .external_lex_state = 37},
  [11929] = {.lex_state = 54, .external_lex_state = 36},
  [11930] = {.lex_state = 54, .external_lex_state = 36},
  [11931] = {.lex_state = 63},
  [11932] = {.lex_state = 63},
  [11933] = {.lex_state = 54, .external_lex_state = 36},
  [11934] = {.lex_state = 54, .external_lex_state = 40},
  [11935] = {.lex_state = 54, .external_lex_state = 36},
  [11936] = {.lex_state = 53, .external_lex_state = 53},
  [11937] = {.lex_state = 54, .external_lex_state = 36},
  [11938] = {.lex_state = 63},
  [11939] = {.lex_state = 54, .external_lex_state = 35},
  [11940] = {.lex_state = 54, .external_lex_state = 36},
  [11941] = {.lex_state = 54, .external_lex_state = 36},
  [11942] = {.lex_state = 54, .external_lex_state = 36},
  [11943] = {.lex_state = 63},
  [11944] = {.lex_state = 54, .external_lex_state = 56},
  [11945] = {.lex_state = 51},
  [11946] = {.lex_state = 63},
  [11947] = {.lex_state = 63},
  [11948] = {.lex_state = 53, .external_lex_state = 53},
  [11949] = {.lex_state = 60, .external_lex_state = 31},
  [11950] = {.lex_state = 60, .external_lex_state = 28},
  [11951] = {.lex_state = 53, .external_lex_state = 53},
  [11952] = {.lex_state = 54, .external_lex_state = 62},
  [11953] = {.lex_state = 60, .external_lex_state = 31},
  [11954] = {.lex_state = 51},
  [11955] = {.lex_state = 63},
  [11956] = {.lex_state = 60, .external_lex_state = 31},
  [11957] = {.lex_state = 60, .external_lex_state = 31},
  [11958] = {.lex_state = 54, .external_lex_state = 36},
  [11959] = {.lex_state = 63},
  [11960] = {.lex_state = 63},
  [11961] = {.lex_state = 51},
  [11962] = {.lex_state = 60, .external_lex_state = 31},
  [11963] = {.lex_state = 63},
  [11964] = {.lex_state = 63},
  [11965] = {.lex_state = 53, .external_lex_state = 24},
  [11966] = {.lex_state = 54, .external_lex_state = 37},
  [11967] = {.lex_state = 60, .external_lex_state = 28},
  [11968] = {.lex_state = 63},
  [11969] = {.lex_state = 51},
  [11970] = {.lex_state = 51},
  [11971] = {.lex_state = 63},
  [11972] = {.lex_state = 53},
  [11973] = {.lex_state = 63},
  [11974] = {.lex_state = 63},
  [11975] = {.lex_state = 63},
  [11976] = {.lex_state = 63},
  [11977] = {.lex_state = 60, .external_lex_state = 42},
  [11978] = {.lex_state = 53},
  [11979] = {.lex_state = 54, .external_lex_state = 23},
  [11980] = {.lex_state = 60, .external_lex_state = 28},
  [11981] = {.lex_state = 63},
  [11982] = {.lex_state = 60, .external_lex_state = 42},
  [11983] = {.lex_state = 54, .external_lex_state = 63},
  [11984] = {.lex_state = 53},
  [11985] = {.lex_state = 60, .external_lex_state = 28},
  [11986] = {.lex_state = 60, .external_lex_state = 28},
  [11987] = {.lex_state = 54, .external_lex_state = 35},
  [11988] = {.lex_state = 54, .external_lex_state = 57},
  [11989] = {.lex_state = 60, .external_lex_state = 28},
  [11990] = {.lex_state = 63},
  [11991] = {.lex_state = 54, .external_lex_state = 35},
  [11992] = {.lex_state = 51},
  [11993] = {.lex_state = 54, .external_lex_state = 63},
  [11994] = {.lex_state = 54, .external_lex_state = 23},
  [11995] = {.lex_state = 53},
  [11996] = {.lex_state = 60, .external_lex_state = 28},
  [11997] = {.lex_state = 63},
  [11998] = {.lex_state = 60, .external_lex_state = 28},
  [11999] = {.lex_state = 60, .external_lex_state = 28},
  [12000] = {.lex_state = 54, .external_lex_state = 35},
  [12001] = {.lex_state = 63},
  [12002] = {.lex_state = 60, .external_lex_state = 28},
  [12003] = {.lex_state = 60, .external_lex_state = 28},
  [12004] = {.lex_state = 60, .external_lex_state = 28},
  [12005] = {.lex_state = 60, .external_lex_state = 39},
  [12006] = {.lex_state = 60, .external_lex_state = 28},
  [12007] = {.lex_state = 54, .external_lex_state = 35},
  [12008] = {.lex_state = 54, .external_lex_state = 35},
  [12009] = {.lex_state = 60, .external_lex_state = 28},
  [12010] = {.lex_state = 54, .external_lex_state = 35},
  [12011] = {.lex_state = 63},
  [12012] = {.lex_state = 60, .external_lex_state = 28},
  [12013] = {.lex_state = 54, .external_lex_state = 35},
  [12014] = {.lex_state = 54, .external_lex_state = 35},
  [12015] = {.lex_state = 54, .external_lex_state = 23},
  [12016] = {.lex_state = 63},
  [12017] = {.lex_state = 63},
  [12018] = {.lex_state = 63},
  [12019] = {.lex_state = 60, .external_lex_state = 28},
  [12020] = {.lex_state = 53, .external_lex_state = 53},
  [12021] = {.lex_state = 63},
  [12022] = {.lex_state = 60, .external_lex_state = 31},
  [12023] = {.lex_state = 60, .external_lex_state = 39},
  [12024] = {.lex_state = 63},
  [12025] = {.lex_state = 63},
  [12026] = {.lex_state = 54, .external_lex_state = 61},
  [12027] = {.lex_state = 63},
  [12028] = {.lex_state = 60, .external_lex_state = 28},
  [12029] = {.lex_state = 60, .external_lex_state = 28},
  [12030] = {.lex_state = 54, .external_lex_state = 58},
  [12031] = {.lex_state = 60, .external_lex_state = 28},
  [12032] = {.lex_state = 63},
  [12033] = {.lex_state = 54, .external_lex_state = 23},
  [12034] = {.lex_state = 63},
  [12035] = {.lex_state = 60, .external_lex_state = 28},
  [12036] = {.lex_state = 63},
  [12037] = {.lex_state = 54, .external_lex_state = 36},
  [12038] = {.lex_state = 63},
  [12039] = {.lex_state = 63},
  [12040] = {.lex_state = 60, .external_lex_state = 23},
  [12041] = {.lex_state = 60, .external_lex_state = 35},
  [12042] = {.lex_state = 63},
  [12043] = {.lex_state = 63},
  [12044] = {.lex_state = 63},
  [12045] = {.lex_state = 63},
  [12046] = {.lex_state = 63},
  [12047] = {.lex_state = 54, .external_lex_state = 39},
  [12048] = {.lex_state = 54, .external_lex_state = 63},
  [12049] = {.lex_state = 53, .external_lex_state = 53},
  [12050] = {.lex_state = 63},
  [12051] = {.lex_state = 54, .external_lex_state = 23},
  [12052] = {.lex_state = 60, .external_lex_state = 31},
  [12053] = {.lex_state = 63},
  [12054] = {.lex_state = 63},
  [12055] = {.lex_state = 54, .external_lex_state = 40},
  [12056] = {.lex_state = 63},
  [12057] = {.lex_state = 63},
  [12058] = {.lex_state = 54, .external_lex_state = 37},
  [12059] = {.lex_state = 54, .external_lex_state = 37},
  [12060] = {.lex_state = 60, .external_lex_state = 36},
  [12061] = {.lex_state = 60, .external_lex_state = 31},
  [12062] = {.lex_state = 54, .external_lex_state = 23},
  [12063] = {.lex_state = 63},
  [12064] = {.lex_state = 63},
  [12065] = {.lex_state = 54, .external_lex_state = 37},
  [12066] = {.lex_state = 54, .external_lex_state = 35},
  [12067] = {.lex_state = 54, .external_lex_state = 37},
  [12068] = {.lex_state = 63},
  [12069] = {.lex_state = 63},
  [12070] = {.lex_state = 63},
  [12071] = {.lex_state = 60, .external_lex_state = 31},
  [12072] = {.lex_state = 60, .external_lex_state = 31},
  [12073] = {.lex_state = 54, .external_lex_state = 66},
  [12074] = {.lex_state = 63},
  [12075] = {.lex_state = 63},
  [12076] = {.lex_state = 63},
  [12077] = {.lex_state = 63},
  [12078] = {.lex_state = 54, .external_lex_state = 37},
  [12079] = {.lex_state = 63},
  [12080] = {.lex_state = 54, .external_lex_state = 37},
  [12081] = {.lex_state = 54, .external_lex_state = 37},
  [12082] = {.lex_state = 63},
  [12083] = {.lex_state = 54, .external_lex_state = 53},
  [12084] = {.lex_state = 54, .external_lex_state = 63},
  [12085] = {.lex_state = 54, .external_lex_state = 37},
  [12086] = {.lex_state = 60, .external_lex_state = 31},
  [12087] = {.lex_state = 60, .external_lex_state = 31},
  [12088] = {.lex_state = 54, .external_lex_state = 37},
  [12089] = {.lex_state = 63},
  [12090] = {.lex_state = 54, .external_lex_state = 37},
  [12091] = {.lex_state = 63},
  [12092] = {.lex_state = 54, .external_lex_state = 37},
  [12093] = {.lex_state = 60, .external_lex_state = 31},
  [12094] = {.lex_state = 54, .external_lex_state = 37},
  [12095] = {.lex_state = 54, .external_lex_state = 23},
  [12096] = {.lex_state = 63},
  [12097] = {.lex_state = 63},
  [12098] = {.lex_state = 54, .external_lex_state = 23},
  [12099] = {.lex_state = 63},
  [12100] = {.lex_state = 54, .external_lex_state = 23},
  [12101] = {.lex_state = 63},
  [12102] = {.lex_state = 60, .external_lex_state = 31},
  [12103] = {.lex_state = 63},
  [12104] = {.lex_state = 63},
  [12105] = {.lex_state = 63},
  [12106] = {.lex_state = 63},
  [12107] = {.lex_state = 63},
  [12108] = {.lex_state = 60, .external_lex_state = 31},
  [12109] = {.lex_state = 53, .external_lex_state = 53},
  [12110] = {.lex_state = 63},
  [12111] = {.lex_state = 63},
  [12112] = {.lex_state = 54, .external_lex_state = 60},
  [12113] = {.lex_state = 63},
  [12114] = {.lex_state = 63},
  [12115] = {.lex_state = 53, .external_lex_state = 53},
  [12116] = {.lex_state = 63},
  [12117] = {.lex_state = 63},
  [12118] = {.lex_state = 63},
  [12119] = {.lex_state = 60, .external_lex_state = 31},
  [12120] = {.lex_state = 63},
  [12121] = {.lex_state = 63},
  [12122] = {.lex_state = 63},
  [12123] = {.lex_state = 63},
  [12124] = {.lex_state = 63},
  [12125] = {.lex_state = 60, .external_lex_state = 31},
  [12126] = {.lex_state = 63},
  [12127] = {.lex_state = 63},
  [12128] = {.lex_state = 63},
  [12129] = {.lex_state = 53, .external_lex_state = 53},
  [12130] = {.lex_state = 63},
  [12131] = {.lex_state = 63},
  [12132] = {.lex_state = 54, .external_lex_state = 36},
  [12133] = {.lex_state = 54, .external_lex_state = 63},
  [12134] = {.lex_state = 63},
  [12135] = {.lex_state = 54, .external_lex_state = 60},
  [12136] = {.lex_state = 63},
  [12137] = {.lex_state = 63},
  [12138] = {.lex_state = 63},
  [12139] = {.lex_state = 54, .external_lex_state = 42},
  [12140] = {.lex_state = 63},
  [12141] = {.lex_state = 63},
  [12142] = {.lex_state = 54, .external_lex_state = 23},
  [12143] = {.lex_state = 63},
  [12144] = {.lex_state = 63},
  [12145] = {.lex_state = 63},
  [12146] = {.lex_state = 63},
  [12147] = {.lex_state = 63},
  [12148] = {.lex_state = 63},
  [12149] = {.lex_state = 21},
  [12150] = {.lex_state = 63},
  [12151] = {.lex_state = 63},
  [12152] = {.lex_state = 63},
  [12153] = {.lex_state = 63},
  [12154] = {.lex_state = 63},
  [12155] = {.lex_state = 63},
  [12156] = {.lex_state = 53, .external_lex_state = 24},
  [12157] = {.lex_state = 54, .external_lex_state = 35},
  [12158] = {.lex_state = 63},
  [12159] = {.lex_state = 63},
  [12160] = {.lex_state = 54, .external_lex_state = 63},
  [12161] = {.lex_state = 54, .external_lex_state = 36},
  [12162] = {.lex_state = 54, .external_lex_state = 63},
  [12163] = {.lex_state = 54, .external_lex_state = 60},
  [12164] = {.lex_state = 54, .external_lex_state = 63},
  [12165] = {.lex_state = 63},
  [12166] = {.lex_state = 53, .external_lex_state = 53},
  [12167] = {.lex_state = 63},
  [12168] = {.lex_state = 63},
  [12169] = {.lex_state = 63},
  [12170] = {.lex_state = 54, .external_lex_state = 35},
  [12171] = {.lex_state = 54, .external_lex_state = 60},
  [12172] = {.lex_state = 53},
  [12173] = {.lex_state = 53},
  [12174] = {.lex_state = 60, .external_lex_state = 27},
  [12175] = {.lex_state = 54, .external_lex_state = 37},
  [12176] = {.lex_state = 54, .external_lex_state = 37},
  [12177] = {.lex_state = 54, .external_lex_state = 37},
  [12178] = {.lex_state = 63},
  [12179] = {.lex_state = 54, .external_lex_state = 37},
  [12180] = {.lex_state = 54, .external_lex_state = 37},
  [12181] = {.lex_state = 63},
  [12182] = {.lex_state = 53, .external_lex_state = 23},
  [12183] = {.lex_state = 60},
  [12184] = {.lex_state = 60},
  [12185] = {.lex_state = 63},
  [12186] = {.lex_state = 63},
  [12187] = {.lex_state = 63},
  [12188] = {.lex_state = 60, .external_lex_state = 49},
  [12189] = {.lex_state = 63},
  [12190] = {.lex_state = 63},
  [12191] = {.lex_state = 63},
  [12192] = {.lex_state = 63},
  [12193] = {.lex_state = 54, .external_lex_state = 48},
  [12194] = {.lex_state = 60, .external_lex_state = 49},
  [12195] = {.lex_state = 63},
  [12196] = {.lex_state = 63},
  [12197] = {.lex_state = 63},
  [12198] = {.lex_state = 54, .external_lex_state = 49},
  [12199] = {.lex_state = 60},
  [12200] = {.lex_state = 60},
  [12201] = {.lex_state = 63},
  [12202] = {.lex_state = 63},
  [12203] = {.lex_state = 63},
  [12204] = {.lex_state = 60, .external_lex_state = 23},
  [12205] = {.lex_state = 54, .external_lex_state = 23},
  [12206] = {.lex_state = 63},
  [12207] = {.lex_state = 63},
  [12208] = {.lex_state = 63},
  [12209] = {.lex_state = 63},
  [12210] = {.lex_state = 54, .external_lex_state = 60},
  [12211] = {.lex_state = 63},
  [12212] = {.lex_state = 54, .external_lex_state = 60},
  [12213] = {.lex_state = 63},
  [12214] = {.lex_state = 63},
  [12215] = {.lex_state = 54, .external_lex_state = 42},
  [12216] = {.lex_state = 63},
  [12217] = {.lex_state = 63},
  [12218] = {.lex_state = 54, .external_lex_state = 67},
  [12219] = {.lex_state = 63},
  [12220] = {.lex_state = 63},
  [12221] = {.lex_state = 63},
  [12222] = {.lex_state = 63},
  [12223] = {.lex_state = 60},
  [12224] = {.lex_state = 60},
  [12225] = {.lex_state = 63},
  [12226] = {.lex_state = 60},
  [12227] = {.lex_state = 54, .external_lex_state = 45},
  [12228] = {.lex_state = 63},
  [12229] = {.lex_state = 63},
  [12230] = {.lex_state = 54, .external_lex_state = 42},
  [12231] = {.lex_state = 63},
  [12232] = {.lex_state = 54, .external_lex_state = 42},
  [12233] = {.lex_state = 54, .external_lex_state = 42},
  [12234] = {.lex_state = 63},
  [12235] = {.lex_state = 54, .external_lex_state = 42},
  [12236] = {.lex_state = 63},
  [12237] = {.lex_state = 54, .external_lex_state = 42},
  [12238] = {.lex_state = 63},
  [12239] = {.lex_state = 54, .external_lex_state = 42},
  [12240] = {.lex_state = 63},
  [12241] = {.lex_state = 54, .external_lex_state = 42},
  [12242] = {.lex_state = 63},
  [12243] = {.lex_state = 63},
  [12244] = {.lex_state = 63},
  [12245] = {.lex_state = 63},
  [12246] = {.lex_state = 63},
  [12247] = {.lex_state = 60},
  [12248] = {.lex_state = 60},
  [12249] = {.lex_state = 63},
  [12250] = {.lex_state = 63},
  [12251] = {.lex_state = 54, .external_lex_state = 67},
  [12252] = {.lex_state = 60},
  [12253] = {.lex_state = 63},
  [12254] = {.lex_state = 63},
  [12255] = {.lex_state = 63},
  [12256] = {.lex_state = 60},
  [12257] = {.lex_state = 63},
  [12258] = {.lex_state = 63},
  [12259] = {.lex_state = 54, .external_lex_state = 37},
  [12260] = {.lex_state = 54, .external_lex_state = 62},
  [12261] = {.lex_state = 63},
  [12262] = {.lex_state = 63},
  [12263] = {.lex_state = 60},
  [12264] = {.lex_state = 63},
  [12265] = {.lex_state = 60},
  [12266] = {.lex_state = 63},
  [12267] = {.lex_state = 54, .external_lex_state = 60},
  [12268] = {.lex_state = 63},
  [12269] = {.lex_state = 60, .external_lex_state = 51},
  [12270] = {.lex_state = 63},
  [12271] = {.lex_state = 60, .external_lex_state = 51},
  [12272] = {.lex_state = 63},
  [12273] = {.lex_state = 63},
  [12274] = {.lex_state = 54, .external_lex_state = 60},
  [12275] = {.lex_state = 63},
  [12276] = {.lex_state = 63},
  [12277] = {.lex_state = 63},
  [12278] = {.lex_state = 60},
  [12279] = {.lex_state = 60},
  [12280] = {.lex_state = 63},
  [12281] = {.lex_state = 63},
  [12282] = {.lex_state = 63},
  [12283] = {.lex_state = 63},
  [12284] = {.lex_state = 63},
  [12285] = {.lex_state = 54, .external_lex_state = 37},
  [12286] = {.lex_state = 63},
  [12287] = {.lex_state = 63},
  [12288] = {.lex_state = 63},
  [12289] = {.lex_state = 63},
  [12290] = {.lex_state = 54, .external_lex_state = 39},
  [12291] = {.lex_state = 60},
  [12292] = {.lex_state = 63},
  [12293] = {.lex_state = 63},
  [12294] = {.lex_state = 54, .external_lex_state = 60},
  [12295] = {.lex_state = 54, .external_lex_state = 60},
  [12296] = {.lex_state = 54, .external_lex_state = 60},
  [12297] = {.lex_state = 54, .external_lex_state = 60},
  [12298] = {.lex_state = 63},
  [12299] = {.lex_state = 60},
  [12300] = {.lex_state = 54, .external_lex_state = 62},
  [12301] = {.lex_state = 60, .external_lex_state = 68},
  [12302] = {.lex_state = 63},
  [12303] = {.lex_state = 54, .external_lex_state = 62},
  [12304] = {.lex_state = 54, .external_lex_state = 39},
  [12305] = {.lex_state = 54, .external_lex_state = 39},
  [12306] = {.lex_state = 54, .external_lex_state = 39},
  [12307] = {.lex_state = 54, .external_lex_state = 39},
  [12308] = {.lex_state = 54, .external_lex_state = 39},
  [12309] = {.lex_state = 54, .external_lex_state = 39},
  [12310] = {.lex_state = 54, .external_lex_state = 39},
  [12311] = {.lex_state = 63},
  [12312] = {.lex_state = 63},
  [12313] = {.lex_state = 60},
  [12314] = {.lex_state = 60, .external_lex_state = 27},
  [12315] = {.lex_state = 63},
  [12316] = {.lex_state = 54},
  [12317] = {.lex_state = 63},
  [12318] = {.lex_state = 63},
  [12319] = {.lex_state = 63},
  [12320] = {.lex_state = 54, .external_lex_state = 51},
  [12321] = {.lex_state = 63},
  [12322] = {.lex_state = 60},
  [12323] = {.lex_state = 63},
  [12324] = {.lex_state = 54, .external_lex_state = 66},
  [12325] = {.lex_state = 63},
  [12326] = {.lex_state = 54, .external_lex_state = 66},
  [12327] = {.lex_state = 60},
  [12328] = {.lex_state = 63},
  [12329] = {.lex_state = 54, .external_lex_state = 66},
  [12330] = {.lex_state = 52},
  [12331] = {.lex_state = 60},
  [12332] = {.lex_state = 63},
  [12333] = {.lex_state = 60, .external_lex_state = 36},
  [12334] = {.lex_state = 63},
  [12335] = {.lex_state = 54, .external_lex_state = 49},
  [12336] = {.lex_state = 63},
  [12337] = {.lex_state = 54, .external_lex_state = 45},
  [12338] = {.lex_state = 63},
  [12339] = {.lex_state = 54, .external_lex_state = 51},
  [12340] = {.lex_state = 63},
  [12341] = {.lex_state = 54, .external_lex_state = 45},
  [12342] = {.lex_state = 63},
  [12343] = {.lex_state = 54},
  [12344] = {.lex_state = 60, .external_lex_state = 27},
  [12345] = {.lex_state = 54, .external_lex_state = 62},
  [12346] = {.lex_state = 63},
  [12347] = {.lex_state = 63},
  [12348] = {.lex_state = 63},
  [12349] = {.lex_state = 60},
  [12350] = {.lex_state = 63},
  [12351] = {.lex_state = 60, .external_lex_state = 45},
  [12352] = {.lex_state = 60},
  [12353] = {.lex_state = 63},
  [12354] = {.lex_state = 63},
  [12355] = {.lex_state = 63},
  [12356] = {.lex_state = 63, .external_lex_state = 64},
  [12357] = {.lex_state = 63},
  [12358] = {.lex_state = 60},
  [12359] = {.lex_state = 54, .external_lex_state = 60},
  [12360] = {.lex_state = 60, .external_lex_state = 45},
  [12361] = {.lex_state = 54, .external_lex_state = 60},
  [12362] = {.lex_state = 54, .external_lex_state = 60},
  [12363] = {.lex_state = 60, .external_lex_state = 69},
  [12364] = {.lex_state = 54, .external_lex_state = 42},
  [12365] = {.lex_state = 54, .external_lex_state = 42},
  [12366] = {.lex_state = 54, .external_lex_state = 42},
  [12367] = {.lex_state = 63},
  [12368] = {.lex_state = 63},
  [12369] = {.lex_state = 53, .external_lex_state = 40},
  [12370] = {.lex_state = 60},
  [12371] = {.lex_state = 54, .external_lex_state = 42},
  [12372] = {.lex_state = 54, .external_lex_state = 62},
  [12373] = {.lex_state = 63},
  [12374] = {.lex_state = 54, .external_lex_state = 37},
  [12375] = {.lex_state = 63},
  [12376] = {.lex_state = 63},
  [12377] = {.lex_state = 54, .external_lex_state = 39},
  [12378] = {.lex_state = 54, .external_lex_state = 39},
  [12379] = {.lex_state = 63},
  [12380] = {.lex_state = 54, .external_lex_state = 39},
  [12381] = {.lex_state = 63},
  [12382] = {.lex_state = 54, .external_lex_state = 39},
  [12383] = {.lex_state = 54, .external_lex_state = 37},
  [12384] = {.lex_state = 60, .external_lex_state = 36},
  [12385] = {.lex_state = 54, .external_lex_state = 48},
  [12386] = {.lex_state = 63},
  [12387] = {.lex_state = 54, .external_lex_state = 48},
  [12388] = {.lex_state = 54, .external_lex_state = 37},
  [12389] = {.lex_state = 63},
  [12390] = {.lex_state = 54, .external_lex_state = 49},
  [12391] = {.lex_state = 60},
  [12392] = {.lex_state = 54, .external_lex_state = 49},
  [12393] = {.lex_state = 60},
  [12394] = {.lex_state = 54, .external_lex_state = 37},
  [12395] = {.lex_state = 60, .external_lex_state = 37},
  [12396] = {.lex_state = 54, .external_lex_state = 24},
  [12397] = {.lex_state = 63},
  [12398] = {.lex_state = 63},
  [12399] = {.lex_state = 54, .external_lex_state = 37},
  [12400] = {.lex_state = 54, .external_lex_state = 37},
  [12401] = {.lex_state = 60, .external_lex_state = 27},
  [12402] = {.lex_state = 63},
  [12403] = {.lex_state = 54, .external_lex_state = 62},
  [12404] = {.lex_state = 63},
  [12405] = {.lex_state = 63},
  [12406] = {.lex_state = 63},
  [12407] = {.lex_state = 54, .external_lex_state = 61},
  [12408] = {.lex_state = 60, .external_lex_state = 27},
  [12409] = {.lex_state = 63},
  [12410] = {.lex_state = 60, .external_lex_state = 36},
  [12411] = {.lex_state = 60},
  [12412] = {.lex_state = 54, .external_lex_state = 51},
  [12413] = {.lex_state = 54, .external_lex_state = 51},
  [12414] = {.lex_state = 63},
  [12415] = {.lex_state = 63},
  [12416] = {.lex_state = 63},
  [12417] = {.lex_state = 63},
  [12418] = {.lex_state = 60, .external_lex_state = 36},
  [12419] = {.lex_state = 60, .external_lex_state = 36},
  [12420] = {.lex_state = 63},
  [12421] = {.lex_state = 60},
  [12422] = {.lex_state = 60},
  [12423] = {.lex_state = 60, .external_lex_state = 42},
  [12424] = {.lex_state = 63},
  [12425] = {.lex_state = 60},
  [12426] = {.lex_state = 63},
  [12427] = {.lex_state = 60, .external_lex_state = 36},
  [12428] = {.lex_state = 63},
  [12429] = {.lex_state = 63},
  [12430] = {.lex_state = 60},
  [12431] = {.lex_state = 54, .external_lex_state = 60},
  [12432] = {.lex_state = 60},
  [12433] = {.lex_state = 63},
  [12434] = {.lex_state = 54, .external_lex_state = 62},
  [12435] = {.lex_state = 53, .external_lex_state = 40},
  [12436] = {.lex_state = 63},
  [12437] = {.lex_state = 63},
  [12438] = {.lex_state = 63},
  [12439] = {.lex_state = 63},
  [12440] = {.lex_state = 54, .external_lex_state = 61},
  [12441] = {.lex_state = 63},
  [12442] = {.lex_state = 60, .external_lex_state = 36},
  [12443] = {.lex_state = 60, .external_lex_state = 36},
  [12444] = {.lex_state = 54, .external_lex_state = 61},
  [12445] = {.lex_state = 63},
  [12446] = {.lex_state = 60, .external_lex_state = 36},
  [12447] = {.lex_state = 60, .external_lex_state = 36},
  [12448] = {.lex_state = 63},
  [12449] = {.lex_state = 60, .external_lex_state = 36},
  [12450] = {.lex_state = 63},
  [12451] = {.lex_state = 60},
  [12452] = {.lex_state = 63},
  [12453] = {.lex_state = 60, .external_lex_state = 36},
  [12454] = {.lex_state = 60, .external_lex_state = 36},
  [12455] = {.lex_state = 63},
  [12456] = {.lex_state = 60, .external_lex_state = 36},
  [12457] = {.lex_state = 63},
  [12458] = {.lex_state = 60},
  [12459] = {.lex_state = 60, .external_lex_state = 36},
  [12460] = {.lex_state = 63},
  [12461] = {.lex_state = 60, .external_lex_state = 36},
  [12462] = {.lex_state = 63},
  [12463] = {.lex_state = 63},
  [12464] = {.lex_state = 54, .external_lex_state = 42},
  [12465] = {.lex_state = 60, .external_lex_state = 36},
  [12466] = {.lex_state = 63},
  [12467] = {.lex_state = 63},
  [12468] = {.lex_state = 63},
  [12469] = {.lex_state = 63},
  [12470] = {.lex_state = 63},
  [12471] = {.lex_state = 60, .external_lex_state = 36},
  [12472] = {.lex_state = 60, .external_lex_state = 36},
  [12473] = {.lex_state = 63},
  [12474] = {.lex_state = 60, .external_lex_state = 36},
  [12475] = {.lex_state = 60, .external_lex_state = 37},
  [12476] = {.lex_state = 60, .external_lex_state = 36},
  [12477] = {.lex_state = 60, .external_lex_state = 36},
  [12478] = {.lex_state = 63},
  [12479] = {.lex_state = 54, .external_lex_state = 45},
  [12480] = {.lex_state = 63},
  [12481] = {.lex_state = 63},
  [12482] = {.lex_state = 54, .external_lex_state = 61},
  [12483] = {.lex_state = 63},
  [12484] = {.lex_state = 63},
  [12485] = {.lex_state = 63},
  [12486] = {.lex_state = 60, .external_lex_state = 35},
  [12487] = {.lex_state = 63, .external_lex_state = 64},
  [12488] = {.lex_state = 63},
  [12489] = {.lex_state = 63},
  [12490] = {.lex_state = 60, .external_lex_state = 35},
  [12491] = {.lex_state = 60, .external_lex_state = 35},
  [12492] = {.lex_state = 60, .external_lex_state = 35},
  [12493] = {.lex_state = 60, .external_lex_state = 35},
  [12494] = {.lex_state = 60, .external_lex_state = 35},
  [12495] = {.lex_state = 63},
  [12496] = {.lex_state = 63},
  [12497] = {.lex_state = 63},
  [12498] = {.lex_state = 60, .external_lex_state = 36},
  [12499] = {.lex_state = 60, .external_lex_state = 35},
  [12500] = {.lex_state = 63},
  [12501] = {.lex_state = 60, .external_lex_state = 36},
  [12502] = {.lex_state = 60, .external_lex_state = 36},
  [12503] = {.lex_state = 60, .external_lex_state = 36},
  [12504] = {.lex_state = 60, .external_lex_state = 36},
  [12505] = {.lex_state = 60, .external_lex_state = 36},
  [12506] = {.lex_state = 63},
  [12507] = {.lex_state = 60, .external_lex_state = 37},
  [12508] = {.lex_state = 60, .external_lex_state = 37},
  [12509] = {.lex_state = 54, .external_lex_state = 37},
  [12510] = {.lex_state = 63},
  [12511] = {.lex_state = 60},
  [12512] = {.lex_state = 60},
  [12513] = {.lex_state = 63},
  [12514] = {.lex_state = 63},
  [12515] = {.lex_state = 60, .external_lex_state = 35},
  [12516] = {.lex_state = 63},
  [12517] = {.lex_state = 54, .external_lex_state = 23},
  [12518] = {.lex_state = 63},
  [12519] = {.lex_state = 63},
  [12520] = {.lex_state = 63},
  [12521] = {.lex_state = 63},
  [12522] = {.lex_state = 63},
  [12523] = {.lex_state = 60, .external_lex_state = 37},
  [12524] = {.lex_state = 63},
  [12525] = {.lex_state = 60, .external_lex_state = 37},
  [12526] = {.lex_state = 63},
  [12527] = {.lex_state = 63},
  [12528] = {.lex_state = 54, .external_lex_state = 66},
  [12529] = {.lex_state = 63},
  [12530] = {.lex_state = 60},
  [12531] = {.lex_state = 60},
  [12532] = {.lex_state = 60, .external_lex_state = 37},
  [12533] = {.lex_state = 63},
  [12534] = {.lex_state = 54, .external_lex_state = 60},
  [12535] = {.lex_state = 63},
  [12536] = {.lex_state = 54, .external_lex_state = 37},
  [12537] = {.lex_state = 63},
  [12538] = {.lex_state = 63},
  [12539] = {.lex_state = 63},
  [12540] = {.lex_state = 63},
  [12541] = {.lex_state = 53, .external_lex_state = 23},
  [12542] = {.lex_state = 63},
  [12543] = {.lex_state = 63},
  [12544] = {.lex_state = 63},
  [12545] = {.lex_state = 63},
  [12546] = {.lex_state = 63},
  [12547] = {.lex_state = 63},
  [12548] = {.lex_state = 63},
  [12549] = {.lex_state = 63},
  [12550] = {.lex_state = 63},
  [12551] = {.lex_state = 60, .external_lex_state = 36},
  [12552] = {.lex_state = 60, .external_lex_state = 36},
  [12553] = {.lex_state = 54, .external_lex_state = 60},
  [12554] = {.lex_state = 63},
  [12555] = {.lex_state = 53, .external_lex_state = 24},
  [12556] = {.lex_state = 60, .external_lex_state = 37},
  [12557] = {.lex_state = 54, .external_lex_state = 48},
  [12558] = {.lex_state = 54, .external_lex_state = 60},
  [12559] = {.lex_state = 53, .external_lex_state = 23},
  [12560] = {.lex_state = 53, .external_lex_state = 23},
  [12561] = {.lex_state = 54, .external_lex_state = 24},
  [12562] = {.lex_state = 63},
  [12563] = {.lex_state = 63},
  [12564] = {.lex_state = 60},
  [12565] = {.lex_state = 60},
  [12566] = {.lex_state = 60},
  [12567] = {.lex_state = 60},
  [12568] = {.lex_state = 63},
  [12569] = {.lex_state = 63},
  [12570] = {.lex_state = 63},
  [12571] = {.lex_state = 60},
  [12572] = {.lex_state = 63},
  [12573] = {.lex_state = 63},
  [12574] = {.lex_state = 60},
  [12575] = {.lex_state = 63},
  [12576] = {.lex_state = 63},
  [12577] = {.lex_state = 60, .external_lex_state = 35},
  [12578] = {.lex_state = 63},
  [12579] = {.lex_state = 54, .external_lex_state = 37},
  [12580] = {.lex_state = 60, .external_lex_state = 35},
  [12581] = {.lex_state = 60, .external_lex_state = 35},
  [12582] = {.lex_state = 63},
  [12583] = {.lex_state = 60, .external_lex_state = 35},
  [12584] = {.lex_state = 60, .external_lex_state = 48},
  [12585] = {.lex_state = 54, .external_lex_state = 63},
  [12586] = {.lex_state = 63},
  [12587] = {.lex_state = 53, .external_lex_state = 40},
  [12588] = {.lex_state = 60, .external_lex_state = 48},
  [12589] = {.lex_state = 63},
  [12590] = {.lex_state = 60},
  [12591] = {.lex_state = 54, .external_lex_state = 60},
  [12592] = {.lex_state = 60},
  [12593] = {.lex_state = 63},
  [12594] = {.lex_state = 60, .external_lex_state = 35},
  [12595] = {.lex_state = 60, .external_lex_state = 35},
  [12596] = {.lex_state = 53, .external_lex_state = 40},
  [12597] = {.lex_state = 63},
  [12598] = {.lex_state = 63, .external_lex_state = 64},
  [12599] = {.lex_state = 60, .external_lex_state = 35},
  [12600] = {.lex_state = 60, .external_lex_state = 35},
  [12601] = {.lex_state = 63, .external_lex_state = 64},
  [12602] = {.lex_state = 63, .external_lex_state = 64},
  [12603] = {.lex_state = 60, .external_lex_state = 35},
  [12604] = {.lex_state = 63},
  [12605] = {.lex_state = 60},
  [12606] = {.lex_state = 60, .external_lex_state = 35},
  [12607] = {.lex_state = 60},
  [12608] = {.lex_state = 63},
  [12609] = {.lex_state = 60, .external_lex_state = 35},
  [12610] = {.lex_state = 60, .external_lex_state = 35},
  [12611] = {.lex_state = 53, .external_lex_state = 40},
  [12612] = {.lex_state = 60, .external_lex_state = 35},
  [12613] = {.lex_state = 60, .external_lex_state = 35},
  [12614] = {.lex_state = 63},
  [12615] = {.lex_state = 63},
  [12616] = {.lex_state = 63},
  [12617] = {.lex_state = 60, .external_lex_state = 35},
  [12618] = {.lex_state = 63},
  [12619] = {.lex_state = 60, .external_lex_state = 39},
  [12620] = {.lex_state = 54, .external_lex_state = 37},
  [12621] = {.lex_state = 60, .external_lex_state = 27},
  [12622] = {.lex_state = 63},
  [12623] = {.lex_state = 60, .external_lex_state = 35},
  [12624] = {.lex_state = 60, .external_lex_state = 35},
  [12625] = {.lex_state = 63},
  [12626] = {.lex_state = 60, .external_lex_state = 35},
  [12627] = {.lex_state = 60},
  [12628] = {.lex_state = 60},
  [12629] = {.lex_state = 63},
  [12630] = {.lex_state = 54, .external_lex_state = 39},
  [12631] = {.lex_state = 60, .external_lex_state = 35},
  [12632] = {.lex_state = 63},
  [12633] = {.lex_state = 63},
  [12634] = {.lex_state = 63},
  [12635] = {.lex_state = 63},
  [12636] = {.lex_state = 60},
  [12637] = {.lex_state = 60},
  [12638] = {.lex_state = 63},
  [12639] = {.lex_state = 63},
  [12640] = {.lex_state = 60, .external_lex_state = 42},
  [12641] = {.lex_state = 54, .external_lex_state = 51},
  [12642] = {.lex_state = 54, .external_lex_state = 61},
  [12643] = {.lex_state = 54, .external_lex_state = 51},
  [12644] = {.lex_state = 53, .external_lex_state = 24},
  [12645] = {.lex_state = 54, .external_lex_state = 51},
  [12646] = {.lex_state = 54, .external_lex_state = 62},
  [12647] = {.lex_state = 63},
  [12648] = {.lex_state = 54, .external_lex_state = 51},
  [12649] = {.lex_state = 54, .external_lex_state = 51},
  [12650] = {.lex_state = 60, .external_lex_state = 23},
  [12651] = {.lex_state = 63},
  [12652] = {.lex_state = 60, .external_lex_state = 42},
  [12653] = {.lex_state = 60, .external_lex_state = 31},
  [12654] = {.lex_state = 63},
  [12655] = {.lex_state = 53, .external_lex_state = 24},
  [12656] = {.lex_state = 63},
  [12657] = {.lex_state = 54, .external_lex_state = 63},
  [12658] = {.lex_state = 53, .external_lex_state = 24},
  [12659] = {.lex_state = 54, .external_lex_state = 62},
  [12660] = {.lex_state = 60, .external_lex_state = 39},
  [12661] = {.lex_state = 63},
  [12662] = {.lex_state = 53, .external_lex_state = 24},
  [12663] = {.lex_state = 60, .external_lex_state = 45},
  [12664] = {.lex_state = 63},
  [12665] = {.lex_state = 63},
  [12666] = {.lex_state = 60, .external_lex_state = 27},
  [12667] = {.lex_state = 63},
  [12668] = {.lex_state = 60, .external_lex_state = 51},
  [12669] = {.lex_state = 60, .external_lex_state = 27},
  [12670] = {.lex_state = 54, .external_lex_state = 48},
  [12671] = {.lex_state = 54, .external_lex_state = 63},
  [12672] = {.lex_state = 54, .external_lex_state = 45},
  [12673] = {.lex_state = 53, .external_lex_state = 23},
  [12674] = {.lex_state = 54, .external_lex_state = 62},
  [12675] = {.lex_state = 63},
  [12676] = {.lex_state = 53, .external_lex_state = 24},
  [12677] = {.lex_state = 60, .external_lex_state = 49},
  [12678] = {.lex_state = 60, .external_lex_state = 37},
  [12679] = {.lex_state = 63},
  [12680] = {.lex_state = 54, .external_lex_state = 49},
  [12681] = {.lex_state = 53, .external_lex_state = 23},
  [12682] = {.lex_state = 54, .external_lex_state = 63},
  [12683] = {.lex_state = 63},
  [12684] = {.lex_state = 54, .external_lex_state = 49},
  [12685] = {.lex_state = 60, .external_lex_state = 31},
  [12686] = {.lex_state = 53, .external_lex_state = 24},
  [12687] = {.lex_state = 54, .external_lex_state = 62},
  [12688] = {.lex_state = 63},
  [12689] = {.lex_state = 60, .external_lex_state = 57},
  [12690] = {.lex_state = 53, .external_lex_state = 24},
  [12691] = {.lex_state = 54, .external_lex_state = 58},
  [12692] = {.lex_state = 63},
  [12693] = {.lex_state = 54, .external_lex_state = 49},
  [12694] = {.lex_state = 53, .external_lex_state = 24},
  [12695] = {.lex_state = 53, .external_lex_state = 24},
  [12696] = {.lex_state = 53, .external_lex_state = 24},
  [12697] = {.lex_state = 54, .external_lex_state = 62},
  [12698] = {.lex_state = 63},
  [12699] = {.lex_state = 63},
  [12700] = {.lex_state = 63},
  [12701] = {.lex_state = 60, .external_lex_state = 31},
  [12702] = {.lex_state = 54, .external_lex_state = 48},
  [12703] = {.lex_state = 54, .external_lex_state = 56},
  [12704] = {.lex_state = 60, .external_lex_state = 23},
  [12705] = {.lex_state = 54, .external_lex_state = 65},
  [12706] = {.lex_state = 63},
  [12707] = {.lex_state = 54, .external_lex_state = 62},
  [12708] = {.lex_state = 60, .external_lex_state = 42},
  [12709] = {.lex_state = 54, .external_lex_state = 62},
  [12710] = {.lex_state = 60, .external_lex_state = 23},
  [12711] = {.lex_state = 54, .external_lex_state = 48},
  [12712] = {.lex_state = 63},
  [12713] = {.lex_state = 53, .external_lex_state = 53},
  [12714] = {.lex_state = 63},
  [12715] = {.lex_state = 63},
  [12716] = {.lex_state = 63},
  [12717] = {.lex_state = 53, .external_lex_state = 24},
  [12718] = {.lex_state = 54, .external_lex_state = 45},
  [12719] = {.lex_state = 54, .external_lex_state = 51},
  [12720] = {.lex_state = 54, .external_lex_state = 51},
  [12721] = {.lex_state = 54, .external_lex_state = 51},
  [12722] = {.lex_state = 54, .external_lex_state = 60},
  [12723] = {.lex_state = 54, .external_lex_state = 51},
  [12724] = {.lex_state = 63},
  [12725] = {.lex_state = 54, .external_lex_state = 63},
  [12726] = {.lex_state = 54, .external_lex_state = 45},
  [12727] = {.lex_state = 60, .external_lex_state = 23},
  [12728] = {.lex_state = 54, .external_lex_state = 49},
  [12729] = {.lex_state = 60, .external_lex_state = 37},
  [12730] = {.lex_state = 63},
  [12731] = {.lex_state = 54, .external_lex_state = 45},
  [12732] = {.lex_state = 54, .external_lex_state = 45},
  [12733] = {.lex_state = 53, .external_lex_state = 53},
  [12734] = {.lex_state = 63},
  [12735] = {.lex_state = 54, .external_lex_state = 63},
  [12736] = {.lex_state = 54, .external_lex_state = 45},
  [12737] = {.lex_state = 63},
  [12738] = {.lex_state = 63},
  [12739] = {.lex_state = 54, .external_lex_state = 45},
  [12740] = {.lex_state = 54, .external_lex_state = 56},
  [12741] = {.lex_state = 54, .external_lex_state = 56},
  [12742] = {.lex_state = 54, .external_lex_state = 57},
  [12743] = {.lex_state = 63},
  [12744] = {.lex_state = 54, .external_lex_state = 57},
  [12745] = {.lex_state = 60, .external_lex_state = 23},
  [12746] = {.lex_state = 54, .external_lex_state = 45},
  [12747] = {.lex_state = 53, .external_lex_state = 53},
  [12748] = {.lex_state = 54, .external_lex_state = 66},
  [12749] = {.lex_state = 53, .external_lex_state = 53},
  [12750] = {.lex_state = 63},
  [12751] = {.lex_state = 54, .external_lex_state = 58},
  [12752] = {.lex_state = 54, .external_lex_state = 58},
  [12753] = {.lex_state = 60, .external_lex_state = 23},
  [12754] = {.lex_state = 54, .external_lex_state = 48},
  [12755] = {.lex_state = 63},
  [12756] = {.lex_state = 60, .external_lex_state = 31},
  [12757] = {.lex_state = 54, .external_lex_state = 62},
  [12758] = {.lex_state = 60, .external_lex_state = 58},
  [12759] = {.lex_state = 54, .external_lex_state = 65},
  [12760] = {.lex_state = 63},
  [12761] = {.lex_state = 53, .external_lex_state = 53},
  [12762] = {.lex_state = 63},
  [12763] = {.lex_state = 63},
  [12764] = {.lex_state = 60},
  [12765] = {.lex_state = 54, .external_lex_state = 60},
  [12766] = {.lex_state = 60, .external_lex_state = 58},
  [12767] = {.lex_state = 63},
  [12768] = {.lex_state = 60, .external_lex_state = 42},
  [12769] = {.lex_state = 60, .external_lex_state = 23},
  [12770] = {.lex_state = 53, .external_lex_state = 23},
  [12771] = {.lex_state = 63},
  [12772] = {.lex_state = 60, .external_lex_state = 42},
  [12773] = {.lex_state = 53, .external_lex_state = 23},
  [12774] = {.lex_state = 60, .external_lex_state = 23},
  [12775] = {.lex_state = 63},
  [12776] = {.lex_state = 60, .external_lex_state = 23},
  [12777] = {.lex_state = 60, .external_lex_state = 23},
  [12778] = {.lex_state = 54, .external_lex_state = 57},
  [12779] = {.lex_state = 63},
  [12780] = {.lex_state = 63},
  [12781] = {.lex_state = 60},
  [12782] = {.lex_state = 63},
  [12783] = {.lex_state = 63},
  [12784] = {.lex_state = 63},
  [12785] = {.lex_state = 60, .external_lex_state = 39},
  [12786] = {.lex_state = 60, .external_lex_state = 23},
  [12787] = {.lex_state = 63},
  [12788] = {.lex_state = 63},
  [12789] = {.lex_state = 54, .external_lex_state = 61},
  [12790] = {.lex_state = 60, .external_lex_state = 39},
  [12791] = {.lex_state = 60, .external_lex_state = 39},
  [12792] = {.lex_state = 63},
  [12793] = {.lex_state = 54, .external_lex_state = 49},
  [12794] = {.lex_state = 54, .external_lex_state = 51},
  [12795] = {.lex_state = 54, .external_lex_state = 49},
  [12796] = {.lex_state = 60, .external_lex_state = 37},
  [12797] = {.lex_state = 60, .external_lex_state = 37},
  [12798] = {.lex_state = 63},
  [12799] = {.lex_state = 60, .external_lex_state = 23},
  [12800] = {.lex_state = 54, .external_lex_state = 61},
  [12801] = {.lex_state = 60, .external_lex_state = 23},
  [12802] = {.lex_state = 63},
  [12803] = {.lex_state = 53, .external_lex_state = 24},
  [12804] = {.lex_state = 63},
  [12805] = {.lex_state = 54, .external_lex_state = 49},
  [12806] = {.lex_state = 53, .external_lex_state = 24},
  [12807] = {.lex_state = 63},
  [12808] = {.lex_state = 53, .external_lex_state = 24},
  [12809] = {.lex_state = 54, .external_lex_state = 42},
  [12810] = {.lex_state = 63},
  [12811] = {.lex_state = 54, .external_lex_state = 39},
  [12812] = {.lex_state = 54, .external_lex_state = 61},
  [12813] = {.lex_state = 63},
  [12814] = {.lex_state = 54, .external_lex_state = 49},
  [12815] = {.lex_state = 54, .external_lex_state = 65},
  [12816] = {.lex_state = 54, .external_lex_state = 62},
  [12817] = {.lex_state = 63},
  [12818] = {.lex_state = 60, .external_lex_state = 39},
  [12819] = {.lex_state = 60, .external_lex_state = 23},
  [12820] = {.lex_state = 63},
  [12821] = {.lex_state = 60, .external_lex_state = 23},
  [12822] = {.lex_state = 60},
  [12823] = {.lex_state = 63},
  [12824] = {.lex_state = 63},
  [12825] = {.lex_state = 54, .external_lex_state = 49},
  [12826] = {.lex_state = 63},
  [12827] = {.lex_state = 63},
  [12828] = {.lex_state = 60, .external_lex_state = 57},
  [12829] = {.lex_state = 60, .external_lex_state = 27},
  [12830] = {.lex_state = 63},
  [12831] = {.lex_state = 54, .external_lex_state = 23},
  [12832] = {.lex_state = 63},
  [12833] = {.lex_state = 54, .external_lex_state = 49},
  [12834] = {.lex_state = 63},
  [12835] = {.lex_state = 54, .external_lex_state = 61},
  [12836] = {.lex_state = 60, .external_lex_state = 39},
  [12837] = {.lex_state = 60, .external_lex_state = 23},
  [12838] = {.lex_state = 54, .external_lex_state = 23},
  [12839] = {.lex_state = 63},
  [12840] = {.lex_state = 54, .external_lex_state = 62},
  [12841] = {.lex_state = 60, .external_lex_state = 37},
  [12842] = {.lex_state = 54, .external_lex_state = 39},
  [12843] = {.lex_state = 60, .external_lex_state = 42},
  [12844] = {.lex_state = 63},
  [12845] = {.lex_state = 54, .external_lex_state = 49},
  [12846] = {.lex_state = 54, .external_lex_state = 42},
  [12847] = {.lex_state = 63},
  [12848] = {.lex_state = 60, .external_lex_state = 27},
  [12849] = {.lex_state = 54, .external_lex_state = 66},
  [12850] = {.lex_state = 60, .external_lex_state = 23},
  [12851] = {.lex_state = 63},
  [12852] = {.lex_state = 60, .external_lex_state = 42},
  [12853] = {.lex_state = 60, .external_lex_state = 42},
  [12854] = {.lex_state = 63},
  [12855] = {.lex_state = 54, .external_lex_state = 49},
  [12856] = {.lex_state = 54, .external_lex_state = 48},
  [12857] = {.lex_state = 54, .external_lex_state = 48},
  [12858] = {.lex_state = 63},
  [12859] = {.lex_state = 63},
  [12860] = {.lex_state = 54, .external_lex_state = 48},
  [12861] = {.lex_state = 54, .external_lex_state = 58},
  [12862] = {.lex_state = 54, .external_lex_state = 42},
  [12863] = {.lex_state = 63},
  [12864] = {.lex_state = 54, .external_lex_state = 48},
  [12865] = {.lex_state = 63},
  [12866] = {.lex_state = 54, .external_lex_state = 62},
  [12867] = {.lex_state = 54, .external_lex_state = 62},
  [12868] = {.lex_state = 60, .external_lex_state = 23},
  [12869] = {.lex_state = 63},
  [12870] = {.lex_state = 54, .external_lex_state = 42},
  [12871] = {.lex_state = 63},
  [12872] = {.lex_state = 54, .external_lex_state = 42},
  [12873] = {.lex_state = 54, .external_lex_state = 39},
  [12874] = {.lex_state = 53, .external_lex_state = 23},
  [12875] = {.lex_state = 63},
  [12876] = {.lex_state = 63},
  [12877] = {.lex_state = 63},
  [12878] = {.lex_state = 53, .external_lex_state = 23},
  [12879] = {.lex_state = 54, .external_lex_state = 61},
  [12880] = {.lex_state = 63},
  [12881] = {.lex_state = 54, .external_lex_state = 42},
  [12882] = {.lex_state = 60, .external_lex_state = 39},
  [12883] = {.lex_state = 63},
  [12884] = {.lex_state = 54, .external_lex_state = 39},
  [12885] = {.lex_state = 60, .external_lex_state = 23},
  [12886] = {.lex_state = 60, .external_lex_state = 37},
  [12887] = {.lex_state = 54, .external_lex_state = 63},
  [12888] = {.lex_state = 60, .external_lex_state = 31},
  [12889] = {.lex_state = 63},
  [12890] = {.lex_state = 54, .external_lex_state = 48},
  [12891] = {.lex_state = 63},
  [12892] = {.lex_state = 60, .external_lex_state = 37},
  [12893] = {.lex_state = 60, .external_lex_state = 37},
  [12894] = {.lex_state = 54, .external_lex_state = 39},
  [12895] = {.lex_state = 63},
  [12896] = {.lex_state = 54, .external_lex_state = 61},
  [12897] = {.lex_state = 53, .external_lex_state = 23},
  [12898] = {.lex_state = 54, .external_lex_state = 42},
  [12899] = {.lex_state = 54, .external_lex_state = 48},
  [12900] = {.lex_state = 63},
  [12901] = {.lex_state = 63},
  [12902] = {.lex_state = 60, .external_lex_state = 37},
  [12903] = {.lex_state = 60, .external_lex_state = 48},
  [12904] = {.lex_state = 63},
  [12905] = {.lex_state = 54, .external_lex_state = 23},
  [12906] = {.lex_state = 54, .external_lex_state = 42},
  [12907] = {.lex_state = 54, .external_lex_state = 39},
  [12908] = {.lex_state = 54, .external_lex_state = 42},
  [12909] = {.lex_state = 54, .external_lex_state = 39},
  [12910] = {.lex_state = 54, .external_lex_state = 42},
  [12911] = {.lex_state = 60, .external_lex_state = 42},
  [12912] = {.lex_state = 54, .external_lex_state = 39},
  [12913] = {.lex_state = 60, .external_lex_state = 23},
  [12914] = {.lex_state = 54, .external_lex_state = 39},
  [12915] = {.lex_state = 54, .external_lex_state = 42},
  [12916] = {.lex_state = 54, .external_lex_state = 57},
  [12917] = {.lex_state = 60, .external_lex_state = 23},
  [12918] = {.lex_state = 60, .external_lex_state = 37},
  [12919] = {.lex_state = 60, .external_lex_state = 37},
  [12920] = {.lex_state = 60, .external_lex_state = 37},
  [12921] = {.lex_state = 54, .external_lex_state = 42},
  [12922] = {.lex_state = 60, .external_lex_state = 37},
  [12923] = {.lex_state = 60, .external_lex_state = 37},
  [12924] = {.lex_state = 54, .external_lex_state = 39},
  [12925] = {.lex_state = 60, .external_lex_state = 37},
  [12926] = {.lex_state = 60, .external_lex_state = 37},
  [12927] = {.lex_state = 60, .external_lex_state = 37},
  [12928] = {.lex_state = 60, .external_lex_state = 23},
  [12929] = {.lex_state = 60, .external_lex_state = 37},
  [12930] = {.lex_state = 54, .external_lex_state = 42},
  [12931] = {.lex_state = 60, .external_lex_state = 37},
  [12932] = {.lex_state = 60, .external_lex_state = 23},
  [12933] = {.lex_state = 54, .external_lex_state = 48},
  [12934] = {.lex_state = 60, .external_lex_state = 42},
  [12935] = {.lex_state = 60, .external_lex_state = 37},
  [12936] = {.lex_state = 54, .external_lex_state = 42},
  [12937] = {.lex_state = 53, .external_lex_state = 24},
  [12938] = {.lex_state = 53, .external_lex_state = 23},
  [12939] = {.lex_state = 60, .external_lex_state = 37},
  [12940] = {.lex_state = 60, .external_lex_state = 37},
  [12941] = {.lex_state = 53, .external_lex_state = 23},
  [12942] = {.lex_state = 60, .external_lex_state = 37},
  [12943] = {.lex_state = 54, .external_lex_state = 39},
  [12944] = {.lex_state = 63},
  [12945] = {.lex_state = 54, .external_lex_state = 61},
  [12946] = {.lex_state = 60, .external_lex_state = 37},
  [12947] = {.lex_state = 54, .external_lex_state = 61},
  [12948] = {.lex_state = 60, .external_lex_state = 23},
  [12949] = {.lex_state = 54, .external_lex_state = 48},
  [12950] = {.lex_state = 54, .external_lex_state = 39},
  [12951] = {.lex_state = 60, .external_lex_state = 42},
  [12952] = {.lex_state = 60, .external_lex_state = 23},
  [12953] = {.lex_state = 60, .external_lex_state = 56},
  [12954] = {.lex_state = 54, .external_lex_state = 39},
  [12955] = {.lex_state = 60, .external_lex_state = 56},
  [12956] = {.lex_state = 54, .external_lex_state = 42},
  [12957] = {.lex_state = 60, .external_lex_state = 42},
  [12958] = {.lex_state = 60, .external_lex_state = 23},
  [12959] = {.lex_state = 60, .external_lex_state = 23},
  [12960] = {.lex_state = 63},
  [12961] = {.lex_state = 54, .external_lex_state = 39},
  [12962] = {.lex_state = 54, .external_lex_state = 39},
  [12963] = {.lex_state = 63},
  [12964] = {.lex_state = 54, .external_lex_state = 42},
  [12965] = {.lex_state = 60},
  [12966] = {.lex_state = 60},
  [12967] = {.lex_state = 60},
  [12968] = {.lex_state = 60},
  [12969] = {.lex_state = 63},
  [12970] = {.lex_state = 54, .external_lex_state = 45},
  [12971] = {.lex_state = 53, .external_lex_state = 24},
  [12972] = {.lex_state = 53, .external_lex_state = 24},
  [12973] = {.lex_state = 54, .external_lex_state = 61},
  [12974] = {.lex_state = 54, .external_lex_state = 61},
  [12975] = {.lex_state = 54, .external_lex_state = 61},
  [12976] = {.lex_state = 60},
  [12977] = {.lex_state = 54, .external_lex_state = 61},
  [12978] = {.lex_state = 63},
  [12979] = {.lex_state = 54, .external_lex_state = 61},
  [12980] = {.lex_state = 54, .external_lex_state = 61},
  [12981] = {.lex_state = 63},
  [12982] = {.lex_state = 54, .external_lex_state = 61},
  [12983] = {.lex_state = 54, .external_lex_state = 45},
  [12984] = {.lex_state = 54, .external_lex_state = 51},
  [12985] = {.lex_state = 54, .external_lex_state = 45},
  [12986] = {.lex_state = 60, .external_lex_state = 23},
  [12987] = {.lex_state = 53, .external_lex_state = 40},
  [12988] = {.lex_state = 60, .external_lex_state = 27},
  [12989] = {.lex_state = 53, .external_lex_state = 24},
  [12990] = {.lex_state = 60, .external_lex_state = 37},
  [12991] = {.lex_state = 63},
  [12992] = {.lex_state = 54, .external_lex_state = 45},
  [12993] = {.lex_state = 60, .external_lex_state = 42},
  [12994] = {.lex_state = 54, .external_lex_state = 62},
  [12995] = {.lex_state = 63},
  [12996] = {.lex_state = 60},
  [12997] = {.lex_state = 54, .external_lex_state = 49},
  [12998] = {.lex_state = 63},
  [12999] = {.lex_state = 54, .external_lex_state = 42},
  [13000] = {.lex_state = 53, .external_lex_state = 24},
  [13001] = {.lex_state = 63},
  [13002] = {.lex_state = 60, .external_lex_state = 39},
  [13003] = {.lex_state = 54, .external_lex_state = 63},
  [13004] = {.lex_state = 54, .external_lex_state = 56},
  [13005] = {.lex_state = 54, .external_lex_state = 39},
  [13006] = {.lex_state = 60, .external_lex_state = 23},
  [13007] = {.lex_state = 60, .external_lex_state = 37},
  [13008] = {.lex_state = 54, .external_lex_state = 23},
  [13009] = {.lex_state = 63},
  [13010] = {.lex_state = 60, .external_lex_state = 31},
  [13011] = {.lex_state = 21},
  [13012] = {.lex_state = 60, .external_lex_state = 42},
  [13013] = {.lex_state = 63},
  [13014] = {.lex_state = 60},
  [13015] = {.lex_state = 21},
  [13016] = {.lex_state = 63},
  [13017] = {.lex_state = 54, .external_lex_state = 62},
  [13018] = {.lex_state = 63},
  [13019] = {.lex_state = 54, .external_lex_state = 62},
  [13020] = {.lex_state = 54, .external_lex_state = 51},
  [13021] = {.lex_state = 54, .external_lex_state = 45},
  [13022] = {.lex_state = 54, .external_lex_state = 48},
  [13023] = {.lex_state = 54, .external_lex_state = 51},
  [13024] = {.lex_state = 54, .external_lex_state = 39},
  [13025] = {.lex_state = 54, .external_lex_state = 45},
  [13026] = {.lex_state = 60, .external_lex_state = 49},
  [13027] = {.lex_state = 60, .external_lex_state = 49},
  [13028] = {.lex_state = 54, .external_lex_state = 65},
  [13029] = {.lex_state = 54, .external_lex_state = 62},
  [13030] = {.lex_state = 54, .external_lex_state = 63},
  [13031] = {.lex_state = 54, .external_lex_state = 60},
  [13032] = {.lex_state = 54, .external_lex_state = 48},
  [13033] = {.lex_state = 54, .external_lex_state = 65},
  [13034] = {.lex_state = 54, .external_lex_state = 60},
  [13035] = {.lex_state = 60, .external_lex_state = 48},
  [13036] = {.lex_state = 54, .external_lex_state = 65},
  [13037] = {.lex_state = 54, .external_lex_state = 49},
  [13038] = {.lex_state = 54, .external_lex_state = 60},
  [13039] = {.lex_state = 54, .external_lex_state = 58},
  [13040] = {.lex_state = 54, .external_lex_state = 49},
  [13041] = {.lex_state = 54, .external_lex_state = 51},
  [13042] = {.lex_state = 0},
  [13043] = {.lex_state = 54, .external_lex_state = 65},
  [13044] = {.lex_state = 54, .external_lex_state = 45},
  [13045] = {.lex_state = 54, .external_lex_state = 65},
  [13046] = {.lex_state = 54, .external_lex_state = 49},
  [13047] = {.lex_state = 54, .external_lex_state = 51},
  [13048] = {.lex_state = 60, .external_lex_state = 39},
  [13049] = {.lex_state = 54, .external_lex_state = 24},
  [13050] = {.lex_state = 54, .external_lex_state = 49},
  [13051] = {.lex_state = 54, .external_lex_state = 49},
  [13052] = {.lex_state = 54, .external_lex_state = 49},
  [13053] = {.lex_state = 54, .external_lex_state = 49},
  [13054] = {.lex_state = 54, .external_lex_state = 60},
  [13055] = {.lex_state = 60, .external_lex_state = 39},
  [13056] = {.lex_state = 54, .external_lex_state = 49},
  [13057] = {.lex_state = 60, .external_lex_state = 39},
  [13058] = {.lex_state = 54, .external_lex_state = 67},
  [13059] = {.lex_state = 54, .external_lex_state = 65},
  [13060] = {.lex_state = 60, .external_lex_state = 48},
  [13061] = {.lex_state = 60, .external_lex_state = 45},
  [13062] = {.lex_state = 54, .external_lex_state = 65},
  [13063] = {.lex_state = 60, .external_lex_state = 49},
  [13064] = {.lex_state = 54, .external_lex_state = 60},
  [13065] = {.lex_state = 60, .external_lex_state = 39},
  [13066] = {.lex_state = 54, .external_lex_state = 60},
  [13067] = {.lex_state = 60, .external_lex_state = 31},
  [13068] = {.lex_state = 60, .external_lex_state = 58},
  [13069] = {.lex_state = 54, .external_lex_state = 51},
  [13070] = {.lex_state = 54, .external_lex_state = 63},
  [13071] = {.lex_state = 60, .external_lex_state = 28},
  [13072] = {.lex_state = 60, .external_lex_state = 28},
  [13073] = {.lex_state = 54, .external_lex_state = 51},
  [13074] = {.lex_state = 54, .external_lex_state = 66},
  [13075] = {.lex_state = 54, .external_lex_state = 51},
  [13076] = {.lex_state = 60, .external_lex_state = 49},
  [13077] = {.lex_state = 54, .external_lex_state = 48},
  [13078] = {.lex_state = 54, .external_lex_state = 24},
  [13079] = {.lex_state = 54, .external_lex_state = 48},
  [13080] = {.lex_state = 60, .external_lex_state = 39},
  [13081] = {.lex_state = 0},
  [13082] = {.lex_state = 60, .external_lex_state = 39},
  [13083] = {.lex_state = 60, .external_lex_state = 39},
  [13084] = {.lex_state = 54, .external_lex_state = 65},
  [13085] = {.lex_state = 60, .external_lex_state = 39},
  [13086] = {.lex_state = 60, .external_lex_state = 39},
  [13087] = {.lex_state = 54, .external_lex_state = 57},
  [13088] = {.lex_state = 54, .external_lex_state = 57},
  [13089] = {.lex_state = 60, .external_lex_state = 39},
  [13090] = {.lex_state = 60, .external_lex_state = 45},
  [13091] = {.lex_state = 60, .external_lex_state = 39},
  [13092] = {.lex_state = 60, .external_lex_state = 39},
  [13093] = {.lex_state = 54, .external_lex_state = 58},
  [13094] = {.lex_state = 54, .external_lex_state = 45},
  [13095] = {.lex_state = 60, .external_lex_state = 39},
  [13096] = {.lex_state = 54, .external_lex_state = 57},
  [13097] = {.lex_state = 60, .external_lex_state = 39},
  [13098] = {.lex_state = 60, .external_lex_state = 49},
  [13099] = {.lex_state = 54, .external_lex_state = 63},
  [13100] = {.lex_state = 60, .external_lex_state = 39},
  [13101] = {.lex_state = 60, .external_lex_state = 39},
  [13102] = {.lex_state = 60, .external_lex_state = 27},
  [13103] = {.lex_state = 53, .external_lex_state = 24},
  [13104] = {.lex_state = 60, .external_lex_state = 42},
  [13105] = {.lex_state = 53, .external_lex_state = 23},
  [13106] = {.lex_state = 60, .external_lex_state = 49},
  [13107] = {.lex_state = 54, .external_lex_state = 60},
  [13108] = {.lex_state = 54, .external_lex_state = 45},
  [13109] = {.lex_state = 54, .external_lex_state = 49},
  [13110] = {.lex_state = 60, .external_lex_state = 39},
  [13111] = {.lex_state = 54, .external_lex_state = 58},
  [13112] = {.lex_state = 54, .external_lex_state = 58},
  [13113] = {.lex_state = 54, .external_lex_state = 57},
  [13114] = {.lex_state = 60, .external_lex_state = 48},
  [13115] = {.lex_state = 54, .external_lex_state = 63},
  [13116] = {.lex_state = 54, .external_lex_state = 49},
  [13117] = {.lex_state = 54, .external_lex_state = 65},
  [13118] = {.lex_state = 54, .external_lex_state = 43},
  [13119] = {.lex_state = 60, .external_lex_state = 37},
  [13120] = {.lex_state = 60, .external_lex_state = 45},
  [13121] = {.lex_state = 60, .external_lex_state = 31},
  [13122] = {.lex_state = 54, .external_lex_state = 45},
  [13123] = {.lex_state = 54, .external_lex_state = 66},
  [13124] = {.lex_state = 54, .external_lex_state = 58},
  [13125] = {.lex_state = 54, .external_lex_state = 51},
  [13126] = {.lex_state = 54, .external_lex_state = 24},
  [13127] = {.lex_state = 60, .external_lex_state = 39},
  [13128] = {.lex_state = 54, .external_lex_state = 60},
  [13129] = {.lex_state = 60, .external_lex_state = 39},
  [13130] = {.lex_state = 54, .external_lex_state = 45},
  [13131] = {.lex_state = 60, .external_lex_state = 39},
  [13132] = {.lex_state = 60, .external_lex_state = 56},
  [13133] = {.lex_state = 54, .external_lex_state = 56},
  [13134] = {.lex_state = 54, .external_lex_state = 63},
  [13135] = {.lex_state = 60, .external_lex_state = 39},
  [13136] = {.lex_state = 54, .external_lex_state = 60},
  [13137] = {.lex_state = 54, .external_lex_state = 58},
  [13138] = {.lex_state = 54, .external_lex_state = 48},
  [13139] = {.lex_state = 60, .external_lex_state = 42},
  [13140] = {.lex_state = 60, .external_lex_state = 45},
  [13141] = {.lex_state = 54, .external_lex_state = 66},
  [13142] = {.lex_state = 54, .external_lex_state = 51},
  [13143] = {.lex_state = 54, .external_lex_state = 58},
  [13144] = {.lex_state = 54, .external_lex_state = 56},
  [13145] = {.lex_state = 54, .external_lex_state = 51},
  [13146] = {.lex_state = 54, .external_lex_state = 51},
  [13147] = {.lex_state = 54, .external_lex_state = 65},
  [13148] = {.lex_state = 54, .external_lex_state = 58},
  [13149] = {.lex_state = 54, .external_lex_state = 65},
  [13150] = {.lex_state = 54, .external_lex_state = 51},
  [13151] = {.lex_state = 60, .external_lex_state = 48},
  [13152] = {.lex_state = 60, .external_lex_state = 42},
  [13153] = {.lex_state = 54, .external_lex_state = 56},
  [13154] = {.lex_state = 54, .external_lex_state = 51},
  [13155] = {.lex_state = 54, .external_lex_state = 48},
  [13156] = {.lex_state = 54, .external_lex_state = 51},
  [13157] = {.lex_state = 54, .external_lex_state = 58},
  [13158] = {.lex_state = 54, .external_lex_state = 48},
  [13159] = {.lex_state = 60, .external_lex_state = 42},
  [13160] = {.lex_state = 60, .external_lex_state = 51},
  [13161] = {.lex_state = 60, .external_lex_state = 42},
  [13162] = {.lex_state = 54, .external_lex_state = 57},
  [13163] = {.lex_state = 60, .external_lex_state = 49},
  [13164] = {.lex_state = 60, .external_lex_state = 27},
  [13165] = {.lex_state = 60, .external_lex_state = 27},
  [13166] = {.lex_state = 60, .external_lex_state = 27},
  [13167] = {.lex_state = 54, .external_lex_state = 45},
  [13168] = {.lex_state = 54, .external_lex_state = 65},
  [13169] = {.lex_state = 60, .external_lex_state = 42},
  [13170] = {.lex_state = 60, .external_lex_state = 45},
  [13171] = {.lex_state = 60, .external_lex_state = 27},
  [13172] = {.lex_state = 60, .external_lex_state = 27},
  [13173] = {.lex_state = 60, .external_lex_state = 42},
  [13174] = {.lex_state = 60, .external_lex_state = 24},
  [13175] = {.lex_state = 60, .external_lex_state = 42},
  [13176] = {.lex_state = 60, .external_lex_state = 45},
  [13177] = {.lex_state = 60, .external_lex_state = 24},
  [13178] = {.lex_state = 54, .external_lex_state = 66},
  [13179] = {.lex_state = 54, .external_lex_state = 51},
  [13180] = {.lex_state = 60, .external_lex_state = 39},
  [13181] = {.lex_state = 60, .external_lex_state = 31},
  [13182] = {.lex_state = 54, .external_lex_state = 56},
  [13183] = {.lex_state = 54, .external_lex_state = 60},
  [13184] = {.lex_state = 54, .external_lex_state = 60},
  [13185] = {.lex_state = 54, .external_lex_state = 48},
  [13186] = {.lex_state = 60, .external_lex_state = 42},
  [13187] = {.lex_state = 60, .external_lex_state = 51},
  [13188] = {.lex_state = 53, .external_lex_state = 53},
  [13189] = {.lex_state = 54, .external_lex_state = 45},
  [13190] = {.lex_state = 54, .external_lex_state = 63},
  [13191] = {.lex_state = 54, .external_lex_state = 49},
  [13192] = {.lex_state = 54, .external_lex_state = 63},
  [13193] = {.lex_state = 60, .external_lex_state = 51},
  [13194] = {.lex_state = 60, .external_lex_state = 51},
  [13195] = {.lex_state = 54, .external_lex_state = 43},
  [13196] = {.lex_state = 54, .external_lex_state = 67},
  [13197] = {.lex_state = 54, .external_lex_state = 63},
  [13198] = {.lex_state = 54, .external_lex_state = 60},
  [13199] = {.lex_state = 54, .external_lex_state = 49},
  [13200] = {.lex_state = 54, .external_lex_state = 63},
  [13201] = {.lex_state = 54, .external_lex_state = 51},
  [13202] = {.lex_state = 60, .external_lex_state = 51},
  [13203] = {.lex_state = 60, .external_lex_state = 49},
  [13204] = {.lex_state = 54, .external_lex_state = 56},
  [13205] = {.lex_state = 54, .external_lex_state = 56},
  [13206] = {.lex_state = 54, .external_lex_state = 60},
  [13207] = {.lex_state = 54, .external_lex_state = 48},
  [13208] = {.lex_state = 60, .external_lex_state = 48},
  [13209] = {.lex_state = 60, .external_lex_state = 39},
  [13210] = {.lex_state = 54, .external_lex_state = 56},
  [13211] = {.lex_state = 54, .external_lex_state = 60},
  [13212] = {.lex_state = 54, .external_lex_state = 48},
  [13213] = {.lex_state = 54, .external_lex_state = 63},
  [13214] = {.lex_state = 60},
  [13215] = {.lex_state = 54, .external_lex_state = 56},
  [13216] = {.lex_state = 60, .external_lex_state = 51},
  [13217] = {.lex_state = 60, .external_lex_state = 31},
  [13218] = {.lex_state = 54, .external_lex_state = 56},
  [13219] = {.lex_state = 60, .external_lex_state = 42},
  [13220] = {.lex_state = 54, .external_lex_state = 56},
  [13221] = {.lex_state = 54, .external_lex_state = 51},
  [13222] = {.lex_state = 54, .external_lex_state = 56},
  [13223] = {.lex_state = 54, .external_lex_state = 56},
  [13224] = {.lex_state = 53, .external_lex_state = 24},
  [13225] = {.lex_state = 60, .external_lex_state = 31},
  [13226] = {.lex_state = 54, .external_lex_state = 63},
  [13227] = {.lex_state = 60, .external_lex_state = 42},
  [13228] = {.lex_state = 54, .external_lex_state = 45},
  [13229] = {.lex_state = 60, .external_lex_state = 49},
  [13230] = {.lex_state = 54, .external_lex_state = 24},
  [13231] = {.lex_state = 60, .external_lex_state = 27},
  [13232] = {.lex_state = 60, .external_lex_state = 42},
  [13233] = {.lex_state = 60, .external_lex_state = 27},
  [13234] = {.lex_state = 60, .external_lex_state = 42},
  [13235] = {.lex_state = 54, .external_lex_state = 63},
  [13236] = {.lex_state = 53, .external_lex_state = 24},
  [13237] = {.lex_state = 60, .external_lex_state = 57},
  [13238] = {.lex_state = 60, .external_lex_state = 51},
  [13239] = {.lex_state = 54, .external_lex_state = 48},
  [13240] = {.lex_state = 54, .external_lex_state = 58},
  [13241] = {.lex_state = 54, .external_lex_state = 48},
  [13242] = {.lex_state = 60, .external_lex_state = 42},
  [13243] = {.lex_state = 54, .external_lex_state = 57},
  [13244] = {.lex_state = 54, .external_lex_state = 58},
  [13245] = {.lex_state = 60, .external_lex_state = 27},
  [13246] = {.lex_state = 54, .external_lex_state = 58},
  [13247] = {.lex_state = 60, .external_lex_state = 27},
  [13248] = {.lex_state = 60, .external_lex_state = 49},
  [13249] = {.lex_state = 60, .external_lex_state = 42},
  [13250] = {.lex_state = 54, .external_lex_state = 67},
  [13251] = {.lex_state = 54, .external_lex_state = 45},
  [13252] = {.lex_state = 60, .external_lex_state = 42},
  [13253] = {.lex_state = 60, .external_lex_state = 28},
  [13254] = {.lex_state = 60, .external_lex_state = 49},
  [13255] = {.lex_state = 54, .external_lex_state = 65},
  [13256] = {.lex_state = 54, .external_lex_state = 65},
  [13257] = {.lex_state = 60, .external_lex_state = 42},
  [13258] = {.lex_state = 60, .external_lex_state = 49},
  [13259] = {.lex_state = 60},
  [13260] = {.lex_state = 60, .external_lex_state = 51},
  [13261] = {.lex_state = 53, .external_lex_state = 24},
  [13262] = {.lex_state = 54, .external_lex_state = 51},
  [13263] = {.lex_state = 60, .external_lex_state = 49},
  [13264] = {.lex_state = 60, .external_lex_state = 42},
  [13265] = {.lex_state = 54, .external_lex_state = 65},
  [13266] = {.lex_state = 54, .external_lex_state = 63},
  [13267] = {.lex_state = 60, .external_lex_state = 42},
  [13268] = {.lex_state = 53, .external_lex_state = 24},
  [13269] = {.lex_state = 53, .external_lex_state = 24},
  [13270] = {.lex_state = 54, .external_lex_state = 57},
  [13271] = {.lex_state = 54, .external_lex_state = 45},
  [13272] = {.lex_state = 60, .external_lex_state = 42},
  [13273] = {.lex_state = 54, .external_lex_state = 57},
  [13274] = {.lex_state = 54, .external_lex_state = 57},
  [13275] = {.lex_state = 60, .external_lex_state = 27},
  [13276] = {.lex_state = 60, .external_lex_state = 42},
  [13277] = {.lex_state = 54, .external_lex_state = 58},
  [13278] = {.lex_state = 54, .external_lex_state = 57},
  [13279] = {.lex_state = 60, .external_lex_state = 45},
  [13280] = {.lex_state = 54, .external_lex_state = 57},
  [13281] = {.lex_state = 54, .external_lex_state = 63},
  [13282] = {.lex_state = 60, .external_lex_state = 49},
  [13283] = {.lex_state = 54, .external_lex_state = 57},
  [13284] = {.lex_state = 54, .external_lex_state = 48},
  [13285] = {.lex_state = 54, .external_lex_state = 57},
  [13286] = {.lex_state = 60},
  [13287] = {.lex_state = 54, .external_lex_state = 48},
  [13288] = {.lex_state = 53, .external_lex_state = 24},
  [13289] = {.lex_state = 54, .external_lex_state = 49},
  [13290] = {.lex_state = 60, .external_lex_state = 48},
  [13291] = {.lex_state = 60, .external_lex_state = 48},
  [13292] = {.lex_state = 60, .external_lex_state = 42},
  [13293] = {.lex_state = 54, .external_lex_state = 51},
  [13294] = {.lex_state = 60, .external_lex_state = 28},
  [13295] = {.lex_state = 54, .external_lex_state = 65},
  [13296] = {.lex_state = 54, .external_lex_state = 45},
  [13297] = {.lex_state = 54, .external_lex_state = 49},
  [13298] = {.lex_state = 60, .external_lex_state = 27},
  [13299] = {.lex_state = 54, .external_lex_state = 45},
  [13300] = {.lex_state = 54, .external_lex_state = 45},
  [13301] = {.lex_state = 54, .external_lex_state = 45},
  [13302] = {.lex_state = 54, .external_lex_state = 45},
  [13303] = {.lex_state = 53, .external_lex_state = 24},
  [13304] = {.lex_state = 54, .external_lex_state = 60},
  [13305] = {.lex_state = 54, .external_lex_state = 48},
  [13306] = {.lex_state = 54, .external_lex_state = 49},
  [13307] = {.lex_state = 54, .external_lex_state = 45},
  [13308] = {.lex_state = 60, .external_lex_state = 45},
  [13309] = {.lex_state = 54, .external_lex_state = 56},
  [13310] = {.lex_state = 54, .external_lex_state = 23},
  [13311] = {.lex_state = 54, .external_lex_state = 48},
  [13312] = {.lex_state = 60, .external_lex_state = 42},
  [13313] = {.lex_state = 60, .external_lex_state = 42},
  [13314] = {.lex_state = 54, .external_lex_state = 48},
  [13315] = {.lex_state = 54, .external_lex_state = 49},
  [13316] = {.lex_state = 54, .external_lex_state = 63},
  [13317] = {.lex_state = 54, .external_lex_state = 49},
  [13318] = {.lex_state = 54, .external_lex_state = 48},
  [13319] = {.lex_state = 60, .external_lex_state = 42},
  [13320] = {.lex_state = 54, .external_lex_state = 24},
  [13321] = {.lex_state = 54, .external_lex_state = 56},
  [13322] = {.lex_state = 60, .external_lex_state = 45},
  [13323] = {.lex_state = 60, .external_lex_state = 49},
  [13324] = {.lex_state = 54, .external_lex_state = 66},
  [13325] = {.lex_state = 60, .external_lex_state = 36},
  [13326] = {.lex_state = 60, .external_lex_state = 48},
  [13327] = {.lex_state = 60, .external_lex_state = 31},
  [13328] = {.lex_state = 60, .external_lex_state = 45},
  [13329] = {.lex_state = 60, .external_lex_state = 27},
  [13330] = {.lex_state = 53, .external_lex_state = 23},
  [13331] = {.lex_state = 60, .external_lex_state = 49},
  [13332] = {.lex_state = 60, .external_lex_state = 37},
  [13333] = {.lex_state = 60, .external_lex_state = 49},
  [13334] = {.lex_state = 60, .external_lex_state = 51},
  [13335] = {.lex_state = 60, .external_lex_state = 27},
  [13336] = {.lex_state = 60, .external_lex_state = 58},
  [13337] = {.lex_state = 60, .external_lex_state = 48},
  [13338] = {.lex_state = 54, .external_lex_state = 66},
  [13339] = {.lex_state = 60, .external_lex_state = 49},
  [13340] = {.lex_state = 54, .external_lex_state = 58},
  [13341] = {.lex_state = 60, .external_lex_state = 28},
  [13342] = {.lex_state = 60, .external_lex_state = 28},
  [13343] = {.lex_state = 60, .external_lex_state = 51},
  [13344] = {.lex_state = 60, .external_lex_state = 36},
  [13345] = {.lex_state = 60, .external_lex_state = 28},
  [13346] = {.lex_state = 60, .external_lex_state = 28},
  [13347] = {.lex_state = 60, .external_lex_state = 28},
  [13348] = {.lex_state = 54, .external_lex_state = 24},
  [13349] = {.lex_state = 54, .external_lex_state = 57},
  [13350] = {.lex_state = 54, .external_lex_state = 23},
  [13351] = {.lex_state = 60, .external_lex_state = 36},
  [13352] = {.lex_state = 54, .external_lex_state = 66},
  [13353] = {.lex_state = 54, .external_lex_state = 24},
  [13354] = {.lex_state = 54, .external_lex_state = 61},
  [13355] = {.lex_state = 60, .external_lex_state = 56},
  [13356] = {.lex_state = 60, .external_lex_state = 27},
  [13357] = {.lex_state = 60, .external_lex_state = 48},
  [13358] = {.lex_state = 54, .external_lex_state = 24},
  [13359] = {.lex_state = 60, .external_lex_state = 57},
  [13360] = {.lex_state = 60, .external_lex_state = 42},
  [13361] = {.lex_state = 60, .external_lex_state = 42},
  [13362] = {.lex_state = 54, .external_lex_state = 24},
  [13363] = {.lex_state = 54, .external_lex_state = 58},
  [13364] = {.lex_state = 60, .external_lex_state = 49},
  [13365] = {.lex_state = 54, .external_lex_state = 61},
  [13366] = {.lex_state = 60, .external_lex_state = 58},
  [13367] = {.lex_state = 60, .external_lex_state = 48},
  [13368] = {.lex_state = 60, .external_lex_state = 51},
  [13369] = {.lex_state = 54, .external_lex_state = 24},
  [13370] = {.lex_state = 54, .external_lex_state = 58},
  [13371] = {.lex_state = 60, .external_lex_state = 23},
  [13372] = {.lex_state = 54, .external_lex_state = 58},
  [13373] = {.lex_state = 54, .external_lex_state = 24},
  [13374] = {.lex_state = 53, .external_lex_state = 24},
  [13375] = {.lex_state = 60, .external_lex_state = 48},
  [13376] = {.lex_state = 60, .external_lex_state = 31},
  [13377] = {.lex_state = 60, .external_lex_state = 56},
  [13378] = {.lex_state = 54, .external_lex_state = 61},
  [13379] = {.lex_state = 60, .external_lex_state = 56},
  [13380] = {.lex_state = 60, .external_lex_state = 48},
  [13381] = {.lex_state = 54, .external_lex_state = 23},
  [13382] = {.lex_state = 54, .external_lex_state = 67},
  [13383] = {.lex_state = 60, .external_lex_state = 37},
  [13384] = {.lex_state = 60, .external_lex_state = 49},
  [13385] = {.lex_state = 54, .external_lex_state = 24},
  [13386] = {.lex_state = 60, .external_lex_state = 42},
  [13387] = {.lex_state = 54, .external_lex_state = 66},
  [13388] = {.lex_state = 53, .external_lex_state = 23},
  [13389] = {.lex_state = 60, .external_lex_state = 49},
  [13390] = {.lex_state = 60, .external_lex_state = 27},
  [13391] = {.lex_state = 60, .external_lex_state = 51},
  [13392] = {.lex_state = 54, .external_lex_state = 61},
  [13393] = {.lex_state = 54, .external_lex_state = 61},
  [13394] = {.lex_state = 60, .external_lex_state = 49},
  [13395] = {.lex_state = 53, .external_lex_state = 23},
  [13396] = {.lex_state = 53, .external_lex_state = 23},
  [13397] = {.lex_state = 54, .external_lex_state = 58},
  [13398] = {.lex_state = 60, .external_lex_state = 49},
  [13399] = {.lex_state = 54, .external_lex_state = 24},
  [13400] = {.lex_state = 60, .external_lex_state = 39},
  [13401] = {.lex_state = 60, .external_lex_state = 57},
  [13402] = {.lex_state = 60, .external_lex_state = 49},
  [13403] = {.lex_state = 54, .external_lex_state = 61},
  [13404] = {.lex_state = 54, .external_lex_state = 56},
  [13405] = {.lex_state = 60, .external_lex_state = 45},
  [13406] = {.lex_state = 54, .external_lex_state = 57},
  [13407] = {.lex_state = 54, .external_lex_state = 66},
  [13408] = {.lex_state = 54, .external_lex_state = 67},
  [13409] = {.lex_state = 60, .external_lex_state = 58},
  [13410] = {.lex_state = 54, .external_lex_state = 66},
  [13411] = {.lex_state = 54, .external_lex_state = 56},
  [13412] = {.lex_state = 54, .external_lex_state = 67},
  [13413] = {.lex_state = 60, .external_lex_state = 48},
  [13414] = {.lex_state = 60, .external_lex_state = 49},
  [13415] = {.lex_state = 54, .external_lex_state = 24},
  [13416] = {.lex_state = 54, .external_lex_state = 67},
  [13417] = {.lex_state = 54, .external_lex_state = 58},
  [13418] = {.lex_state = 60, .external_lex_state = 57},
  [13419] = {.lex_state = 60, .external_lex_state = 58},
  [13420] = {.lex_state = 60, .external_lex_state = 57},
  [13421] = {.lex_state = 60, .external_lex_state = 56},
  [13422] = {.lex_state = 54, .external_lex_state = 57},
  [13423] = {.lex_state = 60, .external_lex_state = 27},
  [13424] = {.lex_state = 54, .external_lex_state = 66},
  [13425] = {.lex_state = 54, .external_lex_state = 61},
  [13426] = {.lex_state = 60, .external_lex_state = 48},
  [13427] = {.lex_state = 54, .external_lex_state = 56},
  [13428] = {.lex_state = 60, .external_lex_state = 49},
  [13429] = {.lex_state = 54, .external_lex_state = 61},
  [13430] = {.lex_state = 60, .external_lex_state = 51},
  [13431] = {.lex_state = 60, .external_lex_state = 48},
  [13432] = {.lex_state = 54, .external_lex_state = 56},
  [13433] = {.lex_state = 54, .external_lex_state = 57},
  [13434] = {.lex_state = 54, .external_lex_state = 56},
  [13435] = {.lex_state = 60, .external_lex_state = 39},
  [13436] = {.lex_state = 54, .external_lex_state = 57},
  [13437] = {.lex_state = 60, .external_lex_state = 48},
  [13438] = {.lex_state = 54, .external_lex_state = 56},
  [13439] = {.lex_state = 60, .external_lex_state = 37},
  [13440] = {.lex_state = 54, .external_lex_state = 57},
  [13441] = {.lex_state = 60, .external_lex_state = 49},
  [13442] = {.lex_state = 54, .external_lex_state = 66},
  [13443] = {.lex_state = 60, .external_lex_state = 51},
  [13444] = {.lex_state = 60, .external_lex_state = 45},
  [13445] = {.lex_state = 60, .external_lex_state = 51},
  [13446] = {.lex_state = 60, .external_lex_state = 57},
  [13447] = {.lex_state = 54, .external_lex_state = 56},
  [13448] = {.lex_state = 54, .external_lex_state = 67},
  [13449] = {.lex_state = 60, .external_lex_state = 45},
  [13450] = {.lex_state = 54, .external_lex_state = 53},
  [13451] = {.lex_state = 60, .external_lex_state = 48},
  [13452] = {.lex_state = 54, .external_lex_state = 61},
  [13453] = {.lex_state = 53, .external_lex_state = 23},
  [13454] = {.lex_state = 60, .external_lex_state = 45},
  [13455] = {.lex_state = 60, .external_lex_state = 51},
  [13456] = {.lex_state = 60, .external_lex_state = 45},
  [13457] = {.lex_state = 60, .external_lex_state = 45},
  [13458] = {.lex_state = 54, .external_lex_state = 66},
  [13459] = {.lex_state = 54, .external_lex_state = 57},
  [13460] = {.lex_state = 60, .external_lex_state = 56},
  [13461] = {.lex_state = 60, .external_lex_state = 56},
  [13462] = {.lex_state = 54, .external_lex_state = 61},
  [13463] = {.lex_state = 60, .external_lex_state = 45},
  [13464] = {.lex_state = 54, .external_lex_state = 56},
  [13465] = {.lex_state = 54, .external_lex_state = 56},
  [13466] = {.lex_state = 54, .external_lex_state = 56},
  [13467] = {.lex_state = 53, .external_lex_state = 23},
  [13468] = {.lex_state = 60, .external_lex_state = 58},
  [13469] = {.lex_state = 60, .external_lex_state = 45},
  [13470] = {.lex_state = 54, .external_lex_state = 67},
  [13471] = {.lex_state = 60, .external_lex_state = 42},
  [13472] = {.lex_state = 54, .external_lex_state = 58},
  [13473] = {.lex_state = 54, .external_lex_state = 56},
  [13474] = {.lex_state = 60, .external_lex_state = 42},
  [13475] = {.lex_state = 60, .external_lex_state = 45},
  [13476] = {.lex_state = 60},
  [13477] = {.lex_state = 60, .external_lex_state = 48},
  [13478] = {.lex_state = 60, .external_lex_state = 45},
  [13479] = {.lex_state = 60, .external_lex_state = 37},
  [13480] = {.lex_state = 54, .external_lex_state = 23},
  [13481] = {.lex_state = 60, .external_lex_state = 51},
  [13482] = {.lex_state = 60, .external_lex_state = 31},
  [13483] = {.lex_state = 60, .external_lex_state = 51},
  [13484] = {.lex_state = 54, .external_lex_state = 67},
  [13485] = {.lex_state = 60, .external_lex_state = 37},
  [13486] = {.lex_state = 60, .external_lex_state = 51},
  [13487] = {.lex_state = 60, .external_lex_state = 51},
  [13488] = {.lex_state = 54, .external_lex_state = 61},
  [13489] = {.lex_state = 54, .external_lex_state = 61},
  [13490] = {.lex_state = 60, .external_lex_state = 51},
  [13491] = {.lex_state = 54, .external_lex_state = 58},
  [13492] = {.lex_state = 53, .external_lex_state = 23},
  [13493] = {.lex_state = 60, .external_lex_state = 49},
  [13494] = {.lex_state = 53, .external_lex_state = 23},
  [13495] = {.lex_state = 60, .external_lex_state = 51},
  [13496] = {.lex_state = 60, .external_lex_state = 56},
  [13497] = {.lex_state = 60, .external_lex_state = 51},
  [13498] = {.lex_state = 60, .external_lex_state = 56},
  [13499] = {.lex_state = 54, .external_lex_state = 67},
  [13500] = {.lex_state = 60, .external_lex_state = 51},
  [13501] = {.lex_state = 54, .external_lex_state = 57},
  [13502] = {.lex_state = 60, .external_lex_state = 28},
  [13503] = {.lex_state = 60, .external_lex_state = 27},
  [13504] = {.lex_state = 60, .external_lex_state = 51},
  [13505] = {.lex_state = 60, .external_lex_state = 28},
  [13506] = {.lex_state = 60, .external_lex_state = 28},
  [13507] = {.lex_state = 54, .external_lex_state = 66},
  [13508] = {.lex_state = 60, .external_lex_state = 28},
  [13509] = {.lex_state = 60, .external_lex_state = 51},
  [13510] = {.lex_state = 60, .external_lex_state = 58},
  [13511] = {.lex_state = 54, .external_lex_state = 67},
  [13512] = {.lex_state = 54, .external_lex_state = 67},
  [13513] = {.lex_state = 60, .external_lex_state = 45},
  [13514] = {.lex_state = 60, .external_lex_state = 49},
  [13515] = {.lex_state = 54, .external_lex_state = 57},
  [13516] = {.lex_state = 60, .external_lex_state = 27},
  [13517] = {.lex_state = 60, .external_lex_state = 49},
  [13518] = {.lex_state = 54, .external_lex_state = 58},
  [13519] = {.lex_state = 60, .external_lex_state = 45},
  [13520] = {.lex_state = 54, .external_lex_state = 43},
  [13521] = {.lex_state = 60, .external_lex_state = 48},
  [13522] = {.lex_state = 54, .external_lex_state = 56},
  [13523] = {.lex_state = 60, .external_lex_state = 49},
  [13524] = {.lex_state = 60, .external_lex_state = 48},
  [13525] = {.lex_state = 60, .external_lex_state = 49},
  [13526] = {.lex_state = 54, .external_lex_state = 56},
  [13527] = {.lex_state = 54, .external_lex_state = 67},
  [13528] = {.lex_state = 54, .external_lex_state = 56},
  [13529] = {.lex_state = 60, .external_lex_state = 42},
  [13530] = {.lex_state = 54, .external_lex_state = 58},
  [13531] = {.lex_state = 60, .external_lex_state = 51},
  [13532] = {.lex_state = 60, .external_lex_state = 49},
  [13533] = {.lex_state = 60, .external_lex_state = 45},
  [13534] = {.lex_state = 60, .external_lex_state = 48},
  [13535] = {.lex_state = 54, .external_lex_state = 57},
  [13536] = {.lex_state = 60, .external_lex_state = 49},
  [13537] = {.lex_state = 60, .external_lex_state = 27},
  [13538] = {.lex_state = 60, .external_lex_state = 49},
  [13539] = {.lex_state = 60, .external_lex_state = 48},
  [13540] = {.lex_state = 60, .external_lex_state = 51},
  [13541] = {.lex_state = 60, .external_lex_state = 23},
  [13542] = {.lex_state = 60, .external_lex_state = 37},
  [13543] = {.lex_state = 60, .external_lex_state = 51},
  [13544] = {.lex_state = 54, .external_lex_state = 56},
  [13545] = {.lex_state = 60, .external_lex_state = 51},
  [13546] = {.lex_state = 54, .external_lex_state = 66},
  [13547] = {.lex_state = 54, .external_lex_state = 58},
  [13548] = {.lex_state = 54, .external_lex_state = 58},
  [13549] = {.lex_state = 60, .external_lex_state = 51},
  [13550] = {.lex_state = 54, .external_lex_state = 58},
  [13551] = {.lex_state = 54, .external_lex_state = 58},
  [13552] = {.lex_state = 54, .external_lex_state = 58},
  [13553] = {.lex_state = 60, .external_lex_state = 51},
  [13554] = {.lex_state = 54, .external_lex_state = 57},
  [13555] = {.lex_state = 60, .external_lex_state = 45},
  [13556] = {.lex_state = 54, .external_lex_state = 66},
  [13557] = {.lex_state = 60, .external_lex_state = 45},
  [13558] = {.lex_state = 60, .external_lex_state = 24},
  [13559] = {.lex_state = 54, .external_lex_state = 66},
  [13560] = {.lex_state = 54, .external_lex_state = 57},
  [13561] = {.lex_state = 54, .external_lex_state = 67},
  [13562] = {.lex_state = 53, .external_lex_state = 23},
  [13563] = {.lex_state = 60, .external_lex_state = 48},
  [13564] = {.lex_state = 60, .external_lex_state = 51},
  [13565] = {.lex_state = 60, .external_lex_state = 51},
  [13566] = {.lex_state = 54},
  [13567] = {.lex_state = 54, .external_lex_state = 66},
  [13568] = {.lex_state = 53, .external_lex_state = 23},
  [13569] = {.lex_state = 60, .external_lex_state = 45},
  [13570] = {.lex_state = 54, .external_lex_state = 67},
  [13571] = {.lex_state = 54, .external_lex_state = 23},
  [13572] = {.lex_state = 54, .external_lex_state = 24},
  [13573] = {.lex_state = 60, .external_lex_state = 49},
  [13574] = {.lex_state = 60, .external_lex_state = 42},
  [13575] = {.lex_state = 60, .external_lex_state = 58},
  [13576] = {.lex_state = 60, .external_lex_state = 58},
  [13577] = {.lex_state = 60, .external_lex_state = 37},
  [13578] = {.lex_state = 60, .external_lex_state = 57},
  [13579] = {.lex_state = 60, .external_lex_state = 45},
  [13580] = {.lex_state = 54, .external_lex_state = 66},
  [13581] = {.lex_state = 54, .external_lex_state = 67},
  [13582] = {.lex_state = 53, .external_lex_state = 23},
  [13583] = {.lex_state = 60, .external_lex_state = 48},
  [13584] = {.lex_state = 54, .external_lex_state = 57},
  [13585] = {.lex_state = 60, .external_lex_state = 31},
  [13586] = {.lex_state = 60, .external_lex_state = 42},
  [13587] = {.lex_state = 54, .external_lex_state = 57},
  [13588] = {.lex_state = 54, .external_lex_state = 57},
  [13589] = {.lex_state = 54, .external_lex_state = 66},
  [13590] = {.lex_state = 54, .external_lex_state = 67},
  [13591] = {.lex_state = 60, .external_lex_state = 28},
  [13592] = {.lex_state = 60, .external_lex_state = 45},
  [13593] = {.lex_state = 54, .external_lex_state = 40},
  [13594] = {.lex_state = 54, .external_lex_state = 57},
  [13595] = {.lex_state = 53, .external_lex_state = 23},
  [13596] = {.lex_state = 60, .external_lex_state = 49},
  [13597] = {.lex_state = 54, .external_lex_state = 61},
  [13598] = {.lex_state = 60, .external_lex_state = 27},
  [13599] = {.lex_state = 60, .external_lex_state = 37},
  [13600] = {.lex_state = 60, .external_lex_state = 48},
  [13601] = {.lex_state = 60, .external_lex_state = 45},
  [13602] = {.lex_state = 60, .external_lex_state = 45},
  [13603] = {.lex_state = 60, .external_lex_state = 45},
  [13604] = {.lex_state = 60, .external_lex_state = 37},
  [13605] = {.lex_state = 60, .external_lex_state = 37},
  [13606] = {.lex_state = 60, .external_lex_state = 27},
  [13607] = {.lex_state = 60, .external_lex_state = 57},
  [13608] = {.lex_state = 60, .external_lex_state = 51},
  [13609] = {.lex_state = 54, .external_lex_state = 58},
  [13610] = {.lex_state = 54, .external_lex_state = 63},
  [13611] = {.lex_state = 60, .external_lex_state = 27},
  [13612] = {.lex_state = 60, .external_lex_state = 49},
  [13613] = {.lex_state = 60, .external_lex_state = 45},
  [13614] = {.lex_state = 60, .external_lex_state = 48},
  [13615] = {.lex_state = 54, .external_lex_state = 66},
  [13616] = {.lex_state = 54, .external_lex_state = 56},
  [13617] = {.lex_state = 54, .external_lex_state = 58},
  [13618] = {.lex_state = 60, .external_lex_state = 45},
  [13619] = {.lex_state = 60, .external_lex_state = 49},
  [13620] = {.lex_state = 60, .external_lex_state = 49},
  [13621] = {.lex_state = 60, .external_lex_state = 31},
  [13622] = {.lex_state = 54, .external_lex_state = 61},
  [13623] = {.lex_state = 54, .external_lex_state = 24},
  [13624] = {.lex_state = 54, .external_lex_state = 61},
  [13625] = {.lex_state = 60, .external_lex_state = 27},
  [13626] = {.lex_state = 54, .external_lex_state = 67},
  [13627] = {.lex_state = 54, .external_lex_state = 23},
  [13628] = {.lex_state = 60, .external_lex_state = 48},
  [13629] = {.lex_state = 60, .external_lex_state = 45},
  [13630] = {.lex_state = 60, .external_lex_state = 36},
  [13631] = {.lex_state = 54, .external_lex_state = 57},
  [13632] = {.lex_state = 60, .external_lex_state = 37},
  [13633] = {.lex_state = 60, .external_lex_state = 56},
  [13634] = {.lex_state = 60, .external_lex_state = 56},
  [13635] = {.lex_state = 53, .external_lex_state = 24},
  [13636] = {.lex_state = 60, .external_lex_state = 56},
  [13637] = {.lex_state = 54, .external_lex_state = 43},
  [13638] = {.lex_state = 60, .external_lex_state = 51},
  [13639] = {.lex_state = 60, .external_lex_state = 39},
  [13640] = {.lex_state = 60, .external_lex_state = 35},
  [13641] = {.lex_state = 60, .external_lex_state = 56},
  [13642] = {.lex_state = 60, .external_lex_state = 40},
  [13643] = {.lex_state = 54, .external_lex_state = 43},
  [13644] = {.lex_state = 0},
  [13645] = {.lex_state = 60, .external_lex_state = 56},
  [13646] = {.lex_state = 0},
  [13647] = {.lex_state = 0},
  [13648] = {.lex_state = 60, .external_lex_state = 51},
  [13649] = {.lex_state = 0},
  [13650] = {.lex_state = 60, .external_lex_state = 57},
  [13651] = {.lex_state = 60, .external_lex_state = 28},
  [13652] = {.lex_state = 53, .external_lex_state = 24},
  [13653] = {.lex_state = 60, .external_lex_state = 31},
  [13654] = {.lex_state = 60},
  [13655] = {.lex_state = 60},
  [13656] = {.lex_state = 60, .external_lex_state = 37},
  [13657] = {.lex_state = 60, .external_lex_state = 24},
  [13658] = {.lex_state = 60, .external_lex_state = 53},
  [13659] = {.lex_state = 60, .external_lex_state = 56},
  [13660] = {.lex_state = 60, .external_lex_state = 27},
  [13661] = {.lex_state = 60, .external_lex_state = 56},
  [13662] = {.lex_state = 53, .external_lex_state = 24},
  [13663] = {.lex_state = 60, .external_lex_state = 40},
  [13664] = {.lex_state = 60},
  [13665] = {.lex_state = 60, .external_lex_state = 58},
  [13666] = {.lex_state = 60, .external_lex_state = 58},
  [13667] = {.lex_state = 54, .external_lex_state = 60},
  [13668] = {.lex_state = 54, .external_lex_state = 60},
  [13669] = {.lex_state = 54, .external_lex_state = 60},
  [13670] = {.lex_state = 54, .external_lex_state = 60},
  [13671] = {.lex_state = 60},
  [13672] = {.lex_state = 60},
  [13673] = {.lex_state = 60, .external_lex_state = 45},
  [13674] = {.lex_state = 54, .external_lex_state = 66},
  [13675] = {.lex_state = 54},
  [13676] = {.lex_state = 54, .external_lex_state = 24},
  [13677] = {.lex_state = 60, .external_lex_state = 51},
  [13678] = {.lex_state = 60, .external_lex_state = 58},
  [13679] = {.lex_state = 60, .external_lex_state = 58},
  [13680] = {.lex_state = 60, .external_lex_state = 58},
  [13681] = {.lex_state = 0, .external_lex_state = 23},
  [13682] = {.lex_state = 60, .external_lex_state = 23},
  [13683] = {.lex_state = 60, .external_lex_state = 58},
  [13684] = {.lex_state = 54, .external_lex_state = 23},
  [13685] = {.lex_state = 60, .external_lex_state = 58},
  [13686] = {.lex_state = 53, .external_lex_state = 24},
  [13687] = {.lex_state = 60, .external_lex_state = 23},
  [13688] = {.lex_state = 60, .external_lex_state = 58},
  [13689] = {.lex_state = 60, .external_lex_state = 58},
  [13690] = {.lex_state = 60, .external_lex_state = 58},
  [13691] = {.lex_state = 60, .external_lex_state = 58},
  [13692] = {.lex_state = 60, .external_lex_state = 24},
  [13693] = {.lex_state = 60, .external_lex_state = 58},
  [13694] = {.lex_state = 60, .external_lex_state = 58},
  [13695] = {.lex_state = 60, .external_lex_state = 56},
  [13696] = {.lex_state = 60, .external_lex_state = 56},
  [13697] = {.lex_state = 60, .external_lex_state = 58},
  [13698] = {.lex_state = 60, .external_lex_state = 51},
  [13699] = {.lex_state = 60, .external_lex_state = 58},
  [13700] = {.lex_state = 60, .external_lex_state = 27},
  [13701] = {.lex_state = 60, .external_lex_state = 58},
  [13702] = {.lex_state = 60, .external_lex_state = 58},
  [13703] = {.lex_state = 0},
  [13704] = {.lex_state = 60, .external_lex_state = 58},
  [13705] = {.lex_state = 0},
  [13706] = {.lex_state = 53, .external_lex_state = 24},
  [13707] = {.lex_state = 60, .external_lex_state = 36},
  [13708] = {.lex_state = 53},
  [13709] = {.lex_state = 53},
  [13710] = {.lex_state = 60, .external_lex_state = 27},
  [13711] = {.lex_state = 60, .external_lex_state = 36},
  [13712] = {.lex_state = 60, .external_lex_state = 57},
  [13713] = {.lex_state = 54, .external_lex_state = 43},
  [13714] = {.lex_state = 60, .external_lex_state = 58},
  [13715] = {.lex_state = 60, .external_lex_state = 57},
  [13716] = {.lex_state = 60, .external_lex_state = 57},
  [13717] = {.lex_state = 60, .external_lex_state = 58},
  [13718] = {.lex_state = 60, .external_lex_state = 58},
  [13719] = {.lex_state = 54, .external_lex_state = 65},
  [13720] = {.lex_state = 60, .external_lex_state = 58},
  [13721] = {.lex_state = 60, .external_lex_state = 58},
  [13722] = {.lex_state = 60, .external_lex_state = 57},
  [13723] = {.lex_state = 60, .external_lex_state = 31},
  [13724] = {.lex_state = 60, .external_lex_state = 56},
  [13725] = {.lex_state = 60, .external_lex_state = 23},
  [13726] = {.lex_state = 54, .external_lex_state = 60},
  [13727] = {.lex_state = 54, .external_lex_state = 60},
  [13728] = {.lex_state = 60},
  [13729] = {.lex_state = 60, .external_lex_state = 24},
  [13730] = {.lex_state = 60, .external_lex_state = 58},
  [13731] = {.lex_state = 60, .external_lex_state = 56},
  [13732] = {.lex_state = 54, .external_lex_state = 24},
  [13733] = {.lex_state = 54, .external_lex_state = 60},
  [13734] = {.lex_state = 60, .external_lex_state = 28},
  [13735] = {.lex_state = 60, .external_lex_state = 28},
  [13736] = {.lex_state = 54, .external_lex_state = 40},
  [13737] = {.lex_state = 60, .external_lex_state = 68},
  [13738] = {.lex_state = 60, .external_lex_state = 23},
  [13739] = {.lex_state = 60, .external_lex_state = 28},
  [13740] = {.lex_state = 60, .external_lex_state = 28},
  [13741] = {.lex_state = 60, .external_lex_state = 35},
  [13742] = {.lex_state = 60, .external_lex_state = 69},
  [13743] = {.lex_state = 54, .external_lex_state = 60},
  [13744] = {.lex_state = 0},
  [13745] = {.lex_state = 60, .external_lex_state = 24},
  [13746] = {.lex_state = 60, .external_lex_state = 28},
  [13747] = {.lex_state = 60, .external_lex_state = 28},
  [13748] = {.lex_state = 54, .external_lex_state = 60},
  [13749] = {.lex_state = 54, .external_lex_state = 60},
  [13750] = {.lex_state = 54, .external_lex_state = 23},
  [13751] = {.lex_state = 60, .external_lex_state = 56},
  [13752] = {.lex_state = 60, .external_lex_state = 28},
  [13753] = {.lex_state = 0},
  [13754] = {.lex_state = 60, .external_lex_state = 24},
  [13755] = {.lex_state = 60, .external_lex_state = 57},
  [13756] = {.lex_state = 0},
  [13757] = {.lex_state = 60, .external_lex_state = 57},
  [13758] = {.lex_state = 0},
  [13759] = {.lex_state = 60, .external_lex_state = 57},
  [13760] = {.lex_state = 60, .external_lex_state = 57},
  [13761] = {.lex_state = 60, .external_lex_state = 69},
  [13762] = {.lex_state = 60, .external_lex_state = 57},
  [13763] = {.lex_state = 60, .external_lex_state = 24},
  [13764] = {.lex_state = 60, .external_lex_state = 56},
  [13765] = {.lex_state = 60, .external_lex_state = 31},
  [13766] = {.lex_state = 54, .external_lex_state = 53},
  [13767] = {.lex_state = 60, .external_lex_state = 28},
  [13768] = {.lex_state = 60, .external_lex_state = 28},
  [13769] = {.lex_state = 60, .external_lex_state = 57},
  [13770] = {.lex_state = 60, .external_lex_state = 51},
  [13771] = {.lex_state = 60, .external_lex_state = 51},
  [13772] = {.lex_state = 60, .external_lex_state = 28},
  [13773] = {.lex_state = 60, .external_lex_state = 28},
  [13774] = {.lex_state = 60, .external_lex_state = 24},
  [13775] = {.lex_state = 60, .external_lex_state = 51},
  [13776] = {.lex_state = 60, .external_lex_state = 51},
  [13777] = {.lex_state = 60, .external_lex_state = 57},
  [13778] = {.lex_state = 60, .external_lex_state = 28},
  [13779] = {.lex_state = 54, .external_lex_state = 24},
  [13780] = {.lex_state = 60, .external_lex_state = 53},
  [13781] = {.lex_state = 60, .external_lex_state = 57},
  [13782] = {.lex_state = 53, .external_lex_state = 24},
  [13783] = {.lex_state = 60, .external_lex_state = 58},
  [13784] = {.lex_state = 60, .external_lex_state = 57},
  [13785] = {.lex_state = 60, .external_lex_state = 23},
  [13786] = {.lex_state = 60, .external_lex_state = 57},
  [13787] = {.lex_state = 60, .external_lex_state = 56},
  [13788] = {.lex_state = 54, .external_lex_state = 24},
  [13789] = {.lex_state = 60, .external_lex_state = 56},
  [13790] = {.lex_state = 53, .external_lex_state = 24},
  [13791] = {.lex_state = 60, .external_lex_state = 31},
  [13792] = {.lex_state = 60, .external_lex_state = 31},
  [13793] = {.lex_state = 60, .external_lex_state = 57},
  [13794] = {.lex_state = 53, .external_lex_state = 24},
  [13795] = {.lex_state = 60, .external_lex_state = 56},
  [13796] = {.lex_state = 60, .external_lex_state = 58},
  [13797] = {.lex_state = 60, .external_lex_state = 58},
  [13798] = {.lex_state = 53, .external_lex_state = 24},
  [13799] = {.lex_state = 60, .external_lex_state = 35},
  [13800] = {.lex_state = 60, .external_lex_state = 35},
  [13801] = {.lex_state = 60, .external_lex_state = 56},
  [13802] = {.lex_state = 60, .external_lex_state = 24},
  [13803] = {.lex_state = 60, .external_lex_state = 27},
  [13804] = {.lex_state = 60, .external_lex_state = 31},
  [13805] = {.lex_state = 60, .external_lex_state = 57},
  [13806] = {.lex_state = 60, .external_lex_state = 56},
  [13807] = {.lex_state = 54, .external_lex_state = 43},
  [13808] = {.lex_state = 60, .external_lex_state = 35},
  [13809] = {.lex_state = 60, .external_lex_state = 31},
  [13810] = {.lex_state = 60, .external_lex_state = 35},
  [13811] = {.lex_state = 60, .external_lex_state = 39},
  [13812] = {.lex_state = 60, .external_lex_state = 56},
  [13813] = {.lex_state = 60, .external_lex_state = 56},
  [13814] = {.lex_state = 60, .external_lex_state = 24},
  [13815] = {.lex_state = 60, .external_lex_state = 39},
  [13816] = {.lex_state = 60, .external_lex_state = 56},
  [13817] = {.lex_state = 60, .external_lex_state = 56},
  [13818] = {.lex_state = 54, .external_lex_state = 24},
  [13819] = {.lex_state = 60, .external_lex_state = 31},
  [13820] = {.lex_state = 60, .external_lex_state = 57},
  [13821] = {.lex_state = 54, .external_lex_state = 24},
  [13822] = {.lex_state = 60, .external_lex_state = 35},
  [13823] = {.lex_state = 60, .external_lex_state = 57},
  [13824] = {.lex_state = 60, .external_lex_state = 35},
  [13825] = {.lex_state = 60, .external_lex_state = 57},
  [13826] = {.lex_state = 60, .external_lex_state = 56},
  [13827] = {.lex_state = 60, .external_lex_state = 68},
  [13828] = {.lex_state = 60, .external_lex_state = 57},
  [13829] = {.lex_state = 60, .external_lex_state = 39},
  [13830] = {.lex_state = 53, .external_lex_state = 24},
  [13831] = {.lex_state = 53, .external_lex_state = 23},
  [13832] = {.lex_state = 53, .external_lex_state = 24},
  [13833] = {.lex_state = 60, .external_lex_state = 24},
  [13834] = {.lex_state = 60, .external_lex_state = 45},
  [13835] = {.lex_state = 60, .external_lex_state = 24},
  [13836] = {.lex_state = 60},
  [13837] = {.lex_state = 60},
  [13838] = {.lex_state = 60},
  [13839] = {.lex_state = 60, .external_lex_state = 40},
  [13840] = {.lex_state = 60, .external_lex_state = 69},
  [13841] = {.lex_state = 60, .external_lex_state = 57},
  [13842] = {.lex_state = 53, .external_lex_state = 23},
  [13843] = {.lex_state = 54, .external_lex_state = 43},
  [13844] = {.lex_state = 60},
  [13845] = {.lex_state = 60, .external_lex_state = 58},
  [13846] = {.lex_state = 54, .external_lex_state = 43},
  [13847] = {.lex_state = 60},
  [13848] = {.lex_state = 54, .external_lex_state = 43},
  [13849] = {.lex_state = 54, .external_lex_state = 43},
  [13850] = {.lex_state = 60, .external_lex_state = 48},
  [13851] = {.lex_state = 60},
  [13852] = {.lex_state = 60},
  [13853] = {.lex_state = 53, .external_lex_state = 24},
  [13854] = {.lex_state = 54, .external_lex_state = 43},
  [13855] = {.lex_state = 53, .external_lex_state = 24},
  [13856] = {.lex_state = 60, .external_lex_state = 35},
  [13857] = {.lex_state = 54, .external_lex_state = 43},
  [13858] = {.lex_state = 60, .external_lex_state = 48},
  [13859] = {.lex_state = 60, .external_lex_state = 35},
  [13860] = {.lex_state = 60, .external_lex_state = 24},
  [13861] = {.lex_state = 54, .external_lex_state = 66},
  [13862] = {.lex_state = 60, .external_lex_state = 39},
  [13863] = {.lex_state = 60, .external_lex_state = 45},
  [13864] = {.lex_state = 60, .external_lex_state = 35},
  [13865] = {.lex_state = 60, .external_lex_state = 23},
  [13866] = {.lex_state = 60, .external_lex_state = 45},
  [13867] = {.lex_state = 60},
  [13868] = {.lex_state = 60, .external_lex_state = 36},
  [13869] = {.lex_state = 60, .external_lex_state = 36},
  [13870] = {.lex_state = 60, .external_lex_state = 48},
  [13871] = {.lex_state = 60, .external_lex_state = 24},
  [13872] = {.lex_state = 60, .external_lex_state = 24},
  [13873] = {.lex_state = 60, .external_lex_state = 36},
  [13874] = {.lex_state = 60, .external_lex_state = 28},
  [13875] = {.lex_state = 60, .external_lex_state = 36},
  [13876] = {.lex_state = 60, .external_lex_state = 36},
  [13877] = {.lex_state = 54, .external_lex_state = 70},
  [13878] = {.lex_state = 54, .external_lex_state = 70},
  [13879] = {.lex_state = 53, .external_lex_state = 23},
  [13880] = {.lex_state = 54, .external_lex_state = 43},
  [13881] = {.lex_state = 54, .external_lex_state = 66},
  [13882] = {.lex_state = 54, .external_lex_state = 70},
  [13883] = {.lex_state = 60},
  [13884] = {.lex_state = 53, .external_lex_state = 23},
  [13885] = {.lex_state = 60, .external_lex_state = 28},
  [13886] = {.lex_state = 54, .external_lex_state = 70},
  [13887] = {.lex_state = 60, .external_lex_state = 28},
  [13888] = {.lex_state = 54, .external_lex_state = 43},
  [13889] = {.lex_state = 60, .external_lex_state = 53},
  [13890] = {.lex_state = 54, .external_lex_state = 43},
  [13891] = {.lex_state = 53, .external_lex_state = 23},
  [13892] = {.lex_state = 60, .external_lex_state = 48},
  [13893] = {.lex_state = 54, .external_lex_state = 66},
  [13894] = {.lex_state = 54, .external_lex_state = 66},
  [13895] = {.lex_state = 60, .external_lex_state = 36},
  [13896] = {.lex_state = 60, .external_lex_state = 23},
  [13897] = {.lex_state = 60},
  [13898] = {.lex_state = 60},
  [13899] = {.lex_state = 60, .external_lex_state = 45},
  [13900] = {.lex_state = 60, .external_lex_state = 56},
  [13901] = {.lex_state = 60},
  [13902] = {.lex_state = 60, .external_lex_state = 36},
  [13903] = {.lex_state = 60},
  [13904] = {.lex_state = 54, .external_lex_state = 24},
  [13905] = {.lex_state = 54, .external_lex_state = 43},
  [13906] = {.lex_state = 60, .external_lex_state = 69},
  [13907] = {.lex_state = 60, .external_lex_state = 39},
  [13908] = {.lex_state = 60, .external_lex_state = 37},
  [13909] = {.lex_state = 60, .external_lex_state = 37},
  [13910] = {.lex_state = 60, .external_lex_state = 57},
  [13911] = {.lex_state = 60, .external_lex_state = 57},
  [13912] = {.lex_state = 60, .external_lex_state = 35},
  [13913] = {.lex_state = 60, .external_lex_state = 35},
  [13914] = {.lex_state = 54, .external_lex_state = 66},
  [13915] = {.lex_state = 60, .external_lex_state = 24},
  [13916] = {.lex_state = 60, .external_lex_state = 28},
  [13917] = {.lex_state = 54, .external_lex_state = 43},
  [13918] = {.lex_state = 53, .external_lex_state = 23},
  [13919] = {.lex_state = 54, .external_lex_state = 43},
  [13920] = {.lex_state = 60, .external_lex_state = 37},
  [13921] = {.lex_state = 60, .external_lex_state = 37},
  [13922] = {.lex_state = 60, .external_lex_state = 57},
  [13923] = {.lex_state = 60, .external_lex_state = 57},
  [13924] = {.lex_state = 60},
  [13925] = {.lex_state = 60, .external_lex_state = 24},
  [13926] = {.lex_state = 60, .external_lex_state = 39},
  [13927] = {.lex_state = 60, .external_lex_state = 24},
  [13928] = {.lex_state = 53, .external_lex_state = 24},
  [13929] = {.lex_state = 54, .external_lex_state = 43},
  [13930] = {.lex_state = 60},
  [13931] = {.lex_state = 60, .external_lex_state = 57},
  [13932] = {.lex_state = 60, .external_lex_state = 24},
  [13933] = {.lex_state = 60, .external_lex_state = 40},
  [13934] = {.lex_state = 60, .external_lex_state = 23},
  [13935] = {.lex_state = 60, .external_lex_state = 23},
  [13936] = {.lex_state = 60, .external_lex_state = 35},
  [13937] = {.lex_state = 53, .external_lex_state = 23},
  [13938] = {.lex_state = 54, .external_lex_state = 43},
  [13939] = {.lex_state = 60, .external_lex_state = 36},
  [13940] = {.lex_state = 0, .external_lex_state = 23},
  [13941] = {.lex_state = 54, .external_lex_state = 67},
  [13942] = {.lex_state = 60, .external_lex_state = 45},
  [13943] = {.lex_state = 54, .external_lex_state = 66},
  [13944] = {.lex_state = 60, .external_lex_state = 35},
  [13945] = {.lex_state = 60},
  [13946] = {.lex_state = 60, .external_lex_state = 35},
  [13947] = {.lex_state = 53, .external_lex_state = 24},
  [13948] = {.lex_state = 54, .external_lex_state = 43},
  [13949] = {.lex_state = 60, .external_lex_state = 23},
  [13950] = {.lex_state = 54, .external_lex_state = 24},
  [13951] = {.lex_state = 60, .external_lex_state = 23},
  [13952] = {.lex_state = 60, .external_lex_state = 24},
  [13953] = {.lex_state = 60, .external_lex_state = 35},
  [13954] = {.lex_state = 60, .external_lex_state = 40},
  [13955] = {.lex_state = 53, .external_lex_state = 23},
  [13956] = {.lex_state = 54, .external_lex_state = 43},
  [13957] = {.lex_state = 60, .external_lex_state = 45},
  [13958] = {.lex_state = 60, .external_lex_state = 24},
  [13959] = {.lex_state = 53, .external_lex_state = 23},
  [13960] = {.lex_state = 60, .external_lex_state = 24},
  [13961] = {.lex_state = 53, .external_lex_state = 23},
  [13962] = {.lex_state = 60, .external_lex_state = 24},
  [13963] = {.lex_state = 60, .external_lex_state = 37},
  [13964] = {.lex_state = 60, .external_lex_state = 37},
  [13965] = {.lex_state = 60, .external_lex_state = 24},
  [13966] = {.lex_state = 60, .external_lex_state = 57},
  [13967] = {.lex_state = 60, .external_lex_state = 57},
  [13968] = {.lex_state = 0, .external_lex_state = 23},
  [13969] = {.lex_state = 60, .external_lex_state = 39},
  [13970] = {.lex_state = 60, .external_lex_state = 23},
  [13971] = {.lex_state = 60, .external_lex_state = 24},
  [13972] = {.lex_state = 60, .external_lex_state = 37},
  [13973] = {.lex_state = 60, .external_lex_state = 37},
  [13974] = {.lex_state = 60, .external_lex_state = 68},
  [13975] = {.lex_state = 60, .external_lex_state = 24},
  [13976] = {.lex_state = 60, .external_lex_state = 36},
  [13977] = {.lex_state = 60, .external_lex_state = 24},
  [13978] = {.lex_state = 60, .external_lex_state = 56},
  [13979] = {.lex_state = 60, .external_lex_state = 24},
  [13980] = {.lex_state = 60, .external_lex_state = 24},
  [13981] = {.lex_state = 60, .external_lex_state = 24},
  [13982] = {.lex_state = 53, .external_lex_state = 24},
  [13983] = {.lex_state = 60, .external_lex_state = 24},
  [13984] = {.lex_state = 60, .external_lex_state = 24},
  [13985] = {.lex_state = 60, .external_lex_state = 23},
  [13986] = {.lex_state = 54, .external_lex_state = 66},
  [13987] = {.lex_state = 60, .external_lex_state = 53},
  [13988] = {.lex_state = 60, .external_lex_state = 69},
  [13989] = {.lex_state = 53, .external_lex_state = 23},
  [13990] = {.lex_state = 60},
  [13991] = {.lex_state = 60, .external_lex_state = 24},
  [13992] = {.lex_state = 0, .external_lex_state = 23},
  [13993] = {.lex_state = 53, .external_lex_state = 24},
  [13994] = {.lex_state = 60, .external_lex_state = 68},
  [13995] = {.lex_state = 60, .external_lex_state = 35},
  [13996] = {.lex_state = 60, .external_lex_state = 53},
  [13997] = {.lex_state = 60},
  [13998] = {.lex_state = 60, .external_lex_state = 24},
  [13999] = {.lex_state = 60, .external_lex_state = 24},
  [14000] = {.lex_state = 60, .external_lex_state = 24},
  [14001] = {.lex_state = 60, .external_lex_state = 24},
  [14002] = {.lex_state = 60, .external_lex_state = 23},
  [14003] = {.lex_state = 60, .external_lex_state = 24},
  [14004] = {.lex_state = 60, .external_lex_state = 24},
  [14005] = {.lex_state = 60, .external_lex_state = 68},
  [14006] = {.lex_state = 54, .external_lex_state = 43},
  [14007] = {.lex_state = 60, .external_lex_state = 36},
  [14008] = {.lex_state = 60},
  [14009] = {.lex_state = 60, .external_lex_state = 39},
  [14010] = {.lex_state = 53, .external_lex_state = 24},
  [14011] = {.lex_state = 60, .external_lex_state = 23},
  [14012] = {.lex_state = 60, .external_lex_state = 24},
  [14013] = {.lex_state = 53, .external_lex_state = 23},
  [14014] = {.lex_state = 60, .external_lex_state = 24},
  [14015] = {.lex_state = 60},
  [14016] = {.lex_state = 60, .external_lex_state = 23},
  [14017] = {.lex_state = 60, .external_lex_state = 40},
  [14018] = {.lex_state = 60, .external_lex_state = 39},
  [14019] = {.lex_state = 60, .external_lex_state = 39},
  [14020] = {.lex_state = 54, .external_lex_state = 66},
  [14021] = {.lex_state = 54, .external_lex_state = 71},
  [14022] = {.lex_state = 60, .external_lex_state = 35},
  [14023] = {.lex_state = 54, .external_lex_state = 66},
  [14024] = {.lex_state = 54, .external_lex_state = 66},
  [14025] = {.lex_state = 60, .external_lex_state = 23},
  [14026] = {.lex_state = 60, .external_lex_state = 40},
  [14027] = {.lex_state = 60},
  [14028] = {.lex_state = 60, .external_lex_state = 35},
  [14029] = {.lex_state = 60, .external_lex_state = 45},
  [14030] = {.lex_state = 60, .external_lex_state = 23},
  [14031] = {.lex_state = 54, .external_lex_state = 66},
  [14032] = {.lex_state = 60, .external_lex_state = 53},
  [14033] = {.lex_state = 60, .external_lex_state = 40},
  [14034] = {.lex_state = 60},
  [14035] = {.lex_state = 60},
  [14036] = {.lex_state = 60},
  [14037] = {.lex_state = 54, .external_lex_state = 66},
  [14038] = {.lex_state = 0, .external_lex_state = 24},
  [14039] = {.lex_state = 60, .external_lex_state = 40},
  [14040] = {.lex_state = 53, .external_lex_state = 23},
  [14041] = {.lex_state = 60, .external_lex_state = 24},
  [14042] = {.lex_state = 0, .external_lex_state = 23},
  [14043] = {.lex_state = 60, .external_lex_state = 23},
  [14044] = {.lex_state = 60, .external_lex_state = 53},
  [14045] = {.lex_state = 0},
  [14046] = {.lex_state = 60, .external_lex_state = 23},
  [14047] = {.lex_state = 53, .external_lex_state = 24},
  [14048] = {.lex_state = 54, .external_lex_state = 66},
  [14049] = {.lex_state = 60},
  [14050] = {.lex_state = 60, .external_lex_state = 23},
  [14051] = {.lex_state = 60, .external_lex_state = 53},
  [14052] = {.lex_state = 60, .external_lex_state = 53},
  [14053] = {.lex_state = 60},
  [14054] = {.lex_state = 60, .external_lex_state = 53},
  [14055] = {.lex_state = 60, .external_lex_state = 35},
  [14056] = {.lex_state = 6},
  [14057] = {.lex_state = 54, .external_lex_state = 66},
  [14058] = {.lex_state = 0, .external_lex_state = 23},
  [14059] = {.lex_state = 53, .external_lex_state = 23},
  [14060] = {.lex_state = 60, .external_lex_state = 53},
  [14061] = {.lex_state = 54},
  [14062] = {.lex_state = 60},
  [14063] = {.lex_state = 53, .external_lex_state = 23},
  [14064] = {.lex_state = 53, .external_lex_state = 23},
  [14065] = {.lex_state = 60, .external_lex_state = 24},
  [14066] = {.lex_state = 53, .external_lex_state = 23},
  [14067] = {.lex_state = 0, .external_lex_state = 23},
  [14068] = {.lex_state = 60, .external_lex_state = 23},
  [14069] = {.lex_state = 60},
  [14070] = {.lex_state = 53, .external_lex_state = 23},
  [14071] = {.lex_state = 60},
  [14072] = {.lex_state = 54},
  [14073] = {.lex_state = 60},
  [14074] = {.lex_state = 60},
  [14075] = {.lex_state = 0, .external_lex_state = 23},
  [14076] = {.lex_state = 60, .external_lex_state = 35},
  [14077] = {.lex_state = 60, .external_lex_state = 53},
  [14078] = {.lex_state = 54, .external_lex_state = 66},
  [14079] = {.lex_state = 60, .external_lex_state = 24},
  [14080] = {.lex_state = 6},
  [14081] = {.lex_state = 60, .external_lex_state = 40},
  [14082] = {.lex_state = 60, .external_lex_state = 40},
  [14083] = {.lex_state = 60, .external_lex_state = 35},
  [14084] = {.lex_state = 60, .external_lex_state = 53},
  [14085] = {.lex_state = 54},
  [14086] = {.lex_state = 60},
  [14087] = {.lex_state = 54, .external_lex_state = 71},
  [14088] = {.lex_state = 60},
  [14089] = {.lex_state = 60},
  [14090] = {.lex_state = 60, .external_lex_state = 40},
  [14091] = {.lex_state = 60, .external_lex_state = 35},
  [14092] = {.lex_state = 60, .external_lex_state = 40},
  [14093] = {.lex_state = 60, .external_lex_state = 39},
  [14094] = {.lex_state = 60, .external_lex_state = 39},
  [14095] = {.lex_state = 60, .external_lex_state = 39},
  [14096] = {.lex_state = 60, .external_lex_state = 40},
  [14097] = {.lex_state = 60, .external_lex_state = 24},
  [14098] = {.lex_state = 60},
  [14099] = {.lex_state = 53, .external_lex_state = 24},
  [14100] = {.lex_state = 0, .external_lex_state = 23},
  [14101] = {.lex_state = 60},
  [14102] = {.lex_state = 54, .external_lex_state = 66},
  [14103] = {.lex_state = 60},
  [14104] = {.lex_state = 60, .external_lex_state = 23},
  [14105] = {.lex_state = 60, .external_lex_state = 57},
  [14106] = {.lex_state = 60, .external_lex_state = 53},
  [14107] = {.lex_state = 60, .external_lex_state = 23},
  [14108] = {.lex_state = 60},
  [14109] = {.lex_state = 60},
  [14110] = {.lex_state = 60, .external_lex_state = 53},
  [14111] = {.lex_state = 60},
  [14112] = {.lex_state = 54},
  [14113] = {.lex_state = 60, .external_lex_state = 24},
  [14114] = {.lex_state = 60, .external_lex_state = 69},
  [14115] = {.lex_state = 0, .external_lex_state = 24},
  [14116] = {.lex_state = 54, .external_lex_state = 66},
  [14117] = {.lex_state = 60, .external_lex_state = 57},
  [14118] = {.lex_state = 0, .external_lex_state = 23},
  [14119] = {.lex_state = 0, .external_lex_state = 23},
  [14120] = {.lex_state = 60, .external_lex_state = 23},
  [14121] = {.lex_state = 53, .external_lex_state = 24},
  [14122] = {.lex_state = 54, .external_lex_state = 66},
  [14123] = {.lex_state = 60, .external_lex_state = 45},
  [14124] = {.lex_state = 53, .external_lex_state = 24},
  [14125] = {.lex_state = 60},
  [14126] = {.lex_state = 0, .external_lex_state = 23},
  [14127] = {.lex_state = 60, .external_lex_state = 53},
  [14128] = {.lex_state = 60, .external_lex_state = 23},
  [14129] = {.lex_state = 0, .external_lex_state = 23},
  [14130] = {.lex_state = 60, .external_lex_state = 40},
  [14131] = {.lex_state = 60, .external_lex_state = 23},
  [14132] = {.lex_state = 60},
  [14133] = {.lex_state = 60, .external_lex_state = 53},
  [14134] = {.lex_state = 0, .external_lex_state = 24},
  [14135] = {.lex_state = 53, .external_lex_state = 23},
  [14136] = {.lex_state = 0, .external_lex_state = 24},
  [14137] = {.lex_state = 60, .external_lex_state = 23},
  [14138] = {.lex_state = 0, .external_lex_state = 23},
  [14139] = {.lex_state = 60, .external_lex_state = 40},
  [14140] = {.lex_state = 60, .external_lex_state = 23},
  [14141] = {.lex_state = 54, .external_lex_state = 66},
  [14142] = {.lex_state = 60, .external_lex_state = 24},
  [14143] = {.lex_state = 60},
  [14144] = {.lex_state = 60, .external_lex_state = 24},
  [14145] = {.lex_state = 60},
  [14146] = {.lex_state = 60, .external_lex_state = 23},
  [14147] = {.lex_state = 60, .external_lex_state = 23},
  [14148] = {.lex_state = 53, .external_lex_state = 23},
  [14149] = {.lex_state = 60},
  [14150] = {.lex_state = 60},
  [14151] = {.lex_state = 60, .external_lex_state = 68},
  [14152] = {.lex_state = 60, .external_lex_state = 23},
  [14153] = {.lex_state = 53, .external_lex_state = 23},
  [14154] = {.lex_state = 60, .external_lex_state = 23},
  [14155] = {.lex_state = 54, .external_lex_state = 71},
  [14156] = {.lex_state = 54, .external_lex_state = 66},
  [14157] = {.lex_state = 54, .external_lex_state = 66},
  [14158] = {.lex_state = 54, .external_lex_state = 66},
  [14159] = {.lex_state = 60},
  [14160] = {.lex_state = 60, .external_lex_state = 40},
  [14161] = {.lex_state = 53, .external_lex_state = 23},
  [14162] = {.lex_state = 53, .external_lex_state = 23},
  [14163] = {.lex_state = 60, .external_lex_state = 39},
  [14164] = {.lex_state = 60, .external_lex_state = 39},
  [14165] = {.lex_state = 60, .external_lex_state = 68},
  [14166] = {.lex_state = 0},
  [14167] = {.lex_state = 60, .external_lex_state = 23},
  [14168] = {.lex_state = 0},
  [14169] = {.lex_state = 0},
  [14170] = {.lex_state = 60, .external_lex_state = 69},
  [14171] = {.lex_state = 0, .external_lex_state = 24},
  [14172] = {.lex_state = 0},
  [14173] = {.lex_state = 60, .external_lex_state = 69},
  [14174] = {.lex_state = 0},
  [14175] = {.lex_state = 0},
  [14176] = {.lex_state = 54, .external_lex_state = 71},
  [14177] = {.lex_state = 0},
  [14178] = {.lex_state = 60, .external_lex_state = 24},
  [14179] = {.lex_state = 60, .external_lex_state = 69},
  [14180] = {.lex_state = 0},
  [14181] = {.lex_state = 60, .external_lex_state = 23},
  [14182] = {.lex_state = 60, .external_lex_state = 23},
  [14183] = {.lex_state = 0},
  [14184] = {.lex_state = 54, .external_lex_state = 43},
  [14185] = {.lex_state = 54, .external_lex_state = 71},
  [14186] = {.lex_state = 0},
  [14187] = {.lex_state = 53, .external_lex_state = 24},
  [14188] = {.lex_state = 60, .external_lex_state = 23},
  [14189] = {.lex_state = 60},
  [14190] = {.lex_state = 0},
  [14191] = {.lex_state = 0},
  [14192] = {.lex_state = 0},
  [14193] = {.lex_state = 54, .external_lex_state = 71},
  [14194] = {.lex_state = 60, .external_lex_state = 23},
  [14195] = {.lex_state = 60, .external_lex_state = 23},
  [14196] = {.lex_state = 60, .external_lex_state = 69},
  [14197] = {.lex_state = 60},
  [14198] = {.lex_state = 0},
  [14199] = {.lex_state = 60, .external_lex_state = 68},
  [14200] = {.lex_state = 0},
  [14201] = {.lex_state = 0},
  [14202] = {.lex_state = 0, .external_lex_state = 23},
  [14203] = {.lex_state = 54, .external_lex_state = 24},
  [14204] = {.lex_state = 0},
  [14205] = {.lex_state = 0},
  [14206] = {.lex_state = 60, .external_lex_state = 23},
  [14207] = {.lex_state = 53, .external_lex_state = 23},
  [14208] = {.lex_state = 0},
  [14209] = {.lex_state = 0, .external_lex_state = 23},
  [14210] = {.lex_state = 53, .external_lex_state = 24},
  [14211] = {.lex_state = 0},
  [14212] = {.lex_state = 54, .external_lex_state = 71},
  [14213] = {.lex_state = 54, .external_lex_state = 66},
  [14214] = {.lex_state = 60, .external_lex_state = 56},
  [14215] = {.lex_state = 0},
  [14216] = {.lex_state = 60, .external_lex_state = 23},
  [14217] = {.lex_state = 54, .external_lex_state = 71},
  [14218] = {.lex_state = 60, .external_lex_state = 23},
  [14219] = {.lex_state = 0},
  [14220] = {.lex_state = 60, .external_lex_state = 69},
  [14221] = {.lex_state = 0},
  [14222] = {.lex_state = 0, .external_lex_state = 24},
  [14223] = {.lex_state = 0},
  [14224] = {.lex_state = 53, .external_lex_state = 23},
  [14225] = {.lex_state = 60, .external_lex_state = 23},
  [14226] = {.lex_state = 60, .external_lex_state = 23},
  [14227] = {.lex_state = 0},
  [14228] = {.lex_state = 0},
  [14229] = {.lex_state = 60, .external_lex_state = 56},
  [14230] = {.lex_state = 53, .external_lex_state = 24},
  [14231] = {.lex_state = 54, .external_lex_state = 71},
  [14232] = {.lex_state = 54, .external_lex_state = 71},
  [14233] = {.lex_state = 0},
  [14234] = {.lex_state = 0, .external_lex_state = 24},
  [14235] = {.lex_state = 0},
  [14236] = {.lex_state = 60, .external_lex_state = 23},
  [14237] = {.lex_state = 60, .external_lex_state = 68},
  [14238] = {.lex_state = 53, .external_lex_state = 23},
  [14239] = {.lex_state = 60, .external_lex_state = 23},
  [14240] = {.lex_state = 54, .external_lex_state = 71},
  [14241] = {.lex_state = 60, .external_lex_state = 23},
  [14242] = {.lex_state = 53, .external_lex_state = 24},
  [14243] = {.lex_state = 54},
  [14244] = {.lex_state = 0},
  [14245] = {.lex_state = 60, .external_lex_state = 24},
  [14246] = {.lex_state = 0},
  [14247] = {.lex_state = 60, .external_lex_state = 23},
  [14248] = {.lex_state = 60, .external_lex_state = 23},
  [14249] = {.lex_state = 53, .external_lex_state = 23},
  [14250] = {.lex_state = 54, .external_lex_state = 43},
  [14251] = {.lex_state = 54, .external_lex_state = 43},
  [14252] = {.lex_state = 54, .external_lex_state = 71},
  [14253] = {.lex_state = 54, .external_lex_state = 71},
  [14254] = {.lex_state = 60},
  [14255] = {.lex_state = 0, .external_lex_state = 23},
  [14256] = {.lex_state = 60, .external_lex_state = 24},
  [14257] = {.lex_state = 0},
  [14258] = {.lex_state = 54, .external_lex_state = 71},
  [14259] = {.lex_state = 60, .external_lex_state = 24},
  [14260] = {.lex_state = 60, .external_lex_state = 48},
  [14261] = {.lex_state = 60, .external_lex_state = 23},
  [14262] = {.lex_state = 60, .external_lex_state = 48},
  [14263] = {.lex_state = 60, .external_lex_state = 23},
  [14264] = {.lex_state = 0},
  [14265] = {.lex_state = 60, .external_lex_state = 23},
  [14266] = {.lex_state = 0},
  [14267] = {.lex_state = 60, .external_lex_state = 23},
  [14268] = {.lex_state = 60, .external_lex_state = 23},
  [14269] = {.lex_state = 54, .external_lex_state = 71},
  [14270] = {.lex_state = 60, .external_lex_state = 56},
  [14271] = {.lex_state = 0, .external_lex_state = 24},
  [14272] = {.lex_state = 60, .external_lex_state = 23},
  [14273] = {.lex_state = 0, .external_lex_state = 24},
  [14274] = {.lex_state = 60, .external_lex_state = 23},
  [14275] = {.lex_state = 60, .external_lex_state = 24},
  [14276] = {.lex_state = 60, .external_lex_state = 23},
  [14277] = {.lex_state = 60, .external_lex_state = 23},
  [14278] = {.lex_state = 60, .external_lex_state = 23},
  [14279] = {.lex_state = 0},
  [14280] = {.lex_state = 0},
  [14281] = {.lex_state = 60, .external_lex_state = 68},
  [14282] = {.lex_state = 54, .external_lex_state = 71},
  [14283] = {.lex_state = 60, .external_lex_state = 69},
  [14284] = {.lex_state = 60, .external_lex_state = 48},
  [14285] = {.lex_state = 60, .external_lex_state = 48},
  [14286] = {.lex_state = 60, .external_lex_state = 23},
  [14287] = {.lex_state = 60, .external_lex_state = 24},
  [14288] = {.lex_state = 0},
  [14289] = {.lex_state = 60, .external_lex_state = 23},
  [14290] = {.lex_state = 54, .external_lex_state = 71},
  [14291] = {.lex_state = 60, .external_lex_state = 23},
  [14292] = {.lex_state = 0},
  [14293] = {.lex_state = 60, .external_lex_state = 23},
  [14294] = {.lex_state = 60, .external_lex_state = 23},
  [14295] = {.lex_state = 60, .external_lex_state = 23},
  [14296] = {.lex_state = 60, .external_lex_state = 23},
  [14297] = {.lex_state = 60},
  [14298] = {.lex_state = 60, .external_lex_state = 23},
  [14299] = {.lex_state = 0},
  [14300] = {.lex_state = 60, .external_lex_state = 68},
  [14301] = {.lex_state = 60, .external_lex_state = 23},
  [14302] = {.lex_state = 60, .external_lex_state = 23},
  [14303] = {.lex_state = 60, .external_lex_state = 23},
  [14304] = {.lex_state = 0},
  [14305] = {.lex_state = 0},
  [14306] = {.lex_state = 0},
  [14307] = {.lex_state = 0},
  [14308] = {.lex_state = 60, .external_lex_state = 24},
  [14309] = {.lex_state = 60, .external_lex_state = 24},
  [14310] = {.lex_state = 0},
  [14311] = {.lex_state = 60, .external_lex_state = 23},
  [14312] = {.lex_state = 60},
  [14313] = {.lex_state = 60, .external_lex_state = 23},
  [14314] = {.lex_state = 60},
  [14315] = {.lex_state = 0, .external_lex_state = 23},
  [14316] = {.lex_state = 0},
  [14317] = {.lex_state = 0},
  [14318] = {.lex_state = 0},
  [14319] = {.lex_state = 60},
  [14320] = {.lex_state = 60, .external_lex_state = 23},
  [14321] = {.lex_state = 60, .external_lex_state = 24},
  [14322] = {.lex_state = 60, .external_lex_state = 23},
  [14323] = {.lex_state = 0, .external_lex_state = 23},
  [14324] = {.lex_state = 0},
  [14325] = {.lex_state = 60, .external_lex_state = 23},
  [14326] = {.lex_state = 60, .external_lex_state = 23},
  [14327] = {.lex_state = 60, .external_lex_state = 23},
  [14328] = {.lex_state = 60, .external_lex_state = 23},
  [14329] = {.lex_state = 60, .external_lex_state = 23},
  [14330] = {.lex_state = 60, .external_lex_state = 23},
  [14331] = {.lex_state = 60, .external_lex_state = 23},
  [14332] = {.lex_state = 60, .external_lex_state = 23},
  [14333] = {.lex_state = 60, .external_lex_state = 24},
  [14334] = {.lex_state = 60, .external_lex_state = 23},
  [14335] = {.lex_state = 0},
  [14336] = {.lex_state = 53, .external_lex_state = 24},
  [14337] = {.lex_state = 60, .external_lex_state = 48},
  [14338] = {.lex_state = 60, .external_lex_state = 48},
  [14339] = {.lex_state = 60, .external_lex_state = 23},
  [14340] = {.lex_state = 60, .external_lex_state = 23},
  [14341] = {.lex_state = 60, .external_lex_state = 69},
  [14342] = {.lex_state = 0},
  [14343] = {.lex_state = 60, .external_lex_state = 23},
  [14344] = {.lex_state = 60},
  [14345] = {.lex_state = 60},
  [14346] = {.lex_state = 60, .external_lex_state = 48},
  [14347] = {.lex_state = 60, .external_lex_state = 48},
  [14348] = {.lex_state = 60, .external_lex_state = 23},
  [14349] = {.lex_state = 0},
  [14350] = {.lex_state = 0, .external_lex_state = 23},
  [14351] = {.lex_state = 0},
  [14352] = {.lex_state = 53, .external_lex_state = 24},
  [14353] = {.lex_state = 54, .external_lex_state = 71},
  [14354] = {.lex_state = 60, .external_lex_state = 23},
  [14355] = {.lex_state = 0},
  [14356] = {.lex_state = 54, .external_lex_state = 71},
  [14357] = {.lex_state = 0},
  [14358] = {.lex_state = 60, .external_lex_state = 23},
  [14359] = {.lex_state = 60, .external_lex_state = 23},
  [14360] = {.lex_state = 60, .external_lex_state = 23},
  [14361] = {.lex_state = 60, .external_lex_state = 23},
  [14362] = {.lex_state = 0},
  [14363] = {.lex_state = 60, .external_lex_state = 23},
  [14364] = {.lex_state = 60, .external_lex_state = 23},
  [14365] = {.lex_state = 0},
  [14366] = {.lex_state = 60, .external_lex_state = 23},
  [14367] = {.lex_state = 53, .external_lex_state = 24},
  [14368] = {.lex_state = 60, .external_lex_state = 23},
  [14369] = {.lex_state = 0},
  [14370] = {.lex_state = 0},
  [14371] = {.lex_state = 0},
  [14372] = {.lex_state = 0, .external_lex_state = 23},
  [14373] = {.lex_state = 53, .external_lex_state = 24},
  [14374] = {.lex_state = 60, .external_lex_state = 23},
  [14375] = {.lex_state = 60, .external_lex_state = 23},
  [14376] = {.lex_state = 60, .external_lex_state = 23},
  [14377] = {.lex_state = 60, .external_lex_state = 23},
  [14378] = {.lex_state = 60},
  [14379] = {.lex_state = 60, .external_lex_state = 23},
  [14380] = {.lex_state = 60, .external_lex_state = 23},
  [14381] = {.lex_state = 60, .external_lex_state = 68},
  [14382] = {.lex_state = 0},
  [14383] = {.lex_state = 54, .external_lex_state = 71},
  [14384] = {.lex_state = 54, .external_lex_state = 71},
  [14385] = {.lex_state = 60, .external_lex_state = 23},
  [14386] = {.lex_state = 0},
  [14387] = {.lex_state = 54},
  [14388] = {.lex_state = 0},
  [14389] = {.lex_state = 60},
  [14390] = {.lex_state = 0, .external_lex_state = 24},
  [14391] = {.lex_state = 54, .external_lex_state = 71},
  [14392] = {.lex_state = 54, .external_lex_state = 71},
  [14393] = {.lex_state = 60, .external_lex_state = 23},
  [14394] = {.lex_state = 0},
  [14395] = {.lex_state = 60, .external_lex_state = 23},
  [14396] = {.lex_state = 0},
  [14397] = {.lex_state = 60, .external_lex_state = 23},
  [14398] = {.lex_state = 0},
  [14399] = {.lex_state = 0},
  [14400] = {.lex_state = 60, .external_lex_state = 23},
  [14401] = {.lex_state = 60, .external_lex_state = 24},
  [14402] = {.lex_state = 54, .external_lex_state = 43},
  [14403] = {.lex_state = 54, .external_lex_state = 43},
  [14404] = {.lex_state = 0, .external_lex_state = 23},
  [14405] = {.lex_state = 60, .external_lex_state = 23},
  [14406] = {.lex_state = 54, .external_lex_state = 43},
  [14407] = {.lex_state = 0},
  [14408] = {.lex_state = 0, .external_lex_state = 23},
  [14409] = {.lex_state = 53, .external_lex_state = 24},
  [14410] = {.lex_state = 60, .external_lex_state = 56},
  [14411] = {.lex_state = 0},
  [14412] = {.lex_state = 0},
  [14413] = {.lex_state = 0},
  [14414] = {.lex_state = 60, .external_lex_state = 68},
  [14415] = {.lex_state = 0},
  [14416] = {.lex_state = 60},
  [14417] = {.lex_state = 0},
  [14418] = {.lex_state = 0, .external_lex_state = 25},
  [14419] = {.lex_state = 53},
  [14420] = {.lex_state = 0, .external_lex_state = 24},
  [14421] = {.lex_state = 60, .external_lex_state = 64},
  [14422] = {.lex_state = 60, .external_lex_state = 64},
  [14423] = {.lex_state = 0},
  [14424] = {.lex_state = 0, .external_lex_state = 23},
  [14425] = {.lex_state = 60},
  [14426] = {.lex_state = 0, .external_lex_state = 23},
  [14427] = {.lex_state = 60},
  [14428] = {.lex_state = 60, .external_lex_state = 64},
  [14429] = {.lex_state = 60, .external_lex_state = 24},
  [14430] = {.lex_state = 0},
  [14431] = {.lex_state = 60, .external_lex_state = 24},
  [14432] = {.lex_state = 60},
  [14433] = {.lex_state = 0, .external_lex_state = 25},
  [14434] = {.lex_state = 60, .external_lex_state = 64},
  [14435] = {.lex_state = 60},
  [14436] = {.lex_state = 60, .external_lex_state = 64},
  [14437] = {.lex_state = 0, .external_lex_state = 25},
  [14438] = {.lex_state = 60, .external_lex_state = 24},
  [14439] = {.lex_state = 60, .external_lex_state = 64},
  [14440] = {.lex_state = 0, .external_lex_state = 25},
  [14441] = {.lex_state = 60, .external_lex_state = 64},
  [14442] = {.lex_state = 60, .external_lex_state = 24},
  [14443] = {.lex_state = 60, .external_lex_state = 24},
  [14444] = {.lex_state = 60, .external_lex_state = 24},
  [14445] = {.lex_state = 60, .external_lex_state = 64},
  [14446] = {.lex_state = 60},
  [14447] = {.lex_state = 60, .external_lex_state = 24},
  [14448] = {.lex_state = 60, .external_lex_state = 24},
  [14449] = {.lex_state = 60},
  [14450] = {.lex_state = 60},
  [14451] = {.lex_state = 0, .external_lex_state = 24},
  [14452] = {.lex_state = 60, .external_lex_state = 64},
  [14453] = {.lex_state = 0, .external_lex_state = 25},
  [14454] = {.lex_state = 53, .external_lex_state = 23},
  [14455] = {.lex_state = 60, .external_lex_state = 24},
  [14456] = {.lex_state = 60, .external_lex_state = 24},
  [14457] = {.lex_state = 60, .external_lex_state = 64},
  [14458] = {.lex_state = 0, .external_lex_state = 23},
  [14459] = {.lex_state = 60, .external_lex_state = 24},
  [14460] = {.lex_state = 60},
  [14461] = {.lex_state = 60, .external_lex_state = 64},
  [14462] = {.lex_state = 60, .external_lex_state = 64},
  [14463] = {.lex_state = 0, .external_lex_state = 23},
  [14464] = {.lex_state = 60, .external_lex_state = 64},
  [14465] = {.lex_state = 0},
  [14466] = {.lex_state = 60, .external_lex_state = 64},
  [14467] = {.lex_state = 60, .external_lex_state = 64},
  [14468] = {.lex_state = 60},
  [14469] = {.lex_state = 0},
  [14470] = {.lex_state = 60, .external_lex_state = 24},
  [14471] = {.lex_state = 53, .external_lex_state = 23},
  [14472] = {.lex_state = 60, .external_lex_state = 64},
  [14473] = {.lex_state = 60, .external_lex_state = 24},
  [14474] = {.lex_state = 60},
  [14475] = {.lex_state = 0, .external_lex_state = 25},
  [14476] = {.lex_state = 0, .external_lex_state = 23},
  [14477] = {.lex_state = 60},
  [14478] = {.lex_state = 60, .external_lex_state = 24},
  [14479] = {.lex_state = 60},
  [14480] = {.lex_state = 60},
  [14481] = {.lex_state = 0, .external_lex_state = 24},
  [14482] = {.lex_state = 0, .external_lex_state = 23},
  [14483] = {.lex_state = 0, .external_lex_state = 23},
  [14484] = {.lex_state = 60},
  [14485] = {.lex_state = 60},
  [14486] = {.lex_state = 0, .external_lex_state = 25},
  [14487] = {.lex_state = 60, .external_lex_state = 24},
  [14488] = {.lex_state = 0, .external_lex_state = 25},
  [14489] = {.lex_state = 0, .external_lex_state = 23},
  [14490] = {.lex_state = 0, .external_lex_state = 24},
  [14491] = {.lex_state = 60},
  [14492] = {.lex_state = 54, .external_lex_state = 43},
  [14493] = {.lex_state = 60},
  [14494] = {.lex_state = 53, .external_lex_state = 23},
  [14495] = {.lex_state = 0, .external_lex_state = 25},
  [14496] = {.lex_state = 60, .external_lex_state = 24},
  [14497] = {.lex_state = 60},
  [14498] = {.lex_state = 60},
  [14499] = {.lex_state = 60, .external_lex_state = 24},
  [14500] = {.lex_state = 60},
  [14501] = {.lex_state = 53},
  [14502] = {.lex_state = 60, .external_lex_state = 24},
  [14503] = {.lex_state = 60, .external_lex_state = 24},
  [14504] = {.lex_state = 60, .external_lex_state = 24},
  [14505] = {.lex_state = 60, .external_lex_state = 24},
  [14506] = {.lex_state = 0, .external_lex_state = 25},
  [14507] = {.lex_state = 60},
  [14508] = {.lex_state = 53},
  [14509] = {.lex_state = 53},
  [14510] = {.lex_state = 0, .external_lex_state = 25},
  [14511] = {.lex_state = 60, .external_lex_state = 24},
  [14512] = {.lex_state = 60, .external_lex_state = 24},
  [14513] = {.lex_state = 60, .external_lex_state = 64},
  [14514] = {.lex_state = 0, .external_lex_state = 25},
  [14515] = {.lex_state = 0},
  [14516] = {.lex_state = 0, .external_lex_state = 24},
  [14517] = {.lex_state = 60, .external_lex_state = 23},
  [14518] = {.lex_state = 60, .external_lex_state = 24},
  [14519] = {.lex_state = 60, .external_lex_state = 64},
  [14520] = {.lex_state = 0, .external_lex_state = 24},
  [14521] = {.lex_state = 60, .external_lex_state = 64},
  [14522] = {.lex_state = 60},
  [14523] = {.lex_state = 60},
  [14524] = {.lex_state = 0, .external_lex_state = 23},
  [14525] = {.lex_state = 0, .external_lex_state = 25},
  [14526] = {.lex_state = 0, .external_lex_state = 25},
  [14527] = {.lex_state = 60, .external_lex_state = 64},
  [14528] = {.lex_state = 60, .external_lex_state = 24},
  [14529] = {.lex_state = 60, .external_lex_state = 64},
  [14530] = {.lex_state = 60},
  [14531] = {.lex_state = 0, .external_lex_state = 25},
  [14532] = {.lex_state = 60},
  [14533] = {.lex_state = 60, .external_lex_state = 24},
  [14534] = {.lex_state = 60},
  [14535] = {.lex_state = 0, .external_lex_state = 25},
  [14536] = {.lex_state = 60},
  [14537] = {.lex_state = 60},
  [14538] = {.lex_state = 0},
  [14539] = {.lex_state = 60, .external_lex_state = 64},
  [14540] = {.lex_state = 60},
  [14541] = {.lex_state = 0, .external_lex_state = 24},
  [14542] = {.lex_state = 60, .external_lex_state = 24},
  [14543] = {.lex_state = 53},
  [14544] = {.lex_state = 53, .external_lex_state = 23},
  [14545] = {.lex_state = 60, .external_lex_state = 24},
  [14546] = {.lex_state = 0},
  [14547] = {.lex_state = 60},
  [14548] = {.lex_state = 0, .external_lex_state = 25},
  [14549] = {.lex_state = 60},
  [14550] = {.lex_state = 60},
  [14551] = {.lex_state = 0, .external_lex_state = 23},
  [14552] = {.lex_state = 0},
  [14553] = {.lex_state = 60, .external_lex_state = 24},
  [14554] = {.lex_state = 60, .external_lex_state = 64},
  [14555] = {.lex_state = 60, .external_lex_state = 24},
  [14556] = {.lex_state = 60},
  [14557] = {.lex_state = 60, .external_lex_state = 64},
  [14558] = {.lex_state = 60, .external_lex_state = 24},
  [14559] = {.lex_state = 53},
  [14560] = {.lex_state = 60, .external_lex_state = 64},
  [14561] = {.lex_state = 60, .external_lex_state = 64},
  [14562] = {.lex_state = 0, .external_lex_state = 24},
  [14563] = {.lex_state = 60, .external_lex_state = 24},
  [14564] = {.lex_state = 0, .external_lex_state = 25},
  [14565] = {.lex_state = 60},
  [14566] = {.lex_state = 60, .external_lex_state = 64},
  [14567] = {.lex_state = 60, .external_lex_state = 64},
  [14568] = {.lex_state = 60, .external_lex_state = 24},
  [14569] = {.lex_state = 60, .external_lex_state = 64},
  [14570] = {.lex_state = 60},
  [14571] = {.lex_state = 60},
  [14572] = {.lex_state = 60},
  [14573] = {.lex_state = 60},
  [14574] = {.lex_state = 0},
  [14575] = {.lex_state = 60},
  [14576] = {.lex_state = 0},
  [14577] = {.lex_state = 0, .external_lex_state = 25},
  [14578] = {.lex_state = 60, .external_lex_state = 64},
  [14579] = {.lex_state = 60},
  [14580] = {.lex_state = 0, .external_lex_state = 25},
  [14581] = {.lex_state = 60},
  [14582] = {.lex_state = 60},
  [14583] = {.lex_state = 60},
  [14584] = {.lex_state = 60},
  [14585] = {.lex_state = 0, .external_lex_state = 25},
  [14586] = {.lex_state = 60},
  [14587] = {.lex_state = 60, .external_lex_state = 64},
  [14588] = {.lex_state = 60},
  [14589] = {.lex_state = 60, .external_lex_state = 64},
  [14590] = {.lex_state = 60, .external_lex_state = 24},
  [14591] = {.lex_state = 60},
  [14592] = {.lex_state = 60},
  [14593] = {.lex_state = 60, .external_lex_state = 64},
  [14594] = {.lex_state = 60, .external_lex_state = 24},
  [14595] = {.lex_state = 0, .external_lex_state = 25},
  [14596] = {.lex_state = 53},
  [14597] = {.lex_state = 60, .external_lex_state = 24},
  [14598] = {.lex_state = 60, .external_lex_state = 24},
  [14599] = {.lex_state = 60, .external_lex_state = 24},
  [14600] = {.lex_state = 60, .external_lex_state = 24},
  [14601] = {.lex_state = 0, .external_lex_state = 24},
  [14602] = {.lex_state = 60, .external_lex_state = 24},
  [14603] = {.lex_state = 0},
  [14604] = {.lex_state = 60, .external_lex_state = 24},
  [14605] = {.lex_state = 60, .external_lex_state = 64},
  [14606] = {.lex_state = 60},
  [14607] = {.lex_state = 60, .external_lex_state = 64},
  [14608] = {.lex_state = 60, .external_lex_state = 24},
  [14609] = {.lex_state = 60},
  [14610] = {.lex_state = 60, .external_lex_state = 24},
  [14611] = {.lex_state = 60, .external_lex_state = 24},
  [14612] = {.lex_state = 60, .external_lex_state = 24},
  [14613] = {.lex_state = 60},
  [14614] = {.lex_state = 0, .external_lex_state = 25},
  [14615] = {.lex_state = 0, .external_lex_state = 25},
  [14616] = {.lex_state = 60},
  [14617] = {.lex_state = 53},
  [14618] = {.lex_state = 0, .external_lex_state = 25},
  [14619] = {.lex_state = 60, .external_lex_state = 24},
  [14620] = {.lex_state = 54, .external_lex_state = 43},
  [14621] = {.lex_state = 0, .external_lex_state = 23},
  [14622] = {.lex_state = 60, .external_lex_state = 24},
  [14623] = {.lex_state = 0, .external_lex_state = 25},
  [14624] = {.lex_state = 0, .external_lex_state = 25},
  [14625] = {.lex_state = 0},
  [14626] = {.lex_state = 53},
  [14627] = {.lex_state = 60, .external_lex_state = 64},
  [14628] = {.lex_state = 60, .external_lex_state = 24},
  [14629] = {.lex_state = 60, .external_lex_state = 24},
  [14630] = {.lex_state = 0, .external_lex_state = 24},
  [14631] = {.lex_state = 0, .external_lex_state = 25},
  [14632] = {.lex_state = 60},
  [14633] = {.lex_state = 0},
  [14634] = {.lex_state = 0, .external_lex_state = 23},
  [14635] = {.lex_state = 60, .external_lex_state = 24},
  [14636] = {.lex_state = 60},
  [14637] = {.lex_state = 60, .external_lex_state = 64},
  [14638] = {.lex_state = 60, .external_lex_state = 24},
  [14639] = {.lex_state = 60, .external_lex_state = 64},
  [14640] = {.lex_state = 60},
  [14641] = {.lex_state = 0, .external_lex_state = 24},
  [14642] = {.lex_state = 60, .external_lex_state = 64},
  [14643] = {.lex_state = 60},
  [14644] = {.lex_state = 60, .external_lex_state = 64},
  [14645] = {.lex_state = 60, .external_lex_state = 64},
  [14646] = {.lex_state = 60},
  [14647] = {.lex_state = 0, .external_lex_state = 25},
  [14648] = {.lex_state = 60},
  [14649] = {.lex_state = 60, .external_lex_state = 24},
  [14650] = {.lex_state = 53},
  [14651] = {.lex_state = 0, .external_lex_state = 25},
  [14652] = {.lex_state = 60, .external_lex_state = 64},
  [14653] = {.lex_state = 60},
  [14654] = {.lex_state = 0},
  [14655] = {.lex_state = 0, .external_lex_state = 23},
  [14656] = {.lex_state = 60, .external_lex_state = 64},
  [14657] = {.lex_state = 60, .external_lex_state = 64},
  [14658] = {.lex_state = 60, .external_lex_state = 64},
  [14659] = {.lex_state = 53},
  [14660] = {.lex_state = 60},
  [14661] = {.lex_state = 60},
  [14662] = {.lex_state = 60},
  [14663] = {.lex_state = 60},
  [14664] = {.lex_state = 60, .external_lex_state = 24},
  [14665] = {.lex_state = 53},
  [14666] = {.lex_state = 0, .external_lex_state = 25},
  [14667] = {.lex_state = 60, .external_lex_state = 64},
  [14668] = {.lex_state = 0, .external_lex_state = 25},
  [14669] = {.lex_state = 60},
  [14670] = {.lex_state = 60},
  [14671] = {.lex_state = 60, .external_lex_state = 24},
  [14672] = {.lex_state = 60, .external_lex_state = 64},
  [14673] = {.lex_state = 60, .external_lex_state = 24},
  [14674] = {.lex_state = 53},
  [14675] = {.lex_state = 60, .external_lex_state = 64},
  [14676] = {.lex_state = 60, .external_lex_state = 24},
  [14677] = {.lex_state = 0, .external_lex_state = 23},
  [14678] = {.lex_state = 60, .external_lex_state = 24},
  [14679] = {.lex_state = 60, .external_lex_state = 24},
  [14680] = {.lex_state = 0},
  [14681] = {.lex_state = 60, .external_lex_state = 64},
  [14682] = {.lex_state = 60},
  [14683] = {.lex_state = 0, .external_lex_state = 24},
  [14684] = {.lex_state = 60},
  [14685] = {.lex_state = 60, .external_lex_state = 24},
  [14686] = {.lex_state = 60},
  [14687] = {.lex_state = 60},
  [14688] = {.lex_state = 60, .external_lex_state = 64},
  [14689] = {.lex_state = 60, .external_lex_state = 64},
  [14690] = {.lex_state = 60},
  [14691] = {.lex_state = 60},
  [14692] = {.lex_state = 60, .external_lex_state = 24},
  [14693] = {.lex_state = 60},
  [14694] = {.lex_state = 60, .external_lex_state = 24},
  [14695] = {.lex_state = 0},
  [14696] = {.lex_state = 53},
  [14697] = {.lex_state = 60, .external_lex_state = 24},
  [14698] = {.lex_state = 60, .external_lex_state = 24},
  [14699] = {.lex_state = 60, .external_lex_state = 24},
  [14700] = {.lex_state = 60},
  [14701] = {.lex_state = 60},
  [14702] = {.lex_state = 0, .external_lex_state = 23},
  [14703] = {.lex_state = 0, .external_lex_state = 25},
  [14704] = {.lex_state = 60, .external_lex_state = 24},
  [14705] = {.lex_state = 60},
  [14706] = {.lex_state = 60},
  [14707] = {.lex_state = 60},
  [14708] = {.lex_state = 0, .external_lex_state = 25},
  [14709] = {.lex_state = 60},
  [14710] = {.lex_state = 0, .external_lex_state = 25},
  [14711] = {.lex_state = 60, .external_lex_state = 64},
  [14712] = {.lex_state = 0, .external_lex_state = 23},
  [14713] = {.lex_state = 54},
  [14714] = {.lex_state = 60, .external_lex_state = 24},
  [14715] = {.lex_state = 0, .external_lex_state = 25},
  [14716] = {.lex_state = 60, .external_lex_state = 24},
  [14717] = {.lex_state = 60},
  [14718] = {.lex_state = 60, .external_lex_state = 24},
  [14719] = {.lex_state = 60, .external_lex_state = 64},
  [14720] = {.lex_state = 60},
  [14721] = {.lex_state = 60},
  [14722] = {.lex_state = 53},
  [14723] = {.lex_state = 0},
  [14724] = {.lex_state = 60, .external_lex_state = 24},
  [14725] = {.lex_state = 53},
  [14726] = {.lex_state = 60},
  [14727] = {.lex_state = 60, .external_lex_state = 24},
  [14728] = {.lex_state = 60},
  [14729] = {.lex_state = 0},
  [14730] = {.lex_state = 0},
  [14731] = {.lex_state = 60, .external_lex_state = 24},
  [14732] = {.lex_state = 0},
  [14733] = {.lex_state = 0},
  [14734] = {.lex_state = 0},
  [14735] = {.lex_state = 0},
  [14736] = {.lex_state = 150},
  [14737] = {.lex_state = 0},
  [14738] = {.lex_state = 0},
  [14739] = {.lex_state = 0},
  [14740] = {.lex_state = 0},
  [14741] = {.lex_state = 60},
  [14742] = {.lex_state = 0},
  [14743] = {.lex_state = 0},
  [14744] = {.lex_state = 0},
  [14745] = {.lex_state = 0},
  [14746] = {.lex_state = 0},
  [14747] = {.lex_state = 0},
  [14748] = {.lex_state = 0},
  [14749] = {.lex_state = 0, .external_lex_state = 72},
  [14750] = {.lex_state = 0, .external_lex_state = 73},
  [14751] = {.lex_state = 0},
  [14752] = {.lex_state = 0},
  [14753] = {.lex_state = 0},
  [14754] = {.lex_state = 0},
  [14755] = {.lex_state = 0},
  [14756] = {.lex_state = 0},
  [14757] = {.lex_state = 0},
  [14758] = {.lex_state = 0},
  [14759] = {.lex_state = 0},
  [14760] = {.lex_state = 0},
  [14761] = {.lex_state = 0},
  [14762] = {.lex_state = 0},
  [14763] = {.lex_state = 0},
  [14764] = {.lex_state = 0},
  [14765] = {.lex_state = 0},
  [14766] = {.lex_state = 0},
  [14767] = {.lex_state = 0},
  [14768] = {.lex_state = 0},
  [14769] = {.lex_state = 0},
  [14770] = {.lex_state = 0, .external_lex_state = 72},
  [14771] = {.lex_state = 0, .external_lex_state = 73},
  [14772] = {.lex_state = 0},
  [14773] = {.lex_state = 0},
  [14774] = {.lex_state = 0},
  [14775] = {.lex_state = 0},
  [14776] = {.lex_state = 0},
  [14777] = {.lex_state = 0},
  [14778] = {.lex_state = 0},
  [14779] = {.lex_state = 0},
  [14780] = {.lex_state = 0},
  [14781] = {.lex_state = 0},
  [14782] = {.lex_state = 0},
  [14783] = {.lex_state = 0},
  [14784] = {.lex_state = 0, .external_lex_state = 72},
  [14785] = {.lex_state = 0},
  [14786] = {.lex_state = 0},
  [14787] = {.lex_state = 0, .external_lex_state = 25},
  [14788] = {.lex_state = 0},
  [14789] = {.lex_state = 0},
  [14790] = {.lex_state = 0},
  [14791] = {.lex_state = 0, .external_lex_state = 72},
  [14792] = {.lex_state = 0, .external_lex_state = 73},
  [14793] = {.lex_state = 0},
  [14794] = {.lex_state = 0},
  [14795] = {.lex_state = 0, .external_lex_state = 72},
  [14796] = {.lex_state = 0},
  [14797] = {.lex_state = 0, .external_lex_state = 73},
  [14798] = {.lex_state = 0},
  [14799] = {.lex_state = 0},
  [14800] = {.lex_state = 0},
  [14801] = {.lex_state = 0},
  [14802] = {.lex_state = 0},
  [14803] = {.lex_state = 0},
  [14804] = {.lex_state = 0},
  [14805] = {.lex_state = 0},
  [14806] = {.lex_state = 0},
  [14807] = {.lex_state = 0},
  [14808] = {.lex_state = 0},
  [14809] = {.lex_state = 0},
  [14810] = {.lex_state = 0},
  [14811] = {.lex_state = 0},
  [14812] = {.lex_state = 0},
  [14813] = {.lex_state = 0},
  [14814] = {.lex_state = 60},
  [14815] = {.lex_state = 0},
  [14816] = {.lex_state = 0},
  [14817] = {.lex_state = 0},
  [14818] = {.lex_state = 0},
  [14819] = {.lex_state = 0},
  [14820] = {.lex_state = 0},
  [14821] = {.lex_state = 0},
  [14822] = {.lex_state = 0, .external_lex_state = 72},
  [14823] = {.lex_state = 0},
  [14824] = {.lex_state = 0},
  [14825] = {.lex_state = 0},
  [14826] = {.lex_state = 0},
  [14827] = {.lex_state = 0, .external_lex_state = 73},
  [14828] = {.lex_state = 0},
  [14829] = {.lex_state = 0},
  [14830] = {.lex_state = 0},
  [14831] = {.lex_state = 0},
  [14832] = {.lex_state = 0},
  [14833] = {.lex_state = 0},
  [14834] = {.lex_state = 0},
  [14835] = {.lex_state = 0},
  [14836] = {.lex_state = 0},
  [14837] = {.lex_state = 0, .external_lex_state = 23},
  [14838] = {.lex_state = 0, .external_lex_state = 73},
  [14839] = {.lex_state = 0},
  [14840] = {.lex_state = 0},
  [14841] = {.lex_state = 0},
  [14842] = {.lex_state = 0},
  [14843] = {.lex_state = 0},
  [14844] = {.lex_state = 0},
  [14845] = {.lex_state = 0},
  [14846] = {.lex_state = 0},
  [14847] = {.lex_state = 0},
  [14848] = {.lex_state = 0, .external_lex_state = 25},
  [14849] = {.lex_state = 0},
  [14850] = {.lex_state = 0},
  [14851] = {.lex_state = 0},
  [14852] = {.lex_state = 0, .external_lex_state = 72},
  [14853] = {.lex_state = 0},
  [14854] = {.lex_state = 0, .external_lex_state = 73},
  [14855] = {.lex_state = 0},
  [14856] = {.lex_state = 0},
  [14857] = {.lex_state = 0},
  [14858] = {.lex_state = 0},
  [14859] = {.lex_state = 0},
  [14860] = {.lex_state = 0},
  [14861] = {.lex_state = 0, .external_lex_state = 25},
  [14862] = {.lex_state = 0},
  [14863] = {.lex_state = 0},
  [14864] = {.lex_state = 0},
  [14865] = {.lex_state = 1},
  [14866] = {.lex_state = 0},
  [14867] = {.lex_state = 0},
  [14868] = {.lex_state = 0},
  [14869] = {.lex_state = 0},
  [14870] = {.lex_state = 0, .external_lex_state = 25},
  [14871] = {.lex_state = 0},
  [14872] = {.lex_state = 0},
  [14873] = {.lex_state = 0},
  [14874] = {.lex_state = 60, .external_lex_state = 43},
  [14875] = {.lex_state = 0},
  [14876] = {.lex_state = 0},
  [14877] = {.lex_state = 0},
  [14878] = {.lex_state = 0},
  [14879] = {.lex_state = 0},
  [14880] = {.lex_state = 0},
  [14881] = {.lex_state = 0},
  [14882] = {.lex_state = 0},
  [14883] = {.lex_state = 0},
  [14884] = {.lex_state = 0},
  [14885] = {.lex_state = 0},
  [14886] = {.lex_state = 0},
  [14887] = {.lex_state = 0},
  [14888] = {.lex_state = 0},
  [14889] = {.lex_state = 0, .external_lex_state = 72},
  [14890] = {.lex_state = 0, .external_lex_state = 73},
  [14891] = {.lex_state = 0},
  [14892] = {.lex_state = 0},
  [14893] = {.lex_state = 0},
  [14894] = {.lex_state = 0},
  [14895] = {.lex_state = 0},
  [14896] = {.lex_state = 0},
  [14897] = {.lex_state = 0},
  [14898] = {.lex_state = 0},
  [14899] = {.lex_state = 0},
  [14900] = {.lex_state = 0},
  [14901] = {.lex_state = 60},
  [14902] = {.lex_state = 0},
  [14903] = {.lex_state = 0},
  [14904] = {.lex_state = 0},
  [14905] = {.lex_state = 0},
  [14906] = {.lex_state = 0},
  [14907] = {.lex_state = 0},
  [14908] = {.lex_state = 0},
  [14909] = {.lex_state = 0},
  [14910] = {.lex_state = 0, .external_lex_state = 72},
  [14911] = {.lex_state = 0, .external_lex_state = 73},
  [14912] = {.lex_state = 0},
  [14913] = {.lex_state = 0},
  [14914] = {.lex_state = 0},
  [14915] = {.lex_state = 0},
  [14916] = {.lex_state = 0},
  [14917] = {.lex_state = 0},
  [14918] = {.lex_state = 0},
  [14919] = {.lex_state = 0},
  [14920] = {.lex_state = 0},
  [14921] = {.lex_state = 0},
  [14922] = {.lex_state = 0},
  [14923] = {.lex_state = 0},
  [14924] = {.lex_state = 0},
  [14925] = {.lex_state = 0},
  [14926] = {.lex_state = 0},
  [14927] = {.lex_state = 0},
  [14928] = {.lex_state = 0},
  [14929] = {.lex_state = 0},
  [14930] = {.lex_state = 0},
  [14931] = {.lex_state = 0},
  [14932] = {.lex_state = 0},
  [14933] = {.lex_state = 0},
  [14934] = {.lex_state = 0, .external_lex_state = 72},
  [14935] = {.lex_state = 0, .external_lex_state = 73},
  [14936] = {.lex_state = 0},
  [14937] = {.lex_state = 0},
  [14938] = {.lex_state = 0},
  [14939] = {.lex_state = 0},
  [14940] = {.lex_state = 0},
  [14941] = {.lex_state = 0},
  [14942] = {.lex_state = 0},
  [14943] = {.lex_state = 0},
  [14944] = {.lex_state = 0},
  [14945] = {.lex_state = 0, .external_lex_state = 72},
  [14946] = {.lex_state = 0},
  [14947] = {.lex_state = 0},
  [14948] = {.lex_state = 0},
  [14949] = {.lex_state = 0},
  [14950] = {.lex_state = 0},
  [14951] = {.lex_state = 0, .external_lex_state = 25},
  [14952] = {.lex_state = 0},
  [14953] = {.lex_state = 0},
  [14954] = {.lex_state = 0},
  [14955] = {.lex_state = 0},
  [14956] = {.lex_state = 0},
  [14957] = {.lex_state = 0},
  [14958] = {.lex_state = 0},
  [14959] = {.lex_state = 0},
  [14960] = {.lex_state = 0},
  [14961] = {.lex_state = 0},
  [14962] = {.lex_state = 0},
  [14963] = {.lex_state = 0},
  [14964] = {.lex_state = 60},
  [14965] = {.lex_state = 0},
  [14966] = {.lex_state = 0, .external_lex_state = 73},
  [14967] = {.lex_state = 0},
  [14968] = {.lex_state = 0},
  [14969] = {.lex_state = 0},
  [14970] = {.lex_state = 0},
  [14971] = {.lex_state = 0},
  [14972] = {.lex_state = 0},
  [14973] = {.lex_state = 0},
  [14974] = {.lex_state = 0},
  [14975] = {.lex_state = 0},
  [14976] = {.lex_state = 0},
  [14977] = {.lex_state = 0, .external_lex_state = 25},
  [14978] = {.lex_state = 0},
  [14979] = {.lex_state = 60},
  [14980] = {.lex_state = 0},
  [14981] = {.lex_state = 60},
  [14982] = {.lex_state = 60},
  [14983] = {.lex_state = 0},
  [14984] = {.lex_state = 0, .external_lex_state = 72},
  [14985] = {.lex_state = 0, .external_lex_state = 73},
  [14986] = {.lex_state = 0},
  [14987] = {.lex_state = 0},
  [14988] = {.lex_state = 0},
  [14989] = {.lex_state = 0},
  [14990] = {.lex_state = 60},
  [14991] = {.lex_state = 0},
  [14992] = {.lex_state = 0},
  [14993] = {.lex_state = 0, .external_lex_state = 72},
  [14994] = {.lex_state = 0},
  [14995] = {.lex_state = 0},
  [14996] = {.lex_state = 0, .external_lex_state = 73},
  [14997] = {.lex_state = 60},
  [14998] = {.lex_state = 0, .external_lex_state = 72},
  [14999] = {.lex_state = 0, .external_lex_state = 73},
  [15000] = {.lex_state = 0},
  [15001] = {.lex_state = 0},
  [15002] = {.lex_state = 0, .external_lex_state = 72},
  [15003] = {.lex_state = 0},
  [15004] = {.lex_state = 0},
  [15005] = {.lex_state = 60},
  [15006] = {.lex_state = 0, .external_lex_state = 73},
  [15007] = {.lex_state = 0},
  [15008] = {.lex_state = 0},
  [15009] = {.lex_state = 0, .external_lex_state = 25},
  [15010] = {.lex_state = 0},
  [15011] = {.lex_state = 0},
  [15012] = {.lex_state = 0},
  [15013] = {.lex_state = 0},
  [15014] = {.lex_state = 0},
  [15015] = {.lex_state = 0},
  [15016] = {.lex_state = 0},
  [15017] = {.lex_state = 0},
  [15018] = {.lex_state = 0},
  [15019] = {.lex_state = 0},
  [15020] = {.lex_state = 0},
  [15021] = {.lex_state = 0},
  [15022] = {.lex_state = 0},
  [15023] = {.lex_state = 0},
  [15024] = {.lex_state = 0},
  [15025] = {.lex_state = 0},
  [15026] = {.lex_state = 0},
  [15027] = {.lex_state = 0},
  [15028] = {.lex_state = 0},
  [15029] = {.lex_state = 0},
  [15030] = {.lex_state = 0},
  [15031] = {.lex_state = 0},
  [15032] = {.lex_state = 0},
  [15033] = {.lex_state = 0},
  [15034] = {.lex_state = 0},
  [15035] = {.lex_state = 0},
  [15036] = {.lex_state = 0},
  [15037] = {.lex_state = 60},
  [15038] = {.lex_state = 0},
  [15039] = {.lex_state = 0},
  [15040] = {.lex_state = 0},
  [15041] = {.lex_state = 0},
  [15042] = {.lex_state = 0, .external_lex_state = 72},
  [15043] = {.lex_state = 60},
  [15044] = {.lex_state = 0},
  [15045] = {.lex_state = 0, .external_lex_state = 73},
  [15046] = {.lex_state = 0},
  [15047] = {.lex_state = 0},
  [15048] = {.lex_state = 1},
  [15049] = {.lex_state = 0},
  [15050] = {.lex_state = 60},
  [15051] = {.lex_state = 0},
  [15052] = {.lex_state = 0},
  [15053] = {.lex_state = 0, .external_lex_state = 23},
  [15054] = {.lex_state = 0},
  [15055] = {.lex_state = 60},
  [15056] = {.lex_state = 0},
  [15057] = {.lex_state = 0},
  [15058] = {.lex_state = 0},
  [15059] = {.lex_state = 0},
  [15060] = {.lex_state = 0},
  [15061] = {.lex_state = 0},
  [15062] = {.lex_state = 0},
  [15063] = {.lex_state = 0},
  [15064] = {.lex_state = 0},
  [15065] = {.lex_state = 0},
  [15066] = {.lex_state = 0, .external_lex_state = 24},
  [15067] = {.lex_state = 0},
  [15068] = {.lex_state = 0},
  [15069] = {.lex_state = 0},
  [15070] = {.lex_state = 0, .external_lex_state = 72},
  [15071] = {.lex_state = 0, .external_lex_state = 73},
  [15072] = {.lex_state = 60},
  [15073] = {.lex_state = 0, .external_lex_state = 72},
  [15074] = {.lex_state = 0, .external_lex_state = 73},
  [15075] = {.lex_state = 0},
  [15076] = {.lex_state = 60},
  [15077] = {.lex_state = 0},
  [15078] = {.lex_state = 0},
  [15079] = {.lex_state = 0},
  [15080] = {.lex_state = 0},
  [15081] = {.lex_state = 60},
  [15082] = {.lex_state = 0},
  [15083] = {.lex_state = 0, .external_lex_state = 25},
  [15084] = {.lex_state = 0},
  [15085] = {.lex_state = 0},
  [15086] = {.lex_state = 0},
  [15087] = {.lex_state = 0},
  [15088] = {.lex_state = 0},
  [15089] = {.lex_state = 0},
  [15090] = {.lex_state = 0},
  [15091] = {.lex_state = 0},
  [15092] = {.lex_state = 0},
  [15093] = {.lex_state = 0},
  [15094] = {.lex_state = 0},
  [15095] = {.lex_state = 0},
  [15096] = {.lex_state = 0},
  [15097] = {.lex_state = 0},
  [15098] = {.lex_state = 60},
  [15099] = {.lex_state = 0, .external_lex_state = 72},
  [15100] = {.lex_state = 0},
  [15101] = {.lex_state = 0, .external_lex_state = 73},
  [15102] = {.lex_state = 0},
  [15103] = {.lex_state = 60},
  [15104] = {.lex_state = 0, .external_lex_state = 25},
  [15105] = {.lex_state = 60},
  [15106] = {.lex_state = 0},
  [15107] = {.lex_state = 0},
  [15108] = {.lex_state = 0},
  [15109] = {.lex_state = 0},
  [15110] = {.lex_state = 0, .external_lex_state = 72},
  [15111] = {.lex_state = 0, .external_lex_state = 73},
  [15112] = {.lex_state = 0},
  [15113] = {.lex_state = 0},
  [15114] = {.lex_state = 0},
  [15115] = {.lex_state = 60},
  [15116] = {.lex_state = 60},
  [15117] = {.lex_state = 0, .external_lex_state = 73},
  [15118] = {.lex_state = 0},
  [15119] = {.lex_state = 60},
  [15120] = {.lex_state = 0},
  [15121] = {.lex_state = 60},
  [15122] = {.lex_state = 0},
  [15123] = {.lex_state = 0},
  [15124] = {.lex_state = 0},
  [15125] = {.lex_state = 0},
  [15126] = {.lex_state = 0},
  [15127] = {.lex_state = 0, .external_lex_state = 72},
  [15128] = {.lex_state = 0, .external_lex_state = 73},
  [15129] = {.lex_state = 0},
  [15130] = {.lex_state = 60},
  [15131] = {.lex_state = 0},
  [15132] = {.lex_state = 0},
  [15133] = {.lex_state = 0},
  [15134] = {.lex_state = 60},
  [15135] = {.lex_state = 0},
  [15136] = {.lex_state = 53},
  [15137] = {.lex_state = 0},
  [15138] = {.lex_state = 60},
  [15139] = {.lex_state = 0, .external_lex_state = 25},
  [15140] = {.lex_state = 0},
  [15141] = {.lex_state = 0},
  [15142] = {.lex_state = 0},
  [15143] = {.lex_state = 0},
  [15144] = {.lex_state = 60},
  [15145] = {.lex_state = 0},
  [15146] = {.lex_state = 0},
  [15147] = {.lex_state = 60},
  [15148] = {.lex_state = 0},
  [15149] = {.lex_state = 60},
  [15150] = {.lex_state = 60},
  [15151] = {.lex_state = 0, .external_lex_state = 72},
  [15152] = {.lex_state = 0},
  [15153] = {.lex_state = 0, .external_lex_state = 73},
  [15154] = {.lex_state = 0},
  [15155] = {.lex_state = 0},
  [15156] = {.lex_state = 0},
  [15157] = {.lex_state = 0},
  [15158] = {.lex_state = 0},
  [15159] = {.lex_state = 60},
  [15160] = {.lex_state = 0, .external_lex_state = 25},
  [15161] = {.lex_state = 0},
  [15162] = {.lex_state = 60},
  [15163] = {.lex_state = 0},
  [15164] = {.lex_state = 0, .external_lex_state = 25},
  [15165] = {.lex_state = 60},
  [15166] = {.lex_state = 0},
  [15167] = {.lex_state = 0, .external_lex_state = 24},
  [15168] = {.lex_state = 60},
  [15169] = {.lex_state = 0},
  [15170] = {.lex_state = 0},
  [15171] = {.lex_state = 60},
  [15172] = {.lex_state = 60},
  [15173] = {.lex_state = 0},
  [15174] = {.lex_state = 0, .external_lex_state = 72},
  [15175] = {.lex_state = 0, .external_lex_state = 73},
  [15176] = {.lex_state = 0},
  [15177] = {.lex_state = 0},
  [15178] = {.lex_state = 0},
  [15179] = {.lex_state = 60},
  [15180] = {.lex_state = 60},
  [15181] = {.lex_state = 0, .external_lex_state = 23},
  [15182] = {.lex_state = 60},
  [15183] = {.lex_state = 0},
  [15184] = {.lex_state = 0},
  [15185] = {.lex_state = 0, .external_lex_state = 72},
  [15186] = {.lex_state = 0, .external_lex_state = 73},
  [15187] = {.lex_state = 60},
  [15188] = {.lex_state = 0},
  [15189] = {.lex_state = 0},
  [15190] = {.lex_state = 60},
  [15191] = {.lex_state = 0},
  [15192] = {.lex_state = 60},
  [15193] = {.lex_state = 0},
  [15194] = {.lex_state = 60},
  [15195] = {.lex_state = 0},
  [15196] = {.lex_state = 0},
  [15197] = {.lex_state = 0},
  [15198] = {.lex_state = 0},
  [15199] = {.lex_state = 0},
  [15200] = {.lex_state = 0},
  [15201] = {.lex_state = 0},
  [15202] = {.lex_state = 60},
  [15203] = {.lex_state = 0},
  [15204] = {.lex_state = 0},
  [15205] = {.lex_state = 0},
  [15206] = {.lex_state = 60},
  [15207] = {.lex_state = 0},
  [15208] = {.lex_state = 60},
  [15209] = {.lex_state = 0},
  [15210] = {.lex_state = 0},
  [15211] = {.lex_state = 0, .external_lex_state = 72},
  [15212] = {.lex_state = 0},
  [15213] = {.lex_state = 0, .external_lex_state = 72},
  [15214] = {.lex_state = 0, .external_lex_state = 73},
  [15215] = {.lex_state = 0, .external_lex_state = 73},
  [15216] = {.lex_state = 60},
  [15217] = {.lex_state = 0},
  [15218] = {.lex_state = 0},
  [15219] = {.lex_state = 0},
  [15220] = {.lex_state = 60},
  [15221] = {.lex_state = 0},
  [15222] = {.lex_state = 60},
  [15223] = {.lex_state = 0},
  [15224] = {.lex_state = 0},
  [15225] = {.lex_state = 0},
  [15226] = {.lex_state = 0, .external_lex_state = 72},
  [15227] = {.lex_state = 60},
  [15228] = {.lex_state = 0, .external_lex_state = 73},
  [15229] = {.lex_state = 0},
  [15230] = {.lex_state = 60},
  [15231] = {.lex_state = 0},
  [15232] = {.lex_state = 0},
  [15233] = {.lex_state = 0},
  [15234] = {.lex_state = 60},
  [15235] = {.lex_state = 60},
  [15236] = {.lex_state = 0, .external_lex_state = 24},
  [15237] = {.lex_state = 0},
  [15238] = {.lex_state = 0},
  [15239] = {.lex_state = 0},
  [15240] = {.lex_state = 53},
  [15241] = {.lex_state = 60},
  [15242] = {.lex_state = 0},
  [15243] = {.lex_state = 60},
  [15244] = {.lex_state = 60},
  [15245] = {.lex_state = 0},
  [15246] = {.lex_state = 0},
  [15247] = {.lex_state = 0},
  [15248] = {.lex_state = 0},
  [15249] = {.lex_state = 60},
  [15250] = {.lex_state = 60},
  [15251] = {.lex_state = 0},
  [15252] = {.lex_state = 0, .external_lex_state = 72},
  [15253] = {.lex_state = 0, .external_lex_state = 73},
  [15254] = {.lex_state = 60},
  [15255] = {.lex_state = 0},
  [15256] = {.lex_state = 0},
  [15257] = {.lex_state = 0, .external_lex_state = 72},
  [15258] = {.lex_state = 0, .external_lex_state = 72},
  [15259] = {.lex_state = 0},
  [15260] = {.lex_state = 60},
  [15261] = {.lex_state = 0, .external_lex_state = 23},
  [15262] = {.lex_state = 0},
  [15263] = {.lex_state = 0, .external_lex_state = 73},
  [15264] = {.lex_state = 0},
  [15265] = {.lex_state = 0, .external_lex_state = 72},
  [15266] = {.lex_state = 60},
  [15267] = {.lex_state = 0, .external_lex_state = 73},
  [15268] = {.lex_state = 0},
  [15269] = {.lex_state = 0},
  [15270] = {.lex_state = 0},
  [15271] = {.lex_state = 0},
  [15272] = {.lex_state = 0},
  [15273] = {.lex_state = 0},
  [15274] = {.lex_state = 60},
  [15275] = {.lex_state = 0},
  [15276] = {.lex_state = 0, .external_lex_state = 73},
  [15277] = {.lex_state = 0, .external_lex_state = 23},
  [15278] = {.lex_state = 0, .external_lex_state = 72},
  [15279] = {.lex_state = 0, .external_lex_state = 72},
  [15280] = {.lex_state = 0, .external_lex_state = 73},
  [15281] = {.lex_state = 0},
  [15282] = {.lex_state = 0, .external_lex_state = 73},
  [15283] = {.lex_state = 0},
  [15284] = {.lex_state = 0},
  [15285] = {.lex_state = 60},
  [15286] = {.lex_state = 0},
  [15287] = {.lex_state = 60},
  [15288] = {.lex_state = 0},
  [15289] = {.lex_state = 0},
  [15290] = {.lex_state = 0},
  [15291] = {.lex_state = 0},
  [15292] = {.lex_state = 0},
  [15293] = {.lex_state = 60},
  [15294] = {.lex_state = 0},
  [15295] = {.lex_state = 0},
  [15296] = {.lex_state = 0},
  [15297] = {.lex_state = 0, .external_lex_state = 23},
  [15298] = {.lex_state = 0},
  [15299] = {.lex_state = 0, .external_lex_state = 25},
  [15300] = {.lex_state = 53},
  [15301] = {.lex_state = 60},
  [15302] = {.lex_state = 60},
  [15303] = {.lex_state = 0},
  [15304] = {.lex_state = 0, .external_lex_state = 72},
  [15305] = {.lex_state = 0, .external_lex_state = 73},
  [15306] = {.lex_state = 0},
  [15307] = {.lex_state = 0, .external_lex_state = 23},
  [15308] = {.lex_state = 0, .external_lex_state = 24},
  [15309] = {.lex_state = 0},
  [15310] = {.lex_state = 0},
  [15311] = {.lex_state = 0},
  [15312] = {.lex_state = 0},
  [15313] = {.lex_state = 0, .external_lex_state = 25},
  [15314] = {.lex_state = 60},
  [15315] = {.lex_state = 0},
  [15316] = {.lex_state = 0},
  [15317] = {.lex_state = 0},
  [15318] = {.lex_state = 0},
  [15319] = {.lex_state = 0},
  [15320] = {.lex_state = 0},
  [15321] = {.lex_state = 0},
  [15322] = {.lex_state = 60},
  [15323] = {.lex_state = 0},
  [15324] = {.lex_state = 0},
  [15325] = {.lex_state = 0},
  [15326] = {.lex_state = 0},
  [15327] = {.lex_state = 0},
  [15328] = {.lex_state = 60},
  [15329] = {.lex_state = 0, .external_lex_state = 24},
  [15330] = {.lex_state = 0},
  [15331] = {.lex_state = 0, .external_lex_state = 72},
  [15332] = {.lex_state = 0},
  [15333] = {.lex_state = 0},
  [15334] = {.lex_state = 0},
  [15335] = {.lex_state = 0},
  [15336] = {.lex_state = 60},
  [15337] = {.lex_state = 0},
  [15338] = {.lex_state = 0},
  [15339] = {.lex_state = 0},
  [15340] = {.lex_state = 0},
  [15341] = {.lex_state = 0},
  [15342] = {.lex_state = 60},
  [15343] = {.lex_state = 0},
  [15344] = {.lex_state = 0},
  [15345] = {.lex_state = 0, .external_lex_state = 72},
  [15346] = {.lex_state = 0, .external_lex_state = 73},
  [15347] = {.lex_state = 0},
  [15348] = {.lex_state = 0},
  [15349] = {.lex_state = 0},
  [15350] = {.lex_state = 0},
  [15351] = {.lex_state = 0},
  [15352] = {.lex_state = 0},
  [15353] = {.lex_state = 0},
  [15354] = {.lex_state = 0},
  [15355] = {.lex_state = 0},
  [15356] = {.lex_state = 0, .external_lex_state = 73},
  [15357] = {.lex_state = 0},
  [15358] = {.lex_state = 0},
  [15359] = {.lex_state = 0},
  [15360] = {.lex_state = 0},
  [15361] = {.lex_state = 0},
  [15362] = {.lex_state = 0, .external_lex_state = 24},
  [15363] = {.lex_state = 0},
  [15364] = {.lex_state = 0},
  [15365] = {.lex_state = 0},
  [15366] = {.lex_state = 0},
  [15367] = {.lex_state = 0},
  [15368] = {.lex_state = 0},
  [15369] = {.lex_state = 0},
  [15370] = {.lex_state = 60},
  [15371] = {.lex_state = 0},
  [15372] = {.lex_state = 0},
  [15373] = {.lex_state = 0},
  [15374] = {.lex_state = 0},
  [15375] = {.lex_state = 0, .external_lex_state = 25},
  [15376] = {.lex_state = 0},
  [15377] = {.lex_state = 0},
  [15378] = {.lex_state = 0},
  [15379] = {.lex_state = 0},
  [15380] = {.lex_state = 0},
  [15381] = {.lex_state = 0},
  [15382] = {.lex_state = 0},
  [15383] = {.lex_state = 0},
  [15384] = {.lex_state = 0},
  [15385] = {.lex_state = 0},
  [15386] = {.lex_state = 0},
  [15387] = {.lex_state = 0},
  [15388] = {.lex_state = 0},
  [15389] = {.lex_state = 0},
  [15390] = {.lex_state = 0, .external_lex_state = 25},
  [15391] = {.lex_state = 0},
  [15392] = {.lex_state = 0, .external_lex_state = 25},
  [15393] = {.lex_state = 0},
  [15394] = {.lex_state = 0},
  [15395] = {.lex_state = 0},
  [15396] = {.lex_state = 0},
  [15397] = {.lex_state = 0},
  [15398] = {.lex_state = 0, .external_lex_state = 24},
  [15399] = {.lex_state = 0},
  [15400] = {.lex_state = 0},
  [15401] = {.lex_state = 0},
  [15402] = {.lex_state = 0},
  [15403] = {.lex_state = 0},
  [15404] = {.lex_state = 0},
  [15405] = {.lex_state = 0},
  [15406] = {.lex_state = 0},
  [15407] = {.lex_state = 0},
  [15408] = {.lex_state = 60},
  [15409] = {.lex_state = 0},
  [15410] = {.lex_state = 0},
  [15411] = {.lex_state = 0},
  [15412] = {.lex_state = 0},
  [15413] = {.lex_state = 0},
  [15414] = {.lex_state = 0},
  [15415] = {.lex_state = 0},
  [15416] = {.lex_state = 0},
  [15417] = {.lex_state = 0},
  [15418] = {.lex_state = 60},
  [15419] = {.lex_state = 0, .external_lex_state = 23},
  [15420] = {.lex_state = 0},
  [15421] = {.lex_state = 0},
  [15422] = {.lex_state = 0},
  [15423] = {.lex_state = 0},
  [15424] = {.lex_state = 0},
  [15425] = {.lex_state = 0, .external_lex_state = 24},
  [15426] = {.lex_state = 60},
  [15427] = {.lex_state = 0},
  [15428] = {.lex_state = 0, .external_lex_state = 25},
  [15429] = {.lex_state = 0, .external_lex_state = 72},
  [15430] = {.lex_state = 0},
  [15431] = {.lex_state = 0, .external_lex_state = 73},
  [15432] = {.lex_state = 0},
  [15433] = {.lex_state = 0},
  [15434] = {.lex_state = 0},
  [15435] = {.lex_state = 0},
  [15436] = {.lex_state = 0},
  [15437] = {.lex_state = 0},
  [15438] = {.lex_state = 0},
  [15439] = {.lex_state = 0},
  [15440] = {.lex_state = 0},
  [15441] = {.lex_state = 0},
  [15442] = {.lex_state = 60},
  [15443] = {.lex_state = 0},
  [15444] = {.lex_state = 60},
  [15445] = {.lex_state = 0},
  [15446] = {.lex_state = 0},
  [15447] = {.lex_state = 0},
  [15448] = {.lex_state = 60},
  [15449] = {.lex_state = 0, .external_lex_state = 72},
  [15450] = {.lex_state = 0, .external_lex_state = 24},
  [15451] = {.lex_state = 0, .external_lex_state = 73},
  [15452] = {.lex_state = 0},
  [15453] = {.lex_state = 0},
  [15454] = {.lex_state = 0},
  [15455] = {.lex_state = 0},
  [15456] = {.lex_state = 0},
  [15457] = {.lex_state = 0},
  [15458] = {.lex_state = 0},
  [15459] = {.lex_state = 0},
  [15460] = {.lex_state = 0},
  [15461] = {.lex_state = 0},
  [15462] = {.lex_state = 0, .external_lex_state = 72},
  [15463] = {.lex_state = 0},
  [15464] = {.lex_state = 0},
  [15465] = {.lex_state = 0},
  [15466] = {.lex_state = 0, .external_lex_state = 73},
  [15467] = {.lex_state = 0},
  [15468] = {.lex_state = 0},
  [15469] = {.lex_state = 0},
  [15470] = {.lex_state = 0},
  [15471] = {.lex_state = 0, .external_lex_state = 72},
  [15472] = {.lex_state = 0, .external_lex_state = 73},
  [15473] = {.lex_state = 0},
  [15474] = {.lex_state = 0, .external_lex_state = 23},
  [15475] = {.lex_state = 0},
  [15476] = {.lex_state = 0},
  [15477] = {.lex_state = 0},
  [15478] = {.lex_state = 0},
  [15479] = {.lex_state = 54, .external_lex_state = 71},
  [15480] = {.lex_state = 0},
  [15481] = {.lex_state = 53},
  [15482] = {.lex_state = 0},
  [15483] = {.lex_state = 0},
  [15484] = {.lex_state = 0},
  [15485] = {.lex_state = 0, .external_lex_state = 72},
  [15486] = {.lex_state = 0, .external_lex_state = 23},
  [15487] = {.lex_state = 0},
  [15488] = {.lex_state = 0, .external_lex_state = 73},
  [15489] = {.lex_state = 0},
  [15490] = {.lex_state = 60},
  [15491] = {.lex_state = 53},
  [15492] = {.lex_state = 0},
  [15493] = {.lex_state = 53},
  [15494] = {.lex_state = 0},
  [15495] = {.lex_state = 0},
  [15496] = {.lex_state = 0, .external_lex_state = 25},
  [15497] = {.lex_state = 0},
  [15498] = {.lex_state = 0, .external_lex_state = 23},
  [15499] = {.lex_state = 0, .external_lex_state = 72},
  [15500] = {.lex_state = 0},
  [15501] = {.lex_state = 0},
  [15502] = {.lex_state = 0, .external_lex_state = 72},
  [15503] = {.lex_state = 0, .external_lex_state = 73},
  [15504] = {.lex_state = 0},
  [15505] = {.lex_state = 0},
  [15506] = {.lex_state = 0, .external_lex_state = 73},
  [15507] = {.lex_state = 0},
  [15508] = {.lex_state = 0},
  [15509] = {.lex_state = 0},
  [15510] = {.lex_state = 0},
  [15511] = {.lex_state = 0, .external_lex_state = 25},
  [15512] = {.lex_state = 0},
  [15513] = {.lex_state = 0},
  [15514] = {.lex_state = 0},
  [15515] = {.lex_state = 6},
  [15516] = {.lex_state = 0},
  [15517] = {.lex_state = 0},
  [15518] = {.lex_state = 0},
  [15519] = {.lex_state = 0},
  [15520] = {.lex_state = 0},
  [15521] = {.lex_state = 0},
  [15522] = {.lex_state = 0},
  [15523] = {.lex_state = 0},
  [15524] = {.lex_state = 0},
  [15525] = {.lex_state = 0},
  [15526] = {.lex_state = 0, .external_lex_state = 72},
  [15527] = {.lex_state = 0, .external_lex_state = 73},
  [15528] = {.lex_state = 0},
  [15529] = {.lex_state = 0},
  [15530] = {.lex_state = 0},
  [15531] = {.lex_state = 0},
  [15532] = {.lex_state = 0, .external_lex_state = 72},
  [15533] = {.lex_state = 0},
  [15534] = {.lex_state = 6},
  [15535] = {.lex_state = 0},
  [15536] = {.lex_state = 0},
  [15537] = {.lex_state = 0},
  [15538] = {.lex_state = 0, .external_lex_state = 72},
  [15539] = {.lex_state = 0},
  [15540] = {.lex_state = 0, .external_lex_state = 72},
  [15541] = {.lex_state = 0, .external_lex_state = 72},
  [15542] = {.lex_state = 0},
  [15543] = {.lex_state = 0},
  [15544] = {.lex_state = 0, .external_lex_state = 25},
  [15545] = {.lex_state = 0},
  [15546] = {.lex_state = 0, .external_lex_state = 73},
  [15547] = {.lex_state = 0},
  [15548] = {.lex_state = 0},
  [15549] = {.lex_state = 0},
  [15550] = {.lex_state = 0},
  [15551] = {.lex_state = 0},
  [15552] = {.lex_state = 0},
  [15553] = {.lex_state = 0},
  [15554] = {.lex_state = 0},
  [15555] = {.lex_state = 0},
  [15556] = {.lex_state = 0},
  [15557] = {.lex_state = 0},
  [15558] = {.lex_state = 0},
  [15559] = {.lex_state = 0},
  [15560] = {.lex_state = 0},
  [15561] = {.lex_state = 0},
  [15562] = {.lex_state = 0},
  [15563] = {.lex_state = 0},
  [15564] = {.lex_state = 0},
  [15565] = {.lex_state = 0},
  [15566] = {.lex_state = 0},
  [15567] = {.lex_state = 0},
  [15568] = {.lex_state = 0},
  [15569] = {.lex_state = 0},
  [15570] = {.lex_state = 0},
  [15571] = {.lex_state = 0, .external_lex_state = 73},
  [15572] = {.lex_state = 0},
  [15573] = {.lex_state = 0},
  [15574] = {.lex_state = 0},
  [15575] = {.lex_state = 0},
  [15576] = {.lex_state = 0},
  [15577] = {.lex_state = 60},
  [15578] = {.lex_state = 0, .external_lex_state = 73},
  [15579] = {.lex_state = 0},
  [15580] = {.lex_state = 0},
  [15581] = {.lex_state = 0},
  [15582] = {.lex_state = 0},
  [15583] = {.lex_state = 60},
  [15584] = {.lex_state = 0},
  [15585] = {.lex_state = 0, .external_lex_state = 72},
  [15586] = {.lex_state = 0},
  [15587] = {.lex_state = 0},
  [15588] = {.lex_state = 0},
  [15589] = {.lex_state = 60},
  [15590] = {.lex_state = 0},
  [15591] = {.lex_state = 0},
  [15592] = {.lex_state = 0},
  [15593] = {.lex_state = 0, .external_lex_state = 72},
  [15594] = {.lex_state = 0},
  [15595] = {.lex_state = 0, .external_lex_state = 73},
  [15596] = {.lex_state = 0},
  [15597] = {.lex_state = 0},
  [15598] = {.lex_state = 0, .external_lex_state = 73},
  [15599] = {.lex_state = 0},
  [15600] = {.lex_state = 0},
  [15601] = {.lex_state = 0},
  [15602] = {.lex_state = 0},
  [15603] = {.lex_state = 60},
  [15604] = {.lex_state = 53},
  [15605] = {.lex_state = 0},
  [15606] = {.lex_state = 0},
  [15607] = {.lex_state = 0},
  [15608] = {.lex_state = 0},
  [15609] = {.lex_state = 0},
  [15610] = {.lex_state = 0},
  [15611] = {.lex_state = 0, .external_lex_state = 72},
  [15612] = {.lex_state = 0, .external_lex_state = 73},
  [15613] = {.lex_state = 0},
  [15614] = {.lex_state = 0},
  [15615] = {.lex_state = 0},
  [15616] = {.lex_state = 0},
  [15617] = {.lex_state = 0},
  [15618] = {.lex_state = 0},
  [15619] = {.lex_state = 0},
  [15620] = {.lex_state = 0},
  [15621] = {.lex_state = 0},
  [15622] = {.lex_state = 0},
  [15623] = {.lex_state = 0, .external_lex_state = 72},
  [15624] = {.lex_state = 0, .external_lex_state = 73},
  [15625] = {.lex_state = 0},
  [15626] = {.lex_state = 0},
  [15627] = {.lex_state = 0},
  [15628] = {.lex_state = 0},
  [15629] = {.lex_state = 0},
  [15630] = {.lex_state = 0},
  [15631] = {.lex_state = 1},
  [15632] = {.lex_state = 0},
  [15633] = {.lex_state = 0},
  [15634] = {.lex_state = 0, .external_lex_state = 72},
  [15635] = {.lex_state = 0, .external_lex_state = 73},
  [15636] = {.lex_state = 0},
  [15637] = {.lex_state = 0},
  [15638] = {.lex_state = 0},
  [15639] = {.lex_state = 0},
  [15640] = {.lex_state = 0},
  [15641] = {.lex_state = 0},
  [15642] = {.lex_state = 0, .external_lex_state = 25},
  [15643] = {.lex_state = 0},
  [15644] = {.lex_state = 0},
  [15645] = {.lex_state = 0},
  [15646] = {.lex_state = 0},
  [15647] = {.lex_state = 0},
  [15648] = {.lex_state = 0},
  [15649] = {.lex_state = 0},
  [15650] = {.lex_state = 0},
  [15651] = {.lex_state = 0},
  [15652] = {.lex_state = 0},
  [15653] = {.lex_state = 0},
  [15654] = {.lex_state = 0},
  [15655] = {.lex_state = 0},
  [15656] = {.lex_state = 0},
  [15657] = {.lex_state = 0},
  [15658] = {.lex_state = 0},
  [15659] = {.lex_state = 0},
  [15660] = {.lex_state = 0},
  [15661] = {.lex_state = 0},
  [15662] = {.lex_state = 0},
  [15663] = {.lex_state = 0},
  [15664] = {.lex_state = 0},
  [15665] = {.lex_state = 0},
  [15666] = {.lex_state = 0},
  [15667] = {.lex_state = 0},
  [15668] = {.lex_state = 0},
  [15669] = {.lex_state = 0},
  [15670] = {.lex_state = 0},
  [15671] = {.lex_state = 0},
  [15672] = {.lex_state = 0},
  [15673] = {.lex_state = 0},
  [15674] = {.lex_state = 0},
  [15675] = {.lex_state = 0},
  [15676] = {.lex_state = 0},
  [15677] = {.lex_state = 0},
  [15678] = {.lex_state = 0},
  [15679] = {.lex_state = 0},
  [15680] = {.lex_state = 0},
  [15681] = {.lex_state = 0},
  [15682] = {.lex_state = 0},
  [15683] = {.lex_state = 0},
  [15684] = {.lex_state = 0},
  [15685] = {.lex_state = 0},
  [15686] = {.lex_state = 0},
  [15687] = {.lex_state = 0},
  [15688] = {.lex_state = 0},
  [15689] = {.lex_state = 0},
  [15690] = {.lex_state = 0},
  [15691] = {.lex_state = 0},
  [15692] = {.lex_state = 0},
  [15693] = {.lex_state = 0},
  [15694] = {.lex_state = 0},
  [15695] = {.lex_state = 0},
  [15696] = {.lex_state = 0},
  [15697] = {.lex_state = 0},
  [15698] = {.lex_state = 0},
  [15699] = {.lex_state = 0},
  [15700] = {.lex_state = 0},
  [15701] = {.lex_state = 0},
  [15702] = {.lex_state = 0},
  [15703] = {.lex_state = 0},
  [15704] = {.lex_state = 0},
  [15705] = {.lex_state = 0},
  [15706] = {.lex_state = 0},
  [15707] = {.lex_state = 0},
  [15708] = {.lex_state = 0},
  [15709] = {.lex_state = 0},
  [15710] = {.lex_state = 0},
  [15711] = {.lex_state = 0, .external_lex_state = 72},
  [15712] = {.lex_state = 0},
  [15713] = {.lex_state = 0},
  [15714] = {.lex_state = 0},
  [15715] = {.lex_state = 0},
  [15716] = {.lex_state = 0, .external_lex_state = 73},
  [15717] = {.lex_state = 0},
  [15718] = {.lex_state = 53},
  [15719] = {.lex_state = 0},
  [15720] = {.lex_state = 0},
  [15721] = {.lex_state = 0},
  [15722] = {.lex_state = 0},
  [15723] = {.lex_state = 0},
  [15724] = {.lex_state = 0},
  [15725] = {.lex_state = 0},
  [15726] = {.lex_state = 0},
  [15727] = {.lex_state = 0},
  [15728] = {.lex_state = 0},
  [15729] = {.lex_state = 0},
  [15730] = {.lex_state = 0},
  [15731] = {.lex_state = 0},
  [15732] = {.lex_state = 0},
  [15733] = {.lex_state = 0},
  [15734] = {.lex_state = 0},
  [15735] = {.lex_state = 0, .external_lex_state = 72},
  [15736] = {.lex_state = 0},
  [15737] = {.lex_state = 0, .external_lex_state = 73},
  [15738] = {.lex_state = 0},
  [15739] = {.lex_state = 0},
  [15740] = {.lex_state = 0},
  [15741] = {.lex_state = 0},
  [15742] = {.lex_state = 0},
  [15743] = {.lex_state = 0},
  [15744] = {.lex_state = 0},
  [15745] = {.lex_state = 0},
  [15746] = {.lex_state = 0},
  [15747] = {.lex_state = 0},
  [15748] = {.lex_state = 0},
  [15749] = {.lex_state = 0},
  [15750] = {.lex_state = 0},
  [15751] = {.lex_state = 0},
  [15752] = {.lex_state = 0},
  [15753] = {.lex_state = 0},
  [15754] = {.lex_state = 0},
  [15755] = {.lex_state = 0},
  [15756] = {.lex_state = 0},
  [15757] = {.lex_state = 0},
  [15758] = {.lex_state = 0},
  [15759] = {.lex_state = 0},
  [15760] = {.lex_state = 0},
  [15761] = {.lex_state = 0},
  [15762] = {.lex_state = 0},
  [15763] = {.lex_state = 0},
  [15764] = {.lex_state = 0},
  [15765] = {.lex_state = 0},
  [15766] = {.lex_state = 0},
  [15767] = {.lex_state = 0},
  [15768] = {.lex_state = 0},
  [15769] = {.lex_state = 0},
  [15770] = {.lex_state = 0},
  [15771] = {.lex_state = 0},
  [15772] = {.lex_state = 0},
  [15773] = {.lex_state = 0},
  [15774] = {.lex_state = 0},
  [15775] = {.lex_state = 0},
  [15776] = {.lex_state = 0},
  [15777] = {.lex_state = 0, .external_lex_state = 23},
  [15778] = {.lex_state = 0},
  [15779] = {.lex_state = 0},
  [15780] = {.lex_state = 0},
  [15781] = {.lex_state = 0},
  [15782] = {.lex_state = 0},
  [15783] = {.lex_state = 0},
  [15784] = {.lex_state = 0},
  [15785] = {.lex_state = 0},
  [15786] = {.lex_state = 0},
  [15787] = {.lex_state = 0},
  [15788] = {.lex_state = 0},
  [15789] = {.lex_state = 0, .external_lex_state = 25},
  [15790] = {.lex_state = 0},
  [15791] = {.lex_state = 0},
  [15792] = {.lex_state = 60},
  [15793] = {.lex_state = 0},
  [15794] = {.lex_state = 0},
  [15795] = {.lex_state = 0, .external_lex_state = 25},
  [15796] = {.lex_state = 0},
  [15797] = {.lex_state = 0},
  [15798] = {.lex_state = 0},
  [15799] = {.lex_state = 0},
  [15800] = {.lex_state = 0},
  [15801] = {.lex_state = 0},
  [15802] = {.lex_state = 0},
  [15803] = {.lex_state = 0},
  [15804] = {.lex_state = 0},
  [15805] = {.lex_state = 0},
  [15806] = {.lex_state = 0},
  [15807] = {.lex_state = 0},
  [15808] = {.lex_state = 0},
  [15809] = {.lex_state = 0},
  [15810] = {.lex_state = 0},
  [15811] = {.lex_state = 0},
  [15812] = {.lex_state = 0},
  [15813] = {.lex_state = 0},
  [15814] = {.lex_state = 0},
  [15815] = {.lex_state = 0},
  [15816] = {.lex_state = 0},
  [15817] = {.lex_state = 0},
  [15818] = {.lex_state = 0},
  [15819] = {.lex_state = 0},
  [15820] = {.lex_state = 0},
  [15821] = {.lex_state = 0},
  [15822] = {.lex_state = 0},
  [15823] = {.lex_state = 0},
  [15824] = {.lex_state = 0},
  [15825] = {.lex_state = 0},
  [15826] = {.lex_state = 0},
  [15827] = {.lex_state = 0, .external_lex_state = 72},
  [15828] = {.lex_state = 0},
  [15829] = {.lex_state = 0, .external_lex_state = 73},
  [15830] = {.lex_state = 0},
  [15831] = {.lex_state = 0, .external_lex_state = 72},
  [15832] = {.lex_state = 0},
  [15833] = {.lex_state = 0, .external_lex_state = 73},
  [15834] = {.lex_state = 0},
  [15835] = {.lex_state = 0},
  [15836] = {.lex_state = 0},
  [15837] = {.lex_state = 0},
  [15838] = {.lex_state = 0},
  [15839] = {.lex_state = 0},
  [15840] = {.lex_state = 0},
  [15841] = {.lex_state = 0},
  [15842] = {.lex_state = 0},
  [15843] = {.lex_state = 0},
  [15844] = {.lex_state = 0},
  [15845] = {.lex_state = 60},
  [15846] = {.lex_state = 0},
  [15847] = {.lex_state = 0},
  [15848] = {.lex_state = 0},
  [15849] = {.lex_state = 0, .external_lex_state = 25},
  [15850] = {.lex_state = 0},
  [15851] = {.lex_state = 60},
  [15852] = {.lex_state = 60},
  [15853] = {.lex_state = 0},
  [15854] = {.lex_state = 0},
  [15855] = {.lex_state = 0},
  [15856] = {.lex_state = 0},
  [15857] = {.lex_state = 0},
  [15858] = {.lex_state = 53},
  [15859] = {.lex_state = 60},
  [15860] = {.lex_state = 0},
  [15861] = {.lex_state = 60, .external_lex_state = 64},
  [15862] = {.lex_state = 0, .external_lex_state = 73},
  [15863] = {.lex_state = 53},
  [15864] = {.lex_state = 0},
  [15865] = {.lex_state = 0},
  [15866] = {.lex_state = 0},
  [15867] = {.lex_state = 60},
  [15868] = {.lex_state = 0},
  [15869] = {.lex_state = 0, .external_lex_state = 25},
  [15870] = {.lex_state = 60},
  [15871] = {.lex_state = 60},
  [15872] = {.lex_state = 0},
  [15873] = {.lex_state = 0},
  [15874] = {.lex_state = 0, .external_lex_state = 72},
  [15875] = {.lex_state = 0},
  [15876] = {.lex_state = 53},
  [15877] = {.lex_state = 0},
  [15878] = {.lex_state = 60, .external_lex_state = 43},
  [15879] = {.lex_state = 0},
  [15880] = {.lex_state = 0},
  [15881] = {.lex_state = 0, .external_lex_state = 25},
  [15882] = {.lex_state = 0},
  [15883] = {.lex_state = 53},
  [15884] = {.lex_state = 60},
  [15885] = {.lex_state = 0},
  [15886] = {.lex_state = 0},
  [15887] = {.lex_state = 0, .external_lex_state = 25},
  [15888] = {.lex_state = 60},
  [15889] = {.lex_state = 0},
  [15890] = {.lex_state = 0},
  [15891] = {.lex_state = 60},
  [15892] = {.lex_state = 60},
  [15893] = {.lex_state = 0},
  [15894] = {.lex_state = 60},
  [15895] = {.lex_state = 0},
  [15896] = {.lex_state = 0},
  [15897] = {.lex_state = 0},
  [15898] = {.lex_state = 0},
  [15899] = {.lex_state = 0},
  [15900] = {.lex_state = 0},
  [15901] = {.lex_state = 60},
  [15902] = {.lex_state = 0},
  [15903] = {.lex_state = 60},
  [15904] = {.lex_state = 0},
  [15905] = {.lex_state = 0},
  [15906] = {.lex_state = 60},
  [15907] = {.lex_state = 60},
  [15908] = {.lex_state = 53},
  [15909] = {.lex_state = 0},
  [15910] = {.lex_state = 60, .external_lex_state = 64},
  [15911] = {.lex_state = 0},
  [15912] = {.lex_state = 60},
  [15913] = {.lex_state = 60},
  [15914] = {.lex_state = 60},
  [15915] = {.lex_state = 0, .external_lex_state = 25},
  [15916] = {.lex_state = 0},
  [15917] = {.lex_state = 60},
  [15918] = {.lex_state = 0},
  [15919] = {.lex_state = 0},
  [15920] = {.lex_state = 0},
  [15921] = {.lex_state = 60, .external_lex_state = 64},
  [15922] = {.lex_state = 0},
  [15923] = {.lex_state = 60},
  [15924] = {.lex_state = 0},
  [15925] = {.lex_state = 0},
  [15926] = {.lex_state = 0},
  [15927] = {.lex_state = 0},
  [15928] = {.lex_state = 0, .external_lex_state = 25},
  [15929] = {.lex_state = 60, .external_lex_state = 64},
  [15930] = {.lex_state = 0},
  [15931] = {.lex_state = 0},
  [15932] = {.lex_state = 60, .external_lex_state = 64},
  [15933] = {.lex_state = 0, .external_lex_state = 72},
  [15934] = {.lex_state = 60},
  [15935] = {.lex_state = 0},
  [15936] = {.lex_state = 60},
  [15937] = {.lex_state = 0},
  [15938] = {.lex_state = 60},
  [15939] = {.lex_state = 60},
  [15940] = {.lex_state = 0},
  [15941] = {.lex_state = 0},
  [15942] = {.lex_state = 0},
  [15943] = {.lex_state = 0},
  [15944] = {.lex_state = 60},
  [15945] = {.lex_state = 60, .external_lex_state = 64},
  [15946] = {.lex_state = 0, .external_lex_state = 25},
  [15947] = {.lex_state = 60},
  [15948] = {.lex_state = 60, .external_lex_state = 43},
  [15949] = {.lex_state = 60},
  [15950] = {.lex_state = 0},
  [15951] = {.lex_state = 0},
  [15952] = {.lex_state = 0},
  [15953] = {.lex_state = 0},
  [15954] = {.lex_state = 0, .external_lex_state = 25},
  [15955] = {.lex_state = 53},
  [15956] = {.lex_state = 0},
  [15957] = {.lex_state = 0},
  [15958] = {.lex_state = 0},
  [15959] = {.lex_state = 0},
  [15960] = {.lex_state = 0},
  [15961] = {.lex_state = 0},
  [15962] = {.lex_state = 0},
  [15963] = {.lex_state = 60},
  [15964] = {.lex_state = 60},
  [15965] = {.lex_state = 60},
  [15966] = {.lex_state = 60},
  [15967] = {.lex_state = 0},
  [15968] = {.lex_state = 0},
  [15969] = {.lex_state = 60},
  [15970] = {.lex_state = 0, .external_lex_state = 25},
  [15971] = {.lex_state = 0},
  [15972] = {.lex_state = 0},
  [15973] = {.lex_state = 0},
  [15974] = {.lex_state = 0},
  [15975] = {.lex_state = 0, .external_lex_state = 25},
  [15976] = {.lex_state = 53},
  [15977] = {.lex_state = 0, .external_lex_state = 25},
  [15978] = {.lex_state = 0},
  [15979] = {.lex_state = 60},
  [15980] = {.lex_state = 53},
  [15981] = {.lex_state = 0},
  [15982] = {.lex_state = 60},
  [15983] = {.lex_state = 0},
  [15984] = {.lex_state = 0, .external_lex_state = 73},
  [15985] = {.lex_state = 0},
  [15986] = {.lex_state = 0},
  [15987] = {.lex_state = 0},
  [15988] = {.lex_state = 0, .external_lex_state = 25},
  [15989] = {.lex_state = 60},
  [15990] = {.lex_state = 0},
  [15991] = {.lex_state = 0},
  [15992] = {.lex_state = 0},
  [15993] = {.lex_state = 0, .external_lex_state = 25},
  [15994] = {.lex_state = 0},
  [15995] = {.lex_state = 60},
  [15996] = {.lex_state = 60},
  [15997] = {.lex_state = 0},
  [15998] = {.lex_state = 0, .external_lex_state = 25},
  [15999] = {.lex_state = 60},
  [16000] = {.lex_state = 0, .external_lex_state = 73},
  [16001] = {.lex_state = 0},
  [16002] = {.lex_state = 0},
  [16003] = {.lex_state = 0},
  [16004] = {.lex_state = 60},
  [16005] = {.lex_state = 0},
  [16006] = {.lex_state = 0},
  [16007] = {.lex_state = 0, .external_lex_state = 25},
  [16008] = {.lex_state = 0, .external_lex_state = 25},
  [16009] = {.lex_state = 0},
  [16010] = {.lex_state = 60, .external_lex_state = 43},
  [16011] = {.lex_state = 60},
  [16012] = {.lex_state = 0, .external_lex_state = 25},
  [16013] = {.lex_state = 0},
  [16014] = {.lex_state = 0},
  [16015] = {.lex_state = 0},
  [16016] = {.lex_state = 53},
  [16017] = {.lex_state = 60, .external_lex_state = 43},
  [16018] = {.lex_state = 0},
  [16019] = {.lex_state = 0, .external_lex_state = 25},
  [16020] = {.lex_state = 0},
  [16021] = {.lex_state = 60},
  [16022] = {.lex_state = 60},
  [16023] = {.lex_state = 0},
  [16024] = {.lex_state = 0},
  [16025] = {.lex_state = 60, .external_lex_state = 64},
  [16026] = {.lex_state = 0},
  [16027] = {.lex_state = 60},
  [16028] = {.lex_state = 0, .external_lex_state = 25},
  [16029] = {.lex_state = 0, .external_lex_state = 25},
  [16030] = {.lex_state = 0},
  [16031] = {.lex_state = 60, .external_lex_state = 64},
  [16032] = {.lex_state = 0},
  [16033] = {.lex_state = 0},
  [16034] = {.lex_state = 0, .external_lex_state = 25},
  [16035] = {.lex_state = 0},
  [16036] = {.lex_state = 60},
  [16037] = {.lex_state = 0, .external_lex_state = 25},
  [16038] = {.lex_state = 0},
  [16039] = {.lex_state = 60},
  [16040] = {.lex_state = 0},
  [16041] = {.lex_state = 60},
  [16042] = {.lex_state = 0},
  [16043] = {.lex_state = 0},
  [16044] = {.lex_state = 0},
  [16045] = {.lex_state = 0},
  [16046] = {.lex_state = 60},
  [16047] = {.lex_state = 0, .external_lex_state = 25},
  [16048] = {.lex_state = 0},
  [16049] = {.lex_state = 0},
  [16050] = {.lex_state = 0},
  [16051] = {.lex_state = 0},
  [16052] = {.lex_state = 0},
  [16053] = {.lex_state = 0},
  [16054] = {.lex_state = 0},
  [16055] = {.lex_state = 0},
  [16056] = {.lex_state = 0},
  [16057] = {.lex_state = 0},
  [16058] = {.lex_state = 0, .external_lex_state = 25},
  [16059] = {.lex_state = 0},
  [16060] = {.lex_state = 60, .external_lex_state = 64},
  [16061] = {.lex_state = 60},
  [16062] = {.lex_state = 60},
  [16063] = {.lex_state = 60, .external_lex_state = 43},
  [16064] = {.lex_state = 0},
  [16065] = {.lex_state = 0},
  [16066] = {.lex_state = 0, .external_lex_state = 72},
  [16067] = {.lex_state = 0},
  [16068] = {.lex_state = 60, .external_lex_state = 64},
  [16069] = {.lex_state = 0},
  [16070] = {.lex_state = 53},
  [16071] = {.lex_state = 0, .external_lex_state = 73},
  [16072] = {.lex_state = 60},
  [16073] = {.lex_state = 60, .external_lex_state = 43},
  [16074] = {.lex_state = 0},
  [16075] = {.lex_state = 0},
  [16076] = {.lex_state = 0, .external_lex_state = 72},
  [16077] = {.lex_state = 0},
  [16078] = {.lex_state = 0, .external_lex_state = 72},
  [16079] = {.lex_state = 0, .external_lex_state = 73},
  [16080] = {.lex_state = 0, .external_lex_state = 72},
  [16081] = {.lex_state = 0, .external_lex_state = 73},
  [16082] = {.lex_state = 0},
  [16083] = {.lex_state = 0, .external_lex_state = 25},
  [16084] = {.lex_state = 0},
  [16085] = {.lex_state = 0},
  [16086] = {.lex_state = 0, .external_lex_state = 73},
  [16087] = {.lex_state = 0},
  [16088] = {.lex_state = 0},
  [16089] = {.lex_state = 60},
  [16090] = {.lex_state = 0},
  [16091] = {.lex_state = 0},
  [16092] = {.lex_state = 0},
  [16093] = {.lex_state = 60},
  [16094] = {.lex_state = 0},
  [16095] = {.lex_state = 1},
  [16096] = {.lex_state = 0},
  [16097] = {.lex_state = 60, .external_lex_state = 64},
  [16098] = {.lex_state = 60},
  [16099] = {.lex_state = 60},
  [16100] = {.lex_state = 60, .external_lex_state = 64},
  [16101] = {.lex_state = 0},
  [16102] = {.lex_state = 0},
  [16103] = {.lex_state = 0},
  [16104] = {.lex_state = 60},
  [16105] = {.lex_state = 0, .external_lex_state = 72},
  [16106] = {.lex_state = 60},
  [16107] = {.lex_state = 0},
  [16108] = {.lex_state = 0},
  [16109] = {.lex_state = 0},
  [16110] = {.lex_state = 0},
  [16111] = {.lex_state = 60},
  [16112] = {.lex_state = 60},
  [16113] = {.lex_state = 0},
  [16114] = {.lex_state = 0},
  [16115] = {.lex_state = 0},
  [16116] = {.lex_state = 0},
  [16117] = {.lex_state = 0},
  [16118] = {.lex_state = 0},
  [16119] = {.lex_state = 0},
  [16120] = {.lex_state = 60},
  [16121] = {.lex_state = 0},
  [16122] = {.lex_state = 60},
  [16123] = {.lex_state = 0},
  [16124] = {.lex_state = 0, .external_lex_state = 25},
  [16125] = {.lex_state = 0},
  [16126] = {.lex_state = 0},
  [16127] = {.lex_state = 0, .external_lex_state = 25},
  [16128] = {.lex_state = 60, .external_lex_state = 43},
  [16129] = {.lex_state = 0},
  [16130] = {.lex_state = 0},
  [16131] = {.lex_state = 0, .external_lex_state = 25},
  [16132] = {.lex_state = 0},
  [16133] = {.lex_state = 60},
  [16134] = {.lex_state = 0, .external_lex_state = 25},
  [16135] = {.lex_state = 0},
  [16136] = {.lex_state = 0},
  [16137] = {.lex_state = 60, .external_lex_state = 64},
  [16138] = {.lex_state = 0},
  [16139] = {.lex_state = 60, .external_lex_state = 43},
  [16140] = {.lex_state = 0},
  [16141] = {.lex_state = 60},
  [16142] = {.lex_state = 0},
  [16143] = {.lex_state = 60},
  [16144] = {.lex_state = 60, .external_lex_state = 64},
  [16145] = {.lex_state = 60},
  [16146] = {.lex_state = 0},
  [16147] = {.lex_state = 0},
  [16148] = {.lex_state = 0},
  [16149] = {.lex_state = 0, .external_lex_state = 64},
  [16150] = {.lex_state = 0},
  [16151] = {.lex_state = 6},
  [16152] = {.lex_state = 0},
  [16153] = {.lex_state = 60},
  [16154] = {.lex_state = 6},
  [16155] = {.lex_state = 0},
  [16156] = {.lex_state = 6},
  [16157] = {.lex_state = 0, .external_lex_state = 64},
  [16158] = {.lex_state = 0},
  [16159] = {.lex_state = 0},
  [16160] = {.lex_state = 60, .external_lex_state = 48},
  [16161] = {.lex_state = 60},
  [16162] = {.lex_state = 0},
  [16163] = {.lex_state = 0},
  [16164] = {.lex_state = 0, .external_lex_state = 64},
  [16165] = {.lex_state = 0},
  [16166] = {.lex_state = 60, .external_lex_state = 48},
  [16167] = {.lex_state = 0},
  [16168] = {.lex_state = 6},
  [16169] = {.lex_state = 0},
  [16170] = {.lex_state = 6},
  [16171] = {.lex_state = 6},
  [16172] = {.lex_state = 6},
  [16173] = {.lex_state = 0},
  [16174] = {.lex_state = 0, .external_lex_state = 64},
  [16175] = {.lex_state = 0},
  [16176] = {.lex_state = 0, .external_lex_state = 64},
  [16177] = {.lex_state = 0},
  [16178] = {.lex_state = 0},
  [16179] = {.lex_state = 0},
  [16180] = {.lex_state = 0},
  [16181] = {.lex_state = 0},
  [16182] = {.lex_state = 0, .external_lex_state = 64},
  [16183] = {.lex_state = 0, .external_lex_state = 64},
  [16184] = {.lex_state = 0},
  [16185] = {.lex_state = 0},
  [16186] = {.lex_state = 0},
  [16187] = {.lex_state = 0, .external_lex_state = 64},
  [16188] = {.lex_state = 0},
  [16189] = {.lex_state = 0},
  [16190] = {.lex_state = 60, .external_lex_state = 48},
  [16191] = {.lex_state = 0},
  [16192] = {.lex_state = 0},
  [16193] = {.lex_state = 60, .external_lex_state = 48},
  [16194] = {.lex_state = 60, .external_lex_state = 48},
  [16195] = {.lex_state = 0},
  [16196] = {.lex_state = 0},
  [16197] = {.lex_state = 0, .external_lex_state = 64},
  [16198] = {.lex_state = 6},
  [16199] = {.lex_state = 0, .external_lex_state = 64},
  [16200] = {.lex_state = 6},
  [16201] = {.lex_state = 6},
  [16202] = {.lex_state = 6},
  [16203] = {.lex_state = 60},
  [16204] = {.lex_state = 0},
  [16205] = {.lex_state = 0, .external_lex_state = 64},
  [16206] = {.lex_state = 0},
  [16207] = {.lex_state = 0},
  [16208] = {.lex_state = 0},
  [16209] = {.lex_state = 0, .external_lex_state = 64},
  [16210] = {.lex_state = 60, .external_lex_state = 48},
  [16211] = {.lex_state = 0},
  [16212] = {.lex_state = 0},
  [16213] = {.lex_state = 0, .external_lex_state = 64},
  [16214] = {.lex_state = 0, .external_lex_state = 64},
  [16215] = {.lex_state = 0},
  [16216] = {.lex_state = 0},
  [16217] = {.lex_state = 0},
  [16218] = {.lex_state = 0},
  [16219] = {.lex_state = 0, .external_lex_state = 64},
  [16220] = {.lex_state = 60, .external_lex_state = 48},
  [16221] = {.lex_state = 0},
  [16222] = {.lex_state = 60, .external_lex_state = 48},
  [16223] = {.lex_state = 0},
  [16224] = {.lex_state = 0},
  [16225] = {.lex_state = 0},
  [16226] = {.lex_state = 0, .external_lex_state = 64},
  [16227] = {.lex_state = 60},
  [16228] = {.lex_state = 6},
  [16229] = {.lex_state = 0, .external_lex_state = 64},
  [16230] = {.lex_state = 6},
  [16231] = {.lex_state = 6},
  [16232] = {.lex_state = 6},
  [16233] = {.lex_state = 0, .external_lex_state = 64},
  [16234] = {.lex_state = 0},
  [16235] = {.lex_state = 0},
  [16236] = {.lex_state = 0, .external_lex_state = 64},
  [16237] = {.lex_state = 0},
  [16238] = {.lex_state = 0},
  [16239] = {.lex_state = 0},
  [16240] = {.lex_state = 0},
  [16241] = {.lex_state = 0},
  [16242] = {.lex_state = 0},
  [16243] = {.lex_state = 0, .external_lex_state = 64},
  [16244] = {.lex_state = 60, .external_lex_state = 48},
  [16245] = {.lex_state = 0},
  [16246] = {.lex_state = 0},
  [16247] = {.lex_state = 0, .external_lex_state = 64},
  [16248] = {.lex_state = 0},
  [16249] = {.lex_state = 0, .external_lex_state = 64},
  [16250] = {.lex_state = 0, .external_lex_state = 64},
  [16251] = {.lex_state = 0, .external_lex_state = 64},
  [16252] = {.lex_state = 0, .external_lex_state = 64},
  [16253] = {.lex_state = 0, .external_lex_state = 64},
  [16254] = {.lex_state = 60},
  [16255] = {.lex_state = 0},
  [16256] = {.lex_state = 0},
  [16257] = {.lex_state = 0},
  [16258] = {.lex_state = 6},
  [16259] = {.lex_state = 0},
  [16260] = {.lex_state = 6},
  [16261] = {.lex_state = 6},
  [16262] = {.lex_state = 6},
  [16263] = {.lex_state = 0},
  [16264] = {.lex_state = 60},
  [16265] = {.lex_state = 0},
  [16266] = {.lex_state = 0},
  [16267] = {.lex_state = 60, .external_lex_state = 43},
  [16268] = {.lex_state = 0},
  [16269] = {.lex_state = 0},
  [16270] = {.lex_state = 0, .external_lex_state = 64},
  [16271] = {.lex_state = 0, .external_lex_state = 64},
  [16272] = {.lex_state = 0},
  [16273] = {.lex_state = 0},
  [16274] = {.lex_state = 0},
  [16275] = {.lex_state = 0},
  [16276] = {.lex_state = 0, .external_lex_state = 64},
  [16277] = {.lex_state = 0},
  [16278] = {.lex_state = 0},
  [16279] = {.lex_state = 60},
  [16280] = {.lex_state = 0, .external_lex_state = 64},
  [16281] = {.lex_state = 0},
  [16282] = {.lex_state = 0},
  [16283] = {.lex_state = 0},
  [16284] = {.lex_state = 0},
  [16285] = {.lex_state = 6},
  [16286] = {.lex_state = 60, .external_lex_state = 48},
  [16287] = {.lex_state = 6},
  [16288] = {.lex_state = 6},
  [16289] = {.lex_state = 6},
  [16290] = {.lex_state = 0},
  [16291] = {.lex_state = 0},
  [16292] = {.lex_state = 0},
  [16293] = {.lex_state = 0},
  [16294] = {.lex_state = 0},
  [16295] = {.lex_state = 0},
  [16296] = {.lex_state = 0},
  [16297] = {.lex_state = 0},
  [16298] = {.lex_state = 0},
  [16299] = {.lex_state = 0},
  [16300] = {.lex_state = 0},
  [16301] = {.lex_state = 0},
  [16302] = {.lex_state = 0},
  [16303] = {.lex_state = 0},
  [16304] = {.lex_state = 0},
  [16305] = {.lex_state = 0, .external_lex_state = 64},
  [16306] = {.lex_state = 0},
  [16307] = {.lex_state = 0},
  [16308] = {.lex_state = 60},
  [16309] = {.lex_state = 6},
  [16310] = {.lex_state = 0},
  [16311] = {.lex_state = 6},
  [16312] = {.lex_state = 6},
  [16313] = {.lex_state = 6},
  [16314] = {.lex_state = 0},
  [16315] = {.lex_state = 60, .external_lex_state = 48},
  [16316] = {.lex_state = 0},
  [16317] = {.lex_state = 0},
  [16318] = {.lex_state = 60},
  [16319] = {.lex_state = 0},
  [16320] = {.lex_state = 60, .external_lex_state = 48},
  [16321] = {.lex_state = 0},
  [16322] = {.lex_state = 0},
  [16323] = {.lex_state = 60, .external_lex_state = 48},
  [16324] = {.lex_state = 0},
  [16325] = {.lex_state = 0},
  [16326] = {.lex_state = 0, .external_lex_state = 64},
  [16327] = {.lex_state = 0},
  [16328] = {.lex_state = 0},
  [16329] = {.lex_state = 0, .external_lex_state = 64},
  [16330] = {.lex_state = 0},
  [16331] = {.lex_state = 0, .external_lex_state = 64},
  [16332] = {.lex_state = 0},
  [16333] = {.lex_state = 6},
  [16334] = {.lex_state = 6},
  [16335] = {.lex_state = 6},
  [16336] = {.lex_state = 6},
  [16337] = {.lex_state = 0, .external_lex_state = 64},
  [16338] = {.lex_state = 0},
  [16339] = {.lex_state = 0},
  [16340] = {.lex_state = 0},
  [16341] = {.lex_state = 0},
  [16342] = {.lex_state = 25},
  [16343] = {.lex_state = 60},
  [16344] = {.lex_state = 0, .external_lex_state = 64},
  [16345] = {.lex_state = 60},
  [16346] = {.lex_state = 0, .external_lex_state = 64},
  [16347] = {.lex_state = 0},
  [16348] = {.lex_state = 0},
  [16349] = {.lex_state = 0, .external_lex_state = 64},
  [16350] = {.lex_state = 0},
  [16351] = {.lex_state = 0, .external_lex_state = 64},
  [16352] = {.lex_state = 0},
  [16353] = {.lex_state = 0},
  [16354] = {.lex_state = 0, .external_lex_state = 64},
  [16355] = {.lex_state = 60},
  [16356] = {.lex_state = 6},
  [16357] = {.lex_state = 6},
  [16358] = {.lex_state = 6},
  [16359] = {.lex_state = 6},
  [16360] = {.lex_state = 0},
  [16361] = {.lex_state = 0},
  [16362] = {.lex_state = 0},
  [16363] = {.lex_state = 0},
  [16364] = {.lex_state = 60, .external_lex_state = 48},
  [16365] = {.lex_state = 0, .external_lex_state = 64},
  [16366] = {.lex_state = 0},
  [16367] = {.lex_state = 0},
  [16368] = {.lex_state = 0, .external_lex_state = 64},
  [16369] = {.lex_state = 0, .external_lex_state = 64},
  [16370] = {.lex_state = 0},
  [16371] = {.lex_state = 0},
  [16372] = {.lex_state = 0},
  [16373] = {.lex_state = 0},
  [16374] = {.lex_state = 0},
  [16375] = {.lex_state = 0},
  [16376] = {.lex_state = 6},
  [16377] = {.lex_state = 6},
  [16378] = {.lex_state = 6},
  [16379] = {.lex_state = 6},
  [16380] = {.lex_state = 60, .external_lex_state = 48},
  [16381] = {.lex_state = 0, .external_lex_state = 64},
  [16382] = {.lex_state = 0},
  [16383] = {.lex_state = 0},
  [16384] = {.lex_state = 0},
  [16385] = {.lex_state = 0},
  [16386] = {.lex_state = 0},
  [16387] = {.lex_state = 0},
  [16388] = {.lex_state = 0, .external_lex_state = 64},
  [16389] = {.lex_state = 0, .external_lex_state = 64},
  [16390] = {.lex_state = 0},
  [16391] = {.lex_state = 0},
  [16392] = {.lex_state = 0},
  [16393] = {.lex_state = 60},
  [16394] = {.lex_state = 0},
  [16395] = {.lex_state = 53},
  [16396] = {.lex_state = 0},
  [16397] = {.lex_state = 6},
  [16398] = {.lex_state = 6},
  [16399] = {.lex_state = 6},
  [16400] = {.lex_state = 6},
  [16401] = {.lex_state = 53},
  [16402] = {.lex_state = 6},
  [16403] = {.lex_state = 0},
  [16404] = {.lex_state = 0},
  [16405] = {.lex_state = 60, .external_lex_state = 48},
  [16406] = {.lex_state = 0},
  [16407] = {.lex_state = 0},
  [16408] = {.lex_state = 0},
  [16409] = {.lex_state = 0, .external_lex_state = 64},
  [16410] = {.lex_state = 0},
  [16411] = {.lex_state = 0},
  [16412] = {.lex_state = 0},
  [16413] = {.lex_state = 0},
  [16414] = {.lex_state = 0},
  [16415] = {.lex_state = 6},
  [16416] = {.lex_state = 0},
  [16417] = {.lex_state = 60, .external_lex_state = 48},
  [16418] = {.lex_state = 6},
  [16419] = {.lex_state = 6},
  [16420] = {.lex_state = 6},
  [16421] = {.lex_state = 6},
  [16422] = {.lex_state = 0},
  [16423] = {.lex_state = 6},
  [16424] = {.lex_state = 0},
  [16425] = {.lex_state = 0},
  [16426] = {.lex_state = 0, .external_lex_state = 64},
  [16427] = {.lex_state = 0},
  [16428] = {.lex_state = 0},
  [16429] = {.lex_state = 0},
  [16430] = {.lex_state = 6},
  [16431] = {.lex_state = 6},
  [16432] = {.lex_state = 0},
  [16433] = {.lex_state = 0, .external_lex_state = 64},
  [16434] = {.lex_state = 0, .external_lex_state = 64},
  [16435] = {.lex_state = 0},
  [16436] = {.lex_state = 0},
  [16437] = {.lex_state = 0},
  [16438] = {.lex_state = 0, .external_lex_state = 64},
  [16439] = {.lex_state = 6},
  [16440] = {.lex_state = 6},
  [16441] = {.lex_state = 6},
  [16442] = {.lex_state = 6},
  [16443] = {.lex_state = 0, .external_lex_state = 64},
  [16444] = {.lex_state = 0},
  [16445] = {.lex_state = 0},
  [16446] = {.lex_state = 0},
  [16447] = {.lex_state = 0},
  [16448] = {.lex_state = 0, .external_lex_state = 64},
  [16449] = {.lex_state = 6},
  [16450] = {.lex_state = 0, .external_lex_state = 64},
  [16451] = {.lex_state = 0, .external_lex_state = 64},
  [16452] = {.lex_state = 60, .external_lex_state = 48},
  [16453] = {.lex_state = 0},
  [16454] = {.lex_state = 0},
  [16455] = {.lex_state = 0, .external_lex_state = 64},
  [16456] = {.lex_state = 0, .external_lex_state = 64},
  [16457] = {.lex_state = 0},
  [16458] = {.lex_state = 0},
  [16459] = {.lex_state = 60, .external_lex_state = 48},
  [16460] = {.lex_state = 6},
  [16461] = {.lex_state = 6},
  [16462] = {.lex_state = 6},
  [16463] = {.lex_state = 6},
  [16464] = {.lex_state = 0},
  [16465] = {.lex_state = 0, .external_lex_state = 64},
  [16466] = {.lex_state = 0},
  [16467] = {.lex_state = 0},
  [16468] = {.lex_state = 0},
  [16469] = {.lex_state = 0},
  [16470] = {.lex_state = 0},
  [16471] = {.lex_state = 0},
  [16472] = {.lex_state = 0},
  [16473] = {.lex_state = 0, .external_lex_state = 64},
  [16474] = {.lex_state = 60, .external_lex_state = 48},
  [16475] = {.lex_state = 0, .external_lex_state = 64},
  [16476] = {.lex_state = 0},
  [16477] = {.lex_state = 0},
  [16478] = {.lex_state = 0, .external_lex_state = 64},
  [16479] = {.lex_state = 0},
  [16480] = {.lex_state = 0, .external_lex_state = 64},
  [16481] = {.lex_state = 6},
  [16482] = {.lex_state = 6},
  [16483] = {.lex_state = 6},
  [16484] = {.lex_state = 6},
  [16485] = {.lex_state = 0, .external_lex_state = 64},
  [16486] = {.lex_state = 0},
  [16487] = {.lex_state = 0},
  [16488] = {.lex_state = 0},
  [16489] = {.lex_state = 0},
  [16490] = {.lex_state = 60, .external_lex_state = 48},
  [16491] = {.lex_state = 0},
  [16492] = {.lex_state = 0},
  [16493] = {.lex_state = 0},
  [16494] = {.lex_state = 0, .external_lex_state = 64},
  [16495] = {.lex_state = 60, .external_lex_state = 48},
  [16496] = {.lex_state = 0},
  [16497] = {.lex_state = 0},
  [16498] = {.lex_state = 0, .external_lex_state = 64},
  [16499] = {.lex_state = 6},
  [16500] = {.lex_state = 0},
  [16501] = {.lex_state = 6},
  [16502] = {.lex_state = 6},
  [16503] = {.lex_state = 6},
  [16504] = {.lex_state = 6},
  [16505] = {.lex_state = 6},
  [16506] = {.lex_state = 0},
  [16507] = {.lex_state = 60, .external_lex_state = 48},
  [16508] = {.lex_state = 0},
  [16509] = {.lex_state = 0},
  [16510] = {.lex_state = 0},
  [16511] = {.lex_state = 0},
  [16512] = {.lex_state = 0},
  [16513] = {.lex_state = 0, .external_lex_state = 64},
  [16514] = {.lex_state = 0},
  [16515] = {.lex_state = 60, .external_lex_state = 48},
  [16516] = {.lex_state = 0, .external_lex_state = 64},
  [16517] = {.lex_state = 0, .external_lex_state = 64},
  [16518] = {.lex_state = 0},
  [16519] = {.lex_state = 6},
  [16520] = {.lex_state = 0, .external_lex_state = 64},
  [16521] = {.lex_state = 60, .external_lex_state = 48},
  [16522] = {.lex_state = 0},
  [16523] = {.lex_state = 6},
  [16524] = {.lex_state = 6},
  [16525] = {.lex_state = 6},
  [16526] = {.lex_state = 6},
  [16527] = {.lex_state = 6},
  [16528] = {.lex_state = 0, .external_lex_state = 64},
  [16529] = {.lex_state = 0},
  [16530] = {.lex_state = 0},
  [16531] = {.lex_state = 60},
  [16532] = {.lex_state = 60, .external_lex_state = 48},
  [16533] = {.lex_state = 0},
  [16534] = {.lex_state = 0},
  [16535] = {.lex_state = 0},
  [16536] = {.lex_state = 0},
  [16537] = {.lex_state = 0},
  [16538] = {.lex_state = 0, .external_lex_state = 64},
  [16539] = {.lex_state = 0, .external_lex_state = 64},
  [16540] = {.lex_state = 0},
  [16541] = {.lex_state = 0},
  [16542] = {.lex_state = 0},
  [16543] = {.lex_state = 6},
  [16544] = {.lex_state = 6},
  [16545] = {.lex_state = 6},
  [16546] = {.lex_state = 6},
  [16547] = {.lex_state = 0},
  [16548] = {.lex_state = 0},
  [16549] = {.lex_state = 0},
  [16550] = {.lex_state = 0},
  [16551] = {.lex_state = 60},
  [16552] = {.lex_state = 60},
  [16553] = {.lex_state = 0},
  [16554] = {.lex_state = 0, .external_lex_state = 64},
  [16555] = {.lex_state = 0},
  [16556] = {.lex_state = 0},
  [16557] = {.lex_state = 60},
  [16558] = {.lex_state = 60, .external_lex_state = 48},
  [16559] = {.lex_state = 0},
  [16560] = {.lex_state = 0},
  [16561] = {.lex_state = 0, .external_lex_state = 64},
  [16562] = {.lex_state = 0},
  [16563] = {.lex_state = 6},
  [16564] = {.lex_state = 6},
  [16565] = {.lex_state = 6},
  [16566] = {.lex_state = 6},
  [16567] = {.lex_state = 0, .external_lex_state = 64},
  [16568] = {.lex_state = 0},
  [16569] = {.lex_state = 0},
  [16570] = {.lex_state = 0},
  [16571] = {.lex_state = 0},
  [16572] = {.lex_state = 60, .external_lex_state = 48},
  [16573] = {.lex_state = 6},
  [16574] = {.lex_state = 0},
  [16575] = {.lex_state = 60, .external_lex_state = 48},
  [16576] = {.lex_state = 0, .external_lex_state = 64},
  [16577] = {.lex_state = 0},
  [16578] = {.lex_state = 0},
  [16579] = {.lex_state = 0, .external_lex_state = 64},
  [16580] = {.lex_state = 6},
  [16581] = {.lex_state = 0},
  [16582] = {.lex_state = 0},
  [16583] = {.lex_state = 6},
  [16584] = {.lex_state = 6},
  [16585] = {.lex_state = 6},
  [16586] = {.lex_state = 6},
  [16587] = {.lex_state = 60, .external_lex_state = 48},
  [16588] = {.lex_state = 6},
  [16589] = {.lex_state = 0},
  [16590] = {.lex_state = 0},
  [16591] = {.lex_state = 6},
  [16592] = {.lex_state = 0},
  [16593] = {.lex_state = 0, .external_lex_state = 64},
  [16594] = {.lex_state = 60, .external_lex_state = 48},
  [16595] = {.lex_state = 0},
  [16596] = {.lex_state = 0},
  [16597] = {.lex_state = 0},
  [16598] = {.lex_state = 0, .external_lex_state = 64},
  [16599] = {.lex_state = 0},
  [16600] = {.lex_state = 0},
  [16601] = {.lex_state = 0, .external_lex_state = 64},
  [16602] = {.lex_state = 0},
  [16603] = {.lex_state = 6},
  [16604] = {.lex_state = 6},
  [16605] = {.lex_state = 6},
  [16606] = {.lex_state = 6},
  [16607] = {.lex_state = 60, .external_lex_state = 48},
  [16608] = {.lex_state = 0},
  [16609] = {.lex_state = 0},
  [16610] = {.lex_state = 0},
  [16611] = {.lex_state = 0},
  [16612] = {.lex_state = 0},
  [16613] = {.lex_state = 0, .external_lex_state = 64},
  [16614] = {.lex_state = 0, .external_lex_state = 64},
  [16615] = {.lex_state = 60},
  [16616] = {.lex_state = 0},
  [16617] = {.lex_state = 0, .external_lex_state = 64},
  [16618] = {.lex_state = 0},
  [16619] = {.lex_state = 0},
  [16620] = {.lex_state = 0},
  [16621] = {.lex_state = 0},
  [16622] = {.lex_state = 0, .external_lex_state = 64},
  [16623] = {.lex_state = 6},
  [16624] = {.lex_state = 6},
  [16625] = {.lex_state = 6},
  [16626] = {.lex_state = 6},
  [16627] = {.lex_state = 0, .external_lex_state = 64},
  [16628] = {.lex_state = 0},
  [16629] = {.lex_state = 0},
  [16630] = {.lex_state = 0},
  [16631] = {.lex_state = 0, .external_lex_state = 64},
  [16632] = {.lex_state = 0},
  [16633] = {.lex_state = 0},
  [16634] = {.lex_state = 0, .external_lex_state = 64},
  [16635] = {.lex_state = 60, .external_lex_state = 48},
  [16636] = {.lex_state = 60},
  [16637] = {.lex_state = 0},
  [16638] = {.lex_state = 0},
  [16639] = {.lex_state = 0},
  [16640] = {.lex_state = 0},
  [16641] = {.lex_state = 0, .external_lex_state = 64},
  [16642] = {.lex_state = 0, .external_lex_state = 64},
  [16643] = {.lex_state = 6},
  [16644] = {.lex_state = 6},
  [16645] = {.lex_state = 6},
  [16646] = {.lex_state = 6},
  [16647] = {.lex_state = 0},
  [16648] = {.lex_state = 60},
  [16649] = {.lex_state = 0},
  [16650] = {.lex_state = 0},
  [16651] = {.lex_state = 0},
  [16652] = {.lex_state = 0},
  [16653] = {.lex_state = 0},
  [16654] = {.lex_state = 0, .external_lex_state = 64},
  [16655] = {.lex_state = 60, .external_lex_state = 48},
  [16656] = {.lex_state = 0},
  [16657] = {.lex_state = 60, .external_lex_state = 48},
  [16658] = {.lex_state = 0},
  [16659] = {.lex_state = 0, .external_lex_state = 64},
  [16660] = {.lex_state = 0},
  [16661] = {.lex_state = 0},
  [16662] = {.lex_state = 0},
  [16663] = {.lex_state = 6},
  [16664] = {.lex_state = 6},
  [16665] = {.lex_state = 6},
  [16666] = {.lex_state = 6},
  [16667] = {.lex_state = 0, .external_lex_state = 64},
  [16668] = {.lex_state = 0, .external_lex_state = 64},
  [16669] = {.lex_state = 0},
  [16670] = {.lex_state = 0},
  [16671] = {.lex_state = 0},
  [16672] = {.lex_state = 0},
  [16673] = {.lex_state = 0, .external_lex_state = 64},
  [16674] = {.lex_state = 0},
  [16675] = {.lex_state = 60},
  [16676] = {.lex_state = 0, .external_lex_state = 64},
  [16677] = {.lex_state = 0},
  [16678] = {.lex_state = 0, .external_lex_state = 64},
  [16679] = {.lex_state = 0},
  [16680] = {.lex_state = 0, .external_lex_state = 64},
  [16681] = {.lex_state = 0},
  [16682] = {.lex_state = 6},
  [16683] = {.lex_state = 6},
  [16684] = {.lex_state = 6},
  [16685] = {.lex_state = 6},
  [16686] = {.lex_state = 60, .external_lex_state = 48},
  [16687] = {.lex_state = 60},
  [16688] = {.lex_state = 0},
  [16689] = {.lex_state = 0},
  [16690] = {.lex_state = 0},
  [16691] = {.lex_state = 0},
  [16692] = {.lex_state = 60, .external_lex_state = 48},
  [16693] = {.lex_state = 60, .external_lex_state = 43},
  [16694] = {.lex_state = 60, .external_lex_state = 48},
  [16695] = {.lex_state = 0},
  [16696] = {.lex_state = 0},
  [16697] = {.lex_state = 0, .external_lex_state = 64},
  [16698] = {.lex_state = 0, .external_lex_state = 64},
  [16699] = {.lex_state = 0},
  [16700] = {.lex_state = 0, .external_lex_state = 64},
  [16701] = {.lex_state = 6},
  [16702] = {.lex_state = 6},
  [16703] = {.lex_state = 6},
  [16704] = {.lex_state = 6},
  [16705] = {.lex_state = 60, .external_lex_state = 48},
  [16706] = {.lex_state = 0},
  [16707] = {.lex_state = 0},
  [16708] = {.lex_state = 0},
  [16709] = {.lex_state = 0},
  [16710] = {.lex_state = 0},
  [16711] = {.lex_state = 0},
  [16712] = {.lex_state = 0},
  [16713] = {.lex_state = 0},
  [16714] = {.lex_state = 60},
  [16715] = {.lex_state = 0, .external_lex_state = 64},
  [16716] = {.lex_state = 60, .external_lex_state = 48},
  [16717] = {.lex_state = 0, .external_lex_state = 64},
  [16718] = {.lex_state = 0},
  [16719] = {.lex_state = 0},
  [16720] = {.lex_state = 6},
  [16721] = {.lex_state = 6},
  [16722] = {.lex_state = 6},
  [16723] = {.lex_state = 6},
  [16724] = {.lex_state = 0},
  [16725] = {.lex_state = 60},
  [16726] = {.lex_state = 0},
  [16727] = {.lex_state = 0},
  [16728] = {.lex_state = 0},
  [16729] = {.lex_state = 0},
  [16730] = {.lex_state = 6},
  [16731] = {.lex_state = 6},
  [16732] = {.lex_state = 0},
  [16733] = {.lex_state = 0},
  [16734] = {.lex_state = 6},
  [16735] = {.lex_state = 6},
  [16736] = {.lex_state = 6},
  [16737] = {.lex_state = 0},
  [16738] = {.lex_state = 60},
  [16739] = {.lex_state = 6},
  [16740] = {.lex_state = 6},
  [16741] = {.lex_state = 6},
  [16742] = {.lex_state = 6},
  [16743] = {.lex_state = 0, .external_lex_state = 64},
  [16744] = {.lex_state = 0},
  [16745] = {.lex_state = 0},
  [16746] = {.lex_state = 0},
  [16747] = {.lex_state = 0, .external_lex_state = 64},
  [16748] = {.lex_state = 0},
  [16749] = {.lex_state = 0},
  [16750] = {.lex_state = 0, .external_lex_state = 64},
  [16751] = {.lex_state = 0},
  [16752] = {.lex_state = 0},
  [16753] = {.lex_state = 60, .external_lex_state = 48},
  [16754] = {.lex_state = 0},
  [16755] = {.lex_state = 0, .external_lex_state = 64},
  [16756] = {.lex_state = 0},
  [16757] = {.lex_state = 0},
  [16758] = {.lex_state = 6},
  [16759] = {.lex_state = 6},
  [16760] = {.lex_state = 6},
  [16761] = {.lex_state = 6},
  [16762] = {.lex_state = 0, .external_lex_state = 64},
  [16763] = {.lex_state = 0},
  [16764] = {.lex_state = 0},
  [16765] = {.lex_state = 0},
  [16766] = {.lex_state = 0},
  [16767] = {.lex_state = 0},
  [16768] = {.lex_state = 0},
  [16769] = {.lex_state = 0, .external_lex_state = 64},
  [16770] = {.lex_state = 0},
  [16771] = {.lex_state = 60, .external_lex_state = 48},
  [16772] = {.lex_state = 0},
  [16773] = {.lex_state = 0},
  [16774] = {.lex_state = 0},
  [16775] = {.lex_state = 0},
  [16776] = {.lex_state = 6},
  [16777] = {.lex_state = 6},
  [16778] = {.lex_state = 6},
  [16779] = {.lex_state = 6},
  [16780] = {.lex_state = 0, .external_lex_state = 64},
  [16781] = {.lex_state = 0, .external_lex_state = 64},
  [16782] = {.lex_state = 0},
  [16783] = {.lex_state = 0},
  [16784] = {.lex_state = 0},
  [16785] = {.lex_state = 0},
  [16786] = {.lex_state = 0, .external_lex_state = 64},
  [16787] = {.lex_state = 0, .external_lex_state = 64},
  [16788] = {.lex_state = 60, .external_lex_state = 48},
  [16789] = {.lex_state = 0},
  [16790] = {.lex_state = 0, .external_lex_state = 64},
  [16791] = {.lex_state = 0},
  [16792] = {.lex_state = 0},
  [16793] = {.lex_state = 0},
  [16794] = {.lex_state = 6},
  [16795] = {.lex_state = 6},
  [16796] = {.lex_state = 6},
  [16797] = {.lex_state = 6},
  [16798] = {.lex_state = 0, .external_lex_state = 64},
  [16799] = {.lex_state = 0},
  [16800] = {.lex_state = 0},
  [16801] = {.lex_state = 0, .external_lex_state = 64},
  [16802] = {.lex_state = 0},
  [16803] = {.lex_state = 0, .external_lex_state = 64},
  [16804] = {.lex_state = 0},
  [16805] = {.lex_state = 0},
  [16806] = {.lex_state = 60, .external_lex_state = 48},
  [16807] = {.lex_state = 0},
  [16808] = {.lex_state = 0},
  [16809] = {.lex_state = 0},
  [16810] = {.lex_state = 0},
  [16811] = {.lex_state = 0},
  [16812] = {.lex_state = 6},
  [16813] = {.lex_state = 6},
  [16814] = {.lex_state = 6},
  [16815] = {.lex_state = 6},
  [16816] = {.lex_state = 60},
  [16817] = {.lex_state = 0},
  [16818] = {.lex_state = 0},
  [16819] = {.lex_state = 60},
  [16820] = {.lex_state = 60},
  [16821] = {.lex_state = 0},
  [16822] = {.lex_state = 0},
  [16823] = {.lex_state = 0, .external_lex_state = 64},
  [16824] = {.lex_state = 0},
  [16825] = {.lex_state = 0},
  [16826] = {.lex_state = 0},
  [16827] = {.lex_state = 0},
  [16828] = {.lex_state = 0},
  [16829] = {.lex_state = 0},
  [16830] = {.lex_state = 6},
  [16831] = {.lex_state = 6},
  [16832] = {.lex_state = 6},
  [16833] = {.lex_state = 6},
  [16834] = {.lex_state = 6},
  [16835] = {.lex_state = 0},
  [16836] = {.lex_state = 60},
  [16837] = {.lex_state = 0},
  [16838] = {.lex_state = 0, .external_lex_state = 64},
  [16839] = {.lex_state = 6},
  [16840] = {.lex_state = 6},
  [16841] = {.lex_state = 0},
  [16842] = {.lex_state = 0},
  [16843] = {.lex_state = 0, .external_lex_state = 64},
  [16844] = {.lex_state = 0},
  [16845] = {.lex_state = 6},
  [16846] = {.lex_state = 0},
  [16847] = {.lex_state = 6},
  [16848] = {.lex_state = 6},
  [16849] = {.lex_state = 6},
  [16850] = {.lex_state = 6},
  [16851] = {.lex_state = 0},
  [16852] = {.lex_state = 0, .external_lex_state = 64},
  [16853] = {.lex_state = 0},
  [16854] = {.lex_state = 0},
  [16855] = {.lex_state = 0, .external_lex_state = 64},
  [16856] = {.lex_state = 60, .external_lex_state = 48},
  [16857] = {.lex_state = 0, .external_lex_state = 64},
  [16858] = {.lex_state = 0, .external_lex_state = 64},
  [16859] = {.lex_state = 60, .external_lex_state = 43},
  [16860] = {.lex_state = 60, .external_lex_state = 48},
  [16861] = {.lex_state = 0},
  [16862] = {.lex_state = 60, .external_lex_state = 48},
  [16863] = {.lex_state = 0},
  [16864] = {.lex_state = 0},
  [16865] = {.lex_state = 6},
  [16866] = {.lex_state = 6},
  [16867] = {.lex_state = 6},
  [16868] = {.lex_state = 6},
  [16869] = {.lex_state = 0},
  [16870] = {.lex_state = 0},
  [16871] = {.lex_state = 0},
  [16872] = {.lex_state = 0},
  [16873] = {.lex_state = 0},
  [16874] = {.lex_state = 0, .external_lex_state = 64},
  [16875] = {.lex_state = 0, .external_lex_state = 64},
  [16876] = {.lex_state = 0, .external_lex_state = 64},
  [16877] = {.lex_state = 0},
  [16878] = {.lex_state = 0, .external_lex_state = 64},
  [16879] = {.lex_state = 0},
  [16880] = {.lex_state = 0, .external_lex_state = 64},
  [16881] = {.lex_state = 60},
  [16882] = {.lex_state = 60},
  [16883] = {.lex_state = 6},
  [16884] = {.lex_state = 6},
  [16885] = {.lex_state = 6},
  [16886] = {.lex_state = 6},
  [16887] = {.lex_state = 60, .external_lex_state = 48},
  [16888] = {.lex_state = 0},
  [16889] = {.lex_state = 0},
  [16890] = {.lex_state = 0},
  [16891] = {.lex_state = 0},
  [16892] = {.lex_state = 0},
  [16893] = {.lex_state = 0},
  [16894] = {.lex_state = 0, .external_lex_state = 64},
  [16895] = {.lex_state = 0},
  [16896] = {.lex_state = 0},
  [16897] = {.lex_state = 0},
  [16898] = {.lex_state = 60, .external_lex_state = 48},
  [16899] = {.lex_state = 0, .external_lex_state = 64},
  [16900] = {.lex_state = 0},
  [16901] = {.lex_state = 6},
  [16902] = {.lex_state = 6},
  [16903] = {.lex_state = 6},
  [16904] = {.lex_state = 6},
  [16905] = {.lex_state = 0},
  [16906] = {.lex_state = 0},
  [16907] = {.lex_state = 0, .external_lex_state = 64},
  [16908] = {.lex_state = 0},
  [16909] = {.lex_state = 0},
  [16910] = {.lex_state = 0},
  [16911] = {.lex_state = 60, .external_lex_state = 48},
  [16912] = {.lex_state = 0, .external_lex_state = 64},
  [16913] = {.lex_state = 6},
  [16914] = {.lex_state = 6},
  [16915] = {.lex_state = 6},
  [16916] = {.lex_state = 6},
  [16917] = {.lex_state = 0},
  [16918] = {.lex_state = 0},
  [16919] = {.lex_state = 0},
  [16920] = {.lex_state = 60},
  [16921] = {.lex_state = 0},
  [16922] = {.lex_state = 0, .external_lex_state = 64},
  [16923] = {.lex_state = 60},
  [16924] = {.lex_state = 0},
  [16925] = {.lex_state = 6},
  [16926] = {.lex_state = 6},
  [16927] = {.lex_state = 6},
  [16928] = {.lex_state = 6},
  [16929] = {.lex_state = 0},
  [16930] = {.lex_state = 6},
  [16931] = {.lex_state = 0},
  [16932] = {.lex_state = 0, .external_lex_state = 64},
  [16933] = {.lex_state = 6},
  [16934] = {.lex_state = 6},
  [16935] = {.lex_state = 0, .external_lex_state = 64},
  [16936] = {.lex_state = 0},
  [16937] = {.lex_state = 6},
  [16938] = {.lex_state = 6},
  [16939] = {.lex_state = 6},
  [16940] = {.lex_state = 6},
  [16941] = {.lex_state = 0},
  [16942] = {.lex_state = 6},
  [16943] = {.lex_state = 0},
  [16944] = {.lex_state = 0},
  [16945] = {.lex_state = 0, .external_lex_state = 64},
  [16946] = {.lex_state = 0},
  [16947] = {.lex_state = 0, .external_lex_state = 64},
  [16948] = {.lex_state = 6},
  [16949] = {.lex_state = 6},
  [16950] = {.lex_state = 6},
  [16951] = {.lex_state = 6},
  [16952] = {.lex_state = 0},
  [16953] = {.lex_state = 0, .external_lex_state = 64},
  [16954] = {.lex_state = 0},
  [16955] = {.lex_state = 0},
  [16956] = {.lex_state = 0, .external_lex_state = 64},
  [16957] = {.lex_state = 0},
  [16958] = {.lex_state = 60},
  [16959] = {.lex_state = 6},
  [16960] = {.lex_state = 6},
  [16961] = {.lex_state = 6},
  [16962] = {.lex_state = 6},
  [16963] = {.lex_state = 0},
  [16964] = {.lex_state = 0},
  [16965] = {.lex_state = 0, .external_lex_state = 64},
  [16966] = {.lex_state = 0},
  [16967] = {.lex_state = 0, .external_lex_state = 64},
  [16968] = {.lex_state = 0},
  [16969] = {.lex_state = 0},
  [16970] = {.lex_state = 6},
  [16971] = {.lex_state = 6},
  [16972] = {.lex_state = 6},
  [16973] = {.lex_state = 6},
  [16974] = {.lex_state = 0},
  [16975] = {.lex_state = 0},
  [16976] = {.lex_state = 0, .external_lex_state = 64},
  [16977] = {.lex_state = 0},
  [16978] = {.lex_state = 0},
  [16979] = {.lex_state = 60, .external_lex_state = 48},
  [16980] = {.lex_state = 0, .external_lex_state = 64},
  [16981] = {.lex_state = 6},
  [16982] = {.lex_state = 6},
  [16983] = {.lex_state = 6},
  [16984] = {.lex_state = 6},
  [16985] = {.lex_state = 0},
  [16986] = {.lex_state = 0},
  [16987] = {.lex_state = 0},
  [16988] = {.lex_state = 0},
  [16989] = {.lex_state = 60, .external_lex_state = 48},
  [16990] = {.lex_state = 0},
  [16991] = {.lex_state = 0},
  [16992] = {.lex_state = 6},
  [16993] = {.lex_state = 6},
  [16994] = {.lex_state = 6},
  [16995] = {.lex_state = 6},
  [16996] = {.lex_state = 0},
  [16997] = {.lex_state = 0},
  [16998] = {.lex_state = 0},
  [16999] = {.lex_state = 0},
  [17000] = {.lex_state = 60, .external_lex_state = 48},
  [17001] = {.lex_state = 0},
  [17002] = {.lex_state = 0},
  [17003] = {.lex_state = 6},
  [17004] = {.lex_state = 6},
  [17005] = {.lex_state = 6},
  [17006] = {.lex_state = 6},
  [17007] = {.lex_state = 0},
  [17008] = {.lex_state = 0},
  [17009] = {.lex_state = 0},
  [17010] = {.lex_state = 0},
  [17011] = {.lex_state = 60, .external_lex_state = 48},
  [17012] = {.lex_state = 0, .external_lex_state = 64},
  [17013] = {.lex_state = 0},
  [17014] = {.lex_state = 6},
  [17015] = {.lex_state = 6},
  [17016] = {.lex_state = 6},
  [17017] = {.lex_state = 6},
  [17018] = {.lex_state = 0},
  [17019] = {.lex_state = 0},
  [17020] = {.lex_state = 0, .external_lex_state = 64},
  [17021] = {.lex_state = 0},
  [17022] = {.lex_state = 0},
  [17023] = {.lex_state = 0},
  [17024] = {.lex_state = 0},
  [17025] = {.lex_state = 0},
  [17026] = {.lex_state = 0},
  [17027] = {.lex_state = 0},
  [17028] = {.lex_state = 0},
  [17029] = {.lex_state = 60, .external_lex_state = 48},
  [17030] = {.lex_state = 0},
  [17031] = {.lex_state = 0, .external_lex_state = 64},
  [17032] = {.lex_state = 0},
  [17033] = {.lex_state = 0},
  [17034] = {.lex_state = 0},
  [17035] = {.lex_state = 0},
  [17036] = {.lex_state = 0, .external_lex_state = 64},
  [17037] = {.lex_state = 0, .external_lex_state = 64},
  [17038] = {.lex_state = 0},
  [17039] = {.lex_state = 0},
  [17040] = {.lex_state = 0},
  [17041] = {.lex_state = 0},
  [17042] = {.lex_state = 0},
  [17043] = {.lex_state = 0, .external_lex_state = 64},
  [17044] = {.lex_state = 0},
  [17045] = {.lex_state = 0, .external_lex_state = 64},
  [17046] = {.lex_state = 6},
  [17047] = {.lex_state = 0},
  [17048] = {.lex_state = 0},
  [17049] = {.lex_state = 6},
  [17050] = {.lex_state = 6},
  [17051] = {.lex_state = 6},
  [17052] = {.lex_state = 0, .external_lex_state = 64},
  [17053] = {.lex_state = 0},
  [17054] = {.lex_state = 0, .external_lex_state = 64},
  [17055] = {.lex_state = 0},
  [17056] = {.lex_state = 0},
  [17057] = {.lex_state = 0},
  [17058] = {.lex_state = 0},
  [17059] = {.lex_state = 0},
  [17060] = {.lex_state = 0},
  [17061] = {.lex_state = 0},
  [17062] = {.lex_state = 60, .external_lex_state = 48},
  [17063] = {.lex_state = 0, .external_lex_state = 64},
  [17064] = {.lex_state = 0, .external_lex_state = 64},
  [17065] = {.lex_state = 0},
  [17066] = {.lex_state = 0},
  [17067] = {.lex_state = 0},
  [17068] = {.lex_state = 0, .external_lex_state = 64},
  [17069] = {.lex_state = 0},
  [17070] = {.lex_state = 0, .external_lex_state = 64},
  [17071] = {.lex_state = 0},
  [17072] = {.lex_state = 60},
  [17073] = {.lex_state = 0},
  [17074] = {.lex_state = 0},
  [17075] = {.lex_state = 53},
  [17076] = {.lex_state = 0},
  [17077] = {.lex_state = 0},
  [17078] = {.lex_state = 53},
  [17079] = {.lex_state = 0},
  [17080] = {.lex_state = 0},
  [17081] = {.lex_state = 0},
  [17082] = {.lex_state = 0},
  [17083] = {.lex_state = 0},
  [17084] = {.lex_state = 0},
  [17085] = {.lex_state = 0},
  [17086] = {.lex_state = 60, .external_lex_state = 48},
  [17087] = {.lex_state = 0},
  [17088] = {.lex_state = 0},
  [17089] = {.lex_state = 0},
  [17090] = {.lex_state = 0},
  [17091] = {.lex_state = 0},
  [17092] = {.lex_state = 0},
  [17093] = {.lex_state = 0, .external_lex_state = 64},
  [17094] = {.lex_state = 0, .external_lex_state = 64},
  [17095] = {.lex_state = 0},
  [17096] = {.lex_state = 6},
  [17097] = {.lex_state = 0},
  [17098] = {.lex_state = 0},
  [17099] = {.lex_state = 0},
  [17100] = {.lex_state = 0},
  [17101] = {.lex_state = 0},
  [17102] = {.lex_state = 0},
  [17103] = {.lex_state = 0, .external_lex_state = 64},
  [17104] = {.lex_state = 0},
  [17105] = {.lex_state = 60},
  [17106] = {.lex_state = 0},
  [17107] = {.lex_state = 0},
  [17108] = {.lex_state = 0},
  [17109] = {.lex_state = 0},
  [17110] = {.lex_state = 0},
  [17111] = {.lex_state = 0},
  [17112] = {.lex_state = 60, .external_lex_state = 48},
  [17113] = {.lex_state = 0},
  [17114] = {.lex_state = 0},
  [17115] = {.lex_state = 0, .external_lex_state = 64},
  [17116] = {.lex_state = 0},
  [17117] = {.lex_state = 0, .external_lex_state = 64},
  [17118] = {.lex_state = 0},
  [17119] = {.lex_state = 0},
  [17120] = {.lex_state = 6},
  [17121] = {.lex_state = 6},
  [17122] = {.lex_state = 0, .external_lex_state = 64},
  [17123] = {.lex_state = 6},
  [17124] = {.lex_state = 6},
  [17125] = {.lex_state = 0},
  [17126] = {.lex_state = 0},
  [17127] = {.lex_state = 0, .external_lex_state = 64},
  [17128] = {.lex_state = 0},
  [17129] = {.lex_state = 0},
  [17130] = {.lex_state = 6},
  [17131] = {.lex_state = 0},
  [17132] = {.lex_state = 6},
  [17133] = {.lex_state = 0},
  [17134] = {.lex_state = 6},
  [17135] = {.lex_state = 0, .external_lex_state = 64},
  [17136] = {.lex_state = 0, .external_lex_state = 64},
  [17137] = {.lex_state = 0},
  [17138] = {.lex_state = 0, .external_lex_state = 64},
  [17139] = {.lex_state = 0},
  [17140] = {.lex_state = 0},
  [17141] = {.lex_state = 0},
  [17142] = {.lex_state = 0},
  [17143] = {.lex_state = 0},
  [17144] = {.lex_state = 60, .external_lex_state = 48},
  [17145] = {.lex_state = 0},
  [17146] = {.lex_state = 0, .external_lex_state = 64},
  [17147] = {.lex_state = 60, .external_lex_state = 48},
  [17148] = {.lex_state = 0},
  [17149] = {.lex_state = 0},
  [17150] = {.lex_state = 0, .external_lex_state = 64},
  [17151] = {.lex_state = 0},
  [17152] = {.lex_state = 0},
  [17153] = {.lex_state = 0, .external_lex_state = 64},
  [17154] = {.lex_state = 0},
  [17155] = {.lex_state = 0},
  [17156] = {.lex_state = 0},
  [17157] = {.lex_state = 0, .external_lex_state = 64},
  [17158] = {.lex_state = 60, .external_lex_state = 48},
  [17159] = {.lex_state = 0, .external_lex_state = 64},
  [17160] = {.lex_state = 0},
  [17161] = {.lex_state = 0},
  [17162] = {.lex_state = 0},
  [17163] = {.lex_state = 0},
  [17164] = {.lex_state = 0},
  [17165] = {.lex_state = 0},
  [17166] = {.lex_state = 0},
  [17167] = {.lex_state = 0},
  [17168] = {.lex_state = 0, .external_lex_state = 64},
  [17169] = {.lex_state = 0, .external_lex_state = 64},
  [17170] = {.lex_state = 0},
  [17171] = {.lex_state = 0},
  [17172] = {.lex_state = 0},
  [17173] = {.lex_state = 0},
  [17174] = {.lex_state = 0},
  [17175] = {.lex_state = 60, .external_lex_state = 48},
  [17176] = {.lex_state = 0},
  [17177] = {.lex_state = 60},
  [17178] = {.lex_state = 0},
  [17179] = {.lex_state = 0},
  [17180] = {.lex_state = 0},
  [17181] = {.lex_state = 0},
  [17182] = {.lex_state = 0},
  [17183] = {.lex_state = 60, .external_lex_state = 48},
  [17184] = {.lex_state = 0},
  [17185] = {.lex_state = 0},
  [17186] = {.lex_state = 0},
  [17187] = {.lex_state = 0},
  [17188] = {.lex_state = 0},
  [17189] = {.lex_state = 6},
  [17190] = {.lex_state = 0},
  [17191] = {.lex_state = 0},
  [17192] = {.lex_state = 6},
  [17193] = {.lex_state = 6},
  [17194] = {.lex_state = 6},
  [17195] = {.lex_state = 0},
  [17196] = {.lex_state = 0, .external_lex_state = 64},
  [17197] = {.lex_state = 0},
  [17198] = {.lex_state = 0},
  [17199] = {.lex_state = 0},
  [17200] = {.lex_state = 60},
  [17201] = {.lex_state = 0},
  [17202] = {.lex_state = 60},
  [17203] = {.lex_state = 0},
  [17204] = {.lex_state = 60},
  [17205] = {.lex_state = 0},
  [17206] = {.lex_state = 0},
  [17207] = {.lex_state = 0, .external_lex_state = 64},
  [17208] = {.lex_state = 0},
  [17209] = {.lex_state = 0},
  [17210] = {.lex_state = 0},
  [17211] = {.lex_state = 0},
  [17212] = {.lex_state = 0},
  [17213] = {.lex_state = 0},
  [17214] = {.lex_state = 0, .external_lex_state = 64},
  [17215] = {.lex_state = 0},
  [17216] = {.lex_state = 0},
  [17217] = {.lex_state = 0},
  [17218] = {.lex_state = 0, .external_lex_state = 64},
  [17219] = {.lex_state = 60, .external_lex_state = 48},
  [17220] = {.lex_state = 0, .external_lex_state = 64},
  [17221] = {.lex_state = 0},
  [17222] = {.lex_state = 0},
  [17223] = {.lex_state = 0},
  [17224] = {.lex_state = 60, .external_lex_state = 48},
  [17225] = {.lex_state = 0, .external_lex_state = 64},
  [17226] = {.lex_state = 0},
  [17227] = {.lex_state = 0},
  [17228] = {.lex_state = 0},
  [17229] = {.lex_state = 0},
  [17230] = {.lex_state = 0, .external_lex_state = 64},
  [17231] = {.lex_state = 0, .external_lex_state = 64},
  [17232] = {.lex_state = 0, .external_lex_state = 64},
  [17233] = {.lex_state = 0},
  [17234] = {.lex_state = 0},
  [17235] = {.lex_state = 0, .external_lex_state = 64},
  [17236] = {.lex_state = 0},
  [17237] = {.lex_state = 0},
  [17238] = {.lex_state = 0, .external_lex_state = 64},
  [17239] = {.lex_state = 0},
  [17240] = {.lex_state = 60, .external_lex_state = 48},
  [17241] = {.lex_state = 60, .external_lex_state = 48},
  [17242] = {.lex_state = 60},
  [17243] = {.lex_state = 0, .external_lex_state = 64},
  [17244] = {.lex_state = 0},
  [17245] = {.lex_state = 0},
  [17246] = {.lex_state = 0},
  [17247] = {.lex_state = 0},
  [17248] = {.lex_state = 0, .external_lex_state = 64},
  [17249] = {.lex_state = 0, .external_lex_state = 64},
  [17250] = {.lex_state = 0},
  [17251] = {.lex_state = 0},
  [17252] = {.lex_state = 60, .external_lex_state = 48},
  [17253] = {.lex_state = 0},
  [17254] = {.lex_state = 0},
  [17255] = {.lex_state = 0},
  [17256] = {.lex_state = 0},
  [17257] = {.lex_state = 0},
  [17258] = {.lex_state = 0},
  [17259] = {.lex_state = 0},
  [17260] = {.lex_state = 0, .external_lex_state = 64},
  [17261] = {.lex_state = 0},
  [17262] = {.lex_state = 0},
  [17263] = {.lex_state = 0},
  [17264] = {.lex_state = 6},
  [17265] = {.lex_state = 0},
  [17266] = {.lex_state = 6},
  [17267] = {.lex_state = 6},
  [17268] = {.lex_state = 60},
  [17269] = {.lex_state = 0},
  [17270] = {.lex_state = 6},
  [17271] = {.lex_state = 0},
  [17272] = {.lex_state = 0, .external_lex_state = 64},
  [17273] = {.lex_state = 0},
  [17274] = {.lex_state = 0},
  [17275] = {.lex_state = 0},
  [17276] = {.lex_state = 0},
  [17277] = {.lex_state = 0},
  [17278] = {.lex_state = 0},
  [17279] = {.lex_state = 0},
  [17280] = {.lex_state = 0},
  [17281] = {.lex_state = 0},
  [17282] = {.lex_state = 0, .external_lex_state = 64},
  [17283] = {.lex_state = 60},
  [17284] = {.lex_state = 0},
  [17285] = {.lex_state = 0, .external_lex_state = 64},
  [17286] = {.lex_state = 0},
  [17287] = {.lex_state = 0, .external_lex_state = 64},
  [17288] = {.lex_state = 0},
  [17289] = {.lex_state = 60},
  [17290] = {.lex_state = 0, .external_lex_state = 64},
  [17291] = {.lex_state = 0},
  [17292] = {.lex_state = 0},
  [17293] = {.lex_state = 0},
  [17294] = {.lex_state = 60},
  [17295] = {.lex_state = 0},
  [17296] = {.lex_state = 60, .external_lex_state = 48},
  [17297] = {.lex_state = 0},
  [17298] = {.lex_state = 0, .external_lex_state = 64},
  [17299] = {.lex_state = 0},
  [17300] = {.lex_state = 0},
  [17301] = {.lex_state = 60, .external_lex_state = 48},
  [17302] = {.lex_state = 0},
  [17303] = {.lex_state = 0, .external_lex_state = 64},
  [17304] = {.lex_state = 0, .external_lex_state = 64},
  [17305] = {.lex_state = 0, .external_lex_state = 64},
  [17306] = {.lex_state = 0, .external_lex_state = 64},
  [17307] = {.lex_state = 60, .external_lex_state = 48},
  [17308] = {.lex_state = 0},
  [17309] = {.lex_state = 0},
  [17310] = {.lex_state = 0},
  [17311] = {.lex_state = 0},
  [17312] = {.lex_state = 0},
  [17313] = {.lex_state = 0},
  [17314] = {.lex_state = 0, .external_lex_state = 64},
  [17315] = {.lex_state = 0, .external_lex_state = 64},
  [17316] = {.lex_state = 0},
  [17317] = {.lex_state = 0},
  [17318] = {.lex_state = 0},
  [17319] = {.lex_state = 0},
  [17320] = {.lex_state = 0},
  [17321] = {.lex_state = 0},
  [17322] = {.lex_state = 53},
  [17323] = {.lex_state = 60},
  [17324] = {.lex_state = 0, .external_lex_state = 64},
  [17325] = {.lex_state = 0},
  [17326] = {.lex_state = 6},
  [17327] = {.lex_state = 0},
  [17328] = {.lex_state = 60, .external_lex_state = 48},
  [17329] = {.lex_state = 0, .external_lex_state = 64},
  [17330] = {.lex_state = 6},
  [17331] = {.lex_state = 0},
  [17332] = {.lex_state = 0, .external_lex_state = 64},
  [17333] = {.lex_state = 6},
  [17334] = {.lex_state = 0, .external_lex_state = 64},
  [17335] = {.lex_state = 0, .external_lex_state = 64},
  [17336] = {.lex_state = 6},
  [17337] = {.lex_state = 0},
  [17338] = {.lex_state = 0},
  [17339] = {.lex_state = 0},
  [17340] = {.lex_state = 0},
  [17341] = {.lex_state = 0},
  [17342] = {.lex_state = 0},
  [17343] = {.lex_state = 60, .external_lex_state = 48},
  [17344] = {.lex_state = 0},
  [17345] = {.lex_state = 0, .external_lex_state = 25},
  [17346] = {.lex_state = 60},
  [17347] = {.lex_state = 0},
  [17348] = {.lex_state = 0, .external_lex_state = 25},
  [17349] = {.lex_state = 60, .external_lex_state = 48},
  [17350] = {.lex_state = 60},
  [17351] = {.lex_state = 0},
  [17352] = {.lex_state = 60, .external_lex_state = 48},
  [17353] = {.lex_state = 0},
  [17354] = {.lex_state = 0, .external_lex_state = 64},
  [17355] = {.lex_state = 53},
  [17356] = {.lex_state = 0},
  [17357] = {.lex_state = 0, .external_lex_state = 64},
  [17358] = {.lex_state = 53},
  [17359] = {.lex_state = 0, .external_lex_state = 64},
  [17360] = {.lex_state = 0},
  [17361] = {.lex_state = 60, .external_lex_state = 48},
  [17362] = {.lex_state = 0},
  [17363] = {.lex_state = 53},
  [17364] = {.lex_state = 0},
  [17365] = {.lex_state = 0, .external_lex_state = 64},
  [17366] = {.lex_state = 0},
  [17367] = {.lex_state = 0, .external_lex_state = 25},
  [17368] = {.lex_state = 0},
  [17369] = {.lex_state = 60, .external_lex_state = 48},
  [17370] = {.lex_state = 0},
  [17371] = {.lex_state = 0},
  [17372] = {.lex_state = 0},
  [17373] = {.lex_state = 0},
  [17374] = {.lex_state = 0},
  [17375] = {.lex_state = 0},
  [17376] = {.lex_state = 0, .external_lex_state = 25},
  [17377] = {.lex_state = 0, .external_lex_state = 64},
  [17378] = {.lex_state = 0},
  [17379] = {.lex_state = 0, .external_lex_state = 64},
  [17380] = {.lex_state = 0},
  [17381] = {.lex_state = 0},
  [17382] = {.lex_state = 0},
  [17383] = {.lex_state = 0},
  [17384] = {.lex_state = 0},
  [17385] = {.lex_state = 0, .external_lex_state = 25},
  [17386] = {.lex_state = 0},
  [17387] = {.lex_state = 0},
  [17388] = {.lex_state = 0, .external_lex_state = 64},
  [17389] = {.lex_state = 6},
  [17390] = {.lex_state = 0},
  [17391] = {.lex_state = 0},
  [17392] = {.lex_state = 0, .external_lex_state = 25},
  [17393] = {.lex_state = 6},
  [17394] = {.lex_state = 60},
  [17395] = {.lex_state = 6},
  [17396] = {.lex_state = 6},
  [17397] = {.lex_state = 0, .external_lex_state = 64},
  [17398] = {.lex_state = 6},
  [17399] = {.lex_state = 0, .external_lex_state = 25},
  [17400] = {.lex_state = 60, .external_lex_state = 48},
  [17401] = {.lex_state = 0, .external_lex_state = 25},
  [17402] = {.lex_state = 60},
  [17403] = {.lex_state = 0},
  [17404] = {.lex_state = 0, .external_lex_state = 64},
  [17405] = {.lex_state = 0},
  [17406] = {.lex_state = 0, .external_lex_state = 25},
  [17407] = {.lex_state = 0},
  [17408] = {.lex_state = 0},
  [17409] = {.lex_state = 0},
  [17410] = {.lex_state = 0},
  [17411] = {.lex_state = 0},
  [17412] = {.lex_state = 0},
  [17413] = {.lex_state = 0, .external_lex_state = 25},
  [17414] = {.lex_state = 0},
  [17415] = {.lex_state = 0, .external_lex_state = 64},
  [17416] = {.lex_state = 0, .external_lex_state = 64},
  [17417] = {.lex_state = 0, .external_lex_state = 64},
  [17418] = {.lex_state = 0},
  [17419] = {.lex_state = 60, .external_lex_state = 48},
  [17420] = {.lex_state = 0, .external_lex_state = 25},
  [17421] = {.lex_state = 0},
  [17422] = {.lex_state = 0},
  [17423] = {.lex_state = 60, .external_lex_state = 48},
  [17424] = {.lex_state = 60},
  [17425] = {.lex_state = 0},
  [17426] = {.lex_state = 0},
  [17427] = {.lex_state = 0, .external_lex_state = 25},
  [17428] = {.lex_state = 60, .external_lex_state = 48},
  [17429] = {.lex_state = 0, .external_lex_state = 64},
  [17430] = {.lex_state = 0},
  [17431] = {.lex_state = 0},
  [17432] = {.lex_state = 0, .external_lex_state = 64},
  [17433] = {.lex_state = 0},
  [17434] = {.lex_state = 0, .external_lex_state = 25},
  [17435] = {.lex_state = 0, .external_lex_state = 64},
  [17436] = {.lex_state = 0},
  [17437] = {.lex_state = 0},
  [17438] = {.lex_state = 0},
  [17439] = {.lex_state = 0, .external_lex_state = 64},
  [17440] = {.lex_state = 6},
  [17441] = {.lex_state = 0, .external_lex_state = 25},
  [17442] = {.lex_state = 60, .external_lex_state = 48},
  [17443] = {.lex_state = 0},
  [17444] = {.lex_state = 60},
  [17445] = {.lex_state = 0},
  [17446] = {.lex_state = 60, .external_lex_state = 48},
  [17447] = {.lex_state = 6},
  [17448] = {.lex_state = 0, .external_lex_state = 25},
  [17449] = {.lex_state = 0},
  [17450] = {.lex_state = 60, .external_lex_state = 48},
  [17451] = {.lex_state = 0},
  [17452] = {.lex_state = 0},
  [17453] = {.lex_state = 0},
  [17454] = {.lex_state = 0},
  [17455] = {.lex_state = 0, .external_lex_state = 25},
  [17456] = {.lex_state = 0},
  [17457] = {.lex_state = 0},
  [17458] = {.lex_state = 6},
  [17459] = {.lex_state = 0, .external_lex_state = 64},
  [17460] = {.lex_state = 0},
  [17461] = {.lex_state = 0},
  [17462] = {.lex_state = 0, .external_lex_state = 25},
  [17463] = {.lex_state = 0},
  [17464] = {.lex_state = 60, .external_lex_state = 48},
  [17465] = {.lex_state = 6},
  [17466] = {.lex_state = 6},
  [17467] = {.lex_state = 6},
  [17468] = {.lex_state = 6},
  [17469] = {.lex_state = 0, .external_lex_state = 25},
  [17470] = {.lex_state = 0, .external_lex_state = 64},
  [17471] = {.lex_state = 0},
  [17472] = {.lex_state = 0},
  [17473] = {.lex_state = 0},
  [17474] = {.lex_state = 0},
  [17475] = {.lex_state = 0},
  [17476] = {.lex_state = 0, .external_lex_state = 25},
  [17477] = {.lex_state = 0},
  [17478] = {.lex_state = 0},
  [17479] = {.lex_state = 0},
  [17480] = {.lex_state = 0},
  [17481] = {.lex_state = 0, .external_lex_state = 64},
  [17482] = {.lex_state = 0, .external_lex_state = 25},
  [17483] = {.lex_state = 0},
  [17484] = {.lex_state = 0},
  [17485] = {.lex_state = 0, .external_lex_state = 64},
  [17486] = {.lex_state = 0},
  [17487] = {.lex_state = 0},
  [17488] = {.lex_state = 0, .external_lex_state = 25},
  [17489] = {.lex_state = 0},
  [17490] = {.lex_state = 0, .external_lex_state = 64},
  [17491] = {.lex_state = 0, .external_lex_state = 25},
  [17492] = {.lex_state = 0},
  [17493] = {.lex_state = 60},
  [17494] = {.lex_state = 0, .external_lex_state = 25},
  [17495] = {.lex_state = 60, .external_lex_state = 48},
  [17496] = {.lex_state = 0},
  [17497] = {.lex_state = 60},
  [17498] = {.lex_state = 60},
  [17499] = {.lex_state = 0, .external_lex_state = 64},
  [17500] = {.lex_state = 0, .external_lex_state = 25},
  [17501] = {.lex_state = 0},
  [17502] = {.lex_state = 0},
  [17503] = {.lex_state = 0, .external_lex_state = 64},
  [17504] = {.lex_state = 0, .external_lex_state = 64},
  [17505] = {.lex_state = 0},
  [17506] = {.lex_state = 0, .external_lex_state = 25},
  [17507] = {.lex_state = 0},
  [17508] = {.lex_state = 0, .external_lex_state = 64},
  [17509] = {.lex_state = 0},
  [17510] = {.lex_state = 0},
  [17511] = {.lex_state = 0},
  [17512] = {.lex_state = 0, .external_lex_state = 25},
  [17513] = {.lex_state = 0},
  [17514] = {.lex_state = 0},
  [17515] = {.lex_state = 60, .external_lex_state = 43},
  [17516] = {.lex_state = 0, .external_lex_state = 64},
  [17517] = {.lex_state = 0, .external_lex_state = 64},
  [17518] = {.lex_state = 0, .external_lex_state = 25},
  [17519] = {.lex_state = 6},
  [17520] = {.lex_state = 0},
  [17521] = {.lex_state = 0},
  [17522] = {.lex_state = 0},
  [17523] = {.lex_state = 6},
  [17524] = {.lex_state = 0, .external_lex_state = 25},
  [17525] = {.lex_state = 6},
  [17526] = {.lex_state = 6},
  [17527] = {.lex_state = 0},
  [17528] = {.lex_state = 0},
  [17529] = {.lex_state = 0, .external_lex_state = 64},
  [17530] = {.lex_state = 0, .external_lex_state = 25},
  [17531] = {.lex_state = 0},
  [17532] = {.lex_state = 0, .external_lex_state = 64},
  [17533] = {.lex_state = 60, .external_lex_state = 48},
  [17534] = {.lex_state = 0},
  [17535] = {.lex_state = 0},
  [17536] = {.lex_state = 0, .external_lex_state = 25},
  [17537] = {.lex_state = 60},
  [17538] = {.lex_state = 0},
  [17539] = {.lex_state = 0},
  [17540] = {.lex_state = 60},
  [17541] = {.lex_state = 0, .external_lex_state = 64},
  [17542] = {.lex_state = 0, .external_lex_state = 25},
  [17543] = {.lex_state = 0},
  [17544] = {.lex_state = 60, .external_lex_state = 48},
  [17545] = {.lex_state = 60},
  [17546] = {.lex_state = 0},
  [17547] = {.lex_state = 0, .external_lex_state = 64},
  [17548] = {.lex_state = 0, .external_lex_state = 25},
  [17549] = {.lex_state = 0},
  [17550] = {.lex_state = 0},
  [17551] = {.lex_state = 0, .external_lex_state = 64},
  [17552] = {.lex_state = 0, .external_lex_state = 64},
  [17553] = {.lex_state = 60},
  [17554] = {.lex_state = 0, .external_lex_state = 25},
  [17555] = {.lex_state = 60, .external_lex_state = 48},
  [17556] = {.lex_state = 0},
  [17557] = {.lex_state = 0, .external_lex_state = 64},
  [17558] = {.lex_state = 0},
  [17559] = {.lex_state = 60, .external_lex_state = 48},
  [17560] = {.lex_state = 0, .external_lex_state = 25},
  [17561] = {.lex_state = 0},
  [17562] = {.lex_state = 0, .external_lex_state = 64},
  [17563] = {.lex_state = 60, .external_lex_state = 48},
  [17564] = {.lex_state = 60, .external_lex_state = 48},
  [17565] = {.lex_state = 0},
  [17566] = {.lex_state = 0, .external_lex_state = 25},
  [17567] = {.lex_state = 0},
  [17568] = {.lex_state = 0},
  [17569] = {.lex_state = 0},
  [17570] = {.lex_state = 0},
  [17571] = {.lex_state = 0, .external_lex_state = 64},
  [17572] = {.lex_state = 0, .external_lex_state = 25},
  [17573] = {.lex_state = 0},
  [17574] = {.lex_state = 0},
  [17575] = {.lex_state = 0, .external_lex_state = 64},
  [17576] = {.lex_state = 60, .external_lex_state = 43},
  [17577] = {.lex_state = 0, .external_lex_state = 64},
  [17578] = {.lex_state = 0, .external_lex_state = 25},
  [17579] = {.lex_state = 0, .external_lex_state = 64},
  [17580] = {.lex_state = 6},
  [17581] = {.lex_state = 0},
  [17582] = {.lex_state = 6},
  [17583] = {.lex_state = 6},
  [17584] = {.lex_state = 0, .external_lex_state = 25},
  [17585] = {.lex_state = 6},
  [17586] = {.lex_state = 0},
  [17587] = {.lex_state = 0},
  [17588] = {.lex_state = 0, .external_lex_state = 64},
  [17589] = {.lex_state = 60},
  [17590] = {.lex_state = 0, .external_lex_state = 25},
  [17591] = {.lex_state = 0, .external_lex_state = 64},
  [17592] = {.lex_state = 0},
  [17593] = {.lex_state = 0},
  [17594] = {.lex_state = 0},
  [17595] = {.lex_state = 60},
  [17596] = {.lex_state = 0, .external_lex_state = 25},
  [17597] = {.lex_state = 0},
  [17598] = {.lex_state = 0, .external_lex_state = 64},
  [17599] = {.lex_state = 60, .external_lex_state = 48},
  [17600] = {.lex_state = 0},
  [17601] = {.lex_state = 0},
  [17602] = {.lex_state = 0, .external_lex_state = 25},
  [17603] = {.lex_state = 0, .external_lex_state = 64},
  [17604] = {.lex_state = 0, .external_lex_state = 64},
  [17605] = {.lex_state = 60, .external_lex_state = 48},
  [17606] = {.lex_state = 0},
  [17607] = {.lex_state = 0},
  [17608] = {.lex_state = 0, .external_lex_state = 25},
  [17609] = {.lex_state = 0, .external_lex_state = 64},
  [17610] = {.lex_state = 0},
  [17611] = {.lex_state = 0},
  [17612] = {.lex_state = 0},
  [17613] = {.lex_state = 0, .external_lex_state = 25},
  [17614] = {.lex_state = 60},
  [17615] = {.lex_state = 60, .external_lex_state = 48},
  [17616] = {.lex_state = 0},
  [17617] = {.lex_state = 0},
  [17618] = {.lex_state = 0, .external_lex_state = 64},
  [17619] = {.lex_state = 0, .external_lex_state = 25},
  [17620] = {.lex_state = 60},
  [17621] = {.lex_state = 0},
  [17622] = {.lex_state = 0},
  [17623] = {.lex_state = 0, .external_lex_state = 64},
  [17624] = {.lex_state = 0},
  [17625] = {.lex_state = 0, .external_lex_state = 25},
  [17626] = {.lex_state = 0},
  [17627] = {.lex_state = 0},
  [17628] = {.lex_state = 60, .external_lex_state = 48},
  [17629] = {.lex_state = 0},
  [17630] = {.lex_state = 157},
  [17631] = {.lex_state = 0, .external_lex_state = 25},
  [17632] = {.lex_state = 0, .external_lex_state = 64},
  [17633] = {.lex_state = 0},
  [17634] = {.lex_state = 0},
  [17635] = {.lex_state = 0},
  [17636] = {.lex_state = 60, .external_lex_state = 48},
  [17637] = {.lex_state = 0, .external_lex_state = 25},
  [17638] = {.lex_state = 0},
  [17639] = {.lex_state = 60, .external_lex_state = 48},
  [17640] = {.lex_state = 6},
  [17641] = {.lex_state = 0},
  [17642] = {.lex_state = 0, .external_lex_state = 64},
  [17643] = {.lex_state = 0, .external_lex_state = 25},
  [17644] = {.lex_state = 6},
  [17645] = {.lex_state = 6},
  [17646] = {.lex_state = 6},
  [17647] = {.lex_state = 0},
  [17648] = {.lex_state = 0, .external_lex_state = 64},
  [17649] = {.lex_state = 0, .external_lex_state = 25},
  [17650] = {.lex_state = 0},
  [17651] = {.lex_state = 0},
  [17652] = {.lex_state = 0},
  [17653] = {.lex_state = 0},
  [17654] = {.lex_state = 60, .external_lex_state = 48},
  [17655] = {.lex_state = 0, .external_lex_state = 25},
  [17656] = {.lex_state = 0, .external_lex_state = 64},
  [17657] = {.lex_state = 60},
  [17658] = {.lex_state = 60},
  [17659] = {.lex_state = 0},
  [17660] = {.lex_state = 0},
  [17661] = {.lex_state = 0, .external_lex_state = 25},
  [17662] = {.lex_state = 0},
  [17663] = {.lex_state = 0, .external_lex_state = 64},
  [17664] = {.lex_state = 0, .external_lex_state = 64},
  [17665] = {.lex_state = 0},
  [17666] = {.lex_state = 0, .external_lex_state = 64},
  [17667] = {.lex_state = 0, .external_lex_state = 25},
  [17668] = {.lex_state = 0},
  [17669] = {.lex_state = 0},
  [17670] = {.lex_state = 60},
  [17671] = {.lex_state = 0},
  [17672] = {.lex_state = 0},
  [17673] = {.lex_state = 0, .external_lex_state = 25},
  [17674] = {.lex_state = 0},
  [17675] = {.lex_state = 0},
  [17676] = {.lex_state = 0},
  [17677] = {.lex_state = 0, .external_lex_state = 64},
  [17678] = {.lex_state = 0, .external_lex_state = 64},
  [17679] = {.lex_state = 0, .external_lex_state = 25},
  [17680] = {.lex_state = 0},
  [17681] = {.lex_state = 0},
  [17682] = {.lex_state = 0, .external_lex_state = 64},
  [17683] = {.lex_state = 0},
  [17684] = {.lex_state = 0},
  [17685] = {.lex_state = 0, .external_lex_state = 25},
  [17686] = {.lex_state = 0},
  [17687] = {.lex_state = 60},
  [17688] = {.lex_state = 0},
  [17689] = {.lex_state = 0},
  [17690] = {.lex_state = 0},
  [17691] = {.lex_state = 0, .external_lex_state = 25},
  [17692] = {.lex_state = 0},
  [17693] = {.lex_state = 0},
  [17694] = {.lex_state = 0},
  [17695] = {.lex_state = 6},
  [17696] = {.lex_state = 0, .external_lex_state = 64},
  [17697] = {.lex_state = 0, .external_lex_state = 25},
  [17698] = {.lex_state = 0},
  [17699] = {.lex_state = 0},
  [17700] = {.lex_state = 6},
  [17701] = {.lex_state = 6},
  [17702] = {.lex_state = 60},
  [17703] = {.lex_state = 0, .external_lex_state = 25},
  [17704] = {.lex_state = 6},
  [17705] = {.lex_state = 0},
  [17706] = {.lex_state = 0, .external_lex_state = 64},
  [17707] = {.lex_state = 0},
  [17708] = {.lex_state = 0, .external_lex_state = 25},
  [17709] = {.lex_state = 0},
  [17710] = {.lex_state = 0},
  [17711] = {.lex_state = 0},
  [17712] = {.lex_state = 0, .external_lex_state = 64},
  [17713] = {.lex_state = 0, .external_lex_state = 25},
  [17714] = {.lex_state = 0, .external_lex_state = 64},
  [17715] = {.lex_state = 0},
  [17716] = {.lex_state = 0},
  [17717] = {.lex_state = 0},
  [17718] = {.lex_state = 0, .external_lex_state = 25},
  [17719] = {.lex_state = 0, .external_lex_state = 64},
  [17720] = {.lex_state = 0},
  [17721] = {.lex_state = 0, .external_lex_state = 64},
  [17722] = {.lex_state = 0},
  [17723] = {.lex_state = 0, .external_lex_state = 25},
  [17724] = {.lex_state = 0, .external_lex_state = 64},
  [17725] = {.lex_state = 0},
  [17726] = {.lex_state = 0},
  [17727] = {.lex_state = 0, .external_lex_state = 64},
  [17728] = {.lex_state = 0, .external_lex_state = 25},
  [17729] = {.lex_state = 0, .external_lex_state = 64},
  [17730] = {.lex_state = 0, .external_lex_state = 64},
  [17731] = {.lex_state = 0},
  [17732] = {.lex_state = 0, .external_lex_state = 64},
  [17733] = {.lex_state = 0, .external_lex_state = 25},
  [17734] = {.lex_state = 0},
  [17735] = {.lex_state = 60, .external_lex_state = 48},
  [17736] = {.lex_state = 60, .external_lex_state = 48},
  [17737] = {.lex_state = 60, .external_lex_state = 48},
  [17738] = {.lex_state = 0, .external_lex_state = 25},
  [17739] = {.lex_state = 60},
  [17740] = {.lex_state = 0},
  [17741] = {.lex_state = 0, .external_lex_state = 64},
  [17742] = {.lex_state = 60, .external_lex_state = 48},
  [17743] = {.lex_state = 0, .external_lex_state = 25},
  [17744] = {.lex_state = 0},
  [17745] = {.lex_state = 0},
  [17746] = {.lex_state = 0},
  [17747] = {.lex_state = 0, .external_lex_state = 64},
  [17748] = {.lex_state = 0, .external_lex_state = 25},
  [17749] = {.lex_state = 6},
  [17750] = {.lex_state = 0},
  [17751] = {.lex_state = 0},
  [17752] = {.lex_state = 0, .external_lex_state = 64},
  [17753] = {.lex_state = 0, .external_lex_state = 25},
  [17754] = {.lex_state = 6},
  [17755] = {.lex_state = 6},
  [17756] = {.lex_state = 6},
  [17757] = {.lex_state = 0},
  [17758] = {.lex_state = 0, .external_lex_state = 25},
  [17759] = {.lex_state = 0, .external_lex_state = 25},
  [17760] = {.lex_state = 0, .external_lex_state = 25},
  [17761] = {.lex_state = 0, .external_lex_state = 25},
  [17762] = {.lex_state = 0, .external_lex_state = 25},
  [17763] = {.lex_state = 0, .external_lex_state = 25},
  [17764] = {.lex_state = 0, .external_lex_state = 25},
  [17765] = {.lex_state = 0, .external_lex_state = 25},
  [17766] = {.lex_state = 0, .external_lex_state = 25},
  [17767] = {.lex_state = 0, .external_lex_state = 25},
  [17768] = {.lex_state = 0, .external_lex_state = 25},
  [17769] = {.lex_state = 0, .external_lex_state = 25},
  [17770] = {.lex_state = 0, .external_lex_state = 25},
  [17771] = {.lex_state = 0, .external_lex_state = 25},
  [17772] = {.lex_state = 0, .external_lex_state = 25},
  [17773] = {.lex_state = 0, .external_lex_state = 25},
  [17774] = {.lex_state = 0, .external_lex_state = 25},
  [17775] = {.lex_state = 0, .external_lex_state = 25},
  [17776] = {.lex_state = 0, .external_lex_state = 25},
  [17777] = {.lex_state = 0, .external_lex_state = 25},
  [17778] = {.lex_state = 0, .external_lex_state = 25},
  [17779] = {.lex_state = 0, .external_lex_state = 25},
  [17780] = {.lex_state = 0, .external_lex_state = 25},
  [17781] = {.lex_state = 0, .external_lex_state = 25},
  [17782] = {.lex_state = 0, .external_lex_state = 25},
  [17783] = {.lex_state = 0, .external_lex_state = 25},
  [17784] = {.lex_state = 0, .external_lex_state = 25},
  [17785] = {.lex_state = 0, .external_lex_state = 25},
  [17786] = {.lex_state = 0, .external_lex_state = 25},
  [17787] = {.lex_state = 0, .external_lex_state = 25},
  [17788] = {.lex_state = 0, .external_lex_state = 25},
  [17789] = {.lex_state = 0, .external_lex_state = 25},
  [17790] = {.lex_state = 0, .external_lex_state = 25},
  [17791] = {.lex_state = 0, .external_lex_state = 25},
  [17792] = {.lex_state = 0, .external_lex_state = 25},
  [17793] = {.lex_state = 0, .external_lex_state = 25},
  [17794] = {.lex_state = 0, .external_lex_state = 25},
  [17795] = {.lex_state = 0, .external_lex_state = 25},
  [17796] = {.lex_state = 0, .external_lex_state = 25},
  [17797] = {.lex_state = 0, .external_lex_state = 25},
  [17798] = {.lex_state = 0, .external_lex_state = 25},
  [17799] = {.lex_state = 0, .external_lex_state = 25},
  [17800] = {.lex_state = 0, .external_lex_state = 25},
  [17801] = {.lex_state = 0, .external_lex_state = 25},
  [17802] = {.lex_state = 0, .external_lex_state = 25},
  [17803] = {.lex_state = 0, .external_lex_state = 25},
  [17804] = {.lex_state = 0, .external_lex_state = 25},
  [17805] = {.lex_state = 0, .external_lex_state = 25},
  [17806] = {.lex_state = 0, .external_lex_state = 25},
  [17807] = {.lex_state = 0, .external_lex_state = 25},
  [17808] = {.lex_state = 0, .external_lex_state = 25},
  [17809] = {.lex_state = 0, .external_lex_state = 25},
  [17810] = {.lex_state = 60, .external_lex_state = 48},
  [17811] = {.lex_state = 60, .external_lex_state = 48},
  [17812] = {.lex_state = 0},
  [17813] = {.lex_state = 0},
  [17814] = {.lex_state = 0},
  [17815] = {.lex_state = 53},
  [17816] = {.lex_state = 60, .external_lex_state = 48},
  [17817] = {.lex_state = 0},
  [17818] = {.lex_state = 0},
  [17819] = {.lex_state = 0},
  [17820] = {.lex_state = 0},
  [17821] = {.lex_state = 0},
  [17822] = {.lex_state = 60},
  [17823] = {.lex_state = 0},
  [17824] = {.lex_state = 53},
  [17825] = {.lex_state = 60, .external_lex_state = 48},
  [17826] = {.lex_state = 0, .external_lex_state = 64},
  [17827] = {.lex_state = 0},
  [17828] = {.lex_state = 60, .external_lex_state = 48},
  [17829] = {.lex_state = 0},
  [17830] = {.lex_state = 0, .external_lex_state = 64},
  [17831] = {.lex_state = 0},
  [17832] = {.lex_state = 0},
  [17833] = {.lex_state = 0},
  [17834] = {.lex_state = 60},
  [17835] = {.lex_state = 0},
  [17836] = {.lex_state = 0},
  [17837] = {.lex_state = 0, .external_lex_state = 64},
  [17838] = {.lex_state = 0},
  [17839] = {.lex_state = 0, .external_lex_state = 64},
  [17840] = {.lex_state = 0, .external_lex_state = 64},
  [17841] = {.lex_state = 0},
  [17842] = {.lex_state = 0},
  [17843] = {.lex_state = 60, .external_lex_state = 48},
  [17844] = {.lex_state = 0, .external_lex_state = 64},
  [17845] = {.lex_state = 0},
  [17846] = {.lex_state = 0},
  [17847] = {.lex_state = 0, .external_lex_state = 64},
  [17848] = {.lex_state = 0},
  [17849] = {.lex_state = 0},
  [17850] = {.lex_state = 60, .external_lex_state = 48},
  [17851] = {.lex_state = 0},
  [17852] = {.lex_state = 6},
  [17853] = {.lex_state = 0},
  [17854] = {.lex_state = 60, .external_lex_state = 48},
  [17855] = {.lex_state = 0},
  [17856] = {.lex_state = 0, .external_lex_state = 64},
  [17857] = {.lex_state = 6},
  [17858] = {.lex_state = 6},
  [17859] = {.lex_state = 0, .external_lex_state = 64},
  [17860] = {.lex_state = 6},
  [17861] = {.lex_state = 6},
  [17862] = {.lex_state = 60},
  [17863] = {.lex_state = 6},
  [17864] = {.lex_state = 0, .external_lex_state = 64},
  [17865] = {.lex_state = 60, .external_lex_state = 48},
  [17866] = {.lex_state = 60},
  [17867] = {.lex_state = 0},
  [17868] = {.lex_state = 0, .external_lex_state = 64},
  [17869] = {.lex_state = 60},
  [17870] = {.lex_state = 0},
  [17871] = {.lex_state = 0},
  [17872] = {.lex_state = 0},
  [17873] = {.lex_state = 0},
  [17874] = {.lex_state = 0, .external_lex_state = 64},
  [17875] = {.lex_state = 0, .external_lex_state = 64},
  [17876] = {(TSStateId)(-1)},
  [17877] = {(TSStateId)(-1)},
  [17878] = {(TSStateId)(-1)},
  [17879] = {(TSStateId)(-1)},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [sym_comment] = STATE(0),
    [sym_block_comment] = STATE(0),
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym__alpha_identifier] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_package] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_object] = ACTIONS(1),
    [anon_sym_import] = ACTIONS(1),
    [anon_sym_export] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym__] = ACTIONS(1),
    [anon_sym_given] = ACTIONS(1),
    [anon_sym_EQ_GT] = ACTIONS(1),
    [anon_sym_as] = ACTIONS(1),
    [anon_sym_class] = ACTIONS(1),
    [anon_sym_trait] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_LT_COLON] = ACTIONS(1),
    [anon_sym_GT_COLON] = ACTIONS(1),
    [anon_sym_LT_PERCENT] = ACTIONS(1),
    [anon_sym_end] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_match] = ACTIONS(1),
    [anon_sym_try] = ACTIONS(1),
    [anon_sym_new] = ACTIONS(1),
    [anon_sym_this] = ACTIONS(1),
    [anon_sym_extension] = ACTIONS(1),
    [anon_sym_val] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_var] = ACTIONS(1),
    [anon_sym_type] = ACTIONS(1),
    [anon_sym_def] = ACTIONS(1),
    [anon_sym_opaque] = ACTIONS(1),
    [anon_sym_with] = ACTIONS(1),
    [anon_sym_abstract] = ACTIONS(1),
    [anon_sym_final] = ACTIONS(1),
    [anon_sym_sealed] = ACTIONS(1),
    [anon_sym_implicit] = ACTIONS(1),
    [anon_sym_lazy] = ACTIONS(1),
    [anon_sym_override] = ACTIONS(1),
    [anon_sym_private] = ACTIONS(1),
    [anon_sym_protected] = ACTIONS(1),
    [anon_sym_inline] = ACTIONS(1),
    [anon_sym_infix] = ACTIONS(1),
    [anon_sym_open] = ACTIONS(1),
    [anon_sym_transparent] = ACTIONS(1),
    [anon_sym_extends] = ACTIONS(1),
    [anon_sym_derives] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_using] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_POUND] = ACTIONS(1),
    [anon_sym_QMARK_EQ_GT] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_then] = ACTIONS(1),
    [anon_sym_catch] = ACTIONS(1),
    [anon_sym_finally] = ACTIONS(1),
    [anon_sym_macro] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_DOLLAR] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [sym__backquoted_id] = ACTIONS(1),
    [sym_integer_literal] = ACTIONS(1),
    [sym_floating_point_literal] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [sym_character_literal] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1),
    [sym_null_literal] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_throw] = ACTIONS(1),
    [anon_sym_do] = ACTIONS(1),
    [anon_sym_yield] = ACTIONS(1),
    [anon_sym_LT_DASH] = ACTIONS(1),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1),
    [sym__indent] = ACTIONS(1),
    [sym__interpolated_string_middle] = ACTIONS(1),
    [sym__interpolated_string_end] = ACTIONS(1),
    [sym__interpolated_multiline_string_middle] = ACTIONS(1),
    [sym__interpolated_multiline_string_end] = ACTIONS(1),
    [sym__outdent] = ACTIONS(1),
    [sym__simple_multiline_string] = ACTIONS(1),
    [sym__simple_string] = ACTIONS(1),
  },
  [1] = {
    [sym_compilation_unit] = STATE(16621),
    [sym__top_level_definition] = STATE(14482),
    [sym_enum_definition] = STATE(15474),
    [sym_package_clause] = STATE(15474),
    [sym_package_object] = STATE(15474),
    [sym_import_declaration] = STATE(15474),
    [sym_export_declaration] = STATE(15474),
    [sym_object_definition] = STATE(15474),
    [sym_class_definition] = STATE(15474),
    [sym_trait_definition] = STATE(15474),
    [sym__end_marker] = STATE(15474),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(15474),
    [sym_val_declaration] = STATE(15474),
    [sym__start_val] = STATE(4133),
    [sym_var_declaration] = STATE(15474),
    [sym_var_definition] = STATE(15474),
    [sym__start_var] = STATE(4121),
    [sym_type_definition] = STATE(15474),
    [sym_function_definition] = STATE(15474),
    [sym_function_declaration] = STATE(15474),
    [sym__function_declaration] = STATE(14153),
    [sym_opaque_modifier] = STATE(16836),
    [sym_extension_definition] = STATE(15474),
    [sym_given_definition] = STATE(15474),
    [sym_modifiers] = STATE(12822),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(524),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(10212),
    [sym_expression] = STATE(14016),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym__shebang] = STATE(134),
    [sym_comment] = STATE(1),
    [sym_block_comment] = STATE(1),
    [aux_sym_enum_definition_repeat1] = STATE(4276),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [ts_builtin_sym_end] = ACTIONS(7),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_package] = ACTIONS(17),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_given] = ACTIONS(27),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(35),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_extension] = ACTIONS(47),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_def] = ACTIONS(57),
    [anon_sym_opaque] = ACTIONS(59),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(63),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(69),
    [anon_sym_open] = ACTIONS(71),
    [anon_sym_transparent] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [aux_sym__shebang_token1] = ACTIONS(101),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [2] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17019),
    [sym__braced_template_body2] = STATE(17019),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(2),
    [sym_block_comment] = STATE(2),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(109),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [3] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17027),
    [sym__braced_template_body2] = STATE(17027),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(3),
    [sym_block_comment] = STATE(3),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(177),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [4] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16240),
    [sym__braced_template_body2] = STATE(16240),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(4),
    [sym_block_comment] = STATE(4),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(179),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [5] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16943),
    [sym__braced_template_body2] = STATE(16943),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(5),
    [sym_block_comment] = STATE(5),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(181),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [6] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17299),
    [sym__braced_template_body2] = STATE(17299),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(6),
    [sym_block_comment] = STATE(6),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(183),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [7] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17021),
    [sym__braced_template_body2] = STATE(17021),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(7),
    [sym_block_comment] = STATE(7),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(185),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [8] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17080),
    [sym__braced_template_body2] = STATE(17080),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(8),
    [sym_block_comment] = STATE(8),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(187),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [9] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17141),
    [sym__braced_template_body2] = STATE(17141),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(9),
    [sym_block_comment] = STATE(9),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(189),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [10] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16756),
    [sym__braced_template_body2] = STATE(16756),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(10),
    [sym_block_comment] = STATE(10),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(191),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [11] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17818),
    [sym__braced_template_body2] = STATE(17818),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(11),
    [sym_block_comment] = STATE(11),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [12] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16175),
    [sym__braced_template_body2] = STATE(16175),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(12),
    [sym_block_comment] = STATE(12),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [13] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17731),
    [sym__braced_template_body2] = STATE(17731),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(13),
    [sym_block_comment] = STATE(13),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(197),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [14] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16732),
    [sym__braced_template_body2] = STATE(16732),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(14),
    [sym_block_comment] = STATE(14),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(199),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [15] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17370),
    [sym__braced_template_body2] = STATE(17370),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(15),
    [sym_block_comment] = STATE(15),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(201),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [16] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17337),
    [sym__braced_template_body2] = STATE(17337),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(16),
    [sym_block_comment] = STATE(16),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(203),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [17] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17217),
    [sym__braced_template_body2] = STATE(17217),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(17),
    [sym_block_comment] = STATE(17),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(205),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [18] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17751),
    [sym__braced_template_body2] = STATE(17751),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(18),
    [sym_block_comment] = STATE(18),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(207),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [19] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17452),
    [sym__braced_template_body2] = STATE(17452),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(19),
    [sym_block_comment] = STATE(19),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(209),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [20] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16628),
    [sym__braced_template_body2] = STATE(16628),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(20),
    [sym_block_comment] = STATE(20),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(211),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [21] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17256),
    [sym__braced_template_body2] = STATE(17256),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(21),
    [sym_block_comment] = STATE(21),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(213),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [22] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17265),
    [sym__braced_template_body2] = STATE(17265),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(22),
    [sym_block_comment] = STATE(22),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(215),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [23] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17176),
    [sym__braced_template_body2] = STATE(17176),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(23),
    [sym_block_comment] = STATE(23),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(217),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [24] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16737),
    [sym__braced_template_body2] = STATE(16737),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(24),
    [sym_block_comment] = STATE(24),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(219),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [25] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17581),
    [sym__braced_template_body2] = STATE(17581),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(25),
    [sym_block_comment] = STATE(25),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(221),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [26] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16361),
    [sym__braced_template_body2] = STATE(16361),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(26),
    [sym_block_comment] = STATE(26),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(223),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [27] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16892),
    [sym__braced_template_body2] = STATE(16892),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(27),
    [sym_block_comment] = STATE(27),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(225),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [28] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17229),
    [sym__braced_template_body2] = STATE(17229),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(28),
    [sym_block_comment] = STATE(28),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(227),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [29] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17437),
    [sym__braced_template_body2] = STATE(17437),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(29),
    [sym_block_comment] = STATE(29),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(229),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [30] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17652),
    [sym__braced_template_body2] = STATE(17652),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(30),
    [sym_block_comment] = STATE(30),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(231),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [31] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16158),
    [sym__braced_template_body2] = STATE(16158),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(31),
    [sym_block_comment] = STATE(31),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(233),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [32] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16272),
    [sym__braced_template_body2] = STATE(16272),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(32),
    [sym_block_comment] = STATE(32),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(235),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [33] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16408),
    [sym__braced_template_body2] = STATE(16408),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(33),
    [sym_block_comment] = STATE(33),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(237),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [34] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16540),
    [sym__braced_template_body2] = STATE(16540),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(34),
    [sym_block_comment] = STATE(34),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(239),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [35] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16647),
    [sym__braced_template_body2] = STATE(16647),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(35),
    [sym_block_comment] = STATE(35),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(241),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [36] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16733),
    [sym__braced_template_body2] = STATE(16733),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(36),
    [sym_block_comment] = STATE(36),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(243),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [37] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16827),
    [sym__braced_template_body2] = STATE(16827),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(37),
    [sym_block_comment] = STATE(37),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(245),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [38] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16936),
    [sym__braced_template_body2] = STATE(16936),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(38),
    [sym_block_comment] = STATE(38),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(247),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [39] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17081),
    [sym__braced_template_body2] = STATE(17081),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(39),
    [sym_block_comment] = STATE(39),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(249),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [40] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17198),
    [sym__braced_template_body2] = STATE(17198),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(40),
    [sym_block_comment] = STATE(40),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(251),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [41] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17292),
    [sym__braced_template_body2] = STATE(17292),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(41),
    [sym_block_comment] = STATE(41),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(253),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [42] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17408),
    [sym__braced_template_body2] = STATE(17408),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(42),
    [sym_block_comment] = STATE(42),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(255),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [43] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17505),
    [sym__braced_template_body2] = STATE(17505),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(43),
    [sym_block_comment] = STATE(43),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(257),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [44] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17600),
    [sym__braced_template_body2] = STATE(17600),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(44),
    [sym_block_comment] = STATE(44),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(259),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [45] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16148),
    [sym__braced_template_body2] = STATE(16148),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(45),
    [sym_block_comment] = STATE(45),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(261),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [46] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17827),
    [sym__braced_template_body2] = STATE(17827),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(46),
    [sym_block_comment] = STATE(46),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(263),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [47] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17867),
    [sym__braced_template_body2] = STATE(17867),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(47),
    [sym_block_comment] = STATE(47),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(265),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [48] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16216),
    [sym__braced_template_body2] = STATE(16216),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(48),
    [sym_block_comment] = STATE(48),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(267),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [49] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17163),
    [sym__braced_template_body2] = STATE(17163),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(49),
    [sym_block_comment] = STATE(49),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(269),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [50] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17489),
    [sym__braced_template_body2] = STATE(17489),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(50),
    [sym_block_comment] = STATE(50),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(271),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [51] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17353),
    [sym__braced_template_body2] = STATE(17353),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(51),
    [sym_block_comment] = STATE(51),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(273),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [52] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16372),
    [sym__braced_template_body2] = STATE(16372),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(52),
    [sym_block_comment] = STATE(52),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(275),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [53] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17831),
    [sym__braced_template_body2] = STATE(17831),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(53),
    [sym_block_comment] = STATE(53),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(277),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [54] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16492),
    [sym__braced_template_body2] = STATE(16492),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(54),
    [sym_block_comment] = STATE(54),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(279),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [55] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17254),
    [sym__braced_template_body2] = STATE(17254),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(55),
    [sym_block_comment] = STATE(55),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(281),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [56] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17325),
    [sym__braced_template_body2] = STATE(17325),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(56),
    [sym_block_comment] = STATE(56),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(283),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [57] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17698),
    [sym__braced_template_body2] = STATE(17698),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(57),
    [sym_block_comment] = STATE(57),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(285),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [58] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16310),
    [sym__braced_template_body2] = STATE(16310),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(58),
    [sym_block_comment] = STATE(58),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(287),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [59] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16535),
    [sym__braced_template_body2] = STATE(16535),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(59),
    [sym_block_comment] = STATE(59),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(289),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [60] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16729),
    [sym__braced_template_body2] = STATE(16729),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(60),
    [sym_block_comment] = STATE(60),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(291),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [61] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17025),
    [sym__braced_template_body2] = STATE(17025),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(61),
    [sym_block_comment] = STATE(61),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(293),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [62] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17199),
    [sym__braced_template_body2] = STATE(17199),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(62),
    [sym_block_comment] = STATE(62),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(295),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [63] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17371),
    [sym__braced_template_body2] = STATE(17371),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(63),
    [sym_block_comment] = STATE(63),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [64] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17543),
    [sym__braced_template_body2] = STATE(17543),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(64),
    [sym_block_comment] = STATE(64),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [65] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17668),
    [sym__braced_template_body2] = STATE(17668),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(65),
    [sym_block_comment] = STATE(65),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(301),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [66] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17849),
    [sym__braced_template_body2] = STATE(17849),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(66),
    [sym_block_comment] = STATE(66),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(303),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [67] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16218),
    [sym__braced_template_body2] = STATE(16218),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(67),
    [sym_block_comment] = STATE(67),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(305),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [68] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16327),
    [sym__braced_template_body2] = STATE(16327),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(68),
    [sym_block_comment] = STATE(68),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(307),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [69] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16412),
    [sym__braced_template_body2] = STATE(16412),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(69),
    [sym_block_comment] = STATE(69),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(309),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [70] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16496),
    [sym__braced_template_body2] = STATE(16496),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(70),
    [sym_block_comment] = STATE(70),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(311),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [71] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16553),
    [sym__braced_template_body2] = STATE(16553),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(71),
    [sym_block_comment] = STATE(71),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(313),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [72] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16595),
    [sym__braced_template_body2] = STATE(16595),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(72),
    [sym_block_comment] = STATE(72),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(315),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [73] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16637),
    [sym__braced_template_body2] = STATE(16637),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(73),
    [sym_block_comment] = STATE(73),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(317),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [74] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16695),
    [sym__braced_template_body2] = STATE(16695),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(74),
    [sym_block_comment] = STATE(74),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(319),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [75] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16767),
    [sym__braced_template_body2] = STATE(16767),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(75),
    [sym_block_comment] = STATE(75),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(321),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [76] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16826),
    [sym__braced_template_body2] = STATE(16826),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(76),
    [sym_block_comment] = STATE(76),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(323),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [77] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16896),
    [sym__braced_template_body2] = STATE(16896),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(77),
    [sym_block_comment] = STATE(77),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(325),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [78] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16988),
    [sym__braced_template_body2] = STATE(16988),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(78),
    [sym_block_comment] = STATE(78),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(327),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [79] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17069),
    [sym__braced_template_body2] = STATE(17069),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(79),
    [sym_block_comment] = STATE(79),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(329),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [80] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17145),
    [sym__braced_template_body2] = STATE(17145),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(80),
    [sym_block_comment] = STATE(80),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(331),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [81] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17181),
    [sym__braced_template_body2] = STATE(17181),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(81),
    [sym_block_comment] = STATE(81),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(333),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [82] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17228),
    [sym__braced_template_body2] = STATE(17228),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(82),
    [sym_block_comment] = STATE(82),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(335),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [83] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17278),
    [sym__braced_template_body2] = STATE(17278),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(83),
    [sym_block_comment] = STATE(83),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(337),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [84] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17342),
    [sym__braced_template_body2] = STATE(17342),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(84),
    [sym_block_comment] = STATE(84),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(339),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [85] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17436),
    [sym__braced_template_body2] = STATE(17436),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(85),
    [sym_block_comment] = STATE(85),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(341),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [86] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17546),
    [sym__braced_template_body2] = STATE(17546),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(86),
    [sym_block_comment] = STATE(86),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(343),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [87] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17641),
    [sym__braced_template_body2] = STATE(17641),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(87),
    [sym_block_comment] = STATE(87),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(345),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [88] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17812),
    [sym__braced_template_body2] = STATE(17812),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(88),
    [sym_block_comment] = STATE(88),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(347),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [89] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17129),
    [sym__braced_template_body2] = STATE(17129),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(89),
    [sym_block_comment] = STATE(89),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(349),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [90] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16582),
    [sym__braced_template_body2] = STATE(16582),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(90),
    [sym_block_comment] = STATE(90),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(351),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [91] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16188),
    [sym__braced_template_body2] = STATE(16188),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(91),
    [sym_block_comment] = STATE(91),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(353),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [92] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17182),
    [sym__braced_template_body2] = STATE(17182),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(92),
    [sym_block_comment] = STATE(92),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(355),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [93] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17835),
    [sym__braced_template_body2] = STATE(17835),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(93),
    [sym_block_comment] = STATE(93),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(357),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [94] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16458),
    [sym__braced_template_body2] = STATE(16458),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(94),
    [sym_block_comment] = STATE(94),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(359),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [95] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17032),
    [sym__braced_template_body2] = STATE(17032),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(95),
    [sym_block_comment] = STATE(95),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(361),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [96] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17288),
    [sym__braced_template_body2] = STATE(17288),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(96),
    [sym_block_comment] = STATE(96),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(363),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [97] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17568),
    [sym__braced_template_body2] = STATE(17568),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(97),
    [sym_block_comment] = STATE(97),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(365),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [98] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16159),
    [sym__braced_template_body2] = STATE(16159),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(98),
    [sym_block_comment] = STATE(98),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(367),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [99] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16314),
    [sym__braced_template_body2] = STATE(16314),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(99),
    [sym_block_comment] = STATE(99),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(369),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [100] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16541),
    [sym__braced_template_body2] = STATE(16541),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(100),
    [sym_block_comment] = STATE(100),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(371),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [101] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16773),
    [sym__braced_template_body2] = STATE(16773),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(101),
    [sym_block_comment] = STATE(101),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(373),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [102] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17061),
    [sym__braced_template_body2] = STATE(17061),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(102),
    [sym_block_comment] = STATE(102),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(375),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [103] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17210),
    [sym__braced_template_body2] = STATE(17210),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(103),
    [sym_block_comment] = STATE(103),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(377),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [104] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17312),
    [sym__braced_template_body2] = STATE(17312),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(104),
    [sym_block_comment] = STATE(104),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(379),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [105] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17407),
    [sym__braced_template_body2] = STATE(17407),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(105),
    [sym_block_comment] = STATE(105),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(381),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [106] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17569),
    [sym__braced_template_body2] = STATE(17569),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(106),
    [sym_block_comment] = STATE(106),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(383),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [107] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(17690),
    [sym__braced_template_body2] = STATE(17690),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(107),
    [sym_block_comment] = STATE(107),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(385),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [108] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16169),
    [sym__braced_template_body2] = STATE(16169),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(108),
    [sym_block_comment] = STATE(108),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(387),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [109] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16241),
    [sym__braced_template_body2] = STATE(16241),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(109),
    [sym_block_comment] = STATE(109),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(389),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [110] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16307),
    [sym__braced_template_body2] = STATE(16307),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(110),
    [sym_block_comment] = STATE(110),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(391),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [111] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16396),
    [sym__braced_template_body2] = STATE(16396),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(111),
    [sym_block_comment] = STATE(111),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(393),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [112] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16491),
    [sym__braced_template_body2] = STATE(16491),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(112),
    [sym_block_comment] = STATE(112),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(395),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [113] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16599),
    [sym__braced_template_body2] = STATE(16599),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(113),
    [sym_block_comment] = STATE(113),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(397),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [114] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16671),
    [sym__braced_template_body2] = STATE(16671),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(114),
    [sym_block_comment] = STATE(114),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(399),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [115] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16751),
    [sym__braced_template_body2] = STATE(16751),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(115),
    [sym_block_comment] = STATE(115),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(401),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [116] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16811),
    [sym__braced_template_body2] = STATE(16811),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(116),
    [sym_block_comment] = STATE(116),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(403),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [117] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16870),
    [sym__braced_template_body2] = STATE(16870),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(117),
    [sym_block_comment] = STATE(117),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(405),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [118] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16919),
    [sym__braced_template_body2] = STATE(16919),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(118),
    [sym_block_comment] = STATE(118),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(407),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [119] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__braced_template_body1] = STATE(16259),
    [sym__braced_template_body2] = STATE(16259),
    [sym__end_marker] = STATE(14677),
    [sym_self_type] = STATE(209),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5909),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(119),
    [sym_block_comment] = STATE(119),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(409),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [120] = {
    [sym__top_level_definition] = STATE(14837),
    [sym_enum_definition] = STATE(15474),
    [sym_package_clause] = STATE(15474),
    [sym_package_object] = STATE(15474),
    [sym_import_declaration] = STATE(15474),
    [sym_export_declaration] = STATE(15474),
    [sym_object_definition] = STATE(15474),
    [sym_class_definition] = STATE(15474),
    [sym_trait_definition] = STATE(15474),
    [sym__end_marker] = STATE(15474),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(15474),
    [sym_val_declaration] = STATE(15474),
    [sym__start_val] = STATE(4133),
    [sym_var_declaration] = STATE(15474),
    [sym_var_definition] = STATE(15474),
    [sym__start_var] = STATE(4121),
    [sym_type_definition] = STATE(15474),
    [sym_function_definition] = STATE(15474),
    [sym_function_declaration] = STATE(15474),
    [sym__function_declaration] = STATE(14153),
    [sym_opaque_modifier] = STATE(16836),
    [sym_extension_definition] = STATE(15474),
    [sym_given_definition] = STATE(15474),
    [sym_modifiers] = STATE(12822),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(524),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(10212),
    [sym_expression] = STATE(14016),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(120),
    [sym_block_comment] = STATE(120),
    [aux_sym_enum_definition_repeat1] = STATE(4276),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [ts_builtin_sym_end] = ACTIONS(411),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_package] = ACTIONS(17),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_given] = ACTIONS(27),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(35),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_extension] = ACTIONS(47),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_def] = ACTIONS(57),
    [anon_sym_opaque] = ACTIONS(59),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(63),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(69),
    [anon_sym_open] = ACTIONS(71),
    [anon_sym_transparent] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [121] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17172),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(121),
    [sym_block_comment] = STATE(121),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14479),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(413),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [122] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17851),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(122),
    [sym_block_comment] = STATE(122),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14449),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(419),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [123] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16511),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(123),
    [sym_block_comment] = STATE(123),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14581),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(421),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [124] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17300),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(124),
    [sym_block_comment] = STATE(124),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14468),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(423),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [125] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17454),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(125),
    [sym_block_comment] = STATE(125),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14534),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(425),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [126] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17672),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(126),
    [sym_block_comment] = STATE(126),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14701),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(427),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [127] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16297),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(127),
    [sym_block_comment] = STATE(127),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14427),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(429),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [128] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17456),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(128),
    [sym_block_comment] = STATE(128),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14537),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(431),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [129] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16784),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(129),
    [sym_block_comment] = STATE(129),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14484),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(433),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [130] = {
    [sym__top_level_definition] = STATE(14837),
    [sym_enum_definition] = STATE(15474),
    [sym_package_clause] = STATE(15474),
    [sym_package_object] = STATE(15474),
    [sym_import_declaration] = STATE(15474),
    [sym_export_declaration] = STATE(15474),
    [sym_object_definition] = STATE(15474),
    [sym_class_definition] = STATE(15474),
    [sym_trait_definition] = STATE(15474),
    [sym__end_marker] = STATE(15474),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(15474),
    [sym_val_declaration] = STATE(15474),
    [sym__start_val] = STATE(4133),
    [sym_var_declaration] = STATE(15474),
    [sym_var_definition] = STATE(15474),
    [sym__start_var] = STATE(4121),
    [sym_type_definition] = STATE(15474),
    [sym_function_definition] = STATE(15474),
    [sym_function_declaration] = STATE(15474),
    [sym__function_declaration] = STATE(14153),
    [sym_opaque_modifier] = STATE(16836),
    [sym_extension_definition] = STATE(15474),
    [sym_given_definition] = STATE(15474),
    [sym_modifiers] = STATE(12822),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(524),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(10212),
    [sym_expression] = STATE(14016),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(130),
    [sym_block_comment] = STATE(130),
    [aux_sym_enum_definition_repeat1] = STATE(4276),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [ts_builtin_sym_end] = ACTIONS(435),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_package] = ACTIONS(17),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_given] = ACTIONS(27),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(35),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_extension] = ACTIONS(47),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_def] = ACTIONS(57),
    [anon_sym_opaque] = ACTIONS(59),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(63),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(69),
    [anon_sym_open] = ACTIONS(71),
    [anon_sym_transparent] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [131] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17184),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(131),
    [sym_block_comment] = STATE(131),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14573),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(437),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [132] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16662),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(132),
    [sym_block_comment] = STATE(132),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14435),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(439),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [133] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17387),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(133),
    [sym_block_comment] = STATE(133),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14682),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(441),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [134] = {
    [sym__top_level_definition] = STATE(14489),
    [sym_enum_definition] = STATE(15474),
    [sym_package_clause] = STATE(15474),
    [sym_package_object] = STATE(15474),
    [sym_import_declaration] = STATE(15474),
    [sym_export_declaration] = STATE(15474),
    [sym_object_definition] = STATE(15474),
    [sym_class_definition] = STATE(15474),
    [sym_trait_definition] = STATE(15474),
    [sym__end_marker] = STATE(15474),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(15474),
    [sym_val_declaration] = STATE(15474),
    [sym__start_val] = STATE(4133),
    [sym_var_declaration] = STATE(15474),
    [sym_var_definition] = STATE(15474),
    [sym__start_var] = STATE(4121),
    [sym_type_definition] = STATE(15474),
    [sym_function_definition] = STATE(15474),
    [sym_function_declaration] = STATE(15474),
    [sym__function_declaration] = STATE(14153),
    [sym_opaque_modifier] = STATE(16836),
    [sym_extension_definition] = STATE(15474),
    [sym_given_definition] = STATE(15474),
    [sym_modifiers] = STATE(12822),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(524),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(10212),
    [sym_expression] = STATE(14016),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(134),
    [sym_block_comment] = STATE(134),
    [aux_sym_enum_definition_repeat1] = STATE(4276),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [ts_builtin_sym_end] = ACTIONS(443),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_package] = ACTIONS(17),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_given] = ACTIONS(27),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(35),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_extension] = ACTIONS(47),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_def] = ACTIONS(57),
    [anon_sym_opaque] = ACTIONS(59),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(63),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(69),
    [anon_sym_open] = ACTIONS(71),
    [anon_sym_transparent] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [135] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16652),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(135),
    [sym_block_comment] = STATE(135),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14575),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(445),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [136] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17174),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(136),
    [sym_block_comment] = STATE(136),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14582),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(447),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [137] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16873),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(137),
    [sym_block_comment] = STATE(137),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14498),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(449),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [138] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17855),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(138),
    [sym_block_comment] = STATE(138),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14726),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(451),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [139] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16651),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(139),
    [sym_block_comment] = STATE(139),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14450),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(453),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [140] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16406),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(140),
    [sym_block_comment] = STATE(140),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14530),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(455),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [141] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16611),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(141),
    [sym_block_comment] = STATE(141),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14572),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(457),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [142] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17451),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(142),
    [sym_block_comment] = STATE(142),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14500),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(459),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [143] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17190),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(143),
    [sym_block_comment] = STATE(143),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14690),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(461),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [144] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17226),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(144),
    [sym_block_comment] = STATE(144),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14706),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(463),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [145] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17262),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(145),
    [sym_block_comment] = STATE(145),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14613),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(465),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [146] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16510),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(146),
    [sym_block_comment] = STATE(146),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14583),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(467),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [147] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17180),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_case_clause] = STATE(15947),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(147),
    [sym_block_comment] = STATE(147),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14556),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(469),
    [anon_sym_case] = ACTIONS(415),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [148] = {
    [sym__top_level_definition] = STATE(14837),
    [sym_enum_definition] = STATE(15474),
    [sym_package_clause] = STATE(15474),
    [sym_package_object] = STATE(15474),
    [sym_import_declaration] = STATE(15474),
    [sym_export_declaration] = STATE(15474),
    [sym_object_definition] = STATE(15474),
    [sym_class_definition] = STATE(15474),
    [sym_trait_definition] = STATE(15474),
    [sym__end_marker] = STATE(15474),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(15474),
    [sym_val_declaration] = STATE(15474),
    [sym__start_val] = STATE(4133),
    [sym_var_declaration] = STATE(15474),
    [sym_var_definition] = STATE(15474),
    [sym__start_var] = STATE(4121),
    [sym_type_definition] = STATE(15474),
    [sym_function_definition] = STATE(15474),
    [sym_function_declaration] = STATE(15474),
    [sym__function_declaration] = STATE(14153),
    [sym_opaque_modifier] = STATE(16836),
    [sym_extension_definition] = STATE(15474),
    [sym_given_definition] = STATE(15474),
    [sym_modifiers] = STATE(12822),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(524),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(10212),
    [sym_expression] = STATE(14016),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(148),
    [sym_block_comment] = STATE(148),
    [aux_sym_enum_definition_repeat1] = STATE(4276),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [ts_builtin_sym_end] = ACTIONS(471),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_package] = ACTIONS(17),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_given] = ACTIONS(27),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(35),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_extension] = ACTIONS(47),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_def] = ACTIONS(57),
    [anon_sym_opaque] = ACTIONS(59),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(63),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(69),
    [anon_sym_open] = ACTIONS(71),
    [anon_sym_transparent] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [149] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17557),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(149),
    [sym_block_comment] = STATE(149),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14519),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [150] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17712),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(150),
    [sym_block_comment] = STATE(150),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14593),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [151] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(221),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16349),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5553),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(151),
    [sym_block_comment] = STATE(151),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(559),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__outdent] = ACTIONS(561),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [152] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16251),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(152),
    [sym_block_comment] = STATE(152),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14527),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [153] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16965),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(153),
    [sym_block_comment] = STATE(153),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14519),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [154] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17306),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(154),
    [sym_block_comment] = STATE(154),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14627),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [155] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16253),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(155),
    [sym_block_comment] = STATE(155),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14452),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [156] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17218),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(156),
    [sym_block_comment] = STATE(156),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14452),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [157] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17303),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(157),
    [sym_block_comment] = STATE(157),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14607),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [158] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17052),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(158),
    [sym_block_comment] = STATE(158),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14639),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [159] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17874),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(159),
    [sym_block_comment] = STATE(159),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14645),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [160] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16213),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(160),
    [sym_block_comment] = STATE(160),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14569),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [161] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17864),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(161),
    [sym_block_comment] = STATE(161),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14457),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [162] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16769),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(162),
    [sym_block_comment] = STATE(162),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14566),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [163] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17415),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(163),
    [sym_block_comment] = STATE(163),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14527),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [164] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16642),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(164),
    [sym_block_comment] = STATE(164),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14464),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [165] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17499),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(165),
    [sym_block_comment] = STATE(165),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14472),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [166] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16226),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(166),
    [sym_block_comment] = STATE(166),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14656),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [167] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16668),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(167),
    [sym_block_comment] = STATE(167),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14461),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [168] = {
    [sym__top_level_definition] = STATE(14837),
    [sym_enum_definition] = STATE(15474),
    [sym_package_clause] = STATE(15474),
    [sym_package_object] = STATE(15474),
    [sym_import_declaration] = STATE(15474),
    [sym_export_declaration] = STATE(15474),
    [sym_object_definition] = STATE(15474),
    [sym_class_definition] = STATE(15474),
    [sym_trait_definition] = STATE(15474),
    [sym__end_marker] = STATE(15474),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(15474),
    [sym_val_declaration] = STATE(15474),
    [sym__start_val] = STATE(4133),
    [sym_var_declaration] = STATE(15474),
    [sym_var_definition] = STATE(15474),
    [sym__start_var] = STATE(4121),
    [sym_type_definition] = STATE(15474),
    [sym_function_definition] = STATE(15474),
    [sym_function_declaration] = STATE(15474),
    [sym__function_declaration] = STATE(14153),
    [sym_opaque_modifier] = STATE(16836),
    [sym_extension_definition] = STATE(15474),
    [sym_given_definition] = STATE(15474),
    [sym_modifiers] = STATE(12822),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(524),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(10212),
    [sym_expression] = STATE(14016),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(168),
    [sym_block_comment] = STATE(168),
    [aux_sym_enum_definition_repeat1] = STATE(4276),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_package] = ACTIONS(17),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_given] = ACTIONS(27),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(35),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_extension] = ACTIONS(47),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_def] = ACTIONS(57),
    [anon_sym_opaque] = ACTIONS(59),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(63),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(69),
    [anon_sym_open] = ACTIONS(71),
    [anon_sym_transparent] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [169] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17290),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(169),
    [sym_block_comment] = STATE(169),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14557),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [170] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16243),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(170),
    [sym_block_comment] = STATE(170),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14557),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [171] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17272),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(171),
    [sym_block_comment] = STATE(171),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14627),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [172] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16858),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(172),
    [sym_block_comment] = STATE(172),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14422),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [173] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17632),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(173),
    [sym_block_comment] = STATE(173),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14639),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [174] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16388),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(174),
    [sym_block_comment] = STATE(174),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14462),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [175] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16967),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(175),
    [sym_block_comment] = STATE(175),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14605),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [176] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17243),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(176),
    [sym_block_comment] = STATE(176),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14645),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [177] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17470),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(177),
    [sym_block_comment] = STATE(177),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14428),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [178] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17666),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(178),
    [sym_block_comment] = STATE(178),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14569),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [179] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16176),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(179),
    [sym_block_comment] = STATE(179),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14566),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [180] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16280),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(180),
    [sym_block_comment] = STATE(180),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14681),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [181] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16426),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(181),
    [sym_block_comment] = STATE(181),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14589),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [182] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16554),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(182),
    [sym_block_comment] = STATE(182),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14441),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [183] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16659),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(183),
    [sym_block_comment] = STATE(183),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14513),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [184] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16747),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(184),
    [sym_block_comment] = STATE(184),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14472),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [185] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16838),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(185),
    [sym_block_comment] = STATE(185),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14656),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [186] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16956),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(186),
    [sym_block_comment] = STATE(186),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14461),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [187] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17093),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(187),
    [sym_block_comment] = STATE(187),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14593),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [188] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17207),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(188),
    [sym_block_comment] = STATE(188),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14462),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [189] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17305),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(189),
    [sym_block_comment] = STATE(189),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14605),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [190] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17417),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(190),
    [sym_block_comment] = STATE(190),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14428),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [191] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17516),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(191),
    [sym_block_comment] = STATE(191),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14719),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [192] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17609),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(192),
    [sym_block_comment] = STATE(192),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14513),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [193] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17682),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_case_clause] = STATE(16060),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(193),
    [sym_block_comment] = STATE(193),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [aux_sym_indented_cases_repeat1] = STATE(14457),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(479),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [194] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(426),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17068),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(194),
    [sym_block_comment] = STATE(194),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [195] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(356),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17840),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(195),
    [sym_block_comment] = STATE(195),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [196] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(481),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17043),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(196),
    [sym_block_comment] = STATE(196),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [197] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16611),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(197),
    [sym_block_comment] = STATE(197),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(565),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [198] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(358),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16790),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(198),
    [sym_block_comment] = STATE(198),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [199] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(489),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17334),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(199),
    [sym_block_comment] = STATE(199),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [200] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(361),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17541),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(200),
    [sym_block_comment] = STATE(200),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [201] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16277),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(201),
    [sym_block_comment] = STATE(201),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(567),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [202] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(364),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17138),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(202),
    [sym_block_comment] = STATE(202),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [203] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(497),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17562),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(203),
    [sym_block_comment] = STATE(203),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [204] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(367),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17588),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(204),
    [sym_block_comment] = STATE(204),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [205] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16651),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(205),
    [sym_block_comment] = STATE(205),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(569),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [206] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(370),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17159),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(206),
    [sym_block_comment] = STATE(206),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [207] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(505),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16450),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(207),
    [sym_block_comment] = STATE(207),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [208] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(373),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17729),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(208),
    [sym_block_comment] = STATE(208),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [209] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16384),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(209),
    [sym_block_comment] = STATE(209),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(571),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [210] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(376),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16528),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(210),
    [sym_block_comment] = STATE(210),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [211] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(326),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17839),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(211),
    [sym_block_comment] = STATE(211),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [212] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(379),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17064),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(212),
    [sym_block_comment] = STATE(212),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [213] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17237),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(213),
    [sym_block_comment] = STATE(213),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(573),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [214] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(381),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17285),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(214),
    [sym_block_comment] = STATE(214),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [215] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(329),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17868),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(215),
    [sym_block_comment] = STATE(215),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [216] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(383),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17503),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(216),
    [sym_block_comment] = STATE(216),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [217] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16752),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(217),
    [sym_block_comment] = STATE(217),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(575),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [218] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(385),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17706),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(218),
    [sym_block_comment] = STATE(218),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [219] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(332),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16149),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(219),
    [sym_block_comment] = STATE(219),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [220] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(386),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16187),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(220),
    [sym_block_comment] = STATE(220),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [221] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16593),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(221),
    [sym_block_comment] = STATE(221),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__outdent] = ACTIONS(577),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [222] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(387),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16305),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(222),
    [sym_block_comment] = STATE(222),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [223] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(335),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16801),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(223),
    [sym_block_comment] = STATE(223),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [224] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(388),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16438),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(224),
    [sym_block_comment] = STATE(224),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [225] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(417),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17230),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(225),
    [sym_block_comment] = STATE(225),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [226] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(389),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16576),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(226),
    [sym_block_comment] = STATE(226),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [227] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(338),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16369),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(227),
    [sym_block_comment] = STATE(227),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [228] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(390),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16673),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(228),
    [sym_block_comment] = STATE(228),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [229] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16710),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(229),
    [sym_block_comment] = STATE(229),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(579),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [230] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(391),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16762),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(230),
    [sym_block_comment] = STATE(230),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [231] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(341),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16876),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(231),
    [sym_block_comment] = STATE(231),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [232] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(392),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16855),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(232),
    [sym_block_comment] = STATE(232),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [233] = {
    [sym_enum_definition] = STATE(14206),
    [sym_import_declaration] = STATE(14206),
    [sym_export_declaration] = STATE(14206),
    [sym_object_definition] = STATE(14206),
    [sym_class_definition] = STATE(14206),
    [sym_trait_definition] = STATE(14206),
    [sym__end_marker] = STATE(14206),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14206),
    [sym_val_declaration] = STATE(14206),
    [sym__start_val] = STATE(4111),
    [sym_var_declaration] = STATE(14206),
    [sym_var_definition] = STATE(14206),
    [sym__start_var] = STATE(4080),
    [sym_type_definition] = STATE(14206),
    [sym_function_definition] = STATE(14206),
    [sym_function_declaration] = STATE(14206),
    [sym__function_declaration] = STATE(13937),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14206),
    [sym_given_definition] = STATE(14206),
    [sym_modifiers] = STATE(12967),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(525),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(15963),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13738),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(233),
    [sym_block_comment] = STATE(233),
    [aux_sym_enum_definition_repeat1] = STATE(4261),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(581),
    [anon_sym_case] = ACTIONS(583),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(585),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(597),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(599),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(601),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [234] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(393),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16980),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(234),
    [sym_block_comment] = STATE(234),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [235] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(344),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17571),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(235),
    [sym_block_comment] = STATE(235),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [236] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(394),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17127),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(236),
    [sym_block_comment] = STATE(236),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [237] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(469),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16351),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(237),
    [sym_block_comment] = STATE(237),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [238] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(395),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17225),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(238),
    [sym_block_comment] = STATE(238),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [239] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(347),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17335),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(239),
    [sym_block_comment] = STATE(239),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [240] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(396),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17332),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(240),
    [sym_block_comment] = STATE(240),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [241] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(472),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16465),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(241),
    [sym_block_comment] = STATE(241),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [242] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(397),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17432),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(242),
    [sym_block_comment] = STATE(242),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [243] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(350),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16233),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(243),
    [sym_block_comment] = STATE(243),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [244] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(400),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17529),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(244),
    [sym_block_comment] = STATE(244),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [245] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(399),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16326),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(245),
    [sym_block_comment] = STATE(245),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [246] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(403),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17623),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(246),
    [sym_block_comment] = STATE(246),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [247] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(353),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16516),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(247),
    [sym_block_comment] = STATE(247),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [248] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(404),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17727),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(248),
    [sym_block_comment] = STATE(248),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [249] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(405),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17837),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(249),
    [sym_block_comment] = STATE(249),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [250] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(406),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16480),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(250),
    [sym_block_comment] = STATE(250),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [251] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(408),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17012),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(251),
    [sym_block_comment] = STATE(251),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [252] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(410),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17664),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(252),
    [sym_block_comment] = STATE(252),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [253] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(411),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16346),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(253),
    [sym_block_comment] = STATE(253),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [254] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(413),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17504),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(254),
    [sym_block_comment] = STATE(254),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [255] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(414),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16539),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(255),
    [sym_block_comment] = STATE(255),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [256] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(415),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17150),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(256),
    [sym_block_comment] = STATE(256),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [257] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(416),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17826),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(257),
    [sym_block_comment] = STATE(257),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [258] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(418),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17117),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(258),
    [sym_block_comment] = STATE(258),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [259] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(419),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16389),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(259),
    [sym_block_comment] = STATE(259),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [260] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(420),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17429),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(260),
    [sym_block_comment] = STATE(260),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [261] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(421),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17844),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(261),
    [sym_block_comment] = STATE(261),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [262] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(422),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16337),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(262),
    [sym_block_comment] = STATE(262),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [263] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(423),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16634),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(263),
    [sym_block_comment] = STATE(263),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [264] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(424),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16803),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(264),
    [sym_block_comment] = STATE(264),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [265] = {
    [sym_enum_definition] = STATE(14256),
    [sym_import_declaration] = STATE(14256),
    [sym_export_declaration] = STATE(14256),
    [sym_object_definition] = STATE(14256),
    [sym_class_definition] = STATE(14256),
    [sym_trait_definition] = STATE(14256),
    [sym__end_marker] = STATE(14256),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14256),
    [sym_val_declaration] = STATE(14256),
    [sym__start_val] = STATE(4089),
    [sym_var_declaration] = STATE(14256),
    [sym_var_definition] = STATE(14256),
    [sym__start_var] = STATE(4110),
    [sym_type_definition] = STATE(14256),
    [sym_function_definition] = STATE(14256),
    [sym_function_declaration] = STATE(14256),
    [sym__function_declaration] = STATE(13993),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14256),
    [sym_given_definition] = STATE(14256),
    [sym_modifiers] = STATE(12965),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(526),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(15861),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13754),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(265),
    [sym_block_comment] = STATE(265),
    [aux_sym_enum_definition_repeat1] = STATE(4262),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(583),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(611),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(623),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(625),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(627),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__outdent] = ACTIONS(581),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [266] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(507),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17036),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(266),
    [sym_block_comment] = STATE(266),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [267] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(429),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17416),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(267),
    [sym_block_comment] = STATE(267),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [268] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(430),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17575),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(268),
    [sym_block_comment] = STATE(268),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [269] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(431),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17714),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(269),
    [sym_block_comment] = STATE(269),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [270] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(432),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16157),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(270),
    [sym_block_comment] = STATE(270),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [271] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(433),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16236),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(271),
    [sym_block_comment] = STATE(271),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [272] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(434),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16354),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(272),
    [sym_block_comment] = STATE(272),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [273] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(435),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16443),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(273),
    [sym_block_comment] = STATE(273),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [274] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(436),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16517),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(274),
    [sym_block_comment] = STATE(274),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [275] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(437),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16567),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(275),
    [sym_block_comment] = STATE(275),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [276] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(438),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16614),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(276),
    [sym_block_comment] = STATE(276),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [277] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(440),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16667),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(277),
    [sym_block_comment] = STATE(277),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [278] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(441),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16717),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(278),
    [sym_block_comment] = STATE(278),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [279] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(443),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16786),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(279),
    [sym_block_comment] = STATE(279),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [280] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(444),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16843),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(280),
    [sym_block_comment] = STATE(280),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [281] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(445),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16912),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(281),
    [sym_block_comment] = STATE(281),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [282] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(446),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17031),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(282),
    [sym_block_comment] = STATE(282),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [283] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(447),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17115),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(283),
    [sym_block_comment] = STATE(283),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [284] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(448),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17157),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(284),
    [sym_block_comment] = STATE(284),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [285] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(450),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17196),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(285),
    [sym_block_comment] = STATE(285),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [286] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(452),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17249),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(286),
    [sym_block_comment] = STATE(286),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [287] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(453),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17298),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(287),
    [sym_block_comment] = STATE(287),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [288] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(454),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17379),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(288),
    [sym_block_comment] = STATE(288),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [289] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(455),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17481),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(289),
    [sym_block_comment] = STATE(289),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [290] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(456),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17577),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(290),
    [sym_block_comment] = STATE(290),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [291] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(457),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17678),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(291),
    [sym_block_comment] = STATE(291),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [292] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(458),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17830),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(292),
    [sym_block_comment] = STATE(292),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [293] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(459),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16164),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(293),
    [sym_block_comment] = STATE(293),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [294] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(460),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17232),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(294),
    [sym_block_comment] = STATE(294),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [295] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(462),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16451),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(295),
    [sym_block_comment] = STATE(295),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [296] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(464),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17329),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(296),
    [sym_block_comment] = STATE(296),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [297] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(466),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16229),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(297),
    [sym_block_comment] = STATE(297),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [298] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(467),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16617),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(298),
    [sym_block_comment] = STATE(298),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [299] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(468),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17122),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(299),
    [sym_block_comment] = STATE(299),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [300] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(470),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17359),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(300),
    [sym_block_comment] = STATE(300),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [301] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(471),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17656),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(301),
    [sym_block_comment] = STATE(301),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [302] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(473),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16214),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(302),
    [sym_block_comment] = STATE(302),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [303] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(474),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16409),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(303),
    [sym_block_comment] = STATE(303),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [304] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(476),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16601),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(304),
    [sym_block_comment] = STATE(304),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [305] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(478),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16880),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(305),
    [sym_block_comment] = STATE(305),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [306] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(480),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17103),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(306),
    [sym_block_comment] = STATE(306),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [307] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(482),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17235),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(307),
    [sym_block_comment] = STATE(307),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [308] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(483),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17354),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(308),
    [sym_block_comment] = STATE(308),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [309] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(485),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17439),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(309),
    [sym_block_comment] = STATE(309),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [310] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(487),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17598),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(310),
    [sym_block_comment] = STATE(310),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [311] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(488),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17724),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(311),
    [sym_block_comment] = STATE(311),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [312] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(490),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16197),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(312),
    [sym_block_comment] = STATE(312),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [313] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(491),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16250),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(313),
    [sym_block_comment] = STATE(313),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [314] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(493),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16329),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(314),
    [sym_block_comment] = STATE(314),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [315] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(495),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16433),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(315),
    [sym_block_comment] = STATE(315),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [316] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(496),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16520),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(316),
    [sym_block_comment] = STATE(316),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [317] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(498),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16613),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(317),
    [sym_block_comment] = STATE(317),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [318] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(499),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16698),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(318),
    [sym_block_comment] = STATE(318),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [319] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(501),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16755),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(319),
    [sym_block_comment] = STATE(319),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [320] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(503),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16823),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(320),
    [sym_block_comment] = STATE(320),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [321] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(504),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16894),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(321),
    [sym_block_comment] = STATE(321),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [322] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(506),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16932),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(322),
    [sym_block_comment] = STATE(322),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [323] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_self_type] = STATE(427),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17238),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5651),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(323),
    [sym_block_comment] = STATE(323),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(563),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [324] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16709),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(324),
    [sym_block_comment] = STATE(324),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [325] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17653),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(325),
    [sym_block_comment] = STATE(325),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [326] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16922),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(326),
    [sym_block_comment] = STATE(326),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [327] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17187),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(327),
    [sym_block_comment] = STATE(327),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [328] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17211),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(328),
    [sym_block_comment] = STATE(328),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [329] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16494),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(329),
    [sym_block_comment] = STATE(329),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [330] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16191),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(330),
    [sym_block_comment] = STATE(330),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [331] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17076),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(331),
    [sym_block_comment] = STATE(331),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [332] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17547),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(332),
    [sym_block_comment] = STATE(332),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [333] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16367),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(333),
    [sym_block_comment] = STATE(333),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [334] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16506),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(334),
    [sym_block_comment] = STATE(334),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [335] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17136),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(335),
    [sym_block_comment] = STATE(335),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [336] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17606),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(336),
    [sym_block_comment] = STATE(336),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [337] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16242),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(337),
    [sym_block_comment] = STATE(337),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [338] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16478),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(338),
    [sym_block_comment] = STATE(338),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [339] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16802),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(339),
    [sym_block_comment] = STATE(339),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [340] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16808),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(340),
    [sym_block_comment] = STATE(340),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [341] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16976),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(341),
    [sym_block_comment] = STATE(341),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [342] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17475),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(342),
    [sym_block_comment] = STATE(342),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [343] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17484),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(343),
    [sym_block_comment] = STATE(343),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [344] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17696),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(344),
    [sym_block_comment] = STATE(344),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [345] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16895),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(345),
    [sym_block_comment] = STATE(345),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [346] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17510),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(346),
    [sym_block_comment] = STATE(346),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [347] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17604),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(347),
    [sym_block_comment] = STATE(347),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [348] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17273),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(348),
    [sym_block_comment] = STATE(348),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [349] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16256),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(349),
    [sym_block_comment] = STATE(349),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [350] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17719),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(350),
    [sym_block_comment] = STATE(350),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [351] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16321),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(351),
    [sym_block_comment] = STATE(351),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [352] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16325),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(352),
    [sym_block_comment] = STATE(352),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [353] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16743),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(353),
    [sym_block_comment] = STATE(353),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [354] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17597),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(354),
    [sym_block_comment] = STATE(354),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [355] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17624),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(355),
    [sym_block_comment] = STATE(355),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [356] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16249),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(356),
    [sym_block_comment] = STATE(356),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [357] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16699),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(357),
    [sym_block_comment] = STATE(357),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [358] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16899),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(358),
    [sym_block_comment] = STATE(358),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [359] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17412),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(359),
    [sym_block_comment] = STATE(359),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [360] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17433),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(360),
    [sym_block_comment] = STATE(360),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [361] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17732),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(361),
    [sym_block_comment] = STATE(361),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [362] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16512),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(362),
    [sym_block_comment] = STATE(362),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [363] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16618),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(363),
    [sym_block_comment] = STATE(363),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [364] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17591),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(364),
    [sym_block_comment] = STATE(364),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [365] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17390),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(365),
    [sym_block_comment] = STATE(365),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [366] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17430),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(366),
    [sym_block_comment] = STATE(366),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [367] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16199),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(367),
    [sym_block_comment] = STATE(367),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [368] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16918),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(368),
    [sym_block_comment] = STATE(368),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [369] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17022),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(369),
    [sym_block_comment] = STATE(369),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [370] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17282),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(370),
    [sym_block_comment] = STATE(370),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [371] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17683),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(371),
    [sym_block_comment] = STATE(371),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [372] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17689),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(372),
    [sym_block_comment] = STATE(372),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [373] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16174),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(373),
    [sym_block_comment] = STATE(373),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [374] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16435),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(374),
    [sym_block_comment] = STATE(374),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [375] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16468),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(375),
    [sym_block_comment] = STATE(375),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [376] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16627),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(376),
    [sym_block_comment] = STATE(376),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [377] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16997),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(377),
    [sym_block_comment] = STATE(377),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [378] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17010),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(378),
    [sym_block_comment] = STATE(378),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [379] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17135),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(379),
    [sym_block_comment] = STATE(379),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [380] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17261),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(380),
    [sym_block_comment] = STATE(380),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [381] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17314),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(381),
    [sym_block_comment] = STATE(381),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [382] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17479),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(382),
    [sym_block_comment] = STATE(382),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [383] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17551),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(383),
    [sym_block_comment] = STATE(383),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [384] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17686),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(384),
    [sym_block_comment] = STATE(384),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [385] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17741),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(385),
    [sym_block_comment] = STATE(385),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [386] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16209),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(386),
    [sym_block_comment] = STATE(386),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [387] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16344),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(387),
    [sym_block_comment] = STATE(387),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [388] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16473),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(388),
    [sym_block_comment] = STATE(388),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [389] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16598),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(389),
    [sym_block_comment] = STATE(389),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [390] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16697),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(390),
    [sym_block_comment] = STATE(390),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [391] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16781),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(391),
    [sym_block_comment] = STATE(391),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [392] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16875),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(392),
    [sym_block_comment] = STATE(392),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [393] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17020),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(393),
    [sym_block_comment] = STATE(393),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [394] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17153),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(394),
    [sym_block_comment] = STATE(394),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [395] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17248),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(395),
    [sym_block_comment] = STATE(395),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [396] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17357),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(396),
    [sym_block_comment] = STATE(396),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [397] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17459),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(397),
    [sym_block_comment] = STATE(397),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [398] = {
    [sym_enum_definition] = STATE(14517),
    [sym_import_declaration] = STATE(14517),
    [sym_export_declaration] = STATE(14517),
    [sym_object_definition] = STATE(14517),
    [sym_class_definition] = STATE(14517),
    [sym_trait_definition] = STATE(14517),
    [sym__end_marker] = STATE(14517),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14517),
    [sym_val_declaration] = STATE(14517),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14517),
    [sym_var_definition] = STATE(14517),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14517),
    [sym_function_definition] = STATE(14517),
    [sym_function_declaration] = STATE(14517),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14517),
    [sym_given_definition] = STATE(14517),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13985),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(398),
    [sym_block_comment] = STATE(398),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(637),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(639),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [399] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17677),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(399),
    [sym_block_comment] = STATE(399),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [400] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17552),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(400),
    [sym_block_comment] = STATE(400),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [401] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17118),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(401),
    [sym_block_comment] = STATE(401),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [402] = {
    [sym_enum_definition] = STATE(14655),
    [sym__enum_block] = STATE(16348),
    [sym_enum_case_definitions] = STATE(14655),
    [sym_import_declaration] = STATE(14655),
    [sym_export_declaration] = STATE(14655),
    [sym_object_definition] = STATE(14655),
    [sym_class_definition] = STATE(14655),
    [sym_trait_definition] = STATE(14655),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14655),
    [sym_val_declaration] = STATE(14655),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14655),
    [sym_var_definition] = STATE(14655),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14655),
    [sym_function_definition] = STATE(14655),
    [sym_function_declaration] = STATE(14655),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14655),
    [sym_given_definition] = STATE(14655),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13934),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(402),
    [sym_block_comment] = STATE(402),
    [aux_sym_enum_definition_repeat1] = STATE(4265),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(641),
    [anon_sym_case] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [403] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17648),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(403),
    [sym_block_comment] = STATE(403),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [404] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17752),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(404),
    [sym_block_comment] = STATE(404),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [405] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17847),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(405),
    [sym_block_comment] = STATE(405),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [406] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16331),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(406),
    [sym_block_comment] = STATE(406),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [407] = {
    [sym_enum_definition] = STATE(14517),
    [sym_import_declaration] = STATE(14517),
    [sym_export_declaration] = STATE(14517),
    [sym_object_definition] = STATE(14517),
    [sym_class_definition] = STATE(14517),
    [sym_trait_definition] = STATE(14517),
    [sym__end_marker] = STATE(14517),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14517),
    [sym_val_declaration] = STATE(14517),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14517),
    [sym_var_definition] = STATE(14517),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14517),
    [sym_function_definition] = STATE(14517),
    [sym_function_declaration] = STATE(14517),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14517),
    [sym_given_definition] = STATE(14517),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13985),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(407),
    [sym_block_comment] = STATE(407),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(647),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(639),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [408] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16183),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(408),
    [sym_block_comment] = STATE(408),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [409] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17063),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(409),
    [sym_block_comment] = STATE(409),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [410] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16252),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(410),
    [sym_block_comment] = STATE(410),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [411] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16678),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(411),
    [sym_block_comment] = STATE(411),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [412] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16581),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(412),
    [sym_block_comment] = STATE(412),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [413] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17663),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(413),
    [sym_block_comment] = STATE(413),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [414] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16654),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(414),
    [sym_block_comment] = STATE(414),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [415] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17304),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(415),
    [sym_block_comment] = STATE(415),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [416] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17231),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(416),
    [sym_block_comment] = STATE(416),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [417] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17070),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(417),
    [sym_block_comment] = STATE(417),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [418] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17388),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(418),
    [sym_block_comment] = STATE(418),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [419] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16641),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(419),
    [sym_block_comment] = STATE(419),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [420] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17532),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(420),
    [sym_block_comment] = STATE(420),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [421] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16205),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(421),
    [sym_block_comment] = STATE(421),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [422] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16485),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(422),
    [sym_block_comment] = STATE(422),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [423] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16676),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(423),
    [sym_block_comment] = STATE(423),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [424] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16878),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(424),
    [sym_block_comment] = STATE(424),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [425] = {
    [sym_enum_definition] = STATE(14478),
    [sym_import_declaration] = STATE(14478),
    [sym_export_declaration] = STATE(14478),
    [sym_object_definition] = STATE(14478),
    [sym_class_definition] = STATE(14478),
    [sym_trait_definition] = STATE(14478),
    [sym__end_marker] = STATE(14478),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14478),
    [sym_val_declaration] = STATE(14478),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14478),
    [sym_var_definition] = STATE(14478),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14478),
    [sym_function_definition] = STATE(14478),
    [sym_function_declaration] = STATE(14478),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14478),
    [sym_given_definition] = STATE(14478),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13971),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(425),
    [sym_block_comment] = STATE(425),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(649),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__outdent] = ACTIONS(647),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [426] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17146),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(426),
    [sym_block_comment] = STATE(426),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [427] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17315),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(427),
    [sym_block_comment] = STATE(427),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [428] = {
    [sym_enum_definition] = STATE(14478),
    [sym_import_declaration] = STATE(14478),
    [sym_export_declaration] = STATE(14478),
    [sym_object_definition] = STATE(14478),
    [sym_class_definition] = STATE(14478),
    [sym_trait_definition] = STATE(14478),
    [sym__end_marker] = STATE(14478),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14478),
    [sym_val_declaration] = STATE(14478),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14478),
    [sym_var_definition] = STATE(14478),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14478),
    [sym_function_definition] = STATE(14478),
    [sym_function_declaration] = STATE(14478),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14478),
    [sym_given_definition] = STATE(14478),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13971),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(428),
    [sym_block_comment] = STATE(428),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(649),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__outdent] = ACTIONS(637),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [429] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17490),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(429),
    [sym_block_comment] = STATE(429),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [430] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17603),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(430),
    [sym_block_comment] = STATE(430),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [431] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17747),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(431),
    [sym_block_comment] = STATE(431),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [432] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16182),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(432),
    [sym_block_comment] = STATE(432),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [433] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16271),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(433),
    [sym_block_comment] = STATE(433),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [434] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16381),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(434),
    [sym_block_comment] = STATE(434),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [435] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16475),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(435),
    [sym_block_comment] = STATE(435),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [436] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16538),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(436),
    [sym_block_comment] = STATE(436),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [437] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16579),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(437),
    [sym_block_comment] = STATE(437),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [438] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16622),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(438),
    [sym_block_comment] = STATE(438),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [439] = {
    [sym_enum_definition] = STATE(14517),
    [sym_import_declaration] = STATE(14517),
    [sym_export_declaration] = STATE(14517),
    [sym_object_definition] = STATE(14517),
    [sym_class_definition] = STATE(14517),
    [sym_trait_definition] = STATE(14517),
    [sym__end_marker] = STATE(14517),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14517),
    [sym_val_declaration] = STATE(14517),
    [sym__start_val] = STATE(4111),
    [sym_var_declaration] = STATE(14517),
    [sym_var_definition] = STATE(14517),
    [sym__start_var] = STATE(4080),
    [sym_type_definition] = STATE(14517),
    [sym_function_definition] = STATE(14517),
    [sym_function_declaration] = STATE(14517),
    [sym__function_declaration] = STATE(13937),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14517),
    [sym_given_definition] = STATE(14517),
    [sym_modifiers] = STATE(12967),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(525),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13985),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(439),
    [sym_block_comment] = STATE(439),
    [aux_sym_enum_definition_repeat1] = STATE(4261),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(647),
    [anon_sym_case] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(585),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(597),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(599),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(639),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [440] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16680),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(440),
    [sym_block_comment] = STATE(440),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [441] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16750),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(441),
    [sym_block_comment] = STATE(441),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [442] = {
    [sym_enum_definition] = STATE(14517),
    [sym_import_declaration] = STATE(14517),
    [sym_export_declaration] = STATE(14517),
    [sym_object_definition] = STATE(14517),
    [sym_class_definition] = STATE(14517),
    [sym_trait_definition] = STATE(14517),
    [sym__end_marker] = STATE(14517),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14517),
    [sym_val_declaration] = STATE(14517),
    [sym__start_val] = STATE(4111),
    [sym_var_declaration] = STATE(14517),
    [sym_var_definition] = STATE(14517),
    [sym__start_var] = STATE(4080),
    [sym_type_definition] = STATE(14517),
    [sym_function_definition] = STATE(14517),
    [sym_function_declaration] = STATE(14517),
    [sym__function_declaration] = STATE(13937),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14517),
    [sym_given_definition] = STATE(14517),
    [sym_modifiers] = STATE(12967),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(525),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13985),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(442),
    [sym_block_comment] = STATE(442),
    [aux_sym_enum_definition_repeat1] = STATE(4261),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(637),
    [anon_sym_case] = ACTIONS(653),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(585),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(597),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(599),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(639),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [443] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16798),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(443),
    [sym_block_comment] = STATE(443),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [444] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16874),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(444),
    [sym_block_comment] = STATE(444),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [445] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16935),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(445),
    [sym_block_comment] = STATE(445),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [446] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17045),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(446),
    [sym_block_comment] = STATE(446),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [447] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17875),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(447),
    [sym_block_comment] = STATE(447),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [448] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17168),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(448),
    [sym_block_comment] = STATE(448),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [449] = {
    [sym_enum_definition] = STATE(14478),
    [sym_import_declaration] = STATE(14478),
    [sym_export_declaration] = STATE(14478),
    [sym_object_definition] = STATE(14478),
    [sym_class_definition] = STATE(14478),
    [sym_trait_definition] = STATE(14478),
    [sym__end_marker] = STATE(14478),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14478),
    [sym_val_declaration] = STATE(14478),
    [sym__start_val] = STATE(4089),
    [sym_var_declaration] = STATE(14478),
    [sym_var_definition] = STATE(14478),
    [sym__start_var] = STATE(4110),
    [sym_type_definition] = STATE(14478),
    [sym_function_definition] = STATE(14478),
    [sym_function_declaration] = STATE(14478),
    [sym__function_declaration] = STATE(13993),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14478),
    [sym_given_definition] = STATE(14478),
    [sym_modifiers] = STATE(12965),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(526),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13971),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(449),
    [sym_block_comment] = STATE(449),
    [aux_sym_enum_definition_repeat1] = STATE(4262),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(651),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(611),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(623),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(625),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(649),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__outdent] = ACTIONS(647),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [450] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17214),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(450),
    [sym_block_comment] = STATE(450),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [451] = {
    [sym_enum_definition] = STATE(14478),
    [sym_import_declaration] = STATE(14478),
    [sym_export_declaration] = STATE(14478),
    [sym_object_definition] = STATE(14478),
    [sym_class_definition] = STATE(14478),
    [sym_trait_definition] = STATE(14478),
    [sym__end_marker] = STATE(14478),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14478),
    [sym_val_declaration] = STATE(14478),
    [sym__start_val] = STATE(4089),
    [sym_var_declaration] = STATE(14478),
    [sym_var_definition] = STATE(14478),
    [sym__start_var] = STATE(4110),
    [sym_type_definition] = STATE(14478),
    [sym_function_definition] = STATE(14478),
    [sym_function_declaration] = STATE(14478),
    [sym__function_declaration] = STATE(13993),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14478),
    [sym_given_definition] = STATE(14478),
    [sym_modifiers] = STATE(12965),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(526),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13971),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(451),
    [sym_block_comment] = STATE(451),
    [aux_sym_enum_definition_repeat1] = STATE(4262),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(653),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(611),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(623),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(625),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(649),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__outdent] = ACTIONS(637),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [452] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17260),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(452),
    [sym_block_comment] = STATE(452),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [453] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17324),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(453),
    [sym_block_comment] = STATE(453),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [454] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17404),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(454),
    [sym_block_comment] = STATE(454),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [455] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17517),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(455),
    [sym_block_comment] = STATE(455),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [456] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17618),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(456),
    [sym_block_comment] = STATE(456),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [457] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17730),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(457),
    [sym_block_comment] = STATE(457),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [458] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17856),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(458),
    [sym_block_comment] = STATE(458),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [459] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17365),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(459),
    [sym_block_comment] = STATE(459),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [460] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17485),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(460),
    [sym_block_comment] = STATE(460),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [461] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16276),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(461),
    [sym_block_comment] = STATE(461),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [462] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17037),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(462),
    [sym_block_comment] = STATE(462),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [463] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16290),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(463),
    [sym_block_comment] = STATE(463),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [464] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17579),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(464),
    [sym_block_comment] = STATE(464),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [465] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16295),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(465),
    [sym_block_comment] = STATE(465),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [466] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16365),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(466),
    [sym_block_comment] = STATE(466),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [467] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16787),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(467),
    [sym_block_comment] = STATE(467),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [468] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17220),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(468),
    [sym_block_comment] = STATE(468),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [469] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16448),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(469),
    [sym_block_comment] = STATE(469),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [470] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17435),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(470),
    [sym_block_comment] = STATE(470),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [471] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17721),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(471),
    [sym_block_comment] = STATE(471),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [472] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16513),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(472),
    [sym_block_comment] = STATE(472),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [473] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16247),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(473),
    [sym_block_comment] = STATE(473),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [474] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16456),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(474),
    [sym_block_comment] = STATE(474),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [475] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17001),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(475),
    [sym_block_comment] = STATE(475),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [476] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16700),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(476),
    [sym_block_comment] = STATE(476),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [477] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17008),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(477),
    [sym_block_comment] = STATE(477),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [478] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16945),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(478),
    [sym_block_comment] = STATE(478),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [479] = {
    [sym_enum_definition] = STATE(14655),
    [sym__enum_block] = STATE(16235),
    [sym_enum_case_definitions] = STATE(14655),
    [sym_import_declaration] = STATE(14655),
    [sym_export_declaration] = STATE(14655),
    [sym_object_definition] = STATE(14655),
    [sym_class_definition] = STATE(14655),
    [sym_trait_definition] = STATE(14655),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14655),
    [sym_val_declaration] = STATE(14655),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14655),
    [sym_var_definition] = STATE(14655),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14655),
    [sym_function_definition] = STATE(14655),
    [sym_function_declaration] = STATE(14655),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14655),
    [sym_given_definition] = STATE(14655),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13934),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(479),
    [sym_block_comment] = STATE(479),
    [aux_sym_enum_definition_repeat1] = STATE(4265),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(655),
    [anon_sym_case] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [480] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17169),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(480),
    [sym_block_comment] = STATE(480),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [481] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17094),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(481),
    [sym_block_comment] = STATE(481),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [482] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17287),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(482),
    [sym_block_comment] = STATE(482),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [483] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17377),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(483),
    [sym_block_comment] = STATE(483),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [484] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17316),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(484),
    [sym_block_comment] = STATE(484),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [485] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17508),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(485),
    [sym_block_comment] = STATE(485),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [486] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17318),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(486),
    [sym_block_comment] = STATE(486),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [487] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17642),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(487),
    [sym_block_comment] = STATE(487),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [488] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17859),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(488),
    [sym_block_comment] = STATE(488),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [489] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17397),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(489),
    [sym_block_comment] = STATE(489),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [490] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16219),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(490),
    [sym_block_comment] = STATE(490),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [491] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16270),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(491),
    [sym_block_comment] = STATE(491),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [492] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17154),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(492),
    [sym_block_comment] = STATE(492),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [493] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16368),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(493),
    [sym_block_comment] = STATE(493),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [494] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16602),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(494),
    [sym_block_comment] = STATE(494),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [495] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16455),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(495),
    [sym_block_comment] = STATE(495),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [496] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16561),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(496),
    [sym_block_comment] = STATE(496),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [497] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16857),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(497),
    [sym_block_comment] = STATE(497),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [498] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16631),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(498),
    [sym_block_comment] = STATE(498),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [499] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16715),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(499),
    [sym_block_comment] = STATE(499),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [500] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16306),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(500),
    [sym_block_comment] = STATE(500),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [501] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16780),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(501),
    [sym_block_comment] = STATE(501),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [502] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16568),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(502),
    [sym_block_comment] = STATE(502),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [503] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16852),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(503),
    [sym_block_comment] = STATE(503),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [504] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16907),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(504),
    [sym_block_comment] = STATE(504),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [505] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16947),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(505),
    [sym_block_comment] = STATE(505),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [506] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16953),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(506),
    [sym_block_comment] = STATE(506),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [507] = {
    [sym_enum_definition] = STATE(14630),
    [sym_import_declaration] = STATE(14630),
    [sym_export_declaration] = STATE(14630),
    [sym_object_definition] = STATE(14630),
    [sym_class_definition] = STATE(14630),
    [sym_trait_definition] = STATE(14630),
    [sym__end_marker] = STATE(14630),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14630),
    [sym_val_declaration] = STATE(14630),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14630),
    [sym_var_definition] = STATE(14630),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14630),
    [sym_function_definition] = STATE(14630),
    [sym_function_declaration] = STATE(14630),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14630),
    [sym_given_definition] = STATE(14630),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(17054),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14004),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(507),
    [sym_block_comment] = STATE(507),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [508] = {
    [sym_enum_definition] = STATE(14677),
    [sym_import_declaration] = STATE(14677),
    [sym_export_declaration] = STATE(14677),
    [sym_object_definition] = STATE(14677),
    [sym_class_definition] = STATE(14677),
    [sym_trait_definition] = STATE(14677),
    [sym__end_marker] = STATE(14677),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14677),
    [sym_val_declaration] = STATE(14677),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14677),
    [sym_var_definition] = STATE(14677),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14677),
    [sym_function_definition] = STATE(14677),
    [sym_function_declaration] = STATE(14677),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14677),
    [sym_given_definition] = STATE(14677),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym__block] = STATE(16224),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13970),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(508),
    [sym_block_comment] = STATE(508),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [509] = {
    [sym_enum_definition] = STATE(14478),
    [sym_import_declaration] = STATE(14478),
    [sym_export_declaration] = STATE(14478),
    [sym_object_definition] = STATE(14478),
    [sym_class_definition] = STATE(14478),
    [sym_trait_definition] = STATE(14478),
    [sym__end_marker] = STATE(14478),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14478),
    [sym_val_declaration] = STATE(14478),
    [sym__start_val] = STATE(4089),
    [sym_var_declaration] = STATE(14478),
    [sym_var_definition] = STATE(14478),
    [sym__start_var] = STATE(4110),
    [sym_type_definition] = STATE(14478),
    [sym_function_definition] = STATE(14478),
    [sym_function_declaration] = STATE(14478),
    [sym__function_declaration] = STATE(13993),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14478),
    [sym_given_definition] = STATE(14478),
    [sym_modifiers] = STATE(12965),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(526),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13971),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(509),
    [sym_block_comment] = STATE(509),
    [aux_sym_enum_definition_repeat1] = STATE(4262),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(611),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(623),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(625),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(649),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [510] = {
    [sym_enum_definition] = STATE(14451),
    [sym__enum_block] = STATE(16498),
    [sym_enum_case_definitions] = STATE(14451),
    [sym_import_declaration] = STATE(14451),
    [sym_export_declaration] = STATE(14451),
    [sym_object_definition] = STATE(14451),
    [sym_class_definition] = STATE(14451),
    [sym_trait_definition] = STATE(14451),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14451),
    [sym_val_declaration] = STATE(14451),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14451),
    [sym_var_definition] = STATE(14451),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14451),
    [sym_function_definition] = STATE(14451),
    [sym_function_declaration] = STATE(14451),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14451),
    [sym_given_definition] = STATE(14451),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13952),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(510),
    [sym_block_comment] = STATE(510),
    [aux_sym_enum_definition_repeat1] = STATE(4266),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(657),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [511] = {
    [sym_enum_definition] = STATE(14517),
    [sym_import_declaration] = STATE(14517),
    [sym_export_declaration] = STATE(14517),
    [sym_object_definition] = STATE(14517),
    [sym_class_definition] = STATE(14517),
    [sym_trait_definition] = STATE(14517),
    [sym__end_marker] = STATE(14517),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14517),
    [sym_val_declaration] = STATE(14517),
    [sym__start_val] = STATE(4111),
    [sym_var_declaration] = STATE(14517),
    [sym_var_definition] = STATE(14517),
    [sym__start_var] = STATE(4080),
    [sym_type_definition] = STATE(14517),
    [sym_function_definition] = STATE(14517),
    [sym_function_declaration] = STATE(14517),
    [sym__function_declaration] = STATE(13937),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14517),
    [sym_given_definition] = STATE(14517),
    [sym_modifiers] = STATE(12967),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(525),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13985),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(511),
    [sym_block_comment] = STATE(511),
    [aux_sym_enum_definition_repeat1] = STATE(4261),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(585),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(597),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(599),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(639),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [512] = {
    [sym_enum_definition] = STATE(14478),
    [sym_import_declaration] = STATE(14478),
    [sym_export_declaration] = STATE(14478),
    [sym_object_definition] = STATE(14478),
    [sym_class_definition] = STATE(14478),
    [sym_trait_definition] = STATE(14478),
    [sym__end_marker] = STATE(14478),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14478),
    [sym_val_declaration] = STATE(14478),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14478),
    [sym_var_definition] = STATE(14478),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14478),
    [sym_function_definition] = STATE(14478),
    [sym_function_declaration] = STATE(14478),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14478),
    [sym_given_definition] = STATE(14478),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13971),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(512),
    [sym_block_comment] = STATE(512),
    [aux_sym_enum_definition_repeat1] = STATE(4256),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(557),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(649),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [513] = {
    [sym_enum_definition] = STATE(14451),
    [sym__enum_block] = STATE(16434),
    [sym_enum_case_definitions] = STATE(14451),
    [sym_import_declaration] = STATE(14451),
    [sym_export_declaration] = STATE(14451),
    [sym_object_definition] = STATE(14451),
    [sym_class_definition] = STATE(14451),
    [sym_trait_definition] = STATE(14451),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14451),
    [sym_val_declaration] = STATE(14451),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(14451),
    [sym_var_definition] = STATE(14451),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(14451),
    [sym_function_definition] = STATE(14451),
    [sym_function_declaration] = STATE(14451),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(14451),
    [sym_given_definition] = STATE(14451),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13952),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(513),
    [sym_block_comment] = STATE(513),
    [aux_sym_enum_definition_repeat1] = STATE(4266),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(657),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [514] = {
    [sym_enum_definition] = STATE(15329),
    [sym_enum_case_definitions] = STATE(15329),
    [sym_import_declaration] = STATE(15329),
    [sym_export_declaration] = STATE(15329),
    [sym_object_definition] = STATE(15329),
    [sym_class_definition] = STATE(15329),
    [sym_trait_definition] = STATE(15329),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(15329),
    [sym_val_declaration] = STATE(15329),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(15329),
    [sym_var_definition] = STATE(15329),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(15329),
    [sym_function_definition] = STATE(15329),
    [sym_function_declaration] = STATE(15329),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(15329),
    [sym_given_definition] = STATE(15329),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14041),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(514),
    [sym_block_comment] = STATE(514),
    [aux_sym_enum_definition_repeat1] = STATE(4266),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(657),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__outdent] = ACTIONS(661),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [515] = {
    [sym_enum_definition] = STATE(15277),
    [sym_enum_case_definitions] = STATE(15277),
    [sym_import_declaration] = STATE(15277),
    [sym_export_declaration] = STATE(15277),
    [sym_object_definition] = STATE(15277),
    [sym_class_definition] = STATE(15277),
    [sym_trait_definition] = STATE(15277),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(15277),
    [sym_val_declaration] = STATE(15277),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(15277),
    [sym_var_definition] = STATE(15277),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(15277),
    [sym_function_definition] = STATE(15277),
    [sym_function_declaration] = STATE(15277),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(15277),
    [sym_given_definition] = STATE(15277),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(14146),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(515),
    [sym_block_comment] = STATE(515),
    [aux_sym_enum_definition_repeat1] = STATE(4265),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(661),
    [anon_sym_case] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [516] = {
    [sym_enum_definition] = STATE(15277),
    [sym_enum_case_definitions] = STATE(15277),
    [sym_import_declaration] = STATE(15277),
    [sym_export_declaration] = STATE(15277),
    [sym_object_definition] = STATE(15277),
    [sym_class_definition] = STATE(15277),
    [sym_trait_definition] = STATE(15277),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(15277),
    [sym_val_declaration] = STATE(15277),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(15277),
    [sym_var_definition] = STATE(15277),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(15277),
    [sym_function_definition] = STATE(15277),
    [sym_function_declaration] = STATE(15277),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(15277),
    [sym_given_definition] = STATE(15277),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(14146),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(516),
    [sym_block_comment] = STATE(516),
    [aux_sym_enum_definition_repeat1] = STATE(4265),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(663),
    [anon_sym_case] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [517] = {
    [sym_enum_definition] = STATE(15329),
    [sym_enum_case_definitions] = STATE(15329),
    [sym_import_declaration] = STATE(15329),
    [sym_export_declaration] = STATE(15329),
    [sym_object_definition] = STATE(15329),
    [sym_class_definition] = STATE(15329),
    [sym_trait_definition] = STATE(15329),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(15329),
    [sym_val_declaration] = STATE(15329),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(15329),
    [sym_var_definition] = STATE(15329),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(15329),
    [sym_function_definition] = STATE(15329),
    [sym_function_declaration] = STATE(15329),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(15329),
    [sym_given_definition] = STATE(15329),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14041),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(517),
    [sym_block_comment] = STATE(517),
    [aux_sym_enum_definition_repeat1] = STATE(4266),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(657),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__outdent] = ACTIONS(663),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [518] = {
    [sym_enum_definition] = STATE(14517),
    [sym_import_declaration] = STATE(14517),
    [sym_export_declaration] = STATE(14517),
    [sym_object_definition] = STATE(14517),
    [sym_class_definition] = STATE(14517),
    [sym_trait_definition] = STATE(14517),
    [sym__end_marker] = STATE(14517),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(14517),
    [sym_val_declaration] = STATE(14517),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(14517),
    [sym_var_definition] = STATE(14517),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(14517),
    [sym_function_definition] = STATE(14517),
    [sym_function_declaration] = STATE(14517),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(14517),
    [sym_given_definition] = STATE(14517),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(13985),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(518),
    [sym_block_comment] = STATE(518),
    [aux_sym_enum_definition_repeat1] = STATE(4275),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(639),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [519] = {
    [sym_enum_definition] = STATE(15329),
    [sym_enum_case_definitions] = STATE(15329),
    [sym_import_declaration] = STATE(15329),
    [sym_export_declaration] = STATE(15329),
    [sym_object_definition] = STATE(15329),
    [sym_class_definition] = STATE(15329),
    [sym_trait_definition] = STATE(15329),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(15329),
    [sym_val_declaration] = STATE(15329),
    [sym__start_val] = STATE(4130),
    [sym_var_declaration] = STATE(15329),
    [sym_var_definition] = STATE(15329),
    [sym__start_var] = STATE(4079),
    [sym_type_definition] = STATE(15329),
    [sym_function_definition] = STATE(15329),
    [sym_function_declaration] = STATE(15329),
    [sym__function_declaration] = STATE(14121),
    [sym_opaque_modifier] = STATE(17834),
    [sym_extension_definition] = STATE(15329),
    [sym_given_definition] = STATE(15329),
    [sym_modifiers] = STATE(12764),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(528),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(14041),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(519),
    [sym_block_comment] = STATE(519),
    [aux_sym_enum_definition_repeat1] = STATE(4266),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_enum] = ACTIONS(475),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(657),
    [anon_sym_object] = ACTIONS(481),
    [anon_sym_import] = ACTIONS(483),
    [anon_sym_export] = ACTIONS(485),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_given] = ACTIONS(489),
    [anon_sym_class] = ACTIONS(491),
    [anon_sym_trait] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_extension] = ACTIONS(509),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(511),
    [anon_sym_def] = ACTIONS(513),
    [anon_sym_opaque] = ACTIONS(515),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(517),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(521),
    [anon_sym_open] = ACTIONS(523),
    [anon_sym_transparent] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [520] = {
    [sym_enum_definition] = STATE(15277),
    [sym_enum_case_definitions] = STATE(15277),
    [sym_import_declaration] = STATE(15277),
    [sym_export_declaration] = STATE(15277),
    [sym_object_definition] = STATE(15277),
    [sym_class_definition] = STATE(15277),
    [sym_trait_definition] = STATE(15277),
    [sym_annotation] = STATE(7896),
    [sym_val_definition] = STATE(15277),
    [sym_val_declaration] = STATE(15277),
    [sym__start_val] = STATE(4103),
    [sym_var_declaration] = STATE(15277),
    [sym_var_definition] = STATE(15277),
    [sym__start_var] = STATE(4105),
    [sym_type_definition] = STATE(15277),
    [sym_function_definition] = STATE(15277),
    [sym_function_declaration] = STATE(15277),
    [sym__function_declaration] = STATE(14148),
    [sym_opaque_modifier] = STATE(17497),
    [sym_extension_definition] = STATE(15277),
    [sym_given_definition] = STATE(15277),
    [sym_modifiers] = STATE(12976),
    [sym_access_modifier] = STATE(6358),
    [sym_inline_modifier] = STATE(527),
    [sym_infix_modifier] = STATE(6358),
    [sym_open_modifier] = STATE(6358),
    [sym_transparent_modifier] = STATE(6358),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(14146),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(520),
    [sym_block_comment] = STATE(520),
    [aux_sym_enum_definition_repeat1] = STATE(4265),
    [aux_sym_modifiers_repeat1] = STATE(5305),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(643),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [521] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(13925),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(521),
    [sym_block_comment] = STATE(521),
    [sym__alpha_identifier] = ACTIONS(665),
    [anon_sym_enum] = ACTIONS(668),
    [anon_sym_LBRACE] = ACTIONS(670),
    [anon_sym_case] = ACTIONS(668),
    [anon_sym_object] = ACTIONS(668),
    [anon_sym_import] = ACTIONS(668),
    [anon_sym_export] = ACTIONS(668),
    [anon_sym__] = ACTIONS(673),
    [anon_sym_given] = ACTIONS(668),
    [anon_sym_class] = ACTIONS(668),
    [anon_sym_trait] = ACTIONS(668),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_end] = ACTIONS(679),
    [anon_sym_if] = ACTIONS(682),
    [anon_sym_while] = ACTIONS(685),
    [anon_sym_for] = ACTIONS(688),
    [anon_sym_try] = ACTIONS(691),
    [anon_sym_new] = ACTIONS(694),
    [anon_sym_extension] = ACTIONS(668),
    [anon_sym_val] = ACTIONS(668),
    [anon_sym_AT] = ACTIONS(668),
    [anon_sym_var] = ACTIONS(668),
    [anon_sym_type] = ACTIONS(668),
    [anon_sym_def] = ACTIONS(668),
    [anon_sym_opaque] = ACTIONS(679),
    [anon_sym_abstract] = ACTIONS(668),
    [anon_sym_final] = ACTIONS(668),
    [anon_sym_sealed] = ACTIONS(668),
    [anon_sym_implicit] = ACTIONS(697),
    [anon_sym_lazy] = ACTIONS(668),
    [anon_sym_override] = ACTIONS(668),
    [anon_sym_private] = ACTIONS(668),
    [anon_sym_protected] = ACTIONS(668),
    [anon_sym_inline] = ACTIONS(700),
    [anon_sym_infix] = ACTIONS(679),
    [anon_sym_open] = ACTIONS(679),
    [anon_sym_transparent] = ACTIONS(679),
    [anon_sym_LPAREN] = ACTIONS(703),
    [anon_sym_SEMI] = ACTIONS(706),
    [anon_sym_macro] = ACTIONS(708),
    [anon_sym_BANG] = ACTIONS(676),
    [anon_sym_TILDE] = ACTIONS(676),
    [anon_sym_DOLLAR] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(714),
    [sym__backquoted_id] = ACTIONS(717),
    [sym_operator_identifier] = ACTIONS(720),
    [sym_integer_literal] = ACTIONS(723),
    [sym_floating_point_literal] = ACTIONS(726),
    [anon_sym_true] = ACTIONS(729),
    [anon_sym_false] = ACTIONS(729),
    [sym_character_literal] = ACTIONS(726),
    [sym_null_literal] = ACTIONS(732),
    [anon_sym_return] = ACTIONS(735),
    [anon_sym_throw] = ACTIONS(738),
    [anon_sym_do] = ACTIONS(741),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__outdent] = ACTIONS(706),
    [sym__simple_multiline_string] = ACTIONS(746),
    [sym__simple_string] = ACTIONS(746),
  },
  [522] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(12986),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(522),
    [sym_block_comment] = STATE(522),
    [sym__alpha_identifier] = ACTIONS(749),
    [anon_sym_enum] = ACTIONS(668),
    [anon_sym_LBRACE] = ACTIONS(752),
    [anon_sym_case] = ACTIONS(668),
    [anon_sym_object] = ACTIONS(668),
    [anon_sym_import] = ACTIONS(668),
    [anon_sym_export] = ACTIONS(668),
    [anon_sym__] = ACTIONS(755),
    [anon_sym_given] = ACTIONS(668),
    [anon_sym_class] = ACTIONS(668),
    [anon_sym_trait] = ACTIONS(668),
    [anon_sym_PLUS] = ACTIONS(758),
    [anon_sym_DASH] = ACTIONS(758),
    [anon_sym_end] = ACTIONS(761),
    [anon_sym_if] = ACTIONS(764),
    [anon_sym_while] = ACTIONS(767),
    [anon_sym_for] = ACTIONS(770),
    [anon_sym_try] = ACTIONS(773),
    [anon_sym_new] = ACTIONS(776),
    [anon_sym_extension] = ACTIONS(668),
    [anon_sym_val] = ACTIONS(668),
    [anon_sym_AT] = ACTIONS(668),
    [anon_sym_var] = ACTIONS(668),
    [anon_sym_type] = ACTIONS(668),
    [anon_sym_def] = ACTIONS(668),
    [anon_sym_opaque] = ACTIONS(761),
    [anon_sym_abstract] = ACTIONS(668),
    [anon_sym_final] = ACTIONS(668),
    [anon_sym_sealed] = ACTIONS(668),
    [anon_sym_implicit] = ACTIONS(779),
    [anon_sym_lazy] = ACTIONS(668),
    [anon_sym_override] = ACTIONS(668),
    [anon_sym_private] = ACTIONS(668),
    [anon_sym_protected] = ACTIONS(668),
    [anon_sym_inline] = ACTIONS(782),
    [anon_sym_infix] = ACTIONS(761),
    [anon_sym_open] = ACTIONS(761),
    [anon_sym_transparent] = ACTIONS(761),
    [anon_sym_LPAREN] = ACTIONS(785),
    [anon_sym_SEMI] = ACTIONS(706),
    [anon_sym_macro] = ACTIONS(788),
    [anon_sym_BANG] = ACTIONS(758),
    [anon_sym_TILDE] = ACTIONS(758),
    [anon_sym_DOLLAR] = ACTIONS(791),
    [anon_sym_SQUOTE] = ACTIONS(794),
    [sym__backquoted_id] = ACTIONS(797),
    [sym_operator_identifier] = ACTIONS(800),
    [sym_integer_literal] = ACTIONS(803),
    [sym_floating_point_literal] = ACTIONS(806),
    [anon_sym_true] = ACTIONS(809),
    [anon_sym_false] = ACTIONS(809),
    [sym_character_literal] = ACTIONS(806),
    [sym_null_literal] = ACTIONS(812),
    [anon_sym_return] = ACTIONS(815),
    [anon_sym_throw] = ACTIONS(818),
    [anon_sym_do] = ACTIONS(821),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(824),
    [sym__simple_multiline_string] = ACTIONS(827),
    [sym__simple_string] = ACTIONS(827),
  },
  [523] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(13925),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(523),
    [sym_block_comment] = STATE(523),
    [sym__alpha_identifier] = ACTIONS(665),
    [anon_sym_enum] = ACTIONS(668),
    [anon_sym_LBRACE] = ACTIONS(670),
    [anon_sym_case] = ACTIONS(668),
    [anon_sym_object] = ACTIONS(668),
    [anon_sym_import] = ACTIONS(668),
    [anon_sym_export] = ACTIONS(668),
    [anon_sym__] = ACTIONS(673),
    [anon_sym_given] = ACTIONS(668),
    [anon_sym_class] = ACTIONS(668),
    [anon_sym_trait] = ACTIONS(668),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_end] = ACTIONS(679),
    [anon_sym_if] = ACTIONS(682),
    [anon_sym_while] = ACTIONS(685),
    [anon_sym_for] = ACTIONS(688),
    [anon_sym_try] = ACTIONS(691),
    [anon_sym_new] = ACTIONS(694),
    [anon_sym_extension] = ACTIONS(668),
    [anon_sym_val] = ACTIONS(668),
    [anon_sym_AT] = ACTIONS(668),
    [anon_sym_var] = ACTIONS(668),
    [anon_sym_type] = ACTIONS(668),
    [anon_sym_def] = ACTIONS(668),
    [anon_sym_opaque] = ACTIONS(679),
    [anon_sym_abstract] = ACTIONS(668),
    [anon_sym_final] = ACTIONS(668),
    [anon_sym_sealed] = ACTIONS(668),
    [anon_sym_implicit] = ACTIONS(697),
    [anon_sym_lazy] = ACTIONS(668),
    [anon_sym_override] = ACTIONS(668),
    [anon_sym_private] = ACTIONS(668),
    [anon_sym_protected] = ACTIONS(668),
    [anon_sym_inline] = ACTIONS(700),
    [anon_sym_infix] = ACTIONS(679),
    [anon_sym_open] = ACTIONS(679),
    [anon_sym_transparent] = ACTIONS(679),
    [anon_sym_LPAREN] = ACTIONS(703),
    [anon_sym_SEMI] = ACTIONS(706),
    [anon_sym_macro] = ACTIONS(708),
    [anon_sym_BANG] = ACTIONS(676),
    [anon_sym_TILDE] = ACTIONS(676),
    [anon_sym_DOLLAR] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(714),
    [sym__backquoted_id] = ACTIONS(717),
    [sym_operator_identifier] = ACTIONS(720),
    [sym_integer_literal] = ACTIONS(723),
    [sym_floating_point_literal] = ACTIONS(726),
    [anon_sym_true] = ACTIONS(729),
    [anon_sym_false] = ACTIONS(729),
    [sym_character_literal] = ACTIONS(726),
    [sym_null_literal] = ACTIONS(732),
    [anon_sym_return] = ACTIONS(735),
    [anon_sym_throw] = ACTIONS(738),
    [anon_sym_do] = ACTIONS(741),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(746),
    [sym__simple_string] = ACTIONS(746),
  },
  [524] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15426),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(524),
    [sym_block_comment] = STATE(524),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym_case] = ACTIONS(834),
    [anon_sym_object] = ACTIONS(834),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_given] = ACTIONS(834),
    [anon_sym_class] = ACTIONS(834),
    [anon_sym_trait] = ACTIONS(834),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(842),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_val] = ACTIONS(834),
    [anon_sym_var] = ACTIONS(834),
    [anon_sym_type] = ACTIONS(834),
    [anon_sym_def] = ACTIONS(834),
    [anon_sym_opaque] = ACTIONS(834),
    [anon_sym_abstract] = ACTIONS(834),
    [anon_sym_final] = ACTIONS(834),
    [anon_sym_sealed] = ACTIONS(834),
    [anon_sym_implicit] = ACTIONS(834),
    [anon_sym_lazy] = ACTIONS(834),
    [anon_sym_override] = ACTIONS(834),
    [anon_sym_private] = ACTIONS(834),
    [anon_sym_protected] = ACTIONS(834),
    [anon_sym_inline] = ACTIONS(834),
    [anon_sym_infix] = ACTIONS(834),
    [anon_sym_open] = ACTIONS(834),
    [anon_sym_transparent] = ACTIONS(834),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [525] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15426),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(525),
    [sym_block_comment] = STATE(525),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym_case] = ACTIONS(834),
    [anon_sym_object] = ACTIONS(834),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_given] = ACTIONS(834),
    [anon_sym_class] = ACTIONS(834),
    [anon_sym_trait] = ACTIONS(834),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(880),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_val] = ACTIONS(834),
    [anon_sym_var] = ACTIONS(834),
    [anon_sym_type] = ACTIONS(834),
    [anon_sym_def] = ACTIONS(834),
    [anon_sym_opaque] = ACTIONS(834),
    [anon_sym_abstract] = ACTIONS(834),
    [anon_sym_final] = ACTIONS(834),
    [anon_sym_sealed] = ACTIONS(834),
    [anon_sym_implicit] = ACTIONS(834),
    [anon_sym_lazy] = ACTIONS(834),
    [anon_sym_override] = ACTIONS(834),
    [anon_sym_private] = ACTIONS(834),
    [anon_sym_protected] = ACTIONS(834),
    [anon_sym_inline] = ACTIONS(834),
    [anon_sym_infix] = ACTIONS(834),
    [anon_sym_open] = ACTIONS(834),
    [anon_sym_transparent] = ACTIONS(834),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [526] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15098),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(526),
    [sym_block_comment] = STATE(526),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym_case] = ACTIONS(834),
    [anon_sym_object] = ACTIONS(834),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_given] = ACTIONS(834),
    [anon_sym_class] = ACTIONS(834),
    [anon_sym_trait] = ACTIONS(834),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(882),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_val] = ACTIONS(834),
    [anon_sym_var] = ACTIONS(834),
    [anon_sym_type] = ACTIONS(834),
    [anon_sym_def] = ACTIONS(834),
    [anon_sym_opaque] = ACTIONS(834),
    [anon_sym_abstract] = ACTIONS(834),
    [anon_sym_final] = ACTIONS(834),
    [anon_sym_sealed] = ACTIONS(834),
    [anon_sym_implicit] = ACTIONS(834),
    [anon_sym_lazy] = ACTIONS(834),
    [anon_sym_override] = ACTIONS(834),
    [anon_sym_private] = ACTIONS(834),
    [anon_sym_protected] = ACTIONS(834),
    [anon_sym_inline] = ACTIONS(834),
    [anon_sym_infix] = ACTIONS(834),
    [anon_sym_open] = ACTIONS(834),
    [anon_sym_transparent] = ACTIONS(834),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [527] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15426),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(527),
    [sym_block_comment] = STATE(527),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym_case] = ACTIONS(834),
    [anon_sym_object] = ACTIONS(834),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_given] = ACTIONS(834),
    [anon_sym_class] = ACTIONS(834),
    [anon_sym_trait] = ACTIONS(834),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(884),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_val] = ACTIONS(834),
    [anon_sym_var] = ACTIONS(834),
    [anon_sym_type] = ACTIONS(834),
    [anon_sym_def] = ACTIONS(834),
    [anon_sym_opaque] = ACTIONS(834),
    [anon_sym_abstract] = ACTIONS(834),
    [anon_sym_final] = ACTIONS(834),
    [anon_sym_sealed] = ACTIONS(834),
    [anon_sym_implicit] = ACTIONS(834),
    [anon_sym_lazy] = ACTIONS(834),
    [anon_sym_override] = ACTIONS(834),
    [anon_sym_private] = ACTIONS(834),
    [anon_sym_protected] = ACTIONS(834),
    [anon_sym_inline] = ACTIONS(834),
    [anon_sym_infix] = ACTIONS(834),
    [anon_sym_open] = ACTIONS(834),
    [anon_sym_transparent] = ACTIONS(834),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [528] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15098),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(528),
    [sym_block_comment] = STATE(528),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym_case] = ACTIONS(834),
    [anon_sym_object] = ACTIONS(834),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_given] = ACTIONS(834),
    [anon_sym_class] = ACTIONS(834),
    [anon_sym_trait] = ACTIONS(834),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(886),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_val] = ACTIONS(834),
    [anon_sym_var] = ACTIONS(834),
    [anon_sym_type] = ACTIONS(834),
    [anon_sym_def] = ACTIONS(834),
    [anon_sym_opaque] = ACTIONS(834),
    [anon_sym_abstract] = ACTIONS(834),
    [anon_sym_final] = ACTIONS(834),
    [anon_sym_sealed] = ACTIONS(834),
    [anon_sym_implicit] = ACTIONS(834),
    [anon_sym_lazy] = ACTIONS(834),
    [anon_sym_override] = ACTIONS(834),
    [anon_sym_private] = ACTIONS(834),
    [anon_sym_protected] = ACTIONS(834),
    [anon_sym_inline] = ACTIONS(834),
    [anon_sym_infix] = ACTIONS(834),
    [anon_sym_open] = ACTIONS(834),
    [anon_sym_transparent] = ACTIONS(834),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [529] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(15418),
    [sym__simple_expression] = STATE(4448),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16424),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(6001),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4267),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(4967),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(529),
    [sym_block_comment] = STATE(529),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_COLON] = ACTIONS(890),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym_RBRACE] = ACTIONS(894),
    [anon_sym_case] = ACTIONS(896),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_RPAREN] = ACTIONS(894),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_else] = ACTIONS(896),
    [anon_sym_catch] = ACTIONS(896),
    [anon_sym_finally] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(920),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_yield] = ACTIONS(896),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [530] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(15792),
    [sym__simple_expression] = STATE(4505),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17344),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(6744),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4348),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(5254),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(530),
    [sym_block_comment] = STATE(530),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_COLON] = ACTIONS(934),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym_RBRACE] = ACTIONS(894),
    [anon_sym_case] = ACTIONS(896),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_RPAREN] = ACTIONS(894),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_catch] = ACTIONS(896),
    [anon_sym_finally] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(956),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_yield] = ACTIONS(896),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [531] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(14981),
    [sym__simple_expression] = STATE(4522),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16688),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(7058),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4278),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(5051),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(531),
    [sym_block_comment] = STATE(531),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_COLON] = ACTIONS(970),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym_RBRACE] = ACTIONS(894),
    [anon_sym_case] = ACTIONS(896),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_RPAREN] = ACTIONS(894),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_else] = ACTIONS(896),
    [anon_sym_finally] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(992),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_yield] = ACTIONS(896),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [532] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(15187),
    [sym__simple_expression] = STATE(4651),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16466),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(7392),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4462),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(5883),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(532),
    [sym_block_comment] = STATE(532),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_COLON] = ACTIONS(1006),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym_COMMA] = ACTIONS(894),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_RPAREN] = ACTIONS(894),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_else] = ACTIONS(896),
    [anon_sym_then] = ACTIONS(896),
    [anon_sym_catch] = ACTIONS(896),
    [anon_sym_finally] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1028),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [533] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(14979),
    [sym__simple_expression] = STATE(4586),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17870),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(7719),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4451),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(5753),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(533),
    [sym_block_comment] = STATE(533),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_COLON] = ACTIONS(1042),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym_RBRACE] = ACTIONS(894),
    [anon_sym_case] = ACTIONS(896),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_RPAREN] = ACTIONS(894),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_else] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1064),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_yield] = ACTIONS(896),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [534] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(14982),
    [sym__simple_expression] = STATE(4644),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16445),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(7984),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4460),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(5866),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(534),
    [sym_block_comment] = STATE(534),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_COLON] = ACTIONS(1078),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym_RBRACE] = ACTIONS(894),
    [anon_sym_case] = ACTIONS(896),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_RPAREN] = ACTIONS(894),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_finally] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1100),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_yield] = ACTIONS(896),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [535] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(7476),
    [sym_expression] = STATE(14741),
    [sym__simple_expression] = STATE(4888),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16629),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(8532),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4560),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(6622),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(535),
    [sym_block_comment] = STATE(535),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_COLON] = ACTIONS(1114),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym_case] = ACTIONS(896),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_else] = ACTIONS(896),
    [anon_sym_catch] = ACTIONS(896),
    [anon_sym_finally] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1136),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__outdent] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [536] = {
    [sym_inline_modifier] = STATE(2314),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(12507),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(536),
    [sym_block_comment] = STATE(536),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym_COMMA] = ACTIONS(1148),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_RPAREN] = ACTIONS(1148),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_then] = ACTIONS(1156),
    [anon_sym_catch] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [537] = {
    [sym_inline_modifier] = STATE(2343),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(11622),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(537),
    [sym_block_comment] = STATE(537),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym_RBRACE] = ACTIONS(1148),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1156),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_RPAREN] = ACTIONS(1148),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_catch] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [538] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8472),
    [sym_expression] = STATE(15442),
    [sym__simple_expression] = STATE(5266),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16339),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9137),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7141),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(538),
    [sym_block_comment] = STATE(538),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_COLON] = ACTIONS(1192),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym_case] = ACTIONS(896),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_catch] = ACTIONS(896),
    [anon_sym_finally] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1214),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__outdent] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [539] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9158),
    [sym_expression] = STATE(15583),
    [sym__simple_expression] = STATE(5648),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16362),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9616),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4954),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(7789),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(539),
    [sym_block_comment] = STATE(539),
    [ts_builtin_sym_end] = ACTIONS(894),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_COLON] = ACTIONS(1228),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_else] = ACTIONS(896),
    [anon_sym_catch] = ACTIONS(896),
    [anon_sym_finally] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1250),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [540] = {
    [sym_inline_modifier] = STATE(2312),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(11622),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(540),
    [sym_block_comment] = STATE(540),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym_RBRACE] = ACTIONS(1148),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_catch] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [541] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(15037),
    [sym__simple_expression] = STATE(4921),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16707),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(8317),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(4485),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(6070),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(541),
    [sym_block_comment] = STATE(541),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_COLON] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym_COMMA] = ACTIONS(894),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_RPAREN] = ACTIONS(894),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_else] = ACTIONS(896),
    [anon_sym_then] = ACTIONS(896),
    [anon_sym_finally] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1302),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [542] = {
    [sym_inline_modifier] = STATE(2325),
    [sym_block] = STATE(7476),
    [sym_expression] = STATE(12843),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(542),
    [sym_block_comment] = STATE(542),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_catch] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__outdent] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [543] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8399),
    [sym_expression] = STATE(15115),
    [sym__simple_expression] = STATE(5374),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16745),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9325),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4740),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(6693),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(543),
    [sym_block_comment] = STATE(543),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_COLON] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym_case] = ACTIONS(896),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_else] = ACTIONS(896),
    [anon_sym_finally] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1358),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__outdent] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [544] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(15235),
    [sym__simple_expression] = STATE(5251),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16237),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9091),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(4665),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(7050),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(544),
    [sym_block_comment] = STATE(544),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_COLON] = ACTIONS(1372),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym_COMMA] = ACTIONS(894),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_RPAREN] = ACTIONS(894),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_else] = ACTIONS(896),
    [anon_sym_then] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(1394),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [545] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9584),
    [sym_expression] = STATE(15603),
    [sym__simple_expression] = STATE(6515),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17205),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9975),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5217),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8120),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(545),
    [sym_block_comment] = STATE(545),
    [ts_builtin_sym_end] = ACTIONS(894),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_COLON] = ACTIONS(1408),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_catch] = ACTIONS(896),
    [anon_sym_finally] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(1430),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [546] = {
    [sym_inline_modifier] = STATE(2304),
    [sym_block] = STATE(9158),
    [sym_expression] = STATE(13503),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(546),
    [sym_block_comment] = STATE(546),
    [ts_builtin_sym_end] = ACTIONS(1148),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_catch] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [547] = {
    [sym_inline_modifier] = STATE(2284),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(11861),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(547),
    [sym_block_comment] = STATE(547),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym_RBRACE] = ACTIONS(1148),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_catch] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [548] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(15149),
    [sym__simple_expression] = STATE(5336),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17474),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(8864),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(4613),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(6807),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(548),
    [sym_block_comment] = STATE(548),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_COLON] = ACTIONS(1482),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym_COMMA] = ACTIONS(894),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_RPAREN] = ACTIONS(894),
    [anon_sym_then] = ACTIONS(896),
    [anon_sym_catch] = ACTIONS(896),
    [anon_sym_finally] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1504),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [549] = {
    [sym_inline_modifier] = STATE(2054),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(11892),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(549),
    [sym_block_comment] = STATE(549),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym_RBRACE] = ACTIONS(1148),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1156),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_RPAREN] = ACTIONS(1148),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [550] = {
    [sym_inline_modifier] = STATE(2337),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(11622),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(550),
    [sym_block_comment] = STATE(550),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1156),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_catch] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1156),
    [anon_sym_yield] = ACTIONS(1156),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [551] = {
    [sym_inline_modifier] = STATE(2300),
    [sym_block] = STATE(8472),
    [sym_expression] = STATE(13026),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(551),
    [sym_block_comment] = STATE(551),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_catch] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__outdent] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [552] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8838),
    [sym_expression] = STATE(15577),
    [sym__simple_expression] = STATE(5747),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16508),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9604),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(4998),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(7932),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(552),
    [sym_block_comment] = STATE(552),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_COLON] = ACTIONS(1570),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym_case] = ACTIONS(896),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_else] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1592),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__outdent] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [553] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(15287),
    [sym__simple_expression] = STATE(4844),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16765),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(8163),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(4482),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(6629),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(553),
    [sym_block_comment] = STATE(553),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_COLON] = ACTIONS(1604),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(894),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_RPAREN] = ACTIONS(894),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(1606),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_yield] = ACTIONS(896),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [554] = {
    [sym_inline_modifier] = STATE(2329),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(11861),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(554),
    [sym_block_comment] = STATE(554),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym_RBRACE] = ACTIONS(1148),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1156),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_RPAREN] = ACTIONS(1148),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_catch] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [555] = {
    [sym_inline_modifier] = STATE(2332),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(11892),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(555),
    [sym_block_comment] = STATE(555),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym_RBRACE] = ACTIONS(1148),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [556] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9357),
    [sym_expression] = STATE(14901),
    [sym__simple_expression] = STATE(6169),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16669),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10075),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5076),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8690),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(556),
    [sym_block_comment] = STATE(556),
    [ts_builtin_sym_end] = ACTIONS(894),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_COLON] = ACTIONS(1640),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_else] = ACTIONS(896),
    [anon_sym_finally] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1662),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [557] = {
    [sym_inline_modifier] = STATE(2333),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(12790),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(557),
    [sym_block_comment] = STATE(557),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym_COMMA] = ACTIONS(1148),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_RPAREN] = ACTIONS(1148),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_then] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [558] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8894),
    [sym_expression] = STATE(14814),
    [sym__simple_expression] = STATE(5772),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16649),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9337),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8069),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(558),
    [sym_block_comment] = STATE(558),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_COLON] = ACTIONS(1696),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym_case] = ACTIONS(896),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_finally] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__outdent] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [559] = {
    [sym_inline_modifier] = STATE(2340),
    [sym_block] = STATE(8399),
    [sym_expression] = STATE(13193),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(559),
    [sym_block_comment] = STATE(559),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__outdent] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [560] = {
    [sym_inline_modifier] = STATE(2341),
    [sym_block] = STATE(7476),
    [sym_expression] = STATE(12843),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(560),
    [sym_block_comment] = STATE(560),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1156),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_catch] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__outdent] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [561] = {
    [sym_inline_modifier] = STATE(2313),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(12501),
    [sym__simple_expression] = STATE(6055),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15856),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9737),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5346),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8338),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(561),
    [sym_block_comment] = STATE(561),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym_RBRACE] = ACTIONS(1148),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1764),
    [anon_sym_while] = ACTIONS(1766),
    [anon_sym_for] = ACTIONS(1768),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1770),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(1772),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1776),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(1778),
    [anon_sym_throw] = ACTIONS(1780),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [562] = {
    [sym_inline_modifier] = STATE(2288),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(13170),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(562),
    [sym_block_comment] = STATE(562),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym_COMMA] = ACTIONS(1148),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_RPAREN] = ACTIONS(1148),
    [anon_sym_then] = ACTIONS(1156),
    [anon_sym_catch] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [563] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(15408),
    [sym__simple_expression] = STATE(5733),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16487),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9453),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(4992),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(7902),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(563),
    [sym_block_comment] = STATE(563),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_COLON] = ACTIONS(1806),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym_COMMA] = ACTIONS(894),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_RPAREN] = ACTIONS(894),
    [anon_sym_then] = ACTIONS(896),
    [anon_sym_finally] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(1828),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [564] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(15448),
    [sym__simple_expression] = STATE(6547),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17534),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9791),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5294),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8672),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(564),
    [sym_block_comment] = STATE(564),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_COLON] = ACTIONS(1840),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(896),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(1844),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__outdent] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [565] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9961),
    [sym_expression] = STATE(15845),
    [sym__simple_expression] = STATE(6816),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16382),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10214),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5853),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(9112),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(565),
    [sym_block_comment] = STATE(565),
    [ts_builtin_sym_end] = ACTIONS(894),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_COLON] = ACTIONS(1848),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_finally] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(1870),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [566] = {
    [sym_inline_modifier] = STATE(2345),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(11892),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(566),
    [sym_block_comment] = STATE(566),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1156),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1156),
    [anon_sym_yield] = ACTIONS(1156),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [567] = {
    [sym_inline_modifier] = STATE(2321),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(11861),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(567),
    [sym_block_comment] = STATE(567),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1156),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_catch] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1156),
    [anon_sym_yield] = ACTIONS(1156),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [568] = {
    [sym_inline_modifier] = STATE(2346),
    [sym_block] = STATE(8399),
    [sym_expression] = STATE(13193),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(568),
    [sym_block_comment] = STATE(568),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1156),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__outdent] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [569] = {
    [sym_inline_modifier] = STATE(2326),
    [sym_block] = STATE(8894),
    [sym_expression] = STATE(13468),
    [sym__simple_expression] = STATE(6190),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15978),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9770),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5440),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8474),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(569),
    [sym_block_comment] = STATE(569),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(1924),
    [anon_sym_while] = ACTIONS(1926),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1930),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1936),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(1938),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__outdent] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [570] = {
    [sym_inline_modifier] = STATE(2296),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(12490),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(570),
    [sym_block_comment] = STATE(570),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym_RBRACE] = ACTIONS(1148),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [571] = {
    [sym_inline_modifier] = STATE(2327),
    [sym_block] = STATE(9357),
    [sym_expression] = STATE(13739),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(571),
    [sym_block_comment] = STATE(571),
    [ts_builtin_sym_end] = ACTIONS(1148),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [572] = {
    [sym_inline_modifier] = STATE(2316),
    [sym_block] = STATE(8838),
    [sym_expression] = STATE(13418),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(572),
    [sym_block_comment] = STATE(572),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__outdent] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [573] = {
    [sym_inline_modifier] = STATE(2328),
    [sym_block] = STATE(8472),
    [sym_expression] = STATE(13026),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(573),
    [sym_block_comment] = STATE(573),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1156),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_catch] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__outdent] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [574] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(10014),
    [sym_expression] = STATE(14964),
    [sym__simple_expression] = STATE(7343),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17659),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10424),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5701),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8721),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(574),
    [sym_block_comment] = STATE(574),
    [ts_builtin_sym_end] = ACTIONS(894),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_COLON] = ACTIONS(2018),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_else] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2040),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [575] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(15287),
    [sym__simple_expression] = STATE(4844),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16765),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(8163),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(4482),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(6629),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(575),
    [sym_block_comment] = STATE(575),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_COLON] = ACTIONS(1604),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(894),
    [anon_sym_case] = ACTIONS(896),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(1606),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [576] = {
    [sym_inline_modifier] = STATE(2298),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(13291),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(576),
    [sym_block_comment] = STATE(576),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym_COMMA] = ACTIONS(1148),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_RPAREN] = ACTIONS(1148),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_then] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(2066),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [577] = {
    [sym_inline_modifier] = STATE(2278),
    [sym_block] = STATE(9584),
    [sym_expression] = STATE(13791),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(577),
    [sym_block_comment] = STATE(577),
    [ts_builtin_sym_end] = ACTIONS(1148),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_catch] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [578] = {
    [sym_inline_modifier] = STATE(2336),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(12490),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(578),
    [sym_block_comment] = STATE(578),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym_RBRACE] = ACTIONS(1148),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1156),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_RPAREN] = ACTIONS(1148),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2100),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [579] = {
    [sym_inline_modifier] = STATE(2344),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(12501),
    [sym__simple_expression] = STATE(5582),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15990),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9422),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4761),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(7890),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(579),
    [sym_block_comment] = STATE(579),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym_RBRACE] = ACTIONS(1148),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1156),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2108),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2112),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_RPAREN] = ACTIONS(1148),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2114),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2116),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [580] = {
    [sym_inline_modifier] = STATE(2317),
    [sym__indentable_expression] = STATE(12796),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym__expr_case_clause] = STATE(12797),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(580),
    [sym_block_comment] = STATE(580),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym_case] = ACTIONS(2120),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [581] = {
    [sym_inline_modifier] = STATE(2294),
    [sym__indentable_expression] = STATE(13629),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym__expr_case_clause] = STATE(13454),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(581),
    [sym_block_comment] = STATE(581),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym_case] = ACTIONS(2140),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [582] = {
    [sym_inline_modifier] = STATE(2346),
    [sym__indentable_expression] = STATE(13564),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym__expr_case_clause] = STATE(13565),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(582),
    [sym_block_comment] = STATE(582),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym_case] = ACTIONS(2160),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [583] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(13612),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym__expr_case_clause] = STATE(13619),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(583),
    [sym_block_comment] = STATE(583),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym_case] = ACTIONS(2166),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [584] = {
    [sym_inline_modifier] = STATE(2290),
    [sym_block] = STATE(10014),
    [sym_expression] = STATE(13859),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(584),
    [sym_block_comment] = STATE(584),
    [ts_builtin_sym_end] = ACTIONS(1148),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2184),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [585] = {
    [sym_inline_modifier] = STATE(2313),
    [sym__indentable_expression] = STATE(12551),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(6055),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym__expr_case_clause] = STATE(12552),
    [sym_bindings] = STATE(15856),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9737),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5346),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8338),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(585),
    [sym_block_comment] = STATE(585),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym_case] = ACTIONS(2190),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1764),
    [anon_sym_while] = ACTIONS(1766),
    [anon_sym_for] = ACTIONS(1768),
    [anon_sym_try] = ACTIONS(1770),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(1772),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1776),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(1778),
    [anon_sym_throw] = ACTIONS(1780),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [586] = {
    [sym_inline_modifier] = STATE(2324),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13833),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(586),
    [sym_block_comment] = STATE(586),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__outdent] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [587] = {
    [sym_inline_modifier] = STATE(2318),
    [sym__indentable_expression] = STATE(13695),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8653),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym__expr_case_clause] = STATE(13696),
    [sym_bindings] = STATE(16129),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10722),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(7377),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9808),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(587),
    [sym_block_comment] = STATE(587),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym_case] = ACTIONS(2196),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2200),
    [anon_sym_for] = ACTIONS(2202),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2206),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2210),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [588] = {
    [sym_inline_modifier] = STATE(2322),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(12507),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(588),
    [sym_block_comment] = STATE(588),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(1156),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_catch] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [589] = {
    [sym_inline_modifier] = STATE(2321),
    [sym__indentable_expression] = STATE(12071),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym__expr_case_clause] = STATE(12072),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(589),
    [sym_block_comment] = STATE(589),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym_case] = ACTIONS(2234),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [590] = {
    [sym_inline_modifier] = STATE(2332),
    [sym__indentable_expression] = STATE(11821),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym__expr_case_clause] = STATE(11827),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(590),
    [sym_block_comment] = STATE(590),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym_case] = ACTIONS(2240),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [591] = {
    [sym_inline_modifier] = STATE(2329),
    [sym__indentable_expression] = STATE(12071),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym__expr_case_clause] = STATE(12072),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(591),
    [sym_block_comment] = STATE(591),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym_case] = ACTIONS(2244),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [592] = {
    [sym_inline_modifier] = STATE(2341),
    [sym__indentable_expression] = STATE(13139),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym__expr_case_clause] = STATE(13161),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(592),
    [sym_block_comment] = STATE(592),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym_case] = ACTIONS(2248),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [593] = {
    [sym_inline_modifier] = STATE(2278),
    [sym__indentable_expression] = STATE(12071),
    [sym_block] = STATE(9584),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(13653),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym__expr_case_clause] = STATE(12072),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(593),
    [sym_block_comment] = STATE(593),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym_case] = ACTIONS(2254),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [594] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12551),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5559),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym__expr_case_clause] = STATE(12552),
    [sym_bindings] = STATE(15942),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9343),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5006),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8062),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(594),
    [sym_block_comment] = STATE(594),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym_case] = ACTIONS(2256),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2258),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2262),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2266),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2268),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2270),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [595] = {
    [sym_inline_modifier] = STATE(2314),
    [sym__indentable_expression] = STATE(12796),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym__expr_case_clause] = STATE(12797),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(595),
    [sym_block_comment] = STATE(595),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym_case] = ACTIONS(2274),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [596] = {
    [sym_inline_modifier] = STATE(2309),
    [sym__indentable_expression] = STATE(12551),
    [sym_block] = STATE(9961),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(14007),
    [sym__simple_expression] = STATE(6847),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym__expr_case_clause] = STATE(12552),
    [sym_bindings] = STATE(15991),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(10631),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(10386),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5726),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(8783),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(596),
    [sym_block_comment] = STATE(596),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym_case] = ACTIONS(2276),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(2278),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2282),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(2286),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_macro] = ACTIONS(2288),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(2290),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2294),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [597] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(11559),
    [sym_block] = STATE(9158),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(13329),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym__expr_case_clause] = STATE(11560),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(597),
    [sym_block_comment] = STATE(597),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym_case] = ACTIONS(2296),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [598] = {
    [sym_inline_modifier] = STATE(2292),
    [sym__indentable_expression] = STATE(13629),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym__expr_case_clause] = STATE(13454),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(598),
    [sym_block_comment] = STATE(598),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym_case] = ACTIONS(2300),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [599] = {
    [sym_inline_modifier] = STATE(2325),
    [sym__indentable_expression] = STATE(13139),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym__expr_case_clause] = STATE(13161),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(599),
    [sym_block_comment] = STATE(599),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym_case] = ACTIONS(2318),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [600] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(15448),
    [sym__simple_expression] = STATE(6547),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17534),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9791),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5294),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8672),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(600),
    [sym_block_comment] = STATE(600),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_COLON] = ACTIONS(1840),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(1844),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__outdent] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [601] = {
    [sym_inline_modifier] = STATE(2323),
    [sym__indentable_expression] = STATE(13695),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8282),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym__expr_case_clause] = STATE(13696),
    [sym_bindings] = STATE(15898),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10750),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(6686),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9873),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(601),
    [sym_block_comment] = STATE(601),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2322),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2330),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2332),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2334),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [602] = {
    [sym_inline_modifier] = STATE(2342),
    [sym_block] = STATE(8894),
    [sym_expression] = STATE(13468),
    [sym__simple_expression] = STATE(6017),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15961),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9804),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5210),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(602),
    [sym_block_comment] = STATE(602),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(1156),
    [anon_sym_while] = ACTIONS(2338),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2342),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(2346),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2350),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__outdent] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [603] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(10212),
    [sym_expression] = STATE(15444),
    [sym__simple_expression] = STATE(7770),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16300),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10599),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6453),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9533),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(603),
    [sym_block_comment] = STATE(603),
    [ts_builtin_sym_end] = ACTIONS(894),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_COLON] = ACTIONS(2352),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(2356),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(894),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [604] = {
    [sym_inline_modifier] = STATE(2334),
    [sym__indentable_expression] = STATE(13082),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym__expr_case_clause] = STATE(13095),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(604),
    [sym_block_comment] = STATE(604),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym_case] = ACTIONS(2358),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [605] = {
    [sym_inline_modifier] = STATE(2342),
    [sym__indentable_expression] = STATE(13796),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6017),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym__expr_case_clause] = STATE(13797),
    [sym_bindings] = STATE(15961),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9804),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5210),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(605),
    [sym_block_comment] = STATE(605),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym_case] = ACTIONS(2378),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(2380),
    [anon_sym_while] = ACTIONS(2338),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2342),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(2346),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2350),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [606] = {
    [sym_inline_modifier] = STATE(2330),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(12490),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(606),
    [sym_block_comment] = STATE(606),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1156),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2392),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(1156),
    [anon_sym_yield] = ACTIONS(1156),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [607] = {
    [sym_inline_modifier] = STATE(2054),
    [sym__indentable_expression] = STATE(11821),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym__expr_case_clause] = STATE(11827),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(607),
    [sym_block_comment] = STATE(607),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym_case] = ACTIONS(2398),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [608] = {
    [sym_inline_modifier] = STATE(2284),
    [sym__indentable_expression] = STATE(12071),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym__expr_case_clause] = STATE(12072),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(608),
    [sym_block_comment] = STATE(608),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym_case] = ACTIONS(2402),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [609] = {
    [sym_inline_modifier] = STATE(2344),
    [sym__indentable_expression] = STATE(12551),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5582),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym__expr_case_clause] = STATE(12552),
    [sym_bindings] = STATE(15990),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9422),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4761),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(7890),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(609),
    [sym_block_comment] = STATE(609),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym_case] = ACTIONS(2404),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2108),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2112),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2114),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2116),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [610] = {
    [sym_inline_modifier] = STATE(2339),
    [sym__indentable_expression] = STATE(13082),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym__expr_case_clause] = STATE(13095),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(610),
    [sym_block_comment] = STATE(610),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym_case] = ACTIONS(2408),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [611] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15490),
    [sym__simple_expression] = STATE(6299),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10098),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(611),
    [sym_block_comment] = STATE(611),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_COLON] = ACTIONS(2426),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym_COMMA] = ACTIONS(894),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(894),
    [anon_sym_then] = ACTIONS(896),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [612] = {
    [sym_inline_modifier] = STATE(2333),
    [sym__indentable_expression] = STATE(13082),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym__expr_case_clause] = STATE(13095),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(612),
    [sym_block_comment] = STATE(612),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym_case] = ACTIONS(2430),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [613] = {
    [sym_inline_modifier] = STATE(2345),
    [sym__indentable_expression] = STATE(11821),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym__expr_case_clause] = STATE(11827),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(613),
    [sym_block_comment] = STATE(613),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym_case] = ACTIONS(2432),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [614] = {
    [sym_inline_modifier] = STATE(2311),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12774),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(614),
    [sym_block_comment] = STATE(614),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(1148),
    [anon_sym_case] = ACTIONS(1156),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [615] = {
    [sym_inline_modifier] = STATE(2309),
    [sym_block] = STATE(9961),
    [sym_expression] = STATE(13868),
    [sym__simple_expression] = STATE(6847),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15991),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(10631),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(10386),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5726),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(8783),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(615),
    [sym_block_comment] = STATE(615),
    [ts_builtin_sym_end] = ACTIONS(1148),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(2278),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2282),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(2286),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(2288),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(2290),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2294),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [616] = {
    [sym_inline_modifier] = STATE(2288),
    [sym__indentable_expression] = STATE(13629),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym__expr_case_clause] = STATE(13454),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(616),
    [sym_block_comment] = STATE(616),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym_case] = ACTIONS(2438),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [617] = {
    [sym_inline_modifier] = STATE(2315),
    [sym__indentable_expression] = STATE(13695),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(6983),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym__expr_case_clause] = STATE(13696),
    [sym_bindings] = STATE(15899),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10174),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(5823),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9043),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(617),
    [sym_block_comment] = STATE(617),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym_case] = ACTIONS(2440),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2446),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2450),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2452),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2456),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [618] = {
    [sym_inline_modifier] = STATE(2340),
    [sym__indentable_expression] = STATE(13564),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym__expr_case_clause] = STATE(13565),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(618),
    [sym_block_comment] = STATE(618),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym_case] = ACTIONS(2458),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [619] = {
    [sym_inline_modifier] = STATE(2335),
    [sym_block] = STATE(8838),
    [sym_expression] = STATE(13418),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(619),
    [sym_block_comment] = STATE(619),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1156),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(2468),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__outdent] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [620] = {
    [sym_inline_modifier] = STATE(2317),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(12507),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(620),
    [sym_block_comment] = STATE(620),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_catch] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1156),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [621] = {
    [sym_inline_modifier] = STATE(2327),
    [sym__indentable_expression] = STATE(11821),
    [sym_block] = STATE(9357),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(13735),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym__expr_case_clause] = STATE(11827),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(621),
    [sym_block_comment] = STATE(621),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym_case] = ACTIONS(2474),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [622] = {
    [sym_inline_modifier] = STATE(2338),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(12501),
    [sym__simple_expression] = STATE(5559),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15942),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9343),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5006),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8062),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(622),
    [sym_block_comment] = STATE(622),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1156),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2262),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2266),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2268),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2270),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(1156),
    [anon_sym_yield] = ACTIONS(1156),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [623] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13796),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6190),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym__expr_case_clause] = STATE(13797),
    [sym_bindings] = STATE(15978),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9770),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5440),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8474),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(623),
    [sym_block_comment] = STATE(623),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym_case] = ACTIONS(2476),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(1924),
    [anon_sym_while] = ACTIONS(1926),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1930),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1936),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(1938),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [624] = {
    [sym_inline_modifier] = STATE(2312),
    [sym__indentable_expression] = STATE(11559),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym__expr_case_clause] = STATE(11560),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(624),
    [sym_block_comment] = STATE(624),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym_case] = ACTIONS(2478),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [625] = {
    [sym_inline_modifier] = STATE(2315),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(13377),
    [sym__simple_expression] = STATE(6983),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15899),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10174),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(5823),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9043),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(625),
    [sym_block_comment] = STATE(625),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym_COMMA] = ACTIONS(1148),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2446),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2450),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_RPAREN] = ACTIONS(1148),
    [anon_sym_then] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2452),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2456),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [626] = {
    [sym_inline_modifier] = STATE(2300),
    [sym__indentable_expression] = STATE(13612),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym__expr_case_clause] = STATE(13619),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(626),
    [sym_block_comment] = STATE(626),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym_case] = ACTIONS(2480),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [627] = {
    [sym_inline_modifier] = STATE(2337),
    [sym__indentable_expression] = STATE(11559),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym__expr_case_clause] = STATE(11560),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(627),
    [sym_block_comment] = STATE(627),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym_case] = ACTIONS(2482),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [628] = {
    [sym_inline_modifier] = STATE(2320),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12774),
    [sym__simple_expression] = STATE(6186),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16018),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9989),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5240),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8124),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(628),
    [sym_block_comment] = STATE(628),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(1148),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(1156),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2488),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2492),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_RPAREN] = ACTIONS(1148),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2494),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2496),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [629] = {
    [sym_inline_modifier] = STATE(2322),
    [sym__indentable_expression] = STATE(12796),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym__expr_case_clause] = STATE(12797),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(629),
    [sym_block_comment] = STATE(629),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym_case] = ACTIONS(2500),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [630] = {
    [sym_inline_modifier] = STATE(2343),
    [sym__indentable_expression] = STATE(11559),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym__expr_case_clause] = STATE(11560),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(630),
    [sym_block_comment] = STATE(630),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym_case] = ACTIONS(2504),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [631] = {
    [sym_inline_modifier] = STATE(2290),
    [sym_block] = STATE(10014),
    [sym_expression] = STATE(13936),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(631),
    [sym_block_comment] = STATE(631),
    [sym__alpha_identifier] = ACTIONS(2508),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2513),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2518),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2518),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2521),
    [anon_sym_infix] = ACTIONS(2518),
    [anon_sym_open] = ACTIONS(2518),
    [anon_sym_transparent] = ACTIONS(2518),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2527),
    [sym_operator_identifier] = ACTIONS(2530),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(2533),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [632] = {
    [sym_inline_modifier] = STATE(2329),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(11863),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(632),
    [sym_block_comment] = STATE(632),
    [sym__alpha_identifier] = ACTIONS(2536),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2539),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(2542),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2542),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(2545),
    [anon_sym_infix] = ACTIONS(2542),
    [anon_sym_open] = ACTIONS(2542),
    [anon_sym_transparent] = ACTIONS(2542),
    [anon_sym_LPAREN] = ACTIONS(2548),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(2551),
    [sym_operator_identifier] = ACTIONS(2554),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(2557),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [633] = {
    [sym_inline_modifier] = STATE(2330),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(12492),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(633),
    [sym_block_comment] = STATE(633),
    [sym__alpha_identifier] = ACTIONS(2560),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2563),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(2566),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2566),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(2571),
    [anon_sym_infix] = ACTIONS(2566),
    [anon_sym_open] = ACTIONS(2566),
    [anon_sym_transparent] = ACTIONS(2566),
    [anon_sym_LPAREN] = ACTIONS(2574),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(2577),
    [sym_operator_identifier] = ACTIONS(2580),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(2533),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [634] = {
    [sym_inline_modifier] = STATE(2332),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(11894),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(634),
    [sym_block_comment] = STATE(634),
    [sym__alpha_identifier] = ACTIONS(2583),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2586),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2589),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(2592),
    [anon_sym_infix] = ACTIONS(2589),
    [anon_sym_open] = ACTIONS(2589),
    [anon_sym_transparent] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(2598),
    [sym_operator_identifier] = ACTIONS(2601),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(2604),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [635] = {
    [sym_inline_modifier] = STATE(2333),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(12818),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(635),
    [sym_block_comment] = STATE(635),
    [sym__alpha_identifier] = ACTIONS(2607),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2610),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(2613),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2613),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(2616),
    [anon_sym_infix] = ACTIONS(2613),
    [anon_sym_open] = ACTIONS(2613),
    [anon_sym_transparent] = ACTIONS(2613),
    [anon_sym_LPAREN] = ACTIONS(2619),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(2622),
    [sym_operator_identifier] = ACTIONS(2625),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(2628),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [636] = {
    [sym_inline_modifier] = STATE(2334),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(12790),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(636),
    [sym_block_comment] = STATE(636),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1156),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [637] = {
    [sym_inline_modifier] = STATE(2334),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(12818),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(637),
    [sym_block_comment] = STATE(637),
    [sym__alpha_identifier] = ACTIONS(2607),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2610),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(2613),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2613),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(2616),
    [anon_sym_infix] = ACTIONS(2613),
    [anon_sym_open] = ACTIONS(2613),
    [anon_sym_transparent] = ACTIONS(2613),
    [anon_sym_LPAREN] = ACTIONS(2619),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(2622),
    [sym_operator_identifier] = ACTIONS(2631),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(2628),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [638] = {
    [sym_inline_modifier] = STATE(2335),
    [sym_block] = STATE(8838),
    [sym_expression] = STATE(13607),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(638),
    [sym_block_comment] = STATE(638),
    [sym__alpha_identifier] = ACTIONS(2634),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2637),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(2640),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2640),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2645),
    [anon_sym_infix] = ACTIONS(2640),
    [anon_sym_open] = ACTIONS(2640),
    [anon_sym_transparent] = ACTIONS(2640),
    [anon_sym_LPAREN] = ACTIONS(2648),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(2651),
    [sym_operator_identifier] = ACTIONS(2654),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2657),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [639] = {
    [sym_inline_modifier] = STATE(2336),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(12492),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(639),
    [sym_block_comment] = STATE(639),
    [sym__alpha_identifier] = ACTIONS(2560),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2563),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(2566),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2566),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(2571),
    [anon_sym_infix] = ACTIONS(2566),
    [anon_sym_open] = ACTIONS(2566),
    [anon_sym_transparent] = ACTIONS(2566),
    [anon_sym_LPAREN] = ACTIONS(2574),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(2577),
    [sym_operator_identifier] = ACTIONS(2662),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(2533),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [640] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(13654),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(640),
    [sym_block_comment] = STATE(640),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym_COMMA] = ACTIONS(1148),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(1148),
    [anon_sym_then] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [641] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(13664),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(641),
    [sym_block_comment] = STATE(641),
    [sym__alpha_identifier] = ACTIONS(2665),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2668),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(2671),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2671),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2674),
    [anon_sym_infix] = ACTIONS(2671),
    [anon_sym_open] = ACTIONS(2671),
    [anon_sym_transparent] = ACTIONS(2671),
    [anon_sym_LPAREN] = ACTIONS(2677),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(2680),
    [sym_operator_identifier] = ACTIONS(2683),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(2686),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [642] = {
    [sym_inline_modifier] = STATE(2337),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(11624),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(642),
    [sym_block_comment] = STATE(642),
    [sym__alpha_identifier] = ACTIONS(2689),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2692),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(2695),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2695),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(2698),
    [anon_sym_infix] = ACTIONS(2695),
    [anon_sym_open] = ACTIONS(2695),
    [anon_sym_transparent] = ACTIONS(2695),
    [anon_sym_LPAREN] = ACTIONS(2701),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(2704),
    [sym_operator_identifier] = ACTIONS(2707),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(2710),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [643] = {
    [sym_inline_modifier] = STATE(2338),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(12503),
    [sym__simple_expression] = STATE(5559),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15942),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9343),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5006),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8062),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(643),
    [sym_block_comment] = STATE(643),
    [sym__alpha_identifier] = ACTIONS(2713),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2716),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(2719),
    [anon_sym_if] = ACTIONS(2258),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2262),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2719),
    [anon_sym_implicit] = ACTIONS(2266),
    [anon_sym_inline] = ACTIONS(2722),
    [anon_sym_infix] = ACTIONS(2719),
    [anon_sym_open] = ACTIONS(2719),
    [anon_sym_transparent] = ACTIONS(2719),
    [anon_sym_LPAREN] = ACTIONS(2725),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(2728),
    [sym_operator_identifier] = ACTIONS(2731),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2270),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(2734),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [644] = {
    [sym_inline_modifier] = STATE(2339),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(12790),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(644),
    [sym_block_comment] = STATE(644),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(1156),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [645] = {
    [sym_inline_modifier] = STATE(2339),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(12818),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(645),
    [sym_block_comment] = STATE(645),
    [sym__alpha_identifier] = ACTIONS(2607),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2610),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(2613),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2613),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(2616),
    [anon_sym_infix] = ACTIONS(2613),
    [anon_sym_open] = ACTIONS(2613),
    [anon_sym_transparent] = ACTIONS(2613),
    [anon_sym_LPAREN] = ACTIONS(2619),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(2622),
    [sym_operator_identifier] = ACTIONS(2737),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(2628),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [646] = {
    [sym_inline_modifier] = STATE(2340),
    [sym_block] = STATE(8399),
    [sym_expression] = STATE(13202),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(646),
    [sym_block_comment] = STATE(646),
    [sym__alpha_identifier] = ACTIONS(2740),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2743),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(2746),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2746),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(2749),
    [anon_sym_infix] = ACTIONS(2746),
    [anon_sym_open] = ACTIONS(2746),
    [anon_sym_transparent] = ACTIONS(2746),
    [anon_sym_LPAREN] = ACTIONS(2752),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(2755),
    [sym_operator_identifier] = ACTIONS(2758),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(2761),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [647] = {
    [sym_inline_modifier] = STATE(2341),
    [sym_block] = STATE(7476),
    [sym_expression] = STATE(12911),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(647),
    [sym_block_comment] = STATE(647),
    [sym__alpha_identifier] = ACTIONS(2764),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(2770),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2770),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(2773),
    [anon_sym_infix] = ACTIONS(2770),
    [anon_sym_open] = ACTIONS(2770),
    [anon_sym_transparent] = ACTIONS(2770),
    [anon_sym_LPAREN] = ACTIONS(2776),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(2779),
    [sym_operator_identifier] = ACTIONS(2782),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(2785),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [648] = {
    [sym_inline_modifier] = STATE(2280),
    [sym_block] = STATE(10212),
    [sym_expression] = STATE(14147),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(648),
    [sym_block_comment] = STATE(648),
    [ts_builtin_sym_end] = ACTIONS(1148),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [649] = {
    [sym_inline_modifier] = STATE(2342),
    [sym_block] = STATE(8894),
    [sym_expression] = STATE(13366),
    [sym__simple_expression] = STATE(6017),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15961),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9804),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5210),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(649),
    [sym_block_comment] = STATE(649),
    [sym__alpha_identifier] = ACTIONS(2790),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2793),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(2796),
    [anon_sym_if] = ACTIONS(2380),
    [anon_sym_while] = ACTIONS(2338),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2342),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2796),
    [anon_sym_implicit] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(2799),
    [anon_sym_infix] = ACTIONS(2796),
    [anon_sym_open] = ACTIONS(2796),
    [anon_sym_transparent] = ACTIONS(2796),
    [anon_sym_LPAREN] = ACTIONS(2802),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(2805),
    [sym_operator_identifier] = ACTIONS(2808),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2350),
    [anon_sym_do] = ACTIONS(2811),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [650] = {
    [sym_inline_modifier] = STATE(2343),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(11624),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(650),
    [sym_block_comment] = STATE(650),
    [sym__alpha_identifier] = ACTIONS(2689),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2692),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(2695),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2695),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(2698),
    [anon_sym_infix] = ACTIONS(2695),
    [anon_sym_open] = ACTIONS(2695),
    [anon_sym_transparent] = ACTIONS(2695),
    [anon_sym_LPAREN] = ACTIONS(2701),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(2704),
    [sym_operator_identifier] = ACTIONS(2814),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(2710),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [651] = {
    [sym_inline_modifier] = STATE(2344),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(12503),
    [sym__simple_expression] = STATE(5582),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15990),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9422),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4761),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(7890),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(651),
    [sym_block_comment] = STATE(651),
    [sym__alpha_identifier] = ACTIONS(2713),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2716),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(2719),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2108),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2719),
    [anon_sym_implicit] = ACTIONS(2112),
    [anon_sym_inline] = ACTIONS(2722),
    [anon_sym_infix] = ACTIONS(2719),
    [anon_sym_open] = ACTIONS(2719),
    [anon_sym_transparent] = ACTIONS(2719),
    [anon_sym_LPAREN] = ACTIONS(2725),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(2728),
    [sym_operator_identifier] = ACTIONS(2817),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2116),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(2734),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [652] = {
    [sym_inline_modifier] = STATE(2345),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(11894),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(652),
    [sym_block_comment] = STATE(652),
    [sym__alpha_identifier] = ACTIONS(2583),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2586),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2589),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(2592),
    [anon_sym_infix] = ACTIONS(2589),
    [anon_sym_open] = ACTIONS(2589),
    [anon_sym_transparent] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(2598),
    [sym_operator_identifier] = ACTIONS(2820),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(2604),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [653] = {
    [sym_inline_modifier] = STATE(2346),
    [sym_block] = STATE(8399),
    [sym_expression] = STATE(13202),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(653),
    [sym_block_comment] = STATE(653),
    [sym__alpha_identifier] = ACTIONS(2740),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2743),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(2746),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2746),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(2749),
    [anon_sym_infix] = ACTIONS(2746),
    [anon_sym_open] = ACTIONS(2746),
    [anon_sym_transparent] = ACTIONS(2746),
    [anon_sym_LPAREN] = ACTIONS(2752),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(2755),
    [sym_operator_identifier] = ACTIONS(2823),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(2761),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [654] = {
    [sym_inline_modifier] = STATE(2054),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(11894),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(654),
    [sym_block_comment] = STATE(654),
    [sym__alpha_identifier] = ACTIONS(2583),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2586),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(2589),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2589),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(2592),
    [anon_sym_infix] = ACTIONS(2589),
    [anon_sym_open] = ACTIONS(2589),
    [anon_sym_transparent] = ACTIONS(2589),
    [anon_sym_LPAREN] = ACTIONS(2595),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(2598),
    [sym_operator_identifier] = ACTIONS(2826),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(2604),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [655] = {
    [sym_inline_modifier] = STATE(2276),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(13664),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(655),
    [sym_block_comment] = STATE(655),
    [sym__alpha_identifier] = ACTIONS(2665),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2668),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(2671),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2671),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2674),
    [anon_sym_infix] = ACTIONS(2671),
    [anon_sym_open] = ACTIONS(2671),
    [anon_sym_transparent] = ACTIONS(2671),
    [anon_sym_LPAREN] = ACTIONS(2677),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(2680),
    [sym_operator_identifier] = ACTIONS(2839),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(2686),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [656] = {
    [sym_inline_modifier] = STATE(2278),
    [sym_block] = STATE(9584),
    [sym_expression] = STATE(13804),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(656),
    [sym_block_comment] = STATE(656),
    [sym__alpha_identifier] = ACTIONS(2846),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2849),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(2852),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2852),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(2855),
    [anon_sym_infix] = ACTIONS(2852),
    [anon_sym_open] = ACTIONS(2852),
    [anon_sym_transparent] = ACTIONS(2852),
    [anon_sym_LPAREN] = ACTIONS(2858),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(2861),
    [sym_operator_identifier] = ACTIONS(2864),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(2557),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [657] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(13664),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(657),
    [sym_block_comment] = STATE(657),
    [sym__alpha_identifier] = ACTIONS(2665),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2668),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(2671),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2671),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2674),
    [anon_sym_infix] = ACTIONS(2671),
    [anon_sym_open] = ACTIONS(2671),
    [anon_sym_transparent] = ACTIONS(2671),
    [anon_sym_LPAREN] = ACTIONS(2677),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(2680),
    [sym_operator_identifier] = ACTIONS(2877),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(2686),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [658] = {
    [sym_inline_modifier] = STATE(2280),
    [sym_block] = STATE(10212),
    [sym_expression] = STATE(14107),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(658),
    [sym_block_comment] = STATE(658),
    [sym__alpha_identifier] = ACTIONS(2884),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2887),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2890),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2890),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(2893),
    [anon_sym_infix] = ACTIONS(2890),
    [anon_sym_open] = ACTIONS(2890),
    [anon_sym_transparent] = ACTIONS(2890),
    [anon_sym_LPAREN] = ACTIONS(2896),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(2899),
    [sym_operator_identifier] = ACTIONS(2902),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(2905),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [659] = {
    [sym_inline_modifier] = STATE(2284),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(11863),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(659),
    [sym_block_comment] = STATE(659),
    [sym__alpha_identifier] = ACTIONS(2536),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2539),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(2542),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2542),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(2545),
    [anon_sym_infix] = ACTIONS(2542),
    [anon_sym_open] = ACTIONS(2542),
    [anon_sym_transparent] = ACTIONS(2542),
    [anon_sym_LPAREN] = ACTIONS(2548),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(2551),
    [sym_operator_identifier] = ACTIONS(2908),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(2557),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [660] = {
    [sym_inline_modifier] = STATE(2288),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(13279),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(660),
    [sym_block_comment] = STATE(660),
    [sym__alpha_identifier] = ACTIONS(2911),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2914),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(2917),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2917),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(2920),
    [anon_sym_infix] = ACTIONS(2917),
    [anon_sym_open] = ACTIONS(2917),
    [anon_sym_transparent] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2923),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(2926),
    [sym_operator_identifier] = ACTIONS(2929),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(2932),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [661] = {
    [sym_inline_modifier] = STATE(2302),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13833),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(661),
    [sym_block_comment] = STATE(661),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__outdent] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [662] = {
    [sym_inline_modifier] = STATE(2302),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13763),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(662),
    [sym_block_comment] = STATE(662),
    [sym__alpha_identifier] = ACTIONS(2937),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2940),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(2943),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2943),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(2946),
    [anon_sym_infix] = ACTIONS(2943),
    [anon_sym_open] = ACTIONS(2943),
    [anon_sym_transparent] = ACTIONS(2943),
    [anon_sym_LPAREN] = ACTIONS(2949),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(2952),
    [sym_operator_identifier] = ACTIONS(2955),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(2958),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [663] = {
    [sym_inline_modifier] = STATE(2292),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(13279),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(663),
    [sym_block_comment] = STATE(663),
    [sym__alpha_identifier] = ACTIONS(2911),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2914),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(2917),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2917),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(2920),
    [anon_sym_infix] = ACTIONS(2917),
    [anon_sym_open] = ACTIONS(2917),
    [anon_sym_transparent] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2923),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(2926),
    [sym_operator_identifier] = ACTIONS(2961),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(2932),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [664] = {
    [sym_inline_modifier] = STATE(2294),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(13279),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(664),
    [sym_block_comment] = STATE(664),
    [sym__alpha_identifier] = ACTIONS(2911),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2914),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(2917),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2917),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(2920),
    [anon_sym_infix] = ACTIONS(2917),
    [anon_sym_open] = ACTIONS(2917),
    [anon_sym_transparent] = ACTIONS(2917),
    [anon_sym_LPAREN] = ACTIONS(2923),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(2926),
    [sym_operator_identifier] = ACTIONS(2964),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(2932),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [665] = {
    [sym_inline_modifier] = STATE(2311),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12786),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(665),
    [sym_block_comment] = STATE(665),
    [sym__alpha_identifier] = ACTIONS(2967),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2970),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(2973),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2973),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2976),
    [anon_sym_infix] = ACTIONS(2973),
    [anon_sym_open] = ACTIONS(2973),
    [anon_sym_transparent] = ACTIONS(2973),
    [anon_sym_LPAREN] = ACTIONS(2979),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(2982),
    [sym_operator_identifier] = ACTIONS(2985),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(2905),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [666] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(941),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(666),
    [sym_block_comment] = STATE(666),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [667] = {
    [sym_inline_modifier] = STATE(2296),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(12492),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(667),
    [sym_block_comment] = STATE(667),
    [sym__alpha_identifier] = ACTIONS(2560),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2563),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(2566),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2566),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(2571),
    [anon_sym_infix] = ACTIONS(2566),
    [anon_sym_open] = ACTIONS(2566),
    [anon_sym_transparent] = ACTIONS(2566),
    [anon_sym_LPAREN] = ACTIONS(2574),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(2577),
    [sym_operator_identifier] = ACTIONS(2992),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(2533),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [668] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(878),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(668),
    [sym_block_comment] = STATE(668),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [669] = {
    [sym_inline_modifier] = STATE(2298),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(13060),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(669),
    [sym_block_comment] = STATE(669),
    [sym__alpha_identifier] = ACTIONS(2995),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2998),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(3001),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(3001),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(3004),
    [anon_sym_infix] = ACTIONS(3001),
    [anon_sym_open] = ACTIONS(3001),
    [anon_sym_transparent] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3007),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(3010),
    [sym_operator_identifier] = ACTIONS(3013),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(3016),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [670] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(882),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(670),
    [sym_block_comment] = STATE(670),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [671] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(900),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(671),
    [sym_block_comment] = STATE(671),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [672] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(903),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(672),
    [sym_block_comment] = STATE(672),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [673] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(908),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(673),
    [sym_block_comment] = STATE(673),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [674] = {
    [sym_inline_modifier] = STATE(2300),
    [sym_block] = STATE(8472),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(674),
    [sym_block_comment] = STATE(674),
    [sym__alpha_identifier] = ACTIONS(3019),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(3022),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(3025),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(3025),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(3028),
    [anon_sym_infix] = ACTIONS(3025),
    [anon_sym_open] = ACTIONS(3025),
    [anon_sym_transparent] = ACTIONS(3025),
    [anon_sym_LPAREN] = ACTIONS(3031),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(3034),
    [sym_operator_identifier] = ACTIONS(3037),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(3040),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [675] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(911),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(675),
    [sym_block_comment] = STATE(675),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [676] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(915),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(676),
    [sym_block_comment] = STATE(676),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [677] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(916),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(677),
    [sym_block_comment] = STATE(677),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [678] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(921),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(678),
    [sym_block_comment] = STATE(678),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [679] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(922),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(679),
    [sym_block_comment] = STATE(679),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [680] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(926),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(680),
    [sym_block_comment] = STATE(680),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [681] = {
    [sym_inline_modifier] = STATE(2304),
    [sym_block] = STATE(9158),
    [sym_expression] = STATE(13598),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(681),
    [sym_block_comment] = STATE(681),
    [sym__alpha_identifier] = ACTIONS(3043),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(3046),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(3049),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(3049),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(3052),
    [anon_sym_infix] = ACTIONS(3049),
    [anon_sym_open] = ACTIONS(3049),
    [anon_sym_transparent] = ACTIONS(3049),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(3058),
    [sym_operator_identifier] = ACTIONS(3061),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(2710),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [682] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(928),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(682),
    [sym_block_comment] = STATE(682),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [683] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(933),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(683),
    [sym_block_comment] = STATE(683),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [684] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(935),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(684),
    [sym_block_comment] = STATE(684),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [685] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(940),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(685),
    [sym_block_comment] = STATE(685),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [686] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(942),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(686),
    [sym_block_comment] = STATE(686),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [687] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(947),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(687),
    [sym_block_comment] = STATE(687),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [688] = {
    [sym_inline_modifier] = STATE(2306),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(13060),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(688),
    [sym_block_comment] = STATE(688),
    [sym__alpha_identifier] = ACTIONS(2995),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2998),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(3001),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(3001),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(3004),
    [anon_sym_infix] = ACTIONS(3001),
    [anon_sym_open] = ACTIONS(3001),
    [anon_sym_transparent] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3007),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(3010),
    [sym_operator_identifier] = ACTIONS(3074),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(3016),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [689] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(948),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(689),
    [sym_block_comment] = STATE(689),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [690] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(953),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(690),
    [sym_block_comment] = STATE(690),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [691] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(955),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(691),
    [sym_block_comment] = STATE(691),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [692] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(960),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(692),
    [sym_block_comment] = STATE(692),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [693] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(962),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(693),
    [sym_block_comment] = STATE(693),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [694] = {
    [sym_inline_modifier] = STATE(2308),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12774),
    [sym__simple_expression] = STATE(6086),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16088),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5234),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8197),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(694),
    [sym_block_comment] = STATE(694),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(1156),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3083),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3087),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(3089),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(3091),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(1156),
    [anon_sym_yield] = ACTIONS(1156),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [695] = {
    [sym_inline_modifier] = STATE(2308),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12786),
    [sym__simple_expression] = STATE(6086),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16088),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5234),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8197),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(695),
    [sym_block_comment] = STATE(695),
    [sym__alpha_identifier] = ACTIONS(2967),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2970),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(2973),
    [anon_sym_if] = ACTIONS(3095),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3083),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2973),
    [anon_sym_implicit] = ACTIONS(3087),
    [anon_sym_inline] = ACTIONS(3097),
    [anon_sym_infix] = ACTIONS(2973),
    [anon_sym_open] = ACTIONS(2973),
    [anon_sym_transparent] = ACTIONS(2973),
    [anon_sym_LPAREN] = ACTIONS(2979),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(2982),
    [sym_operator_identifier] = ACTIONS(3100),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(3091),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(2905),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [696] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1269),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(696),
    [sym_block_comment] = STATE(696),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [697] = {
    [sym_inline_modifier] = STATE(2286),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12774),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(697),
    [sym_block_comment] = STATE(697),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(1148),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [698] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1270),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(698),
    [sym_block_comment] = STATE(698),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [699] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(967),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(699),
    [sym_block_comment] = STATE(699),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [700] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(969),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(700),
    [sym_block_comment] = STATE(700),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [701] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(974),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(701),
    [sym_block_comment] = STATE(701),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [702] = {
    [sym_inline_modifier] = STATE(2286),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12786),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(702),
    [sym_block_comment] = STATE(702),
    [sym__alpha_identifier] = ACTIONS(2967),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2970),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(2973),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2973),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(3097),
    [anon_sym_infix] = ACTIONS(2973),
    [anon_sym_open] = ACTIONS(2973),
    [anon_sym_transparent] = ACTIONS(2973),
    [anon_sym_LPAREN] = ACTIONS(2979),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(2982),
    [sym_operator_identifier] = ACTIONS(3105),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(2905),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [703] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(976),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(703),
    [sym_block_comment] = STATE(703),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [704] = {
    [sym_inline_modifier] = STATE(2309),
    [sym_block] = STATE(9961),
    [sym_expression] = STATE(13875),
    [sym__simple_expression] = STATE(6847),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15991),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(10631),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(10386),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5726),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(8783),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(704),
    [sym_block_comment] = STATE(704),
    [sym__alpha_identifier] = ACTIONS(3108),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(3111),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(3114),
    [anon_sym_if] = ACTIONS(2278),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2282),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(3114),
    [anon_sym_implicit] = ACTIONS(2286),
    [anon_sym_inline] = ACTIONS(3117),
    [anon_sym_infix] = ACTIONS(3114),
    [anon_sym_open] = ACTIONS(3114),
    [anon_sym_transparent] = ACTIONS(3114),
    [anon_sym_LPAREN] = ACTIONS(3120),
    [anon_sym_macro] = ACTIONS(2288),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(3123),
    [sym_operator_identifier] = ACTIONS(3126),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2294),
    [anon_sym_do] = ACTIONS(2734),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [705] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(980),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(705),
    [sym_block_comment] = STATE(705),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [706] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(982),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(706),
    [sym_block_comment] = STATE(706),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [707] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(987),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(707),
    [sym_block_comment] = STATE(707),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [708] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(989),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(708),
    [sym_block_comment] = STATE(708),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [709] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(993),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(709),
    [sym_block_comment] = STATE(709),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [710] = {
    [sym_inline_modifier] = STATE(2310),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(13060),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(710),
    [sym_block_comment] = STATE(710),
    [sym__alpha_identifier] = ACTIONS(2995),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2998),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(3001),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3131),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(3001),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(3004),
    [anon_sym_infix] = ACTIONS(3001),
    [anon_sym_open] = ACTIONS(3001),
    [anon_sym_transparent] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3007),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(3010),
    [sym_operator_identifier] = ACTIONS(3139),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(3016),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [711] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(995),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(711),
    [sym_block_comment] = STATE(711),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [712] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1000),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(712),
    [sym_block_comment] = STATE(712),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [713] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1002),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(713),
    [sym_block_comment] = STATE(713),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [714] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1006),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(714),
    [sym_block_comment] = STATE(714),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [715] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1008),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(715),
    [sym_block_comment] = STATE(715),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [716] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1012),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(716),
    [sym_block_comment] = STATE(716),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [717] = {
    [sym_inline_modifier] = STATE(2312),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(11624),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(717),
    [sym_block_comment] = STATE(717),
    [sym__alpha_identifier] = ACTIONS(2689),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2692),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(2695),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2695),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(2698),
    [anon_sym_infix] = ACTIONS(2695),
    [anon_sym_open] = ACTIONS(2695),
    [anon_sym_transparent] = ACTIONS(2695),
    [anon_sym_LPAREN] = ACTIONS(2701),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(2704),
    [sym_operator_identifier] = ACTIONS(3146),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(2710),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [718] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1014),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(718),
    [sym_block_comment] = STATE(718),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [719] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1019),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(719),
    [sym_block_comment] = STATE(719),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [720] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1021),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(720),
    [sym_block_comment] = STATE(720),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [721] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1025),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(721),
    [sym_block_comment] = STATE(721),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [722] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1027),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(722),
    [sym_block_comment] = STATE(722),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [723] = {
    [sym_inline_modifier] = STATE(2328),
    [sym_block] = STATE(8472),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(723),
    [sym_block_comment] = STATE(723),
    [sym__alpha_identifier] = ACTIONS(3019),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(3022),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(3025),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(3025),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(3028),
    [anon_sym_infix] = ACTIONS(3025),
    [anon_sym_open] = ACTIONS(3025),
    [anon_sym_transparent] = ACTIONS(3025),
    [anon_sym_LPAREN] = ACTIONS(3031),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(3034),
    [sym_operator_identifier] = ACTIONS(3149),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(3040),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [724] = {
    [sym_inline_modifier] = STATE(2313),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(12503),
    [sym__simple_expression] = STATE(6055),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15856),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9737),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5346),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8338),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(724),
    [sym_block_comment] = STATE(724),
    [sym__alpha_identifier] = ACTIONS(2713),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2716),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(2719),
    [anon_sym_if] = ACTIONS(1764),
    [anon_sym_while] = ACTIONS(1766),
    [anon_sym_for] = ACTIONS(1768),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1770),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2719),
    [anon_sym_implicit] = ACTIONS(1772),
    [anon_sym_inline] = ACTIONS(2722),
    [anon_sym_infix] = ACTIONS(2719),
    [anon_sym_open] = ACTIONS(2719),
    [anon_sym_transparent] = ACTIONS(2719),
    [anon_sym_LPAREN] = ACTIONS(2725),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(2728),
    [sym_operator_identifier] = ACTIONS(3152),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(1778),
    [anon_sym_throw] = ACTIONS(1780),
    [anon_sym_do] = ACTIONS(2734),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [725] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1034),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(725),
    [sym_block_comment] = STATE(725),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [726] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1039),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(726),
    [sym_block_comment] = STATE(726),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [727] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1040),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(727),
    [sym_block_comment] = STATE(727),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [728] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1045),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(728),
    [sym_block_comment] = STATE(728),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [729] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1047),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(729),
    [sym_block_comment] = STATE(729),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [730] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1558),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(730),
    [sym_block_comment] = STATE(730),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [731] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1051),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(731),
    [sym_block_comment] = STATE(731),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [732] = {
    [sym_inline_modifier] = STATE(2314),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(12523),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(732),
    [sym_block_comment] = STATE(732),
    [sym__alpha_identifier] = ACTIONS(3155),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(3158),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(3161),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(3161),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(3164),
    [anon_sym_infix] = ACTIONS(3161),
    [anon_sym_open] = ACTIONS(3161),
    [anon_sym_transparent] = ACTIONS(3161),
    [anon_sym_LPAREN] = ACTIONS(3167),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(3170),
    [sym_operator_identifier] = ACTIONS(3173),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(3176),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [733] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1053),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(733),
    [sym_block_comment] = STATE(733),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [734] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1056),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(734),
    [sym_block_comment] = STATE(734),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [735] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1058),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(735),
    [sym_block_comment] = STATE(735),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [736] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1062),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(736),
    [sym_block_comment] = STATE(736),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [737] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1064),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(737),
    [sym_block_comment] = STATE(737),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [738] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1068),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(738),
    [sym_block_comment] = STATE(738),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [739] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1070),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(739),
    [sym_block_comment] = STATE(739),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [740] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1074),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(740),
    [sym_block_comment] = STATE(740),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [741] = {
    [sym_inline_modifier] = STATE(2315),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(13421),
    [sym__simple_expression] = STATE(6983),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15899),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10174),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(5823),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9043),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(741),
    [sym_block_comment] = STATE(741),
    [sym__alpha_identifier] = ACTIONS(3179),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(3182),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(3185),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2446),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(3185),
    [anon_sym_implicit] = ACTIONS(2450),
    [anon_sym_inline] = ACTIONS(3188),
    [anon_sym_infix] = ACTIONS(3185),
    [anon_sym_open] = ACTIONS(3185),
    [anon_sym_transparent] = ACTIONS(3185),
    [anon_sym_LPAREN] = ACTIONS(3191),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(3194),
    [sym_operator_identifier] = ACTIONS(3197),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2456),
    [anon_sym_do] = ACTIONS(3200),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [742] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1076),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(742),
    [sym_block_comment] = STATE(742),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [743] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1080),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(743),
    [sym_block_comment] = STATE(743),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [744] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1082),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(744),
    [sym_block_comment] = STATE(744),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [745] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1086),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(745),
    [sym_block_comment] = STATE(745),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [746] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1088),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(746),
    [sym_block_comment] = STATE(746),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [747] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1092),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(747),
    [sym_block_comment] = STATE(747),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [748] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1094),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(748),
    [sym_block_comment] = STATE(748),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [749] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1097),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(749),
    [sym_block_comment] = STATE(749),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [750] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1099),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(750),
    [sym_block_comment] = STATE(750),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [751] = {
    [sym_inline_modifier] = STATE(2324),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13763),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(751),
    [sym_block_comment] = STATE(751),
    [sym__alpha_identifier] = ACTIONS(2937),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2940),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(2943),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2943),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(3203),
    [anon_sym_infix] = ACTIONS(2943),
    [anon_sym_open] = ACTIONS(2943),
    [anon_sym_transparent] = ACTIONS(2943),
    [anon_sym_LPAREN] = ACTIONS(2949),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(2952),
    [sym_operator_identifier] = ACTIONS(3206),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(2958),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [752] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1103),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(752),
    [sym_block_comment] = STATE(752),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [753] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1105),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(753),
    [sym_block_comment] = STATE(753),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [754] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1109),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(754),
    [sym_block_comment] = STATE(754),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [755] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1111),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(755),
    [sym_block_comment] = STATE(755),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [756] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1115),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(756),
    [sym_block_comment] = STATE(756),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [757] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1116),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(757),
    [sym_block_comment] = STATE(757),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [758] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1120),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(758),
    [sym_block_comment] = STATE(758),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [759] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1121),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(759),
    [sym_block_comment] = STATE(759),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [760] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1125),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(760),
    [sym_block_comment] = STATE(760),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [761] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1126),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(761),
    [sym_block_comment] = STATE(761),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [762] = {
    [sym_inline_modifier] = STATE(2316),
    [sym_block] = STATE(8838),
    [sym_expression] = STATE(13607),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(762),
    [sym_block_comment] = STATE(762),
    [sym__alpha_identifier] = ACTIONS(2634),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2637),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(2640),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2640),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(2645),
    [anon_sym_infix] = ACTIONS(2640),
    [anon_sym_open] = ACTIONS(2640),
    [anon_sym_transparent] = ACTIONS(2640),
    [anon_sym_LPAREN] = ACTIONS(2648),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(2651),
    [sym_operator_identifier] = ACTIONS(3209),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2657),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [763] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1130),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(763),
    [sym_block_comment] = STATE(763),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [764] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1131),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(764),
    [sym_block_comment] = STATE(764),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [765] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1135),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(765),
    [sym_block_comment] = STATE(765),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [766] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1136),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(766),
    [sym_block_comment] = STATE(766),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [767] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1140),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(767),
    [sym_block_comment] = STATE(767),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [768] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1141),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(768),
    [sym_block_comment] = STATE(768),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [769] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1145),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(769),
    [sym_block_comment] = STATE(769),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [770] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1146),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(770),
    [sym_block_comment] = STATE(770),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [771] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1150),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(771),
    [sym_block_comment] = STATE(771),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [772] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1151),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(772),
    [sym_block_comment] = STATE(772),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [773] = {
    [sym_inline_modifier] = STATE(2317),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(12523),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(773),
    [sym_block_comment] = STATE(773),
    [sym__alpha_identifier] = ACTIONS(3155),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(3158),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(3161),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(3161),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(3164),
    [anon_sym_infix] = ACTIONS(3161),
    [anon_sym_open] = ACTIONS(3161),
    [anon_sym_transparent] = ACTIONS(3161),
    [anon_sym_LPAREN] = ACTIONS(3167),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(3170),
    [sym_operator_identifier] = ACTIONS(3212),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(3176),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [774] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1154),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(774),
    [sym_block_comment] = STATE(774),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [775] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1155),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(775),
    [sym_block_comment] = STATE(775),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [776] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1159),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(776),
    [sym_block_comment] = STATE(776),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [777] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1160),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(777),
    [sym_block_comment] = STATE(777),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [778] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1164),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(778),
    [sym_block_comment] = STATE(778),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [779] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1165),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(779),
    [sym_block_comment] = STATE(779),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [780] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1169),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(780),
    [sym_block_comment] = STATE(780),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [781] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1170),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(781),
    [sym_block_comment] = STATE(781),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [782] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1174),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(782),
    [sym_block_comment] = STATE(782),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [783] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1175),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(783),
    [sym_block_comment] = STATE(783),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [784] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1179),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(784),
    [sym_block_comment] = STATE(784),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [785] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1180),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(785),
    [sym_block_comment] = STATE(785),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [786] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1184),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(786),
    [sym_block_comment] = STATE(786),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [787] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1185),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(787),
    [sym_block_comment] = STATE(787),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [788] = {
    [sym_inline_modifier] = STATE(2318),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(13421),
    [sym__simple_expression] = STATE(8653),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(16129),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10722),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(7377),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9808),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(788),
    [sym_block_comment] = STATE(788),
    [sym__alpha_identifier] = ACTIONS(3179),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(3182),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(3185),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2200),
    [anon_sym_for] = ACTIONS(2202),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(3185),
    [anon_sym_implicit] = ACTIONS(2206),
    [anon_sym_inline] = ACTIONS(3188),
    [anon_sym_infix] = ACTIONS(3185),
    [anon_sym_open] = ACTIONS(3185),
    [anon_sym_transparent] = ACTIONS(3185),
    [anon_sym_LPAREN] = ACTIONS(3191),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(3194),
    [sym_operator_identifier] = ACTIONS(3215),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(3200),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [789] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1188),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(789),
    [sym_block_comment] = STATE(789),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [790] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1189),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(790),
    [sym_block_comment] = STATE(790),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [791] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1192),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(791),
    [sym_block_comment] = STATE(791),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [792] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1193),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(792),
    [sym_block_comment] = STATE(792),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [793] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1196),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(793),
    [sym_block_comment] = STATE(793),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [794] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1197),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(794),
    [sym_block_comment] = STATE(794),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [795] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1200),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(795),
    [sym_block_comment] = STATE(795),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [796] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1201),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(796),
    [sym_block_comment] = STATE(796),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [797] = {
    [sym_inline_modifier] = STATE(2319),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13833),
    [sym__simple_expression] = STATE(6682),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(15930),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10414),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5580),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9016),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(797),
    [sym_block_comment] = STATE(797),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(1156),
    [anon_sym_while] = ACTIONS(3218),
    [anon_sym_for] = ACTIONS(3220),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(3222),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(3224),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(3226),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(3228),
    [anon_sym_throw] = ACTIONS(3230),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1148),
    [sym__outdent] = ACTIONS(1148),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [798] = {
    [sym_inline_modifier] = STATE(2319),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13763),
    [sym__simple_expression] = STATE(6682),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(15930),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10414),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5580),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9016),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(798),
    [sym_block_comment] = STATE(798),
    [sym__alpha_identifier] = ACTIONS(2937),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2940),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(2943),
    [anon_sym_if] = ACTIONS(3232),
    [anon_sym_while] = ACTIONS(3218),
    [anon_sym_for] = ACTIONS(3220),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(3222),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2943),
    [anon_sym_implicit] = ACTIONS(3224),
    [anon_sym_inline] = ACTIONS(2946),
    [anon_sym_infix] = ACTIONS(2943),
    [anon_sym_open] = ACTIONS(2943),
    [anon_sym_transparent] = ACTIONS(2943),
    [anon_sym_LPAREN] = ACTIONS(2949),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(2952),
    [sym_operator_identifier] = ACTIONS(3234),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(3228),
    [anon_sym_throw] = ACTIONS(3230),
    [anon_sym_do] = ACTIONS(2958),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [799] = {
    [sym_inline_modifier] = STATE(2320),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12786),
    [sym__simple_expression] = STATE(6186),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16018),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9989),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5240),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8124),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(799),
    [sym_block_comment] = STATE(799),
    [sym__alpha_identifier] = ACTIONS(2967),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2970),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(2973),
    [anon_sym_if] = ACTIONS(3237),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2488),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2973),
    [anon_sym_implicit] = ACTIONS(2492),
    [anon_sym_inline] = ACTIONS(3097),
    [anon_sym_infix] = ACTIONS(2973),
    [anon_sym_open] = ACTIONS(2973),
    [anon_sym_transparent] = ACTIONS(2973),
    [anon_sym_LPAREN] = ACTIONS(2979),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(2982),
    [sym_operator_identifier] = ACTIONS(3239),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2496),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(2905),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [800] = {
    [sym_inline_modifier] = STATE(2321),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(11863),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(800),
    [sym_block_comment] = STATE(800),
    [sym__alpha_identifier] = ACTIONS(2536),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2539),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(2542),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2542),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(2545),
    [anon_sym_infix] = ACTIONS(2542),
    [anon_sym_open] = ACTIONS(2542),
    [anon_sym_transparent] = ACTIONS(2542),
    [anon_sym_LPAREN] = ACTIONS(2548),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(2551),
    [sym_operator_identifier] = ACTIONS(3242),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(2557),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [801] = {
    [sym_inline_modifier] = STATE(2322),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(12523),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(801),
    [sym_block_comment] = STATE(801),
    [sym__alpha_identifier] = ACTIONS(3155),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(3158),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(3161),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(3161),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(3164),
    [anon_sym_infix] = ACTIONS(3161),
    [anon_sym_open] = ACTIONS(3161),
    [anon_sym_transparent] = ACTIONS(3161),
    [anon_sym_LPAREN] = ACTIONS(3167),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(3170),
    [sym_operator_identifier] = ACTIONS(3245),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(3176),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [802] = {
    [sym_inline_modifier] = STATE(2323),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(13421),
    [sym__simple_expression] = STATE(8282),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15898),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10750),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(6686),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9873),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(802),
    [sym_block_comment] = STATE(802),
    [sym__alpha_identifier] = ACTIONS(3179),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(3182),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(3185),
    [anon_sym_if] = ACTIONS(2322),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(3185),
    [anon_sym_implicit] = ACTIONS(2330),
    [anon_sym_inline] = ACTIONS(3188),
    [anon_sym_infix] = ACTIONS(3185),
    [anon_sym_open] = ACTIONS(3185),
    [anon_sym_transparent] = ACTIONS(3185),
    [anon_sym_LPAREN] = ACTIONS(3191),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(3194),
    [sym_operator_identifier] = ACTIONS(3248),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2334),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(3200),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [803] = {
    [sym_inline_modifier] = STATE(2325),
    [sym_block] = STATE(7476),
    [sym_expression] = STATE(12911),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(803),
    [sym_block_comment] = STATE(803),
    [sym__alpha_identifier] = ACTIONS(2764),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2767),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(2770),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2770),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(2773),
    [anon_sym_infix] = ACTIONS(2770),
    [anon_sym_open] = ACTIONS(2770),
    [anon_sym_transparent] = ACTIONS(2770),
    [anon_sym_LPAREN] = ACTIONS(2776),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(2779),
    [sym_operator_identifier] = ACTIONS(3251),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(2785),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [804] = {
    [sym_inline_modifier] = STATE(2326),
    [sym_block] = STATE(8894),
    [sym_expression] = STATE(13366),
    [sym__simple_expression] = STATE(6190),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15978),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9770),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5440),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8474),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(804),
    [sym_block_comment] = STATE(804),
    [sym__alpha_identifier] = ACTIONS(2790),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(2793),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(2796),
    [anon_sym_if] = ACTIONS(1924),
    [anon_sym_while] = ACTIONS(1926),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1930),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(2796),
    [anon_sym_implicit] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(2799),
    [anon_sym_infix] = ACTIONS(2796),
    [anon_sym_open] = ACTIONS(2796),
    [anon_sym_transparent] = ACTIONS(2796),
    [anon_sym_LPAREN] = ACTIONS(2802),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(2805),
    [sym_operator_identifier] = ACTIONS(3254),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(1938),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(2811),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [805] = {
    [sym_inline_modifier] = STATE(2327),
    [sym_block] = STATE(9357),
    [sym_expression] = STATE(13746),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(805),
    [sym_block_comment] = STATE(805),
    [sym__alpha_identifier] = ACTIONS(3257),
    [anon_sym_COLON] = ACTIONS(2511),
    [anon_sym_LBRACE] = ACTIONS(3260),
    [anon_sym_DOT] = ACTIONS(2511),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(3263),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_match] = ACTIONS(2511),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_EQ] = ACTIONS(2511),
    [anon_sym_opaque] = ACTIONS(3263),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(3266),
    [anon_sym_infix] = ACTIONS(3263),
    [anon_sym_open] = ACTIONS(3263),
    [anon_sym_transparent] = ACTIONS(3263),
    [anon_sym_LPAREN] = ACTIONS(3269),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(3272),
    [sym_operator_identifier] = ACTIONS(3275),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(2604),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [806] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(17540),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym__if_condition] = STATE(1032),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(4069),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(806),
    [sym_block_comment] = STATE(806),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(2988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [807] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(12799),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(807),
    [sym_block_comment] = STATE(807),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [808] = {
    [sym_inline_modifier] = STATE(2342),
    [sym__indentable_expression] = STATE(13694),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6017),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15961),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9804),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5210),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(808),
    [sym_block_comment] = STATE(808),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(2380),
    [anon_sym_while] = ACTIONS(2338),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2342),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(2346),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2350),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [809] = {
    [sym_inline_modifier] = STATE(2342),
    [sym__indentable_expression] = STATE(13714),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6017),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15961),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9804),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5210),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(809),
    [sym_block_comment] = STATE(809),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(2380),
    [anon_sym_while] = ACTIONS(2338),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2342),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(2346),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2350),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [810] = {
    [sym_inline_modifier] = STATE(2342),
    [sym__indentable_expression] = STATE(13717),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6017),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15961),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9804),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5210),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(810),
    [sym_block_comment] = STATE(810),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(2380),
    [anon_sym_while] = ACTIONS(2338),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2342),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(2346),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2350),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [811] = {
    [sym_inline_modifier] = STATE(2342),
    [sym__indentable_expression] = STATE(13718),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6017),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15961),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9804),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5210),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(811),
    [sym_block_comment] = STATE(811),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(2380),
    [anon_sym_while] = ACTIONS(2338),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2342),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(2346),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2350),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [812] = {
    [sym_inline_modifier] = STATE(2342),
    [sym__indentable_expression] = STATE(13720),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6017),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15961),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9804),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5210),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(812),
    [sym_block_comment] = STATE(812),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(2380),
    [anon_sym_while] = ACTIONS(2338),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2342),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(2346),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2350),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [813] = {
    [sym_inline_modifier] = STATE(2342),
    [sym__indentable_expression] = STATE(13721),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6017),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15961),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9804),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5210),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(813),
    [sym_block_comment] = STATE(813),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(2380),
    [anon_sym_while] = ACTIONS(2338),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2342),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(2346),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2350),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [814] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(13997),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(814),
    [sym_block_comment] = STATE(814),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [815] = {
    [sym_inline_modifier] = STATE(2330),
    [sym__indentable_expression] = STATE(12594),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(815),
    [sym_block_comment] = STATE(815),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2392),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [816] = {
    [sym_inline_modifier] = STATE(2343),
    [sym__indentable_expression] = STATE(11552),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(816),
    [sym_block_comment] = STATE(816),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [817] = {
    [sym_inline_modifier] = STATE(2343),
    [sym__indentable_expression] = STATE(11557),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(817),
    [sym_block_comment] = STATE(817),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [818] = {
    [sym_inline_modifier] = STATE(2343),
    [sym__indentable_expression] = STATE(11459),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(818),
    [sym_block_comment] = STATE(818),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [819] = {
    [sym_inline_modifier] = STATE(2343),
    [sym__indentable_expression] = STATE(11561),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(819),
    [sym_block_comment] = STATE(819),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [820] = {
    [sym_inline_modifier] = STATE(2343),
    [sym__indentable_expression] = STATE(11563),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(820),
    [sym_block_comment] = STATE(820),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [821] = {
    [sym_inline_modifier] = STATE(2343),
    [sym__indentable_expression] = STATE(11572),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(821),
    [sym_block_comment] = STATE(821),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [822] = {
    [sym_inline_modifier] = STATE(2343),
    [sym__indentable_expression] = STATE(11573),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(822),
    [sym_block_comment] = STATE(822),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [823] = {
    [sym_inline_modifier] = STATE(2343),
    [sym__indentable_expression] = STATE(11575),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(823),
    [sym_block_comment] = STATE(823),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [824] = {
    [sym_inline_modifier] = STATE(2343),
    [sym__indentable_expression] = STATE(11578),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(824),
    [sym_block_comment] = STATE(824),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [825] = {
    [sym_inline_modifier] = STATE(2343),
    [sym__indentable_expression] = STATE(11582),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(825),
    [sym_block_comment] = STATE(825),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [826] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(13836),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(826),
    [sym_block_comment] = STATE(826),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [827] = {
    [sym_inline_modifier] = STATE(2330),
    [sym__indentable_expression] = STATE(12595),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(827),
    [sym_block_comment] = STATE(827),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2392),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [828] = {
    [sym_inline_modifier] = STATE(2344),
    [sym__indentable_expression] = STATE(12418),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5582),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15990),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9422),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4761),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(7890),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(828),
    [sym_block_comment] = STATE(828),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2108),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2112),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2114),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2116),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [829] = {
    [sym_inline_modifier] = STATE(2344),
    [sym__indentable_expression] = STATE(12442),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5582),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15990),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9422),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4761),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(7890),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(829),
    [sym_block_comment] = STATE(829),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2108),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2112),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2114),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2116),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [830] = {
    [sym_inline_modifier] = STATE(2344),
    [sym__indentable_expression] = STATE(12443),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5582),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15990),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9422),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4761),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(7890),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(830),
    [sym_block_comment] = STATE(830),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2108),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2112),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2114),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2116),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [831] = {
    [sym_inline_modifier] = STATE(2344),
    [sym__indentable_expression] = STATE(12446),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5582),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15990),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9422),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4761),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(7890),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(831),
    [sym_block_comment] = STATE(831),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2108),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2112),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2114),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2116),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [832] = {
    [sym_inline_modifier] = STATE(2344),
    [sym__indentable_expression] = STATE(12449),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5582),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15990),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9422),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4761),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(7890),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(832),
    [sym_block_comment] = STATE(832),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2108),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2112),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2114),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2116),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [833] = {
    [sym_inline_modifier] = STATE(2344),
    [sym__indentable_expression] = STATE(12465),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5582),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15990),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9422),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4761),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(7890),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(833),
    [sym_block_comment] = STATE(833),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2108),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2112),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2114),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2116),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [834] = {
    [sym_inline_modifier] = STATE(2344),
    [sym__indentable_expression] = STATE(12472),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5582),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15990),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9422),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4761),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(7890),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(834),
    [sym_block_comment] = STATE(834),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2108),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2112),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2114),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2116),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [835] = {
    [sym_inline_modifier] = STATE(2344),
    [sym__indentable_expression] = STATE(12474),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5582),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15990),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9422),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4761),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(7890),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(835),
    [sym_block_comment] = STATE(835),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2108),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2112),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2114),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2116),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [836] = {
    [sym_inline_modifier] = STATE(2344),
    [sym__indentable_expression] = STATE(12476),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5582),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15990),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9422),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4761),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(7890),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(836),
    [sym_block_comment] = STATE(836),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2108),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2112),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2114),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2116),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [837] = {
    [sym_inline_modifier] = STATE(2344),
    [sym__indentable_expression] = STATE(12477),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5582),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15990),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9422),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4761),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(7890),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(837),
    [sym_block_comment] = STATE(837),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2108),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2112),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2114),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2116),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [838] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(13837),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(838),
    [sym_block_comment] = STATE(838),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [839] = {
    [sym_inline_modifier] = STATE(2330),
    [sym__indentable_expression] = STATE(12599),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(839),
    [sym_block_comment] = STATE(839),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2392),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [840] = {
    [sym_inline_modifier] = STATE(2345),
    [sym__indentable_expression] = STATE(11985),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(840),
    [sym_block_comment] = STATE(840),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [841] = {
    [sym_inline_modifier] = STATE(2345),
    [sym__indentable_expression] = STATE(11996),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(841),
    [sym_block_comment] = STATE(841),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [842] = {
    [sym_inline_modifier] = STATE(2345),
    [sym__indentable_expression] = STATE(11998),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(842),
    [sym_block_comment] = STATE(842),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [843] = {
    [sym_inline_modifier] = STATE(2345),
    [sym__indentable_expression] = STATE(11999),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(843),
    [sym_block_comment] = STATE(843),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [844] = {
    [sym_inline_modifier] = STATE(2345),
    [sym__indentable_expression] = STATE(12002),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(844),
    [sym_block_comment] = STATE(844),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [845] = {
    [sym_inline_modifier] = STATE(2345),
    [sym__indentable_expression] = STATE(12019),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(845),
    [sym_block_comment] = STATE(845),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [846] = {
    [sym_inline_modifier] = STATE(2345),
    [sym__indentable_expression] = STATE(12028),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(846),
    [sym_block_comment] = STATE(846),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [847] = {
    [sym_inline_modifier] = STATE(2345),
    [sym__indentable_expression] = STATE(12029),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(847),
    [sym_block_comment] = STATE(847),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [848] = {
    [sym_inline_modifier] = STATE(2345),
    [sym__indentable_expression] = STATE(12031),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(848),
    [sym_block_comment] = STATE(848),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [849] = {
    [sym_inline_modifier] = STATE(2345),
    [sym__indentable_expression] = STATE(12035),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(849),
    [sym_block_comment] = STATE(849),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [850] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(13844),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(850),
    [sym_block_comment] = STATE(850),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [851] = {
    [sym_inline_modifier] = STATE(2330),
    [sym__indentable_expression] = STATE(12603),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(851),
    [sym_block_comment] = STATE(851),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2392),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [852] = {
    [sym_inline_modifier] = STATE(2346),
    [sym__indentable_expression] = STATE(13443),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(852),
    [sym_block_comment] = STATE(852),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [853] = {
    [sym_inline_modifier] = STATE(2346),
    [sym__indentable_expression] = STATE(13481),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(853),
    [sym_block_comment] = STATE(853),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [854] = {
    [sym_inline_modifier] = STATE(2346),
    [sym__indentable_expression] = STATE(13483),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(854),
    [sym_block_comment] = STATE(854),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [855] = {
    [sym_inline_modifier] = STATE(2346),
    [sym__indentable_expression] = STATE(13486),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(855),
    [sym_block_comment] = STATE(855),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [856] = {
    [sym_inline_modifier] = STATE(2346),
    [sym__indentable_expression] = STATE(13490),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(856),
    [sym_block_comment] = STATE(856),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [857] = {
    [sym_inline_modifier] = STATE(2346),
    [sym__indentable_expression] = STATE(13531),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(857),
    [sym_block_comment] = STATE(857),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [858] = {
    [sym_inline_modifier] = STATE(2346),
    [sym__indentable_expression] = STATE(13540),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(858),
    [sym_block_comment] = STATE(858),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [859] = {
    [sym_inline_modifier] = STATE(2346),
    [sym__indentable_expression] = STATE(13543),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(859),
    [sym_block_comment] = STATE(859),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [860] = {
    [sym_inline_modifier] = STATE(2346),
    [sym__indentable_expression] = STATE(13545),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(860),
    [sym_block_comment] = STATE(860),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [861] = {
    [sym_inline_modifier] = STATE(2346),
    [sym__indentable_expression] = STATE(13549),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(861),
    [sym_block_comment] = STATE(861),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [862] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(14679),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(862),
    [sym_block_comment] = STATE(862),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [863] = {
    [sym_inline_modifier] = STATE(2330),
    [sym__indentable_expression] = STATE(12617),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(863),
    [sym_block_comment] = STATE(863),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2392),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [864] = {
    [sym_inline_modifier] = STATE(2054),
    [sym__indentable_expression] = STATE(11985),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(864),
    [sym_block_comment] = STATE(864),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [865] = {
    [sym_inline_modifier] = STATE(2054),
    [sym__indentable_expression] = STATE(11996),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(865),
    [sym_block_comment] = STATE(865),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [866] = {
    [sym_inline_modifier] = STATE(2054),
    [sym__indentable_expression] = STATE(11998),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(866),
    [sym_block_comment] = STATE(866),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [867] = {
    [sym_inline_modifier] = STATE(2054),
    [sym__indentable_expression] = STATE(11999),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(867),
    [sym_block_comment] = STATE(867),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [868] = {
    [sym_inline_modifier] = STATE(2054),
    [sym__indentable_expression] = STATE(12002),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(868),
    [sym_block_comment] = STATE(868),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [869] = {
    [sym_inline_modifier] = STATE(2054),
    [sym__indentable_expression] = STATE(12019),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(869),
    [sym_block_comment] = STATE(869),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [870] = {
    [sym_inline_modifier] = STATE(2054),
    [sym__indentable_expression] = STATE(12028),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(870),
    [sym_block_comment] = STATE(870),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [871] = {
    [sym_inline_modifier] = STATE(2054),
    [sym__indentable_expression] = STATE(12029),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(871),
    [sym_block_comment] = STATE(871),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [872] = {
    [sym_inline_modifier] = STATE(2054),
    [sym__indentable_expression] = STATE(12031),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(872),
    [sym_block_comment] = STATE(872),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [873] = {
    [sym_inline_modifier] = STATE(2054),
    [sym__indentable_expression] = STATE(12035),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(873),
    [sym_block_comment] = STATE(873),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [874] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(14685),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(874),
    [sym_block_comment] = STATE(874),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [875] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16153),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(702),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(875),
    [sym_block_comment] = STATE(875),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [876] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(13538),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(876),
    [sym_block_comment] = STATE(876),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [877] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(14301),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(877),
    [sym_block_comment] = STATE(877),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [878] = {
    [sym_inline_modifier] = STATE(2296),
    [sym__indentable_expression] = STATE(14028),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(878),
    [sym_block_comment] = STATE(878),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [879] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(12986),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(879),
    [sym_block_comment] = STATE(879),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [880] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(14542),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(880),
    [sym_block_comment] = STATE(880),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [881] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(13867),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(881),
    [sym_block_comment] = STATE(881),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [882] = {
    [sym_inline_modifier] = STATE(2296),
    [sym__indentable_expression] = STATE(14055),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(882),
    [sym_block_comment] = STATE(882),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [883] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(14638),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(883),
    [sym_block_comment] = STATE(883),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [884] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(13897),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(884),
    [sym_block_comment] = STATE(884),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [885] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(14599),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(885),
    [sym_block_comment] = STATE(885),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [886] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(14555),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(886),
    [sym_block_comment] = STATE(886),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [887] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(14679),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(887),
    [sym_block_comment] = STATE(887),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [888] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(14685),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(888),
    [sym_block_comment] = STATE(888),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [889] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(14542),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(889),
    [sym_block_comment] = STATE(889),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [890] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(14638),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(890),
    [sym_block_comment] = STATE(890),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [891] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(14649),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(891),
    [sym_block_comment] = STATE(891),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [892] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(14673),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(892),
    [sym_block_comment] = STATE(892),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [893] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(14676),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(893),
    [sym_block_comment] = STATE(893),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [894] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(14704),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(894),
    [sym_block_comment] = STATE(894),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [895] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(14444),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(895),
    [sym_block_comment] = STATE(895),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [896] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(13898),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(896),
    [sym_block_comment] = STATE(896),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [897] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16881),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(641),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(897),
    [sym_block_comment] = STATE(897),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [898] = {
    [sym_inline_modifier] = STATE(2288),
    [sym__indentable_expression] = STATE(13449),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(898),
    [sym_block_comment] = STATE(898),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [899] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(14649),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(899),
    [sym_block_comment] = STATE(899),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [900] = {
    [sym_inline_modifier] = STATE(2298),
    [sym__indentable_expression] = STATE(13892),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(900),
    [sym_block_comment] = STATE(900),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(2066),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [901] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(14673),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(901),
    [sym_block_comment] = STATE(901),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [902] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(14676),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(902),
    [sym_block_comment] = STATE(902),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [903] = {
    [sym_inline_modifier] = STATE(2298),
    [sym__indentable_expression] = STATE(13850),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(903),
    [sym_block_comment] = STATE(903),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(2066),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [904] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(13901),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(904),
    [sym_block_comment] = STATE(904),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [905] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17268),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(655),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(905),
    [sym_block_comment] = STATE(905),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [906] = {
    [sym_inline_modifier] = STATE(2292),
    [sym__indentable_expression] = STATE(13899),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(906),
    [sym_block_comment] = STATE(906),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [907] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(14704),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(907),
    [sym_block_comment] = STATE(907),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [908] = {
    [sym_inline_modifier] = STATE(2306),
    [sym__indentable_expression] = STATE(14260),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(908),
    [sym_block_comment] = STATE(908),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [909] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(12819),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(909),
    [sym_block_comment] = STATE(909),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [910] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(14008),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(910),
    [sym_block_comment] = STATE(910),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [911] = {
    [sym_inline_modifier] = STATE(2306),
    [sym__indentable_expression] = STATE(14262),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(911),
    [sym_block_comment] = STATE(911),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [912] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(14444),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(912),
    [sym_block_comment] = STATE(912),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [913] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17702),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(656),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(913),
    [sym_block_comment] = STATE(913),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [914] = {
    [sym_inline_modifier] = STATE(2294),
    [sym__indentable_expression] = STATE(13957),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(914),
    [sym_block_comment] = STATE(914),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [915] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(13803),
    [sym_block] = STATE(9158),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(13329),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(915),
    [sym_block_comment] = STATE(915),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [916] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(13660),
    [sym_block] = STATE(9158),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(13329),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(916),
    [sym_block_comment] = STATE(916),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [917] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(13924),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(917),
    [sym_block_comment] = STATE(917),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [918] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16345),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(657),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(918),
    [sym_block_comment] = STATE(918),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [919] = {
    [sym_inline_modifier] = STATE(2288),
    [sym__indentable_expression] = STATE(13463),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(919),
    [sym_block_comment] = STATE(919),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [920] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(14278),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(920),
    [sym_block_comment] = STATE(920),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [921] = {
    [sym_inline_modifier] = STATE(2310),
    [sym__indentable_expression] = STATE(14337),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(921),
    [sym_block_comment] = STATE(921),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3131),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3290),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [922] = {
    [sym_inline_modifier] = STATE(2310),
    [sym__indentable_expression] = STATE(14338),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(922),
    [sym_block_comment] = STATE(922),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3131),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3290),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [923] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16738),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(659),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(923),
    [sym_block_comment] = STATE(923),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [924] = {
    [sym_inline_modifier] = STATE(2300),
    [sym__indentable_expression] = STATE(13573),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(924),
    [sym_block_comment] = STATE(924),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [925] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(14248),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(925),
    [sym_block_comment] = STATE(925),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [926] = {
    [sym_inline_modifier] = STATE(2312),
    [sym__indentable_expression] = STATE(13390),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(926),
    [sym_block_comment] = STATE(926),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [927] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(13997),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(927),
    [sym_block_comment] = STATE(927),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [928] = {
    [sym_inline_modifier] = STATE(2312),
    [sym__indentable_expression] = STATE(13423),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(928),
    [sym_block_comment] = STATE(928),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [929] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(13836),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(929),
    [sym_block_comment] = STATE(929),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [930] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17537),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(660),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(930),
    [sym_block_comment] = STATE(930),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [931] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(13102),
    [sym_block] = STATE(9158),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(13329),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(931),
    [sym_block_comment] = STATE(931),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [932] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(13837),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(932),
    [sym_block_comment] = STATE(932),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [933] = {
    [sym_inline_modifier] = STATE(2314),
    [sym__indentable_expression] = STATE(13542),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(933),
    [sym_block_comment] = STATE(933),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [934] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(13844),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(934),
    [sym_block_comment] = STATE(934),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [935] = {
    [sym_inline_modifier] = STATE(2314),
    [sym__indentable_expression] = STATE(13383),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(935),
    [sym_block_comment] = STATE(935),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [936] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(14364),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(936),
    [sym_block_comment] = STATE(936),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [937] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17289),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(662),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(937),
    [sym_block_comment] = STATE(937),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [938] = {
    [sym_inline_modifier] = STATE(2292),
    [sym__indentable_expression] = STATE(13866),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(938),
    [sym_block_comment] = STATE(938),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [939] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(14368),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(939),
    [sym_block_comment] = STATE(939),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [940] = {
    [sym_inline_modifier] = STATE(2316),
    [sym__indentable_expression] = STATE(14117),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(940),
    [sym_block_comment] = STATE(940),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [941] = {
    [sym_inline_modifier] = STATE(2290),
    [sym__indentable_expression] = STATE(14091),
    [sym_block] = STATE(10014),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(13944),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(941),
    [sym_block_comment] = STATE(941),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2184),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [942] = {
    [sym_inline_modifier] = STATE(2316),
    [sym__indentable_expression] = STATE(14105),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(942),
    [sym_block_comment] = STATE(942),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [943] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(14301),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(943),
    [sym_block_comment] = STATE(943),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [944] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17444),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(631),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(944),
    [sym_block_comment] = STATE(944),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [945] = {
    [sym_inline_modifier] = STATE(2294),
    [sym__indentable_expression] = STATE(13834),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(945),
    [sym_block_comment] = STATE(945),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [946] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(13867),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(946),
    [sym_block_comment] = STATE(946),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [947] = {
    [sym_inline_modifier] = STATE(2290),
    [sym__indentable_expression] = STATE(14022),
    [sym_block] = STATE(10014),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(13944),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(947),
    [sym_block_comment] = STATE(947),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2184),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [948] = {
    [sym_inline_modifier] = STATE(2290),
    [sym__indentable_expression] = STATE(14083),
    [sym_block] = STATE(10014),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(13944),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(948),
    [sym_block_comment] = STATE(948),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2184),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [949] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(14295),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(949),
    [sym_block_comment] = STATE(949),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [950] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17553),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(663),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(950),
    [sym_block_comment] = STATE(950),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [951] = {
    [sym_inline_modifier] = STATE(2312),
    [sym__indentable_expression] = STATE(12848),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(951),
    [sym_block_comment] = STATE(951),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [952] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(13897),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(952),
    [sym_block_comment] = STATE(952),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [953] = {
    [sym_inline_modifier] = STATE(2317),
    [sym__indentable_expression] = STATE(13908),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(953),
    [sym_block_comment] = STATE(953),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [954] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(13898),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(954),
    [sym_block_comment] = STATE(954),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [955] = {
    [sym_inline_modifier] = STATE(2317),
    [sym__indentable_expression] = STATE(13909),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(955),
    [sym_block_comment] = STATE(955),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [956] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(14359),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(956),
    [sym_block_comment] = STATE(956),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [957] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16687),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(664),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(957),
    [sym_block_comment] = STATE(957),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [958] = {
    [sym_inline_modifier] = STATE(2314),
    [sym__indentable_expression] = STATE(13007),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(958),
    [sym_block_comment] = STATE(958),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [959] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(14363),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(959),
    [sym_block_comment] = STATE(959),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [960] = {
    [sym_inline_modifier] = STATE(2322),
    [sym__indentable_expression] = STATE(13963),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(960),
    [sym_block_comment] = STATE(960),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [961] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(14366),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(961),
    [sym_block_comment] = STATE(961),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [962] = {
    [sym_inline_modifier] = STATE(2322),
    [sym__indentable_expression] = STATE(13964),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(962),
    [sym_block_comment] = STATE(962),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [963] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(13901),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(963),
    [sym_block_comment] = STATE(963),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [964] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17242),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(665),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(964),
    [sym_block_comment] = STATE(964),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [965] = {
    [sym_inline_modifier] = STATE(2300),
    [sym__indentable_expression] = STATE(13063),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(965),
    [sym_block_comment] = STATE(965),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [966] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(14379),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(966),
    [sym_block_comment] = STATE(966),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [967] = {
    [sym_inline_modifier] = STATE(2296),
    [sym__indentable_expression] = STATE(13912),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(967),
    [sym_block_comment] = STATE(967),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [968] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(14008),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(968),
    [sym_block_comment] = STATE(968),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [969] = {
    [sym_inline_modifier] = STATE(2296),
    [sym__indentable_expression] = STATE(13913),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(969),
    [sym_block_comment] = STATE(969),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [970] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(14225),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(970),
    [sym_block_comment] = STATE(970),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [971] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17866),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(667),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(971),
    [sym_block_comment] = STATE(971),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [972] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(13166),
    [sym_block] = STATE(9158),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(13329),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(972),
    [sym_block_comment] = STATE(972),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [973] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(14295),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(973),
    [sym_block_comment] = STATE(973),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [974] = {
    [sym_inline_modifier] = STATE(2298),
    [sym__indentable_expression] = STATE(13858),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(974),
    [sym_block_comment] = STATE(974),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(2066),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [975] = {
    [sym_inline_modifier] = STATE(2330),
    [sym__indentable_expression] = STATE(12623),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(975),
    [sym_block_comment] = STATE(975),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2392),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [976] = {
    [sym_inline_modifier] = STATE(2298),
    [sym__indentable_expression] = STATE(13870),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(976),
    [sym_block_comment] = STATE(976),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(2066),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [977] = {
    [sym_inline_modifier] = STATE(2278),
    [sym__indentable_expression] = STATE(11953),
    [sym_block] = STATE(9584),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(13653),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(977),
    [sym_block_comment] = STATE(977),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [978] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16675),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(669),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(978),
    [sym_block_comment] = STATE(978),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [979] = {
    [sym_inline_modifier] = STATE(2317),
    [sym__indentable_expression] = STATE(13485),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(979),
    [sym_block_comment] = STATE(979),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [980] = {
    [sym_inline_modifier] = STATE(2325),
    [sym__indentable_expression] = STATE(13471),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(980),
    [sym_block_comment] = STATE(980),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [981] = {
    [sym_inline_modifier] = STATE(2278),
    [sym__indentable_expression] = STATE(12119),
    [sym_block] = STATE(9584),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(13653),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(981),
    [sym_block_comment] = STATE(981),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [982] = {
    [sym_inline_modifier] = STATE(2325),
    [sym__indentable_expression] = STATE(13386),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(982),
    [sym_block_comment] = STATE(982),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [983] = {
    [sym_inline_modifier] = STATE(2278),
    [sym__indentable_expression] = STATE(12061),
    [sym_block] = STATE(9584),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(13653),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(983),
    [sym_block_comment] = STATE(983),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [984] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17545),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(674),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(984),
    [sym_block_comment] = STATE(984),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [985] = {
    [sym_inline_modifier] = STATE(2321),
    [sym__indentable_expression] = STATE(12653),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(985),
    [sym_block_comment] = STATE(985),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [986] = {
    [sym_inline_modifier] = STATE(2278),
    [sym__indentable_expression] = STATE(12086),
    [sym_block] = STATE(9584),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(13653),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(986),
    [sym_block_comment] = STATE(986),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [987] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(13700),
    [sym_block] = STATE(9158),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(13329),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(987),
    [sym_block_comment] = STATE(987),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [988] = {
    [sym_inline_modifier] = STATE(2278),
    [sym__indentable_expression] = STATE(12093),
    [sym_block] = STATE(9584),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(13653),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(988),
    [sym_block_comment] = STATE(988),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [989] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(13710),
    [sym_block] = STATE(9158),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(13329),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(989),
    [sym_block_comment] = STATE(989),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [990] = {
    [sym_inline_modifier] = STATE(2278),
    [sym__indentable_expression] = STATE(12125),
    [sym_block] = STATE(9584),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(13653),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(990),
    [sym_block_comment] = STATE(990),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [991] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17323),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(681),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(991),
    [sym_block_comment] = STATE(991),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [992] = {
    [sym_inline_modifier] = STATE(2322),
    [sym__indentable_expression] = STATE(13332),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(992),
    [sym_block_comment] = STATE(992),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [993] = {
    [sym_inline_modifier] = STATE(2306),
    [sym__indentable_expression] = STATE(14284),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(993),
    [sym_block_comment] = STATE(993),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [994] = {
    [sym_inline_modifier] = STATE(2278),
    [sym__indentable_expression] = STATE(11850),
    [sym_block] = STATE(9584),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(13653),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(994),
    [sym_block_comment] = STATE(994),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [995] = {
    [sym_inline_modifier] = STATE(2306),
    [sym__indentable_expression] = STATE(14285),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(995),
    [sym_block_comment] = STATE(995),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [996] = {
    [sym_inline_modifier] = STATE(2278),
    [sym__indentable_expression] = STATE(11852),
    [sym_block] = STATE(9584),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(13653),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(996),
    [sym_block_comment] = STATE(996),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [997] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16551),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(688),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(997),
    [sym_block_comment] = STATE(997),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [998] = {
    [sym_inline_modifier] = STATE(2312),
    [sym__indentable_expression] = STATE(12988),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(998),
    [sym_block_comment] = STATE(998),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [999] = {
    [sym_inline_modifier] = STATE(2278),
    [sym__indentable_expression] = STATE(11901),
    [sym_block] = STATE(9584),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(13653),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(999),
    [sym_block_comment] = STATE(999),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [1000] = {
    [sym_inline_modifier] = STATE(2330),
    [sym__indentable_expression] = STATE(13808),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1000),
    [sym_block_comment] = STATE(1000),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2392),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1001] = {
    [sym_inline_modifier] = STATE(2278),
    [sym__indentable_expression] = STATE(12022),
    [sym_block] = STATE(9584),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(13653),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1001),
    [sym_block_comment] = STATE(1001),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [1002] = {
    [sym_inline_modifier] = STATE(2330),
    [sym__indentable_expression] = STATE(13810),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1002),
    [sym_block_comment] = STATE(1002),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2392),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1003] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17200),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(695),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1003),
    [sym_block_comment] = STATE(1003),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1004] = {
    [sym_inline_modifier] = STATE(2314),
    [sym__indentable_expression] = STATE(12990),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1004),
    [sym_block_comment] = STATE(1004),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1005] = {
    [sym_inline_modifier] = STATE(2330),
    [sym__indentable_expression] = STATE(12624),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1005),
    [sym_block_comment] = STATE(1005),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2392),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1006] = {
    [sym_inline_modifier] = STATE(2327),
    [sym__indentable_expression] = STATE(13874),
    [sym_block] = STATE(9357),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(13735),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1006),
    [sym_block_comment] = STATE(1006),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1007] = {
    [sym_inline_modifier] = STATE(2282),
    [sym__indentable_expression] = STATE(13924),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1007),
    [sym_block_comment] = STATE(1007),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1008] = {
    [sym_inline_modifier] = STATE(2327),
    [sym__indentable_expression] = STATE(13887),
    [sym_block] = STATE(9357),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(13735),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1008),
    [sym_block_comment] = STATE(1008),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1009] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17670),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(704),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1009),
    [sym_block_comment] = STATE(1009),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1010] = {
    [sym_inline_modifier] = STATE(2288),
    [sym__indentable_expression] = STATE(13478),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1010),
    [sym_block_comment] = STATE(1010),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1011] = {
    [sym_inline_modifier] = STATE(2282),
    [sym__indentable_expression] = STATE(13997),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1011),
    [sym_block_comment] = STATE(1011),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1012] = {
    [sym_inline_modifier] = STATE(2310),
    [sym__indentable_expression] = STATE(14346),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1012),
    [sym_block_comment] = STATE(1012),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3131),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3290),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1013] = {
    [sym_inline_modifier] = STATE(2282),
    [sym__indentable_expression] = STATE(13836),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1013),
    [sym_block_comment] = STATE(1013),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1014] = {
    [sym_inline_modifier] = STATE(2310),
    [sym__indentable_expression] = STATE(14347),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1014),
    [sym_block_comment] = STATE(1014),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3131),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3290),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1015] = {
    [sym_inline_modifier] = STATE(2282),
    [sym__indentable_expression] = STATE(13837),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1015),
    [sym_block_comment] = STATE(1015),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1016] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16816),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(710),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1016),
    [sym_block_comment] = STATE(1016),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1017] = {
    [sym_inline_modifier] = STATE(2300),
    [sym__indentable_expression] = STATE(13163),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1017),
    [sym_block_comment] = STATE(1017),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1018] = {
    [sym_inline_modifier] = STATE(2282),
    [sym__indentable_expression] = STATE(13844),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1018),
    [sym_block_comment] = STATE(1018),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1019] = {
    [sym_inline_modifier] = STATE(2312),
    [sym__indentable_expression] = STATE(13606),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1019),
    [sym_block_comment] = STATE(1019),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1020] = {
    [sym_inline_modifier] = STATE(2282),
    [sym__indentable_expression] = STATE(13867),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1020),
    [sym_block_comment] = STATE(1020),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1021] = {
    [sym_inline_modifier] = STATE(2312),
    [sym__indentable_expression] = STATE(13611),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1021),
    [sym_block_comment] = STATE(1021),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1022] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16615),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(717),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1022),
    [sym_block_comment] = STATE(1022),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1023] = {
    [sym_inline_modifier] = STATE(2325),
    [sym__indentable_expression] = STATE(12934),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1023),
    [sym_block_comment] = STATE(1023),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1024] = {
    [sym_inline_modifier] = STATE(2282),
    [sym__indentable_expression] = STATE(13897),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1024),
    [sym_block_comment] = STATE(1024),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1025] = {
    [sym_inline_modifier] = STATE(2332),
    [sym__indentable_expression] = STATE(13767),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1025),
    [sym_block_comment] = STATE(1025),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1026] = {
    [sym_inline_modifier] = STATE(2282),
    [sym__indentable_expression] = STATE(13898),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1026),
    [sym_block_comment] = STATE(1026),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1027] = {
    [sym_inline_modifier] = STATE(2332),
    [sym__indentable_expression] = STATE(13768),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1027),
    [sym_block_comment] = STATE(1027),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1028] = {
    [sym_inline_modifier] = STATE(2282),
    [sym__indentable_expression] = STATE(13901),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1028),
    [sym_block_comment] = STATE(1028),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1029] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17498),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(724),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1029),
    [sym_block_comment] = STATE(1029),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1030] = {
    [sym_inline_modifier] = STATE(2317),
    [sym__indentable_expression] = STATE(13604),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1030),
    [sym_block_comment] = STATE(1030),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1031] = {
    [sym_inline_modifier] = STATE(2282),
    [sym__indentable_expression] = STATE(14008),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1031),
    [sym_block_comment] = STATE(1031),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1032] = {
    [sym_inline_modifier] = STATE(2314),
    [sym__indentable_expression] = STATE(13439),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1032),
    [sym_block_comment] = STATE(1032),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1033] = {
    [sym_inline_modifier] = STATE(2330),
    [sym__indentable_expression] = STATE(12626),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1033),
    [sym_block_comment] = STATE(1033),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2392),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1034] = {
    [sym_inline_modifier] = STATE(2314),
    [sym__indentable_expression] = STATE(13577),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1034),
    [sym_block_comment] = STATE(1034),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1035] = {
    [sym_inline_modifier] = STATE(2330),
    [sym__indentable_expression] = STATE(12631),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1035),
    [sym_block_comment] = STATE(1035),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2392),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1036] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16308),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(732),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1036),
    [sym_block_comment] = STATE(1036),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1037] = {
    [sym_inline_modifier] = STATE(2292),
    [sym__indentable_expression] = STATE(13863),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1037),
    [sym_block_comment] = STATE(1037),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1038] = {
    [sym_inline_modifier] = STATE(2284),
    [sym__indentable_expression] = STATE(11953),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1038),
    [sym_block_comment] = STATE(1038),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1039] = {
    [sym_inline_modifier] = STATE(2333),
    [sym__indentable_expression] = STATE(13811),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1039),
    [sym_block_comment] = STATE(1039),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1040] = {
    [sym_inline_modifier] = STATE(2333),
    [sym__indentable_expression] = STATE(13639),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1040),
    [sym_block_comment] = STATE(1040),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1041] = {
    [sym_inline_modifier] = STATE(2284),
    [sym__indentable_expression] = STATE(12119),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1041),
    [sym_block_comment] = STATE(1041),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1042] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16820),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(741),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1042),
    [sym_block_comment] = STATE(1042),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1043] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(13229),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1043),
    [sym_block_comment] = STATE(1043),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1044] = {
    [sym_inline_modifier] = STATE(2284),
    [sym__indentable_expression] = STATE(12061),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1044),
    [sym_block_comment] = STATE(1044),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1045] = {
    [sym_inline_modifier] = STATE(2316),
    [sym__indentable_expression] = STATE(13910),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1045),
    [sym_block_comment] = STATE(1045),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1046] = {
    [sym_inline_modifier] = STATE(2284),
    [sym__indentable_expression] = STATE(12086),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1046),
    [sym_block_comment] = STATE(1046),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1047] = {
    [sym_inline_modifier] = STATE(2316),
    [sym__indentable_expression] = STATE(13911),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1047),
    [sym_block_comment] = STATE(1047),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1048] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17202),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(751),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1048),
    [sym_block_comment] = STATE(1048),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1049] = {
    [sym_inline_modifier] = STATE(2329),
    [sym__indentable_expression] = STATE(12888),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1049),
    [sym_block_comment] = STATE(1049),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1050] = {
    [sym_inline_modifier] = STATE(2284),
    [sym__indentable_expression] = STATE(12093),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1050),
    [sym_block_comment] = STATE(1050),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1051] = {
    [sym_inline_modifier] = STATE(2316),
    [sym__indentable_expression] = STATE(13841),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1051),
    [sym_block_comment] = STATE(1051),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1052] = {
    [sym_inline_modifier] = STATE(2284),
    [sym__indentable_expression] = STATE(12125),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1052),
    [sym_block_comment] = STATE(1052),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1053] = {
    [sym_inline_modifier] = STATE(2316),
    [sym__indentable_expression] = STATE(13931),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1053),
    [sym_block_comment] = STATE(1053),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1054] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17402),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(762),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1054),
    [sym_block_comment] = STATE(1054),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1055] = {
    [sym_inline_modifier] = STATE(2321),
    [sym__indentable_expression] = STATE(12701),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1055),
    [sym_block_comment] = STATE(1055),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1056] = {
    [sym_inline_modifier] = STATE(2317),
    [sym__indentable_expression] = STATE(13920),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1056),
    [sym_block_comment] = STATE(1056),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1057] = {
    [sym_inline_modifier] = STATE(2284),
    [sym__indentable_expression] = STATE(11850),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1057),
    [sym_block_comment] = STATE(1057),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1058] = {
    [sym_inline_modifier] = STATE(2317),
    [sym__indentable_expression] = STATE(13921),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1058),
    [sym_block_comment] = STATE(1058),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1059] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17614),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(773),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1059),
    [sym_block_comment] = STATE(1059),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1060] = {
    [sym_inline_modifier] = STATE(2322),
    [sym__indentable_expression] = STATE(13599),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1060),
    [sym_block_comment] = STATE(1060),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1061] = {
    [sym_inline_modifier] = STATE(2284),
    [sym__indentable_expression] = STATE(11852),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1061),
    [sym_block_comment] = STATE(1061),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1062] = {
    [sym_inline_modifier] = STATE(2334),
    [sym__indentable_expression] = STATE(14163),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1062),
    [sym_block_comment] = STATE(1062),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1063] = {
    [sym_inline_modifier] = STATE(2284),
    [sym__indentable_expression] = STATE(11901),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1063),
    [sym_block_comment] = STATE(1063),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1064] = {
    [sym_inline_modifier] = STATE(2334),
    [sym__indentable_expression] = STATE(14093),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1064),
    [sym_block_comment] = STATE(1064),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1065] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17869),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(788),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1065),
    [sym_block_comment] = STATE(1065),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1066] = {
    [sym_inline_modifier] = STATE(2294),
    [sym__indentable_expression] = STATE(13942),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1066),
    [sym_block_comment] = STATE(1066),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1067] = {
    [sym_inline_modifier] = STATE(2284),
    [sym__indentable_expression] = STATE(12022),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1067),
    [sym_block_comment] = STATE(1067),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1068] = {
    [sym_inline_modifier] = STATE(2335),
    [sym__indentable_expression] = STATE(13966),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1068),
    [sym_block_comment] = STATE(1068),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(2468),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1069] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(14248),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1069),
    [sym_block_comment] = STATE(1069),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1070] = {
    [sym_inline_modifier] = STATE(2335),
    [sym__indentable_expression] = STATE(13967),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1070),
    [sym_block_comment] = STATE(1070),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(2468),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1071] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16264),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(798),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1071),
    [sym_block_comment] = STATE(1071),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1072] = {
    [sym_inline_modifier] = STATE(2325),
    [sym__indentable_expression] = STATE(12853),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1072),
    [sym_block_comment] = STATE(1072),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1073] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(14366),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1073),
    [sym_block_comment] = STATE(1073),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1074] = {
    [sym_inline_modifier] = STATE(2336),
    [sym__indentable_expression] = STATE(13640),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1074),
    [sym_block_comment] = STATE(1074),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2100),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1075] = {
    [sym_inline_modifier] = STATE(2288),
    [sym__indentable_expression] = STATE(13603),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1075),
    [sym_block_comment] = STATE(1075),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1076] = {
    [sym_inline_modifier] = STATE(2336),
    [sym__indentable_expression] = STATE(13741),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1076),
    [sym_block_comment] = STATE(1076),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2100),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1077] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16393),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(799),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1077),
    [sym_block_comment] = STATE(1077),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1078] = {
    [sym_inline_modifier] = STATE(2300),
    [sym__indentable_expression] = STATE(13258),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1078),
    [sym_block_comment] = STATE(1078),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1079] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(12868),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1079),
    [sym_block_comment] = STATE(1079),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1080] = {
    [sym_inline_modifier] = STATE(2337),
    [sym__indentable_expression] = STATE(13164),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1080),
    [sym_block_comment] = STATE(1080),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1081] = {
    [sym_inline_modifier] = STATE(2288),
    [sym__indentable_expression] = STATE(13457),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1081),
    [sym_block_comment] = STATE(1081),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1082] = {
    [sym_inline_modifier] = STATE(2337),
    [sym__indentable_expression] = STATE(13165),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1082),
    [sym_block_comment] = STATE(1082),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1083] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16531),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(800),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1083),
    [sym_block_comment] = STATE(1083),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1084] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(13275),
    [sym_block] = STATE(9158),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(13329),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1084),
    [sym_block_comment] = STATE(1084),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [1085] = {
    [sym_inline_modifier] = STATE(2288),
    [sym__indentable_expression] = STATE(13602),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1085),
    [sym_block_comment] = STATE(1085),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1086] = {
    [sym_inline_modifier] = STATE(2322),
    [sym__indentable_expression] = STATE(13972),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1086),
    [sym_block_comment] = STATE(1086),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1087] = {
    [sym_inline_modifier] = STATE(2288),
    [sym__indentable_expression] = STATE(13618),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1087),
    [sym_block_comment] = STATE(1087),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1088] = {
    [sym_inline_modifier] = STATE(2322),
    [sym__indentable_expression] = STATE(13973),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1088),
    [sym_block_comment] = STATE(1088),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1089] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16636),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(801),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1089),
    [sym_block_comment] = STATE(1089),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1090] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(13106),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1090),
    [sym_block_comment] = STATE(1090),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1091] = {
    [sym_inline_modifier] = STATE(2288),
    [sym__indentable_expression] = STATE(13519),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1091),
    [sym_block_comment] = STATE(1091),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1092] = {
    [sym_inline_modifier] = STATE(2339),
    [sym__indentable_expression] = STATE(14009),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1092),
    [sym_block_comment] = STATE(1092),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1093] = {
    [sym_inline_modifier] = STATE(2288),
    [sym__indentable_expression] = STATE(13569),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1093),
    [sym_block_comment] = STATE(1093),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1094] = {
    [sym_inline_modifier] = STATE(2339),
    [sym__indentable_expression] = STATE(14164),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1094),
    [sym_block_comment] = STATE(1094),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1095] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16725),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(802),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1095),
    [sym_block_comment] = STATE(1095),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1096] = {
    [sym_inline_modifier] = STATE(2329),
    [sym__indentable_expression] = STATE(12756),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1096),
    [sym_block_comment] = STATE(1096),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1097] = {
    [sym_inline_modifier] = STATE(2325),
    [sym__indentable_expression] = STATE(13474),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1097),
    [sym_block_comment] = STATE(1097),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1098] = {
    [sym_inline_modifier] = STATE(2288),
    [sym__indentable_expression] = STATE(13444),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1098),
    [sym_block_comment] = STATE(1098),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1099] = {
    [sym_inline_modifier] = STATE(2325),
    [sym__indentable_expression] = STATE(13529),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1099),
    [sym_block_comment] = STATE(1099),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1100] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16819),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(803),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1100),
    [sym_block_comment] = STATE(1100),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1101] = {
    [sym_inline_modifier] = STATE(2337),
    [sym__indentable_expression] = STATE(12408),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1101),
    [sym_block_comment] = STATE(1101),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1102] = {
    [sym_inline_modifier] = STATE(2288),
    [sym__indentable_expression] = STATE(13601),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1102),
    [sym_block_comment] = STATE(1102),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1103] = {
    [sym_inline_modifier] = STATE(2340),
    [sym__indentable_expression] = STATE(13677),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1103),
    [sym_block_comment] = STATE(1103),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1104] = {
    [sym_inline_modifier] = STATE(2288),
    [sym__indentable_expression] = STATE(13469),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1104),
    [sym_block_comment] = STATE(1104),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1105] = {
    [sym_inline_modifier] = STATE(2340),
    [sym__indentable_expression] = STATE(13698),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1105),
    [sym_block_comment] = STATE(1105),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1106] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16920),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(804),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1106),
    [sym_block_comment] = STATE(1106),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1107] = {
    [sym_inline_modifier] = STATE(2312),
    [sym__indentable_expression] = STATE(12669),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1107),
    [sym_block_comment] = STATE(1107),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1108] = {
    [sym_inline_modifier] = STATE(2288),
    [sym__indentable_expression] = STATE(13328),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1108),
    [sym_block_comment] = STATE(1108),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1109] = {
    [sym_inline_modifier] = STATE(2327),
    [sym__indentable_expression] = STATE(13885),
    [sym_block] = STATE(9357),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(13735),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1109),
    [sym_block_comment] = STATE(1109),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1110] = {
    [sym_inline_modifier] = STATE(2329),
    [sym__indentable_expression] = STATE(11953),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1110),
    [sym_block_comment] = STATE(1110),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1111] = {
    [sym_inline_modifier] = STATE(2327),
    [sym__indentable_expression] = STATE(13916),
    [sym_block] = STATE(9357),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(13735),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1111),
    [sym_block_comment] = STATE(1111),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1112] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17072),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(805),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1112),
    [sym_block_comment] = STATE(1112),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1113] = {
    [sym_inline_modifier] = STATE(2314),
    [sym__indentable_expression] = STATE(12678),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1113),
    [sym_block_comment] = STATE(1113),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1114] = {
    [sym_inline_modifier] = STATE(2332),
    [sym__indentable_expression] = STATE(11985),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1114),
    [sym_block_comment] = STATE(1114),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1115] = {
    [sym_inline_modifier] = STATE(2341),
    [sym__indentable_expression] = STATE(13574),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1115),
    [sym_block_comment] = STATE(1115),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1116] = {
    [sym_inline_modifier] = STATE(2341),
    [sym__indentable_expression] = STATE(13586),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1116),
    [sym_block_comment] = STATE(1116),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1117] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17177),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(723),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1117),
    [sym_block_comment] = STATE(1117),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1118] = {
    [sym_inline_modifier] = STATE(2317),
    [sym__indentable_expression] = STATE(13479),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1118),
    [sym_block_comment] = STATE(1118),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1119] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(13925),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1119),
    [sym_block_comment] = STATE(1119),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1120] = {
    [sym_inline_modifier] = STATE(2343),
    [sym__indentable_expression] = STATE(13231),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1120),
    [sym_block_comment] = STATE(1120),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1121] = {
    [sym_inline_modifier] = STATE(2343),
    [sym__indentable_expression] = STATE(13233),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1121),
    [sym_block_comment] = STATE(1121),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1122] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17283),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(632),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1122),
    [sym_block_comment] = STATE(1122),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1123] = {
    [sym_inline_modifier] = STATE(2341),
    [sym__indentable_expression] = STATE(12951),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1123),
    [sym_block_comment] = STATE(1123),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1124] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(12913),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1124),
    [sym_block_comment] = STATE(1124),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1125] = {
    [sym_inline_modifier] = STATE(2330),
    [sym__indentable_expression] = STATE(13799),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1125),
    [sym_block_comment] = STATE(1125),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2392),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1126] = {
    [sym_inline_modifier] = STATE(2330),
    [sym__indentable_expression] = STATE(13800),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1126),
    [sym_block_comment] = STATE(1126),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2392),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1127] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17394),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(633),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1127),
    [sym_block_comment] = STATE(1127),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1128] = {
    [sym_inline_modifier] = STATE(2343),
    [sym__indentable_expression] = STATE(12401),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1128),
    [sym_block_comment] = STATE(1128),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1129] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(13958),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1129),
    [sym_block_comment] = STATE(1129),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1130] = {
    [sym_inline_modifier] = STATE(2332),
    [sym__indentable_expression] = STATE(13772),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1130),
    [sym_block_comment] = STATE(1130),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1131] = {
    [sym_inline_modifier] = STATE(2332),
    [sym__indentable_expression] = STATE(13773),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1131),
    [sym_block_comment] = STATE(1131),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1132] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17493),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(634),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1132),
    [sym_block_comment] = STATE(1132),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1133] = {
    [sym_inline_modifier] = STATE(2337),
    [sym__indentable_expression] = STATE(12621),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1133),
    [sym_block_comment] = STATE(1133),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1134] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(13960),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1134),
    [sym_block_comment] = STATE(1134),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1135] = {
    [sym_inline_modifier] = STATE(2333),
    [sym__indentable_expression] = STATE(13815),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1135),
    [sym_block_comment] = STATE(1135),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1136] = {
    [sym_inline_modifier] = STATE(2333),
    [sym__indentable_expression] = STATE(13829),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1136),
    [sym_block_comment] = STATE(1136),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1137] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17589),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(635),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1137),
    [sym_block_comment] = STATE(1137),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1138] = {
    [sym_inline_modifier] = STATE(2321),
    [sym__indentable_expression] = STATE(13010),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1138),
    [sym_block_comment] = STATE(1138),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1139] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(13962),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1139),
    [sym_block_comment] = STATE(1139),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1140] = {
    [sym_inline_modifier] = STATE(2334),
    [sym__indentable_expression] = STATE(14018),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1140),
    [sym_block_comment] = STATE(1140),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1141] = {
    [sym_inline_modifier] = STATE(2334),
    [sym__indentable_expression] = STATE(14019),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1141),
    [sym_block_comment] = STATE(1141),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1142] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17687),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(637),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1142),
    [sym_block_comment] = STATE(1142),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1143] = {
    [sym_inline_modifier] = STATE(2322),
    [sym__indentable_expression] = STATE(13605),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1143),
    [sym_block_comment] = STATE(1143),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1144] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(13975),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1144),
    [sym_block_comment] = STATE(1144),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1145] = {
    [sym_inline_modifier] = STATE(2335),
    [sym__indentable_expression] = STATE(13922),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1145),
    [sym_block_comment] = STATE(1145),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(2468),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1146] = {
    [sym_inline_modifier] = STATE(2335),
    [sym__indentable_expression] = STATE(13923),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1146),
    [sym_block_comment] = STATE(1146),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(2468),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1147] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17822),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(638),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1147),
    [sym_block_comment] = STATE(1147),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1148] = {
    [sym_inline_modifier] = STATE(2325),
    [sym__indentable_expression] = STATE(12993),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1148),
    [sym_block_comment] = STATE(1148),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1149] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(13991),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1149),
    [sym_block_comment] = STATE(1149),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1150] = {
    [sym_inline_modifier] = STATE(2336),
    [sym__indentable_expression] = STATE(13822),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1150),
    [sym_block_comment] = STATE(1150),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2100),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1151] = {
    [sym_inline_modifier] = STATE(2336),
    [sym__indentable_expression] = STATE(13824),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1151),
    [sym_block_comment] = STATE(1151),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2100),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1152] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17862),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(639),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1152),
    [sym_block_comment] = STATE(1152),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1153] = {
    [sym_inline_modifier] = STATE(2341),
    [sym__indentable_expression] = STATE(12708),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1153),
    [sym_block_comment] = STATE(1153),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1154] = {
    [sym_inline_modifier] = STATE(2337),
    [sym__indentable_expression] = STATE(13171),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1154),
    [sym_block_comment] = STATE(1154),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1155] = {
    [sym_inline_modifier] = STATE(2337),
    [sym__indentable_expression] = STATE(13172),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1155),
    [sym_block_comment] = STATE(1155),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1156] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16648),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(642),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1156),
    [sym_block_comment] = STATE(1156),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1157] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(13203),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1157),
    [sym_block_comment] = STATE(1157),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1158] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(13998),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1158),
    [sym_block_comment] = STATE(1158),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1159] = {
    [sym_inline_modifier] = STATE(2345),
    [sym__indentable_expression] = STATE(13341),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1159),
    [sym_block_comment] = STATE(1159),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1160] = {
    [sym_inline_modifier] = STATE(2345),
    [sym__indentable_expression] = STATE(13342),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1160),
    [sym_block_comment] = STATE(1160),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1161] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16882),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(643),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1161),
    [sym_block_comment] = STATE(1161),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1162] = {
    [sym_inline_modifier] = STATE(2343),
    [sym__indentable_expression] = STATE(12174),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1162),
    [sym_block_comment] = STATE(1162),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1163] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(13999),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1163),
    [sym_block_comment] = STATE(1163),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1164] = {
    [sym_inline_modifier] = STATE(2339),
    [sym__indentable_expression] = STATE(14094),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1164),
    [sym_block_comment] = STATE(1164),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1165] = {
    [sym_inline_modifier] = STATE(2339),
    [sym__indentable_expression] = STATE(14095),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1165),
    [sym_block_comment] = STATE(1165),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1166] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17294),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(645),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1166),
    [sym_block_comment] = STATE(1166),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1167] = {
    [sym_inline_modifier] = STATE(2329),
    [sym__indentable_expression] = STATE(12685),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1167),
    [sym_block_comment] = STATE(1167),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1168] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(14001),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1168),
    [sym_block_comment] = STATE(1168),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1169] = {
    [sym_inline_modifier] = STATE(2340),
    [sym__indentable_expression] = STATE(13638),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1169),
    [sym_block_comment] = STATE(1169),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1170] = {
    [sym_inline_modifier] = STATE(2340),
    [sym__indentable_expression] = STATE(13648),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1170),
    [sym_block_comment] = STATE(1170),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1171] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17105),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(646),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1171),
    [sym_block_comment] = STATE(1171),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1172] = {
    [sym_inline_modifier] = STATE(2337),
    [sym__indentable_expression] = STATE(12314),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1172),
    [sym_block_comment] = STATE(1172),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1173] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(14003),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1173),
    [sym_block_comment] = STATE(1173),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1174] = {
    [sym_inline_modifier] = STATE(2341),
    [sym__indentable_expression] = STATE(13360),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1174),
    [sym_block_comment] = STATE(1174),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1175] = {
    [sym_inline_modifier] = STATE(2341),
    [sym__indentable_expression] = STATE(13361),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1175),
    [sym_block_comment] = STATE(1175),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1176] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16254),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(647),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1176),
    [sym_block_comment] = STATE(1176),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1177] = {
    [sym_inline_modifier] = STATE(2341),
    [sym__indentable_expression] = STATE(12768),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1177),
    [sym_block_comment] = STATE(1177),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1178] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(12769),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1178),
    [sym_block_comment] = STATE(1178),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1179] = {
    [sym_inline_modifier] = STATE(2346),
    [sym__indentable_expression] = STATE(13770),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1179),
    [sym_block_comment] = STATE(1179),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1180] = {
    [sym_inline_modifier] = STATE(2346),
    [sym__indentable_expression] = STATE(13771),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1180),
    [sym_block_comment] = STATE(1180),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1181] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16923),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(649),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1181),
    [sym_block_comment] = STATE(1181),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1182] = {
    [sym_inline_modifier] = STATE(2343),
    [sym__indentable_expression] = STATE(12344),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1182),
    [sym_block_comment] = STATE(1182),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1183] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(12777),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1183),
    [sym_block_comment] = STATE(1183),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1184] = {
    [sym_inline_modifier] = STATE(2343),
    [sym__indentable_expression] = STATE(13245),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1184),
    [sym_block_comment] = STATE(1184),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1185] = {
    [sym_inline_modifier] = STATE(2343),
    [sym__indentable_expression] = STATE(13247),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1185),
    [sym_block_comment] = STATE(1185),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1186] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17657),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(650),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1186),
    [sym_block_comment] = STATE(1186),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1187] = {
    [sym_inline_modifier] = STATE(2290),
    [sym__indentable_expression] = STATE(12580),
    [sym_block] = STATE(10014),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(13944),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1187),
    [sym_block_comment] = STATE(1187),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2184),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [1188] = {
    [sym_inline_modifier] = STATE(2054),
    [sym__indentable_expression] = STATE(13502),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1188),
    [sym_block_comment] = STATE(1188),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1189] = {
    [sym_inline_modifier] = STATE(2054),
    [sym__indentable_expression] = STATE(13505),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1189),
    [sym_block_comment] = STATE(1189),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1190] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16355),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(651),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1190),
    [sym_block_comment] = STATE(1190),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1191] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(14359),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1191),
    [sym_block_comment] = STATE(1191),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1192] = {
    [sym_inline_modifier] = STATE(2345),
    [sym__indentable_expression] = STATE(13345),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1192),
    [sym_block_comment] = STATE(1192),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1193] = {
    [sym_inline_modifier] = STATE(2345),
    [sym__indentable_expression] = STATE(13346),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1193),
    [sym_block_comment] = STATE(1193),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1194] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16227),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(652),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1194),
    [sym_block_comment] = STATE(1194),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1195] = {
    [sym_inline_modifier] = STATE(2290),
    [sym__indentable_expression] = STATE(12594),
    [sym_block] = STATE(10014),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(13944),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1195),
    [sym_block_comment] = STATE(1195),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2184),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [1196] = {
    [sym_inline_modifier] = STATE(2346),
    [sym__indentable_expression] = STATE(13775),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1196),
    [sym_block_comment] = STATE(1196),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1197] = {
    [sym_inline_modifier] = STATE(2346),
    [sym__indentable_expression] = STATE(13776),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1197),
    [sym_block_comment] = STATE(1197),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1198] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17204),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(653),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1198),
    [sym_block_comment] = STATE(1198),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1199] = {
    [sym_inline_modifier] = STATE(2290),
    [sym__indentable_expression] = STATE(12595),
    [sym_block] = STATE(10014),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(13944),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1199),
    [sym_block_comment] = STATE(1199),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2184),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [1200] = {
    [sym_inline_modifier] = STATE(2054),
    [sym__indentable_expression] = STATE(13506),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1200),
    [sym_block_comment] = STATE(1200),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1201] = {
    [sym_inline_modifier] = STATE(2054),
    [sym__indentable_expression] = STATE(13508),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1201),
    [sym_block_comment] = STATE(1201),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1202] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(17658),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(654),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1202),
    [sym_block_comment] = STATE(1202),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1203] = {
    [sym_inline_modifier] = STATE(2290),
    [sym__indentable_expression] = STATE(12599),
    [sym_block] = STATE(10014),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(13944),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1203),
    [sym_block_comment] = STATE(1203),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2184),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [1204] = {
    [sym_inline_modifier] = STATE(2290),
    [sym__indentable_expression] = STATE(12603),
    [sym_block] = STATE(10014),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(13944),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1204),
    [sym_block_comment] = STATE(1204),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2184),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [1205] = {
    [sym_inline_modifier] = STATE(2290),
    [sym__indentable_expression] = STATE(12617),
    [sym_block] = STATE(10014),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(13944),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1205),
    [sym_block_comment] = STATE(1205),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2184),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [1206] = {
    [sym_inline_modifier] = STATE(2290),
    [sym__indentable_expression] = STATE(12623),
    [sym_block] = STATE(10014),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(13944),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1206),
    [sym_block_comment] = STATE(1206),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2184),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [1207] = {
    [sym_inline_modifier] = STATE(2290),
    [sym__indentable_expression] = STATE(12624),
    [sym_block] = STATE(10014),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(13944),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1207),
    [sym_block_comment] = STATE(1207),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2184),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [1208] = {
    [sym_inline_modifier] = STATE(2290),
    [sym__indentable_expression] = STATE(12626),
    [sym_block] = STATE(10014),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(13944),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1208),
    [sym_block_comment] = STATE(1208),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2184),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [1209] = {
    [sym_inline_modifier] = STATE(2290),
    [sym__indentable_expression] = STATE(12631),
    [sym_block] = STATE(10014),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(13944),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1209),
    [sym_block_comment] = STATE(1209),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2184),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [1210] = {
    [sym_inline_modifier] = STATE(2292),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(13170),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1210),
    [sym_block_comment] = STATE(1210),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_catch] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1156),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1211] = {
    [sym_inline_modifier] = STATE(2292),
    [sym__indentable_expression] = STATE(13603),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1211),
    [sym_block_comment] = STATE(1211),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1212] = {
    [sym_inline_modifier] = STATE(2292),
    [sym__indentable_expression] = STATE(13457),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1212),
    [sym_block_comment] = STATE(1212),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1213] = {
    [sym_inline_modifier] = STATE(2292),
    [sym__indentable_expression] = STATE(13602),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1213),
    [sym_block_comment] = STATE(1213),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1214] = {
    [sym_inline_modifier] = STATE(2292),
    [sym__indentable_expression] = STATE(13618),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1214),
    [sym_block_comment] = STATE(1214),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1215] = {
    [sym_inline_modifier] = STATE(2292),
    [sym__indentable_expression] = STATE(13519),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1215),
    [sym_block_comment] = STATE(1215),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1216] = {
    [sym_inline_modifier] = STATE(2292),
    [sym__indentable_expression] = STATE(13569),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1216),
    [sym_block_comment] = STATE(1216),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1217] = {
    [sym_inline_modifier] = STATE(2292),
    [sym__indentable_expression] = STATE(13444),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1217),
    [sym_block_comment] = STATE(1217),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1218] = {
    [sym_inline_modifier] = STATE(2292),
    [sym__indentable_expression] = STATE(13601),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1218),
    [sym_block_comment] = STATE(1218),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1219] = {
    [sym_inline_modifier] = STATE(2292),
    [sym__indentable_expression] = STATE(13469),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1219),
    [sym_block_comment] = STATE(1219),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1220] = {
    [sym_inline_modifier] = STATE(2292),
    [sym__indentable_expression] = STATE(13328),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1220),
    [sym_block_comment] = STATE(1220),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1221] = {
    [sym_inline_modifier] = STATE(2294),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(13170),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1221),
    [sym_block_comment] = STATE(1221),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(1156),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_catch] = ACTIONS(1156),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1222] = {
    [sym_inline_modifier] = STATE(2332),
    [sym__indentable_expression] = STATE(11996),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1222),
    [sym_block_comment] = STATE(1222),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1223] = {
    [sym_inline_modifier] = STATE(2294),
    [sym__indentable_expression] = STATE(13603),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1223),
    [sym_block_comment] = STATE(1223),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1224] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(14363),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1224),
    [sym_block_comment] = STATE(1224),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1225] = {
    [sym_inline_modifier] = STATE(2294),
    [sym__indentable_expression] = STATE(13457),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1225),
    [sym_block_comment] = STATE(1225),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1226] = {
    [sym_inline_modifier] = STATE(2294),
    [sym__indentable_expression] = STATE(13602),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1226),
    [sym_block_comment] = STATE(1226),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1227] = {
    [sym_inline_modifier] = STATE(2294),
    [sym__indentable_expression] = STATE(13618),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1227),
    [sym_block_comment] = STATE(1227),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1228] = {
    [sym_inline_modifier] = STATE(2294),
    [sym__indentable_expression] = STATE(13519),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1228),
    [sym_block_comment] = STATE(1228),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1229] = {
    [sym_inline_modifier] = STATE(2294),
    [sym__indentable_expression] = STATE(13569),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1229),
    [sym_block_comment] = STATE(1229),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1230] = {
    [sym_inline_modifier] = STATE(2294),
    [sym__indentable_expression] = STATE(13444),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1230),
    [sym_block_comment] = STATE(1230),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1231] = {
    [sym_inline_modifier] = STATE(2294),
    [sym__indentable_expression] = STATE(13601),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1231),
    [sym_block_comment] = STATE(1231),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1232] = {
    [sym_inline_modifier] = STATE(2294),
    [sym__indentable_expression] = STATE(13469),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1232),
    [sym_block_comment] = STATE(1232),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1233] = {
    [sym_inline_modifier] = STATE(2294),
    [sym__indentable_expression] = STATE(13328),
    [sym_block] = STATE(8222),
    [sym_indented_block] = STATE(13557),
    [sym_indented_cases] = STATE(13557),
    [sym_expression] = STATE(13140),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1233),
    [sym_block_comment] = STATE(1233),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2158),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1234] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(14366),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1234),
    [sym_block_comment] = STATE(1234),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1235] = {
    [sym_inline_modifier] = STATE(2332),
    [sym__indentable_expression] = STATE(11998),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1235),
    [sym_block_comment] = STATE(1235),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1236] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(12986),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1236),
    [sym_block_comment] = STATE(1236),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1237] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(12799),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1237),
    [sym_block_comment] = STATE(1237),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1238] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(12868),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1238),
    [sym_block_comment] = STATE(1238),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1239] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(12913),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1239),
    [sym_block_comment] = STATE(1239),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1240] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(12928),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1240),
    [sym_block_comment] = STATE(1240),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1241] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(12948),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1241),
    [sym_block_comment] = STATE(1241),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1242] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(12819),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1242),
    [sym_block_comment] = STATE(1242),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1243] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(12769),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1243),
    [sym_block_comment] = STATE(1243),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1244] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(12777),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1244),
    [sym_block_comment] = STATE(1244),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1245] = {
    [sym_inline_modifier] = STATE(2332),
    [sym__indentable_expression] = STATE(11999),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1245),
    [sym_block_comment] = STATE(1245),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1246] = {
    [sym_inline_modifier] = STATE(2311),
    [sym__indentable_expression] = STATE(12952),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1246),
    [sym_block_comment] = STATE(1246),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1247] = {
    [sym_inline_modifier] = STATE(2332),
    [sym__indentable_expression] = STATE(12002),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1247),
    [sym_block_comment] = STATE(1247),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1248] = {
    [sym_inline_modifier] = STATE(2296),
    [sym__indentable_expression] = STATE(12580),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1248),
    [sym_block_comment] = STATE(1248),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1249] = {
    [sym_inline_modifier] = STATE(2296),
    [sym__indentable_expression] = STATE(12594),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1249),
    [sym_block_comment] = STATE(1249),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1250] = {
    [sym_inline_modifier] = STATE(2296),
    [sym__indentable_expression] = STATE(12595),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1250),
    [sym_block_comment] = STATE(1250),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1251] = {
    [sym_inline_modifier] = STATE(2296),
    [sym__indentable_expression] = STATE(12599),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1251),
    [sym_block_comment] = STATE(1251),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1252] = {
    [sym_inline_modifier] = STATE(2296),
    [sym__indentable_expression] = STATE(12603),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1252),
    [sym_block_comment] = STATE(1252),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1253] = {
    [sym_inline_modifier] = STATE(2296),
    [sym__indentable_expression] = STATE(12617),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1253),
    [sym_block_comment] = STATE(1253),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1254] = {
    [sym_inline_modifier] = STATE(2296),
    [sym__indentable_expression] = STATE(12623),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1254),
    [sym_block_comment] = STATE(1254),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1255] = {
    [sym_inline_modifier] = STATE(2296),
    [sym__indentable_expression] = STATE(12624),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1255),
    [sym_block_comment] = STATE(1255),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1256] = {
    [sym_inline_modifier] = STATE(2296),
    [sym__indentable_expression] = STATE(12626),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1256),
    [sym_block_comment] = STATE(1256),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1257] = {
    [sym_inline_modifier] = STATE(2332),
    [sym__indentable_expression] = STATE(12019),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1257),
    [sym_block_comment] = STATE(1257),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1258] = {
    [sym_inline_modifier] = STATE(2278),
    [sym__indentable_expression] = STATE(13482),
    [sym_block] = STATE(9584),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(13653),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1258),
    [sym_block_comment] = STATE(1258),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [1259] = {
    [sym_inline_modifier] = STATE(2296),
    [sym__indentable_expression] = STATE(12631),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1259),
    [sym_block_comment] = STATE(1259),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1260] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(14379),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1260),
    [sym_block_comment] = STATE(1260),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1261] = {
    [sym_inline_modifier] = STATE(2298),
    [sym__indentable_expression] = STATE(13367),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1261),
    [sym_block_comment] = STATE(1261),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(2066),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1262] = {
    [sym_inline_modifier] = STATE(2332),
    [sym__indentable_expression] = STATE(12028),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1262),
    [sym_block_comment] = STATE(1262),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1263] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(14278),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1263),
    [sym_block_comment] = STATE(1263),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1264] = {
    [sym_inline_modifier] = STATE(2298),
    [sym__indentable_expression] = STATE(13524),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1264),
    [sym_block_comment] = STATE(1264),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(2066),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1265] = {
    [sym_inline_modifier] = STATE(2298),
    [sym__indentable_expression] = STATE(13426),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1265),
    [sym_block_comment] = STATE(1265),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(2066),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1266] = {
    [sym_inline_modifier] = STATE(2298),
    [sym__indentable_expression] = STATE(13326),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1266),
    [sym_block_comment] = STATE(1266),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(2066),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1267] = {
    [sym_inline_modifier] = STATE(2298),
    [sym__indentable_expression] = STATE(13477),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1267),
    [sym_block_comment] = STATE(1267),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(2066),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1268] = {
    [sym_inline_modifier] = STATE(2284),
    [sym__indentable_expression] = STATE(13181),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1268),
    [sym_block_comment] = STATE(1268),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1269] = {
    [sym_inline_modifier] = STATE(2296),
    [sym__indentable_expression] = STATE(13946),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1269),
    [sym_block_comment] = STATE(1269),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1270] = {
    [sym_inline_modifier] = STATE(2296),
    [sym__indentable_expression] = STATE(13953),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1270),
    [sym_block_comment] = STATE(1270),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1271] = {
    [sym_inline_modifier] = STATE(2332),
    [sym__indentable_expression] = STATE(12029),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1271),
    [sym_block_comment] = STATE(1271),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1272] = {
    [sym_inline_modifier] = STATE(2278),
    [sym__indentable_expression] = STATE(13585),
    [sym_block] = STATE(9584),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(13653),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1272),
    [sym_block_comment] = STATE(1272),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [1273] = {
    [sym_inline_modifier] = STATE(2298),
    [sym__indentable_expression] = STATE(13534),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1273),
    [sym_block_comment] = STATE(1273),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(2066),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1274] = {
    [sym_inline_modifier] = STATE(2298),
    [sym__indentable_expression] = STATE(13451),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1274),
    [sym_block_comment] = STATE(1274),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(2066),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1275] = {
    [sym_inline_modifier] = STATE(2332),
    [sym__indentable_expression] = STATE(12031),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1275),
    [sym_block_comment] = STATE(1275),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1276] = {
    [sym_inline_modifier] = STATE(2298),
    [sym__indentable_expression] = STATE(13563),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1276),
    [sym_block_comment] = STATE(1276),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(2066),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1277] = {
    [sym_inline_modifier] = STATE(2298),
    [sym__indentable_expression] = STATE(13337),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1277),
    [sym_block_comment] = STATE(1277),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(2066),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1278] = {
    [sym_inline_modifier] = STATE(2284),
    [sym__indentable_expression] = STATE(13121),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1278),
    [sym_block_comment] = STATE(1278),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1279] = {
    [sym_inline_modifier] = STATE(2332),
    [sym__indentable_expression] = STATE(12035),
    [sym_block] = STATE(6188),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(11891),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1279),
    [sym_block_comment] = STATE(1279),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1280] = {
    [sym_inline_modifier] = STATE(2298),
    [sym__indentable_expression] = STATE(13357),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1280),
    [sym_block_comment] = STATE(1280),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(2066),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1281] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(12952),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1281),
    [sym_block_comment] = STATE(1281),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1282] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(12799),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1282),
    [sym_block_comment] = STATE(1282),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1283] = {
    [sym_inline_modifier] = STATE(2300),
    [sym__indentable_expression] = STATE(13331),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1283),
    [sym_block_comment] = STATE(1283),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1284] = {
    [sym_inline_modifier] = STATE(2284),
    [sym__indentable_expression] = STATE(13225),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1284),
    [sym_block_comment] = STATE(1284),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1285] = {
    [sym_inline_modifier] = STATE(2333),
    [sym__indentable_expression] = STATE(13055),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1285),
    [sym_block_comment] = STATE(1285),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1286] = {
    [sym_inline_modifier] = STATE(2300),
    [sym__indentable_expression] = STATE(13523),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1286),
    [sym_block_comment] = STATE(1286),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1287] = {
    [sym_inline_modifier] = STATE(2300),
    [sym__indentable_expression] = STATE(13596),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1287),
    [sym_block_comment] = STATE(1287),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1288] = {
    [sym_inline_modifier] = STATE(2300),
    [sym__indentable_expression] = STATE(13620),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1288),
    [sym_block_comment] = STATE(1288),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1289] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(14379),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1289),
    [sym_block_comment] = STATE(1289),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1290] = {
    [sym_inline_modifier] = STATE(2300),
    [sym__indentable_expression] = STATE(13364),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1290),
    [sym_block_comment] = STATE(1290),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1291] = {
    [sym_inline_modifier] = STATE(2300),
    [sym__indentable_expression] = STATE(13493),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1291),
    [sym_block_comment] = STATE(1291),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1292] = {
    [sym_inline_modifier] = STATE(2333),
    [sym__indentable_expression] = STATE(13080),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1292),
    [sym_block_comment] = STATE(1292),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1293] = {
    [sym_inline_modifier] = STATE(2300),
    [sym__indentable_expression] = STATE(13514),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1293),
    [sym_block_comment] = STATE(1293),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1294] = {
    [sym_inline_modifier] = STATE(2300),
    [sym__indentable_expression] = STATE(13517),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1294),
    [sym_block_comment] = STATE(1294),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1295] = {
    [sym_inline_modifier] = STATE(2333),
    [sym__indentable_expression] = STATE(13083),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1295),
    [sym_block_comment] = STATE(1295),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1296] = {
    [sym_inline_modifier] = STATE(2300),
    [sym__indentable_expression] = STATE(13532),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1296),
    [sym_block_comment] = STATE(1296),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1297] = {
    [sym_inline_modifier] = STATE(2300),
    [sym__indentable_expression] = STATE(13538),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1297),
    [sym_block_comment] = STATE(1297),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1298] = {
    [sym_inline_modifier] = STATE(2333),
    [sym__indentable_expression] = STATE(13085),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1298),
    [sym_block_comment] = STATE(1298),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1299] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(14225),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1299),
    [sym_block_comment] = STATE(1299),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1300] = {
    [sym_inline_modifier] = STATE(2333),
    [sym__indentable_expression] = STATE(13089),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1300),
    [sym_block_comment] = STATE(1300),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1301] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(11552),
    [sym_block] = STATE(9158),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(13329),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1301),
    [sym_block_comment] = STATE(1301),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [1302] = {
    [sym_inline_modifier] = STATE(2333),
    [sym__indentable_expression] = STATE(13110),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1302),
    [sym_block_comment] = STATE(1302),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1303] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(12928),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1303),
    [sym_block_comment] = STATE(1303),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1304] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(11557),
    [sym_block] = STATE(9158),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(13329),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1304),
    [sym_block_comment] = STATE(1304),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [1305] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(11459),
    [sym_block] = STATE(9158),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(13329),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1305),
    [sym_block_comment] = STATE(1305),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [1306] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(11561),
    [sym_block] = STATE(9158),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(13329),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1306),
    [sym_block_comment] = STATE(1306),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [1307] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(11563),
    [sym_block] = STATE(9158),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(13329),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1307),
    [sym_block_comment] = STATE(1307),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [1308] = {
    [sym_inline_modifier] = STATE(2333),
    [sym__indentable_expression] = STATE(13127),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1308),
    [sym_block_comment] = STATE(1308),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1309] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(11572),
    [sym_block] = STATE(9158),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(13329),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1309),
    [sym_block_comment] = STATE(1309),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [1310] = {
    [sym_inline_modifier] = STATE(2333),
    [sym__indentable_expression] = STATE(13129),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1310),
    [sym_block_comment] = STATE(1310),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1311] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(11573),
    [sym_block] = STATE(9158),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(13329),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1311),
    [sym_block_comment] = STATE(1311),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [1312] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(11575),
    [sym_block] = STATE(9158),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(13329),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1312),
    [sym_block_comment] = STATE(1312),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [1313] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(11578),
    [sym_block] = STATE(9158),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(13329),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1313),
    [sym_block_comment] = STATE(1313),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [1314] = {
    [sym_inline_modifier] = STATE(2333),
    [sym__indentable_expression] = STATE(13131),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1314),
    [sym_block_comment] = STATE(1314),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1315] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(11582),
    [sym_block] = STATE(9158),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(13329),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1315),
    [sym_block_comment] = STATE(1315),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [1316] = {
    [sym_inline_modifier] = STATE(2306),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(13291),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1316),
    [sym_block_comment] = STATE(1316),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(1156),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1317] = {
    [sym_inline_modifier] = STATE(2333),
    [sym__indentable_expression] = STATE(13135),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1317),
    [sym_block_comment] = STATE(1317),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1318] = {
    [sym_inline_modifier] = STATE(2329),
    [sym__indentable_expression] = STATE(12119),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1318),
    [sym_block_comment] = STATE(1318),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1319] = {
    [sym_inline_modifier] = STATE(2306),
    [sym__indentable_expression] = STATE(13367),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1319),
    [sym_block_comment] = STATE(1319),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1320] = {
    [sym_inline_modifier] = STATE(2329),
    [sym__indentable_expression] = STATE(12061),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1320),
    [sym_block_comment] = STATE(1320),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1321] = {
    [sym_inline_modifier] = STATE(2306),
    [sym__indentable_expression] = STATE(13524),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1321),
    [sym_block_comment] = STATE(1321),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1322] = {
    [sym_inline_modifier] = STATE(2306),
    [sym__indentable_expression] = STATE(13426),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1322),
    [sym_block_comment] = STATE(1322),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1323] = {
    [sym_inline_modifier] = STATE(2334),
    [sym__indentable_expression] = STATE(13055),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1323),
    [sym_block_comment] = STATE(1323),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1324] = {
    [sym_inline_modifier] = STATE(2306),
    [sym__indentable_expression] = STATE(13326),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1324),
    [sym_block_comment] = STATE(1324),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1325] = {
    [sym_inline_modifier] = STATE(2306),
    [sym__indentable_expression] = STATE(13477),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1325),
    [sym_block_comment] = STATE(1325),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1326] = {
    [sym_inline_modifier] = STATE(2306),
    [sym__indentable_expression] = STATE(13534),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1326),
    [sym_block_comment] = STATE(1326),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1327] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(16714),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(658),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1327),
    [sym_block_comment] = STATE(1327),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3282),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1328] = {
    [sym_inline_modifier] = STATE(2306),
    [sym__indentable_expression] = STATE(13451),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1328),
    [sym_block_comment] = STATE(1328),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1329] = {
    [sym_inline_modifier] = STATE(2334),
    [sym__indentable_expression] = STATE(13080),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1329),
    [sym_block_comment] = STATE(1329),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1330] = {
    [sym_inline_modifier] = STATE(2306),
    [sym__indentable_expression] = STATE(13563),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1330),
    [sym_block_comment] = STATE(1330),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1331] = {
    [sym_inline_modifier] = STATE(2306),
    [sym__indentable_expression] = STATE(13337),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1331),
    [sym_block_comment] = STATE(1331),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1332] = {
    [sym_inline_modifier] = STATE(2306),
    [sym__indentable_expression] = STATE(13357),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1332),
    [sym_block_comment] = STATE(1332),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1333] = {
    [sym_inline_modifier] = STATE(2334),
    [sym__indentable_expression] = STATE(13083),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1333),
    [sym_block_comment] = STATE(1333),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1334] = {
    [sym_inline_modifier] = STATE(2334),
    [sym__indentable_expression] = STATE(13085),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1334),
    [sym_block_comment] = STATE(1334),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1335] = {
    [sym_inline_modifier] = STATE(2334),
    [sym__indentable_expression] = STATE(13089),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1335),
    [sym_block_comment] = STATE(1335),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1336] = {
    [sym_inline_modifier] = STATE(2334),
    [sym__indentable_expression] = STATE(13110),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1336),
    [sym_block_comment] = STATE(1336),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1337] = {
    [sym_inline_modifier] = STATE(2308),
    [sym__indentable_expression] = STATE(12986),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6086),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16088),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5234),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8197),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1337),
    [sym_block_comment] = STATE(1337),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3095),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3083),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3087),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(3089),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(3091),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1338] = {
    [sym_inline_modifier] = STATE(2308),
    [sym__indentable_expression] = STATE(12868),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6086),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16088),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5234),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8197),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1338),
    [sym_block_comment] = STATE(1338),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3095),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3083),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3087),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(3089),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(3091),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1339] = {
    [sym_inline_modifier] = STATE(2334),
    [sym__indentable_expression] = STATE(13127),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1339),
    [sym_block_comment] = STATE(1339),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1340] = {
    [sym_inline_modifier] = STATE(2308),
    [sym__indentable_expression] = STATE(12913),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6086),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16088),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5234),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8197),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1340),
    [sym_block_comment] = STATE(1340),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3095),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3083),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3087),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(3089),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(3091),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1341] = {
    [sym_inline_modifier] = STATE(2308),
    [sym__indentable_expression] = STATE(12928),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6086),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16088),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5234),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8197),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1341),
    [sym_block_comment] = STATE(1341),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3095),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3083),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3087),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(3089),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(3091),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1342] = {
    [sym_inline_modifier] = STATE(2334),
    [sym__indentable_expression] = STATE(13129),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1342),
    [sym_block_comment] = STATE(1342),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1343] = {
    [sym_inline_modifier] = STATE(2308),
    [sym__indentable_expression] = STATE(12948),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6086),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16088),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5234),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8197),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1343),
    [sym_block_comment] = STATE(1343),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3095),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3083),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3087),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(3089),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(3091),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1344] = {
    [sym_inline_modifier] = STATE(2308),
    [sym__indentable_expression] = STATE(12819),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6086),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16088),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5234),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8197),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1344),
    [sym_block_comment] = STATE(1344),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3095),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3083),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3087),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(3089),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(3091),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1345] = {
    [sym_inline_modifier] = STATE(2334),
    [sym__indentable_expression] = STATE(13131),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1345),
    [sym_block_comment] = STATE(1345),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1346] = {
    [sym_inline_modifier] = STATE(2308),
    [sym__indentable_expression] = STATE(12769),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6086),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16088),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5234),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8197),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1346),
    [sym_block_comment] = STATE(1346),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3095),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3083),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3087),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(3089),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(3091),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1347] = {
    [sym_inline_modifier] = STATE(2308),
    [sym__indentable_expression] = STATE(12777),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6086),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16088),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5234),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8197),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1347),
    [sym_block_comment] = STATE(1347),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3095),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3083),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3087),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(3089),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(3091),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1348] = {
    [sym_inline_modifier] = STATE(2334),
    [sym__indentable_expression] = STATE(13135),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1348),
    [sym_block_comment] = STATE(1348),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1349] = {
    [sym_inline_modifier] = STATE(2308),
    [sym__indentable_expression] = STATE(12799),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6086),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16088),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5234),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8197),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1349),
    [sym_block_comment] = STATE(1349),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3095),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3083),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3087),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(3089),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(3091),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1350] = {
    [sym_inline_modifier] = STATE(2308),
    [sym__indentable_expression] = STATE(12952),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6086),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16088),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5234),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8197),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1350),
    [sym_block_comment] = STATE(1350),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3095),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3083),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3087),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(3089),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(3091),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1351] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(12952),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1351),
    [sym_block_comment] = STATE(1351),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1352] = {
    [sym_inline_modifier] = STATE(2329),
    [sym__indentable_expression] = STATE(12086),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1352),
    [sym_block_comment] = STATE(1352),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1353] = {
    [sym_inline_modifier] = STATE(2335),
    [sym__indentable_expression] = STATE(13715),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1353),
    [sym_block_comment] = STATE(1353),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(2468),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1354] = {
    [sym_inline_modifier] = STATE(2309),
    [sym__indentable_expression] = STATE(12418),
    [sym_block] = STATE(9961),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(14007),
    [sym__simple_expression] = STATE(6847),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15991),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(10631),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(10386),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5726),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(8783),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1354),
    [sym_block_comment] = STATE(1354),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(2278),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2282),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(2286),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_macro] = ACTIONS(2288),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(2290),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2294),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [1355] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(14225),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1355),
    [sym_block_comment] = STATE(1355),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1356] = {
    [sym_inline_modifier] = STATE(2309),
    [sym__indentable_expression] = STATE(12442),
    [sym_block] = STATE(9961),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(14007),
    [sym__simple_expression] = STATE(6847),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15991),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(10631),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(10386),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5726),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(8783),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1356),
    [sym_block_comment] = STATE(1356),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(2278),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2282),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(2286),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_macro] = ACTIONS(2288),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(2290),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2294),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [1357] = {
    [sym_inline_modifier] = STATE(2309),
    [sym__indentable_expression] = STATE(12443),
    [sym_block] = STATE(9961),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(14007),
    [sym__simple_expression] = STATE(6847),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15991),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(10631),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(10386),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5726),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(8783),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1357),
    [sym_block_comment] = STATE(1357),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(2278),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2282),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(2286),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_macro] = ACTIONS(2288),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(2290),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2294),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [1358] = {
    [sym_inline_modifier] = STATE(2335),
    [sym__indentable_expression] = STATE(13755),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1358),
    [sym_block_comment] = STATE(1358),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(2468),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1359] = {
    [sym_inline_modifier] = STATE(2309),
    [sym__indentable_expression] = STATE(12446),
    [sym_block] = STATE(9961),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(14007),
    [sym__simple_expression] = STATE(6847),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15991),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(10631),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(10386),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5726),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(8783),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1359),
    [sym_block_comment] = STATE(1359),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(2278),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2282),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(2286),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_macro] = ACTIONS(2288),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(2290),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2294),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [1360] = {
    [sym_inline_modifier] = STATE(2309),
    [sym__indentable_expression] = STATE(12449),
    [sym_block] = STATE(9961),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(14007),
    [sym__simple_expression] = STATE(6847),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15991),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(10631),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(10386),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5726),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(8783),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1360),
    [sym_block_comment] = STATE(1360),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(2278),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2282),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(2286),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_macro] = ACTIONS(2288),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(2290),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2294),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [1361] = {
    [sym_inline_modifier] = STATE(2335),
    [sym__indentable_expression] = STATE(13757),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1361),
    [sym_block_comment] = STATE(1361),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(2468),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1362] = {
    [sym_inline_modifier] = STATE(2309),
    [sym__indentable_expression] = STATE(12465),
    [sym_block] = STATE(9961),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(14007),
    [sym__simple_expression] = STATE(6847),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15991),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(10631),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(10386),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5726),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(8783),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1362),
    [sym_block_comment] = STATE(1362),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(2278),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2282),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(2286),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_macro] = ACTIONS(2288),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(2290),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2294),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [1363] = {
    [sym_inline_modifier] = STATE(2309),
    [sym__indentable_expression] = STATE(12472),
    [sym_block] = STATE(9961),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(14007),
    [sym__simple_expression] = STATE(6847),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15991),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(10631),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(10386),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5726),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(8783),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1363),
    [sym_block_comment] = STATE(1363),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(2278),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2282),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(2286),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_macro] = ACTIONS(2288),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(2290),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2294),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [1364] = {
    [sym_inline_modifier] = STATE(2335),
    [sym__indentable_expression] = STATE(13759),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1364),
    [sym_block_comment] = STATE(1364),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(2468),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1365] = {
    [sym_inline_modifier] = STATE(2309),
    [sym__indentable_expression] = STATE(12474),
    [sym_block] = STATE(9961),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(14007),
    [sym__simple_expression] = STATE(6847),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15991),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(10631),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(10386),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5726),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(8783),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1365),
    [sym_block_comment] = STATE(1365),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(2278),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2282),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(2286),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_macro] = ACTIONS(2288),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(2290),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2294),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [1366] = {
    [sym_inline_modifier] = STATE(2309),
    [sym__indentable_expression] = STATE(12476),
    [sym_block] = STATE(9961),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(14007),
    [sym__simple_expression] = STATE(6847),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15991),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(10631),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(10386),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5726),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(8783),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1366),
    [sym_block_comment] = STATE(1366),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(2278),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2282),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(2286),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_macro] = ACTIONS(2288),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(2290),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2294),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [1367] = {
    [sym_inline_modifier] = STATE(2335),
    [sym__indentable_expression] = STATE(13762),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1367),
    [sym_block_comment] = STATE(1367),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(2468),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1368] = {
    [sym_inline_modifier] = STATE(2309),
    [sym__indentable_expression] = STATE(12477),
    [sym_block] = STATE(9961),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(14007),
    [sym__simple_expression] = STATE(6847),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15991),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(10631),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(10386),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5726),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(8783),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1368),
    [sym_block_comment] = STATE(1368),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(2278),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2282),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(2286),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_macro] = ACTIONS(2288),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(2290),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2294),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [1369] = {
    [sym_inline_modifier] = STATE(2310),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(13291),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1369),
    [sym_block_comment] = STATE(1369),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(1156),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_SEMI] = ACTIONS(1148),
    [anon_sym_else] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3290),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1370] = {
    [sym_inline_modifier] = STATE(2335),
    [sym__indentable_expression] = STATE(13793),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1370),
    [sym_block_comment] = STATE(1370),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(2468),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1371] = {
    [sym_inline_modifier] = STATE(2310),
    [sym__indentable_expression] = STATE(13367),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1371),
    [sym_block_comment] = STATE(1371),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3131),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3290),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1372] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(12986),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1372),
    [sym_block_comment] = STATE(1372),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1373] = {
    [sym_inline_modifier] = STATE(2335),
    [sym__indentable_expression] = STATE(13820),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1373),
    [sym_block_comment] = STATE(1373),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(2468),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1374] = {
    [sym_inline_modifier] = STATE(2310),
    [sym__indentable_expression] = STATE(13524),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1374),
    [sym_block_comment] = STATE(1374),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3131),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3290),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1375] = {
    [sym_inline_modifier] = STATE(2310),
    [sym__indentable_expression] = STATE(13426),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1375),
    [sym_block_comment] = STATE(1375),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3131),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3290),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1376] = {
    [sym_inline_modifier] = STATE(2310),
    [sym__indentable_expression] = STATE(13326),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1376),
    [sym_block_comment] = STATE(1376),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3131),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3290),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1377] = {
    [sym_inline_modifier] = STATE(2335),
    [sym__indentable_expression] = STATE(13823),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1377),
    [sym_block_comment] = STATE(1377),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(2468),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1378] = {
    [sym_inline_modifier] = STATE(2310),
    [sym__indentable_expression] = STATE(13477),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1378),
    [sym_block_comment] = STATE(1378),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3131),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3290),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1379] = {
    [sym_inline_modifier] = STATE(2310),
    [sym__indentable_expression] = STATE(13534),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1379),
    [sym_block_comment] = STATE(1379),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3131),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3290),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1380] = {
    [sym_inline_modifier] = STATE(2335),
    [sym__indentable_expression] = STATE(13825),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1380),
    [sym_block_comment] = STATE(1380),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(2468),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1381] = {
    [sym_inline_modifier] = STATE(2310),
    [sym__indentable_expression] = STATE(13451),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1381),
    [sym_block_comment] = STATE(1381),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3131),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3290),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1382] = {
    [sym_inline_modifier] = STATE(2310),
    [sym__indentable_expression] = STATE(13563),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1382),
    [sym_block_comment] = STATE(1382),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3131),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3290),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1383] = {
    [sym_inline_modifier] = STATE(2335),
    [sym__indentable_expression] = STATE(13828),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1383),
    [sym_block_comment] = STATE(1383),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(2468),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1384] = {
    [sym_inline_modifier] = STATE(2310),
    [sym__indentable_expression] = STATE(13337),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1384),
    [sym_block_comment] = STATE(1384),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3131),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3290),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1385] = {
    [sym_inline_modifier] = STATE(2310),
    [sym__indentable_expression] = STATE(13357),
    [sym_block] = STATE(8380),
    [sym_indented_block] = STATE(13600),
    [sym_indented_cases] = STATE(13600),
    [sym_expression] = STATE(13151),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1385),
    [sym_block_comment] = STATE(1385),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3131),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3290),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3286),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1386] = {
    [sym_inline_modifier] = STATE(2278),
    [sym__indentable_expression] = STATE(13376),
    [sym_block] = STATE(9584),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(13653),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1386),
    [sym_block_comment] = STATE(1386),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [1387] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(14278),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1387),
    [sym_block_comment] = STATE(1387),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1388] = {
    [sym_inline_modifier] = STATE(2329),
    [sym__indentable_expression] = STATE(12093),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1388),
    [sym_block_comment] = STATE(1388),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1389] = {
    [sym_inline_modifier] = STATE(2312),
    [sym__indentable_expression] = STATE(11552),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1389),
    [sym_block_comment] = STATE(1389),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1390] = {
    [sym_inline_modifier] = STATE(2336),
    [sym__indentable_expression] = STATE(12580),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1390),
    [sym_block_comment] = STATE(1390),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2100),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1391] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(10748),
    [sym_expression] = STATE(15589),
    [sym__simple_expression] = STATE(9273),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(10748),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(10748),
    [sym_call_expression] = STATE(10748),
    [sym_field_expression] = STATE(10748),
    [sym_instance_expression] = STATE(10748),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16403),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11096),
    [sym_tuple_expression] = STATE(10748),
    [sym_parenthesized_expression] = STATE(10748),
    [sym_splice_expression] = STATE(10748),
    [sym_quote_expression] = STATE(10748),
    [sym_identifier] = STATE(8325),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10486),
    [sym__non_null_literal] = STATE(10748),
    [sym_boolean_literal] = STATE(10820),
    [sym_interpolated_string_expression] = STATE(10748),
    [sym_string] = STATE(10820),
    [sym_unit] = STATE(10748),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1391),
    [sym_block_comment] = STATE(1391),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_COLON] = ACTIONS(3296),
    [anon_sym_LBRACE] = ACTIONS(3298),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_EQ_GT] = ACTIONS(896),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(3300),
    [anon_sym_DASH] = ACTIONS(3300),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(3302),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(3300),
    [anon_sym_TILDE] = ACTIONS(3300),
    [anon_sym_DOLLAR] = ACTIONS(3306),
    [anon_sym_SQUOTE] = ACTIONS(3308),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3310),
    [sym_integer_literal] = ACTIONS(3312),
    [sym_floating_point_literal] = ACTIONS(3314),
    [anon_sym_true] = ACTIONS(3316),
    [anon_sym_false] = ACTIONS(3316),
    [sym_character_literal] = ACTIONS(3314),
    [sym_null_literal] = ACTIONS(3318),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(3320),
    [sym__simple_string] = ACTIONS(3320),
  },
  [1392] = {
    [sym_inline_modifier] = STATE(2312),
    [sym__indentable_expression] = STATE(11557),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1392),
    [sym_block_comment] = STATE(1392),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1393] = {
    [sym_inline_modifier] = STATE(2329),
    [sym__indentable_expression] = STATE(12125),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1393),
    [sym_block_comment] = STATE(1393),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1394] = {
    [sym_inline_modifier] = STATE(2312),
    [sym__indentable_expression] = STATE(11459),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1394),
    [sym_block_comment] = STATE(1394),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1395] = {
    [sym_inline_modifier] = STATE(2312),
    [sym__indentable_expression] = STATE(11561),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1395),
    [sym_block_comment] = STATE(1395),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1396] = {
    [sym_inline_modifier] = STATE(2312),
    [sym__indentable_expression] = STATE(11563),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1396),
    [sym_block_comment] = STATE(1396),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1397] = {
    [sym_inline_modifier] = STATE(2336),
    [sym__indentable_expression] = STATE(12594),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1397),
    [sym_block_comment] = STATE(1397),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2100),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1398] = {
    [sym_inline_modifier] = STATE(2312),
    [sym__indentable_expression] = STATE(11572),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1398),
    [sym_block_comment] = STATE(1398),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1399] = {
    [sym_inline_modifier] = STATE(2336),
    [sym__indentable_expression] = STATE(12595),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1399),
    [sym_block_comment] = STATE(1399),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2100),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1400] = {
    [sym_inline_modifier] = STATE(2312),
    [sym__indentable_expression] = STATE(11573),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1400),
    [sym_block_comment] = STATE(1400),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1401] = {
    [sym_inline_modifier] = STATE(2312),
    [sym__indentable_expression] = STATE(11575),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1401),
    [sym_block_comment] = STATE(1401),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1402] = {
    [sym_inline_modifier] = STATE(2312),
    [sym__indentable_expression] = STATE(11578),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1402),
    [sym_block_comment] = STATE(1402),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1403] = {
    [sym_inline_modifier] = STATE(2336),
    [sym__indentable_expression] = STATE(12599),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1403),
    [sym_block_comment] = STATE(1403),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2100),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1404] = {
    [sym_inline_modifier] = STATE(2312),
    [sym__indentable_expression] = STATE(11582),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1404),
    [sym_block_comment] = STATE(1404),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1405] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(12948),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1405),
    [sym_block_comment] = STATE(1405),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1406] = {
    [sym_inline_modifier] = STATE(2336),
    [sym__indentable_expression] = STATE(12603),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1406),
    [sym_block_comment] = STATE(1406),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2100),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1407] = {
    [sym_inline_modifier] = STATE(2336),
    [sym__indentable_expression] = STATE(12617),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1407),
    [sym_block_comment] = STATE(1407),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2100),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1408] = {
    [sym_inline_modifier] = STATE(2313),
    [sym__indentable_expression] = STATE(12418),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(6055),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15856),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9737),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5346),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8338),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1408),
    [sym_block_comment] = STATE(1408),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1764),
    [anon_sym_while] = ACTIONS(1766),
    [anon_sym_for] = ACTIONS(1768),
    [anon_sym_try] = ACTIONS(1770),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(1772),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1776),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(1778),
    [anon_sym_throw] = ACTIONS(1780),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1409] = {
    [sym_inline_modifier] = STATE(2313),
    [sym__indentable_expression] = STATE(12442),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(6055),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15856),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9737),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5346),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8338),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1409),
    [sym_block_comment] = STATE(1409),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1764),
    [anon_sym_while] = ACTIONS(1766),
    [anon_sym_for] = ACTIONS(1768),
    [anon_sym_try] = ACTIONS(1770),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(1772),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1776),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(1778),
    [anon_sym_throw] = ACTIONS(1780),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1410] = {
    [sym_inline_modifier] = STATE(2313),
    [sym__indentable_expression] = STATE(12443),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(6055),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15856),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9737),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5346),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8338),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1410),
    [sym_block_comment] = STATE(1410),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1764),
    [anon_sym_while] = ACTIONS(1766),
    [anon_sym_for] = ACTIONS(1768),
    [anon_sym_try] = ACTIONS(1770),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(1772),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1776),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(1778),
    [anon_sym_throw] = ACTIONS(1780),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1411] = {
    [sym_inline_modifier] = STATE(2336),
    [sym__indentable_expression] = STATE(12623),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1411),
    [sym_block_comment] = STATE(1411),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2100),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1412] = {
    [sym_inline_modifier] = STATE(2313),
    [sym__indentable_expression] = STATE(12446),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(6055),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15856),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9737),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5346),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8338),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1412),
    [sym_block_comment] = STATE(1412),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1764),
    [anon_sym_while] = ACTIONS(1766),
    [anon_sym_for] = ACTIONS(1768),
    [anon_sym_try] = ACTIONS(1770),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(1772),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1776),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(1778),
    [anon_sym_throw] = ACTIONS(1780),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1413] = {
    [sym_inline_modifier] = STATE(2313),
    [sym__indentable_expression] = STATE(12449),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(6055),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15856),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9737),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5346),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8338),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1413),
    [sym_block_comment] = STATE(1413),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1764),
    [anon_sym_while] = ACTIONS(1766),
    [anon_sym_for] = ACTIONS(1768),
    [anon_sym_try] = ACTIONS(1770),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(1772),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1776),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(1778),
    [anon_sym_throw] = ACTIONS(1780),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1414] = {
    [sym_inline_modifier] = STATE(2313),
    [sym__indentable_expression] = STATE(12465),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(6055),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15856),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9737),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5346),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8338),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1414),
    [sym_block_comment] = STATE(1414),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1764),
    [anon_sym_while] = ACTIONS(1766),
    [anon_sym_for] = ACTIONS(1768),
    [anon_sym_try] = ACTIONS(1770),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(1772),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1776),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(1778),
    [anon_sym_throw] = ACTIONS(1780),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1415] = {
    [sym_inline_modifier] = STATE(2336),
    [sym__indentable_expression] = STATE(12624),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1415),
    [sym_block_comment] = STATE(1415),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2100),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1416] = {
    [sym_inline_modifier] = STATE(2313),
    [sym__indentable_expression] = STATE(12472),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(6055),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15856),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9737),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5346),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8338),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1416),
    [sym_block_comment] = STATE(1416),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1764),
    [anon_sym_while] = ACTIONS(1766),
    [anon_sym_for] = ACTIONS(1768),
    [anon_sym_try] = ACTIONS(1770),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(1772),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1776),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(1778),
    [anon_sym_throw] = ACTIONS(1780),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1417] = {
    [sym_inline_modifier] = STATE(2336),
    [sym__indentable_expression] = STATE(12626),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1417),
    [sym_block_comment] = STATE(1417),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2100),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1418] = {
    [sym_inline_modifier] = STATE(2313),
    [sym__indentable_expression] = STATE(12474),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(6055),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15856),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9737),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5346),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8338),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1418),
    [sym_block_comment] = STATE(1418),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1764),
    [anon_sym_while] = ACTIONS(1766),
    [anon_sym_for] = ACTIONS(1768),
    [anon_sym_try] = ACTIONS(1770),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(1772),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1776),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(1778),
    [anon_sym_throw] = ACTIONS(1780),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1419] = {
    [sym_inline_modifier] = STATE(2313),
    [sym__indentable_expression] = STATE(12476),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(6055),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15856),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9737),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5346),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8338),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1419),
    [sym_block_comment] = STATE(1419),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1764),
    [anon_sym_while] = ACTIONS(1766),
    [anon_sym_for] = ACTIONS(1768),
    [anon_sym_try] = ACTIONS(1770),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(1772),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1776),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(1778),
    [anon_sym_throw] = ACTIONS(1780),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1420] = {
    [sym_inline_modifier] = STATE(2336),
    [sym__indentable_expression] = STATE(12631),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1420),
    [sym_block_comment] = STATE(1420),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2100),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1421] = {
    [sym_inline_modifier] = STATE(2313),
    [sym__indentable_expression] = STATE(12477),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(6055),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15856),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9737),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5346),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8338),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1421),
    [sym_block_comment] = STATE(1421),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1764),
    [anon_sym_while] = ACTIONS(1766),
    [anon_sym_for] = ACTIONS(1768),
    [anon_sym_try] = ACTIONS(1770),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(1772),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1776),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(1778),
    [anon_sym_throw] = ACTIONS(1780),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1422] = {
    [sym_inline_modifier] = STATE(2329),
    [sym__indentable_expression] = STATE(11850),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1422),
    [sym_block_comment] = STATE(1422),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1423] = {
    [sym_inline_modifier] = STATE(2337),
    [sym__indentable_expression] = STATE(11552),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1423),
    [sym_block_comment] = STATE(1423),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1424] = {
    [sym_inline_modifier] = STATE(2314),
    [sym__indentable_expression] = STATE(12892),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1424),
    [sym_block_comment] = STATE(1424),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1425] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(14364),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1425),
    [sym_block_comment] = STATE(1425),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1426] = {
    [sym_inline_modifier] = STATE(2314),
    [sym__indentable_expression] = STATE(12918),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1426),
    [sym_block_comment] = STATE(1426),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1427] = {
    [sym_inline_modifier] = STATE(2337),
    [sym__indentable_expression] = STATE(11557),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1427),
    [sym_block_comment] = STATE(1427),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1428] = {
    [sym_inline_modifier] = STATE(2314),
    [sym__indentable_expression] = STATE(12919),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1428),
    [sym_block_comment] = STATE(1428),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1429] = {
    [sym_inline_modifier] = STATE(2314),
    [sym__indentable_expression] = STATE(12920),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1429),
    [sym_block_comment] = STATE(1429),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1430] = {
    [sym_inline_modifier] = STATE(2337),
    [sym__indentable_expression] = STATE(11459),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1430),
    [sym_block_comment] = STATE(1430),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1431] = {
    [sym_inline_modifier] = STATE(2314),
    [sym__indentable_expression] = STATE(12923),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1431),
    [sym_block_comment] = STATE(1431),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1432] = {
    [sym_inline_modifier] = STATE(2314),
    [sym__indentable_expression] = STATE(12935),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1432),
    [sym_block_comment] = STATE(1432),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1433] = {
    [sym_inline_modifier] = STATE(2337),
    [sym__indentable_expression] = STATE(11561),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1433),
    [sym_block_comment] = STATE(1433),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1434] = {
    [sym_inline_modifier] = STATE(2337),
    [sym__indentable_expression] = STATE(11563),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1434),
    [sym_block_comment] = STATE(1434),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1435] = {
    [sym_inline_modifier] = STATE(2314),
    [sym__indentable_expression] = STATE(12939),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1435),
    [sym_block_comment] = STATE(1435),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1436] = {
    [sym_inline_modifier] = STATE(2314),
    [sym__indentable_expression] = STATE(12940),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1436),
    [sym_block_comment] = STATE(1436),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1437] = {
    [sym_inline_modifier] = STATE(2337),
    [sym__indentable_expression] = STATE(11572),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1437),
    [sym_block_comment] = STATE(1437),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1438] = {
    [sym_inline_modifier] = STATE(2314),
    [sym__indentable_expression] = STATE(12942),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1438),
    [sym_block_comment] = STATE(1438),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1439] = {
    [sym_inline_modifier] = STATE(2314),
    [sym__indentable_expression] = STATE(12946),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1439),
    [sym_block_comment] = STATE(1439),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1440] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(14248),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1440),
    [sym_block_comment] = STATE(1440),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1441] = {
    [sym_inline_modifier] = STATE(2337),
    [sym__indentable_expression] = STATE(11573),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1441),
    [sym_block_comment] = STATE(1441),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1442] = {
    [sym_inline_modifier] = STATE(2337),
    [sym__indentable_expression] = STATE(11575),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1442),
    [sym_block_comment] = STATE(1442),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1443] = {
    [sym_inline_modifier] = STATE(2337),
    [sym__indentable_expression] = STATE(11578),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1443),
    [sym_block_comment] = STATE(1443),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1444] = {
    [sym_inline_modifier] = STATE(2315),
    [sym__indentable_expression] = STATE(13816),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(6983),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15899),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10174),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(5823),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9043),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1444),
    [sym_block_comment] = STATE(1444),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2446),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2450),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2452),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2456),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1445] = {
    [sym_inline_modifier] = STATE(2337),
    [sym__indentable_expression] = STATE(11582),
    [sym_block] = STATE(5465),
    [sym_indented_block] = STATE(11510),
    [sym_indented_cases] = STATE(11510),
    [sym_expression] = STATE(11621),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1445),
    [sym_block_comment] = STATE(1445),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2298),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1446] = {
    [sym_inline_modifier] = STATE(2315),
    [sym__indentable_expression] = STATE(13731),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(6983),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15899),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10174),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(5823),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9043),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1446),
    [sym_block_comment] = STATE(1446),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2446),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2450),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2452),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2456),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1447] = {
    [sym_inline_modifier] = STATE(2093),
    [sym__indentable_expression] = STATE(13924),
    [sym_block] = STATE(9331),
    [sym_indented_block] = STATE(13883),
    [sym_indented_cases] = STATE(13883),
    [sym_expression] = STATE(13672),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1447),
    [sym_block_comment] = STATE(1447),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2990),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1448] = {
    [sym_inline_modifier] = STATE(2315),
    [sym__indentable_expression] = STATE(13751),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(6983),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15899),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10174),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(5823),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9043),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1448),
    [sym_block_comment] = STATE(1448),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2446),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2450),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2452),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2456),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1449] = {
    [sym_inline_modifier] = STATE(2315),
    [sym__indentable_expression] = STATE(13795),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(6983),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15899),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10174),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(5823),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9043),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1449),
    [sym_block_comment] = STATE(1449),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2446),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2450),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2452),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2456),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1450] = {
    [sym_inline_modifier] = STATE(2329),
    [sym__indentable_expression] = STATE(11852),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1450),
    [sym_block_comment] = STATE(1450),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1451] = {
    [sym_inline_modifier] = STATE(2315),
    [sym__indentable_expression] = STATE(13634),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(6983),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15899),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10174),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(5823),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9043),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1451),
    [sym_block_comment] = STATE(1451),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2446),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2450),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2452),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2456),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1452] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12418),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5559),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15942),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9343),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5006),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8062),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1452),
    [sym_block_comment] = STATE(1452),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2258),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2262),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2266),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2268),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2270),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1453] = {
    [sym_inline_modifier] = STATE(2315),
    [sym__indentable_expression] = STATE(13724),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(6983),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15899),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10174),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(5823),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9043),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1453),
    [sym_block_comment] = STATE(1453),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2446),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2450),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2452),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2456),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1454] = {
    [sym_inline_modifier] = STATE(2315),
    [sym__indentable_expression] = STATE(13787),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(6983),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15899),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10174),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(5823),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9043),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1454),
    [sym_block_comment] = STATE(1454),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2446),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2450),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2452),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2456),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1455] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12442),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5559),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15942),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9343),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5006),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8062),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1455),
    [sym_block_comment] = STATE(1455),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2258),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2262),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2266),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2268),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2270),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1456] = {
    [sym_inline_modifier] = STATE(2315),
    [sym__indentable_expression] = STATE(13789),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(6983),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15899),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10174),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(5823),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9043),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1456),
    [sym_block_comment] = STATE(1456),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2446),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2450),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2452),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2456),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1457] = {
    [sym_inline_modifier] = STATE(2315),
    [sym__indentable_expression] = STATE(13812),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(6983),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15899),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10174),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(5823),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9043),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1457),
    [sym_block_comment] = STATE(1457),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2446),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2450),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2452),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2456),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1458] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12443),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5559),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15942),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9343),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5006),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8062),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1458),
    [sym_block_comment] = STATE(1458),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2258),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2262),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2266),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2268),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2270),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1459] = {
    [sym_inline_modifier] = STATE(2315),
    [sym__indentable_expression] = STATE(13633),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(6983),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15899),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10174),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(5823),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9043),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1459),
    [sym_block_comment] = STATE(1459),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2446),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2450),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2452),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2456),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1460] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12446),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5559),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15942),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9343),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5006),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8062),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1460),
    [sym_block_comment] = STATE(1460),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2258),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2262),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2266),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2268),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2270),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1461] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(12868),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1461),
    [sym_block_comment] = STATE(1461),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1462] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12449),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5559),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15942),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9343),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5006),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8062),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1462),
    [sym_block_comment] = STATE(1462),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2258),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2262),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2266),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2268),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2270),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1463] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12465),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5559),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15942),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9343),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5006),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8062),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1463),
    [sym_block_comment] = STATE(1463),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2258),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2262),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2266),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2268),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2270),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1464] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(13925),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1464),
    [sym_block_comment] = STATE(1464),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1465] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(12913),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1465),
    [sym_block_comment] = STATE(1465),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1466] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(13958),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1466),
    [sym_block_comment] = STATE(1466),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1467] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12472),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5559),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15942),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9343),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5006),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8062),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1467),
    [sym_block_comment] = STATE(1467),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2258),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2262),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2266),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2268),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2270),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1468] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(13960),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1468),
    [sym_block_comment] = STATE(1468),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1469] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12474),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5559),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15942),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9343),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5006),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8062),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1469),
    [sym_block_comment] = STATE(1469),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2258),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2262),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2266),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2268),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2270),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1470] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(13962),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1470),
    [sym_block_comment] = STATE(1470),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1471] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(13975),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1471),
    [sym_block_comment] = STATE(1471),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1472] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12476),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5559),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15942),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9343),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5006),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8062),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1472),
    [sym_block_comment] = STATE(1472),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2258),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2262),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2266),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2268),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2270),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1473] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(13991),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1473),
    [sym_block_comment] = STATE(1473),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1474] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12477),
    [sym_block] = STATE(6874),
    [sym_indented_block] = STATE(12333),
    [sym_indented_cases] = STATE(12333),
    [sym_expression] = STATE(12498),
    [sym__simple_expression] = STATE(5559),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15942),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9343),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5006),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8062),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1474),
    [sym_block_comment] = STATE(1474),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2258),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2262),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2266),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2268),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2270),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2192),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1475] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(13998),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1475),
    [sym_block_comment] = STATE(1475),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1476] = {
    [sym_inline_modifier] = STATE(2329),
    [sym__indentable_expression] = STATE(11901),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1476),
    [sym_block_comment] = STATE(1476),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1477] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(13999),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1477),
    [sym_block_comment] = STATE(1477),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1478] = {
    [sym_inline_modifier] = STATE(2329),
    [sym__indentable_expression] = STATE(12022),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1478),
    [sym_block_comment] = STATE(1478),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1479] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(14001),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1479),
    [sym_block_comment] = STATE(1479),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1480] = {
    [sym_inline_modifier] = STATE(2324),
    [sym__indentable_expression] = STATE(14003),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1480),
    [sym_block_comment] = STATE(1480),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1481] = {
    [sym_inline_modifier] = STATE(2339),
    [sym__indentable_expression] = STATE(13055),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1481),
    [sym_block_comment] = STATE(1481),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1482] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(12928),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1482),
    [sym_block_comment] = STATE(1482),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1483] = {
    [sym_inline_modifier] = STATE(2339),
    [sym__indentable_expression] = STATE(13080),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1483),
    [sym_block_comment] = STATE(1483),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1484] = {
    [sym_inline_modifier] = STATE(2316),
    [sym__indentable_expression] = STATE(13715),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1484),
    [sym_block_comment] = STATE(1484),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1485] = {
    [sym_inline_modifier] = STATE(2339),
    [sym__indentable_expression] = STATE(13083),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1485),
    [sym_block_comment] = STATE(1485),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1486] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(12948),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1486),
    [sym_block_comment] = STATE(1486),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1487] = {
    [sym_inline_modifier] = STATE(2339),
    [sym__indentable_expression] = STATE(13085),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1487),
    [sym_block_comment] = STATE(1487),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1488] = {
    [sym_inline_modifier] = STATE(2316),
    [sym__indentable_expression] = STATE(13755),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1488),
    [sym_block_comment] = STATE(1488),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1489] = {
    [sym_inline_modifier] = STATE(2316),
    [sym__indentable_expression] = STATE(13757),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1489),
    [sym_block_comment] = STATE(1489),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1490] = {
    [sym_inline_modifier] = STATE(2339),
    [sym__indentable_expression] = STATE(13089),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1490),
    [sym_block_comment] = STATE(1490),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1491] = {
    [sym_inline_modifier] = STATE(2316),
    [sym__indentable_expression] = STATE(13759),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1491),
    [sym_block_comment] = STATE(1491),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1492] = {
    [sym_inline_modifier] = STATE(2339),
    [sym__indentable_expression] = STATE(13110),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1492),
    [sym_block_comment] = STATE(1492),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1493] = {
    [sym_inline_modifier] = STATE(2316),
    [sym__indentable_expression] = STATE(13762),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1493),
    [sym_block_comment] = STATE(1493),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1494] = {
    [sym_inline_modifier] = STATE(2316),
    [sym__indentable_expression] = STATE(13793),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1494),
    [sym_block_comment] = STATE(1494),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1495] = {
    [sym_inline_modifier] = STATE(2339),
    [sym__indentable_expression] = STATE(13127),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1495),
    [sym_block_comment] = STATE(1495),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1496] = {
    [sym_inline_modifier] = STATE(2316),
    [sym__indentable_expression] = STATE(13820),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1496),
    [sym_block_comment] = STATE(1496),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1497] = {
    [sym_inline_modifier] = STATE(2316),
    [sym__indentable_expression] = STATE(13823),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1497),
    [sym_block_comment] = STATE(1497),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1498] = {
    [sym_inline_modifier] = STATE(2339),
    [sym__indentable_expression] = STATE(13129),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1498),
    [sym_block_comment] = STATE(1498),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1499] = {
    [sym_inline_modifier] = STATE(2339),
    [sym__indentable_expression] = STATE(13131),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1499),
    [sym_block_comment] = STATE(1499),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1500] = {
    [sym_inline_modifier] = STATE(2316),
    [sym__indentable_expression] = STATE(13825),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1500),
    [sym_block_comment] = STATE(1500),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1501] = {
    [sym_inline_modifier] = STATE(2316),
    [sym__indentable_expression] = STATE(13828),
    [sym_block] = STATE(8838),
    [sym_indented_block] = STATE(13805),
    [sym_indented_cases] = STATE(13805),
    [sym_expression] = STATE(13359),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1501),
    [sym_block_comment] = STATE(1501),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3292),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1502] = {
    [sym_inline_modifier] = STATE(2339),
    [sym__indentable_expression] = STATE(13135),
    [sym_block] = STATE(7648),
    [sym_indented_block] = STATE(13209),
    [sym_indented_cases] = STATE(13209),
    [sym_expression] = STATE(12785),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1502),
    [sym_block_comment] = STATE(1502),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2376),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1503] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(14599),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1503),
    [sym_block_comment] = STATE(1503),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1504] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(14364),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1504),
    [sym_block_comment] = STATE(1504),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1505] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(14359),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1505),
    [sym_block_comment] = STATE(1505),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1506] = {
    [sym_inline_modifier] = STATE(2340),
    [sym__indentable_expression] = STATE(13443),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1506),
    [sym_block_comment] = STATE(1506),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1507] = {
    [sym_inline_modifier] = STATE(2317),
    [sym__indentable_expression] = STATE(12892),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1507),
    [sym_block_comment] = STATE(1507),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1508] = {
    [sym_inline_modifier] = STATE(2340),
    [sym__indentable_expression] = STATE(13481),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1508),
    [sym_block_comment] = STATE(1508),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1509] = {
    [sym_inline_modifier] = STATE(2340),
    [sym__indentable_expression] = STATE(13483),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1509),
    [sym_block_comment] = STATE(1509),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1510] = {
    [sym_inline_modifier] = STATE(2317),
    [sym__indentable_expression] = STATE(12918),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1510),
    [sym_block_comment] = STATE(1510),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1511] = {
    [sym_inline_modifier] = STATE(2317),
    [sym__indentable_expression] = STATE(12919),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1511),
    [sym_block_comment] = STATE(1511),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1512] = {
    [sym_inline_modifier] = STATE(2340),
    [sym__indentable_expression] = STATE(13486),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1512),
    [sym_block_comment] = STATE(1512),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1513] = {
    [sym_inline_modifier] = STATE(2340),
    [sym__indentable_expression] = STATE(13490),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1513),
    [sym_block_comment] = STATE(1513),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1514] = {
    [sym_inline_modifier] = STATE(2317),
    [sym__indentable_expression] = STATE(12920),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1514),
    [sym_block_comment] = STATE(1514),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1515] = {
    [sym_inline_modifier] = STATE(2317),
    [sym__indentable_expression] = STATE(12923),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1515),
    [sym_block_comment] = STATE(1515),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1516] = {
    [sym_inline_modifier] = STATE(2340),
    [sym__indentable_expression] = STATE(13531),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1516),
    [sym_block_comment] = STATE(1516),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1517] = {
    [sym_inline_modifier] = STATE(2317),
    [sym__indentable_expression] = STATE(12935),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1517),
    [sym_block_comment] = STATE(1517),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1518] = {
    [sym_inline_modifier] = STATE(2340),
    [sym__indentable_expression] = STATE(13540),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1518),
    [sym_block_comment] = STATE(1518),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1519] = {
    [sym_inline_modifier] = STATE(2340),
    [sym__indentable_expression] = STATE(13543),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1519),
    [sym_block_comment] = STATE(1519),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1520] = {
    [sym_inline_modifier] = STATE(2317),
    [sym__indentable_expression] = STATE(12939),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1520),
    [sym_block_comment] = STATE(1520),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1521] = {
    [sym_inline_modifier] = STATE(2317),
    [sym__indentable_expression] = STATE(12940),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1521),
    [sym_block_comment] = STATE(1521),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1522] = {
    [sym_inline_modifier] = STATE(2340),
    [sym__indentable_expression] = STATE(13545),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1522),
    [sym_block_comment] = STATE(1522),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1523] = {
    [sym_inline_modifier] = STATE(2340),
    [sym__indentable_expression] = STATE(13549),
    [sym_block] = STATE(8399),
    [sym_indented_block] = STATE(13391),
    [sym_indented_cases] = STATE(13391),
    [sym_expression] = STATE(13187),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1523),
    [sym_block_comment] = STATE(1523),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2164),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1524] = {
    [sym_inline_modifier] = STATE(2317),
    [sym__indentable_expression] = STATE(12942),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1524),
    [sym_block_comment] = STATE(1524),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1525] = {
    [sym_inline_modifier] = STATE(2317),
    [sym__indentable_expression] = STATE(12946),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1525),
    [sym_block_comment] = STATE(1525),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1526] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(12777),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1526),
    [sym_block_comment] = STATE(1526),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1527] = {
    [sym_inline_modifier] = STATE(2341),
    [sym__indentable_expression] = STATE(13173),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1527),
    [sym_block_comment] = STATE(1527),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1528] = {
    [sym_inline_modifier] = STATE(2341),
    [sym__indentable_expression] = STATE(13219),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1528),
    [sym_block_comment] = STATE(1528),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1529] = {
    [sym_inline_modifier] = STATE(2318),
    [sym__indentable_expression] = STATE(13816),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8653),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(16129),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10722),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(7377),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9808),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1529),
    [sym_block_comment] = STATE(1529),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2200),
    [anon_sym_for] = ACTIONS(2202),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2206),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2210),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1530] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(14368),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1530),
    [sym_block_comment] = STATE(1530),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1531] = {
    [sym_inline_modifier] = STATE(2341),
    [sym__indentable_expression] = STATE(13227),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1531),
    [sym_block_comment] = STATE(1531),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1532] = {
    [sym_inline_modifier] = STATE(2341),
    [sym__indentable_expression] = STATE(13232),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1532),
    [sym_block_comment] = STATE(1532),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1533] = {
    [sym_inline_modifier] = STATE(2318),
    [sym__indentable_expression] = STATE(13731),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8653),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(16129),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10722),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(7377),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9808),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1533),
    [sym_block_comment] = STATE(1533),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2200),
    [anon_sym_for] = ACTIONS(2202),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2206),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2210),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1534] = {
    [sym_inline_modifier] = STATE(2318),
    [sym__indentable_expression] = STATE(13751),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8653),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(16129),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10722),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(7377),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9808),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1534),
    [sym_block_comment] = STATE(1534),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2200),
    [anon_sym_for] = ACTIONS(2202),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2206),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2210),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1535] = {
    [sym_inline_modifier] = STATE(2341),
    [sym__indentable_expression] = STATE(13249),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1535),
    [sym_block_comment] = STATE(1535),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1536] = {
    [sym_inline_modifier] = STATE(2341),
    [sym__indentable_expression] = STATE(13292),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1536),
    [sym_block_comment] = STATE(1536),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1537] = {
    [sym_inline_modifier] = STATE(2318),
    [sym__indentable_expression] = STATE(13795),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8653),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(16129),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10722),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(7377),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9808),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1537),
    [sym_block_comment] = STATE(1537),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2200),
    [anon_sym_for] = ACTIONS(2202),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2206),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2210),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1538] = {
    [sym_inline_modifier] = STATE(2318),
    [sym__indentable_expression] = STATE(13634),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8653),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(16129),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10722),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(7377),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9808),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1538),
    [sym_block_comment] = STATE(1538),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2200),
    [anon_sym_for] = ACTIONS(2202),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2206),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2210),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1539] = {
    [sym_inline_modifier] = STATE(2341),
    [sym__indentable_expression] = STATE(13312),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1539),
    [sym_block_comment] = STATE(1539),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1540] = {
    [sym_inline_modifier] = STATE(2318),
    [sym__indentable_expression] = STATE(13724),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8653),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(16129),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10722),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(7377),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9808),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1540),
    [sym_block_comment] = STATE(1540),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2200),
    [anon_sym_for] = ACTIONS(2202),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2206),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2210),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1541] = {
    [sym_inline_modifier] = STATE(2318),
    [sym__indentable_expression] = STATE(13787),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8653),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(16129),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10722),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(7377),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9808),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1541),
    [sym_block_comment] = STATE(1541),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2200),
    [anon_sym_for] = ACTIONS(2202),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2206),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2210),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1542] = {
    [sym_inline_modifier] = STATE(2318),
    [sym__indentable_expression] = STATE(13789),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8653),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(16129),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10722),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(7377),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9808),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1542),
    [sym_block_comment] = STATE(1542),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2200),
    [anon_sym_for] = ACTIONS(2202),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2206),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2210),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1543] = {
    [sym_inline_modifier] = STATE(2318),
    [sym__indentable_expression] = STATE(13812),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8653),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(16129),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10722),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(7377),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9808),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1543),
    [sym_block_comment] = STATE(1543),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2200),
    [anon_sym_for] = ACTIONS(2202),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2206),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2210),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1544] = {
    [sym_inline_modifier] = STATE(2318),
    [sym__indentable_expression] = STATE(13633),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8653),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(16129),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10722),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(7377),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9808),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1544),
    [sym_block_comment] = STATE(1544),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2200),
    [anon_sym_for] = ACTIONS(2202),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2206),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2210),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1545] = {
    [sym_inline_modifier] = STATE(2341),
    [sym__indentable_expression] = STATE(13313),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1545),
    [sym_block_comment] = STATE(1545),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1546] = {
    [sym_inline_modifier] = STATE(2341),
    [sym__indentable_expression] = STATE(13319),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1546),
    [sym_block_comment] = STATE(1546),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1547] = {
    [sym_inline_modifier] = STATE(2319),
    [sym__indentable_expression] = STATE(13925),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(6682),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(15930),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10414),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5580),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9016),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1547),
    [sym_block_comment] = STATE(1547),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(3232),
    [anon_sym_while] = ACTIONS(3218),
    [anon_sym_for] = ACTIONS(3220),
    [anon_sym_try] = ACTIONS(3222),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(3224),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(3226),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(3228),
    [anon_sym_throw] = ACTIONS(3230),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1548] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(14368),
    [sym_block] = STATE(10212),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1548),
    [sym_block_comment] = STATE(1548),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1549] = {
    [sym_inline_modifier] = STATE(2319),
    [sym__indentable_expression] = STATE(13958),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(6682),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(15930),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10414),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5580),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9016),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1549),
    [sym_block_comment] = STATE(1549),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(3232),
    [anon_sym_while] = ACTIONS(3218),
    [anon_sym_for] = ACTIONS(3220),
    [anon_sym_try] = ACTIONS(3222),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(3224),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(3226),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(3228),
    [anon_sym_throw] = ACTIONS(3230),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1550] = {
    [sym_inline_modifier] = STATE(2319),
    [sym__indentable_expression] = STATE(13960),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(6682),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(15930),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10414),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5580),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9016),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1550),
    [sym_block_comment] = STATE(1550),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(3232),
    [anon_sym_while] = ACTIONS(3218),
    [anon_sym_for] = ACTIONS(3220),
    [anon_sym_try] = ACTIONS(3222),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(3224),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(3226),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(3228),
    [anon_sym_throw] = ACTIONS(3230),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1551] = {
    [sym_inline_modifier] = STATE(2319),
    [sym__indentable_expression] = STATE(13962),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(6682),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(15930),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10414),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5580),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9016),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1551),
    [sym_block_comment] = STATE(1551),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(3232),
    [anon_sym_while] = ACTIONS(3218),
    [anon_sym_for] = ACTIONS(3220),
    [anon_sym_try] = ACTIONS(3222),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(3224),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(3226),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(3228),
    [anon_sym_throw] = ACTIONS(3230),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1552] = {
    [sym_inline_modifier] = STATE(2319),
    [sym__indentable_expression] = STATE(13975),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(6682),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(15930),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10414),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5580),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9016),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1552),
    [sym_block_comment] = STATE(1552),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(3232),
    [anon_sym_while] = ACTIONS(3218),
    [anon_sym_for] = ACTIONS(3220),
    [anon_sym_try] = ACTIONS(3222),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(3224),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(3226),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(3228),
    [anon_sym_throw] = ACTIONS(3230),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1553] = {
    [sym_inline_modifier] = STATE(2319),
    [sym__indentable_expression] = STATE(13991),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(6682),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(15930),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10414),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5580),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9016),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1553),
    [sym_block_comment] = STATE(1553),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(3232),
    [anon_sym_while] = ACTIONS(3218),
    [anon_sym_for] = ACTIONS(3220),
    [anon_sym_try] = ACTIONS(3222),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(3224),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(3226),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(3228),
    [anon_sym_throw] = ACTIONS(3230),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1554] = {
    [sym_inline_modifier] = STATE(2319),
    [sym__indentable_expression] = STATE(13998),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(6682),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(15930),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10414),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5580),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9016),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1554),
    [sym_block_comment] = STATE(1554),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(3232),
    [anon_sym_while] = ACTIONS(3218),
    [anon_sym_for] = ACTIONS(3220),
    [anon_sym_try] = ACTIONS(3222),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(3224),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(3226),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(3228),
    [anon_sym_throw] = ACTIONS(3230),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1555] = {
    [sym_inline_modifier] = STATE(2319),
    [sym__indentable_expression] = STATE(13999),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(6682),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(15930),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10414),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5580),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9016),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1555),
    [sym_block_comment] = STATE(1555),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(3232),
    [anon_sym_while] = ACTIONS(3218),
    [anon_sym_for] = ACTIONS(3220),
    [anon_sym_try] = ACTIONS(3222),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(3224),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(3226),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(3228),
    [anon_sym_throw] = ACTIONS(3230),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1556] = {
    [sym_inline_modifier] = STATE(2319),
    [sym__indentable_expression] = STATE(14001),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(6682),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(15930),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10414),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5580),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9016),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1556),
    [sym_block_comment] = STATE(1556),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(3232),
    [anon_sym_while] = ACTIONS(3218),
    [anon_sym_for] = ACTIONS(3220),
    [anon_sym_try] = ACTIONS(3222),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(3224),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(3226),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(3228),
    [anon_sym_throw] = ACTIONS(3230),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1557] = {
    [sym_inline_modifier] = STATE(2319),
    [sym__indentable_expression] = STATE(14003),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(6682),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(15930),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10414),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5580),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9016),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1557),
    [sym_block_comment] = STATE(1557),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(3232),
    [anon_sym_while] = ACTIONS(3218),
    [anon_sym_for] = ACTIONS(3220),
    [anon_sym_try] = ACTIONS(3222),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(3224),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(3226),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(3228),
    [anon_sym_throw] = ACTIONS(3230),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1558] = {
    [sym_inline_modifier] = STATE(2290),
    [sym__indentable_expression] = STATE(14076),
    [sym_block] = STATE(10014),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(13944),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1558),
    [sym_block_comment] = STATE(1558),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2184),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [1559] = {
    [sym_inline_modifier] = STATE(2341),
    [sym__indentable_expression] = STATE(13252),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1559),
    [sym_block_comment] = STATE(1559),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1560] = {
    [sym_inline_modifier] = STATE(2320),
    [sym__indentable_expression] = STATE(12986),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6186),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16018),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9989),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5240),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8124),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1560),
    [sym_block_comment] = STATE(1560),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3237),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2488),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2492),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2494),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2496),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1561] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(14301),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1561),
    [sym_block_comment] = STATE(1561),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1562] = {
    [sym_inline_modifier] = STATE(2320),
    [sym__indentable_expression] = STATE(12868),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6186),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16018),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9989),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5240),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8124),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1562),
    [sym_block_comment] = STATE(1562),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3237),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2488),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2492),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2494),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2496),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1563] = {
    [sym_inline_modifier] = STATE(2320),
    [sym__indentable_expression] = STATE(12913),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6186),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16018),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9989),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5240),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8124),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1563),
    [sym_block_comment] = STATE(1563),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3237),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2488),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2492),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2494),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2496),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1564] = {
    [sym_inline_modifier] = STATE(2320),
    [sym__indentable_expression] = STATE(12928),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6186),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16018),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9989),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5240),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8124),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1564),
    [sym_block_comment] = STATE(1564),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3237),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2488),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2492),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2494),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2496),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1565] = {
    [sym_inline_modifier] = STATE(2320),
    [sym__indentable_expression] = STATE(12948),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6186),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16018),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9989),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5240),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8124),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1565),
    [sym_block_comment] = STATE(1565),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3237),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2488),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2492),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2494),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2496),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1566] = {
    [sym_inline_modifier] = STATE(2320),
    [sym__indentable_expression] = STATE(12819),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6186),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16018),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9989),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5240),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8124),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1566),
    [sym_block_comment] = STATE(1566),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3237),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2488),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2492),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2494),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2496),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1567] = {
    [sym_inline_modifier] = STATE(2320),
    [sym__indentable_expression] = STATE(12769),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6186),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16018),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9989),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5240),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8124),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1567),
    [sym_block_comment] = STATE(1567),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3237),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2488),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2492),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2494),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2496),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1568] = {
    [sym_inline_modifier] = STATE(2320),
    [sym__indentable_expression] = STATE(12777),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6186),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16018),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9989),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5240),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8124),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1568),
    [sym_block_comment] = STATE(1568),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3237),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2488),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2492),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2494),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2496),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1569] = {
    [sym_inline_modifier] = STATE(2320),
    [sym__indentable_expression] = STATE(12799),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6186),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16018),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9989),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5240),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8124),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1569),
    [sym_block_comment] = STATE(1569),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3237),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2488),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2492),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2494),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2496),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1570] = {
    [sym_inline_modifier] = STATE(2320),
    [sym__indentable_expression] = STATE(12952),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(6186),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16018),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9989),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5240),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8124),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1570),
    [sym_block_comment] = STATE(1570),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3237),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2488),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2492),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2494),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2496),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1571] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(12819),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1571),
    [sym_block_comment] = STATE(1571),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1572] = {
    [sym_inline_modifier] = STATE(2330),
    [sym__indentable_expression] = STATE(12580),
    [sym_block] = STATE(6675),
    [sym_indented_block] = STATE(12499),
    [sym_indented_cases] = STATE(12499),
    [sym_expression] = STATE(12486),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1572),
    [sym_block_comment] = STATE(1572),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2392),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3280),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1573] = {
    [sym_inline_modifier] = STATE(2321),
    [sym__indentable_expression] = STATE(11953),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1573),
    [sym_block_comment] = STATE(1573),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1574] = {
    [sym_inline_modifier] = STATE(2321),
    [sym__indentable_expression] = STATE(12119),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1574),
    [sym_block_comment] = STATE(1574),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1575] = {
    [sym_inline_modifier] = STATE(2321),
    [sym__indentable_expression] = STATE(12061),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1575),
    [sym_block_comment] = STATE(1575),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1576] = {
    [sym_inline_modifier] = STATE(2321),
    [sym__indentable_expression] = STATE(12086),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1576),
    [sym_block_comment] = STATE(1576),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1577] = {
    [sym_inline_modifier] = STATE(2321),
    [sym__indentable_expression] = STATE(12093),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1577),
    [sym_block_comment] = STATE(1577),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1578] = {
    [sym_inline_modifier] = STATE(2321),
    [sym__indentable_expression] = STATE(12125),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1578),
    [sym_block_comment] = STATE(1578),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1579] = {
    [sym_inline_modifier] = STATE(2321),
    [sym__indentable_expression] = STATE(11850),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1579),
    [sym_block_comment] = STATE(1579),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1580] = {
    [sym_inline_modifier] = STATE(2321),
    [sym__indentable_expression] = STATE(11852),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1580),
    [sym_block_comment] = STATE(1580),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1581] = {
    [sym_inline_modifier] = STATE(2321),
    [sym__indentable_expression] = STATE(11901),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1581),
    [sym_block_comment] = STATE(1581),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1582] = {
    [sym_inline_modifier] = STATE(2321),
    [sym__indentable_expression] = STATE(12022),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1582),
    [sym_block_comment] = STATE(1582),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1583] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(14363),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1583),
    [sym_block_comment] = STATE(1583),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1584] = {
    [sym_inline_modifier] = STATE(2322),
    [sym__indentable_expression] = STATE(12892),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1584),
    [sym_block_comment] = STATE(1584),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1585] = {
    [sym_inline_modifier] = STATE(2322),
    [sym__indentable_expression] = STATE(12918),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1585),
    [sym_block_comment] = STATE(1585),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1586] = {
    [sym_inline_modifier] = STATE(2322),
    [sym__indentable_expression] = STATE(12919),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1586),
    [sym_block_comment] = STATE(1586),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1587] = {
    [sym_inline_modifier] = STATE(2322),
    [sym__indentable_expression] = STATE(12920),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1587),
    [sym_block_comment] = STATE(1587),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1588] = {
    [sym_inline_modifier] = STATE(2322),
    [sym__indentable_expression] = STATE(12923),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1588),
    [sym_block_comment] = STATE(1588),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1589] = {
    [sym_inline_modifier] = STATE(2322),
    [sym__indentable_expression] = STATE(12935),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1589),
    [sym_block_comment] = STATE(1589),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1590] = {
    [sym_inline_modifier] = STATE(2322),
    [sym__indentable_expression] = STATE(12939),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1590),
    [sym_block_comment] = STATE(1590),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1591] = {
    [sym_inline_modifier] = STATE(2322),
    [sym__indentable_expression] = STATE(12940),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1591),
    [sym_block_comment] = STATE(1591),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1592] = {
    [sym_inline_modifier] = STATE(2322),
    [sym__indentable_expression] = STATE(12942),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1592),
    [sym_block_comment] = STATE(1592),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1593] = {
    [sym_inline_modifier] = STATE(2322),
    [sym__indentable_expression] = STATE(12946),
    [sym_block] = STATE(6910),
    [sym_indented_block] = STATE(12729),
    [sym_indented_cases] = STATE(12729),
    [sym_expression] = STATE(12395),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1593),
    [sym_block_comment] = STATE(1593),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2138),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1594] = {
    [sym_inline_modifier] = STATE(2342),
    [sym__indentable_expression] = STATE(13679),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6017),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15961),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9804),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5210),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(1594),
    [sym_block_comment] = STATE(1594),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(2380),
    [anon_sym_while] = ACTIONS(2338),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2342),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(2346),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2350),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [1595] = {
    [sym_inline_modifier] = STATE(2323),
    [sym__indentable_expression] = STATE(13816),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8282),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15898),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10750),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(6686),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9873),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1595),
    [sym_block_comment] = STATE(1595),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2322),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2330),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2332),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2334),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1596] = {
    [sym_inline_modifier] = STATE(2323),
    [sym__indentable_expression] = STATE(13731),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8282),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15898),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10750),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(6686),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9873),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1596),
    [sym_block_comment] = STATE(1596),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2322),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2330),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2332),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2334),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1597] = {
    [sym_inline_modifier] = STATE(2323),
    [sym__indentable_expression] = STATE(13751),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8282),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15898),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10750),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(6686),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9873),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1597),
    [sym_block_comment] = STATE(1597),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2322),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2330),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2332),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2334),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1598] = {
    [sym_inline_modifier] = STATE(2323),
    [sym__indentable_expression] = STATE(13795),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8282),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15898),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10750),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(6686),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9873),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1598),
    [sym_block_comment] = STATE(1598),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2322),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2330),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2332),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2334),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1599] = {
    [sym_inline_modifier] = STATE(2323),
    [sym__indentable_expression] = STATE(13634),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8282),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15898),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10750),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(6686),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9873),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1599),
    [sym_block_comment] = STATE(1599),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2322),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2330),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2332),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2334),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1600] = {
    [sym_inline_modifier] = STATE(2323),
    [sym__indentable_expression] = STATE(13724),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8282),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15898),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10750),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(6686),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9873),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1600),
    [sym_block_comment] = STATE(1600),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2322),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2330),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2332),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2334),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1601] = {
    [sym_inline_modifier] = STATE(2323),
    [sym__indentable_expression] = STATE(13787),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8282),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15898),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10750),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(6686),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9873),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1601),
    [sym_block_comment] = STATE(1601),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2322),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2330),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2332),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2334),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1602] = {
    [sym_inline_modifier] = STATE(2323),
    [sym__indentable_expression] = STATE(13789),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8282),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15898),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10750),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(6686),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9873),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1602),
    [sym_block_comment] = STATE(1602),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2322),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2330),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2332),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2334),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1603] = {
    [sym_inline_modifier] = STATE(2323),
    [sym__indentable_expression] = STATE(13812),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8282),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15898),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10750),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(6686),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9873),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1603),
    [sym_block_comment] = STATE(1603),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2322),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2330),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2332),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2334),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1604] = {
    [sym_inline_modifier] = STATE(2323),
    [sym__indentable_expression] = STATE(13633),
    [sym_block] = STATE(8786),
    [sym_indented_block] = STATE(13764),
    [sym_indented_cases] = STATE(13764),
    [sym_expression] = STATE(13498),
    [sym__simple_expression] = STATE(8282),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15898),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10750),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(6686),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9873),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1604),
    [sym_block_comment] = STATE(1604),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2322),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2330),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2332),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2334),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2218),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1605] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(14295),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1605),
    [sym_block_comment] = STATE(1605),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1606] = {
    [sym_inline_modifier] = STATE(2302),
    [sym__indentable_expression] = STATE(14555),
    [sym_block] = STATE(9416),
    [sym_indented_block] = STATE(13860),
    [sym_indented_cases] = STATE(13860),
    [sym_expression] = STATE(13657),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1606),
    [sym_block_comment] = STATE(1606),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(744),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1607] = {
    [sym_inline_modifier] = STATE(2325),
    [sym__indentable_expression] = STATE(13173),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1607),
    [sym_block_comment] = STATE(1607),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1608] = {
    [sym_inline_modifier] = STATE(2325),
    [sym__indentable_expression] = STATE(13219),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1608),
    [sym_block_comment] = STATE(1608),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1609] = {
    [sym_inline_modifier] = STATE(2325),
    [sym__indentable_expression] = STATE(13227),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1609),
    [sym_block_comment] = STATE(1609),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1610] = {
    [sym_inline_modifier] = STATE(2325),
    [sym__indentable_expression] = STATE(13232),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1610),
    [sym_block_comment] = STATE(1610),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1611] = {
    [sym_inline_modifier] = STATE(2325),
    [sym__indentable_expression] = STATE(13249),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1611),
    [sym_block_comment] = STATE(1611),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1612] = {
    [sym_inline_modifier] = STATE(2325),
    [sym__indentable_expression] = STATE(13292),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1612),
    [sym_block_comment] = STATE(1612),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1613] = {
    [sym_inline_modifier] = STATE(2325),
    [sym__indentable_expression] = STATE(13312),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1613),
    [sym_block_comment] = STATE(1613),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1614] = {
    [sym_inline_modifier] = STATE(2325),
    [sym__indentable_expression] = STATE(13313),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1614),
    [sym_block_comment] = STATE(1614),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1615] = {
    [sym_inline_modifier] = STATE(2325),
    [sym__indentable_expression] = STATE(13319),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1615),
    [sym_block_comment] = STATE(1615),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1616] = {
    [sym_inline_modifier] = STATE(2325),
    [sym__indentable_expression] = STATE(13252),
    [sym_block] = STATE(7476),
    [sym_indented_block] = STATE(13169),
    [sym_indented_cases] = STATE(13169),
    [sym_expression] = STATE(12772),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1616),
    [sym_block_comment] = STATE(1616),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2252),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1617] = {
    [sym_inline_modifier] = STATE(2342),
    [sym__indentable_expression] = STATE(13688),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6017),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15961),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9804),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5210),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(1617),
    [sym_block_comment] = STATE(1617),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(2380),
    [anon_sym_while] = ACTIONS(2338),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2342),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(2346),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2350),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [1618] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13679),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6190),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15978),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9770),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5440),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8474),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(1618),
    [sym_block_comment] = STATE(1618),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(1924),
    [anon_sym_while] = ACTIONS(1926),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1930),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1936),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(1938),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [1619] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13688),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6190),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15978),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9770),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5440),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8474),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(1619),
    [sym_block_comment] = STATE(1619),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(1924),
    [anon_sym_while] = ACTIONS(1926),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1930),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1936),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(1938),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [1620] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13689),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6190),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15978),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9770),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5440),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8474),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(1620),
    [sym_block_comment] = STATE(1620),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(1924),
    [anon_sym_while] = ACTIONS(1926),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1930),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1936),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(1938),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [1621] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13690),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6190),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15978),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9770),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5440),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8474),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(1621),
    [sym_block_comment] = STATE(1621),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(1924),
    [anon_sym_while] = ACTIONS(1926),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1930),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1936),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(1938),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [1622] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13694),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6190),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15978),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9770),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5440),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8474),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(1622),
    [sym_block_comment] = STATE(1622),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(1924),
    [anon_sym_while] = ACTIONS(1926),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1930),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1936),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(1938),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [1623] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13714),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6190),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15978),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9770),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5440),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8474),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(1623),
    [sym_block_comment] = STATE(1623),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(1924),
    [anon_sym_while] = ACTIONS(1926),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1930),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1936),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(1938),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [1624] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13717),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6190),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15978),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9770),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5440),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8474),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(1624),
    [sym_block_comment] = STATE(1624),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(1924),
    [anon_sym_while] = ACTIONS(1926),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1930),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1936),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(1938),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [1625] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13718),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6190),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15978),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9770),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5440),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8474),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(1625),
    [sym_block_comment] = STATE(1625),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(1924),
    [anon_sym_while] = ACTIONS(1926),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1930),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1936),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(1938),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [1626] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13720),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6190),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15978),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9770),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5440),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8474),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(1626),
    [sym_block_comment] = STATE(1626),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(1924),
    [anon_sym_while] = ACTIONS(1926),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1930),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1936),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(1938),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [1627] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13721),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6190),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15978),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9770),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5440),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8474),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(1627),
    [sym_block_comment] = STATE(1627),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(1924),
    [anon_sym_while] = ACTIONS(1926),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1930),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1936),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(1938),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [1628] = {
    [sym_inline_modifier] = STATE(2342),
    [sym__indentable_expression] = STATE(13689),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6017),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15961),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9804),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5210),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(1628),
    [sym_block_comment] = STATE(1628),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(2380),
    [anon_sym_while] = ACTIONS(2338),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2342),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(2346),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2350),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [1629] = {
    [sym_inline_modifier] = STATE(2327),
    [sym__indentable_expression] = STATE(11985),
    [sym_block] = STATE(9357),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(13735),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1629),
    [sym_block_comment] = STATE(1629),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1630] = {
    [sym_inline_modifier] = STATE(2327),
    [sym__indentable_expression] = STATE(11996),
    [sym_block] = STATE(9357),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(13735),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1630),
    [sym_block_comment] = STATE(1630),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1631] = {
    [sym_inline_modifier] = STATE(2327),
    [sym__indentable_expression] = STATE(11998),
    [sym_block] = STATE(9357),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(13735),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1631),
    [sym_block_comment] = STATE(1631),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1632] = {
    [sym_inline_modifier] = STATE(2327),
    [sym__indentable_expression] = STATE(11999),
    [sym_block] = STATE(9357),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(13735),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1632),
    [sym_block_comment] = STATE(1632),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1633] = {
    [sym_inline_modifier] = STATE(2327),
    [sym__indentable_expression] = STATE(12002),
    [sym_block] = STATE(9357),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(13735),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1633),
    [sym_block_comment] = STATE(1633),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1634] = {
    [sym_inline_modifier] = STATE(2327),
    [sym__indentable_expression] = STATE(12019),
    [sym_block] = STATE(9357),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(13735),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1634),
    [sym_block_comment] = STATE(1634),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1635] = {
    [sym_inline_modifier] = STATE(2327),
    [sym__indentable_expression] = STATE(12028),
    [sym_block] = STATE(9357),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(13735),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1635),
    [sym_block_comment] = STATE(1635),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1636] = {
    [sym_inline_modifier] = STATE(2327),
    [sym__indentable_expression] = STATE(12029),
    [sym_block] = STATE(9357),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(13735),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1636),
    [sym_block_comment] = STATE(1636),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1637] = {
    [sym_inline_modifier] = STATE(2327),
    [sym__indentable_expression] = STATE(12031),
    [sym_block] = STATE(9357),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(13735),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1637),
    [sym_block_comment] = STATE(1637),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1638] = {
    [sym_inline_modifier] = STATE(2327),
    [sym__indentable_expression] = STATE(12035),
    [sym_block] = STATE(9357),
    [sym_indented_block] = STATE(11967),
    [sym_indented_cases] = STATE(11967),
    [sym_expression] = STATE(13735),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1638),
    [sym_block_comment] = STATE(1638),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2242),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1639] = {
    [sym_inline_modifier] = STATE(2286),
    [sym__indentable_expression] = STATE(12769),
    [sym_block] = STATE(7873),
    [sym_indented_block] = STATE(13006),
    [sym_indented_cases] = STATE(13006),
    [sym_expression] = STATE(12850),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1639),
    [sym_block_comment] = STATE(1639),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3278),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1640] = {
    [sym_inline_modifier] = STATE(2342),
    [sym__indentable_expression] = STATE(13690),
    [sym_block] = STATE(8894),
    [sym_indented_block] = STATE(13666),
    [sym_indented_cases] = STATE(13666),
    [sym_expression] = STATE(13409),
    [sym__simple_expression] = STATE(6017),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15961),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9804),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5210),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(1640),
    [sym_block_comment] = STATE(1640),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(2380),
    [anon_sym_while] = ACTIONS(2338),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2342),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(2346),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2350),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2382),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [1641] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(13331),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1641),
    [sym_block_comment] = STATE(1641),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1642] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(13523),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1642),
    [sym_block_comment] = STATE(1642),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1643] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(13596),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1643),
    [sym_block_comment] = STATE(1643),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1644] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(13620),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1644),
    [sym_block_comment] = STATE(1644),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1645] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(13364),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1645),
    [sym_block_comment] = STATE(1645),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1646] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(13493),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1646),
    [sym_block_comment] = STATE(1646),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1647] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(13514),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1647),
    [sym_block_comment] = STATE(1647),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1648] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(13517),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1648),
    [sym_block_comment] = STATE(1648),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1649] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(13532),
    [sym_block] = STATE(8472),
    [sym_indented_block] = STATE(13525),
    [sym_indented_cases] = STATE(13525),
    [sym_expression] = STATE(13263),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1649),
    [sym_block_comment] = STATE(1649),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2170),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1650] = {
    [sym_inline_modifier] = STATE(2284),
    [sym__indentable_expression] = STATE(13327),
    [sym_block] = STATE(6602),
    [sym_indented_block] = STATE(11906),
    [sym_indented_cases] = STATE(11906),
    [sym_expression] = STATE(11857),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1650),
    [sym_block_comment] = STATE(1650),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1651] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17842),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1651),
    [sym_block_comment] = STATE(1651),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3322),
    [anon_sym_RPAREN] = ACTIONS(3324),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1652] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16391),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1652),
    [sym_block_comment] = STATE(1652),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3326),
    [anon_sym_RPAREN] = ACTIONS(3328),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1653] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16600),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1653),
    [sym_block_comment] = STATE(1653),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3330),
    [anon_sym_RPAREN] = ACTIONS(3332),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1654] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16500),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1654),
    [sym_block_comment] = STATE(1654),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3334),
    [anon_sym_RPAREN] = ACTIONS(3336),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1655] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16837),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1655),
    [sym_block_comment] = STATE(1655),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3338),
    [anon_sym_RPAREN] = ACTIONS(3340),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1656] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17099),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1656),
    [sym_block_comment] = STATE(1656),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3342),
    [anon_sym_RPAREN] = ACTIONS(3344),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1657] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17039),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1657),
    [sym_block_comment] = STATE(1657),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3346),
    [anon_sym_RPAREN] = ACTIONS(3348),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1658] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17234),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1658),
    [sym_block_comment] = STATE(1658),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3350),
    [anon_sym_RPAREN] = ACTIONS(3352),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1659] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17528),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1659),
    [sym_block_comment] = STATE(1659),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3354),
    [anon_sym_RPAREN] = ACTIONS(3356),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1660] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17341),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1660),
    [sym_block_comment] = STATE(1660),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3358),
    [anon_sym_RPAREN] = ACTIONS(3360),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1661] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17438),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1661),
    [sym_block_comment] = STATE(1661),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3362),
    [anon_sym_RPAREN] = ACTIONS(3364),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1662] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(7476),
    [sym_expression] = STATE(14741),
    [sym__simple_expression] = STATE(4888),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16629),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(8532),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4560),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(6622),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1662),
    [sym_block_comment] = STATE(1662),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_COLON] = ACTIONS(1114),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1136),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1663] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17594),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1663),
    [sym_block_comment] = STATE(1663),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3366),
    [anon_sym_RPAREN] = ACTIONS(3368),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1664] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17722),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1664),
    [sym_block_comment] = STATE(1664),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3370),
    [anon_sym_RPAREN] = ACTIONS(3372),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1665] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16196),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1665),
    [sym_block_comment] = STATE(1665),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3374),
    [anon_sym_RPAREN] = ACTIONS(3376),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1666] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16248),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1666),
    [sym_block_comment] = STATE(1666),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3378),
    [anon_sym_RPAREN] = ACTIONS(3380),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1667] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(15792),
    [sym__simple_expression] = STATE(4505),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17344),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(6744),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4348),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(5254),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1667),
    [sym_block_comment] = STATE(1667),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_COLON] = ACTIONS(934),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(956),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1668] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16328),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1668),
    [sym_block_comment] = STATE(1668),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3382),
    [anon_sym_RPAREN] = ACTIONS(3384),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1669] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16422),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1669),
    [sym_block_comment] = STATE(1669),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3386),
    [anon_sym_RPAREN] = ACTIONS(3388),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1670] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17621),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1670),
    [sym_block_comment] = STATE(1670),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3390),
    [anon_sym_RPAREN] = ACTIONS(3392),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1671] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16518),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1671),
    [sym_block_comment] = STATE(1671),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3394),
    [anon_sym_RPAREN] = ACTIONS(3396),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1672] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16608),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1672),
    [sym_block_comment] = STATE(1672),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3398),
    [anon_sym_RPAREN] = ACTIONS(3400),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1673] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16690),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1673),
    [sym_block_comment] = STATE(1673),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3402),
    [anon_sym_RPAREN] = ACTIONS(3404),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1674] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17274),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1674),
    [sym_block_comment] = STATE(1674),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3406),
    [anon_sym_RPAREN] = ACTIONS(3408),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1675] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16754),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1675),
    [sym_block_comment] = STATE(1675),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3410),
    [anon_sym_RPAREN] = ACTIONS(3412),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1676] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(14979),
    [sym__simple_expression] = STATE(4586),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17870),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(7719),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4451),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(5753),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1676),
    [sym_block_comment] = STATE(1676),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_COLON] = ACTIONS(1042),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1064),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1677] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16821),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1677),
    [sym_block_comment] = STATE(1677),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3414),
    [anon_sym_RPAREN] = ACTIONS(3416),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1678] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16890),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1678),
    [sym_block_comment] = STATE(1678),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3418),
    [anon_sym_RPAREN] = ACTIONS(3420),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1679] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16924),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1679),
    [sym_block_comment] = STATE(1679),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3422),
    [anon_sym_RPAREN] = ACTIONS(3424),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1680] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17725),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1680),
    [sym_block_comment] = STATE(1680),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3426),
    [anon_sym_RPAREN] = ACTIONS(3428),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1681] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17033),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1681),
    [sym_block_comment] = STATE(1681),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3430),
    [anon_sym_RPAREN] = ACTIONS(3432),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1682] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17073),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1682),
    [sym_block_comment] = STATE(1682),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3434),
    [anon_sym_RPAREN] = ACTIONS(3436),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1683] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8894),
    [sym_expression] = STATE(14814),
    [sym__simple_expression] = STATE(5772),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16649),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9337),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8069),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1683),
    [sym_block_comment] = STATE(1683),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_COLON] = ACTIONS(1696),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [1684] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17091),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1684),
    [sym_block_comment] = STATE(1684),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3438),
    [anon_sym_RPAREN] = ACTIONS(3440),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1685] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17151),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1685),
    [sym_block_comment] = STATE(1685),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3442),
    [anon_sym_RPAREN] = ACTIONS(3444),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1686] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17170),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1686),
    [sym_block_comment] = STATE(1686),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3446),
    [anon_sym_RPAREN] = ACTIONS(3448),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1687] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17821),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1687),
    [sym_block_comment] = STATE(1687),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3450),
    [anon_sym_RPAREN] = ACTIONS(3452),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1688] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17327),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1688),
    [sym_block_comment] = STATE(1688),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3454),
    [anon_sym_RPAREN] = ACTIONS(3456),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1689] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17492),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1689),
    [sym_block_comment] = STATE(1689),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3458),
    [anon_sym_RPAREN] = ACTIONS(3460),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1690] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17836),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1690),
    [sym_block_comment] = STATE(1690),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3462),
    [anon_sym_RPAREN] = ACTIONS(3464),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1691] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16278),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1691),
    [sym_block_comment] = STATE(1691),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3466),
    [anon_sym_RPAREN] = ACTIONS(3468),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1692] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17814),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1692),
    [sym_block_comment] = STATE(1692),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3470),
    [anon_sym_RPAREN] = ACTIONS(3472),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1693] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17699),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1693),
    [sym_block_comment] = STATE(1693),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3474),
    [anon_sym_RPAREN] = ACTIONS(3476),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1694] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17693),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1694),
    [sym_block_comment] = STATE(1694),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3478),
    [anon_sym_RPAREN] = ACTIONS(3480),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1695] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8399),
    [sym_expression] = STATE(15115),
    [sym__simple_expression] = STATE(5374),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16745),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9325),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4740),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(6693),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1695),
    [sym_block_comment] = STATE(1695),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_COLON] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1358),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1696] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16968),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1696),
    [sym_block_comment] = STATE(1696),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3482),
    [anon_sym_RPAREN] = ACTIONS(3484),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1697] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16770),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1697),
    [sym_block_comment] = STATE(1697),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3486),
    [anon_sym_RPAREN] = ACTIONS(3488),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1698] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9357),
    [sym_expression] = STATE(14901),
    [sym__simple_expression] = STATE(6169),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16669),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10075),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5076),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8690),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1698),
    [sym_block_comment] = STATE(1698),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_COLON] = ACTIONS(1640),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1662),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1699] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16186),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1699),
    [sym_block_comment] = STATE(1699),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3490),
    [anon_sym_RPAREN] = ACTIONS(3492),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1700] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17463),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1700),
    [sym_block_comment] = STATE(1700),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3494),
    [anon_sym_RPAREN] = ACTIONS(3496),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1701] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16330),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1701),
    [sym_block_comment] = STATE(1701),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3498),
    [anon_sym_RPAREN] = ACTIONS(3500),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1702] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(15448),
    [sym__simple_expression] = STATE(6547),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17534),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9791),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5294),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8672),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1702),
    [sym_block_comment] = STATE(1702),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_COLON] = ACTIONS(1840),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(1844),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1703] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(15149),
    [sym__simple_expression] = STATE(5336),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17474),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(8864),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(4613),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(6807),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1703),
    [sym_block_comment] = STATE(1703),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_COLON] = ACTIONS(1482),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1504),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1704] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16851),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1704),
    [sym_block_comment] = STATE(1704),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3502),
    [anon_sym_RPAREN] = ACTIONS(3504),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1705] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16275),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1705),
    [sym_block_comment] = STATE(1705),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3506),
    [anon_sym_RPAREN] = ACTIONS(3508),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1706] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17034),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1706),
    [sym_block_comment] = STATE(1706),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3510),
    [anon_sym_RPAREN] = ACTIONS(3512),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1707] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16303),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1707),
    [sym_block_comment] = STATE(1707),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3514),
    [anon_sym_RPAREN] = ACTIONS(3516),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1708] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17487),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1708),
    [sym_block_comment] = STATE(1708),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3518),
    [anon_sym_RPAREN] = ACTIONS(3520),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1709] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17496),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1709),
    [sym_block_comment] = STATE(1709),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3522),
    [anon_sym_RPAREN] = ACTIONS(3524),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1710] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(14981),
    [sym__simple_expression] = STATE(4522),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16688),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(7058),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4278),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(5051),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1710),
    [sym_block_comment] = STATE(1710),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_COLON] = ACTIONS(970),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(992),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1711] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16437),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1711),
    [sym_block_comment] = STATE(1711),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3526),
    [anon_sym_RPAREN] = ACTIONS(3528),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1712] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(15235),
    [sym__simple_expression] = STATE(5251),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16237),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9091),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(4665),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(7050),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1712),
    [sym_block_comment] = STATE(1712),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_COLON] = ACTIONS(1372),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(1394),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1713] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16522),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1713),
    [sym_block_comment] = STATE(1713),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3530),
    [anon_sym_RPAREN] = ACTIONS(3532),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1714] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17539),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1714),
    [sym_block_comment] = STATE(1714),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3534),
    [anon_sym_RPAREN] = ACTIONS(3536),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1715] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16909),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1715),
    [sym_block_comment] = STATE(1715),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3538),
    [anon_sym_RPAREN] = ACTIONS(3540),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1716] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17133),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1716),
    [sym_block_comment] = STATE(1716),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3542),
    [anon_sym_RPAREN] = ACTIONS(3544),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1717] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16574),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1717),
    [sym_block_comment] = STATE(1717),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3546),
    [anon_sym_RPAREN] = ACTIONS(3548),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1718] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16457),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1718),
    [sym_block_comment] = STATE(1718),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_RPAREN] = ACTIONS(3552),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1719] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17558),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1719),
    [sym_block_comment] = STATE(1719),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3554),
    [anon_sym_RPAREN] = ACTIONS(3556),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1720] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17160),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1720),
    [sym_block_comment] = STATE(1720),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3558),
    [anon_sym_RPAREN] = ACTIONS(3560),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1721] = {
    [sym_inline_modifier] = STATE(2318),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(13377),
    [sym__simple_expression] = STATE(8653),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(16129),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10722),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(7377),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9808),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1721),
    [sym_block_comment] = STATE(1721),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2200),
    [anon_sym_for] = ACTIONS(2202),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2206),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2210),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(1156),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1722] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(15037),
    [sym__simple_expression] = STATE(4921),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16707),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(8317),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(4485),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(6070),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1722),
    [sym_block_comment] = STATE(1722),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_COLON] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1302),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1723] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16672),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1723),
    [sym_block_comment] = STATE(1723),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3562),
    [anon_sym_RPAREN] = ACTIONS(3564),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1724] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17057),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1724),
    [sym_block_comment] = STATE(1724),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3566),
    [anon_sym_RPAREN] = ACTIONS(3568),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1725] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17527),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1725),
    [sym_block_comment] = STATE(1725),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3570),
    [anon_sym_RPAREN] = ACTIONS(3572),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1726] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16387),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1726),
    [sym_block_comment] = STATE(1726),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3574),
    [anon_sym_RPAREN] = ACTIONS(3576),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1727] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(15448),
    [sym__simple_expression] = STATE(6547),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17534),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9791),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5294),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8672),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1727),
    [sym_block_comment] = STATE(1727),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_COLON] = ACTIONS(1840),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(1844),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1728] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16757),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1728),
    [sym_block_comment] = STATE(1728),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3578),
    [anon_sym_RPAREN] = ACTIONS(3580),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1729] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17411),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1729),
    [sym_block_comment] = STATE(1729),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3582),
    [anon_sym_RPAREN] = ACTIONS(3584),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1730] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(15287),
    [sym__simple_expression] = STATE(4844),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16765),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(8163),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(4482),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(6629),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1730),
    [sym_block_comment] = STATE(1730),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_COLON] = ACTIONS(1604),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(1606),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1731] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16211),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1731),
    [sym_block_comment] = STATE(1731),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3586),
    [anon_sym_RPAREN] = ACTIONS(3588),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1732] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16633),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1732),
    [sym_block_comment] = STATE(1732),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3590),
    [anon_sym_RPAREN] = ACTIONS(3592),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1733] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16789),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1733),
    [sym_block_comment] = STATE(1733),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3594),
    [anon_sym_RPAREN] = ACTIONS(3596),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1734] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16854),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1734),
    [sym_block_comment] = STATE(1734),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3598),
    [anon_sym_RPAREN] = ACTIONS(3600),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1735] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17067),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1735),
    [sym_block_comment] = STATE(1735),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3602),
    [anon_sym_RPAREN] = ACTIONS(3604),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1736] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16763),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1736),
    [sym_block_comment] = STATE(1736),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3606),
    [anon_sym_RPAREN] = ACTIONS(3608),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1737] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17236),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1737),
    [sym_block_comment] = STATE(1737),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3610),
    [anon_sym_RPAREN] = ACTIONS(3612),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1738] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17085),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1738),
    [sym_block_comment] = STATE(1738),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3614),
    [anon_sym_RPAREN] = ACTIONS(3616),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1739] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17414),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1739),
    [sym_block_comment] = STATE(1739),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3618),
    [anon_sym_RPAREN] = ACTIONS(3620),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1740] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17302),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1740),
    [sym_block_comment] = STATE(1740),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3622),
    [anon_sym_RPAREN] = ACTIONS(3624),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1741] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17570),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1741),
    [sym_block_comment] = STATE(1741),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3626),
    [anon_sym_RPAREN] = ACTIONS(3628),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1742] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17707),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1742),
    [sym_block_comment] = STATE(1742),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3630),
    [anon_sym_RPAREN] = ACTIONS(3632),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1743] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8838),
    [sym_expression] = STATE(15577),
    [sym__simple_expression] = STATE(5747),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16508),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9604),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(4998),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(7932),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1743),
    [sym_block_comment] = STATE(1743),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_COLON] = ACTIONS(1570),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1592),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1744] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16155),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1744),
    [sym_block_comment] = STATE(1744),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3634),
    [anon_sym_RPAREN] = ACTIONS(3636),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1745] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8472),
    [sym_expression] = STATE(15442),
    [sym__simple_expression] = STATE(5266),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16339),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9137),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7141),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1745),
    [sym_block_comment] = STATE(1745),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_COLON] = ACTIONS(1192),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1214),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1746] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16234),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1746),
    [sym_block_comment] = STATE(1746),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3638),
    [anon_sym_RPAREN] = ACTIONS(3640),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1747] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9584),
    [sym_expression] = STATE(15603),
    [sym__simple_expression] = STATE(6515),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17205),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9975),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5217),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8120),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1747),
    [sym_block_comment] = STATE(1747),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_COLON] = ACTIONS(1408),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(1430),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [1748] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16352),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1748),
    [sym_block_comment] = STATE(1748),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3642),
    [anon_sym_RPAREN] = ACTIONS(3644),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1749] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16436),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1749),
    [sym_block_comment] = STATE(1749),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3646),
    [anon_sym_RPAREN] = ACTIONS(3648),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1750] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16978),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1750),
    [sym_block_comment] = STATE(1750),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3650),
    [anon_sym_RPAREN] = ACTIONS(3652),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1751] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16514),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1751),
    [sym_block_comment] = STATE(1751),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3654),
    [anon_sym_RPAREN] = ACTIONS(3656),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1752] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(10014),
    [sym_expression] = STATE(14964),
    [sym__simple_expression] = STATE(7343),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17659),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10424),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5701),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8721),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1752),
    [sym_block_comment] = STATE(1752),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_COLON] = ACTIONS(2018),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2040),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [1753] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16562),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1753),
    [sym_block_comment] = STATE(1753),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3658),
    [anon_sym_RPAREN] = ACTIONS(3660),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1754] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9158),
    [sym_expression] = STATE(15583),
    [sym__simple_expression] = STATE(5648),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16362),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9616),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4954),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(7789),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1754),
    [sym_block_comment] = STATE(1754),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_COLON] = ACTIONS(1228),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1250),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [1755] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16612),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1755),
    [sym_block_comment] = STATE(1755),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3662),
    [anon_sym_RPAREN] = ACTIONS(3664),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1756] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16656),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1756),
    [sym_block_comment] = STATE(1756),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3666),
    [anon_sym_RPAREN] = ACTIONS(3668),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1757] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16712),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1757),
    [sym_block_comment] = STATE(1757),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3670),
    [anon_sym_RPAREN] = ACTIONS(3672),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1758] = {
    [sym_inline_modifier] = STATE(2323),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(13377),
    [sym__simple_expression] = STATE(8282),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15898),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10750),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(6686),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9873),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1758),
    [sym_block_comment] = STATE(1758),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2322),
    [anon_sym_while] = ACTIONS(1156),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2330),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_finally] = ACTIONS(1156),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2332),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2334),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1759] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16783),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1759),
    [sym_block_comment] = STATE(1759),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3674),
    [anon_sym_RPAREN] = ACTIONS(3676),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1760] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9961),
    [sym_expression] = STATE(15845),
    [sym__simple_expression] = STATE(6816),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16382),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10214),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5853),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(9112),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1760),
    [sym_block_comment] = STATE(1760),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_COLON] = ACTIONS(1848),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(1870),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [1761] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16842),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1761),
    [sym_block_comment] = STATE(1761),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3678),
    [anon_sym_RPAREN] = ACTIONS(3680),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1762] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17716),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1762),
    [sym_block_comment] = STATE(1762),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3682),
    [anon_sym_RPAREN] = ACTIONS(3684),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1763] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16910),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1763),
    [sym_block_comment] = STATE(1763),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3686),
    [anon_sym_RPAREN] = ACTIONS(3688),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1764] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17126),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1764),
    [sym_block_comment] = STATE(1764),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3690),
    [anon_sym_RPAREN] = ACTIONS(3692),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1765] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17026),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1765),
    [sym_block_comment] = STATE(1765),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3694),
    [anon_sym_RPAREN] = ACTIONS(3696),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1766] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(10212),
    [sym_expression] = STATE(15444),
    [sym__simple_expression] = STATE(7770),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16300),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10599),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6453),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9533),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1766),
    [sym_block_comment] = STATE(1766),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_COLON] = ACTIONS(2352),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(2356),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1767] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17111),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1767),
    [sym_block_comment] = STATE(1767),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3698),
    [anon_sym_RPAREN] = ACTIONS(3700),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1768] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17156),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1768),
    [sym_block_comment] = STATE(1768),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3702),
    [anon_sym_RPAREN] = ACTIONS(3704),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1769] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(15418),
    [sym__simple_expression] = STATE(4448),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16424),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(6001),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4267),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(4967),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1769),
    [sym_block_comment] = STATE(1769),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_COLON] = ACTIONS(890),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(920),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1770] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17195),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1770),
    [sym_block_comment] = STATE(1770),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3706),
    [anon_sym_RPAREN] = ACTIONS(3708),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1771] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17823),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1771),
    [sym_block_comment] = STATE(1771),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3710),
    [anon_sym_RPAREN] = ACTIONS(3712),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1772] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17247),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1772),
    [sym_block_comment] = STATE(1772),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3714),
    [anon_sym_RPAREN] = ACTIONS(3716),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1773] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16302),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1773),
    [sym_block_comment] = STATE(1773),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3718),
    [anon_sym_RPAREN] = ACTIONS(3720),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1774] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17297),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1774),
    [sym_block_comment] = STATE(1774),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3722),
    [anon_sym_RPAREN] = ACTIONS(3724),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1775] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17222),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1775),
    [sym_block_comment] = STATE(1775),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3726),
    [anon_sym_RPAREN] = ACTIONS(3728),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1776] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17368),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1776),
    [sym_block_comment] = STATE(1776),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3730),
    [anon_sym_RPAREN] = ACTIONS(3732),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1777] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(14982),
    [sym__simple_expression] = STATE(4644),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16445),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(7984),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4460),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(5866),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1777),
    [sym_block_comment] = STATE(1777),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_COLON] = ACTIONS(1078),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1100),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1778] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17478),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1778),
    [sym_block_comment] = STATE(1778),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3734),
    [anon_sym_RPAREN] = ACTIONS(3736),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1779] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17574),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1779),
    [sym_block_comment] = STATE(1779),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3738),
    [anon_sym_RPAREN] = ACTIONS(3740),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1780] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17669),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1780),
    [sym_block_comment] = STATE(1780),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3742),
    [anon_sym_RPAREN] = ACTIONS(3744),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1781] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17829),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1781),
    [sym_block_comment] = STATE(1781),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3746),
    [anon_sym_RPAREN] = ACTIONS(3748),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1782] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16534),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1782),
    [sym_block_comment] = STATE(1782),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3750),
    [anon_sym_RPAREN] = ACTIONS(3752),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1783] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17705),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1783),
    [sym_block_comment] = STATE(1783),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3754),
    [anon_sym_RPAREN] = ACTIONS(3756),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1784] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(15187),
    [sym__simple_expression] = STATE(4651),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16466),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(7392),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4462),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(5883),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1784),
    [sym_block_comment] = STATE(1784),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_COLON] = ACTIONS(1006),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1028),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1785] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16497),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1785),
    [sym_block_comment] = STATE(1785),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3758),
    [anon_sym_RPAREN] = ACTIONS(3760),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1786] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17171),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1786),
    [sym_block_comment] = STATE(1786),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3762),
    [anon_sym_RPAREN] = ACTIONS(3764),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1787] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1787),
    [sym_block_comment] = STATE(1787),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3766),
    [anon_sym_RPAREN] = ACTIONS(3768),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1788] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16416),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1788),
    [sym_block_comment] = STATE(1788),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3770),
    [anon_sym_RPAREN] = ACTIONS(3772),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1789] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(15287),
    [sym__simple_expression] = STATE(4844),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16765),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(8163),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(4482),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(6629),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1789),
    [sym_block_comment] = STATE(1789),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_COLON] = ACTIONS(1604),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(1606),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1790] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17293),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1790),
    [sym_block_comment] = STATE(1790),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3774),
    [anon_sym_RPAREN] = ACTIONS(3776),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1791] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16223),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1791),
    [sym_block_comment] = STATE(1791),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3778),
    [anon_sym_RPAREN] = ACTIONS(3780),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1792] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16616),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1792),
    [sym_block_comment] = STATE(1792),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3782),
    [anon_sym_RPAREN] = ACTIONS(3784),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1793] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(15408),
    [sym__simple_expression] = STATE(5733),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16487),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9453),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(4992),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(7902),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1793),
    [sym_block_comment] = STATE(1793),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_COLON] = ACTIONS(1806),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(1828),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1794] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16711),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1794),
    [sym_block_comment] = STATE(1794),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3786),
    [anon_sym_RPAREN] = ACTIONS(3788),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1795] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17087),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1795),
    [sym_block_comment] = STATE(1795),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3790),
    [anon_sym_RPAREN] = ACTIONS(3792),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1796] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17340),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1796),
    [sym_block_comment] = STATE(1796),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3794),
    [anon_sym_RPAREN] = ACTIONS(3796),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1797] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17431),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1797),
    [sym_block_comment] = STATE(1797),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3798),
    [anon_sym_RPAREN] = ACTIONS(3800),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1798] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17626),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1798),
    [sym_block_comment] = STATE(1798),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3802),
    [anon_sym_RPAREN] = ACTIONS(3804),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1799] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16332),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1799),
    [sym_block_comment] = STATE(1799),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_using] = ACTIONS(3806),
    [anon_sym_RPAREN] = ACTIONS(3808),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1800] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14150),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1800),
    [sym_block_comment] = STATE(1800),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3810),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1801] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14109),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1801),
    [sym_block_comment] = STATE(1801),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3814),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1802] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14027),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1802),
    [sym_block_comment] = STATE(1802),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3816),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1803] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14149),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1803),
    [sym_block_comment] = STATE(1803),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3818),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1804] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14098),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1804),
    [sym_block_comment] = STATE(1804),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3820),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1805] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14062),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1805),
    [sym_block_comment] = STATE(1805),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3822),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1806] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14103),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1806),
    [sym_block_comment] = STATE(1806),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3824),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1807] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14074),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1807),
    [sym_block_comment] = STATE(1807),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3826),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1808] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14035),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1808),
    [sym_block_comment] = STATE(1808),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3828),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1809] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14143),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1809),
    [sym_block_comment] = STATE(1809),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3830),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1810] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14036),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1810),
    [sym_block_comment] = STATE(1810),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3832),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1811] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14108),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1811),
    [sym_block_comment] = STATE(1811),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3828),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1812] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14111),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1812),
    [sym_block_comment] = STATE(1812),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3834),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1813] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14073),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1813),
    [sym_block_comment] = STATE(1813),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3836),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1814] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14086),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1814),
    [sym_block_comment] = STATE(1814),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3838),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1815] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14071),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1815),
    [sym_block_comment] = STATE(1815),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3828),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1816] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14034),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1816),
    [sym_block_comment] = STATE(1816),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3840),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1817] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(13654),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1817),
    [sym_block_comment] = STATE(1817),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(1156),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1818] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14015),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1818),
    [sym_block_comment] = STATE(1818),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3842),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1819] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14088),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1819),
    [sym_block_comment] = STATE(1819),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3844),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1820] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14159),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1820),
    [sym_block_comment] = STATE(1820),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3846),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1821] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14132),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1821),
    [sym_block_comment] = STATE(1821),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3848),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1822] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14069),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1822),
    [sym_block_comment] = STATE(1822),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3850),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1823] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14101),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1823),
    [sym_block_comment] = STATE(1823),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1824] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14145),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1824),
    [sym_block_comment] = STATE(1824),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3854),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1825] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14049),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1825),
    [sym_block_comment] = STATE(1825),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3856),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1826] = {
    [sym_inline_modifier] = STATE(2276),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(13654),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1826),
    [sym_block_comment] = STATE(1826),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_match] = ACTIONS(1156),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(1156),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1827] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14053),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1827),
    [sym_block_comment] = STATE(1827),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3858),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1828] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14125),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_binding] = STATE(15323),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(6779),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(9907),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1828),
    [sym_block_comment] = STATE(1828),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3860),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3812),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1829] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17110),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1829),
    [sym_block_comment] = STATE(1829),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1830] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16410),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1830),
    [sym_block_comment] = STATE(1830),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1831] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17509),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1831),
    [sym_block_comment] = STATE(1831),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1832] = {
    [sym_inline_modifier] = STATE(2288),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(13090),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1832),
    [sym_block_comment] = STATE(1832),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_yield] = ACTIONS(3862),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1833] = {
    [sym_inline_modifier] = STATE(2341),
    [sym_block] = STATE(7476),
    [sym_expression] = STATE(13012),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1833),
    [sym_block_comment] = STATE(1833),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_yield] = ACTIONS(3864),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1834] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16653),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1834),
    [sym_block_comment] = STATE(1834),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1835] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17090),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1835),
    [sym_block_comment] = STATE(1835),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1836] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16204),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1836),
    [sym_block_comment] = STATE(1836),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1837] = {
    [sym_inline_modifier] = STATE(2318),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(13461),
    [sym__simple_expression] = STATE(8653),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(16129),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10722),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(7377),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9808),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1837),
    [sym_block_comment] = STATE(1837),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2200),
    [anon_sym_for] = ACTIONS(2202),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2206),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2210),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_yield] = ACTIONS(3866),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1838] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17013),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1838),
    [sym_block_comment] = STATE(1838),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1839] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16469),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1839),
    [sym_block_comment] = STATE(1839),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1840] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1840),
    [sym_block_comment] = STATE(1840),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3868),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1841] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1841),
    [sym_block_comment] = STATE(1841),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3870),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1842] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16674),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1842),
    [sym_block_comment] = STATE(1842),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1843] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(13728),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1843),
    [sym_block_comment] = STATE(1843),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_yield] = ACTIONS(3872),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1844] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1844),
    [sym_block_comment] = STATE(1844),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3874),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1845] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16877),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1845),
    [sym_block_comment] = STATE(1845),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1846] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1846),
    [sym_block_comment] = STATE(1846),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3876),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1847] = {
    [sym_inline_modifier] = STATE(2306),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(13290),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1847),
    [sym_block_comment] = STATE(1847),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_yield] = ACTIONS(3878),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1848] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17139),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1848),
    [sym_block_comment] = STATE(1848),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1849] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16464),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1849),
    [sym_block_comment] = STATE(1849),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1850] = {
    [sym_inline_modifier] = STATE(2284),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(11867),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1850),
    [sym_block_comment] = STATE(1850),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_yield] = ACTIONS(3880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1851] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17295),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1851),
    [sym_block_comment] = STATE(1851),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1852] = {
    [sym_inline_modifier] = STATE(2311),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12821),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1852),
    [sym_block_comment] = STATE(1852),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_yield] = ACTIONS(3882),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1853] = {
    [sym_inline_modifier] = STATE(2302),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13814),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1853),
    [sym_block_comment] = STATE(1853),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_yield] = ACTIONS(3884),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1854] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17486),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1854),
    [sym_block_comment] = STATE(1854),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1855] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1855),
    [sym_block_comment] = STATE(1855),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3886),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1856] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16341),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1856),
    [sym_block_comment] = STATE(1856),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1857] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17601),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1857),
    [sym_block_comment] = STATE(1857),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1858] = {
    [sym_inline_modifier] = STATE(2319),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13814),
    [sym__simple_expression] = STATE(6682),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(15930),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10414),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5580),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9016),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1858),
    [sym_block_comment] = STATE(1858),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(3232),
    [anon_sym_while] = ACTIONS(3218),
    [anon_sym_for] = ACTIONS(3220),
    [anon_sym_try] = ACTIONS(3222),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(3224),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(3226),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(3228),
    [anon_sym_throw] = ACTIONS(3230),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_yield] = ACTIONS(3888),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1859] = {
    [sym_inline_modifier] = STATE(2290),
    [sym_block] = STATE(10014),
    [sym_expression] = STATE(13995),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1859),
    [sym_block_comment] = STATE(1859),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2184),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_yield] = ACTIONS(3890),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [1860] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17746),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1860),
    [sym_block_comment] = STATE(1860),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1861] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1861),
    [sym_block_comment] = STATE(1861),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3892),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1862] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16955),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1862),
    [sym_block_comment] = STATE(1862),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1863] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16181),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1863),
    [sym_block_comment] = STATE(1863),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1864] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17152),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1864),
    [sym_block_comment] = STATE(1864),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1865] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1865),
    [sym_block_comment] = STATE(1865),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3894),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1866] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16269),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1866),
    [sym_block_comment] = STATE(1866),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1867] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16489),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1867),
    [sym_block_comment] = STATE(1867),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1868] = {
    [sym_inline_modifier] = STATE(2334),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(12882),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1868),
    [sym_block_comment] = STATE(1868),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_yield] = ACTIONS(3896),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1869] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16374),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1869),
    [sym_block_comment] = STATE(1869),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1870] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17277),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1870),
    [sym_block_comment] = STATE(1870),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1871] = {
    [sym_inline_modifier] = STATE(2304),
    [sym_block] = STATE(9158),
    [sym_expression] = STATE(13356),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1871),
    [sym_block_comment] = STATE(1871),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(3898),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [1872] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16471),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1872),
    [sym_block_comment] = STATE(1872),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1873] = {
    [sym_inline_modifier] = STATE(2324),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13814),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(1873),
    [sym_block_comment] = STATE(1873),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_yield] = ACTIONS(3900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [1874] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17675),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1874),
    [sym_block_comment] = STATE(1874),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1875] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16536),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1875),
    [sym_block_comment] = STATE(1875),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1876] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17246),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1876),
    [sym_block_comment] = STATE(1876),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1877] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17549),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1877),
    [sym_block_comment] = STATE(1877),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1878] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16577),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1878),
    [sym_block_comment] = STATE(1878),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1879] = {
    [sym_inline_modifier] = STATE(2320),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12821),
    [sym__simple_expression] = STATE(6186),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16018),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9989),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5240),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8124),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1879),
    [sym_block_comment] = STATE(1879),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3237),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2488),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2492),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2494),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2496),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_yield] = ACTIONS(3902),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1880] = {
    [sym_inline_modifier] = STATE(2054),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(11896),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1880),
    [sym_block_comment] = STATE(1880),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_yield] = ACTIONS(3904),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1881] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16620),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1881),
    [sym_block_comment] = STATE(1881),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1882] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1882),
    [sym_block_comment] = STATE(1882),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3906),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1883] = {
    [sym_inline_modifier] = STATE(2308),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12821),
    [sym__simple_expression] = STATE(6086),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16088),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5234),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8197),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1883),
    [sym_block_comment] = STATE(1883),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3095),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3083),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3087),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(3089),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(3091),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_yield] = ACTIONS(3908),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1884] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16677),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1884),
    [sym_block_comment] = STATE(1884),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1885] = {
    [sym_inline_modifier] = STATE(2298),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(13290),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1885),
    [sym_block_comment] = STATE(1885),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(2066),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_yield] = ACTIONS(3910),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1886] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16596),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1886),
    [sym_block_comment] = STATE(1886),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1887] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16744),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1887),
    [sym_block_comment] = STATE(1887),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1888] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17165),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1888),
    [sym_block_comment] = STATE(1888),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1889] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1889),
    [sym_block_comment] = STATE(1889),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3912),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1890] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16793),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1890),
    [sym_block_comment] = STATE(1890),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1891] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1891),
    [sym_block_comment] = STATE(1891),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3914),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1892] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17356),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1892),
    [sym_block_comment] = STATE(1892),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1893] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16869),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1893),
    [sym_block_comment] = STATE(1893),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1894] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1894),
    [sym_block_comment] = STATE(1894),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3916),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1895] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17084),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1895),
    [sym_block_comment] = STATE(1895),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1896] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16931),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1896),
    [sym_block_comment] = STATE(1896),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1897] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1897),
    [sym_block_comment] = STATE(1897),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3918),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1898] = {
    [sym_inline_modifier] = STATE(2333),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(12882),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1898),
    [sym_block_comment] = STATE(1898),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_yield] = ACTIONS(3920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1899] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17040),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1899),
    [sym_block_comment] = STATE(1899),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1900] = {
    [sym_inline_modifier] = STATE(2321),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(11867),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1900),
    [sym_block_comment] = STATE(1900),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_yield] = ACTIONS(3922),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1901] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16470),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1901),
    [sym_block_comment] = STATE(1901),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1902] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17128),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1902),
    [sym_block_comment] = STATE(1902),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1903] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17676),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1903),
    [sym_block_comment] = STATE(1903),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1904] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1904),
    [sym_block_comment] = STATE(1904),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3924),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1905] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17166),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1905),
    [sym_block_comment] = STATE(1905),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1906] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1906),
    [sym_block_comment] = STATE(1906),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3926),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1907] = {
    [sym_inline_modifier] = STATE(2286),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12821),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1907),
    [sym_block_comment] = STATE(1907),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_yield] = ACTIONS(3928),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1908] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17212),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1908),
    [sym_block_comment] = STATE(1908),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1909] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17457),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1909),
    [sym_block_comment] = STATE(1909),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1910] = {
    [sym_inline_modifier] = STATE(2332),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(11896),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(1910),
    [sym_block_comment] = STATE(1910),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_yield] = ACTIONS(3930),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [1911] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17259),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1911),
    [sym_block_comment] = STATE(1911),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1912] = {
    [sym_inline_modifier] = STATE(2313),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(12505),
    [sym__simple_expression] = STATE(6055),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15856),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9737),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5346),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8338),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1912),
    [sym_block_comment] = STATE(1912),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1764),
    [anon_sym_while] = ACTIONS(1766),
    [anon_sym_for] = ACTIONS(1768),
    [anon_sym_try] = ACTIONS(1770),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(1772),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1776),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(1778),
    [anon_sym_throw] = ACTIONS(1780),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_yield] = ACTIONS(3932),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [1913] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1913),
    [sym_block_comment] = STATE(1913),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3934),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1914] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17321),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1914),
    [sym_block_comment] = STATE(1914),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1915] = {
    [sym_inline_modifier] = STATE(2296),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(12494),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1915),
    [sym_block_comment] = STATE(1915),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_yield] = ACTIONS(3936),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1916] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17223),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1916),
    [sym_block_comment] = STATE(1916),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1917] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17391),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1917),
    [sym_block_comment] = STATE(1917),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1918] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16718),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1918),
    [sym_block_comment] = STATE(1918),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1919] = {
    [sym_inline_modifier] = STATE(2330),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(12494),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1919),
    [sym_block_comment] = STATE(1919),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2392),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_yield] = ACTIONS(3938),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1920] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17511),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1920),
    [sym_block_comment] = STATE(1920),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1921] = {
    [sym_inline_modifier] = STATE(2322),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(12556),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1921),
    [sym_block_comment] = STATE(1921),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_yield] = ACTIONS(3940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1922] = {
    [sym_inline_modifier] = STATE(2292),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(13090),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1922),
    [sym_block_comment] = STATE(1922),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_yield] = ACTIONS(3942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1923] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17607),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1923),
    [sym_block_comment] = STATE(1923),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1924] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1924),
    [sym_block_comment] = STATE(1924),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3944),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1925] = {
    [sym_inline_modifier] = STATE(2309),
    [sym_block] = STATE(9961),
    [sym_expression] = STATE(13895),
    [sym__simple_expression] = STATE(6847),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15991),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(10631),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(10386),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5726),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(8783),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(1925),
    [sym_block_comment] = STATE(1925),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(2278),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2282),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(2286),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_macro] = ACTIONS(2288),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(2290),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2294),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_yield] = ACTIONS(3946),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [1926] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17720),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1926),
    [sym_block_comment] = STATE(1926),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1927] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16872),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1927),
    [sym_block_comment] = STATE(1927),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1928] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17550),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1928),
    [sym_block_comment] = STATE(1928),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1929] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17848),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1929),
    [sym_block_comment] = STATE(1929),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1930] = {
    [sym_inline_modifier] = STATE(2317),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(12556),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1930),
    [sym_block_comment] = STATE(1930),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_yield] = ACTIONS(3948),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [1931] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1931),
    [sym_block_comment] = STATE(1931),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3950),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1932] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17291),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1932),
    [sym_block_comment] = STATE(1932),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1933] = {
    [sym_inline_modifier] = STATE(2342),
    [sym_block] = STATE(8894),
    [sym_expression] = STATE(13576),
    [sym__simple_expression] = STATE(6017),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15961),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9804),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5210),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(1933),
    [sym_block_comment] = STATE(1933),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(2380),
    [anon_sym_while] = ACTIONS(2338),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2342),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(2346),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2350),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_yield] = ACTIONS(3952),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [1934] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16221),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1934),
    [sym_block_comment] = STATE(1934),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1935] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17380),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1935),
    [sym_block_comment] = STATE(1935),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1936] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17373),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1936),
    [sym_block_comment] = STATE(1936),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1937] = {
    [sym_inline_modifier] = STATE(2276),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(13728),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1937),
    [sym_block_comment] = STATE(1937),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_yield] = ACTIONS(3954),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1938] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16908),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1938),
    [sym_block_comment] = STATE(1938),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1939] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17383),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1939),
    [sym_block_comment] = STATE(1939),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1940] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17647),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1940),
    [sym_block_comment] = STATE(1940),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1941] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17650),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1941),
    [sym_block_comment] = STATE(1941),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1942] = {
    [sym_inline_modifier] = STATE(2323),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(13461),
    [sym__simple_expression] = STATE(8282),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15898),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10750),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(6686),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9873),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1942),
    [sym_block_comment] = STATE(1942),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2322),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2330),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2332),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2334),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_yield] = ACTIONS(3956),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1943] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16597),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1943),
    [sym_block_comment] = STATE(1943),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1944] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16324),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1944),
    [sym_block_comment] = STATE(1944),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1945] = {
    [sym_inline_modifier] = STATE(2335),
    [sym_block] = STATE(8838),
    [sym_expression] = STATE(13401),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1945),
    [sym_block_comment] = STATE(1945),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(2468),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_yield] = ACTIONS(3958),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1946] = {
    [sym_inline_modifier] = STATE(2339),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(12882),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(1946),
    [sym_block_comment] = STATE(1946),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_yield] = ACTIONS(3960),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [1947] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16766),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1947),
    [sym_block_comment] = STATE(1947),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1948] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16893),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1948),
    [sym_block_comment] = STATE(1948),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1949] = {
    [sym_inline_modifier] = STATE(2316),
    [sym_block] = STATE(8838),
    [sym_expression] = STATE(13401),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(1949),
    [sym_block_comment] = STATE(1949),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_yield] = ACTIONS(3962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1950] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17201),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1950),
    [sym_block_comment] = STATE(1950),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1951] = {
    [sym_inline_modifier] = STATE(2337),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(11626),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(1951),
    [sym_block_comment] = STATE(1951),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(3964),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [1952] = {
    [sym_inline_modifier] = STATE(2278),
    [sym_block] = STATE(9584),
    [sym_expression] = STATE(13723),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1952),
    [sym_block_comment] = STATE(1952),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_yield] = ACTIONS(3966),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [1953] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17421),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1953),
    [sym_block_comment] = STATE(1953),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1954] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1954),
    [sym_block_comment] = STATE(1954),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3968),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1955] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1955),
    [sym_block_comment] = STATE(1955),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3970),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1956] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17709),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1956),
    [sym_block_comment] = STATE(1956),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1957] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17750),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1957),
    [sym_block_comment] = STATE(1957),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1958] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17740),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1958),
    [sym_block_comment] = STATE(1958),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1959] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16245),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1959),
    [sym_block_comment] = STATE(1959),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1960] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17308),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1960),
    [sym_block_comment] = STATE(1960),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1961] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17681),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1961),
    [sym_block_comment] = STATE(1961),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1962] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16453),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1962),
    [sym_block_comment] = STATE(1962),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1963] = {
    [sym_inline_modifier] = STATE(2325),
    [sym_block] = STATE(7476),
    [sym_expression] = STATE(13012),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(1963),
    [sym_block_comment] = STATE(1963),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_yield] = ACTIONS(3972),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [1964] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1964),
    [sym_block_comment] = STATE(1964),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3974),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1965] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16679),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1965),
    [sym_block_comment] = STATE(1965),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1966] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16592),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1966),
    [sym_block_comment] = STATE(1966),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1967] = {
    [sym_inline_modifier] = STATE(2310),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(13290),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(1967),
    [sym_block_comment] = STATE(1967),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3131),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3290),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_yield] = ACTIONS(3976),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [1968] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16944),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1968),
    [sym_block_comment] = STATE(1968),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1969] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17846),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1969),
    [sym_block_comment] = STATE(1969),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1970] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16493),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1970),
    [sym_block_comment] = STATE(1970),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1971] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17164),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1971),
    [sym_block_comment] = STATE(1971),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1972] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1972),
    [sym_block_comment] = STATE(1972),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3978),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1973] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17244),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1973),
    [sym_block_comment] = STATE(1973),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1974] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17284),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1974),
    [sym_block_comment] = STATE(1974),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1975] = {
    [sym_inline_modifier] = STATE(2329),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(11867),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(1975),
    [sym_block_comment] = STATE(1975),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_yield] = ACTIONS(3980),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [1976] = {
    [sym_inline_modifier] = STATE(2300),
    [sym_block] = STATE(8472),
    [sym_expression] = STATE(13248),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(1976),
    [sym_block_comment] = STATE(1976),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_yield] = ACTIONS(3982),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [1977] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17372),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1977),
    [sym_block_comment] = STATE(1977),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1978] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17567),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1978),
    [sym_block_comment] = STATE(1978),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1979] = {
    [sym_inline_modifier] = STATE(2336),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(12494),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(1979),
    [sym_block_comment] = STATE(1979),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2100),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_yield] = ACTIONS(3984),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [1980] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17507),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1980),
    [sym_block_comment] = STATE(1980),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1981] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1981),
    [sym_block_comment] = STATE(1981),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3986),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1982] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1982),
    [sym_block_comment] = STATE(1982),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3988),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1983] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17634),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1983),
    [sym_block_comment] = STATE(1983),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1984] = {
    [sym_inline_modifier] = STATE(2326),
    [sym_block] = STATE(8894),
    [sym_expression] = STATE(13576),
    [sym__simple_expression] = STATE(6190),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15978),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9770),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5440),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8474),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(1984),
    [sym_block_comment] = STATE(1984),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(1924),
    [anon_sym_while] = ACTIONS(1926),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1930),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1936),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(1938),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_yield] = ACTIONS(3990),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [1985] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16192),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1985),
    [sym_block_comment] = STATE(1985),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1986] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17841),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1986),
    [sym_block_comment] = STATE(1986),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1987] = {
    [sym_inline_modifier] = STATE(2294),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(13090),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(1987),
    [sym_block_comment] = STATE(1987),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_yield] = ACTIONS(3992),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [1988] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1988),
    [sym_block_comment] = STATE(1988),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(3994),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1989] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16215),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1989),
    [sym_block_comment] = STATE(1989),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1990] = {
    [sym_inline_modifier] = STATE(2280),
    [sym_block] = STATE(10212),
    [sym_expression] = STATE(14046),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(1990),
    [sym_block_comment] = STATE(1990),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_yield] = ACTIONS(3996),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1991] = {
    [sym_inline_modifier] = STATE(2346),
    [sym_block] = STATE(8399),
    [sym_expression] = STATE(13260),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(1991),
    [sym_block_comment] = STATE(1991),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_yield] = ACTIONS(3998),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [1992] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16268),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1992),
    [sym_block_comment] = STATE(1992),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1993] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16185),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1993),
    [sym_block_comment] = STATE(1993),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1994] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16696),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1994),
    [sym_block_comment] = STATE(1994),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1995] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16366),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1995),
    [sym_block_comment] = STATE(1995),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1996] = {
    [sym_inline_modifier] = STATE(2315),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(13461),
    [sym__simple_expression] = STATE(6983),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15899),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10174),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(5823),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9043),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(1996),
    [sym_block_comment] = STATE(1996),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2446),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2450),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2452),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2456),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_yield] = ACTIONS(4000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [1997] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16173),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1997),
    [sym_block_comment] = STATE(1997),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1998] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16454),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(1998),
    [sym_block_comment] = STATE(1998),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [1999] = {
    [sym_inline_modifier] = STATE(2314),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(12556),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(1999),
    [sym_block_comment] = STATE(1999),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_yield] = ACTIONS(4002),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [2000] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16284),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2000),
    [sym_block_comment] = STATE(2000),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2001] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16548),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2001),
    [sym_block_comment] = STATE(2001),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2002] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16578),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2002),
    [sym_block_comment] = STATE(2002),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2003] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2003),
    [sym_block_comment] = STATE(2003),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(4004),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2004] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16619),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2004),
    [sym_block_comment] = STATE(2004),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2005] = {
    [sym_inline_modifier] = STATE(2327),
    [sym_block] = STATE(9357),
    [sym_expression] = STATE(13778),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(2005),
    [sym_block_comment] = STATE(2005),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_yield] = ACTIONS(4006),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [2006] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16212),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2006),
    [sym_block_comment] = STATE(2006),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2007] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16713),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2007),
    [sym_block_comment] = STATE(2007),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2008] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17258),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2008),
    [sym_block_comment] = STATE(2008),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2009] = {
    [sym_inline_modifier] = STATE(2312),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(11626),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(2009),
    [sym_block_comment] = STATE(2009),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(4008),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [2010] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16774),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2010),
    [sym_block_comment] = STATE(2010),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2011] = {
    [sym_inline_modifier] = STATE(2343),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(11626),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(2011),
    [sym_block_comment] = STATE(2011),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_yield] = ACTIONS(4010),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [2012] = {
    [sym_inline_modifier] = STATE(2345),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(11896),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(2012),
    [sym_block_comment] = STATE(2012),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_yield] = ACTIONS(4012),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [2013] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16846),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2013),
    [sym_block_comment] = STATE(2013),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2014] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2014),
    [sym_block_comment] = STATE(2014),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(4014),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2015] = {
    [sym_inline_modifier] = STATE(2344),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(12505),
    [sym__simple_expression] = STATE(5582),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15990),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9422),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4761),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(7890),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(2015),
    [sym_block_comment] = STATE(2015),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2108),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2112),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2114),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2116),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_yield] = ACTIONS(4016),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [2016] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16906),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2016),
    [sym_block_comment] = STATE(2016),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2017] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2017),
    [sym_block_comment] = STATE(2017),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_RPAREN] = ACTIONS(4018),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2018] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16206),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2018),
    [sym_block_comment] = STATE(2018),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2019] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16946),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2019),
    [sym_block_comment] = STATE(2019),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2020] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16639),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2020),
    [sym_block_comment] = STATE(2020),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2021] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16162),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2021),
    [sym_block_comment] = STATE(2021),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2022] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17048),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2022),
    [sym_block_comment] = STATE(2022),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2023] = {
    [sym_inline_modifier] = STATE(2338),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(12505),
    [sym__simple_expression] = STATE(5559),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15942),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9343),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5006),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8062),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(2023),
    [sym_block_comment] = STATE(2023),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2258),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2262),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2266),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2268),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2270),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_yield] = ACTIONS(4020),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [2024] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17079),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2024),
    [sym_block_comment] = STATE(2024),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2025] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17106),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2025),
    [sym_block_comment] = STATE(2025),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2026] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17162),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2026),
    [sym_block_comment] = STATE(2026),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2027] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17178),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2027),
    [sym_block_comment] = STATE(2027),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2028] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(13728),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2028),
    [sym_block_comment] = STATE(2028),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_yield] = ACTIONS(4022),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2029] = {
    [sym_inline_modifier] = STATE(2328),
    [sym_block] = STATE(8472),
    [sym_expression] = STATE(13248),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(2029),
    [sym_block_comment] = STATE(2029),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_yield] = ACTIONS(4024),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [2030] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16533),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2030),
    [sym_block_comment] = STATE(2030),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2031] = {
    [sym_inline_modifier] = STATE(2340),
    [sym_block] = STATE(8399),
    [sym_expression] = STATE(13260),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(2031),
    [sym_block_comment] = STATE(2031),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_yield] = ACTIONS(4026),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [2032] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(16775),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2032),
    [sym_block_comment] = STATE(2032),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2033] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14089),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym__exprs_in_parens] = STATE(17514),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2033),
    [sym_block_comment] = STATE(2033),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2034] = {
    [sym_inline_modifier] = STATE(2276),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(13671),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2034),
    [sym_block_comment] = STATE(2034),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2035] = {
    [sym_inline_modifier] = STATE(2344),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(12502),
    [sym__simple_expression] = STATE(5582),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15990),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9422),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4761),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(7890),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(2035),
    [sym_block_comment] = STATE(2035),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2108),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2112),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2114),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2116),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [2036] = {
    [sym_inline_modifier] = STATE(2328),
    [sym_block] = STATE(8472),
    [sym_expression] = STATE(13254),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(2036),
    [sym_block_comment] = STATE(2036),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [2037] = {
    [sym_inline_modifier] = STATE(2308),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12727),
    [sym__simple_expression] = STATE(6086),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16088),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5234),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8197),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(2037),
    [sym_block_comment] = STATE(2037),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3095),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3083),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3087),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(3089),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(3091),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2038] = {
    [sym_inline_modifier] = STATE(2344),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(12504),
    [sym__simple_expression] = STATE(5582),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15990),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9422),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4761),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(7890),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(2038),
    [sym_block_comment] = STATE(2038),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2108),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2112),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2114),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2116),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [2039] = {
    [sym_inline_modifier] = STATE(2329),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(11869),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(2039),
    [sym_block_comment] = STATE(2039),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [2040] = {
    [sym_inline_modifier] = STATE(2300),
    [sym_block] = STATE(8472),
    [sym_expression] = STATE(13027),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(2040),
    [sym_block_comment] = STATE(2040),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [2041] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14686),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2041),
    [sym_block_comment] = STATE(2041),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2042] = {
    [sym_inline_modifier] = STATE(2322),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(12508),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(2042),
    [sym_block_comment] = STATE(2042),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [2043] = {
    [sym_inline_modifier] = STATE(2345),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(11874),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(2043),
    [sym_block_comment] = STATE(2043),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [2044] = {
    [sym_inline_modifier] = STATE(2300),
    [sym_block] = STATE(8472),
    [sym_expression] = STATE(13098),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(2044),
    [sym_block_comment] = STATE(2044),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [2045] = {
    [sym_inline_modifier] = STATE(2345),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(11893),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(2045),
    [sym_block_comment] = STATE(2045),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [2046] = {
    [sym_inline_modifier] = STATE(2322),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(12532),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(2046),
    [sym_block_comment] = STATE(2046),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [2047] = {
    [sym_inline_modifier] = STATE(2345),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(11895),
    [sym__simple_expression] = STATE(5208),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16103),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(8946),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4708),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7385),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(2047),
    [sym_block_comment] = STATE(2047),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2434),
    [anon_sym_while] = ACTIONS(1882),
    [anon_sym_for] = ACTIONS(1884),
    [anon_sym_try] = ACTIONS(1886),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1888),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1890),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1892),
    [anon_sym_throw] = ACTIONS(1894),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [2048] = {
    [sym_inline_modifier] = STATE(2346),
    [sym_block] = STATE(8399),
    [sym_expression] = STATE(13160),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(2048),
    [sym_block_comment] = STATE(2048),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [2049] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9584),
    [sym_expression] = STATE(15603),
    [sym__simple_expression] = STATE(6442),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17205),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5217),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8120),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2049),
    [sym_block_comment] = STATE(2049),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(1430),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [2050] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9584),
    [sym_expression] = STATE(15603),
    [sym__simple_expression] = STATE(6456),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10342),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17205),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9920),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5217),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8120),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2050),
    [sym_block_comment] = STATE(2050),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(1430),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [2051] = {
    [sym_inline_modifier] = STATE(2276),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(13655),
    [sym__simple_expression] = STATE(8890),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16140),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11093),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(8017),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10406),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2051),
    [sym_block_comment] = STATE(2051),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2829),
    [anon_sym_while] = ACTIONS(2831),
    [anon_sym_for] = ACTIONS(2833),
    [anon_sym_try] = ACTIONS(2835),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2837),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3284),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2842),
    [anon_sym_throw] = ACTIONS(2844),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2052] = {
    [sym_inline_modifier] = STATE(2054),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(11874),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(2052),
    [sym_block_comment] = STATE(2052),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [2053] = {
    [sym_inline_modifier] = STATE(2346),
    [sym_block] = STATE(8399),
    [sym_expression] = STATE(13194),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(2053),
    [sym_block_comment] = STATE(2053),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [2054] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15241),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2054),
    [sym_block_comment] = STATE(2054),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4028),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2055] = {
    [sym_inline_modifier] = STATE(2323),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(13379),
    [sym__simple_expression] = STATE(8282),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15898),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10750),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(6686),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9873),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(2055),
    [sym_block_comment] = STATE(2055),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2322),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2330),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2332),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2334),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [2056] = {
    [sym_inline_modifier] = STATE(2346),
    [sym_block] = STATE(8399),
    [sym_expression] = STATE(13216),
    [sym__simple_expression] = STATE(5562),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16013),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9359),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(5013),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(8086),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(2056),
    [sym_block_comment] = STATE(2056),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(1910),
    [anon_sym_for] = ACTIONS(1912),
    [anon_sym_try] = ACTIONS(1914),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1916),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1918),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1920),
    [anon_sym_throw] = ACTIONS(1922),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [2057] = {
    [sym_inline_modifier] = STATE(2304),
    [sym_block] = STATE(9158),
    [sym_expression] = STATE(13537),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(2057),
    [sym_block_comment] = STATE(2057),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [2058] = {
    [sym_inline_modifier] = STATE(2337),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(11627),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(2058),
    [sym_block_comment] = STATE(2058),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [2059] = {
    [sym_inline_modifier] = STATE(2323),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(13460),
    [sym__simple_expression] = STATE(8282),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15898),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10750),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(6686),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9873),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(2059),
    [sym_block_comment] = STATE(2059),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2322),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2330),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2332),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2334),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [2060] = {
    [sym_inline_modifier] = STATE(2304),
    [sym_block] = STATE(9158),
    [sym_expression] = STATE(13335),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(2060),
    [sym_block_comment] = STATE(2060),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [2061] = {
    [sym_inline_modifier] = STATE(2280),
    [sym_block] = STATE(10212),
    [sym_expression] = STATE(14025),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(2061),
    [sym_block_comment] = STATE(2061),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [2062] = {
    [sym_inline_modifier] = STATE(2341),
    [sym_block] = STATE(7476),
    [sym_expression] = STATE(12640),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(2062),
    [sym_block_comment] = STATE(2062),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [2063] = {
    [sym_inline_modifier] = STATE(2054),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(11893),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(2063),
    [sym_block_comment] = STATE(2063),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [2064] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14189),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2064),
    [sym_block_comment] = STATE(2064),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2065] = {
    [sym_inline_modifier] = STATE(2343),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(11627),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(2065),
    [sym_block_comment] = STATE(2065),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [2066] = {
    [sym_inline_modifier] = STATE(2054),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(11895),
    [sym__simple_expression] = STATE(5223),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15951),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9020),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4752),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(6688),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(2066),
    [sym_block_comment] = STATE(2066),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1516),
    [anon_sym_for] = ACTIONS(1518),
    [anon_sym_try] = ACTIONS(1520),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1522),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1526),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1528),
    [anon_sym_throw] = ACTIONS(1530),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [2067] = {
    [sym_inline_modifier] = STATE(2325),
    [sym_block] = STATE(7476),
    [sym_expression] = STATE(12852),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(2067),
    [sym_block_comment] = STATE(2067),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [2068] = {
    [sym_inline_modifier] = STATE(2325),
    [sym_block] = STATE(7476),
    [sym_expression] = STATE(12957),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(2068),
    [sym_block_comment] = STATE(2068),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [2069] = {
    [sym_inline_modifier] = STATE(2306),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(13035),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(2069),
    [sym_block_comment] = STATE(2069),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [2070] = {
    [sym_inline_modifier] = STATE(2306),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(13114),
    [sym__simple_expression] = STATE(8044),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16077),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10593),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6005),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9336),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(2070),
    [sym_block_comment] = STATE(2070),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3064),
    [anon_sym_while] = ACTIONS(3066),
    [anon_sym_for] = ACTIONS(3068),
    [anon_sym_try] = ACTIONS(3070),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3072),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3079),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [2071] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(15448),
    [sym__simple_expression] = STATE(6824),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10582),
    [sym_postfix_expression] = STATE(13904),
    [sym__postfix_expression_choice] = STATE(14203),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10273),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5294),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8672),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2071),
    [sym_block_comment] = STATE(2071),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(1844),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [2072] = {
    [sym_inline_modifier] = STATE(2326),
    [sym_block] = STATE(8894),
    [sym_expression] = STATE(13510),
    [sym__simple_expression] = STATE(6190),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15978),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9770),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5440),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8474),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(2072),
    [sym_block_comment] = STATE(2072),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(1924),
    [anon_sym_while] = ACTIONS(1926),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1930),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1936),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(1938),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [2073] = {
    [sym_inline_modifier] = STATE(2319),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13692),
    [sym__simple_expression] = STATE(6682),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(15930),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10414),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5580),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9016),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(2073),
    [sym_block_comment] = STATE(2073),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(3232),
    [anon_sym_while] = ACTIONS(3218),
    [anon_sym_for] = ACTIONS(3220),
    [anon_sym_try] = ACTIONS(3222),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(3224),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(3226),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(3228),
    [anon_sym_throw] = ACTIONS(3230),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [2074] = {
    [sym_inline_modifier] = STATE(2319),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13729),
    [sym__simple_expression] = STATE(6682),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(15930),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10414),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5580),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9016),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(2074),
    [sym_block_comment] = STATE(2074),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(3232),
    [anon_sym_while] = ACTIONS(3218),
    [anon_sym_for] = ACTIONS(3220),
    [anon_sym_try] = ACTIONS(3222),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(3224),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(3226),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(3228),
    [anon_sym_throw] = ACTIONS(3230),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [2075] = {
    [sym_inline_modifier] = STATE(2326),
    [sym_block] = STATE(8894),
    [sym_expression] = STATE(13336),
    [sym__simple_expression] = STATE(6190),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15978),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9770),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5440),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8474),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(2075),
    [sym_block_comment] = STATE(2075),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(1924),
    [anon_sym_while] = ACTIONS(1926),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1930),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1936),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(1938),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [2076] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14592),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2076),
    [sym_block_comment] = STATE(2076),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2077] = {
    [sym_inline_modifier] = STATE(2313),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(12471),
    [sym__simple_expression] = STATE(6055),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15856),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9737),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5346),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8338),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(2077),
    [sym_block_comment] = STATE(2077),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1764),
    [anon_sym_while] = ACTIONS(1766),
    [anon_sym_for] = ACTIONS(1768),
    [anon_sym_try] = ACTIONS(1770),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(1772),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1776),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(1778),
    [anon_sym_throw] = ACTIONS(1780),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [2078] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(15287),
    [sym__simple_expression] = STATE(4797),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16765),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(4482),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(6629),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2078),
    [sym_block_comment] = STATE(2078),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(1606),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2079] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(10748),
    [sym_expression] = STATE(15589),
    [sym__simple_expression] = STATE(9258),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(10748),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(10748),
    [sym_call_expression] = STATE(10748),
    [sym_field_expression] = STATE(10748),
    [sym_instance_expression] = STATE(10748),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16403),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(10748),
    [sym_parenthesized_expression] = STATE(10748),
    [sym_splice_expression] = STATE(10748),
    [sym_quote_expression] = STATE(10748),
    [sym_identifier] = STATE(8325),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10486),
    [sym__non_null_literal] = STATE(10748),
    [sym_boolean_literal] = STATE(10820),
    [sym_interpolated_string_expression] = STATE(10748),
    [sym_string] = STATE(10820),
    [sym_unit] = STATE(10748),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2079),
    [sym_block_comment] = STATE(2079),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(3298),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(3302),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(3306),
    [anon_sym_SQUOTE] = ACTIONS(3308),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3310),
    [sym_integer_literal] = ACTIONS(3312),
    [sym_floating_point_literal] = ACTIONS(3314),
    [anon_sym_true] = ACTIONS(3316),
    [anon_sym_false] = ACTIONS(3316),
    [sym_character_literal] = ACTIONS(3314),
    [sym_null_literal] = ACTIONS(3318),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(3320),
    [sym__simple_string] = ACTIONS(3320),
  },
  [2080] = {
    [sym_inline_modifier] = STATE(2308),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12776),
    [sym__simple_expression] = STATE(6086),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16088),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5234),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8197),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(2080),
    [sym_block_comment] = STATE(2080),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3095),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3083),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3087),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(3089),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(3091),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2081] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(15792),
    [sym__simple_expression] = STATE(4563),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(8056),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17344),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(7371),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4348),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(5254),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2081),
    [sym_block_comment] = STATE(2081),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(956),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [2082] = {
    [sym_inline_modifier] = STATE(2309),
    [sym_block] = STATE(9961),
    [sym_expression] = STATE(13976),
    [sym__simple_expression] = STATE(6847),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15991),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(10631),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(10386),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5726),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(8783),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(2082),
    [sym_block_comment] = STATE(2082),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(2278),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2282),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(2286),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_macro] = ACTIONS(2288),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(2290),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2294),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [2083] = {
    [sym_inline_modifier] = STATE(2308),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12801),
    [sym__simple_expression] = STATE(6086),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16088),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5234),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8197),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(2083),
    [sym_block_comment] = STATE(2083),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3095),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3083),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3087),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(3089),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(3091),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2084] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(15792),
    [sym__simple_expression] = STATE(4559),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17344),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4348),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(5254),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2084),
    [sym_block_comment] = STATE(2084),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(956),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [2085] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(15448),
    [sym__simple_expression] = STATE(6770),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10535),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17534),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10302),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5294),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8672),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2085),
    [sym_block_comment] = STATE(2085),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(1844),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [2086] = {
    [sym_inline_modifier] = STATE(2327),
    [sym_block] = STATE(9357),
    [sym_expression] = STATE(13740),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(2086),
    [sym_block_comment] = STATE(2086),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [2087] = {
    [sym_inline_modifier] = STATE(2278),
    [sym_block] = STATE(9584),
    [sym_expression] = STATE(13792),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(2087),
    [sym_block_comment] = STATE(2087),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [2088] = {
    [sym_inline_modifier] = STATE(2327),
    [sym_block] = STATE(9357),
    [sym_expression] = STATE(13752),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(2088),
    [sym_block_comment] = STATE(2088),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [2089] = {
    [sym_inline_modifier] = STATE(2278),
    [sym_block] = STATE(9584),
    [sym_expression] = STATE(13809),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(2089),
    [sym_block_comment] = STATE(2089),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [2090] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(10748),
    [sym_expression] = STATE(15589),
    [sym__simple_expression] = STATE(8723),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(10748),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(10748),
    [sym_call_expression] = STATE(10748),
    [sym_field_expression] = STATE(10748),
    [sym_instance_expression] = STATE(10748),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(11168),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16132),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10984),
    [sym_tuple_expression] = STATE(10748),
    [sym_parenthesized_expression] = STATE(10748),
    [sym_splice_expression] = STATE(10748),
    [sym_quote_expression] = STATE(10748),
    [sym_identifier] = STATE(8325),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10486),
    [sym__non_null_literal] = STATE(10748),
    [sym_boolean_literal] = STATE(10820),
    [sym_interpolated_string_expression] = STATE(10748),
    [sym_string] = STATE(10820),
    [sym_unit] = STATE(10748),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2090),
    [sym_block_comment] = STATE(2090),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(3298),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(3300),
    [anon_sym_DASH] = ACTIONS(3300),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(3302),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(3300),
    [anon_sym_TILDE] = ACTIONS(3300),
    [anon_sym_DOLLAR] = ACTIONS(3306),
    [anon_sym_SQUOTE] = ACTIONS(3308),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3310),
    [sym_integer_literal] = ACTIONS(3312),
    [sym_floating_point_literal] = ACTIONS(3314),
    [anon_sym_true] = ACTIONS(3316),
    [anon_sym_false] = ACTIONS(3316),
    [sym_character_literal] = ACTIONS(3314),
    [sym_null_literal] = ACTIONS(3318),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(3320),
    [sym__simple_string] = ACTIONS(3320),
  },
  [2091] = {
    [sym_inline_modifier] = STATE(2320),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12885),
    [sym__simple_expression] = STATE(6186),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16018),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9989),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5240),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8124),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(2091),
    [sym_block_comment] = STATE(2091),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3237),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2488),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2492),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2494),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2496),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2092] = {
    [sym_inline_modifier] = STATE(2320),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12727),
    [sym__simple_expression] = STATE(6186),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16018),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9989),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5240),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8124),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(2092),
    [sym_block_comment] = STATE(2092),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3237),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2488),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2492),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2494),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2496),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2093] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14990),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2093),
    [sym_block_comment] = STATE(2093),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4030),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2094] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14693),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2094),
    [sym_block_comment] = STATE(2094),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2095] = {
    [sym_inline_modifier] = STATE(2315),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(13496),
    [sym__simple_expression] = STATE(6983),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15899),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10174),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(5823),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9043),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(2095),
    [sym_block_comment] = STATE(2095),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2446),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2450),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2452),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2456),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [2096] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(15149),
    [sym__simple_expression] = STATE(5198),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17474),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(4613),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(6807),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2096),
    [sym_block_comment] = STATE(2096),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1504),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [2097] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(10014),
    [sym_expression] = STATE(14964),
    [sym__simple_expression] = STATE(7300),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10461),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17659),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10367),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5701),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8721),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2097),
    [sym_block_comment] = STATE(2097),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2040),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [2098] = {
    [sym_inline_modifier] = STATE(2309),
    [sym_block] = STATE(9961),
    [sym_expression] = STATE(13869),
    [sym__simple_expression] = STATE(6847),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15991),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(10631),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(10386),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5726),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(8783),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(2098),
    [sym_block_comment] = STATE(2098),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(2278),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2282),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(2286),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_macro] = ACTIONS(2288),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(2290),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2294),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [2099] = {
    [sym_inline_modifier] = STATE(2328),
    [sym_block] = STATE(8472),
    [sym_expression] = STATE(13027),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(2099),
    [sym_block_comment] = STATE(2099),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [2100] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14389),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2100),
    [sym_block_comment] = STATE(2100),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2101] = {
    [sym_inline_modifier] = STATE(2328),
    [sym_block] = STATE(8472),
    [sym_expression] = STATE(13098),
    [sym__simple_expression] = STATE(5558),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16087),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9338),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4995),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(8048),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(2101),
    [sym_block_comment] = STATE(2101),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(2168),
    [anon_sym_while] = ACTIONS(2002),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2006),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(2010),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2014),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [2102] = {
    [sym_inline_modifier] = STATE(2309),
    [sym_block] = STATE(9961),
    [sym_expression] = STATE(13876),
    [sym__simple_expression] = STATE(6847),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15991),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(10631),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(10386),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5726),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(8783),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(2102),
    [sym_block_comment] = STATE(2102),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(2278),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2282),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(2286),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_macro] = ACTIONS(2288),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(2290),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2294),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [2103] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14565),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2103),
    [sym_block_comment] = STATE(2103),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2104] = {
    [sym_inline_modifier] = STATE(2318),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(13496),
    [sym__simple_expression] = STATE(8653),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(16129),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10722),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(7377),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9808),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(2104),
    [sym_block_comment] = STATE(2104),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2200),
    [anon_sym_for] = ACTIONS(2202),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2206),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2210),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [2105] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(15448),
    [sym__simple_expression] = STATE(6148),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17534),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5294),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8672),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2105),
    [sym_block_comment] = STATE(2105),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(1844),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [2106] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(14979),
    [sym__simple_expression] = STATE(4571),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(8277),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17870),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(7481),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4451),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(5753),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2106),
    [sym_block_comment] = STATE(2106),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1064),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [2107] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(15149),
    [sym__simple_expression] = STATE(5228),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(9498),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17474),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9093),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(4613),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(6807),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2107),
    [sym_block_comment] = STATE(2107),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1504),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [2108] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(13655),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2108),
    [sym_block_comment] = STATE(2108),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2109] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14314),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2109),
    [sym_block_comment] = STATE(2109),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2110] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(13671),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2110),
    [sym_block_comment] = STATE(2110),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2111] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14669),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2111),
    [sym_block_comment] = STATE(2111),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2112] = {
    [sym_inline_modifier] = STATE(2278),
    [sym_block] = STATE(9584),
    [sym_expression] = STATE(13819),
    [sym__simple_expression] = STATE(6411),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16059),
    [sym_case_block] = STATE(9584),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(9584),
    [sym_call_expression] = STATE(9584),
    [sym_field_expression] = STATE(9584),
    [sym_instance_expression] = STATE(9584),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16638),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9880),
    [sym_tuple_expression] = STATE(9584),
    [sym_parenthesized_expression] = STATE(9584),
    [sym_splice_expression] = STATE(9584),
    [sym_quote_expression] = STATE(9584),
    [sym_identifier] = STATE(5405),
    [sym__soft_identifier] = STATE(4473),
    [sym_wildcard] = STATE(8088),
    [sym__non_null_literal] = STATE(9584),
    [sym_boolean_literal] = STATE(9688),
    [sym_interpolated_string_expression] = STATE(9584),
    [sym_string] = STATE(9688),
    [sym_unit] = STATE(9584),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(2112),
    [sym_block_comment] = STATE(2112),
    [sym__alpha_identifier] = ACTIONS(1406),
    [anon_sym_LBRACE] = ACTIONS(1410),
    [anon_sym__] = ACTIONS(1412),
    [anon_sym_PLUS] = ACTIONS(1414),
    [anon_sym_DASH] = ACTIONS(1414),
    [anon_sym_end] = ACTIONS(1416),
    [anon_sym_if] = ACTIONS(2074),
    [anon_sym_while] = ACTIONS(2076),
    [anon_sym_for] = ACTIONS(2078),
    [anon_sym_try] = ACTIONS(2080),
    [anon_sym_new] = ACTIONS(1418),
    [anon_sym_opaque] = ACTIONS(1416),
    [anon_sym_implicit] = ACTIONS(2082),
    [anon_sym_inline] = ACTIONS(1420),
    [anon_sym_infix] = ACTIONS(1416),
    [anon_sym_open] = ACTIONS(1416),
    [anon_sym_transparent] = ACTIONS(1416),
    [anon_sym_LPAREN] = ACTIONS(1422),
    [anon_sym_macro] = ACTIONS(2084),
    [anon_sym_BANG] = ACTIONS(1414),
    [anon_sym_TILDE] = ACTIONS(1414),
    [anon_sym_DOLLAR] = ACTIONS(1424),
    [anon_sym_SQUOTE] = ACTIONS(1426),
    [sym__backquoted_id] = ACTIONS(1428),
    [sym_operator_identifier] = ACTIONS(2086),
    [sym_integer_literal] = ACTIONS(1432),
    [sym_floating_point_literal] = ACTIONS(1434),
    [anon_sym_true] = ACTIONS(1436),
    [anon_sym_false] = ACTIONS(1436),
    [sym_character_literal] = ACTIONS(1434),
    [sym_null_literal] = ACTIONS(1438),
    [anon_sym_return] = ACTIONS(2088),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1440),
    [sym__simple_string] = ACTIONS(1440),
  },
  [2113] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(10014),
    [sym_expression] = STATE(14964),
    [sym__simple_expression] = STATE(7295),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17659),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5701),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8721),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2113),
    [sym_block_comment] = STATE(2113),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2040),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [2114] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(15235),
    [sym__simple_expression] = STATE(5250),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(9506),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16237),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9080),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(4665),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(7050),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2114),
    [sym_block_comment] = STATE(2114),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(1394),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [2115] = {
    [sym_inline_modifier] = STATE(2329),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(11862),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(2115),
    [sym_block_comment] = STATE(2115),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [2116] = {
    [sym_inline_modifier] = STATE(2329),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(11865),
    [sym__simple_expression] = STATE(5219),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15854),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9014),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4749),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(6680),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(2116),
    [sym_block_comment] = STATE(2116),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2246),
    [anon_sym_while] = ACTIONS(1608),
    [anon_sym_for] = ACTIONS(1610),
    [anon_sym_try] = ACTIONS(1612),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1614),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1616),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1618),
    [anon_sym_throw] = ACTIONS(1620),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [2117] = {
    [sym_inline_modifier] = STATE(2310),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(13035),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(2117),
    [sym_block_comment] = STATE(2117),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3131),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3290),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [2118] = {
    [sym_inline_modifier] = STATE(2310),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(13114),
    [sym__simple_expression] = STATE(7814),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(15967),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(10555),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(6101),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(9420),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(2118),
    [sym_block_comment] = STATE(2118),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3131),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3135),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(3137),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(3290),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(3142),
    [anon_sym_throw] = ACTIONS(3144),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [2119] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14643),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2119),
    [sym_block_comment] = STATE(2119),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2120] = {
    [sym_inline_modifier] = STATE(2323),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(13496),
    [sym__simple_expression] = STATE(8282),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15898),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10750),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(6686),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9873),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(2120),
    [sym_block_comment] = STATE(2120),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2322),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2326),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2330),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2332),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2334),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [2121] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(14979),
    [sym__simple_expression] = STATE(4755),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17870),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4451),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(5753),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2121),
    [sym_block_comment] = STATE(2121),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1064),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [2122] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8472),
    [sym_expression] = STATE(15442),
    [sym__simple_expression] = STATE(5260),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(9563),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16339),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9126),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7141),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2122),
    [sym_block_comment] = STATE(2122),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1214),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [2123] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14378),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2123),
    [sym_block_comment] = STATE(2123),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2124] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14416),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2124),
    [sym_block_comment] = STATE(2124),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2125] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(15287),
    [sym__simple_expression] = STATE(7334),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10621),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16765),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10384),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(4482),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(6629),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2125),
    [sym_block_comment] = STATE(2125),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(1606),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2126] = {
    [sym_inline_modifier] = STATE(2330),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(12491),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(2126),
    [sym_block_comment] = STATE(2126),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2392),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [2127] = {
    [sym_inline_modifier] = STATE(2284),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(11862),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(2127),
    [sym_block_comment] = STATE(2127),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [2128] = {
    [sym_inline_modifier] = STATE(2330),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(12493),
    [sym__simple_expression] = STATE(5557),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15911),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9335),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4991),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8040),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(2128),
    [sym_block_comment] = STATE(2128),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2384),
    [anon_sym_for] = ACTIONS(2386),
    [anon_sym_try] = ACTIONS(2388),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2390),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2392),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2394),
    [anon_sym_throw] = ACTIONS(2396),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [2129] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14570),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2129),
    [sym_block_comment] = STATE(2129),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2130] = {
    [sym_inline_modifier] = STATE(2284),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(11869),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(2130),
    [sym_block_comment] = STATE(2130),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [2131] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(15235),
    [sym__simple_expression] = STATE(5247),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16237),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(4665),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(7050),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2131),
    [sym_block_comment] = STATE(2131),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(1394),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [2132] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9158),
    [sym_expression] = STATE(15583),
    [sym__simple_expression] = STATE(5645),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(9916),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16362),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9607),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4954),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(7789),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2132),
    [sym_block_comment] = STATE(2132),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1250),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [2133] = {
    [sym_inline_modifier] = STATE(2284),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(11865),
    [sym__simple_expression] = STATE(5964),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(15875),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(9696),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(5033),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(8013),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(2133),
    [sym_block_comment] = STATE(2133),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [2134] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14197),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2134),
    [sym_block_comment] = STATE(2134),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2135] = {
    [sym_inline_modifier] = STATE(2312),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(11623),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(2135),
    [sym_block_comment] = STATE(2135),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [2136] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14254),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2136),
    [sym_block_comment] = STATE(2136),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2137] = {
    [sym_inline_modifier] = STATE(2312),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(11625),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(2137),
    [sym_block_comment] = STATE(2137),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [2138] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14297),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2138),
    [sym_block_comment] = STATE(2138),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2139] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14591),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2139),
    [sym_block_comment] = STATE(2139),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2140] = {
    [sym_inline_modifier] = STATE(2288),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(13061),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(2140),
    [sym_block_comment] = STATE(2140),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [2141] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8472),
    [sym_expression] = STATE(15442),
    [sym__simple_expression] = STATE(5257),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16339),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7141),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2141),
    [sym_block_comment] = STATE(2141),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1214),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [2142] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9961),
    [sym_expression] = STATE(15845),
    [sym__simple_expression] = STATE(6813),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10525),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16382),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10179),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5853),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(9112),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2142),
    [sym_block_comment] = STATE(2142),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_PLUS] = ACTIONS(1854),
    [anon_sym_DASH] = ACTIONS(1854),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1854),
    [anon_sym_TILDE] = ACTIONS(1854),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(1870),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [2143] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14312),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2143),
    [sym_block_comment] = STATE(2143),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2144] = {
    [sym_inline_modifier] = STATE(2332),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(11893),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(2144),
    [sym_block_comment] = STATE(2144),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [2145] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14319),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2145),
    [sym_block_comment] = STATE(2145),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2146] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14344),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2146),
    [sym_block_comment] = STATE(2146),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2147] = {
    [sym_inline_modifier] = STATE(2332),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(11895),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(2147),
    [sym_block_comment] = STATE(2147),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [2148] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(15287),
    [sym__simple_expression] = STATE(4797),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16765),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(4482),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(6629),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2148),
    [sym_block_comment] = STATE(2148),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(1606),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2149] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14663),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2149),
    [sym_block_comment] = STATE(2149),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2150] = {
    [sym_inline_modifier] = STATE(2326),
    [sym_block] = STATE(8894),
    [sym_expression] = STATE(13419),
    [sym__simple_expression] = STATE(6190),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15978),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9770),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5440),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8474),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(2150),
    [sym_block_comment] = STATE(2150),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(1924),
    [anon_sym_while] = ACTIONS(1926),
    [anon_sym_for] = ACTIONS(1928),
    [anon_sym_try] = ACTIONS(1930),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(1932),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1936),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(1938),
    [anon_sym_throw] = ACTIONS(1940),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [2151] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9158),
    [sym_expression] = STATE(15583),
    [sym__simple_expression] = STATE(5641),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16362),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4954),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(7789),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2151),
    [sym_block_comment] = STATE(2151),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1250),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [2152] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(15418),
    [sym__simple_expression] = STATE(4445),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(6829),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16424),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(6577),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4267),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(4967),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2152),
    [sym_block_comment] = STATE(2152),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(920),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [2153] = {
    [sym_inline_modifier] = STATE(2288),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(13176),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(2153),
    [sym_block_comment] = STATE(2153),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [2154] = {
    [sym_inline_modifier] = STATE(2313),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(12502),
    [sym__simple_expression] = STATE(6055),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15856),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9737),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5346),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8338),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(2154),
    [sym_block_comment] = STATE(2154),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1764),
    [anon_sym_while] = ACTIONS(1766),
    [anon_sym_for] = ACTIONS(1768),
    [anon_sym_try] = ACTIONS(1770),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(1772),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1776),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(1778),
    [anon_sym_throw] = ACTIONS(1780),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [2155] = {
    [sym_inline_modifier] = STATE(2313),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(12504),
    [sym__simple_expression] = STATE(6055),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15856),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9737),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5346),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8338),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(2155),
    [sym_block_comment] = STATE(2155),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(1764),
    [anon_sym_while] = ACTIONS(1766),
    [anon_sym_for] = ACTIONS(1768),
    [anon_sym_try] = ACTIONS(1770),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(1772),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1776),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(1778),
    [anon_sym_throw] = ACTIONS(1780),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [2156] = {
    [sym_inline_modifier] = STATE(2333),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(12791),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(2156),
    [sym_block_comment] = STATE(2156),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [2157] = {
    [sym_inline_modifier] = STATE(2288),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(13308),
    [sym__simple_expression] = STATE(6128),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(16126),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10097),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5182),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(8710),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(2157),
    [sym_block_comment] = STATE(2157),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(1784),
    [anon_sym_while] = ACTIONS(1786),
    [anon_sym_for] = ACTIONS(1788),
    [anon_sym_try] = ACTIONS(1790),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(1792),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(1796),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(1798),
    [anon_sym_throw] = ACTIONS(1800),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [2158] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14728),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2158),
    [sym_block_comment] = STATE(2158),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2159] = {
    [sym_inline_modifier] = STATE(2327),
    [sym_block] = STATE(9357),
    [sym_expression] = STATE(13651),
    [sym__simple_expression] = STATE(6235),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(16040),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(10230),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16569),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9879),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5443),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8510),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(2159),
    [sym_block_comment] = STATE(2159),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(1964),
    [anon_sym_while] = ACTIONS(1966),
    [anon_sym_for] = ACTIONS(1968),
    [anon_sym_try] = ACTIONS(1970),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(1972),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(1974),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1976),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(1978),
    [anon_sym_throw] = ACTIONS(1980),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [2160] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9961),
    [sym_expression] = STATE(15845),
    [sym__simple_expression] = STATE(6810),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9961),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9961),
    [sym_call_expression] = STATE(9961),
    [sym_field_expression] = STATE(9961),
    [sym_instance_expression] = STATE(9961),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16382),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9961),
    [sym_parenthesized_expression] = STATE(9961),
    [sym_splice_expression] = STATE(9961),
    [sym_quote_expression] = STATE(9961),
    [sym_identifier] = STATE(5853),
    [sym__soft_identifier] = STATE(4597),
    [sym_wildcard] = STATE(9112),
    [sym__non_null_literal] = STATE(9961),
    [sym_boolean_literal] = STATE(9797),
    [sym_interpolated_string_expression] = STATE(9961),
    [sym_string] = STATE(9797),
    [sym_unit] = STATE(9961),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2160),
    [sym_block_comment] = STATE(2160),
    [sym__alpha_identifier] = ACTIONS(1846),
    [anon_sym_LBRACE] = ACTIONS(1850),
    [anon_sym__] = ACTIONS(1852),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(1856),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1858),
    [anon_sym_opaque] = ACTIONS(1856),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1860),
    [anon_sym_infix] = ACTIONS(1856),
    [anon_sym_open] = ACTIONS(1856),
    [anon_sym_transparent] = ACTIONS(1856),
    [anon_sym_LPAREN] = ACTIONS(1862),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(1864),
    [anon_sym_SQUOTE] = ACTIONS(1866),
    [sym__backquoted_id] = ACTIONS(1868),
    [sym_operator_identifier] = ACTIONS(1870),
    [sym_integer_literal] = ACTIONS(1872),
    [sym_floating_point_literal] = ACTIONS(1874),
    [anon_sym_true] = ACTIONS(1876),
    [anon_sym_false] = ACTIONS(1876),
    [sym_character_literal] = ACTIONS(1874),
    [sym_null_literal] = ACTIONS(1878),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1880),
    [sym__simple_string] = ACTIONS(1880),
  },
  [2161] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(14982),
    [sym__simple_expression] = STATE(4638),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(8318),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16445),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(7895),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4460),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(5866),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2161),
    [sym_block_comment] = STATE(2161),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1100),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [2162] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(15287),
    [sym__simple_expression] = STATE(5265),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(9580),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16765),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9145),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(4482),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(6629),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2162),
    [sym_block_comment] = STATE(2162),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(1606),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2163] = {
    [sym_inline_modifier] = STATE(2333),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(12836),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(2163),
    [sym_block_comment] = STATE(2163),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [2164] = {
    [sym_inline_modifier] = STATE(2286),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12776),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(2164),
    [sym_block_comment] = STATE(2164),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2165] = {
    [sym_inline_modifier] = STATE(2308),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12885),
    [sym__simple_expression] = STATE(6086),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16088),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5234),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8197),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(2165),
    [sym_block_comment] = STATE(2165),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3095),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3083),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3087),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(3089),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(3091),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2166] = {
    [sym_inline_modifier] = STATE(2286),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12801),
    [sym__simple_expression] = STATE(7894),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16123),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10617),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(6249),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(9457),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(2166),
    [sym_block_comment] = STATE(2166),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(3103),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(417),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2167] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14660),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2167),
    [sym_block_comment] = STATE(2167),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2168] = {
    [sym_inline_modifier] = STATE(2292),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(13061),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(2168),
    [sym_block_comment] = STATE(2168),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [2169] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(15418),
    [sym__simple_expression] = STATE(4447),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16424),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4267),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(4967),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2169),
    [sym_block_comment] = STATE(2169),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(920),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [2170] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(15187),
    [sym__simple_expression] = STATE(4643),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(8504),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16466),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(7971),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4462),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(5883),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2170),
    [sym_block_comment] = STATE(2170),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1028),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [2171] = {
    [sym_inline_modifier] = STATE(2314),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(12508),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(2171),
    [sym_block_comment] = STATE(2171),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [2172] = {
    [sym_inline_modifier] = STATE(2334),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(12791),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(2172),
    [sym_block_comment] = STATE(2172),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [2173] = {
    [sym_inline_modifier] = STATE(2334),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(12836),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(2173),
    [sym_block_comment] = STATE(2173),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [2174] = {
    [sym_inline_modifier] = STATE(2314),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(12532),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(2174),
    [sym_block_comment] = STATE(2174),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [2175] = {
    [sym_inline_modifier] = STATE(2302),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13745),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(2175),
    [sym_block_comment] = STATE(2175),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [2176] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14687),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2176),
    [sym_block_comment] = STATE(2176),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2177] = {
    [sym_inline_modifier] = STATE(2294),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(13061),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(2177),
    [sym_block_comment] = STATE(2177),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [2178] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(14982),
    [sym__simple_expression] = STATE(4641),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16445),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4460),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(5866),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2178),
    [sym_block_comment] = STATE(2178),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(1100),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [2179] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(15408),
    [sym__simple_expression] = STATE(5720),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10095),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16487),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9708),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(4992),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(7902),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2179),
    [sym_block_comment] = STATE(2179),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(1828),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [2180] = {
    [sym_inline_modifier] = STATE(2302),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13774),
    [sym__simple_expression] = STATE(8002),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16085),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10557),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(6316),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9711),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(2180),
    [sym_block_comment] = STATE(2180),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2935),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(539),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(549),
    [anon_sym_throw] = ACTIONS(551),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [2181] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14540),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2181),
    [sym_block_comment] = STATE(2181),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2182] = {
    [sym_inline_modifier] = STATE(2332),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(11874),
    [sym__simple_expression] = STATE(5822),
    [sym_lambda_expression] = STATE(11950),
    [sym_if_expression] = STATE(11950),
    [sym_match_expression] = STATE(11950),
    [sym_try_expression] = STATE(11950),
    [sym_bindings] = STATE(15960),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(11950),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(11950),
    [sym_infix_expression] = STATE(7708),
    [sym_postfix_expression] = STATE(11714),
    [sym__postfix_expression_choice] = STATE(16589),
    [sym_macro_body] = STATE(11950),
    [sym_prefix_expression] = STATE(9459),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(5026),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(7989),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(11950),
    [sym_throw_expression] = STATE(11950),
    [sym_while_expression] = STATE(11950),
    [sym_do_while_expression] = STATE(11950),
    [sym_for_expression] = STATE(11950),
    [sym_comment] = STATE(2182),
    [sym_block_comment] = STATE(2182),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(1622),
    [anon_sym_while] = ACTIONS(1624),
    [anon_sym_for] = ACTIONS(1626),
    [anon_sym_try] = ACTIONS(1628),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(1630),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(1524),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(1632),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(1634),
    [anon_sym_throw] = ACTIONS(1636),
    [anon_sym_do] = ACTIONS(1532),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [2183] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(15187),
    [sym__simple_expression] = STATE(4645),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16466),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4462),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(5883),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2183),
    [sym_block_comment] = STATE(2183),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1028),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [2184] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(15448),
    [sym__simple_expression] = STATE(7358),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10623),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17534),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10351),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5294),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8672),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2184),
    [sym_block_comment] = STATE(2184),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(1844),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [2185] = {
    [sym_inline_modifier] = STATE(2335),
    [sym_block] = STATE(8838),
    [sym_expression] = STATE(13420),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(2185),
    [sym_block_comment] = STATE(2185),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(2468),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [2186] = {
    [sym_inline_modifier] = STATE(2335),
    [sym_block] = STATE(8838),
    [sym_expression] = STATE(13578),
    [sym__simple_expression] = STATE(6011),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(16117),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9772),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5209),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8687),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(2186),
    [sym_block_comment] = STATE(2186),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2643),
    [anon_sym_while] = ACTIONS(2460),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2464),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(2468),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2472),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [2187] = {
    [sym_inline_modifier] = STATE(2315),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(13379),
    [sym__simple_expression] = STATE(6983),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15899),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10174),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(5823),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9043),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(2187),
    [sym_block_comment] = STATE(2187),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2446),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2450),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2452),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2456),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [2188] = {
    [sym_inline_modifier] = STATE(2315),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(13460),
    [sym__simple_expression] = STATE(6983),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(15899),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10174),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(5823),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9043),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(2188),
    [sym_block_comment] = STATE(2188),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2442),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2446),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2450),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2452),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2456),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [2189] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14717),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2189),
    [sym_block_comment] = STATE(2189),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2190] = {
    [sym_inline_modifier] = STATE(2333),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(12660),
    [sym__simple_expression] = STATE(5833),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16147),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(9496),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5031),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8016),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(2190),
    [sym_block_comment] = STATE(2190),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(1674),
    [anon_sym_while] = ACTIONS(1676),
    [anon_sym_for] = ACTIONS(1678),
    [anon_sym_try] = ACTIONS(1680),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(1682),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1686),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(1688),
    [anon_sym_throw] = ACTIONS(1690),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [2191] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(15408),
    [sym__simple_expression] = STATE(5727),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16487),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(4992),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(7902),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2191),
    [sym_block_comment] = STATE(2191),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(1828),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [2192] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8838),
    [sym_expression] = STATE(15577),
    [sym__simple_expression] = STATE(5728),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(9821),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16508),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9411),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(4998),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(7932),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2192),
    [sym_block_comment] = STATE(2192),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1592),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [2193] = {
    [sym_inline_modifier] = STATE(2290),
    [sym_block] = STATE(10014),
    [sym_expression] = STATE(13864),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(2193),
    [sym_block_comment] = STATE(2193),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2184),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [2194] = {
    [sym_inline_modifier] = STATE(2290),
    [sym_block] = STATE(10014),
    [sym_expression] = STATE(13856),
    [sym__simple_expression] = STATE(7282),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(15994),
    [sym_case_block] = STATE(10014),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(10014),
    [sym_call_expression] = STATE(10014),
    [sym_field_expression] = STATE(10014),
    [sym_instance_expression] = STATE(10014),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(10474),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17140),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(10430),
    [sym_tuple_expression] = STATE(10014),
    [sym_parenthesized_expression] = STATE(10014),
    [sym_splice_expression] = STATE(10014),
    [sym_quote_expression] = STATE(10014),
    [sym_identifier] = STATE(5539),
    [sym__soft_identifier] = STATE(4685),
    [sym_wildcard] = STATE(8781),
    [sym__non_null_literal] = STATE(10014),
    [sym_boolean_literal] = STATE(9825),
    [sym_interpolated_string_expression] = STATE(10014),
    [sym_string] = STATE(9825),
    [sym_unit] = STATE(10014),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(2194),
    [sym_block_comment] = STATE(2194),
    [sym__alpha_identifier] = ACTIONS(2016),
    [anon_sym_LBRACE] = ACTIONS(2020),
    [anon_sym__] = ACTIONS(2022),
    [anon_sym_PLUS] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2024),
    [anon_sym_end] = ACTIONS(2026),
    [anon_sym_if] = ACTIONS(2172),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2176),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2028),
    [anon_sym_opaque] = ACTIONS(2026),
    [anon_sym_implicit] = ACTIONS(2180),
    [anon_sym_inline] = ACTIONS(2030),
    [anon_sym_infix] = ACTIONS(2026),
    [anon_sym_open] = ACTIONS(2026),
    [anon_sym_transparent] = ACTIONS(2026),
    [anon_sym_LPAREN] = ACTIONS(2032),
    [anon_sym_macro] = ACTIONS(2182),
    [anon_sym_BANG] = ACTIONS(2024),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DOLLAR] = ACTIONS(2034),
    [anon_sym_SQUOTE] = ACTIONS(2036),
    [sym__backquoted_id] = ACTIONS(2038),
    [sym_operator_identifier] = ACTIONS(2184),
    [sym_integer_literal] = ACTIONS(2042),
    [sym_floating_point_literal] = ACTIONS(2044),
    [anon_sym_true] = ACTIONS(2046),
    [anon_sym_false] = ACTIONS(2046),
    [sym_character_literal] = ACTIONS(2044),
    [sym_null_literal] = ACTIONS(2048),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2188),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2050),
    [sym__simple_string] = ACTIONS(2050),
  },
  [2195] = {
    [sym_inline_modifier] = STATE(2336),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(12491),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(2195),
    [sym_block_comment] = STATE(2195),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2100),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [2196] = {
    [sym_inline_modifier] = STATE(2336),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(12493),
    [sym__simple_expression] = STATE(5581),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16138),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9418),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(4918),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(7796),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(2196),
    [sym_block_comment] = STATE(2196),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2092),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2096),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(2100),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2104),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [2197] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14707),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2197),
    [sym_block_comment] = STATE(2197),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2198] = {
    [sym_inline_modifier] = STATE(2300),
    [sym_block] = STATE(8472),
    [sym_expression] = STATE(13254),
    [sym__simple_expression] = STATE(5638),
    [sym_lambda_expression] = STATE(13323),
    [sym_if_expression] = STATE(13323),
    [sym_match_expression] = STATE(13323),
    [sym_try_expression] = STATE(13323),
    [sym_bindings] = STATE(16116),
    [sym_case_block] = STATE(8472),
    [sym_assignment_expression] = STATE(13323),
    [sym_generic_function] = STATE(8472),
    [sym_call_expression] = STATE(8472),
    [sym_field_expression] = STATE(8472),
    [sym_instance_expression] = STATE(8472),
    [sym_ascription_expression] = STATE(13323),
    [sym_infix_expression] = STATE(9601),
    [sym_postfix_expression] = STATE(13317),
    [sym__postfix_expression_choice] = STATE(17592),
    [sym_macro_body] = STATE(13323),
    [sym_prefix_expression] = STATE(9602),
    [sym_tuple_expression] = STATE(8472),
    [sym_parenthesized_expression] = STATE(8472),
    [sym_splice_expression] = STATE(8472),
    [sym_quote_expression] = STATE(8472),
    [sym_identifier] = STATE(4848),
    [sym__soft_identifier] = STATE(5821),
    [sym_wildcard] = STATE(7867),
    [sym__non_null_literal] = STATE(8472),
    [sym_boolean_literal] = STATE(8608),
    [sym_interpolated_string_expression] = STATE(8472),
    [sym_string] = STATE(8608),
    [sym_unit] = STATE(8472),
    [sym_return_expression] = STATE(13323),
    [sym_throw_expression] = STATE(13323),
    [sym_while_expression] = STATE(13323),
    [sym_do_while_expression] = STATE(13323),
    [sym_for_expression] = STATE(13323),
    [sym_comment] = STATE(2198),
    [sym_block_comment] = STATE(2198),
    [sym__alpha_identifier] = ACTIONS(1190),
    [anon_sym_LBRACE] = ACTIONS(1194),
    [anon_sym__] = ACTIONS(1196),
    [anon_sym_PLUS] = ACTIONS(1198),
    [anon_sym_DASH] = ACTIONS(1198),
    [anon_sym_end] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1202),
    [anon_sym_opaque] = ACTIONS(1200),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1204),
    [anon_sym_infix] = ACTIONS(1200),
    [anon_sym_open] = ACTIONS(1200),
    [anon_sym_transparent] = ACTIONS(1200),
    [anon_sym_LPAREN] = ACTIONS(1206),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1198),
    [anon_sym_TILDE] = ACTIONS(1198),
    [anon_sym_DOLLAR] = ACTIONS(1208),
    [anon_sym_SQUOTE] = ACTIONS(1210),
    [sym__backquoted_id] = ACTIONS(1212),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1216),
    [sym_floating_point_literal] = ACTIONS(1218),
    [anon_sym_true] = ACTIONS(1220),
    [anon_sym_false] = ACTIONS(1220),
    [sym_character_literal] = ACTIONS(1218),
    [sym_null_literal] = ACTIONS(1222),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1224),
    [sym__simple_string] = ACTIONS(1224),
  },
  [2199] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(15448),
    [sym__simple_expression] = STATE(6148),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(17534),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5294),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8672),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2199),
    [sym_block_comment] = STATE(2199),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(1844),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [2200] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(7476),
    [sym_expression] = STATE(14741),
    [sym__simple_expression] = STATE(4881),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(8848),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16629),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(8495),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4560),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(6622),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2200),
    [sym_block_comment] = STATE(2200),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1136),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [2201] = {
    [sym_inline_modifier] = STATE(2324),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13745),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(2201),
    [sym_block_comment] = STATE(2201),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [2202] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14345),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2202),
    [sym_block_comment] = STATE(2202),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2203] = {
    [sym_inline_modifier] = STATE(2321),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(11865),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(2203),
    [sym_block_comment] = STATE(2203),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [2204] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14691),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2204),
    [sym_block_comment] = STATE(2204),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2205] = {
    [sym_inline_modifier] = STATE(2304),
    [sym_block] = STATE(9158),
    [sym_expression] = STATE(13516),
    [sym__simple_expression] = STATE(5655),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16109),
    [sym_case_block] = STATE(9158),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(9158),
    [sym_call_expression] = STATE(9158),
    [sym_field_expression] = STATE(9158),
    [sym_instance_expression] = STATE(9158),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(9964),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(17710),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(9630),
    [sym_tuple_expression] = STATE(9158),
    [sym_parenthesized_expression] = STATE(9158),
    [sym_splice_expression] = STATE(9158),
    [sym_quote_expression] = STATE(9158),
    [sym_identifier] = STATE(4867),
    [sym__soft_identifier] = STATE(4411),
    [sym_wildcard] = STATE(8027),
    [sym__non_null_literal] = STATE(9158),
    [sym_boolean_literal] = STATE(8784),
    [sym_interpolated_string_expression] = STATE(9158),
    [sym_string] = STATE(8784),
    [sym_unit] = STATE(9158),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(2205),
    [sym_block_comment] = STATE(2205),
    [sym__alpha_identifier] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1230),
    [anon_sym__] = ACTIONS(1232),
    [anon_sym_PLUS] = ACTIONS(1234),
    [anon_sym_DASH] = ACTIONS(1234),
    [anon_sym_end] = ACTIONS(1236),
    [anon_sym_if] = ACTIONS(1442),
    [anon_sym_while] = ACTIONS(1444),
    [anon_sym_for] = ACTIONS(1446),
    [anon_sym_try] = ACTIONS(1448),
    [anon_sym_new] = ACTIONS(1238),
    [anon_sym_opaque] = ACTIONS(1236),
    [anon_sym_implicit] = ACTIONS(1450),
    [anon_sym_inline] = ACTIONS(1240),
    [anon_sym_infix] = ACTIONS(1236),
    [anon_sym_open] = ACTIONS(1236),
    [anon_sym_transparent] = ACTIONS(1236),
    [anon_sym_LPAREN] = ACTIONS(1242),
    [anon_sym_macro] = ACTIONS(1452),
    [anon_sym_BANG] = ACTIONS(1234),
    [anon_sym_TILDE] = ACTIONS(1234),
    [anon_sym_DOLLAR] = ACTIONS(1244),
    [anon_sym_SQUOTE] = ACTIONS(1246),
    [sym__backquoted_id] = ACTIONS(1248),
    [sym_operator_identifier] = ACTIONS(1454),
    [sym_integer_literal] = ACTIONS(1252),
    [sym_floating_point_literal] = ACTIONS(1254),
    [anon_sym_true] = ACTIONS(1256),
    [anon_sym_false] = ACTIONS(1256),
    [sym_character_literal] = ACTIONS(1254),
    [sym_null_literal] = ACTIONS(1258),
    [anon_sym_return] = ACTIONS(1456),
    [anon_sym_throw] = ACTIONS(1458),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1260),
    [sym__simple_string] = ACTIONS(1260),
  },
  [2206] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8838),
    [sym_expression] = STATE(15577),
    [sym__simple_expression] = STATE(5742),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16508),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(4998),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(7932),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2206),
    [sym_block_comment] = STATE(2206),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1592),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [2207] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8894),
    [sym_expression] = STATE(14814),
    [sym__simple_expression] = STATE(5761),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10011),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16649),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9653),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8069),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2207),
    [sym_block_comment] = STATE(2207),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [2208] = {
    [sym_inline_modifier] = STATE(2337),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(11623),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(2208),
    [sym_block_comment] = STATE(2208),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [2209] = {
    [sym_inline_modifier] = STATE(2337),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(11625),
    [sym__simple_expression] = STATE(5000),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16053),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8646),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4483),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6010),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(2209),
    [sym_block_comment] = STATE(2209),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2484),
    [anon_sym_while] = ACTIONS(1534),
    [anon_sym_for] = ACTIONS(1536),
    [anon_sym_try] = ACTIONS(1538),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1540),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1542),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1544),
    [anon_sym_throw] = ACTIONS(1546),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [2210] = {
    [sym_inline_modifier] = STATE(2292),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(13176),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(2210),
    [sym_block_comment] = STATE(2210),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [2211] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14636),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2211),
    [sym_block_comment] = STATE(2211),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2212] = {
    [sym_inline_modifier] = STATE(2334),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(12660),
    [sym__simple_expression] = STATE(7381),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16065),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10307),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5565),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(8959),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(2212),
    [sym_block_comment] = STATE(2212),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2362),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2366),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2368),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2370),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2372),
    [anon_sym_throw] = ACTIONS(2374),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [2213] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(7476),
    [sym_expression] = STATE(14741),
    [sym__simple_expression] = STATE(4884),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16629),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4560),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(6622),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2213),
    [sym_block_comment] = STATE(2213),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1136),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [2214] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9357),
    [sym_expression] = STATE(14901),
    [sym__simple_expression] = STATE(6138),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10314),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16669),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9752),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5076),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8690),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2214),
    [sym_block_comment] = STATE(2214),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1662),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [2215] = {
    [sym_inline_modifier] = STATE(2292),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(13308),
    [sym__simple_expression] = STATE(8033),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15962),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10598),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(5995),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9330),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(2215),
    [sym_block_comment] = STATE(2215),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2302),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2306),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2310),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2312),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2314),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [2216] = {
    [sym_inline_modifier] = STATE(2316),
    [sym_block] = STATE(8838),
    [sym_expression] = STATE(13420),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(2216),
    [sym_block_comment] = STATE(2216),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [2217] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(15287),
    [sym__simple_expression] = STATE(5216),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(9399),
    [sym_postfix_expression] = STATE(13310),
    [sym__postfix_expression_choice] = STATE(13684),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(8998),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(4482),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(6629),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2217),
    [sym_block_comment] = STATE(2217),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(1606),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2218] = {
    [sym_inline_modifier] = STATE(2316),
    [sym_block] = STATE(8838),
    [sym_expression] = STATE(13578),
    [sym__simple_expression] = STATE(6133),
    [sym_lambda_expression] = STATE(13650),
    [sym_if_expression] = STATE(13650),
    [sym_match_expression] = STATE(13650),
    [sym_try_expression] = STATE(13650),
    [sym_bindings] = STATE(15925),
    [sym_case_block] = STATE(8838),
    [sym_assignment_expression] = STATE(13650),
    [sym_generic_function] = STATE(8838),
    [sym_call_expression] = STATE(8838),
    [sym_field_expression] = STATE(8838),
    [sym_instance_expression] = STATE(8838),
    [sym_ascription_expression] = STATE(13650),
    [sym_infix_expression] = STATE(9789),
    [sym_postfix_expression] = STATE(13422),
    [sym__postfix_expression_choice] = STATE(16316),
    [sym_macro_body] = STATE(13650),
    [sym_prefix_expression] = STATE(9872),
    [sym_tuple_expression] = STATE(8838),
    [sym_parenthesized_expression] = STATE(8838),
    [sym_splice_expression] = STATE(8838),
    [sym_quote_expression] = STATE(8838),
    [sym_identifier] = STATE(5377),
    [sym__soft_identifier] = STATE(6091),
    [sym_wildcard] = STATE(8572),
    [sym__non_null_literal] = STATE(8838),
    [sym_boolean_literal] = STATE(9231),
    [sym_interpolated_string_expression] = STATE(8838),
    [sym_string] = STATE(9231),
    [sym_unit] = STATE(8838),
    [sym_return_expression] = STATE(13650),
    [sym_throw_expression] = STATE(13650),
    [sym_while_expression] = STATE(13650),
    [sym_do_while_expression] = STATE(13650),
    [sym_for_expression] = STATE(13650),
    [sym_comment] = STATE(2218),
    [sym_block_comment] = STATE(2218),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1982),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1986),
    [anon_sym_try] = ACTIONS(1988),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1994),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1996),
    [anon_sym_throw] = ACTIONS(1998),
    [anon_sym_do] = ACTIONS(2000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [2219] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2219),
    [sym_block_comment] = STATE(2219),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2220] = {
    [sym_inline_modifier] = STATE(2338),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(12471),
    [sym__simple_expression] = STATE(5559),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15942),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9343),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5006),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8062),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(2220),
    [sym_block_comment] = STATE(2220),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2258),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2262),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2266),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2268),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2270),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [2221] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8894),
    [sym_expression] = STATE(14814),
    [sym__simple_expression] = STATE(5770),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16649),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8069),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2221),
    [sym_block_comment] = STATE(2221),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [2222] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(14981),
    [sym__simple_expression] = STATE(4565),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(7580),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16688),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(7033),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4278),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(5051),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2222),
    [sym_block_comment] = STATE(2222),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(976),
    [anon_sym_DASH] = ACTIONS(976),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(976),
    [anon_sym_TILDE] = ACTIONS(976),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(992),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [2223] = {
    [sym_inline_modifier] = STATE(2338),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(12502),
    [sym__simple_expression] = STATE(5559),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15942),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9343),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5006),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8062),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(2223),
    [sym_block_comment] = STATE(2223),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2258),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2262),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2266),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2268),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2270),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [2224] = {
    [sym_inline_modifier] = STATE(2338),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(12504),
    [sym__simple_expression] = STATE(5559),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15942),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9343),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(5006),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(8062),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(2224),
    [sym_block_comment] = STATE(2224),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2258),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2262),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2266),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2268),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2270),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [2225] = {
    [sym_inline_modifier] = STATE(2294),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(13176),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(2225),
    [sym_block_comment] = STATE(2225),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [2226] = {
    [sym_inline_modifier] = STATE(2339),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(12660),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(2226),
    [sym_block_comment] = STATE(2226),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [2227] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9357),
    [sym_expression] = STATE(14901),
    [sym__simple_expression] = STATE(6155),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9357),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9357),
    [sym_call_expression] = STATE(9357),
    [sym_field_expression] = STATE(9357),
    [sym_instance_expression] = STATE(9357),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16669),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9357),
    [sym_parenthesized_expression] = STATE(9357),
    [sym_splice_expression] = STATE(9357),
    [sym_quote_expression] = STATE(9357),
    [sym_identifier] = STATE(5076),
    [sym__soft_identifier] = STATE(4471),
    [sym_wildcard] = STATE(8690),
    [sym__non_null_literal] = STATE(9357),
    [sym_boolean_literal] = STATE(9685),
    [sym_interpolated_string_expression] = STATE(9357),
    [sym_string] = STATE(9685),
    [sym_unit] = STATE(9357),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2227),
    [sym_block_comment] = STATE(2227),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1662),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [2228] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(15037),
    [sym__simple_expression] = STATE(4908),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(8997),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16707),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(8101),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(4485),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(6070),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2228),
    [sym_block_comment] = STATE(2228),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1302),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [2229] = {
    [sym_inline_modifier] = STATE(2317),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(12508),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(2229),
    [sym_block_comment] = STATE(2229),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [2230] = {
    [sym_inline_modifier] = STATE(2294),
    [sym_block] = STATE(8222),
    [sym_expression] = STATE(13308),
    [sym__simple_expression] = STATE(7754),
    [sym_lambda_expression] = STATE(13322),
    [sym_if_expression] = STATE(13322),
    [sym_match_expression] = STATE(13322),
    [sym_try_expression] = STATE(13322),
    [sym_bindings] = STATE(15880),
    [sym_case_block] = STATE(8222),
    [sym_assignment_expression] = STATE(13322),
    [sym_generic_function] = STATE(8222),
    [sym_call_expression] = STATE(8222),
    [sym_field_expression] = STATE(8222),
    [sym_instance_expression] = STATE(8222),
    [sym_ascription_expression] = STATE(13322),
    [sym_infix_expression] = STATE(9340),
    [sym_postfix_expression] = STATE(13044),
    [sym__postfix_expression_choice] = STATE(16954),
    [sym_macro_body] = STATE(13322),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(8222),
    [sym_parenthesized_expression] = STATE(8222),
    [sym_splice_expression] = STATE(8222),
    [sym_quote_expression] = STATE(8222),
    [sym_identifier] = STATE(6096),
    [sym__soft_identifier] = STATE(5752),
    [sym_wildcard] = STATE(9415),
    [sym__non_null_literal] = STATE(8222),
    [sym_boolean_literal] = STATE(8229),
    [sym_interpolated_string_expression] = STATE(8222),
    [sym_string] = STATE(8229),
    [sym_unit] = STATE(8222),
    [sym_return_expression] = STATE(13322),
    [sym_throw_expression] = STATE(13322),
    [sym_while_expression] = STATE(13322),
    [sym_do_while_expression] = STATE(13322),
    [sym_for_expression] = STATE(13322),
    [sym_comment] = STATE(2230),
    [sym_block_comment] = STATE(2230),
    [sym__alpha_identifier] = ACTIONS(1480),
    [anon_sym_LBRACE] = ACTIONS(1484),
    [anon_sym__] = ACTIONS(1486),
    [anon_sym_PLUS] = ACTIONS(1488),
    [anon_sym_DASH] = ACTIONS(1488),
    [anon_sym_end] = ACTIONS(1490),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2144),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2148),
    [anon_sym_new] = ACTIONS(1492),
    [anon_sym_opaque] = ACTIONS(1490),
    [anon_sym_implicit] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(1494),
    [anon_sym_infix] = ACTIONS(1490),
    [anon_sym_open] = ACTIONS(1490),
    [anon_sym_transparent] = ACTIONS(1490),
    [anon_sym_LPAREN] = ACTIONS(1496),
    [anon_sym_macro] = ACTIONS(1794),
    [anon_sym_BANG] = ACTIONS(1488),
    [anon_sym_TILDE] = ACTIONS(1488),
    [anon_sym_DOLLAR] = ACTIONS(1498),
    [anon_sym_SQUOTE] = ACTIONS(1500),
    [sym__backquoted_id] = ACTIONS(1502),
    [sym_operator_identifier] = ACTIONS(2152),
    [sym_integer_literal] = ACTIONS(1506),
    [sym_floating_point_literal] = ACTIONS(1508),
    [anon_sym_true] = ACTIONS(1510),
    [anon_sym_false] = ACTIONS(1510),
    [sym_character_literal] = ACTIONS(1508),
    [sym_null_literal] = ACTIONS(1512),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2156),
    [anon_sym_do] = ACTIONS(1802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1514),
    [sym__simple_string] = ACTIONS(1514),
  },
  [2231] = {
    [sym_inline_modifier] = STATE(2339),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(12791),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(2231),
    [sym_block_comment] = STATE(2231),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [2232] = {
    [sym_inline_modifier] = STATE(2317),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(12532),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(2232),
    [sym_block_comment] = STATE(2232),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [2233] = {
    [sym_inline_modifier] = STATE(2339),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(12836),
    [sym__simple_expression] = STATE(6687),
    [sym_lambda_expression] = STATE(13180),
    [sym_if_expression] = STATE(13180),
    [sym_match_expression] = STATE(13180),
    [sym_try_expression] = STATE(13180),
    [sym_bindings] = STATE(16048),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13180),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13180),
    [sym_infix_expression] = STATE(9067),
    [sym_postfix_expression] = STATE(13005),
    [sym__postfix_expression_choice] = STATE(16609),
    [sym_macro_body] = STATE(13180),
    [sym_prefix_expression] = STATE(10217),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(5585),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(9022),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13180),
    [sym_throw_expression] = STATE(13180),
    [sym_while_expression] = STATE(13180),
    [sym_do_while_expression] = STATE(13180),
    [sym_for_expression] = STATE(13180),
    [sym_comment] = STATE(2233),
    [sym_block_comment] = STATE(2233),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(1286),
    [anon_sym_DASH] = ACTIONS(1286),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(2410),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2414),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(2418),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(1684),
    [anon_sym_BANG] = ACTIONS(1286),
    [anon_sym_TILDE] = ACTIONS(1286),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(2420),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(2422),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(1692),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [2234] = {
    [sym_inline_modifier] = STATE(2312),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(11627),
    [sym__simple_expression] = STATE(5323),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16092),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8747),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4658),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(7006),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(2234),
    [sym_block_comment] = STATE(2234),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(1262),
    [anon_sym_while] = ACTIONS(1264),
    [anon_sym_for] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1268),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1270),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [2235] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(6188),
    [sym_expression] = STATE(14981),
    [sym__simple_expression] = STATE(4520),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(6188),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(6188),
    [sym_call_expression] = STATE(6188),
    [sym_field_expression] = STATE(6188),
    [sym_instance_expression] = STATE(6188),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16688),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(6188),
    [sym_parenthesized_expression] = STATE(6188),
    [sym_splice_expression] = STATE(6188),
    [sym_quote_expression] = STATE(6188),
    [sym_identifier] = STATE(4278),
    [sym__soft_identifier] = STATE(4594),
    [sym_wildcard] = STATE(5051),
    [sym__non_null_literal] = STATE(6188),
    [sym_boolean_literal] = STATE(6247),
    [sym_interpolated_string_expression] = STATE(6188),
    [sym_string] = STATE(6247),
    [sym_unit] = STATE(6188),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2235),
    [sym_block_comment] = STATE(2235),
    [sym__alpha_identifier] = ACTIONS(968),
    [anon_sym_LBRACE] = ACTIONS(972),
    [anon_sym__] = ACTIONS(974),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(978),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(980),
    [anon_sym_opaque] = ACTIONS(978),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(982),
    [anon_sym_infix] = ACTIONS(978),
    [anon_sym_open] = ACTIONS(978),
    [anon_sym_transparent] = ACTIONS(978),
    [anon_sym_LPAREN] = ACTIONS(984),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(986),
    [anon_sym_SQUOTE] = ACTIONS(988),
    [sym__backquoted_id] = ACTIONS(990),
    [sym_operator_identifier] = ACTIONS(992),
    [sym_integer_literal] = ACTIONS(994),
    [sym_floating_point_literal] = ACTIONS(996),
    [anon_sym_true] = ACTIONS(998),
    [anon_sym_false] = ACTIONS(998),
    [sym_character_literal] = ACTIONS(996),
    [sym_null_literal] = ACTIONS(1000),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1002),
    [sym__simple_string] = ACTIONS(1002),
  },
  [2236] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8399),
    [sym_expression] = STATE(15115),
    [sym__simple_expression] = STATE(5364),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(9433),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16745),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9024),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4740),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(6693),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2236),
    [sym_block_comment] = STATE(2236),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1358),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [2237] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15490),
    [sym__simple_expression] = STATE(6161),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2237),
    [sym_block_comment] = STATE(2237),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2238] = {
    [sym_inline_modifier] = STATE(2314),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(12475),
    [sym__simple_expression] = STATE(5330),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15889),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(8841),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(4669),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(7074),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(2238),
    [sym_block_comment] = STATE(2238),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(1150),
    [anon_sym_while] = ACTIONS(1152),
    [anon_sym_for] = ACTIONS(1154),
    [anon_sym_try] = ACTIONS(1158),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(1160),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(1164),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(1166),
    [anon_sym_throw] = ACTIONS(1168),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [2239] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(7648),
    [sym_expression] = STATE(15037),
    [sym__simple_expression] = STATE(4914),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(7648),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(7648),
    [sym_call_expression] = STATE(7648),
    [sym_field_expression] = STATE(7648),
    [sym_instance_expression] = STATE(7648),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16707),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(7648),
    [sym_parenthesized_expression] = STATE(7648),
    [sym_splice_expression] = STATE(7648),
    [sym_quote_expression] = STATE(7648),
    [sym_identifier] = STATE(4485),
    [sym__soft_identifier] = STATE(5185),
    [sym_wildcard] = STATE(6070),
    [sym__non_null_literal] = STATE(7648),
    [sym_boolean_literal] = STATE(7829),
    [sym_interpolated_string_expression] = STATE(7648),
    [sym_string] = STATE(7829),
    [sym_unit] = STATE(7648),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2239),
    [sym_block_comment] = STATE(2239),
    [sym__alpha_identifier] = ACTIONS(1278),
    [anon_sym_LBRACE] = ACTIONS(1282),
    [anon_sym__] = ACTIONS(1284),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(1288),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1290),
    [anon_sym_opaque] = ACTIONS(1288),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1292),
    [anon_sym_infix] = ACTIONS(1288),
    [anon_sym_open] = ACTIONS(1288),
    [anon_sym_transparent] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1294),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(1296),
    [anon_sym_SQUOTE] = ACTIONS(1298),
    [sym__backquoted_id] = ACTIONS(1300),
    [sym_operator_identifier] = ACTIONS(1302),
    [sym_integer_literal] = ACTIONS(1304),
    [sym_floating_point_literal] = ACTIONS(1306),
    [anon_sym_true] = ACTIONS(1308),
    [anon_sym_false] = ACTIONS(1308),
    [sym_character_literal] = ACTIONS(1306),
    [sym_null_literal] = ACTIONS(1310),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1312),
    [sym__simple_string] = ACTIONS(1312),
  },
  [2240] = {
    [sym_inline_modifier] = STATE(2340),
    [sym_block] = STATE(8399),
    [sym_expression] = STATE(13194),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(2240),
    [sym_block_comment] = STATE(2240),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [2241] = {
    [sym_inline_modifier] = STATE(2318),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(13379),
    [sym__simple_expression] = STATE(8653),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(16129),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10722),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(7377),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9808),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(2241),
    [sym_block_comment] = STATE(2241),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2200),
    [anon_sym_for] = ACTIONS(2202),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2206),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2210),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [2242] = {
    [sym_inline_modifier] = STATE(2340),
    [sym_block] = STATE(8399),
    [sym_expression] = STATE(13216),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(2242),
    [sym_block_comment] = STATE(2242),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [2243] = {
    [sym_inline_modifier] = STATE(2318),
    [sym_block] = STATE(8786),
    [sym_expression] = STATE(13460),
    [sym__simple_expression] = STATE(8653),
    [sym_lambda_expression] = STATE(13801),
    [sym_if_expression] = STATE(13801),
    [sym_match_expression] = STATE(13801),
    [sym_try_expression] = STATE(13801),
    [sym_bindings] = STATE(16129),
    [sym_case_block] = STATE(8786),
    [sym_assignment_expression] = STATE(13801),
    [sym_generic_function] = STATE(8786),
    [sym_call_expression] = STATE(8786),
    [sym_field_expression] = STATE(8786),
    [sym_instance_expression] = STATE(8786),
    [sym_ascription_expression] = STATE(13801),
    [sym_infix_expression] = STATE(9972),
    [sym_postfix_expression] = STATE(13447),
    [sym__postfix_expression_choice] = STATE(16292),
    [sym_macro_body] = STATE(13801),
    [sym_prefix_expression] = STATE(10722),
    [sym_tuple_expression] = STATE(8786),
    [sym_parenthesized_expression] = STATE(8786),
    [sym_splice_expression] = STATE(8786),
    [sym_quote_expression] = STATE(8786),
    [sym_identifier] = STATE(7377),
    [sym__soft_identifier] = STATE(6619),
    [sym_wildcard] = STATE(9808),
    [sym__non_null_literal] = STATE(8786),
    [sym_boolean_literal] = STATE(9185),
    [sym_interpolated_string_expression] = STATE(8786),
    [sym_string] = STATE(9185),
    [sym_unit] = STATE(8786),
    [sym_return_expression] = STATE(13801),
    [sym_throw_expression] = STATE(13801),
    [sym_while_expression] = STATE(13801),
    [sym_do_while_expression] = STATE(13801),
    [sym_for_expression] = STATE(13801),
    [sym_comment] = STATE(2243),
    [sym_block_comment] = STATE(2243),
    [sym__alpha_identifier] = ACTIONS(1804),
    [anon_sym_LBRACE] = ACTIONS(1808),
    [anon_sym__] = ACTIONS(1810),
    [anon_sym_PLUS] = ACTIONS(1812),
    [anon_sym_DASH] = ACTIONS(1812),
    [anon_sym_end] = ACTIONS(1814),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2200),
    [anon_sym_for] = ACTIONS(2202),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(1816),
    [anon_sym_opaque] = ACTIONS(1814),
    [anon_sym_implicit] = ACTIONS(2206),
    [anon_sym_inline] = ACTIONS(1818),
    [anon_sym_infix] = ACTIONS(1814),
    [anon_sym_open] = ACTIONS(1814),
    [anon_sym_transparent] = ACTIONS(1814),
    [anon_sym_LPAREN] = ACTIONS(1820),
    [anon_sym_macro] = ACTIONS(2208),
    [anon_sym_BANG] = ACTIONS(1812),
    [anon_sym_TILDE] = ACTIONS(1812),
    [anon_sym_DOLLAR] = ACTIONS(1822),
    [anon_sym_SQUOTE] = ACTIONS(1824),
    [sym__backquoted_id] = ACTIONS(1826),
    [sym_operator_identifier] = ACTIONS(2210),
    [sym_integer_literal] = ACTIONS(1830),
    [sym_floating_point_literal] = ACTIONS(1832),
    [anon_sym_true] = ACTIONS(1834),
    [anon_sym_false] = ACTIONS(1834),
    [sym_character_literal] = ACTIONS(1832),
    [sym_null_literal] = ACTIONS(1836),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2214),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1838),
    [sym__simple_string] = ACTIONS(1838),
  },
  [2244] = {
    [sym_inline_modifier] = STATE(2311),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12776),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(2244),
    [sym_block_comment] = STATE(2244),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2245] = {
    [sym_inline_modifier] = STATE(2340),
    [sym_block] = STATE(8399),
    [sym_expression] = STATE(13160),
    [sym__simple_expression] = STATE(5841),
    [sym_lambda_expression] = STATE(13334),
    [sym_if_expression] = STATE(13334),
    [sym_match_expression] = STATE(13334),
    [sym_try_expression] = STATE(13334),
    [sym_bindings] = STATE(16006),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13334),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13334),
    [sym_infix_expression] = STATE(9517),
    [sym_postfix_expression] = STATE(13075),
    [sym__postfix_expression_choice] = STATE(16726),
    [sym_macro_body] = STATE(13334),
    [sym_prefix_expression] = STATE(9518),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4883),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(7425),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13334),
    [sym_throw_expression] = STATE(13334),
    [sym_while_expression] = STATE(13334),
    [sym_do_while_expression] = STATE(13334),
    [sym_for_expression] = STATE(13334),
    [sym_comment] = STATE(2245),
    [sym_block_comment] = STATE(2245),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(1342),
    [anon_sym_DASH] = ACTIONS(1342),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(1730),
    [anon_sym_while] = ACTIONS(1732),
    [anon_sym_for] = ACTIONS(1734),
    [anon_sym_try] = ACTIONS(1736),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(1738),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(1740),
    [anon_sym_BANG] = ACTIONS(1342),
    [anon_sym_TILDE] = ACTIONS(1342),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1742),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(1744),
    [anon_sym_throw] = ACTIONS(1746),
    [anon_sym_do] = ACTIONS(1748),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [2246] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(8399),
    [sym_expression] = STATE(15115),
    [sym__simple_expression] = STATE(5370),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(8399),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(8399),
    [sym_call_expression] = STATE(8399),
    [sym_field_expression] = STATE(8399),
    [sym_instance_expression] = STATE(8399),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16745),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(8399),
    [sym_parenthesized_expression] = STATE(8399),
    [sym_splice_expression] = STATE(8399),
    [sym_quote_expression] = STATE(8399),
    [sym_identifier] = STATE(4740),
    [sym__soft_identifier] = STATE(5530),
    [sym_wildcard] = STATE(6693),
    [sym__non_null_literal] = STATE(8399),
    [sym_boolean_literal] = STATE(8206),
    [sym_interpolated_string_expression] = STATE(8399),
    [sym_string] = STATE(8206),
    [sym_unit] = STATE(8399),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2246),
    [sym_block_comment] = STATE(2246),
    [sym__alpha_identifier] = ACTIONS(1334),
    [anon_sym_LBRACE] = ACTIONS(1338),
    [anon_sym__] = ACTIONS(1340),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(1344),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(1346),
    [anon_sym_opaque] = ACTIONS(1344),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(1348),
    [anon_sym_infix] = ACTIONS(1344),
    [anon_sym_open] = ACTIONS(1344),
    [anon_sym_transparent] = ACTIONS(1344),
    [anon_sym_LPAREN] = ACTIONS(1350),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(1352),
    [anon_sym_SQUOTE] = ACTIONS(1354),
    [sym__backquoted_id] = ACTIONS(1356),
    [sym_operator_identifier] = ACTIONS(1358),
    [sym_integer_literal] = ACTIONS(1360),
    [sym_floating_point_literal] = ACTIONS(1362),
    [anon_sym_true] = ACTIONS(1364),
    [anon_sym_false] = ACTIONS(1364),
    [sym_character_literal] = ACTIONS(1362),
    [sym_null_literal] = ACTIONS(1366),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1368),
    [sym__simple_string] = ACTIONS(1368),
  },
  [2247] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15490),
    [sym__simple_expression] = STATE(6183),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10247),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(9749),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2247),
    [sym_block_comment] = STATE(2247),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2248] = {
    [sym_inline_modifier] = STATE(2311),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12801),
    [sym__simple_expression] = STATE(7331),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16084),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10619),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10364),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5576),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8999),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(2248),
    [sym_block_comment] = STATE(2248),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(591),
    [anon_sym_for] = ACTIONS(593),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2052),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(603),
    [anon_sym_BANG] = ACTIONS(587),
    [anon_sym_TILDE] = ACTIONS(587),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(605),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(607),
    [anon_sym_throw] = ACTIONS(609),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2249] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(13655),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2249),
    [sym_block_comment] = STATE(2249),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2250] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(13671),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2250),
    [sym_block_comment] = STATE(2250),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2251] = {
    [sym_inline_modifier] = STATE(2341),
    [sym_block] = STATE(7476),
    [sym_expression] = STATE(12852),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(2251),
    [sym_block_comment] = STATE(2251),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [2252] = {
    [sym_inline_modifier] = STATE(2317),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(12475),
    [sym__simple_expression] = STATE(6009),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(16032),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9745),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5207),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8679),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(2252),
    [sym_block_comment] = STATE(2252),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2124),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2128),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2132),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2136),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [2253] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(10212),
    [sym_expression] = STATE(15444),
    [sym__simple_expression] = STATE(7619),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10666),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16300),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10529),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6453),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9533),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2253),
    [sym_block_comment] = STATE(2253),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(2356),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [2254] = {
    [sym_inline_modifier] = STATE(2341),
    [sym_block] = STATE(7476),
    [sym_expression] = STATE(12957),
    [sym__simple_expression] = STATE(5206),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15904),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8940),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4707),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7382),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(2254),
    [sym_block_comment] = STATE(2254),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(2250),
    [anon_sym_while] = ACTIONS(1750),
    [anon_sym_for] = ACTIONS(1752),
    [anon_sym_try] = ACTIONS(1754),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1756),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1758),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1760),
    [anon_sym_throw] = ACTIONS(1762),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [2255] = {
    [sym_inline_modifier] = STATE(2319),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13745),
    [sym__simple_expression] = STATE(6682),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(15930),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10414),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5580),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9016),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(2255),
    [sym_block_comment] = STATE(2255),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(3232),
    [anon_sym_while] = ACTIONS(3218),
    [anon_sym_for] = ACTIONS(3220),
    [anon_sym_try] = ACTIONS(3222),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(3224),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(3226),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(3228),
    [anon_sym_throw] = ACTIONS(3230),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [2256] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(10212),
    [sym_expression] = STATE(15444),
    [sym__simple_expression] = STATE(7498),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16300),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6453),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9533),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2256),
    [sym_block_comment] = STATE(2256),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(2356),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [2257] = {
    [sym_inline_modifier] = STATE(2319),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13774),
    [sym__simple_expression] = STATE(6682),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(15930),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10630),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10414),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5580),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(9016),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(2257),
    [sym_block_comment] = STATE(2257),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DASH] = ACTIONS(495),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(3232),
    [anon_sym_while] = ACTIONS(3218),
    [anon_sym_for] = ACTIONS(3220),
    [anon_sym_try] = ACTIONS(3222),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(3224),
    [anon_sym_inline] = ACTIONS(519),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(3226),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(3228),
    [anon_sym_throw] = ACTIONS(3230),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [2258] = {
    [sym_inline_modifier] = STATE(2342),
    [sym_block] = STATE(8894),
    [sym_expression] = STATE(13419),
    [sym__simple_expression] = STATE(6017),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15961),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9804),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5210),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(2258),
    [sym_block_comment] = STATE(2258),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(2380),
    [anon_sym_while] = ACTIONS(2338),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2342),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(2346),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2350),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [2259] = {
    [sym_inline_modifier] = STATE(2296),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(12491),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(2259),
    [sym_block_comment] = STATE(2259),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [2260] = {
    [sym_inline_modifier] = STATE(2342),
    [sym_block] = STATE(8894),
    [sym_expression] = STATE(13510),
    [sym__simple_expression] = STATE(6017),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15961),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9804),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5210),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(2260),
    [sym_block_comment] = STATE(2260),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(2380),
    [anon_sym_while] = ACTIONS(2338),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2342),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(2346),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2350),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [2261] = {
    [sym_inline_modifier] = STATE(2296),
    [sym_block] = STATE(6675),
    [sym_expression] = STATE(12493),
    [sym__simple_expression] = STATE(6251),
    [sym_lambda_expression] = STATE(12515),
    [sym_if_expression] = STATE(12515),
    [sym_match_expression] = STATE(12515),
    [sym_try_expression] = STATE(12515),
    [sym_bindings] = STATE(16135),
    [sym_case_block] = STATE(6675),
    [sym_assignment_expression] = STATE(12515),
    [sym_generic_function] = STATE(6675),
    [sym_call_expression] = STATE(6675),
    [sym_field_expression] = STATE(6675),
    [sym_instance_expression] = STATE(6675),
    [sym_ascription_expression] = STATE(12515),
    [sym_infix_expression] = STATE(8402),
    [sym_postfix_expression] = STATE(12066),
    [sym__postfix_expression_choice] = STATE(17276),
    [sym_macro_body] = STATE(12515),
    [sym_prefix_expression] = STATE(9751),
    [sym_tuple_expression] = STATE(6675),
    [sym_parenthesized_expression] = STATE(6675),
    [sym_splice_expression] = STATE(6675),
    [sym_quote_expression] = STATE(6675),
    [sym_identifier] = STATE(5246),
    [sym__soft_identifier] = STATE(4997),
    [sym_wildcard] = STATE(8348),
    [sym__non_null_literal] = STATE(6675),
    [sym_boolean_literal] = STATE(6808),
    [sym_interpolated_string_expression] = STATE(6675),
    [sym_string] = STATE(6808),
    [sym_unit] = STATE(6675),
    [sym_return_expression] = STATE(12515),
    [sym_throw_expression] = STATE(12515),
    [sym_while_expression] = STATE(12515),
    [sym_do_while_expression] = STATE(12515),
    [sym_for_expression] = STATE(12515),
    [sym_comment] = STATE(2261),
    [sym_block_comment] = STATE(2261),
    [sym__alpha_identifier] = ACTIONS(1040),
    [anon_sym_LBRACE] = ACTIONS(1044),
    [anon_sym__] = ACTIONS(1046),
    [anon_sym_PLUS] = ACTIONS(1048),
    [anon_sym_DASH] = ACTIONS(1048),
    [anon_sym_end] = ACTIONS(1050),
    [anon_sym_if] = ACTIONS(1944),
    [anon_sym_while] = ACTIONS(1946),
    [anon_sym_for] = ACTIONS(1948),
    [anon_sym_try] = ACTIONS(1950),
    [anon_sym_new] = ACTIONS(1052),
    [anon_sym_opaque] = ACTIONS(1050),
    [anon_sym_implicit] = ACTIONS(1952),
    [anon_sym_inline] = ACTIONS(1054),
    [anon_sym_infix] = ACTIONS(1050),
    [anon_sym_open] = ACTIONS(1050),
    [anon_sym_transparent] = ACTIONS(1050),
    [anon_sym_LPAREN] = ACTIONS(1056),
    [anon_sym_macro] = ACTIONS(1954),
    [anon_sym_BANG] = ACTIONS(1048),
    [anon_sym_TILDE] = ACTIONS(1048),
    [anon_sym_DOLLAR] = ACTIONS(1058),
    [anon_sym_SQUOTE] = ACTIONS(1060),
    [sym__backquoted_id] = ACTIONS(1062),
    [sym_operator_identifier] = ACTIONS(1956),
    [sym_integer_literal] = ACTIONS(1066),
    [sym_floating_point_literal] = ACTIONS(1068),
    [anon_sym_true] = ACTIONS(1070),
    [anon_sym_false] = ACTIONS(1070),
    [sym_character_literal] = ACTIONS(1068),
    [sym_null_literal] = ACTIONS(1072),
    [anon_sym_return] = ACTIONS(1958),
    [anon_sym_throw] = ACTIONS(1960),
    [anon_sym_do] = ACTIONS(1962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1074),
    [sym__simple_string] = ACTIONS(1074),
  },
  [2262] = {
    [sym_inline_modifier] = STATE(2342),
    [sym_block] = STATE(8894),
    [sym_expression] = STATE(13336),
    [sym__simple_expression] = STATE(6017),
    [sym_lambda_expression] = STATE(13665),
    [sym_if_expression] = STATE(13665),
    [sym_match_expression] = STATE(13665),
    [sym_try_expression] = STATE(13665),
    [sym_bindings] = STATE(15961),
    [sym_case_block] = STATE(8894),
    [sym_assignment_expression] = STATE(13665),
    [sym_generic_function] = STATE(8894),
    [sym_call_expression] = STATE(8894),
    [sym_field_expression] = STATE(8894),
    [sym_instance_expression] = STATE(8894),
    [sym_ascription_expression] = STATE(13665),
    [sym_infix_expression] = STATE(9769),
    [sym_postfix_expression] = STATE(13370),
    [sym__postfix_expression_choice] = STATE(16549),
    [sym_macro_body] = STATE(13665),
    [sym_prefix_expression] = STATE(9804),
    [sym_tuple_expression] = STATE(8894),
    [sym_parenthesized_expression] = STATE(8894),
    [sym_splice_expression] = STATE(8894),
    [sym_quote_expression] = STATE(8894),
    [sym_identifier] = STATE(5210),
    [sym__soft_identifier] = STATE(6117),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(8894),
    [sym_boolean_literal] = STATE(9082),
    [sym_interpolated_string_expression] = STATE(8894),
    [sym_string] = STATE(9082),
    [sym_unit] = STATE(8894),
    [sym_return_expression] = STATE(13665),
    [sym_throw_expression] = STATE(13665),
    [sym_while_expression] = STATE(13665),
    [sym_do_while_expression] = STATE(13665),
    [sym_for_expression] = STATE(13665),
    [sym_comment] = STATE(2262),
    [sym_block_comment] = STATE(2262),
    [sym__alpha_identifier] = ACTIONS(1694),
    [anon_sym_LBRACE] = ACTIONS(1698),
    [anon_sym__] = ACTIONS(1700),
    [anon_sym_PLUS] = ACTIONS(1702),
    [anon_sym_DASH] = ACTIONS(1702),
    [anon_sym_end] = ACTIONS(1704),
    [anon_sym_if] = ACTIONS(2380),
    [anon_sym_while] = ACTIONS(2338),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2342),
    [anon_sym_new] = ACTIONS(1706),
    [anon_sym_opaque] = ACTIONS(1704),
    [anon_sym_implicit] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(1708),
    [anon_sym_infix] = ACTIONS(1704),
    [anon_sym_open] = ACTIONS(1704),
    [anon_sym_transparent] = ACTIONS(1704),
    [anon_sym_LPAREN] = ACTIONS(1710),
    [anon_sym_macro] = ACTIONS(1934),
    [anon_sym_BANG] = ACTIONS(1702),
    [anon_sym_TILDE] = ACTIONS(1702),
    [anon_sym_DOLLAR] = ACTIONS(1712),
    [anon_sym_SQUOTE] = ACTIONS(1714),
    [sym__backquoted_id] = ACTIONS(1716),
    [sym_operator_identifier] = ACTIONS(2346),
    [sym_integer_literal] = ACTIONS(1720),
    [sym_floating_point_literal] = ACTIONS(1722),
    [anon_sym_true] = ACTIONS(1724),
    [anon_sym_false] = ACTIONS(1724),
    [sym_character_literal] = ACTIONS(1722),
    [sym_null_literal] = ACTIONS(1726),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2350),
    [anon_sym_do] = ACTIONS(1942),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1728),
    [sym__simple_string] = ACTIONS(1728),
  },
  [2263] = {
    [sym_inline_modifier] = STATE(2344),
    [sym_block] = STATE(6874),
    [sym_expression] = STATE(12471),
    [sym__simple_expression] = STATE(5582),
    [sym_lambda_expression] = STATE(12384),
    [sym_if_expression] = STATE(12384),
    [sym_match_expression] = STATE(12384),
    [sym_try_expression] = STATE(12384),
    [sym_bindings] = STATE(15990),
    [sym_case_block] = STATE(6874),
    [sym_assignment_expression] = STATE(12384),
    [sym_generic_function] = STATE(6874),
    [sym_call_expression] = STATE(6874),
    [sym_field_expression] = STATE(6874),
    [sym_instance_expression] = STATE(6874),
    [sym_ascription_expression] = STATE(12384),
    [sym_infix_expression] = STATE(8484),
    [sym_postfix_expression] = STATE(11941),
    [sym__postfix_expression_choice] = STATE(16207),
    [sym_macro_body] = STATE(12384),
    [sym_prefix_expression] = STATE(9422),
    [sym_tuple_expression] = STATE(6874),
    [sym_parenthesized_expression] = STATE(6874),
    [sym_splice_expression] = STATE(6874),
    [sym_quote_expression] = STATE(6874),
    [sym_identifier] = STATE(4761),
    [sym__soft_identifier] = STATE(4809),
    [sym_wildcard] = STATE(7890),
    [sym__non_null_literal] = STATE(6874),
    [sym_boolean_literal] = STATE(7105),
    [sym_interpolated_string_expression] = STATE(6874),
    [sym_string] = STATE(7105),
    [sym_unit] = STATE(6874),
    [sym_return_expression] = STATE(12384),
    [sym_throw_expression] = STATE(12384),
    [sym_while_expression] = STATE(12384),
    [sym_do_while_expression] = STATE(12384),
    [sym_for_expression] = STATE(12384),
    [sym_comment] = STATE(2263),
    [sym_block_comment] = STATE(2263),
    [sym__alpha_identifier] = ACTIONS(1076),
    [anon_sym_LBRACE] = ACTIONS(1080),
    [anon_sym__] = ACTIONS(1082),
    [anon_sym_PLUS] = ACTIONS(1084),
    [anon_sym_DASH] = ACTIONS(1084),
    [anon_sym_end] = ACTIONS(1086),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2108),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(1088),
    [anon_sym_opaque] = ACTIONS(1086),
    [anon_sym_implicit] = ACTIONS(2112),
    [anon_sym_inline] = ACTIONS(1090),
    [anon_sym_infix] = ACTIONS(1086),
    [anon_sym_open] = ACTIONS(1086),
    [anon_sym_transparent] = ACTIONS(1086),
    [anon_sym_LPAREN] = ACTIONS(1092),
    [anon_sym_macro] = ACTIONS(1774),
    [anon_sym_BANG] = ACTIONS(1084),
    [anon_sym_TILDE] = ACTIONS(1084),
    [anon_sym_DOLLAR] = ACTIONS(1094),
    [anon_sym_SQUOTE] = ACTIONS(1096),
    [sym__backquoted_id] = ACTIONS(1098),
    [sym_operator_identifier] = ACTIONS(2114),
    [sym_integer_literal] = ACTIONS(1102),
    [sym_floating_point_literal] = ACTIONS(1104),
    [anon_sym_true] = ACTIONS(1106),
    [anon_sym_false] = ACTIONS(1106),
    [sym_character_literal] = ACTIONS(1104),
    [sym_null_literal] = ACTIONS(1108),
    [anon_sym_return] = ACTIONS(2116),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(1782),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1110),
    [sym__simple_string] = ACTIONS(1110),
  },
  [2264] = {
    [sym_inline_modifier] = STATE(2320),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12776),
    [sym__simple_expression] = STATE(6186),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16018),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9989),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5240),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8124),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(2264),
    [sym_block_comment] = STATE(2264),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3237),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2488),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2492),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2494),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2496),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2265] = {
    [sym_inline_modifier] = STATE(2320),
    [sym_block] = STATE(7873),
    [sym_expression] = STATE(12801),
    [sym__simple_expression] = STATE(6186),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(16018),
    [sym_case_block] = STATE(7873),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(7873),
    [sym_call_expression] = STATE(7873),
    [sym_field_expression] = STATE(7873),
    [sym_instance_expression] = STATE(7873),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(9489),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(17501),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(9989),
    [sym_tuple_expression] = STATE(7873),
    [sym_parenthesized_expression] = STATE(7873),
    [sym_splice_expression] = STATE(7873),
    [sym_quote_expression] = STATE(7873),
    [sym_identifier] = STATE(5240),
    [sym__soft_identifier] = STATE(5337),
    [sym_wildcard] = STATE(8124),
    [sym__non_null_literal] = STATE(7873),
    [sym_boolean_literal] = STATE(7802),
    [sym_interpolated_string_expression] = STATE(7873),
    [sym_string] = STATE(7802),
    [sym_unit] = STATE(7873),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(2265),
    [sym_block_comment] = STATE(2265),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(645),
    [anon_sym_if] = ACTIONS(3237),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2488),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(645),
    [anon_sym_implicit] = ACTIONS(2492),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(645),
    [anon_sym_open] = ACTIONS(645),
    [anon_sym_transparent] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2494),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2496),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2266] = {
    [sym_inline_modifier] = STATE(2321),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(11869),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(2266),
    [sym_block_comment] = STATE(2266),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [2267] = {
    [sym_inline_modifier] = STATE(2280),
    [sym_block] = STATE(10212),
    [sym_expression] = STATE(14152),
    [sym__simple_expression] = STATE(7959),
    [sym_lambda_expression] = STATE(12650),
    [sym_if_expression] = STATE(12650),
    [sym_match_expression] = STATE(12650),
    [sym_try_expression] = STATE(12650),
    [sym_bindings] = STATE(15981),
    [sym_case_block] = STATE(10212),
    [sym_assignment_expression] = STATE(12650),
    [sym_generic_function] = STATE(10212),
    [sym_call_expression] = STATE(10212),
    [sym_field_expression] = STATE(10212),
    [sym_instance_expression] = STATE(10212),
    [sym_ascription_expression] = STATE(12650),
    [sym_infix_expression] = STATE(10932),
    [sym_postfix_expression] = STATE(12517),
    [sym__postfix_expression_choice] = STATE(16807),
    [sym_macro_body] = STATE(12650),
    [sym_prefix_expression] = STATE(10614),
    [sym_tuple_expression] = STATE(10212),
    [sym_parenthesized_expression] = STATE(10212),
    [sym_splice_expression] = STATE(10212),
    [sym_quote_expression] = STATE(10212),
    [sym_identifier] = STATE(6382),
    [sym__soft_identifier] = STATE(4512),
    [sym_wildcard] = STATE(9352),
    [sym__non_null_literal] = STATE(10212),
    [sym_boolean_literal] = STATE(10271),
    [sym_interpolated_string_expression] = STATE(10212),
    [sym_string] = STATE(10271),
    [sym_unit] = STATE(10212),
    [sym_return_expression] = STATE(12650),
    [sym_throw_expression] = STATE(12650),
    [sym_while_expression] = STATE(12650),
    [sym_do_while_expression] = STATE(12650),
    [sym_for_expression] = STATE(12650),
    [sym_comment] = STATE(2267),
    [sym_block_comment] = STATE(2267),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2354),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2354),
    [anon_sym_implicit] = ACTIONS(2788),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2354),
    [anon_sym_open] = ACTIONS(2354),
    [anon_sym_transparent] = ACTIONS(2354),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [2268] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14721),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2268),
    [sym_block_comment] = STATE(2268),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2269] = {
    [sym_inline_modifier] = STATE(2343),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(11623),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(2269),
    [sym_block_comment] = STATE(2269),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [2270] = {
    [sym_inline_modifier] = STATE(2322),
    [sym_block] = STATE(6910),
    [sym_expression] = STATE(12475),
    [sym__simple_expression] = STATE(6104),
    [sym_lambda_expression] = STATE(12841),
    [sym_if_expression] = STATE(12841),
    [sym_match_expression] = STATE(12841),
    [sym_try_expression] = STATE(12841),
    [sym_bindings] = STATE(15866),
    [sym_case_block] = STATE(6910),
    [sym_assignment_expression] = STATE(12841),
    [sym_generic_function] = STATE(6910),
    [sym_call_expression] = STATE(6910),
    [sym_field_expression] = STATE(6910),
    [sym_instance_expression] = STATE(6910),
    [sym_ascription_expression] = STATE(12841),
    [sym_infix_expression] = STATE(8319),
    [sym_postfix_expression] = STATE(12374),
    [sym__postfix_expression_choice] = STATE(16265),
    [sym_macro_body] = STATE(12841),
    [sym_prefix_expression] = STATE(9863),
    [sym_tuple_expression] = STATE(6910),
    [sym_parenthesized_expression] = STATE(6910),
    [sym_splice_expression] = STATE(6910),
    [sym_quote_expression] = STATE(6910),
    [sym_identifier] = STATE(5222),
    [sym__soft_identifier] = STATE(4922),
    [sym_wildcard] = STATE(8350),
    [sym__non_null_literal] = STATE(6910),
    [sym_boolean_literal] = STATE(7223),
    [sym_interpolated_string_expression] = STATE(6910),
    [sym_string] = STATE(7223),
    [sym_unit] = STATE(6910),
    [sym_return_expression] = STATE(12841),
    [sym_throw_expression] = STATE(12841),
    [sym_while_expression] = STATE(12841),
    [sym_do_while_expression] = STATE(12841),
    [sym_for_expression] = STATE(12841),
    [sym_comment] = STATE(2270),
    [sym_block_comment] = STATE(2270),
    [sym__alpha_identifier] = ACTIONS(1004),
    [anon_sym_LBRACE] = ACTIONS(1008),
    [anon_sym__] = ACTIONS(1010),
    [anon_sym_PLUS] = ACTIONS(1012),
    [anon_sym_DASH] = ACTIONS(1012),
    [anon_sym_end] = ACTIONS(1014),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2222),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(1016),
    [anon_sym_opaque] = ACTIONS(1014),
    [anon_sym_implicit] = ACTIONS(2226),
    [anon_sym_inline] = ACTIONS(1018),
    [anon_sym_infix] = ACTIONS(1014),
    [anon_sym_open] = ACTIONS(1014),
    [anon_sym_transparent] = ACTIONS(1014),
    [anon_sym_LPAREN] = ACTIONS(1020),
    [anon_sym_macro] = ACTIONS(1162),
    [anon_sym_BANG] = ACTIONS(1012),
    [anon_sym_TILDE] = ACTIONS(1012),
    [anon_sym_DOLLAR] = ACTIONS(1022),
    [anon_sym_SQUOTE] = ACTIONS(1024),
    [sym__backquoted_id] = ACTIONS(1026),
    [sym_operator_identifier] = ACTIONS(2228),
    [sym_integer_literal] = ACTIONS(1030),
    [sym_floating_point_literal] = ACTIONS(1032),
    [anon_sym_true] = ACTIONS(1034),
    [anon_sym_false] = ACTIONS(1034),
    [sym_character_literal] = ACTIONS(1032),
    [sym_null_literal] = ACTIONS(1036),
    [anon_sym_return] = ACTIONS(2230),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(1170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1038),
    [sym__simple_string] = ACTIONS(1038),
  },
  [2271] = {
    [sym_inline_modifier] = STATE(2343),
    [sym_block] = STATE(5465),
    [sym_expression] = STATE(11625),
    [sym__simple_expression] = STATE(4759),
    [sym_lambda_expression] = STATE(11542),
    [sym_if_expression] = STATE(11542),
    [sym_match_expression] = STATE(11542),
    [sym_try_expression] = STATE(11542),
    [sym_bindings] = STATE(16038),
    [sym_case_block] = STATE(5465),
    [sym_assignment_expression] = STATE(11542),
    [sym_generic_function] = STATE(5465),
    [sym_call_expression] = STATE(5465),
    [sym_field_expression] = STATE(5465),
    [sym_instance_expression] = STATE(5465),
    [sym_ascription_expression] = STATE(11542),
    [sym_infix_expression] = STATE(6912),
    [sym_postfix_expression] = STATE(11282),
    [sym__postfix_expression_choice] = STATE(16177),
    [sym_macro_body] = STATE(11542),
    [sym_prefix_expression] = STATE(8256),
    [sym_tuple_expression] = STATE(5465),
    [sym_parenthesized_expression] = STATE(5465),
    [sym_splice_expression] = STATE(5465),
    [sym_quote_expression] = STATE(5465),
    [sym_identifier] = STATE(4489),
    [sym__soft_identifier] = STATE(4530),
    [sym_wildcard] = STATE(6108),
    [sym__non_null_literal] = STATE(5465),
    [sym_boolean_literal] = STATE(5805),
    [sym_interpolated_string_expression] = STATE(5465),
    [sym_string] = STATE(5805),
    [sym_unit] = STATE(5465),
    [sym_return_expression] = STATE(11542),
    [sym_throw_expression] = STATE(11542),
    [sym_while_expression] = STATE(11542),
    [sym_do_while_expression] = STATE(11542),
    [sym_for_expression] = STATE(11542),
    [sym_comment] = STATE(2271),
    [sym_block_comment] = STATE(2271),
    [sym__alpha_identifier] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(892),
    [anon_sym__] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(900),
    [anon_sym_DASH] = ACTIONS(900),
    [anon_sym_end] = ACTIONS(902),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(1172),
    [anon_sym_for] = ACTIONS(1174),
    [anon_sym_try] = ACTIONS(1176),
    [anon_sym_new] = ACTIONS(906),
    [anon_sym_opaque] = ACTIONS(902),
    [anon_sym_implicit] = ACTIONS(1178),
    [anon_sym_inline] = ACTIONS(910),
    [anon_sym_infix] = ACTIONS(902),
    [anon_sym_open] = ACTIONS(902),
    [anon_sym_transparent] = ACTIONS(902),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(1180),
    [anon_sym_BANG] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(900),
    [anon_sym_DOLLAR] = ACTIONS(914),
    [anon_sym_SQUOTE] = ACTIONS(916),
    [sym__backquoted_id] = ACTIONS(918),
    [sym_operator_identifier] = ACTIONS(1182),
    [sym_integer_literal] = ACTIONS(922),
    [sym_floating_point_literal] = ACTIONS(924),
    [anon_sym_true] = ACTIONS(926),
    [anon_sym_false] = ACTIONS(926),
    [sym_character_literal] = ACTIONS(924),
    [sym_null_literal] = ACTIONS(928),
    [anon_sym_return] = ACTIONS(1184),
    [anon_sym_throw] = ACTIONS(1186),
    [anon_sym_do] = ACTIONS(1188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(930),
    [sym__simple_string] = ACTIONS(930),
  },
  [2272] = {
    [sym_inline_modifier] = STATE(2298),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(13035),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(2272),
    [sym_block_comment] = STATE(2272),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(2066),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [2273] = {
    [sym_inline_modifier] = STATE(2298),
    [sym_block] = STATE(8380),
    [sym_expression] = STATE(13114),
    [sym__simple_expression] = STATE(6338),
    [sym_lambda_expression] = STATE(13614),
    [sym_if_expression] = STATE(13614),
    [sym_match_expression] = STATE(13614),
    [sym_try_expression] = STATE(13614),
    [sym_bindings] = STATE(16020),
    [sym_case_block] = STATE(8380),
    [sym_assignment_expression] = STATE(13614),
    [sym_generic_function] = STATE(8380),
    [sym_call_expression] = STATE(8380),
    [sym_field_expression] = STATE(8380),
    [sym_instance_expression] = STATE(8380),
    [sym_ascription_expression] = STATE(13614),
    [sym_infix_expression] = STATE(9548),
    [sym_postfix_expression] = STATE(13079),
    [sym__postfix_expression_choice] = STATE(17409),
    [sym_macro_body] = STATE(13614),
    [sym_prefix_expression] = STATE(9832),
    [sym_tuple_expression] = STATE(8380),
    [sym_parenthesized_expression] = STATE(8380),
    [sym_splice_expression] = STATE(8380),
    [sym_quote_expression] = STATE(8380),
    [sym_identifier] = STATE(5272),
    [sym__soft_identifier] = STATE(5569),
    [sym_wildcard] = STATE(8271),
    [sym__non_null_literal] = STATE(8380),
    [sym_boolean_literal] = STATE(8445),
    [sym_interpolated_string_expression] = STATE(8380),
    [sym_string] = STATE(8445),
    [sym_unit] = STATE(8380),
    [sym_return_expression] = STATE(13614),
    [sym_throw_expression] = STATE(13614),
    [sym_while_expression] = STATE(13614),
    [sym_do_while_expression] = STATE(13614),
    [sym_for_expression] = STATE(13614),
    [sym_comment] = STATE(2273),
    [sym_block_comment] = STATE(2273),
    [sym__alpha_identifier] = ACTIONS(1370),
    [anon_sym_LBRACE] = ACTIONS(1374),
    [anon_sym__] = ACTIONS(1376),
    [anon_sym_PLUS] = ACTIONS(1378),
    [anon_sym_DASH] = ACTIONS(1378),
    [anon_sym_end] = ACTIONS(1380),
    [anon_sym_if] = ACTIONS(2054),
    [anon_sym_while] = ACTIONS(2056),
    [anon_sym_for] = ACTIONS(2058),
    [anon_sym_try] = ACTIONS(2060),
    [anon_sym_new] = ACTIONS(1382),
    [anon_sym_opaque] = ACTIONS(1380),
    [anon_sym_implicit] = ACTIONS(2062),
    [anon_sym_inline] = ACTIONS(1384),
    [anon_sym_infix] = ACTIONS(1380),
    [anon_sym_open] = ACTIONS(1380),
    [anon_sym_transparent] = ACTIONS(1380),
    [anon_sym_LPAREN] = ACTIONS(1386),
    [anon_sym_macro] = ACTIONS(2064),
    [anon_sym_BANG] = ACTIONS(1378),
    [anon_sym_TILDE] = ACTIONS(1378),
    [anon_sym_DOLLAR] = ACTIONS(1388),
    [anon_sym_SQUOTE] = ACTIONS(1390),
    [sym__backquoted_id] = ACTIONS(1392),
    [sym_operator_identifier] = ACTIONS(2066),
    [sym_integer_literal] = ACTIONS(1396),
    [sym_floating_point_literal] = ACTIONS(1398),
    [anon_sym_true] = ACTIONS(1400),
    [anon_sym_false] = ACTIONS(1400),
    [sym_character_literal] = ACTIONS(1398),
    [sym_null_literal] = ACTIONS(1402),
    [anon_sym_return] = ACTIONS(2068),
    [anon_sym_throw] = ACTIONS(2070),
    [anon_sym_do] = ACTIONS(2072),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1404),
    [sym__simple_string] = ACTIONS(1404),
  },
  [2274] = {
    [sym_inline_modifier] = STATE(2325),
    [sym_block] = STATE(7476),
    [sym_expression] = STATE(12640),
    [sym__simple_expression] = STATE(5345),
    [sym_lambda_expression] = STATE(13104),
    [sym_if_expression] = STATE(13104),
    [sym_match_expression] = STATE(13104),
    [sym_try_expression] = STATE(13104),
    [sym_bindings] = STATE(15935),
    [sym_case_block] = STATE(7476),
    [sym_assignment_expression] = STATE(13104),
    [sym_generic_function] = STATE(7476),
    [sym_call_expression] = STATE(7476),
    [sym_field_expression] = STATE(7476),
    [sym_instance_expression] = STATE(7476),
    [sym_ascription_expression] = STATE(13104),
    [sym_infix_expression] = STATE(8955),
    [sym_postfix_expression] = STATE(12956),
    [sym__postfix_expression_choice] = STATE(16529),
    [sym_macro_body] = STATE(13104),
    [sym_prefix_expression] = STATE(8956),
    [sym_tuple_expression] = STATE(7476),
    [sym_parenthesized_expression] = STATE(7476),
    [sym_splice_expression] = STATE(7476),
    [sym_quote_expression] = STATE(7476),
    [sym_identifier] = STATE(4735),
    [sym__soft_identifier] = STATE(5173),
    [sym_wildcard] = STATE(7275),
    [sym__non_null_literal] = STATE(7476),
    [sym_boolean_literal] = STATE(7452),
    [sym_interpolated_string_expression] = STATE(7476),
    [sym_string] = STATE(7452),
    [sym_unit] = STATE(7476),
    [sym_return_expression] = STATE(13104),
    [sym_throw_expression] = STATE(13104),
    [sym_while_expression] = STATE(13104),
    [sym_do_while_expression] = STATE(13104),
    [sym_for_expression] = STATE(13104),
    [sym_comment] = STATE(2274),
    [sym_block_comment] = STATE(2274),
    [sym__alpha_identifier] = ACTIONS(1112),
    [anon_sym_LBRACE] = ACTIONS(1116),
    [anon_sym__] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1120),
    [anon_sym_DASH] = ACTIONS(1120),
    [anon_sym_end] = ACTIONS(1122),
    [anon_sym_if] = ACTIONS(1314),
    [anon_sym_while] = ACTIONS(1316),
    [anon_sym_for] = ACTIONS(1318),
    [anon_sym_try] = ACTIONS(1320),
    [anon_sym_new] = ACTIONS(1124),
    [anon_sym_opaque] = ACTIONS(1122),
    [anon_sym_implicit] = ACTIONS(1322),
    [anon_sym_inline] = ACTIONS(1126),
    [anon_sym_infix] = ACTIONS(1122),
    [anon_sym_open] = ACTIONS(1122),
    [anon_sym_transparent] = ACTIONS(1122),
    [anon_sym_LPAREN] = ACTIONS(1128),
    [anon_sym_macro] = ACTIONS(1324),
    [anon_sym_BANG] = ACTIONS(1120),
    [anon_sym_TILDE] = ACTIONS(1120),
    [anon_sym_DOLLAR] = ACTIONS(1130),
    [anon_sym_SQUOTE] = ACTIONS(1132),
    [sym__backquoted_id] = ACTIONS(1134),
    [sym_operator_identifier] = ACTIONS(1326),
    [sym_integer_literal] = ACTIONS(1138),
    [sym_floating_point_literal] = ACTIONS(1140),
    [anon_sym_true] = ACTIONS(1142),
    [anon_sym_false] = ACTIONS(1142),
    [sym_character_literal] = ACTIONS(1140),
    [sym_null_literal] = ACTIONS(1144),
    [anon_sym_return] = ACTIONS(1328),
    [anon_sym_throw] = ACTIONS(1330),
    [anon_sym_do] = ACTIONS(1332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1146),
    [sym__simple_string] = ACTIONS(1146),
  },
  [2275] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14507),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2275),
    [sym_block_comment] = STATE(2275),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2276] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14990),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2276),
    [sym_block_comment] = STATE(2276),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4032),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2277] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14588),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2277),
    [sym_block_comment] = STATE(2277),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2278] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15043),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2278),
    [sym_block_comment] = STATE(2278),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4034),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2279] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14609),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2279),
    [sym_block_comment] = STATE(2279),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2280] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15426),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2280),
    [sym_block_comment] = STATE(2280),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(842),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2281] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14653),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2281),
    [sym_block_comment] = STATE(2281),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2282] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14990),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2282),
    [sym_block_comment] = STATE(2282),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4036),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2283] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14684),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2283),
    [sym_block_comment] = STATE(2283),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2284] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15043),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2284),
    [sym_block_comment] = STATE(2284),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4038),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2285] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14705),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2285),
    [sym_block_comment] = STATE(2285),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2286] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15426),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2286),
    [sym_block_comment] = STATE(2286),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(884),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2287] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14720),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2287),
    [sym_block_comment] = STATE(2287),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2288] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15072),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2288),
    [sym_block_comment] = STATE(2288),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4040),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2289] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14474),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2289),
    [sym_block_comment] = STATE(2289),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2290] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15116),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2290),
    [sym_block_comment] = STATE(2290),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4042),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2291] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14485),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2291),
    [sym_block_comment] = STATE(2291),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2292] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15072),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2292),
    [sym_block_comment] = STATE(2292),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4044),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2293] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14606),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2293),
    [sym_block_comment] = STATE(2293),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2294] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15072),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2294),
    [sym_block_comment] = STATE(2294),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4046),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2295] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14425),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2295),
    [sym_block_comment] = STATE(2295),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2296] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15116),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2296),
    [sym_block_comment] = STATE(2296),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4048),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2297] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14477),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2297),
    [sym_block_comment] = STATE(2297),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2298] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15130),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2298),
    [sym_block_comment] = STATE(2298),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4050),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2299] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14522),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2299),
    [sym_block_comment] = STATE(2299),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2300] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15144),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2300),
    [sym_block_comment] = STATE(2300),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4052),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2301] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14547),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2301),
    [sym_block_comment] = STATE(2301),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2302] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15098),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2302),
    [sym_block_comment] = STATE(2302),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(886),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2303] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14586),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2303),
    [sym_block_comment] = STATE(2303),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2304] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15159),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2304),
    [sym_block_comment] = STATE(2304),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4054),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2305] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14646),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2305),
    [sym_block_comment] = STATE(2305),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2306] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15130),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2306),
    [sym_block_comment] = STATE(2306),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4056),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2307] = {
    [sym_inline_modifier] = STATE(2282),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(14700),
    [sym__simple_expression] = STATE(9005),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(16055),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(11087),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(7660),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(10206),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2307),
    [sym_block_comment] = STATE(2307),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(2867),
    [anon_sym_while] = ACTIONS(2869),
    [anon_sym_for] = ACTIONS(2871),
    [anon_sym_try] = ACTIONS(2873),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(2875),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(3294),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(2880),
    [anon_sym_throw] = ACTIONS(2882),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2308] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15426),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2308),
    [sym_block_comment] = STATE(2308),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4058),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2309] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15168),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2309),
    [sym_block_comment] = STATE(2309),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4060),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2310] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15130),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2310),
    [sym_block_comment] = STATE(2310),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4062),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2311] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15426),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2311),
    [sym_block_comment] = STATE(2311),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(880),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2312] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15159),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2312),
    [sym_block_comment] = STATE(2312),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4064),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2313] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15168),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2313),
    [sym_block_comment] = STATE(2313),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4066),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2314] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15179),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2314),
    [sym_block_comment] = STATE(2314),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4068),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2315] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15190),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2315),
    [sym_block_comment] = STATE(2315),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4070),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2316] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15202),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2316),
    [sym_block_comment] = STATE(2316),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4072),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2317] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15179),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2317),
    [sym_block_comment] = STATE(2317),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4074),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2318] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15190),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2318),
    [sym_block_comment] = STATE(2318),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4076),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2319] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15098),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2319),
    [sym_block_comment] = STATE(2319),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4078),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2320] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15426),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2320),
    [sym_block_comment] = STATE(2320),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4080),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2321] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15043),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2321),
    [sym_block_comment] = STATE(2321),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4082),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2322] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15179),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2322),
    [sym_block_comment] = STATE(2322),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4084),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2323] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15190),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2323),
    [sym_block_comment] = STATE(2323),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4086),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2324] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15098),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2324),
    [sym_block_comment] = STATE(2324),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(882),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2325] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15216),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2325),
    [sym_block_comment] = STATE(2325),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4088),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2326] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15227),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2326),
    [sym_block_comment] = STATE(2326),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4090),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2327] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15241),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2327),
    [sym_block_comment] = STATE(2327),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4092),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2328] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15144),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2328),
    [sym_block_comment] = STATE(2328),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4094),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2329] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15043),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2329),
    [sym_block_comment] = STATE(2329),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4096),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2330] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15116),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2330),
    [sym_block_comment] = STATE(2330),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4098),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2331] = {
    [sym_inline_modifier] = STATE(2321),
    [sym_block] = STATE(6602),
    [sym_expression] = STATE(11862),
    [sym__simple_expression] = STATE(5205),
    [sym_lambda_expression] = STATE(11905),
    [sym_if_expression] = STATE(11905),
    [sym_match_expression] = STATE(11905),
    [sym_try_expression] = STATE(11905),
    [sym_bindings] = STATE(16091),
    [sym_case_block] = STATE(6602),
    [sym_assignment_expression] = STATE(11905),
    [sym_generic_function] = STATE(6602),
    [sym_call_expression] = STATE(6602),
    [sym_field_expression] = STATE(6602),
    [sym_instance_expression] = STATE(6602),
    [sym_ascription_expression] = STATE(11905),
    [sym_infix_expression] = STATE(8020),
    [sym_postfix_expression] = STATE(11634),
    [sym__postfix_expression_choice] = STATE(16861),
    [sym_macro_body] = STATE(11905),
    [sym_prefix_expression] = STATE(8899),
    [sym_tuple_expression] = STATE(6602),
    [sym_parenthesized_expression] = STATE(6602),
    [sym_splice_expression] = STATE(6602),
    [sym_quote_expression] = STATE(6602),
    [sym_identifier] = STATE(4699),
    [sym__soft_identifier] = STATE(4633),
    [sym_wildcard] = STATE(7349),
    [sym__non_null_literal] = STATE(6602),
    [sym_boolean_literal] = STATE(6215),
    [sym_interpolated_string_expression] = STATE(6602),
    [sym_string] = STATE(6215),
    [sym_unit] = STATE(6602),
    [sym_return_expression] = STATE(11905),
    [sym_throw_expression] = STATE(11905),
    [sym_while_expression] = STATE(11905),
    [sym_do_while_expression] = STATE(11905),
    [sym_for_expression] = STATE(11905),
    [sym_comment] = STATE(2331),
    [sym_block_comment] = STATE(2331),
    [sym__alpha_identifier] = ACTIONS(932),
    [anon_sym_LBRACE] = ACTIONS(936),
    [anon_sym__] = ACTIONS(938),
    [anon_sym_PLUS] = ACTIONS(940),
    [anon_sym_DASH] = ACTIONS(940),
    [anon_sym_end] = ACTIONS(942),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(1896),
    [anon_sym_for] = ACTIONS(1898),
    [anon_sym_try] = ACTIONS(1900),
    [anon_sym_new] = ACTIONS(944),
    [anon_sym_opaque] = ACTIONS(942),
    [anon_sym_implicit] = ACTIONS(1902),
    [anon_sym_inline] = ACTIONS(946),
    [anon_sym_infix] = ACTIONS(942),
    [anon_sym_open] = ACTIONS(942),
    [anon_sym_transparent] = ACTIONS(942),
    [anon_sym_LPAREN] = ACTIONS(948),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(940),
    [anon_sym_TILDE] = ACTIONS(940),
    [anon_sym_DOLLAR] = ACTIONS(950),
    [anon_sym_SQUOTE] = ACTIONS(952),
    [sym__backquoted_id] = ACTIONS(954),
    [sym_operator_identifier] = ACTIONS(1904),
    [sym_integer_literal] = ACTIONS(958),
    [sym_floating_point_literal] = ACTIONS(960),
    [anon_sym_true] = ACTIONS(962),
    [anon_sym_false] = ACTIONS(962),
    [sym_character_literal] = ACTIONS(960),
    [sym_null_literal] = ACTIONS(964),
    [anon_sym_return] = ACTIONS(1906),
    [anon_sym_throw] = ACTIONS(1908),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(966),
    [sym__simple_string] = ACTIONS(966),
  },
  [2332] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15241),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2332),
    [sym_block_comment] = STATE(2332),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4100),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2333] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15249),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2333),
    [sym_block_comment] = STATE(2333),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2334] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15249),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2334),
    [sym_block_comment] = STATE(2334),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4104),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2335] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15202),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2335),
    [sym_block_comment] = STATE(2335),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4106),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2336] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15116),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2336),
    [sym_block_comment] = STATE(2336),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4108),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2337] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15159),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2337),
    [sym_block_comment] = STATE(2337),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4110),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2338] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15168),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2338),
    [sym_block_comment] = STATE(2338),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4112),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2339] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15249),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2339),
    [sym_block_comment] = STATE(2339),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4114),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2340] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15260),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2340),
    [sym_block_comment] = STATE(2340),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4116),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2341] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15216),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2341),
    [sym_block_comment] = STATE(2341),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4118),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2342] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15227),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2342),
    [sym_block_comment] = STATE(2342),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4120),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2343] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15159),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2343),
    [sym_block_comment] = STATE(2343),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4122),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2344] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15168),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2344),
    [sym_block_comment] = STATE(2344),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4124),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2345] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15241),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2345),
    [sym_block_comment] = STATE(2345),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4126),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2346] = {
    [sym_inline_modifier] = STATE(2093),
    [sym_block] = STATE(9331),
    [sym_expression] = STATE(15260),
    [sym__simple_expression] = STATE(7538),
    [sym_lambda_expression] = STATE(13990),
    [sym_if_expression] = STATE(13990),
    [sym_match_expression] = STATE(13990),
    [sym_try_expression] = STATE(13990),
    [sym_bindings] = STATE(15959),
    [sym_case_block] = STATE(9331),
    [sym_assignment_expression] = STATE(13990),
    [sym_generic_function] = STATE(9331),
    [sym_call_expression] = STATE(9331),
    [sym_field_expression] = STATE(9331),
    [sym_instance_expression] = STATE(9331),
    [sym_ascription_expression] = STATE(13990),
    [sym_infix_expression] = STATE(10416),
    [sym_postfix_expression] = STATE(13566),
    [sym__postfix_expression_choice] = STATE(16477),
    [sym_macro_body] = STATE(13990),
    [sym_prefix_expression] = STATE(10586),
    [sym_tuple_expression] = STATE(9331),
    [sym_parenthesized_expression] = STATE(9331),
    [sym_splice_expression] = STATE(9331),
    [sym_quote_expression] = STATE(9331),
    [sym_identifier] = STATE(5339),
    [sym__soft_identifier] = STATE(5706),
    [sym_wildcard] = STATE(8097),
    [sym__non_null_literal] = STATE(9331),
    [sym_boolean_literal] = STATE(8137),
    [sym_interpolated_string_expression] = STATE(9331),
    [sym_string] = STATE(8137),
    [sym_unit] = STATE(9331),
    [sym_return_expression] = STATE(13990),
    [sym_throw_expression] = STATE(13990),
    [sym_while_expression] = STATE(13990),
    [sym_do_while_expression] = STATE(13990),
    [sym_for_expression] = STATE(13990),
    [sym_comment] = STATE(2346),
    [sym_block_comment] = STATE(2346),
    [sym__alpha_identifier] = ACTIONS(830),
    [anon_sym_LBRACE] = ACTIONS(832),
    [anon_sym__] = ACTIONS(836),
    [anon_sym_PLUS] = ACTIONS(838),
    [anon_sym_DASH] = ACTIONS(838),
    [anon_sym_end] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(4128),
    [anon_sym_while] = ACTIONS(844),
    [anon_sym_for] = ACTIONS(846),
    [anon_sym_try] = ACTIONS(848),
    [anon_sym_new] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(840),
    [anon_sym_implicit] = ACTIONS(908),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym_infix] = ACTIONS(840),
    [anon_sym_open] = ACTIONS(840),
    [anon_sym_transparent] = ACTIONS(840),
    [anon_sym_LPAREN] = ACTIONS(852),
    [anon_sym_macro] = ACTIONS(854),
    [anon_sym_BANG] = ACTIONS(838),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(856),
    [anon_sym_SQUOTE] = ACTIONS(858),
    [sym__backquoted_id] = ACTIONS(860),
    [sym_operator_identifier] = ACTIONS(862),
    [sym_integer_literal] = ACTIONS(864),
    [sym_floating_point_literal] = ACTIONS(866),
    [anon_sym_true] = ACTIONS(868),
    [anon_sym_false] = ACTIONS(868),
    [sym_character_literal] = ACTIONS(866),
    [sym_null_literal] = ACTIONS(870),
    [anon_sym_return] = ACTIONS(872),
    [anon_sym_throw] = ACTIONS(874),
    [anon_sym_do] = ACTIONS(876),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(878),
    [sym__simple_string] = ACTIONS(878),
  },
  [2347] = {
    [sym_inline_modifier] = STATE(2324),
    [sym_block] = STATE(9416),
    [sym_expression] = STATE(13774),
    [sym__simple_expression] = STATE(7356),
    [sym_lambda_expression] = STATE(13871),
    [sym_if_expression] = STATE(13871),
    [sym_match_expression] = STATE(13871),
    [sym_try_expression] = STATE(13871),
    [sym_bindings] = STATE(16096),
    [sym_case_block] = STATE(9416),
    [sym_assignment_expression] = STATE(13871),
    [sym_generic_function] = STATE(9416),
    [sym_call_expression] = STATE(9416),
    [sym_field_expression] = STATE(9416),
    [sym_instance_expression] = STATE(9416),
    [sym_ascription_expression] = STATE(13871),
    [sym_infix_expression] = STATE(10516),
    [sym_postfix_expression] = STATE(13732),
    [sym__postfix_expression_choice] = STATE(17058),
    [sym_macro_body] = STATE(13871),
    [sym_prefix_expression] = STATE(10433),
    [sym_tuple_expression] = STATE(9416),
    [sym_parenthesized_expression] = STATE(9416),
    [sym_splice_expression] = STATE(9416),
    [sym_quote_expression] = STATE(9416),
    [sym_identifier] = STATE(5556),
    [sym__soft_identifier] = STATE(5776),
    [sym_wildcard] = STATE(8903),
    [sym__non_null_literal] = STATE(9416),
    [sym_boolean_literal] = STATE(9490),
    [sym_interpolated_string_expression] = STATE(9416),
    [sym_string] = STATE(9490),
    [sym_unit] = STATE(9416),
    [sym_return_expression] = STATE(13871),
    [sym_throw_expression] = STATE(13871),
    [sym_while_expression] = STATE(13871),
    [sym_do_while_expression] = STATE(13871),
    [sym_for_expression] = STATE(13871),
    [sym_comment] = STATE(2347),
    [sym_block_comment] = STATE(2347),
    [sym__alpha_identifier] = ACTIONS(473),
    [anon_sym_LBRACE] = ACTIONS(477),
    [anon_sym__] = ACTIONS(487),
    [anon_sym_PLUS] = ACTIONS(613),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_end] = ACTIONS(659),
    [anon_sym_if] = ACTIONS(615),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(619),
    [anon_sym_try] = ACTIONS(621),
    [anon_sym_new] = ACTIONS(507),
    [anon_sym_opaque] = ACTIONS(659),
    [anon_sym_implicit] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(1842),
    [anon_sym_infix] = ACTIONS(659),
    [anon_sym_open] = ACTIONS(659),
    [anon_sym_transparent] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(527),
    [anon_sym_macro] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_TILDE] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(535),
    [sym__backquoted_id] = ACTIONS(537),
    [sym_operator_identifier] = ACTIONS(631),
    [sym_integer_literal] = ACTIONS(541),
    [sym_floating_point_literal] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(545),
    [anon_sym_false] = ACTIONS(545),
    [sym_character_literal] = ACTIONS(543),
    [sym_null_literal] = ACTIONS(547),
    [anon_sym_return] = ACTIONS(633),
    [anon_sym_throw] = ACTIONS(635),
    [anon_sym_do] = ACTIONS(553),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(555),
    [sym__simple_string] = ACTIONS(555),
  },
  [2348] = {
    [sym_comment] = STATE(2348),
    [sym_block_comment] = STATE(2348),
    [sym__alpha_identifier] = ACTIONS(4130),
    [anon_sym_COLON] = ACTIONS(4132),
    [anon_sym_LBRACE] = ACTIONS(4134),
    [anon_sym_RBRACE] = ACTIONS(4136),
    [anon_sym_case] = ACTIONS(4130),
    [anon_sym_DOT] = ACTIONS(4132),
    [anon_sym_object] = ACTIONS(4130),
    [anon_sym__] = ACTIONS(4130),
    [anon_sym_given] = ACTIONS(4130),
    [anon_sym_EQ_GT] = ACTIONS(4132),
    [anon_sym_class] = ACTIONS(4130),
    [anon_sym_trait] = ACTIONS(4130),
    [anon_sym_LBRACK] = ACTIONS(4136),
    [anon_sym_PLUS] = ACTIONS(4130),
    [anon_sym_DASH] = ACTIONS(4130),
    [anon_sym_end] = ACTIONS(4130),
    [anon_sym_if] = ACTIONS(4130),
    [anon_sym_while] = ACTIONS(4130),
    [anon_sym_for] = ACTIONS(4130),
    [anon_sym_match] = ACTIONS(4132),
    [anon_sym_try] = ACTIONS(4130),
    [anon_sym_new] = ACTIONS(4130),
    [anon_sym_val] = ACTIONS(4130),
    [anon_sym_EQ] = ACTIONS(4132),
    [anon_sym_var] = ACTIONS(4130),
    [anon_sym_type] = ACTIONS(4130),
    [anon_sym_def] = ACTIONS(4130),
    [anon_sym_opaque] = ACTIONS(4130),
    [anon_sym_abstract] = ACTIONS(4130),
    [anon_sym_final] = ACTIONS(4130),
    [anon_sym_sealed] = ACTIONS(4130),
    [anon_sym_implicit] = ACTIONS(4130),
    [anon_sym_lazy] = ACTIONS(4130),
    [anon_sym_override] = ACTIONS(4130),
    [anon_sym_private] = ACTIONS(4130),
    [anon_sym_protected] = ACTIONS(4130),
    [anon_sym_inline] = ACTIONS(4130),
    [anon_sym_infix] = ACTIONS(4130),
    [anon_sym_open] = ACTIONS(4130),
    [anon_sym_transparent] = ACTIONS(4130),
    [anon_sym_LPAREN] = ACTIONS(4134),
    [anon_sym_RPAREN] = ACTIONS(4136),
    [anon_sym_SEMI] = ACTIONS(4136),
    [anon_sym_QMARK_EQ_GT] = ACTIONS(4132),
    [anon_sym_macro] = ACTIONS(4130),
    [anon_sym_BANG] = ACTIONS(4130),
    [anon_sym_TILDE] = ACTIONS(4130),
    [anon_sym_DOLLAR] = ACTIONS(4130),
    [anon_sym_SQUOTE] = ACTIONS(4130),
    [sym__backquoted_id] = ACTIONS(4134),
    [sym_operator_identifier] = ACTIONS(4130),
    [sym_integer_literal] = ACTIONS(4130),
    [sym_floating_point_literal] = ACTIONS(4134),
    [anon_sym_true] = ACTIONS(4130),
    [anon_sym_false] = ACTIONS(4130),
    [sym_character_literal] = ACTIONS(4134),
    [anon_sym_DQUOTE] = ACTIONS(4132),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(4136),
    [sym_null_literal] = ACTIONS(4130),
    [anon_sym_return] = ACTIONS(4130),
    [anon_sym_throw] = ACTIONS(4130),
    [anon_sym_do] = ACTIONS(4130),
    [anon_sym_yield] = ACTIONS(4132),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(4136),
    [sym__simple_multiline_string] = ACTIONS(4134),
    [sym__simple_string] = ACTIONS(4134),
  },
  [2349] = {
    [sym_comment] = STATE(2349),
    [sym_block_comment] = STATE(2349),
    [sym__alpha_identifier] = ACTIONS(4130),
    [anon_sym_COLON] = ACTIONS(4132),
    [anon_sym_LBRACE] = ACTIONS(4134),
    [anon_sym_case] = ACTIONS(4130),
    [anon_sym_DOT] = ACTIONS(4132),
    [anon_sym_object] = ACTIONS(4130),
    [anon_sym__] = ACTIONS(4130),
    [anon_sym_given] = ACTIONS(4130),
    [anon_sym_EQ_GT] = ACTIONS(4132),
    [anon_sym_class] = ACTIONS(4130),
    [anon_sym_trait] = ACTIONS(4130),
    [anon_sym_LBRACK] = ACTIONS(4136),
    [anon_sym_PLUS] = ACTIONS(4130),
    [anon_sym_DASH] = ACTIONS(4130),
    [anon_sym_end] = ACTIONS(4130),
    [anon_sym_if] = ACTIONS(4130),
    [anon_sym_while] = ACTIONS(4130),
    [anon_sym_for] = ACTIONS(4130),
    [anon_sym_match] = ACTIONS(4132),
    [anon_sym_try] = ACTIONS(4130),
    [anon_sym_new] = ACTIONS(4130),
    [anon_sym_val] = ACTIONS(4130),
    [anon_sym_EQ] = ACTIONS(4132),
    [anon_sym_var] = ACTIONS(4130),
    [anon_sym_type] = ACTIONS(4130),
    [anon_sym_def] = ACTIONS(4130),
    [anon_sym_opaque] = ACTIONS(4130),
    [anon_sym_abstract] = ACTIONS(4130),
    [anon_sym_final] = ACTIONS(4130),
    [anon_sym_sealed] = ACTIONS(4130),
    [anon_sym_implicit] = ACTIONS(4130),
    [anon_sym_lazy] = ACTIONS(4130),
    [anon_sym_override] = ACTIONS(4130),
    [anon_sym_private] = ACTIONS(4130),
    [anon_sym_protected] = ACTIONS(4130),
    [anon_sym_inline] = ACTIONS(4130),
    [anon_sym_infix] = ACTIONS(4130),
    [anon_sym_open] = ACTIONS(4130),
    [anon_sym_transparent] = ACTIONS(4130),
    [anon_sym_LPAREN] = ACTIONS(4134),
    [anon_sym_SEMI] = ACTIONS(4136),
    [anon_sym_QMARK_EQ_GT] = ACTIONS(4132),
    [anon_sym_macro] = ACTIONS(4130),
    [anon_sym_BANG] = ACTIONS(4130),
    [anon_sym_TILDE] = ACTIONS(4130),
    [anon_sym_DOLLAR] = ACTIONS(4130),
    [anon_sym_SQUOTE] = ACTIONS(4130),
    [sym__backquoted_id] = ACTIONS(4134),
    [sym_operator_identifier] = ACTIONS(4130),
    [sym_integer_literal] = ACTIONS(4130),
    [sym_floating_point_literal] = ACTIONS(4134),
    [anon_sym_true] = ACTIONS(4130),
    [anon_sym_false] = ACTIONS(4130),
    [sym_character_literal] = ACTIONS(4134),
    [anon_sym_DQUOTE] = ACTIONS(4132),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(4136),
    [sym_null_literal] = ACTIONS(4130),
    [anon_sym_return] = ACTIONS(4130),
    [anon_sym_throw] = ACTIONS(4130),
    [anon_sym_do] = ACTIONS(4130),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(4136),
    [sym__outdent] = ACTIONS(4136),
    [sym__simple_multiline_string] = ACTIONS(4134),
    [sym__simple_string] = ACTIONS(4134),
  },
  [2350] = {
    [sym_comment] = STATE(2350),
    [sym_block_comment] = STATE(2350),
    [ts_builtin_sym_end] = ACTIONS(4136),
    [sym__alpha_identifier] = ACTIONS(4130),
    [anon_sym_COLON] = ACTIONS(4132),
    [anon_sym_LBRACE] = ACTIONS(4134),
    [anon_sym_case] = ACTIONS(4130),
    [anon_sym_DOT] = ACTIONS(4132),
    [anon_sym_object] = ACTIONS(4130),
    [anon_sym__] = ACTIONS(4130),
    [anon_sym_given] = ACTIONS(4130),
    [anon_sym_EQ_GT] = ACTIONS(4132),
    [anon_sym_class] = ACTIONS(4130),
    [anon_sym_trait] = ACTIONS(4130),
    [anon_sym_LBRACK] = ACTIONS(4136),
    [anon_sym_PLUS] = ACTIONS(4130),
    [anon_sym_DASH] = ACTIONS(4130),
    [anon_sym_end] = ACTIONS(4130),
    [anon_sym_if] = ACTIONS(4130),
    [anon_sym_while] = ACTIONS(4130),
    [anon_sym_for] = ACTIONS(4130),
    [anon_sym_match] = ACTIONS(4132),
    [anon_sym_try] = ACTIONS(4130),
    [anon_sym_new] = ACTIONS(4130),
    [anon_sym_val] = ACTIONS(4130),
    [anon_sym_EQ] = ACTIONS(4132),
    [anon_sym_var] = ACTIONS(4130),
    [anon_sym_type] = ACTIONS(4130),
    [anon_sym_def] = ACTIONS(4130),
    [anon_sym_opaque] = ACTIONS(4130),
    [anon_sym_abstract] = ACTIONS(4130),
    [anon_sym_final] = ACTIONS(4130),
    [anon_sym_sealed] = ACTIONS(4130),
    [anon_sym_implicit] = ACTIONS(4130),
    [anon_sym_lazy] = ACTIONS(4130),
    [anon_sym_override] = ACTIONS(4130),
    [anon_sym_private] = ACTIONS(4130),
    [anon_sym_protected] = ACTIONS(4130),
    [anon_sym_inline] = ACTIONS(4130),
    [anon_sym_infix] = ACTIONS(4130),
    [anon_sym_open] = ACTIONS(4130),
    [anon_sym_transparent] = ACTIONS(4130),
    [anon_sym_LPAREN] = ACTIONS(4134),
    [anon_sym_SEMI] = ACTIONS(4136),
    [anon_sym_QMARK_EQ_GT] = ACTIONS(4132),
    [anon_sym_macro] = ACTIONS(4130),
    [anon_sym_BANG] = ACTIONS(4130),
    [anon_sym_TILDE] = ACTIONS(4130),
    [anon_sym_DOLLAR] = ACTIONS(4130),
    [anon_sym_SQUOTE] = ACTIONS(4130),
    [sym__backquoted_id] = ACTIONS(4134),
    [sym_operator_identifier] = ACTIONS(4130),
    [sym_integer_literal] = ACTIONS(4130),
    [sym_floating_point_literal] = ACTIONS(4134),
    [anon_sym_true] = ACTIONS(4130),
    [anon_sym_false] = ACTIONS(4130),
    [sym_character_literal] = ACTIONS(4134),
    [anon_sym_DQUOTE] = ACTIONS(4132),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(4136),
    [sym_null_literal] = ACTIONS(4130),
    [anon_sym_return] = ACTIONS(4130),
    [anon_sym_throw] = ACTIONS(4130),
    [anon_sym_do] = ACTIONS(4130),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(4136),
    [sym__simple_multiline_string] = ACTIONS(4134),
    [sym__simple_string] = ACTIONS(4134),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4138), 1,
      sym__alpha_identifier,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(4144), 1,
      anon_sym__,
    ACTIONS(4146), 1,
      anon_sym_EQ_GT,
    ACTIONS(4148), 1,
      anon_sym_LBRACK,
    ACTIONS(4152), 1,
      anon_sym_AT,
    ACTIONS(4154), 1,
      anon_sym_LPAREN,
    ACTIONS(4156), 1,
      sym__backquoted_id,
    ACTIONS(4158), 1,
      sym_operator_identifier,
    ACTIONS(4160), 1,
      sym_integer_literal,
    ACTIONS(4166), 1,
      sym__indent,
    STATE(5771), 1,
      sym__simple_type,
    STATE(5791), 1,
      sym__annotated_type,
    STATE(6041), 1,
      sym__soft_identifier,
    STATE(6850), 1,
      sym_identifier,
    STATE(7910), 1,
      sym_wildcard,
    STATE(9212), 1,
      sym_annotated_type,
    STATE(9535), 1,
      sym_colon_argument,
    STATE(10773), 1,
      sym_literal_type,
    STATE(10898), 1,
      sym__non_null_literal,
    STATE(12156), 1,
      sym_template_body,
    STATE(12437), 1,
      sym__infix_type_choice,
    STATE(13779), 1,
      sym__type,
    STATE(14851), 1,
      sym_parameter_types,
    STATE(16550), 1,
      sym_stable_identifier,
    STATE(16921), 1,
      sym_bindings,
    ACTIONS(4162), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4164), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4168), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2351), 2,
      sym_comment,
      sym_block_comment,
    STATE(9528), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10288), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10717), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13932), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4150), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7341), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [147] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4190), 1,
      sym_operator_identifier,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4198), 1,
      sym__indent,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(8818), 1,
      sym_colon_argument,
    STATE(9805), 1,
      sym_identifier,
    STATE(10195), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    STATE(17692), 1,
      sym_bindings,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2352), 2,
      sym_comment,
      sym_block_comment,
    STATE(8817), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [294] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4202), 1,
      sym_operator_identifier,
    ACTIONS(4204), 1,
      sym__indent,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(7344), 1,
      sym_identifier,
    STATE(8023), 1,
      sym_wildcard,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9479), 1,
      sym_colon_argument,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(16390), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2353), 2,
      sym_comment,
      sym_block_comment,
    STATE(9478), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [441] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4206), 1,
      sym_operator_identifier,
    ACTIONS(4208), 1,
      sym__indent,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(8866), 1,
      sym_colon_argument,
    STATE(9809), 1,
      sym_identifier,
    STATE(10219), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    STATE(17745), 1,
      sym_bindings,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2354), 2,
      sym_comment,
      sym_block_comment,
    STATE(8865), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [588] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4210), 1,
      sym__alpha_identifier,
    ACTIONS(4212), 1,
      anon_sym_COLON,
    ACTIONS(4214), 1,
      anon_sym_LBRACE,
    ACTIONS(4216), 1,
      anon_sym__,
    ACTIONS(4218), 1,
      anon_sym_EQ_GT,
    ACTIONS(4220), 1,
      anon_sym_LBRACK,
    ACTIONS(4224), 1,
      anon_sym_AT,
    ACTIONS(4226), 1,
      anon_sym_LPAREN,
    ACTIONS(4228), 1,
      sym__backquoted_id,
    ACTIONS(4230), 1,
      sym_operator_identifier,
    ACTIONS(4232), 1,
      sym_integer_literal,
    ACTIONS(4238), 1,
      sym__indent,
    STATE(5545), 1,
      sym__annotated_type,
    STATE(5546), 1,
      sym__simple_type,
    STATE(6658), 1,
      sym__soft_identifier,
    STATE(7270), 1,
      sym_identifier,
    STATE(7944), 1,
      sym_wildcard,
    STATE(8878), 1,
      sym_annotated_type,
    STATE(9640), 1,
      sym_colon_argument,
    STATE(10706), 1,
      sym__non_null_literal,
    STATE(10736), 1,
      sym_literal_type,
    STATE(11665), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12350), 1,
      sym__infix_type_choice,
    STATE(15564), 1,
      sym_parameter_types,
    STATE(16208), 1,
      sym_stable_identifier,
    STATE(16555), 1,
      sym_bindings,
    ACTIONS(4234), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4236), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4240), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2355), 2,
      sym_comment,
      sym_block_comment,
    STATE(9637), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10225), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10825), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11717), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11962), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4222), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7079), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [735] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4242), 1,
      sym_operator_identifier,
    ACTIONS(4244), 1,
      sym__indent,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9190), 1,
      sym_colon_argument,
    STATE(9776), 1,
      sym_identifier,
    STATE(10233), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17320), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2356), 2,
      sym_comment,
      sym_block_comment,
    STATE(9189), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [882] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4246), 1,
      sym_operator_identifier,
    ACTIONS(4248), 1,
      sym__indent,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(7854), 1,
      sym_colon_argument,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9813), 1,
      sym_identifier,
    STATE(10275), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    STATE(17726), 1,
      sym_bindings,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2357), 2,
      sym_comment,
      sym_block_comment,
    STATE(7841), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [1029] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4250), 1,
      sym_operator_identifier,
    ACTIONS(4252), 1,
      sym__indent,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5693), 1,
      sym_colon_argument,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9787), 1,
      sym_identifier,
    STATE(10321), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17513), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2358), 2,
      sym_comment,
      sym_block_comment,
    STATE(5692), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [1176] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4254), 1,
      sym__alpha_identifier,
    ACTIONS(4256), 1,
      anon_sym_COLON,
    ACTIONS(4258), 1,
      anon_sym_LBRACE,
    ACTIONS(4260), 1,
      anon_sym__,
    ACTIONS(4262), 1,
      anon_sym_EQ_GT,
    ACTIONS(4264), 1,
      anon_sym_LBRACK,
    ACTIONS(4268), 1,
      anon_sym_AT,
    ACTIONS(4270), 1,
      anon_sym_LPAREN,
    ACTIONS(4272), 1,
      sym__backquoted_id,
    ACTIONS(4274), 1,
      sym_operator_identifier,
    ACTIONS(4276), 1,
      sym_integer_literal,
    ACTIONS(4282), 1,
      sym__indent,
    STATE(4728), 1,
      sym__annotated_type,
    STATE(4744), 1,
      sym__simple_type,
    STATE(4941), 1,
      sym__soft_identifier,
    STATE(5333), 1,
      sym_identifier,
    STATE(5748), 1,
      sym_wildcard,
    STATE(7118), 1,
      sym_annotated_type,
    STATE(7505), 1,
      sym_colon_argument,
    STATE(9780), 1,
      sym__non_null_literal,
    STATE(9969), 1,
      sym_literal_type,
    STATE(12524), 1,
      sym__infix_type_choice,
    STATE(12881), 1,
      sym_template_body,
    STATE(12964), 1,
      sym__type,
    STATE(15047), 1,
      sym_parameter_types,
    STATE(17161), 1,
      sym_stable_identifier,
    STATE(17853), 1,
      sym_bindings,
    ACTIONS(4278), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4280), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4284), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2359), 2,
      sym_comment,
      sym_block_comment,
    STATE(7504), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9211), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9742), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12862), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13186), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(12809), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4266), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5096), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [1323] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4212), 1,
      anon_sym_COLON,
    ACTIONS(4214), 1,
      anon_sym_LBRACE,
    ACTIONS(4224), 1,
      anon_sym_AT,
    ACTIONS(4286), 1,
      sym__alpha_identifier,
    ACTIONS(4288), 1,
      anon_sym__,
    ACTIONS(4290), 1,
      anon_sym_EQ_GT,
    ACTIONS(4292), 1,
      anon_sym_LBRACK,
    ACTIONS(4296), 1,
      anon_sym_LPAREN,
    ACTIONS(4298), 1,
      sym__backquoted_id,
    ACTIONS(4300), 1,
      sym_operator_identifier,
    ACTIONS(4302), 1,
      sym_integer_literal,
    ACTIONS(4308), 1,
      sym__indent,
    STATE(4439), 1,
      sym__annotated_type,
    STATE(4440), 1,
      sym__simple_type,
    STATE(4467), 1,
      sym__soft_identifier,
    STATE(4684), 1,
      sym_identifier,
    STATE(4782), 1,
      sym_wildcard,
    STATE(5824), 1,
      sym_annotated_type,
    STATE(6163), 1,
      sym_colon_argument,
    STATE(9176), 1,
      sym__non_null_literal,
    STATE(9177), 1,
      sym_literal_type,
    STATE(11665), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12389), 1,
      sym__infix_type_choice,
    STATE(15019), 1,
      sym_parameter_types,
    STATE(16363), 1,
      sym_stable_identifier,
    STATE(16719), 1,
      sym_bindings,
    ACTIONS(4304), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4306), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4310), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2360), 2,
      sym_comment,
      sym_block_comment,
    STATE(6617), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(7606), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9064), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11717), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11962), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4294), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4713), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [1470] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4312), 1,
      sym__alpha_identifier,
    ACTIONS(4314), 1,
      anon_sym_COLON,
    ACTIONS(4316), 1,
      anon_sym_LBRACE,
    ACTIONS(4318), 1,
      anon_sym__,
    ACTIONS(4320), 1,
      anon_sym_EQ_GT,
    ACTIONS(4322), 1,
      anon_sym_LBRACK,
    ACTIONS(4326), 1,
      anon_sym_AT,
    ACTIONS(4328), 1,
      anon_sym_LPAREN,
    ACTIONS(4330), 1,
      sym__backquoted_id,
    ACTIONS(4332), 1,
      sym_operator_identifier,
    ACTIONS(4334), 1,
      sym_integer_literal,
    ACTIONS(4340), 1,
      sym__indent,
    STATE(5091), 1,
      sym__annotated_type,
    STATE(5344), 1,
      sym__simple_type,
    STATE(5532), 1,
      sym__soft_identifier,
    STATE(6121), 1,
      sym_identifier,
    STATE(6998), 1,
      sym_wildcard,
    STATE(8214), 1,
      sym_annotated_type,
    STATE(8923), 1,
      sym_colon_argument,
    STATE(10543), 1,
      sym_literal_type,
    STATE(10644), 1,
      sym__non_null_literal,
    STATE(12533), 1,
      sym__infix_type_choice,
    STATE(13340), 1,
      sym__type,
    STATE(13617), 1,
      sym_template_body,
    STATE(15133), 1,
      sym_parameter_types,
    STATE(16165), 1,
      sym_bindings,
    STATE(17179), 1,
      sym_stable_identifier,
    ACTIONS(4336), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4338), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4342), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2361), 2,
      sym_comment,
      sym_block_comment,
    STATE(8922), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9951), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10503), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13609), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13685), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(13417), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4324), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6288), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [1617] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4344), 1,
      sym__alpha_identifier,
    ACTIONS(4346), 1,
      anon_sym_COLON,
    ACTIONS(4348), 1,
      anon_sym_LBRACE,
    ACTIONS(4350), 1,
      anon_sym__,
    ACTIONS(4352), 1,
      anon_sym_EQ_GT,
    ACTIONS(4354), 1,
      anon_sym_LBRACK,
    ACTIONS(4358), 1,
      anon_sym_AT,
    ACTIONS(4360), 1,
      anon_sym_LPAREN,
    ACTIONS(4362), 1,
      sym__backquoted_id,
    ACTIONS(4364), 1,
      sym_operator_identifier,
    ACTIONS(4366), 1,
      sym_integer_literal,
    ACTIONS(4372), 1,
      sym__indent,
    STATE(5613), 1,
      sym__annotated_type,
    STATE(5792), 1,
      sym__simple_type,
    STATE(6290), 1,
      sym__soft_identifier,
    STATE(7016), 1,
      sym_identifier,
    STATE(7542), 1,
      sym_wildcard,
    STATE(9068), 1,
      sym_annotated_type,
    STATE(9377), 1,
      sym_colon_argument,
    STATE(10738), 1,
      sym_literal_type,
    STATE(10922), 1,
      sym__non_null_literal,
    STATE(11664), 1,
      sym_template_body,
    STATE(11673), 1,
      sym__type,
    STATE(12535), 1,
      sym__infix_type_choice,
    STATE(15178), 1,
      sym_parameter_types,
    STATE(16195), 1,
      sym_bindings,
    STATE(17185), 1,
      sym_stable_identifier,
    ACTIONS(4368), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4370), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4374), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2362), 2,
      sym_comment,
      sym_block_comment,
    STATE(9376), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10202), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10795), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11677), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11989), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4356), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6857), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [1764] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4376), 1,
      sym__alpha_identifier,
    ACTIONS(4378), 1,
      anon_sym_COLON,
    ACTIONS(4380), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      anon_sym__,
    ACTIONS(4384), 1,
      anon_sym_EQ_GT,
    ACTIONS(4386), 1,
      anon_sym_LBRACK,
    ACTIONS(4390), 1,
      anon_sym_AT,
    ACTIONS(4392), 1,
      anon_sym_LPAREN,
    ACTIONS(4394), 1,
      sym__backquoted_id,
    ACTIONS(4396), 1,
      sym_operator_identifier,
    ACTIONS(4398), 1,
      sym_integer_literal,
    ACTIONS(4404), 1,
      sym__indent,
    STATE(4887), 1,
      sym__simple_type,
    STATE(4899), 1,
      sym__annotated_type,
    STATE(5049), 1,
      sym__soft_identifier,
    STATE(5812), 1,
      sym_identifier,
    STATE(6324), 1,
      sym_wildcard,
    STATE(7877), 1,
      sym_annotated_type,
    STATE(8467), 1,
      sym_colon_argument,
    STATE(10234), 1,
      sym_literal_type,
    STATE(10289), 1,
      sym__non_null_literal,
    STATE(12639), 1,
      sym__infix_type_choice,
    STATE(13108), 1,
      sym__type,
    STATE(13167), 1,
      sym_template_body,
    STATE(15643), 1,
      sym_parameter_types,
    STATE(16509), 1,
      sym_stable_identifier,
    STATE(16824), 1,
      sym_bindings,
    ACTIONS(4400), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4402), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4406), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2363), 2,
      sym_comment,
      sym_block_comment,
    STATE(8424), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10144), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13130), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13475), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(13189), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5943), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [1911] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4346), 1,
      anon_sym_COLON,
    ACTIONS(4348), 1,
      anon_sym_LBRACE,
    ACTIONS(4358), 1,
      anon_sym_AT,
    ACTIONS(4408), 1,
      sym__alpha_identifier,
    ACTIONS(4410), 1,
      anon_sym__,
    ACTIONS(4412), 1,
      anon_sym_EQ_GT,
    ACTIONS(4414), 1,
      anon_sym_LBRACK,
    ACTIONS(4418), 1,
      anon_sym_LPAREN,
    ACTIONS(4420), 1,
      sym__backquoted_id,
    ACTIONS(4422), 1,
      sym_operator_identifier,
    ACTIONS(4424), 1,
      sym_integer_literal,
    ACTIONS(4430), 1,
      sym__indent,
    STATE(4385), 1,
      sym__simple_type,
    STATE(4413), 1,
      sym__annotated_type,
    STATE(4476), 1,
      sym__soft_identifier,
    STATE(4664), 1,
      sym_identifier,
    STATE(4901), 1,
      sym_wildcard,
    STATE(5974), 1,
      sym_annotated_type,
    STATE(6213), 1,
      sym_colon_argument,
    STATE(9225), 1,
      sym__non_null_literal,
    STATE(9317), 1,
      sym_literal_type,
    STATE(11664), 1,
      sym_template_body,
    STATE(11673), 1,
      sym__type,
    STATE(12537), 1,
      sym__infix_type_choice,
    STATE(15032), 1,
      sym_parameter_types,
    STATE(16225), 1,
      sym_bindings,
    STATE(17191), 1,
      sym_stable_identifier,
    ACTIONS(4426), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4428), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4432), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2364), 2,
      sym_comment,
      sym_block_comment,
    STATE(6212), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(7930), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8772), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11677), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11989), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4416), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4659), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [2058] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4434), 1,
      sym__alpha_identifier,
    ACTIONS(4436), 1,
      anon_sym_COLON,
    ACTIONS(4438), 1,
      anon_sym_LBRACE,
    ACTIONS(4440), 1,
      anon_sym__,
    ACTIONS(4442), 1,
      anon_sym_EQ_GT,
    ACTIONS(4444), 1,
      anon_sym_LBRACK,
    ACTIONS(4448), 1,
      anon_sym_AT,
    ACTIONS(4450), 1,
      anon_sym_LPAREN,
    ACTIONS(4452), 1,
      sym__backquoted_id,
    ACTIONS(4454), 1,
      sym_operator_identifier,
    ACTIONS(4456), 1,
      sym_integer_literal,
    ACTIONS(4462), 1,
      sym__indent,
    STATE(4590), 1,
      sym__simple_type,
    STATE(4592), 1,
      sym__annotated_type,
    STATE(4948), 1,
      sym__soft_identifier,
    STATE(5355), 1,
      sym_identifier,
    STATE(5794), 1,
      sym_wildcard,
    STATE(7281), 1,
      sym_annotated_type,
    STATE(7682), 1,
      sym_colon_argument,
    STATE(10057), 1,
      sym__non_null_literal,
    STATE(10116), 1,
      sym_literal_type,
    STATE(12539), 1,
      sym__infix_type_choice,
    STATE(12842), 1,
      sym__type,
    STATE(12873), 1,
      sym_template_body,
    STATE(15256), 1,
      sym_parameter_types,
    STATE(16255), 1,
      sym_bindings,
    STATE(17203), 1,
      sym_stable_identifier,
    ACTIONS(4458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4464), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2365), 2,
      sym_comment,
      sym_block_comment,
    STATE(7681), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(8888), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9862), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12943), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13065), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(12811), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4446), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5122), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [2205] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4282), 1,
      sym__indent,
    ACTIONS(4466), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(7505), 1,
      sym_colon_argument,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9819), 1,
      sym_identifier,
    STATE(10255), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    STATE(17853), 1,
      sym_bindings,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2366), 2,
      sym_comment,
      sym_block_comment,
    STATE(7504), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [2352] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4468), 1,
      sym__alpha_identifier,
    ACTIONS(4470), 1,
      anon_sym_COLON,
    ACTIONS(4472), 1,
      anon_sym_LBRACE,
    ACTIONS(4474), 1,
      anon_sym__,
    ACTIONS(4476), 1,
      anon_sym_EQ_GT,
    ACTIONS(4478), 1,
      anon_sym_LBRACK,
    ACTIONS(4482), 1,
      anon_sym_AT,
    ACTIONS(4484), 1,
      anon_sym_LPAREN,
    ACTIONS(4486), 1,
      sym__backquoted_id,
    ACTIONS(4488), 1,
      sym_operator_identifier,
    ACTIONS(4490), 1,
      sym_integer_literal,
    ACTIONS(4496), 1,
      sym__indent,
    STATE(6206), 1,
      sym__simple_type,
    STATE(6248), 1,
      sym__annotated_type,
    STATE(6759), 1,
      sym__soft_identifier,
    STATE(8019), 1,
      sym_identifier,
    STATE(8595), 1,
      sym_wildcard,
    STATE(9655), 1,
      sym_annotated_type,
    STATE(10125), 1,
      sym_colon_argument,
    STATE(10968), 1,
      sym_literal_type,
    STATE(11044), 1,
      sym__non_null_literal,
    STATE(11868), 1,
      sym_template_body,
    STATE(12000), 1,
      sym__type,
    STATE(12441), 1,
      sym__infix_type_choice,
    STATE(15622), 1,
      sym_parameter_types,
    STATE(16590), 1,
      sym_stable_identifier,
    STATE(17038), 1,
      sym_bindings,
    ACTIONS(4492), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4494), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4498), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2367), 2,
      sym_comment,
      sym_block_comment,
    STATE(10120), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10450), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11090), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12157), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12583), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4480), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8071), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [2499] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4340), 1,
      sym__indent,
    ACTIONS(4500), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(8923), 1,
      sym_colon_argument,
    STATE(9824), 1,
      sym_identifier,
    STATE(10292), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(16165), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2368), 2,
      sym_comment,
      sym_block_comment,
    STATE(8922), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [2646] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4372), 1,
      sym__indent,
    ACTIONS(4502), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9377), 1,
      sym_colon_argument,
    STATE(9834), 1,
      sym_identifier,
    STATE(10334), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(16195), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2369), 2,
      sym_comment,
      sym_block_comment,
    STATE(9376), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [2793] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4238), 1,
      sym__indent,
    ACTIONS(4504), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9640), 1,
      sym_colon_argument,
    STATE(9994), 1,
      sym_identifier,
    STATE(10210), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(16555), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2370), 2,
      sym_comment,
      sym_block_comment,
    STATE(9637), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [2940] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4506), 1,
      sym_operator_identifier,
    ACTIONS(4508), 1,
      sym__indent,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10101), 1,
      sym_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(10382), 1,
      sym_colon_argument,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(16804), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2371), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10378), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [3087] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4470), 1,
      anon_sym_COLON,
    ACTIONS(4472), 1,
      anon_sym_LBRACE,
    ACTIONS(4482), 1,
      anon_sym_AT,
    ACTIONS(4510), 1,
      sym__alpha_identifier,
    ACTIONS(4512), 1,
      anon_sym__,
    ACTIONS(4514), 1,
      anon_sym_EQ_GT,
    ACTIONS(4516), 1,
      anon_sym_LBRACK,
    ACTIONS(4520), 1,
      anon_sym_LPAREN,
    ACTIONS(4522), 1,
      sym__backquoted_id,
    ACTIONS(4524), 1,
      sym_operator_identifier,
    ACTIONS(4526), 1,
      sym_integer_literal,
    ACTIONS(4532), 1,
      sym__indent,
    STATE(4536), 1,
      sym__annotated_type,
    STATE(4538), 1,
      sym__simple_type,
    STATE(4572), 1,
      sym__soft_identifier,
    STATE(4786), 1,
      sym_identifier,
    STATE(5238), 1,
      sym_wildcard,
    STATE(6644), 1,
      sym_annotated_type,
    STATE(6724), 1,
      sym_colon_argument,
    STATE(9406), 1,
      sym_literal_type,
    STATE(9524), 1,
      sym__non_null_literal,
    STATE(11868), 1,
      sym_template_body,
    STATE(12000), 1,
      sym__type,
    STATE(12448), 1,
      sym__infix_type_choice,
    STATE(15022), 1,
      sym_parameter_types,
    STATE(16708), 1,
      sym_stable_identifier,
    STATE(17109), 1,
      sym_bindings,
    ACTIONS(4528), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4530), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4534), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2372), 2,
      sym_comment,
      sym_block_comment,
    STATE(6723), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(8135), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9713), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12157), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12583), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4518), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4978), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [3234] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4462), 1,
      sym__indent,
    ACTIONS(4536), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(7682), 1,
      sym_colon_argument,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9845), 1,
      sym_identifier,
    STATE(10431), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(16255), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2373), 2,
      sym_comment,
      sym_block_comment,
    STATE(7681), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [3381] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4308), 1,
      sym__indent,
    ACTIONS(4538), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(6163), 1,
      sym_colon_argument,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10053), 1,
      sym_identifier,
    STATE(10315), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(16719), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2374), 2,
      sym_comment,
      sym_block_comment,
    STATE(6617), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [3528] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4540), 1,
      sym__alpha_identifier,
    ACTIONS(4542), 1,
      anon_sym_COLON,
    ACTIONS(4544), 1,
      anon_sym_LBRACE,
    ACTIONS(4546), 1,
      anon_sym__,
    ACTIONS(4548), 1,
      anon_sym_EQ_GT,
    ACTIONS(4550), 1,
      anon_sym_LBRACK,
    ACTIONS(4554), 1,
      anon_sym_AT,
    ACTIONS(4556), 1,
      anon_sym_LPAREN,
    ACTIONS(4558), 1,
      sym__backquoted_id,
    ACTIONS(4560), 1,
      sym_operator_identifier,
    ACTIONS(4562), 1,
      sym_integer_literal,
    ACTIONS(4568), 1,
      sym__indent,
    STATE(4958), 1,
      sym__annotated_type,
    STATE(4984), 1,
      sym__simple_type,
    STATE(5155), 1,
      sym__soft_identifier,
    STATE(5619), 1,
      sym_identifier,
    STATE(6296), 1,
      sym_wildcard,
    STATE(7631), 1,
      sym_annotated_type,
    STATE(8590), 1,
      sym_colon_argument,
    STATE(10262), 1,
      sym__non_null_literal,
    STATE(10394), 1,
      sym_literal_type,
    STATE(12452), 1,
      sym__infix_type_choice,
    STATE(13138), 1,
      sym_template_body,
    STATE(13239), 1,
      sym__type,
    STATE(15013), 1,
      sym_parameter_types,
    STATE(16782), 1,
      sym_stable_identifier,
    STATE(17186), 1,
      sym_bindings,
    ACTIONS(4564), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4566), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4570), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2375), 2,
      sym_comment,
      sym_block_comment,
    STATE(8588), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9468), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10280), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13185), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13431), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(13212), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5928), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [3675] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4248), 1,
      sym__indent,
    ACTIONS(4572), 1,
      sym__alpha_identifier,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(4578), 1,
      anon_sym__,
    ACTIONS(4580), 1,
      anon_sym_EQ_GT,
    ACTIONS(4582), 1,
      anon_sym_LBRACK,
    ACTIONS(4586), 1,
      anon_sym_AT,
    ACTIONS(4588), 1,
      anon_sym_LPAREN,
    ACTIONS(4590), 1,
      sym__backquoted_id,
    ACTIONS(4592), 1,
      sym_operator_identifier,
    ACTIONS(4594), 1,
      sym_integer_literal,
    STATE(4694), 1,
      sym__annotated_type,
    STATE(4753), 1,
      sym__simple_type,
    STATE(5025), 1,
      sym__soft_identifier,
    STATE(5310), 1,
      sym_identifier,
    STATE(5673), 1,
      sym_wildcard,
    STATE(6780), 1,
      sym_annotated_type,
    STATE(7854), 1,
      sym_colon_argument,
    STATE(9897), 1,
      sym__non_null_literal,
    STATE(9912), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(12205), 1,
      sym__type,
    STATE(12346), 1,
      sym__infix_type_choice,
    STATE(15016), 1,
      sym_parameter_types,
    STATE(17351), 1,
      sym_stable_identifier,
    STATE(17726), 1,
      sym_bindings,
    ACTIONS(4596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4600), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2376), 2,
      sym_comment,
      sym_block_comment,
    STATE(7841), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9287), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10030), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12704), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5296), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [3822] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4602), 1,
      sym__alpha_identifier,
    ACTIONS(4604), 1,
      anon_sym_COLON,
    ACTIONS(4606), 1,
      anon_sym_LBRACE,
    ACTIONS(4608), 1,
      anon_sym__,
    ACTIONS(4610), 1,
      anon_sym_EQ_GT,
    ACTIONS(4612), 1,
      anon_sym_LBRACK,
    ACTIONS(4616), 1,
      anon_sym_AT,
    ACTIONS(4618), 1,
      anon_sym_LPAREN,
    ACTIONS(4620), 1,
      sym__backquoted_id,
    ACTIONS(4622), 1,
      sym_operator_identifier,
    ACTIONS(4624), 1,
      sym_integer_literal,
    ACTIONS(4630), 1,
      sym__indent,
    STATE(4990), 1,
      sym__annotated_type,
    STATE(5035), 1,
      sym__simple_type,
    STATE(5195), 1,
      sym__soft_identifier,
    STATE(5816), 1,
      sym_identifier,
    STATE(6260), 1,
      sym_wildcard,
    STATE(8014), 1,
      sym_annotated_type,
    STATE(8536), 1,
      sym_colon_argument,
    STATE(10209), 1,
      sym__non_null_literal,
    STATE(10287), 1,
      sym_literal_type,
    STATE(12549), 1,
      sym__infix_type_choice,
    STATE(13150), 1,
      sym_template_body,
    STATE(13221), 1,
      sym__type,
    STATE(15291), 1,
      sym_parameter_types,
    STATE(16282), 1,
      sym_bindings,
    STATE(17269), 1,
      sym_stable_identifier,
    ACTIONS(4626), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4628), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4632), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2377), 2,
      sym_comment,
      sym_block_comment,
    STATE(8535), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9383), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10251), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13125), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13455), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(13262), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5955), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [3969] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4404), 1,
      sym__indent,
    ACTIONS(4634), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(8467), 1,
      sym_colon_argument,
    STATE(10088), 1,
      sym_identifier,
    STATE(10371), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(16824), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2378), 2,
      sym_comment,
      sym_block_comment,
    STATE(8424), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [4116] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4630), 1,
      sym__indent,
    ACTIONS(4636), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(8536), 1,
      sym_colon_argument,
    STATE(9854), 1,
      sym_identifier,
    STATE(10150), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(16282), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2379), 2,
      sym_comment,
      sym_block_comment,
    STATE(8535), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [4263] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4166), 1,
      sym__indent,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4638), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9535), 1,
      sym_colon_argument,
    STATE(10113), 1,
      sym_identifier,
    STATE(10425), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(16921), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2380), 2,
      sym_comment,
      sym_block_comment,
    STATE(9528), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [4410] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4508), 1,
      sym__indent,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(4586), 1,
      anon_sym_AT,
    ACTIONS(4640), 1,
      sym__alpha_identifier,
    ACTIONS(4642), 1,
      anon_sym__,
    ACTIONS(4644), 1,
      anon_sym_EQ_GT,
    ACTIONS(4646), 1,
      anon_sym_LBRACK,
    ACTIONS(4650), 1,
      anon_sym_LPAREN,
    ACTIONS(4652), 1,
      sym__backquoted_id,
    ACTIONS(4654), 1,
      sym_operator_identifier,
    ACTIONS(4656), 1,
      sym_integer_literal,
    STATE(7244), 1,
      sym__annotated_type,
    STATE(7245), 1,
      sym__simple_type,
    STATE(7872), 1,
      sym__soft_identifier,
    STATE(8265), 1,
      sym_identifier,
    STATE(9295), 1,
      sym_wildcard,
    STATE(9803), 1,
      sym_annotated_type,
    STATE(10382), 1,
      sym_colon_argument,
    STATE(10807), 1,
      sym_template_body,
    STATE(11164), 1,
      sym__non_null_literal,
    STATE(11165), 1,
      sym_literal_type,
    STATE(12205), 1,
      sym__type,
    STATE(12340), 1,
      sym__infix_type_choice,
    STATE(15510), 1,
      sym_parameter_types,
    STATE(16804), 1,
      sym_bindings,
    STATE(17142), 1,
      sym_stable_identifier,
    ACTIONS(4658), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4660), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4662), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2381), 2,
      sym_comment,
      sym_block_comment,
    STATE(10378), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10734), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11317), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12704), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4648), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8425), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [4557] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4664), 1,
      sym__alpha_identifier,
    ACTIONS(4666), 1,
      anon_sym_COLON,
    ACTIONS(4668), 1,
      anon_sym_LBRACE,
    ACTIONS(4670), 1,
      anon_sym__,
    ACTIONS(4672), 1,
      anon_sym_EQ_GT,
    ACTIONS(4674), 1,
      anon_sym_LBRACK,
    ACTIONS(4678), 1,
      anon_sym_AT,
    ACTIONS(4680), 1,
      anon_sym_LPAREN,
    ACTIONS(4682), 1,
      sym__backquoted_id,
    ACTIONS(4684), 1,
      sym_operator_identifier,
    ACTIONS(4686), 1,
      sym_integer_literal,
    ACTIONS(4692), 1,
      sym__indent,
    STATE(4972), 1,
      sym__annotated_type,
    STATE(5002), 1,
      sym__simple_type,
    STATE(5176), 1,
      sym__soft_identifier,
    STATE(5633), 1,
      sym_identifier,
    STATE(6417), 1,
      sym_wildcard,
    STATE(7967), 1,
      sym_annotated_type,
    STATE(8347), 1,
      sym_colon_argument,
    STATE(10369), 1,
      sym_literal_type,
    STATE(10429), 1,
      sym__non_null_literal,
    STATE(12460), 1,
      sym__infix_type_choice,
    STATE(13109), 1,
      sym__type,
    STATE(13199), 1,
      sym_template_body,
    STATE(15231), 1,
      sym_parameter_types,
    STATE(16905), 1,
      sym_stable_identifier,
    STATE(17255), 1,
      sym_bindings,
    ACTIONS(4688), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4690), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4694), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2382), 2,
      sym_comment,
      sym_block_comment,
    STATE(8345), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9523), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10326), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13289), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13389), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(13116), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4676), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5890), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [4704] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4496), 1,
      sym__indent,
    ACTIONS(4696), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9735), 1,
      sym_identifier,
    STATE(10125), 1,
      sym_colon_argument,
    STATE(10395), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17038), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2383), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10120), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [4851] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4244), 1,
      sym__indent,
    ACTIONS(4698), 1,
      sym__alpha_identifier,
    ACTIONS(4700), 1,
      anon_sym_COLON,
    ACTIONS(4702), 1,
      anon_sym_LBRACE,
    ACTIONS(4704), 1,
      anon_sym__,
    ACTIONS(4706), 1,
      anon_sym_EQ_GT,
    ACTIONS(4708), 1,
      anon_sym_LBRACK,
    ACTIONS(4712), 1,
      anon_sym_AT,
    ACTIONS(4714), 1,
      anon_sym_LPAREN,
    ACTIONS(4716), 1,
      sym__backquoted_id,
    ACTIONS(4718), 1,
      sym_operator_identifier,
    ACTIONS(4720), 1,
      sym_integer_literal,
    STATE(5437), 1,
      sym__annotated_type,
    STATE(5453), 1,
      sym__simple_type,
    STATE(5498), 1,
      sym__soft_identifier,
    STATE(6488), 1,
      sym_identifier,
    STATE(6794), 1,
      sym_wildcard,
    STATE(8602), 1,
      sym_annotated_type,
    STATE(9190), 1,
      sym_colon_argument,
    STATE(10590), 1,
      sym__non_null_literal,
    STATE(10652), 1,
      sym_literal_type,
    STATE(11182), 1,
      sym_template_body,
    STATE(11263), 1,
      sym__type,
    STATE(12473), 1,
      sym__infix_type_choice,
    STATE(15606), 1,
      sym_parameter_types,
    STATE(16963), 1,
      sym_stable_identifier,
    STATE(17320), 1,
      sym_bindings,
    ACTIONS(4722), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4724), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4726), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2384), 2,
      sym_comment,
      sym_block_comment,
    STATE(9189), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9889), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10515), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11555), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4710), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6568), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [4998] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4728), 1,
      sym_operator_identifier,
    ACTIONS(4730), 1,
      sym__indent,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(6896), 1,
      sym_colon_argument,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9792), 1,
      sym_identifier,
    STATE(10405), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17573), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2385), 2,
      sym_comment,
      sym_block_comment,
    STATE(6895), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [5145] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4732), 1,
      sym__alpha_identifier,
    ACTIONS(4734), 1,
      anon_sym_COLON,
    ACTIONS(4736), 1,
      anon_sym_LBRACE,
    ACTIONS(4738), 1,
      anon_sym__,
    ACTIONS(4740), 1,
      anon_sym_EQ_GT,
    ACTIONS(4742), 1,
      anon_sym_LBRACK,
    ACTIONS(4746), 1,
      anon_sym_AT,
    ACTIONS(4748), 1,
      anon_sym_LPAREN,
    ACTIONS(4750), 1,
      sym__backquoted_id,
    ACTIONS(4752), 1,
      sym_operator_identifier,
    ACTIONS(4754), 1,
      sym_integer_literal,
    ACTIONS(4760), 1,
      sym__indent,
    STATE(6090), 1,
      sym__simple_type,
    STATE(6570), 1,
      sym__annotated_type,
    STATE(7205), 1,
      sym__soft_identifier,
    STATE(7732), 1,
      sym_identifier,
    STATE(8569), 1,
      sym_wildcard,
    STATE(9502), 1,
      sym_annotated_type,
    STATE(10002), 1,
      sym_colon_argument,
    STATE(10959), 1,
      sym__non_null_literal,
    STATE(11086), 1,
      sym_literal_type,
    STATE(11813), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12480), 1,
      sym__infix_type_choice,
    STATE(14754), 1,
      sym_parameter_types,
    STATE(16996), 1,
      sym_stable_identifier,
    STATE(17386), 1,
      sym_bindings,
    ACTIONS(4756), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4758), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4762), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2386), 2,
      sym_comment,
      sym_block_comment,
    STATE(9999), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10481), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11068), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11907), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12427), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4744), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7933), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [5292] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4764), 1,
      sym_operator_identifier,
    ACTIONS(4766), 1,
      sym__indent,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9741), 1,
      sym_identifier,
    STATE(10135), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(10824), 1,
      sym_colon_argument,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17453), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2387), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10822), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [5439] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4532), 1,
      sym__indent,
    ACTIONS(4768), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(6724), 1,
      sym_colon_argument,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9750), 1,
      sym_identifier,
    STATE(10137), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17109), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2388), 2,
      sym_comment,
      sym_block_comment,
    STATE(6723), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [5586] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4252), 1,
      sym__indent,
    ACTIONS(4700), 1,
      anon_sym_COLON,
    ACTIONS(4702), 1,
      anon_sym_LBRACE,
    ACTIONS(4712), 1,
      anon_sym_AT,
    ACTIONS(4770), 1,
      sym__alpha_identifier,
    ACTIONS(4772), 1,
      anon_sym__,
    ACTIONS(4774), 1,
      anon_sym_EQ_GT,
    ACTIONS(4776), 1,
      anon_sym_LBRACK,
    ACTIONS(4780), 1,
      anon_sym_LPAREN,
    ACTIONS(4782), 1,
      sym__backquoted_id,
    ACTIONS(4784), 1,
      sym_operator_identifier,
    ACTIONS(4786), 1,
      sym_integer_literal,
    STATE(4279), 1,
      sym__simple_type,
    STATE(4380), 1,
      sym__annotated_type,
    STATE(4399), 1,
      sym__soft_identifier,
    STATE(4509), 1,
      sym_identifier,
    STATE(4632), 1,
      sym_wildcard,
    STATE(5134), 1,
      sym_annotated_type,
    STATE(5693), 1,
      sym_colon_argument,
    STATE(8293), 1,
      sym__non_null_literal,
    STATE(8397), 1,
      sym_literal_type,
    STATE(11182), 1,
      sym_template_body,
    STATE(11263), 1,
      sym__type,
    STATE(12481), 1,
      sym__infix_type_choice,
    STATE(15025), 1,
      sym_parameter_types,
    STATE(17007), 1,
      sym_stable_identifier,
    STATE(17513), 1,
      sym_bindings,
    ACTIONS(4788), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4790), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4792), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2389), 2,
      sym_comment,
      sym_block_comment,
    STATE(5692), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(7263), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8127), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11555), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4778), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4539), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [5733] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4730), 1,
      sym__indent,
    ACTIONS(4734), 1,
      anon_sym_COLON,
    ACTIONS(4736), 1,
      anon_sym_LBRACE,
    ACTIONS(4746), 1,
      anon_sym_AT,
    ACTIONS(4794), 1,
      sym__alpha_identifier,
    ACTIONS(4796), 1,
      anon_sym__,
    ACTIONS(4798), 1,
      anon_sym_EQ_GT,
    ACTIONS(4800), 1,
      anon_sym_LBRACK,
    ACTIONS(4804), 1,
      anon_sym_LPAREN,
    ACTIONS(4806), 1,
      sym__backquoted_id,
    ACTIONS(4808), 1,
      sym_operator_identifier,
    ACTIONS(4810), 1,
      sym_integer_literal,
    STATE(4477), 1,
      sym__simple_type,
    STATE(4561), 1,
      sym__annotated_type,
    STATE(4605), 1,
      sym__soft_identifier,
    STATE(4859), 1,
      sym_identifier,
    STATE(5319), 1,
      sym_wildcard,
    STATE(6171), 1,
      sym_annotated_type,
    STATE(6896), 1,
      sym_colon_argument,
    STATE(9652), 1,
      sym__non_null_literal,
    STATE(9661), 1,
      sym_literal_type,
    STATE(11813), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12485), 1,
      sym__infix_type_choice,
    STATE(15026), 1,
      sym_parameter_types,
    STATE(17024), 1,
      sym_stable_identifier,
    STATE(17573), 1,
      sym_bindings,
    ACTIONS(4812), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4814), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4816), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2390), 2,
      sym_comment,
      sym_block_comment,
    STATE(6895), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(8488), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9443), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11907), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12427), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4802), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4813), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [5880] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4568), 1,
      sym__indent,
    ACTIONS(4818), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(8590), 1,
      sym_colon_argument,
    STATE(9756), 1,
      sym_identifier,
    STATE(10286), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17186), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2391), 2,
      sym_comment,
      sym_block_comment,
    STATE(8588), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [6027] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4820), 1,
      sym__alpha_identifier,
    ACTIONS(4822), 1,
      anon_sym_COLON,
    ACTIONS(4824), 1,
      anon_sym_LBRACE,
    ACTIONS(4826), 1,
      anon_sym__,
    ACTIONS(4828), 1,
      anon_sym_EQ_GT,
    ACTIONS(4830), 1,
      anon_sym_LBRACK,
    ACTIONS(4834), 1,
      anon_sym_AT,
    ACTIONS(4836), 1,
      anon_sym_LPAREN,
    ACTIONS(4838), 1,
      sym__backquoted_id,
    ACTIONS(4840), 1,
      sym_operator_identifier,
    ACTIONS(4842), 1,
      sym_integer_literal,
    ACTIONS(4848), 1,
      sym__indent,
    STATE(4479), 1,
      sym__simple_type,
    STATE(4564), 1,
      sym__annotated_type,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(4865), 1,
      sym_identifier,
    STATE(5322), 1,
      sym_wildcard,
    STATE(5999), 1,
      sym_annotated_type,
    STATE(6928), 1,
      sym_colon_argument,
    STATE(9362), 1,
      sym__non_null_literal,
    STATE(9672), 1,
      sym_literal_type,
    STATE(12259), 1,
      sym_template_body,
    STATE(12488), 1,
      sym__infix_type_choice,
    STATE(12536), 1,
      sym__type,
    STATE(14829), 1,
      sym_parameter_types,
    STATE(17030), 1,
      sym_stable_identifier,
    STATE(17633), 1,
      sym_bindings,
    ACTIONS(4844), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4846), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4850), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2392), 2,
      sym_comment,
      sym_block_comment,
    STATE(6927), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(8521), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9588), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12383), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12902), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(12509), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4832), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4830), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [6174] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4198), 1,
      sym__indent,
    ACTIONS(4852), 1,
      sym__alpha_identifier,
    ACTIONS(4854), 1,
      anon_sym_COLON,
    ACTIONS(4856), 1,
      anon_sym_LBRACE,
    ACTIONS(4858), 1,
      anon_sym__,
    ACTIONS(4860), 1,
      anon_sym_EQ_GT,
    ACTIONS(4862), 1,
      anon_sym_LBRACK,
    ACTIONS(4866), 1,
      anon_sym_AT,
    ACTIONS(4868), 1,
      anon_sym_LPAREN,
    ACTIONS(4870), 1,
      sym__backquoted_id,
    ACTIONS(4872), 1,
      sym_operator_identifier,
    ACTIONS(4874), 1,
      sym_integer_literal,
    STATE(5136), 1,
      sym__annotated_type,
    STATE(5391), 1,
      sym__simple_type,
    STATE(5519), 1,
      sym__soft_identifier,
    STATE(6049), 1,
      sym_identifier,
    STATE(6929), 1,
      sym_wildcard,
    STATE(8415), 1,
      sym_annotated_type,
    STATE(8818), 1,
      sym_colon_argument,
    STATE(10606), 1,
      sym__non_null_literal,
    STATE(10615), 1,
      sym_literal_type,
    STATE(12495), 1,
      sym__infix_type_choice,
    STATE(13404), 1,
      sym_template_body,
    STATE(13522), 1,
      sym__type,
    STATE(14915), 1,
      sym_parameter_types,
    STATE(17047), 1,
      sym_stable_identifier,
    STATE(17692), 1,
      sym_bindings,
    ACTIONS(4876), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4878), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4880), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2393), 2,
      sym_comment,
      sym_block_comment,
    STATE(8817), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10073), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10505), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13434), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13826), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(13465), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4864), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6267), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [6321] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4208), 1,
      sym__indent,
    ACTIONS(4882), 1,
      sym__alpha_identifier,
    ACTIONS(4884), 1,
      anon_sym_COLON,
    ACTIONS(4886), 1,
      anon_sym_LBRACE,
    ACTIONS(4888), 1,
      anon_sym__,
    ACTIONS(4890), 1,
      anon_sym_EQ_GT,
    ACTIONS(4892), 1,
      anon_sym_LBRACK,
    ACTIONS(4896), 1,
      anon_sym_AT,
    ACTIONS(4898), 1,
      anon_sym_LPAREN,
    ACTIONS(4900), 1,
      sym__backquoted_id,
    ACTIONS(4902), 1,
      sym_operator_identifier,
    ACTIONS(4904), 1,
      sym_integer_literal,
    STATE(5273), 1,
      sym__annotated_type,
    STATE(5446), 1,
      sym__simple_type,
    STATE(5522), 1,
      sym__soft_identifier,
    STATE(6071), 1,
      sym_identifier,
    STATE(6955), 1,
      sym_wildcard,
    STATE(8698), 1,
      sym_annotated_type,
    STATE(8866), 1,
      sym_colon_argument,
    STATE(10444), 1,
      sym_literal_type,
    STATE(10485), 1,
      sym__non_null_literal,
    STATE(12497), 1,
      sym__infix_type_choice,
    STATE(13349), 1,
      sym__type,
    STATE(13587), 1,
      sym_template_body,
    STATE(14987), 1,
      sym_parameter_types,
    STATE(17059), 1,
      sym_stable_identifier,
    STATE(17745), 1,
      sym_bindings,
    ACTIONS(4906), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4908), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4910), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2394), 2,
      sym_comment,
      sym_block_comment,
    STATE(8865), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10093), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10448), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13436), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13722), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(13594), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4894), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6372), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [6468] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4692), 1,
      sym__indent,
    ACTIONS(4912), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(8347), 1,
      sym_colon_argument,
    STATE(9766), 1,
      sym_identifier,
    STATE(10136), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17255), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2395), 2,
      sym_comment,
      sym_block_comment,
    STATE(8345), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [6615] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4760), 1,
      sym__indent,
    ACTIONS(4914), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9779), 1,
      sym_identifier,
    STATE(10002), 1,
      sym_colon_argument,
    STATE(10270), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17386), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2396), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9999), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [6762] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4848), 1,
      sym__indent,
    ACTIONS(4916), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(6928), 1,
      sym_colon_argument,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9796), 1,
      sym_identifier,
    STATE(10146), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    STATE(17633), 1,
      sym_bindings,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2397), 2,
      sym_comment,
      sym_block_comment,
    STATE(6927), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [6909] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4184), 1,
      anon_sym_AT,
    ACTIONS(4186), 1,
      anon_sym_LPAREN,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4430), 1,
      sym__indent,
    ACTIONS(4918), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(6213), 1,
      sym_colon_argument,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9840), 1,
      sym_identifier,
    STATE(10377), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(13675), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(16225), 1,
      sym_bindings,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2398), 2,
      sym_comment,
      sym_block_comment,
    STATE(6212), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13945), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [7056] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4922), 9,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4920), 50,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_import,
      anon_sym_export,
      anon_sym__,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_extension,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [7130] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4926), 9,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4924), 50,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_import,
      anon_sym_export,
      anon_sym__,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_extension,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [7204] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4930), 9,
      sym__indent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4928), 50,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_import,
      anon_sym_export,
      anon_sym__,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_extension,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [7278] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2402), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4932), 8,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4934), 51,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_package,
      anon_sym_object,
      anon_sym_import,
      anon_sym_export,
      anon_sym__,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_extension,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [7352] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4926), 9,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4924), 50,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_import,
      anon_sym_export,
      anon_sym__,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_extension,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [7426] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4930), 9,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4928), 50,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_import,
      anon_sym_export,
      anon_sym__,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_extension,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [7500] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2405), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4922), 9,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4920), 50,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_import,
      anon_sym_export,
      anon_sym__,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_extension,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [7574] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(4938), 1,
      anon_sym_inline,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4942), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9209), 1,
      sym_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(14538), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15533), 1,
      sym_parameter,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2406), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15535), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [7719] = 42,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_implicit,
    ACTIONS(4958), 1,
      anon_sym_inline,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      anon_sym_using,
    ACTIONS(4964), 1,
      anon_sym_RPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(9668), 1,
      sym_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(14801), 1,
      sym_parameter,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15409), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2407), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [7866] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2408), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4930), 8,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4928), 50,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_import,
      anon_sym_export,
      anon_sym__,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_extension,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [7939] = 42,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_implicit,
    ACTIONS(4958), 1,
      anon_sym_inline,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      anon_sym_using,
    ACTIONS(4964), 1,
      anon_sym_RPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(9668), 1,
      sym_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(14801), 1,
      sym_parameter,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15617), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2409), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [8086] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(4938), 1,
      anon_sym_inline,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4942), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9209), 1,
      sym_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(14469), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15195), 1,
      sym_parameter,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2410), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15205), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [8231] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(4938), 1,
      anon_sym_inline,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4942), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9209), 1,
      sym_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(14574), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15353), 1,
      sym_parameter,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2411), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15355), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [8376] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14228), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2412), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [8512] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14246), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2413), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [8648] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14318), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2414), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [8784] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14166), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2415), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [8920] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14211), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2416), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [9056] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14244), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2417), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [9192] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14264), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2418), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [9328] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14292), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2419), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [9464] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14304), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2420), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [9600] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14335), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2421), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [9736] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14355), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2422), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [9872] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14417), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2423), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [10008] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14357), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2424), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [10144] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14177), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2425), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [10280] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14168), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2426), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [10416] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14342), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2427), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [10552] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14221), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2428), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [10688] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14279), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2429), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [10824] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14413), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2430), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [10960] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14235), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2431), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [11096] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14370), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2432), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [11232] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14306), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2433), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [11368] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14371), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2434), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [11504] = 38,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9123), 1,
      sym_identifier,
    STATE(9562), 1,
      sym_wildcard,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14183), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15323), 1,
      sym_binding,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2435), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [11640] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4974), 1,
      anon_sym_RPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2436), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [11771] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4978), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2437), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [11902] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14168), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2438), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [12033] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14349), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2439), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [12164] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4982), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2440), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [12295] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14362), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2441), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [12426] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4984), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2442), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [12557] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4986), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2443), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [12688] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14175), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2444), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [12819] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4988), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2445), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [12950] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4990), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2446), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [13081] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4992), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2447), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [13212] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14186), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2448), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [13343] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14215), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2449), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [13474] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14233), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2450), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [13605] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14198), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2451), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [13736] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14204), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2452), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [13867] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4994), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2453), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [13998] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14223), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2454), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [14129] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4996), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2455), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [14260] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4998), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2456), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [14391] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5000), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2457), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [14522] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14413), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2458), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [14653] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5002), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15465), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2459), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [14784] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14201), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2460), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [14915] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5004), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2461), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [15046] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14280), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2462), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [15177] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5006), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2463), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [15308] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_DQUOTE,
      anon_sym_yield,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [15381] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14235), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2465), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [15512] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5008), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15465), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2466), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [15643] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5010), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15465), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2467), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [15774] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5012), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2468), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [15905] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14316), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2469), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [16036] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5014), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2470), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [16167] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14306), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2471), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [16298] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5016), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2472), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [16429] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14369), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2473), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [16560] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14371), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2474), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [16691] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5018), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2475), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [16822] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14324), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2476), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [16953] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14382), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2477), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [17084] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14183), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2478), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [17215] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5020), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15465), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2479), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [17346] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5022), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2480), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [17477] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14388), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2481), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [17608] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14172), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2482), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [17739] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14398), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2483), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [17870] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5024), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2484), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [18001] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5026), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2485), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [18132] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14246), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2486), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [18263] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14407), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2487), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [18394] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5028), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2488), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [18525] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14412), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2489), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [18656] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5030), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15465), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2490), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [18787] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14318), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2491), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [18918] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14279), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2492), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [19049] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14307), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2493), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [19180] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5032), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2494), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [19311] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14205), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2495), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [19442] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5034), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2496), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [19573] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14166), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2497), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [19704] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14211), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2498), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [19835] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14370), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2499), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [19966] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14244), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2500), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [20097] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5036), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2501), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [20228] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5038), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2502), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [20359] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5040), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2503), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [20490] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5042), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15465), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2504), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [20621] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14292), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2505), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [20752] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5044), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2506), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [20883] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14299), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2507), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [21014] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14317), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2508), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [21145] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5046), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2509), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [21276] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14304), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2510), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [21407] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5048), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2511), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [21538] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14335), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2512), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [21669] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5050), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2513), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [21800] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14351), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2514), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [21931] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5052), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2515), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [22062] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14355), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2516), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [22193] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5054), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15465), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2517), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [22324] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14386), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2518), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [22455] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5056), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2519), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [22586] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14180), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2520), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [22717] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5058), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2521), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [22848] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14192), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2522), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [22979] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14200), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2523), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [23110] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5060), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2524), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [23241] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14417), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2525), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [23372] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14357), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2526), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [23503] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14177), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2527), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [23634] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14208), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2528), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [23765] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5062), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2529), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [23896] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14228), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2530), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [24027] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14342), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2531), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [24158] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14227), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2532), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [24289] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5064), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2533), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [24420] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14221), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2534), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [24551] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5066), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15465), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2535), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [24682] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5068), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2536), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [24813] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5070), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2537), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [24944] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5072), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2538), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [25075] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5074), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2539), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [25206] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5076), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2540), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [25337] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5078), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2541), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [25468] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5080), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2542), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [25599] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5082), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2543), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [25730] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5084), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2544), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [25861] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5086), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2545), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [25992] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5088), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2546), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [26123] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5090), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2547), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [26254] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14399), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2548), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [26385] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5092), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2549), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [26516] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5094), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2550), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [26647] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14288), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2551), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [26778] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5096), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2552), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [26909] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5098), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2553), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [27040] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5100), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2554), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [27171] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5102), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2555), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [27302] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5104), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2556), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [27433] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5106), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2557), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [27564] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5108), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2558), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [27695] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14305), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2559), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [27826] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5110), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15434), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2560), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [27957] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14394), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2561), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [28088] = 36,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14264), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2562), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15193), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [28219] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5112), 1,
      anon_sym_EQ_GT,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14674), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2563), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15136), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [28347] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5112), 1,
      anon_sym_EQ_GT,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14543), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2564), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15240), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [28475] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5112), 1,
      anon_sym_EQ_GT,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14501), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2565), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15493), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [28603] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5112), 1,
      anon_sym_EQ_GT,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14665), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2566), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15718), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [28731] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5112), 1,
      anon_sym_EQ_GT,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14508), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2567), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15300), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [28859] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15592), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2568), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(16125), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [28987] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5112), 1,
      anon_sym_EQ_GT,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14509), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2569), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15491), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [29115] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(5112), 1,
      anon_sym_EQ_GT,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14650), 1,
      sym__type,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2570), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15481), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [29243] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 11,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_DQUOTE,
      anon_sym_yield,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [29315] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15574), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2572), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(16090), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [29443] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4178), 1,
      anon_sym_EQ_GT,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(15465), 1,
      sym__type,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2573), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(15873), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [29571] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 11,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_DQUOTE,
      anon_sym_yield,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [29643] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 11,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [29714] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 10,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_DQUOTE,
      anon_sym_yield,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [29785] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2577), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 10,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      anon_sym_DQUOTE,
      anon_sym_yield,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [29856] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15922), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    ACTIONS(5114), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(2578), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [29981] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 11,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [30052] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5118), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2580), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [30176] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5120), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2581), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [30300] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5122), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2582), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [30424] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5124), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2583), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [30548] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5126), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2584), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [30672] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5128), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2585), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [30796] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5130), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2586), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [30920] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5132), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2587), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [31044] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5134), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2588), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [31168] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5136), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2589), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [31292] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5138), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2590), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [31416] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5140), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2591), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [31540] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5142), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2592), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [31664] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5144), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2593), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [31788] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5146), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2594), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [31912] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5148), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2595), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [32036] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5150), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2596), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [32160] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5152), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2597), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [32284] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5154), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2598), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [32408] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5156), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2599), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [32532] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5158), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2600), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [32656] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5160), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2601), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [32780] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5162), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2602), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [32904] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5164), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2603), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [33028] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5166), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2604), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [33152] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5168), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2605), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [33276] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5170), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2606), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [33400] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5172), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2607), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [33524] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5174), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2608), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [33648] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5176), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2609), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [33772] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5178), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2610), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [33896] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5180), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2611), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [34020] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5182), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2612), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [34144] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5184), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2613), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [34268] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5186), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2614), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [34392] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5188), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2615), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [34516] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5190), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2616), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [34640] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5192), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2617), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [34764] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5194), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2618), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [34888] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5196), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2619), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [35012] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5198), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2620), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [35136] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5200), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2621), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [35260] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5202), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2622), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [35384] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5204), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2623), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [35508] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5206), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2624), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [35632] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5208), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2625), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [35756] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5210), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2626), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [35880] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5212), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2627), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [36004] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5214), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2628), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [36128] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5216), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2629), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [36252] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5218), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2630), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [36376] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5220), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2631), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [36500] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5222), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2632), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [36624] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5224), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2633), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [36748] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5226), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2634), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [36872] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5228), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2635), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [36996] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5230), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2636), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [37120] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5232), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2637), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [37244] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5234), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2638), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [37368] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5236), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2639), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [37492] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5238), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2640), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [37616] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5240), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2641), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [37740] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5242), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2642), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [37864] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5244), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2643), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [37988] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5246), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2644), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [38112] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5248), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2645), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [38236] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5250), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2646), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [38360] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5252), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2647), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [38484] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5254), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2648), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [38608] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5256), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2649), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [38732] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5258), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2650), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [38856] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5260), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2651), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [38980] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5262), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2652), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [39104] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5264), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2653), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [39228] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5266), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2654), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [39352] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5268), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2655), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [39476] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5270), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2656), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [39600] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5272), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2657), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [39724] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5274), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2658), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [39848] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5276), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2659), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [39972] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5278), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2660), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [40096] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5280), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2661), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [40220] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5282), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2662), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [40344] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5284), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2663), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [40468] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5286), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2664), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [40592] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5288), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2665), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [40716] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5290), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2666), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [40840] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5292), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2667), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [40964] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5294), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2668), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [41088] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5296), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2669), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [41212] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5298), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2670), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [41336] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5300), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2671), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [41460] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5302), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2672), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [41584] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5304), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2673), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [41708] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5306), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2674), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [41832] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5308), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2675), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [41956] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5310), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2676), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [42080] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5312), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2677), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [42204] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5314), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2678), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [42328] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5316), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2679), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [42452] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5318), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2680), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [42576] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5320), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2681), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [42700] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5322), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2682), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [42824] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5324), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2683), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [42948] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5326), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2684), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [43072] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5328), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2685), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [43196] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5330), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2686), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [43320] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5332), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2687), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [43444] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5334), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2688), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [43568] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5336), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2689), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [43692] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5338), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2690), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [43816] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5340), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2691), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [43940] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5342), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2692), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [44064] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5344), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2693), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [44188] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5346), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2694), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [44312] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5348), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2695), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [44436] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5350), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2696), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [44560] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5352), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2697), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [44684] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5354), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2698), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [44808] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5356), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2699), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [44932] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5358), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2700), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [45056] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5360), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2701), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [45180] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5362), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2702), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [45304] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5364), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2703), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [45428] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5366), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2704), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [45552] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5368), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2705), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [45676] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5370), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2706), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [45800] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5372), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2707), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [45924] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5374), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2708), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [46048] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5376), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2709), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [46172] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5378), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2710), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [46296] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5380), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2711), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [46420] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5382), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2712), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [46544] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5384), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2713), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [46668] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5386), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2714), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [46792] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5388), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2715), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [46916] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5390), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2716), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [47040] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5392), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2717), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [47164] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5394), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2718), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [47288] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5396), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2719), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [47412] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5398), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2720), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [47536] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5400), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2721), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [47660] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5402), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2722), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [47784] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5404), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2723), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [47908] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5406), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2724), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [48032] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5408), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2725), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [48156] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5410), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2726), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [48280] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5412), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2727), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [48404] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5414), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2728), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [48528] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5416), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2729), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [48652] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5418), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2730), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [48776] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5420), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2731), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [48900] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5422), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2732), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [49024] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5424), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2733), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [49148] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5426), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2734), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [49272] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5428), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2735), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [49396] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5430), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2736), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [49520] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5432), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2737), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [49644] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5434), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2738), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [49768] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5436), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2739), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [49892] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5438), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2740), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [50016] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5440), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2741), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [50140] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5442), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2742), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [50264] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5444), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2743), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [50388] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5446), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2744), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [50512] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5448), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2745), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [50636] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5450), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2746), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [50760] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5452), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2747), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [50884] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5454), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2748), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [51008] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5456), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2749), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [51132] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5458), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2750), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [51256] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5460), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2751), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [51380] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5462), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2752), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [51504] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5464), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2753), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [51628] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5466), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2754), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [51752] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5468), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2755), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [51876] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5470), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2756), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [52000] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5472), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2757), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [52124] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5474), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2758), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [52248] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5476), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2759), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [52372] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5478), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2760), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [52496] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5480), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2761), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [52620] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5482), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2762), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [52744] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5484), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2763), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [52868] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5486), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2764), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [52992] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5488), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2765), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [53116] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5490), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2766), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [53240] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5492), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2767), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [53364] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5494), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2768), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [53488] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5496), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2769), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [53612] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5498), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2770), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [53736] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5500), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2771), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [53860] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5502), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2772), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [53984] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5504), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2773), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [54108] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5506), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2774), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [54232] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5508), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2775), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [54356] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5510), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2776), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [54480] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5512), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2777), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [54604] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5514), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2778), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [54728] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5516), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2779), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [54852] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5518), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2780), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [54976] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5520), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2781), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [55100] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5522), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2782), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [55224] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5524), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2783), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [55348] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5526), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2784), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [55472] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5528), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2785), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [55596] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5530), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2786), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [55720] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5532), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2787), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [55844] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5534), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2788), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [55968] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5536), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2789), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [56092] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5538), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2790), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [56216] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5540), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2791), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [56340] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5542), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2792), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [56464] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5544), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2793), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [56588] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5546), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2794), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [56712] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5548), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2795), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [56836] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5550), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2796), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [56960] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5552), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2797), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [57084] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5554), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2798), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [57208] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5556), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2799), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [57332] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5558), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2800), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [57456] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5560), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2801), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [57580] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5562), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2802), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [57704] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5564), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2803), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [57828] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5566), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2804), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [57952] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5568), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2805), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [58076] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5570), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2806), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [58200] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5572), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2807), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [58324] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5574), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2808), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [58448] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5576), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2809), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [58572] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5578), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2810), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [58696] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5580), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2811), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [58820] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5582), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2812), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [58944] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5584), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2813), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [59068] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5586), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2814), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [59192] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5588), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2815), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [59316] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5590), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2816), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [59440] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5592), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2817), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [59564] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5594), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2818), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [59688] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5596), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2819), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [59812] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5598), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2820), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [59936] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5600), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2821), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [60060] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5602), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2822), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [60184] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5604), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2823), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [60308] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5606), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2824), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [60432] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5608), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2825), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [60556] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5610), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2826), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [60680] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5612), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2827), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [60804] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5614), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2828), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [60928] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5616), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2829), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [61052] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5618), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2830), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [61176] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5620), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2831), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [61300] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5622), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2832), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [61424] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5624), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2833), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [61548] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5626), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2834), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [61672] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5628), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2835), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [61796] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5630), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2836), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [61920] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5632), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2837), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [62044] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5634), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2838), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [62168] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5636), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2839), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [62292] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5638), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2840), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [62416] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5640), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2841), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [62540] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5642), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2842), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [62664] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5644), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2843), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [62788] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5646), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2844), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [62912] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5648), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2845), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [63036] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5650), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2846), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [63160] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5652), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2847), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [63284] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5654), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2848), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [63408] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5656), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2849), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [63532] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5658), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2850), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [63656] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5660), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2851), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [63780] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5662), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2852), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [63904] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5664), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2853), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [64028] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5666), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2854), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [64152] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5668), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2855), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [64276] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5670), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2856), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [64400] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5672), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2857), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [64524] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5674), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2858), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [64648] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5676), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2859), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [64772] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5678), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2860), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [64896] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5680), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2861), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [65020] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5682), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2862), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [65144] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5684), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2863), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [65268] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5686), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2864), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [65392] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5688), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2865), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [65516] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5690), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2866), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [65640] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5692), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2867), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [65764] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5694), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2868), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [65888] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5696), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2869), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [66012] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5698), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2870), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [66136] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5700), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2871), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [66260] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5702), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2872), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [66384] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5704), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2873), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [66508] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5706), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2874), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [66632] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5708), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2875), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [66756] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5710), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2876), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [66880] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5712), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2877), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [67004] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5714), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2878), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [67128] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5716), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2879), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [67252] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5718), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2880), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [67376] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5720), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2881), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [67500] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5722), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2882), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [67624] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5724), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2883), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [67748] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5726), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2884), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [67872] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5728), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2885), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [67996] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5730), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2886), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [68120] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5732), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2887), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [68244] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5734), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2888), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [68368] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5736), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2889), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [68492] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5738), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2890), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [68616] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5740), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2891), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [68740] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5742), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2892), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [68864] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5744), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2893), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [68988] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5746), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2894), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [69112] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5748), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2895), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [69236] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2896), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 10,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [69306] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5750), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2897), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [69430] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5752), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2898), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [69554] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5754), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2899), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [69678] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5756), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2900), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [69802] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5758), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2901), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [69926] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5760), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2902), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [70050] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5762), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2903), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [70174] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5764), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2904), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [70298] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5766), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2905), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [70422] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5768), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2906), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [70546] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5770), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2907), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [70670] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5772), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2908), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [70794] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5774), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2909), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [70918] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5776), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2910), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [71042] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5778), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2911), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [71166] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5780), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2912), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [71290] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5782), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2913), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [71414] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5784), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2914), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [71538] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5786), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2915), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [71662] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5788), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2916), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [71786] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5790), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2917), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [71910] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5792), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2918), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [72034] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5794), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2919), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [72158] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5796), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2920), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [72282] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5798), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2921), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [72406] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5800), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2922), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [72530] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5802), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2923), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [72654] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5804), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2924), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [72778] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5806), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2925), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [72902] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 10,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [72972] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5808), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2927), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [73096] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5810), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2928), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [73220] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5812), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2929), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [73344] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5814), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2930), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [73468] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5816), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2931), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [73592] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5818), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2932), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [73716] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5820), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2933), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [73840] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5822), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2934), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [73964] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5824), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2935), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [74088] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5826), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2936), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [74212] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5828), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2937), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [74336] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5830), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2938), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [74460] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5832), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2939), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [74584] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5834), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2940), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [74708] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5836), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2941), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [74832] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5838), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2942), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [74956] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5840), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2943), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [75080] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5842), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2944), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [75204] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5844), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2945), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [75328] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5846), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2946), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [75452] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5848), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2947), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [75576] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5850), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2948), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [75700] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5852), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2949), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [75824] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5854), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2950), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [75948] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5856), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2951), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [76072] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5858), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2952), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [76196] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5860), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2953), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [76320] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5862), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2954), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [76444] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5864), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2955), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [76568] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5866), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2956), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [76692] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5868), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2957), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [76816] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5870), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2958), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [76940] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5872), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2959), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [77064] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5874), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2960), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [77188] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5876), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2961), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [77312] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5878), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2962), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [77436] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5880), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2963), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [77560] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5882), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2964), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [77684] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2965), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 10,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [77754] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5884), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2966), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [77878] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5886), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2967), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [78002] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5888), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2968), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [78126] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5890), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2969), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [78250] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5892), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2970), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [78374] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5894), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2971), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [78498] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5896), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2972), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [78622] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5898), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2973), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [78746] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5900), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2974), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [78870] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5902), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2975), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [78994] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5904), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2976), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [79118] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5906), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2977), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [79242] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5908), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2978), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [79366] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5910), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2979), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [79490] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5912), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2980), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [79614] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5914), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2981), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [79738] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5916), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2982), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [79862] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5918), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2983), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [79986] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5920), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2984), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [80110] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5922), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2985), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [80234] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5924), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2986), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [80358] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5926), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2987), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [80482] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5928), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2988), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [80606] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5930), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2989), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [80730] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5932), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2990), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [80854] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5934), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2991), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [80978] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2992), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 10,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [81048] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5936), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2993), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [81172] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5938), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2994), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [81296] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5940), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2995), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [81420] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5942), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2996), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [81544] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5944), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2997), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [81668] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5946), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2998), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [81792] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5948), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2999), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [81916] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5950), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3000), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [82040] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5952), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3001), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [82164] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5954), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3002), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [82288] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5956), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3003), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [82412] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5958), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3004), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [82536] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5960), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3005), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [82660] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5962), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3006), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [82784] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5964), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3007), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [82908] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5966), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3008), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [83032] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5968), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3009), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [83156] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5970), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3010), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [83280] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5972), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3011), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [83404] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5974), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3012), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [83528] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5976), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3013), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [83652] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5978), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3014), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [83776] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5980), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3015), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [83900] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5982), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3016), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [84024] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5984), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3017), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [84148] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5986), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3018), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [84272] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5988), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3019), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [84396] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5990), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3020), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [84520] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5992), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3021), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [84644] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5994), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3022), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [84768] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5996), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3023), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [84892] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(5998), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3024), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [85016] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6000), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3025), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [85140] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6002), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3026), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [85264] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6004), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3027), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [85388] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6006), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3028), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [85512] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6008), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3029), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [85636] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6010), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3030), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [85760] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6012), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3031), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [85884] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6014), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3032), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [86008] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6016), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3033), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [86132] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6018), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3034), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [86256] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6020), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3035), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [86380] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6022), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3036), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [86504] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6024), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3037), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [86628] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6026), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3038), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [86752] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6028), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3039), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [86876] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6030), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3040), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [87000] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6032), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3041), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [87124] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6034), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3042), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [87248] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6036), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3043), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [87372] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6038), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3044), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [87496] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6040), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3045), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [87620] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6042), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3046), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [87744] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6044), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3047), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [87868] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6046), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3048), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [87992] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6048), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3049), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [88116] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6050), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3050), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [88240] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6052), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3051), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [88364] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6054), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3052), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [88488] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6056), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3053), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [88612] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6058), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3054), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [88736] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6060), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3055), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [88860] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6062), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3056), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [88984] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6064), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3057), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [89108] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6066), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3058), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [89232] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6068), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3059), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [89356] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6070), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3060), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [89480] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6072), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3061), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [89604] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6074), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3062), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [89728] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6076), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3063), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [89852] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6078), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3064), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [89976] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6080), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3065), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [90100] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6082), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3066), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [90224] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6084), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3067), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [90348] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6086), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3068), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [90472] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6088), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3069), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [90596] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6090), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3070), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [90720] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6092), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3071), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [90844] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6094), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3072), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [90968] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6096), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3073), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [91092] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6098), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3074), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [91216] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6100), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3075), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [91340] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6102), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3076), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [91464] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6104), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3077), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [91588] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6106), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3078), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [91712] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6108), 1,
      anon_sym_RPAREN,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3079), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [91836] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6110), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3080), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [91960] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6112), 1,
      anon_sym_RBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3081), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [92084] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17635), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3082), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [92205] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(8560), 1,
      sym__type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3083), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [92326] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1304), 1,
      sym_integer_literal,
    ACTIONS(6114), 1,
      sym__alpha_identifier,
    ACTIONS(6116), 1,
      anon_sym_COLON,
    ACTIONS(6118), 1,
      anon_sym_LBRACE,
    ACTIONS(6120), 1,
      anon_sym__,
    ACTIONS(6122), 1,
      anon_sym_LBRACK,
    ACTIONS(6126), 1,
      anon_sym_LPAREN,
    ACTIONS(6128), 1,
      sym__backquoted_id,
    ACTIONS(6130), 1,
      sym_operator_identifier,
    STATE(4976), 1,
      sym__annotated_type,
    STATE(5030), 1,
      sym__simple_type,
    STATE(5135), 1,
      sym_identifier,
    STATE(5193), 1,
      sym__soft_identifier,
    STATE(7769), 1,
      sym_annotated_type,
    STATE(10265), 1,
      sym_literal_type,
    STATE(10325), 1,
      sym__non_null_literal,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(12873), 1,
      sym_template_body,
    STATE(12924), 1,
      sym__type,
    STATE(15033), 1,
      sym_parameter_types,
    STATE(17257), 1,
      sym_stable_identifier,
    ACTIONS(1306), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1308), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1312), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3084), 2,
      sym_comment,
      sym_block_comment,
    STATE(7638), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7829), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9590), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12811), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6124), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5886), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [92447] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15409), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3085), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [92568] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6134), 1,
      anon_sym_COLON,
    ACTIONS(6136), 1,
      anon_sym_LBRACE,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6140), 1,
      anon_sym_LBRACK,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6150), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(8699), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(11171), 1,
      sym__non_null_literal,
    STATE(11172), 1,
      sym_literal_type,
    STATE(11576), 1,
      sym_template_body,
    STATE(11656), 1,
      sym__type,
    STATE(12342), 1,
      sym__infix_type_choice,
    STATE(15615), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3086), 2,
      sym_comment,
      sym_block_comment,
    STATE(11119), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11526), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11592), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [92689] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17317), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3087), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [92810] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17319), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3088), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [92931] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(11878), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3089), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [93052] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15621), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3090), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [93173] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6158), 1,
      anon_sym_COLON,
    ACTIONS(6160), 1,
      anon_sym_LBRACE,
    ACTIONS(6162), 1,
      anon_sym_LBRACK,
    ACTIONS(6164), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(7387), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(10986), 1,
      sym__non_null_literal,
    STATE(10988), 1,
      sym_literal_type,
    STATE(11158), 1,
      sym_template_body,
    STATE(11969), 1,
      sym__type,
    STATE(12334), 1,
      sym__infix_type_choice,
    STATE(15319), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3091), 2,
      sym_comment,
      sym_block_comment,
    STATE(10591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11237), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11264), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [93294] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6172), 1,
      anon_sym_LBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12386), 1,
      sym__infix_type_choice,
    STATE(15018), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17358), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3092), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [93415] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6158), 1,
      anon_sym_COLON,
    ACTIONS(6160), 1,
      anon_sym_LBRACE,
    ACTIONS(6162), 1,
      anon_sym_LBRACK,
    ACTIONS(6164), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(7387), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(10986), 1,
      sym__non_null_literal,
    STATE(10988), 1,
      sym_literal_type,
    STATE(11158), 1,
      sym_template_body,
    STATE(11970), 1,
      sym__type,
    STATE(12334), 1,
      sym__infix_type_choice,
    STATE(15319), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3093), 2,
      sym_comment,
      sym_block_comment,
    STATE(10591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11237), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11264), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [93536] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6172), 1,
      anon_sym_LBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12386), 1,
      sym__infix_type_choice,
    STATE(15018), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17363), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3094), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [93657] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4602), 1,
      sym__alpha_identifier,
    ACTIONS(4604), 1,
      anon_sym_COLON,
    ACTIONS(4606), 1,
      anon_sym_LBRACE,
    ACTIONS(4608), 1,
      anon_sym__,
    ACTIONS(4612), 1,
      anon_sym_LBRACK,
    ACTIONS(4620), 1,
      sym__backquoted_id,
    ACTIONS(4624), 1,
      sym_integer_literal,
    ACTIONS(6174), 1,
      anon_sym_LPAREN,
    ACTIONS(6176), 1,
      sym_operator_identifier,
    STATE(4990), 1,
      sym__annotated_type,
    STATE(5035), 1,
      sym__simple_type,
    STATE(5163), 1,
      sym_identifier,
    STATE(5195), 1,
      sym__soft_identifier,
    STATE(8014), 1,
      sym_annotated_type,
    STATE(10209), 1,
      sym__non_null_literal,
    STATE(10287), 1,
      sym_literal_type,
    STATE(12549), 1,
      sym__infix_type_choice,
    STATE(13069), 1,
      sym__type,
    STATE(13150), 1,
      sym_template_body,
    STATE(15291), 1,
      sym_parameter_types,
    STATE(17269), 1,
      sym_stable_identifier,
    ACTIONS(4626), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4628), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4632), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3095), 2,
      sym_comment,
      sym_block_comment,
    STATE(9383), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10251), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13125), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13262), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5955), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [93778] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6182), 1,
      anon_sym_LBRACK,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(7246), 1,
      sym__annotated_type,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12466), 1,
      sym__infix_type_choice,
    STATE(14099), 1,
      sym__type,
    STATE(15109), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3096), 2,
      sym_comment,
      sym_block_comment,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [93899] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1396), 1,
      sym_integer_literal,
    ACTIONS(6192), 1,
      sym__alpha_identifier,
    ACTIONS(6194), 1,
      anon_sym_COLON,
    ACTIONS(6196), 1,
      anon_sym_LBRACE,
    ACTIONS(6198), 1,
      anon_sym__,
    ACTIONS(6200), 1,
      anon_sym_LBRACK,
    ACTIONS(6204), 1,
      anon_sym_LPAREN,
    ACTIONS(6206), 1,
      sym__backquoted_id,
    ACTIONS(6208), 1,
      sym_operator_identifier,
    STATE(5297), 1,
      sym__annotated_type,
    STATE(5313), 1,
      sym__simple_type,
    STATE(5503), 1,
      sym_identifier,
    STATE(5516), 1,
      sym__soft_identifier,
    STATE(8264), 1,
      sym_annotated_type,
    STATE(10605), 1,
      sym_literal_type,
    STATE(10642), 1,
      sym__non_null_literal,
    STATE(12489), 1,
      sym__infix_type_choice,
    STATE(13138), 1,
      sym_template_body,
    STATE(13284), 1,
      sym__type,
    STATE(15023), 1,
      sym_parameter_types,
    STATE(17035), 1,
      sym_stable_identifier,
    ACTIONS(1398), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1400), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1404), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3097), 2,
      sym_comment,
      sym_block_comment,
    STATE(8355), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8445), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10056), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13212), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6202), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6134), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [94020] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4602), 1,
      sym__alpha_identifier,
    ACTIONS(4604), 1,
      anon_sym_COLON,
    ACTIONS(4606), 1,
      anon_sym_LBRACE,
    ACTIONS(4608), 1,
      anon_sym__,
    ACTIONS(4612), 1,
      anon_sym_LBRACK,
    ACTIONS(4620), 1,
      sym__backquoted_id,
    ACTIONS(4624), 1,
      sym_integer_literal,
    ACTIONS(6174), 1,
      anon_sym_LPAREN,
    ACTIONS(6176), 1,
      sym_operator_identifier,
    STATE(4990), 1,
      sym__annotated_type,
    STATE(5035), 1,
      sym__simple_type,
    STATE(5163), 1,
      sym_identifier,
    STATE(5195), 1,
      sym__soft_identifier,
    STATE(8014), 1,
      sym_annotated_type,
    STATE(10209), 1,
      sym__non_null_literal,
    STATE(10287), 1,
      sym_literal_type,
    STATE(12549), 1,
      sym__infix_type_choice,
    STATE(13145), 1,
      sym__type,
    STATE(13150), 1,
      sym_template_body,
    STATE(15291), 1,
      sym_parameter_types,
    STATE(17269), 1,
      sym_stable_identifier,
    ACTIONS(4626), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4628), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4632), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3098), 2,
      sym_comment,
      sym_block_comment,
    STATE(9383), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10251), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13125), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13262), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5955), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [94141] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4602), 1,
      sym__alpha_identifier,
    ACTIONS(4604), 1,
      anon_sym_COLON,
    ACTIONS(4606), 1,
      anon_sym_LBRACE,
    ACTIONS(4608), 1,
      anon_sym__,
    ACTIONS(4612), 1,
      anon_sym_LBRACK,
    ACTIONS(4620), 1,
      sym__backquoted_id,
    ACTIONS(4624), 1,
      sym_integer_literal,
    ACTIONS(6174), 1,
      anon_sym_LPAREN,
    ACTIONS(6176), 1,
      sym_operator_identifier,
    STATE(4990), 1,
      sym__annotated_type,
    STATE(5035), 1,
      sym__simple_type,
    STATE(5163), 1,
      sym_identifier,
    STATE(5195), 1,
      sym__soft_identifier,
    STATE(8014), 1,
      sym_annotated_type,
    STATE(10209), 1,
      sym__non_null_literal,
    STATE(10287), 1,
      sym_literal_type,
    STATE(12549), 1,
      sym__infix_type_choice,
    STATE(13150), 1,
      sym_template_body,
    STATE(13154), 1,
      sym__type,
    STATE(15291), 1,
      sym_parameter_types,
    STATE(17269), 1,
      sym_stable_identifier,
    ACTIONS(4626), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4628), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4632), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3099), 2,
      sym_comment,
      sym_block_comment,
    STATE(9383), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10251), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13125), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13262), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5955), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [94262] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15841), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3100), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [94383] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4602), 1,
      sym__alpha_identifier,
    ACTIONS(4604), 1,
      anon_sym_COLON,
    ACTIONS(4606), 1,
      anon_sym_LBRACE,
    ACTIONS(4608), 1,
      anon_sym__,
    ACTIONS(4612), 1,
      anon_sym_LBRACK,
    ACTIONS(4620), 1,
      sym__backquoted_id,
    ACTIONS(4624), 1,
      sym_integer_literal,
    ACTIONS(6174), 1,
      anon_sym_LPAREN,
    ACTIONS(6176), 1,
      sym_operator_identifier,
    STATE(4990), 1,
      sym__annotated_type,
    STATE(5035), 1,
      sym__simple_type,
    STATE(5163), 1,
      sym_identifier,
    STATE(5195), 1,
      sym__soft_identifier,
    STATE(8014), 1,
      sym_annotated_type,
    STATE(10209), 1,
      sym__non_null_literal,
    STATE(10287), 1,
      sym_literal_type,
    STATE(12549), 1,
      sym__infix_type_choice,
    STATE(13150), 1,
      sym_template_body,
    STATE(13156), 1,
      sym__type,
    STATE(15291), 1,
      sym_parameter_types,
    STATE(17269), 1,
      sym_stable_identifier,
    ACTIONS(4626), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4628), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4632), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3101), 2,
      sym_comment,
      sym_block_comment,
    STATE(9383), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10251), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13125), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13262), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5955), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [94504] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16407), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3102), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [94625] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(11890), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3103), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [94746] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(16900), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3104), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [94867] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(11898), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3105), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [94988] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15844), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3106), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [95109] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(11899), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3107), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [95230] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4602), 1,
      sym__alpha_identifier,
    ACTIONS(4604), 1,
      anon_sym_COLON,
    ACTIONS(4606), 1,
      anon_sym_LBRACE,
    ACTIONS(4608), 1,
      anon_sym__,
    ACTIONS(4612), 1,
      anon_sym_LBRACK,
    ACTIONS(4620), 1,
      sym__backquoted_id,
    ACTIONS(4624), 1,
      sym_integer_literal,
    ACTIONS(6174), 1,
      anon_sym_LPAREN,
    ACTIONS(6176), 1,
      sym_operator_identifier,
    STATE(4990), 1,
      sym__annotated_type,
    STATE(5035), 1,
      sym__simple_type,
    STATE(5163), 1,
      sym_identifier,
    STATE(5195), 1,
      sym__soft_identifier,
    STATE(8014), 1,
      sym_annotated_type,
    STATE(10209), 1,
      sym__non_null_literal,
    STATE(10287), 1,
      sym_literal_type,
    STATE(12549), 1,
      sym__infix_type_choice,
    STATE(13150), 1,
      sym_template_body,
    STATE(13179), 1,
      sym__type,
    STATE(15291), 1,
      sym_parameter_types,
    STATE(17269), 1,
      sym_stable_identifier,
    ACTIONS(4626), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4628), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4632), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3108), 2,
      sym_comment,
      sym_block_comment,
    STATE(9383), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10251), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13125), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13262), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5955), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [95351] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6158), 1,
      anon_sym_COLON,
    ACTIONS(6160), 1,
      anon_sym_LBRACE,
    ACTIONS(6162), 1,
      anon_sym_LBRACK,
    ACTIONS(6164), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(7387), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(10986), 1,
      sym__non_null_literal,
    STATE(10988), 1,
      sym_literal_type,
    STATE(11158), 1,
      sym_template_body,
    STATE(11945), 1,
      sym__type,
    STATE(12334), 1,
      sym__infix_type_choice,
    STATE(15319), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3109), 2,
      sym_comment,
      sym_block_comment,
    STATE(10591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11237), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11264), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [95472] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6172), 1,
      anon_sym_LBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12386), 1,
      sym__infix_type_choice,
    STATE(15018), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17815), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3110), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [95593] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6158), 1,
      anon_sym_COLON,
    ACTIONS(6160), 1,
      anon_sym_LBRACE,
    ACTIONS(6162), 1,
      anon_sym_LBRACK,
    ACTIONS(6164), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(7387), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(10986), 1,
      sym__non_null_literal,
    STATE(10988), 1,
      sym_literal_type,
    STATE(11158), 1,
      sym_template_body,
    STATE(11992), 1,
      sym__type,
    STATE(12334), 1,
      sym__infix_type_choice,
    STATE(15319), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3111), 2,
      sym_comment,
      sym_block_comment,
    STATE(10591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11237), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11264), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [95714] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6172), 1,
      anon_sym_LBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12386), 1,
      sym__infix_type_choice,
    STATE(15018), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17824), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3112), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [95835] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4180), 1,
      anon_sym_LBRACK,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4192), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      anon_sym_LPAREN,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    STATE(5107), 1,
      sym__annotated_type,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__non_null_literal,
    STATE(10653), 1,
      sym_literal_type,
    STATE(11900), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12348), 1,
      sym__infix_type_choice,
    STATE(14887), 1,
      sym_parameter_types,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(4194), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4196), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4200), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3113), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10627), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [95956] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6218), 1,
      anon_sym_LBRACK,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(14374), 1,
      sym__type,
    STATE(15570), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3114), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [96077] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1396), 1,
      sym_integer_literal,
    ACTIONS(6192), 1,
      sym__alpha_identifier,
    ACTIONS(6194), 1,
      anon_sym_COLON,
    ACTIONS(6196), 1,
      anon_sym_LBRACE,
    ACTIONS(6198), 1,
      anon_sym__,
    ACTIONS(6200), 1,
      anon_sym_LBRACK,
    ACTIONS(6204), 1,
      anon_sym_LPAREN,
    ACTIONS(6206), 1,
      sym__backquoted_id,
    ACTIONS(6208), 1,
      sym_operator_identifier,
    STATE(5297), 1,
      sym__annotated_type,
    STATE(5313), 1,
      sym__simple_type,
    STATE(5503), 1,
      sym_identifier,
    STATE(5516), 1,
      sym__soft_identifier,
    STATE(8264), 1,
      sym_annotated_type,
    STATE(10605), 1,
      sym_literal_type,
    STATE(10642), 1,
      sym__non_null_literal,
    STATE(12489), 1,
      sym__infix_type_choice,
    STATE(13138), 1,
      sym_template_body,
    STATE(13628), 1,
      sym__type,
    STATE(15023), 1,
      sym_parameter_types,
    STATE(17035), 1,
      sym_stable_identifier,
    ACTIONS(1398), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1400), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1404), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3115), 2,
      sym_comment,
      sym_block_comment,
    STATE(8355), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8445), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10056), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13212), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6202), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6134), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [96198] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1396), 1,
      sym_integer_literal,
    ACTIONS(6192), 1,
      sym__alpha_identifier,
    ACTIONS(6194), 1,
      anon_sym_COLON,
    ACTIONS(6196), 1,
      anon_sym_LBRACE,
    ACTIONS(6198), 1,
      anon_sym__,
    ACTIONS(6200), 1,
      anon_sym_LBRACK,
    ACTIONS(6204), 1,
      anon_sym_LPAREN,
    ACTIONS(6206), 1,
      sym__backquoted_id,
    ACTIONS(6208), 1,
      sym_operator_identifier,
    STATE(5297), 1,
      sym__annotated_type,
    STATE(5313), 1,
      sym__simple_type,
    STATE(5503), 1,
      sym_identifier,
    STATE(5516), 1,
      sym__soft_identifier,
    STATE(8264), 1,
      sym_annotated_type,
    STATE(10605), 1,
      sym_literal_type,
    STATE(10642), 1,
      sym__non_null_literal,
    STATE(12489), 1,
      sym__infix_type_choice,
    STATE(13138), 1,
      sym_template_body,
    STATE(13311), 1,
      sym__type,
    STATE(15023), 1,
      sym_parameter_types,
    STATE(17035), 1,
      sym_stable_identifier,
    ACTIONS(1398), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1400), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1404), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3116), 2,
      sym_comment,
      sym_block_comment,
    STATE(8355), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8445), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10056), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13212), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6202), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6134), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [96319] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15562), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3117), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [96440] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(8592), 1,
      sym__type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3118), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [96561] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16537), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3119), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [96682] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1360), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(5087), 1,
      sym__simple_type,
    STATE(5218), 1,
      sym__annotated_type,
    STATE(5538), 1,
      sym__soft_identifier,
    STATE(5956), 1,
      sym_identifier,
    STATE(8528), 1,
      sym_annotated_type,
    STATE(10533), 1,
      sym_literal_type,
    STATE(10609), 1,
      sym__non_null_literal,
    STATE(12550), 1,
      sym__infix_type_choice,
    STATE(13069), 1,
      sym__type,
    STATE(13150), 1,
      sym_template_body,
    STATE(15034), 1,
      sym_parameter_types,
    STATE(17275), 1,
      sym_stable_identifier,
    ACTIONS(1362), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1364), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1368), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3120), 2,
      sym_comment,
      sym_block_comment,
    STATE(8206), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8220), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9979), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13262), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6616), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [96803] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17042), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3121), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [96924] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1396), 1,
      sym_integer_literal,
    ACTIONS(6192), 1,
      sym__alpha_identifier,
    ACTIONS(6194), 1,
      anon_sym_COLON,
    ACTIONS(6196), 1,
      anon_sym_LBRACE,
    ACTIONS(6198), 1,
      anon_sym__,
    ACTIONS(6200), 1,
      anon_sym_LBRACK,
    ACTIONS(6204), 1,
      anon_sym_LPAREN,
    ACTIONS(6206), 1,
      sym__backquoted_id,
    ACTIONS(6208), 1,
      sym_operator_identifier,
    STATE(5297), 1,
      sym__annotated_type,
    STATE(5313), 1,
      sym__simple_type,
    STATE(5503), 1,
      sym_identifier,
    STATE(5516), 1,
      sym__soft_identifier,
    STATE(8264), 1,
      sym_annotated_type,
    STATE(10605), 1,
      sym_literal_type,
    STATE(10642), 1,
      sym__non_null_literal,
    STATE(12489), 1,
      sym__infix_type_choice,
    STATE(13138), 1,
      sym_template_body,
    STATE(13314), 1,
      sym__type,
    STATE(15023), 1,
      sym_parameter_types,
    STATE(17035), 1,
      sym_stable_identifier,
    ACTIONS(1398), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1400), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1404), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3122), 2,
      sym_comment,
      sym_block_comment,
    STATE(8355), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8445), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10056), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13212), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6202), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6134), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [97045] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14867), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3123), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [97166] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3124), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 9,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_DQUOTE,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [97235] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1396), 1,
      sym_integer_literal,
    ACTIONS(6192), 1,
      sym__alpha_identifier,
    ACTIONS(6194), 1,
      anon_sym_COLON,
    ACTIONS(6196), 1,
      anon_sym_LBRACE,
    ACTIONS(6198), 1,
      anon_sym__,
    ACTIONS(6200), 1,
      anon_sym_LBRACK,
    ACTIONS(6204), 1,
      anon_sym_LPAREN,
    ACTIONS(6206), 1,
      sym__backquoted_id,
    ACTIONS(6208), 1,
      sym_operator_identifier,
    STATE(5297), 1,
      sym__annotated_type,
    STATE(5313), 1,
      sym__simple_type,
    STATE(5503), 1,
      sym_identifier,
    STATE(5516), 1,
      sym__soft_identifier,
    STATE(8264), 1,
      sym_annotated_type,
    STATE(10605), 1,
      sym_literal_type,
    STATE(10642), 1,
      sym__non_null_literal,
    STATE(12489), 1,
      sym__infix_type_choice,
    STATE(13138), 1,
      sym_template_body,
    STATE(13318), 1,
      sym__type,
    STATE(15023), 1,
      sym_parameter_types,
    STATE(17035), 1,
      sym_stable_identifier,
    ACTIONS(1398), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1400), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1404), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3125), 2,
      sym_comment,
      sym_block_comment,
    STATE(8355), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8445), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10056), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13212), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6202), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6134), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [97356] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1360), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(5087), 1,
      sym__simple_type,
    STATE(5218), 1,
      sym__annotated_type,
    STATE(5538), 1,
      sym__soft_identifier,
    STATE(5956), 1,
      sym_identifier,
    STATE(8528), 1,
      sym_annotated_type,
    STATE(10533), 1,
      sym_literal_type,
    STATE(10609), 1,
      sym__non_null_literal,
    STATE(12550), 1,
      sym__infix_type_choice,
    STATE(13145), 1,
      sym__type,
    STATE(13150), 1,
      sym_template_body,
    STATE(15034), 1,
      sym_parameter_types,
    STATE(17275), 1,
      sym_stable_identifier,
    ACTIONS(1362), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1364), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1368), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3126), 2,
      sym_comment,
      sym_block_comment,
    STATE(8206), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8220), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9979), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13262), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6616), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [97477] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1360), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(5087), 1,
      sym__simple_type,
    STATE(5218), 1,
      sym__annotated_type,
    STATE(5538), 1,
      sym__soft_identifier,
    STATE(5956), 1,
      sym_identifier,
    STATE(8528), 1,
      sym_annotated_type,
    STATE(10533), 1,
      sym_literal_type,
    STATE(10609), 1,
      sym__non_null_literal,
    STATE(12550), 1,
      sym__infix_type_choice,
    STATE(13150), 1,
      sym_template_body,
    STATE(13154), 1,
      sym__type,
    STATE(15034), 1,
      sym_parameter_types,
    STATE(17275), 1,
      sym_stable_identifier,
    ACTIONS(1362), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1364), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1368), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3127), 2,
      sym_comment,
      sym_block_comment,
    STATE(8206), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8220), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9979), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13262), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6616), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [97598] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1360), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(5087), 1,
      sym__simple_type,
    STATE(5218), 1,
      sym__annotated_type,
    STATE(5538), 1,
      sym__soft_identifier,
    STATE(5956), 1,
      sym_identifier,
    STATE(8528), 1,
      sym_annotated_type,
    STATE(10533), 1,
      sym_literal_type,
    STATE(10609), 1,
      sym__non_null_literal,
    STATE(12550), 1,
      sym__infix_type_choice,
    STATE(13150), 1,
      sym_template_body,
    STATE(13156), 1,
      sym__type,
    STATE(15034), 1,
      sym_parameter_types,
    STATE(17275), 1,
      sym_stable_identifier,
    ACTIONS(1362), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1364), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1368), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3128), 2,
      sym_comment,
      sym_block_comment,
    STATE(8206), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8220), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9979), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13262), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6616), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [97719] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1360), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(5087), 1,
      sym__simple_type,
    STATE(5218), 1,
      sym__annotated_type,
    STATE(5538), 1,
      sym__soft_identifier,
    STATE(5956), 1,
      sym_identifier,
    STATE(8528), 1,
      sym_annotated_type,
    STATE(10533), 1,
      sym_literal_type,
    STATE(10609), 1,
      sym__non_null_literal,
    STATE(12550), 1,
      sym__infix_type_choice,
    STATE(13150), 1,
      sym_template_body,
    STATE(13179), 1,
      sym__type,
    STATE(15034), 1,
      sym_parameter_types,
    STATE(17275), 1,
      sym_stable_identifier,
    ACTIONS(1362), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1364), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1368), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3129), 2,
      sym_comment,
      sym_block_comment,
    STATE(8206), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8220), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9979), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13262), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6616), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [97840] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15566), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3130), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [97961] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6182), 1,
      anon_sym_LBRACK,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(7246), 1,
      sym__annotated_type,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12466), 1,
      sym__infix_type_choice,
    STATE(14124), 1,
      sym__type,
    STATE(15109), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3131), 2,
      sym_comment,
      sym_block_comment,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [98082] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17665), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3132), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [98203] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15817), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3133), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [98324] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4210), 1,
      sym__alpha_identifier,
    ACTIONS(4212), 1,
      anon_sym_COLON,
    ACTIONS(4214), 1,
      anon_sym_LBRACE,
    ACTIONS(4216), 1,
      anon_sym__,
    ACTIONS(4220), 1,
      anon_sym_LBRACK,
    ACTIONS(4228), 1,
      sym__backquoted_id,
    ACTIONS(4232), 1,
      sym_integer_literal,
    ACTIONS(6246), 1,
      anon_sym_LPAREN,
    ACTIONS(6248), 1,
      sym_operator_identifier,
    STATE(5545), 1,
      sym__annotated_type,
    STATE(5546), 1,
      sym__simple_type,
    STATE(6312), 1,
      sym_identifier,
    STATE(6658), 1,
      sym__soft_identifier,
    STATE(8878), 1,
      sym_annotated_type,
    STATE(10706), 1,
      sym__non_null_literal,
    STATE(10736), 1,
      sym_literal_type,
    STATE(11501), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12350), 1,
      sym__infix_type_choice,
    STATE(15564), 1,
      sym_parameter_types,
    STATE(16208), 1,
      sym_stable_identifier,
    ACTIONS(4234), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4236), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4240), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3134), 2,
      sym_comment,
      sym_block_comment,
    STATE(10225), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10825), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11717), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4222), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7079), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [98445] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6250), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(12686), 1,
      sym__type,
    STATE(15060), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3135), 2,
      sym_comment,
      sym_block_comment,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [98566] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6158), 1,
      anon_sym_COLON,
    ACTIONS(6160), 1,
      anon_sym_LBRACE,
    ACTIONS(6162), 1,
      anon_sym_LBRACK,
    ACTIONS(6164), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(7387), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(10986), 1,
      sym__non_null_literal,
    STATE(10988), 1,
      sym_literal_type,
    STATE(11138), 1,
      sym__type,
    STATE(11158), 1,
      sym_template_body,
    STATE(12334), 1,
      sym__infix_type_choice,
    STATE(15319), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3136), 2,
      sym_comment,
      sym_block_comment,
    STATE(10591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11237), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11264), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [98687] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15112), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3137), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [98808] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6252), 1,
      sym__alpha_identifier,
    ACTIONS(6254), 1,
      anon_sym_COLON,
    ACTIONS(6256), 1,
      anon_sym_LBRACE,
    ACTIONS(6258), 1,
      anon_sym__,
    ACTIONS(6260), 1,
      anon_sym_LBRACK,
    ACTIONS(6264), 1,
      anon_sym_LPAREN,
    ACTIONS(6266), 1,
      sym__backquoted_id,
    ACTIONS(6268), 1,
      sym_operator_identifier,
    ACTIONS(6270), 1,
      sym_integer_literal,
    STATE(5450), 1,
      sym__simple_type,
    STATE(5492), 1,
      sym__soft_identifier,
    STATE(5705), 1,
      sym_identifier,
    STATE(5911), 1,
      sym__annotated_type,
    STATE(8761), 1,
      sym_annotated_type,
    STATE(10563), 1,
      sym__non_null_literal,
    STATE(10613), 1,
      sym_literal_type,
    STATE(10671), 1,
      sym_template_body,
    STATE(10938), 1,
      sym__type,
    STATE(12469), 1,
      sym__infix_type_choice,
    STATE(15433), 1,
      sym_parameter_types,
    STATE(16941), 1,
      sym_stable_identifier,
    ACTIONS(6272), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6274), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6276), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3138), 2,
      sym_comment,
      sym_block_comment,
    STATE(9865), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10635), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10850), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10815), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6262), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6211), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [98929] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17188), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3139), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [99050] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6252), 1,
      sym__alpha_identifier,
    ACTIONS(6254), 1,
      anon_sym_COLON,
    ACTIONS(6256), 1,
      anon_sym_LBRACE,
    ACTIONS(6258), 1,
      anon_sym__,
    ACTIONS(6260), 1,
      anon_sym_LBRACK,
    ACTIONS(6264), 1,
      anon_sym_LPAREN,
    ACTIONS(6266), 1,
      sym__backquoted_id,
    ACTIONS(6268), 1,
      sym_operator_identifier,
    ACTIONS(6270), 1,
      sym_integer_literal,
    STATE(5450), 1,
      sym__simple_type,
    STATE(5492), 1,
      sym__soft_identifier,
    STATE(5705), 1,
      sym_identifier,
    STATE(5911), 1,
      sym__annotated_type,
    STATE(8761), 1,
      sym_annotated_type,
    STATE(10563), 1,
      sym__non_null_literal,
    STATE(10613), 1,
      sym_literal_type,
    STATE(10671), 1,
      sym_template_body,
    STATE(10940), 1,
      sym__type,
    STATE(12469), 1,
      sym__infix_type_choice,
    STATE(15433), 1,
      sym_parameter_types,
    STATE(16941), 1,
      sym_stable_identifier,
    ACTIONS(6272), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6274), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6276), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3140), 2,
      sym_comment,
      sym_block_comment,
    STATE(9865), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10635), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10850), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10815), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6262), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6211), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [99171] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17286), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3141), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [99292] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15233), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3142), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [99413] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1396), 1,
      sym_integer_literal,
    ACTIONS(6192), 1,
      sym__alpha_identifier,
    ACTIONS(6194), 1,
      anon_sym_COLON,
    ACTIONS(6196), 1,
      anon_sym_LBRACE,
    ACTIONS(6198), 1,
      anon_sym__,
    ACTIONS(6200), 1,
      anon_sym_LBRACK,
    ACTIONS(6204), 1,
      anon_sym_LPAREN,
    ACTIONS(6206), 1,
      sym__backquoted_id,
    ACTIONS(6208), 1,
      sym_operator_identifier,
    STATE(5297), 1,
      sym__annotated_type,
    STATE(5313), 1,
      sym__simple_type,
    STATE(5503), 1,
      sym_identifier,
    STATE(5516), 1,
      sym__soft_identifier,
    STATE(8264), 1,
      sym_annotated_type,
    STATE(10605), 1,
      sym_literal_type,
    STATE(10642), 1,
      sym__non_null_literal,
    STATE(12489), 1,
      sym__infix_type_choice,
    STATE(13138), 1,
      sym_template_body,
    STATE(13158), 1,
      sym__type,
    STATE(15023), 1,
      sym_parameter_types,
    STATE(17035), 1,
      sym_stable_identifier,
    ACTIONS(1398), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1400), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1404), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3143), 2,
      sym_comment,
      sym_block_comment,
    STATE(8355), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8445), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10056), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13212), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6202), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6134), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [99534] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6252), 1,
      sym__alpha_identifier,
    ACTIONS(6254), 1,
      anon_sym_COLON,
    ACTIONS(6256), 1,
      anon_sym_LBRACE,
    ACTIONS(6258), 1,
      anon_sym__,
    ACTIONS(6260), 1,
      anon_sym_LBRACK,
    ACTIONS(6264), 1,
      anon_sym_LPAREN,
    ACTIONS(6266), 1,
      sym__backquoted_id,
    ACTIONS(6268), 1,
      sym_operator_identifier,
    ACTIONS(6270), 1,
      sym_integer_literal,
    STATE(5450), 1,
      sym__simple_type,
    STATE(5492), 1,
      sym__soft_identifier,
    STATE(5705), 1,
      sym_identifier,
    STATE(5911), 1,
      sym__annotated_type,
    STATE(8761), 1,
      sym_annotated_type,
    STATE(10563), 1,
      sym__non_null_literal,
    STATE(10613), 1,
      sym_literal_type,
    STATE(10671), 1,
      sym_template_body,
    STATE(10943), 1,
      sym__type,
    STATE(12469), 1,
      sym__infix_type_choice,
    STATE(15433), 1,
      sym_parameter_types,
    STATE(16941), 1,
      sym_stable_identifier,
    ACTIONS(6272), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6274), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6276), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3144), 2,
      sym_comment,
      sym_block_comment,
    STATE(9865), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10635), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10850), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10815), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6262), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6211), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [99655] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4210), 1,
      sym__alpha_identifier,
    ACTIONS(4212), 1,
      anon_sym_COLON,
    ACTIONS(4214), 1,
      anon_sym_LBRACE,
    ACTIONS(4216), 1,
      anon_sym__,
    ACTIONS(4220), 1,
      anon_sym_LBRACK,
    ACTIONS(4228), 1,
      sym__backquoted_id,
    ACTIONS(4232), 1,
      sym_integer_literal,
    ACTIONS(6246), 1,
      anon_sym_LPAREN,
    ACTIONS(6248), 1,
      sym_operator_identifier,
    STATE(5545), 1,
      sym__annotated_type,
    STATE(5546), 1,
      sym__simple_type,
    STATE(6312), 1,
      sym_identifier,
    STATE(6658), 1,
      sym__soft_identifier,
    STATE(8878), 1,
      sym_annotated_type,
    STATE(10706), 1,
      sym__non_null_literal,
    STATE(10736), 1,
      sym_literal_type,
    STATE(11533), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12350), 1,
      sym__infix_type_choice,
    STATE(15564), 1,
      sym_parameter_types,
    STATE(16208), 1,
      sym_stable_identifier,
    ACTIONS(4234), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4236), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4240), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3145), 2,
      sym_comment,
      sym_block_comment,
    STATE(10225), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10825), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11717), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4222), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7079), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [99776] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4210), 1,
      sym__alpha_identifier,
    ACTIONS(4212), 1,
      anon_sym_COLON,
    ACTIONS(4214), 1,
      anon_sym_LBRACE,
    ACTIONS(4216), 1,
      anon_sym__,
    ACTIONS(4220), 1,
      anon_sym_LBRACK,
    ACTIONS(4228), 1,
      sym__backquoted_id,
    ACTIONS(4232), 1,
      sym_integer_literal,
    ACTIONS(6246), 1,
      anon_sym_LPAREN,
    ACTIONS(6248), 1,
      sym_operator_identifier,
    STATE(5545), 1,
      sym__annotated_type,
    STATE(5546), 1,
      sym__simple_type,
    STATE(6312), 1,
      sym_identifier,
    STATE(6658), 1,
      sym__soft_identifier,
    STATE(8878), 1,
      sym_annotated_type,
    STATE(10706), 1,
      sym__non_null_literal,
    STATE(10736), 1,
      sym_literal_type,
    STATE(11536), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12350), 1,
      sym__infix_type_choice,
    STATE(15564), 1,
      sym_parameter_types,
    STATE(16208), 1,
      sym_stable_identifier,
    ACTIONS(4234), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4236), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4240), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3146), 2,
      sym_comment,
      sym_block_comment,
    STATE(10225), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10825), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11717), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4222), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7079), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [99897] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4210), 1,
      sym__alpha_identifier,
    ACTIONS(4212), 1,
      anon_sym_COLON,
    ACTIONS(4214), 1,
      anon_sym_LBRACE,
    ACTIONS(4216), 1,
      anon_sym__,
    ACTIONS(4220), 1,
      anon_sym_LBRACK,
    ACTIONS(4228), 1,
      sym__backquoted_id,
    ACTIONS(4232), 1,
      sym_integer_literal,
    ACTIONS(6246), 1,
      anon_sym_LPAREN,
    ACTIONS(6248), 1,
      sym_operator_identifier,
    STATE(5545), 1,
      sym__annotated_type,
    STATE(5546), 1,
      sym__simple_type,
    STATE(6312), 1,
      sym_identifier,
    STATE(6658), 1,
      sym__soft_identifier,
    STATE(8878), 1,
      sym_annotated_type,
    STATE(10706), 1,
      sym__non_null_literal,
    STATE(10736), 1,
      sym_literal_type,
    STATE(11537), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12350), 1,
      sym__infix_type_choice,
    STATE(15564), 1,
      sym_parameter_types,
    STATE(16208), 1,
      sym_stable_identifier,
    ACTIONS(4234), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4236), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4240), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3147), 2,
      sym_comment,
      sym_block_comment,
    STATE(10225), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10825), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11717), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4222), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7079), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [100018] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4210), 1,
      sym__alpha_identifier,
    ACTIONS(4212), 1,
      anon_sym_COLON,
    ACTIONS(4214), 1,
      anon_sym_LBRACE,
    ACTIONS(4216), 1,
      anon_sym__,
    ACTIONS(4220), 1,
      anon_sym_LBRACK,
    ACTIONS(4228), 1,
      sym__backquoted_id,
    ACTIONS(4232), 1,
      sym_integer_literal,
    ACTIONS(6246), 1,
      anon_sym_LPAREN,
    ACTIONS(6248), 1,
      sym_operator_identifier,
    STATE(5545), 1,
      sym__annotated_type,
    STATE(5546), 1,
      sym__simple_type,
    STATE(6312), 1,
      sym_identifier,
    STATE(6658), 1,
      sym__soft_identifier,
    STATE(8878), 1,
      sym_annotated_type,
    STATE(10706), 1,
      sym__non_null_literal,
    STATE(10736), 1,
      sym_literal_type,
    STATE(11538), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12350), 1,
      sym__infix_type_choice,
    STATE(15564), 1,
      sym_parameter_types,
    STATE(16208), 1,
      sym_stable_identifier,
    ACTIONS(4234), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4236), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4240), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3148), 2,
      sym_comment,
      sym_block_comment,
    STATE(10225), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10825), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11717), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4222), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7079), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [100139] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15838), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3149), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [100260] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6252), 1,
      sym__alpha_identifier,
    ACTIONS(6254), 1,
      anon_sym_COLON,
    ACTIONS(6256), 1,
      anon_sym_LBRACE,
    ACTIONS(6258), 1,
      anon_sym__,
    ACTIONS(6260), 1,
      anon_sym_LBRACK,
    ACTIONS(6264), 1,
      anon_sym_LPAREN,
    ACTIONS(6266), 1,
      sym__backquoted_id,
    ACTIONS(6268), 1,
      sym_operator_identifier,
    ACTIONS(6270), 1,
      sym_integer_literal,
    STATE(5450), 1,
      sym__simple_type,
    STATE(5492), 1,
      sym__soft_identifier,
    STATE(5705), 1,
      sym_identifier,
    STATE(5911), 1,
      sym__annotated_type,
    STATE(8761), 1,
      sym_annotated_type,
    STATE(10563), 1,
      sym__non_null_literal,
    STATE(10613), 1,
      sym_literal_type,
    STATE(10671), 1,
      sym_template_body,
    STATE(10944), 1,
      sym__type,
    STATE(12469), 1,
      sym__infix_type_choice,
    STATE(15433), 1,
      sym_parameter_types,
    STATE(16941), 1,
      sym_stable_identifier,
    ACTIONS(6272), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6274), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6276), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3150), 2,
      sym_comment,
      sym_block_comment,
    STATE(9865), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10635), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10850), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10815), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6262), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6211), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [100381] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16375), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3151), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [100502] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1216), 1,
      sym_integer_literal,
    ACTIONS(6278), 1,
      sym__alpha_identifier,
    ACTIONS(6280), 1,
      anon_sym_COLON,
    ACTIONS(6282), 1,
      anon_sym_LBRACE,
    ACTIONS(6284), 1,
      anon_sym__,
    ACTIONS(6286), 1,
      anon_sym_LBRACK,
    ACTIONS(6290), 1,
      anon_sym_LPAREN,
    ACTIONS(6292), 1,
      sym__backquoted_id,
    ACTIONS(6294), 1,
      sym_operator_identifier,
    STATE(5075), 1,
      sym__simple_type,
    STATE(5077), 1,
      sym__annotated_type,
    STATE(5525), 1,
      sym__soft_identifier,
    STATE(5572), 1,
      sym_identifier,
    STATE(8337), 1,
      sym_annotated_type,
    STATE(10633), 1,
      sym__non_null_literal,
    STATE(10655), 1,
      sym_literal_type,
    STATE(12500), 1,
      sym__infix_type_choice,
    STATE(13199), 1,
      sym_template_body,
    STATE(13414), 1,
      sym__type,
    STATE(15024), 1,
      sym_parameter_types,
    STATE(17071), 1,
      sym_stable_identifier,
    ACTIONS(1218), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1220), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1224), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3152), 2,
      sym_comment,
      sym_block_comment,
    STATE(8139), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8608), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10111), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13116), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6477), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [100623] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16274), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3153), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [100744] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14758), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3154), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [100865] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(8669), 1,
      sym__type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3155), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [100986] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6250), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(12694), 1,
      sym__type,
    STATE(15060), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3156), 2,
      sym_comment,
      sym_block_comment,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [101107] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4852), 1,
      sym__alpha_identifier,
    ACTIONS(4854), 1,
      anon_sym_COLON,
    ACTIONS(4856), 1,
      anon_sym_LBRACE,
    ACTIONS(4858), 1,
      anon_sym__,
    ACTIONS(4862), 1,
      anon_sym_LBRACK,
    ACTIONS(4870), 1,
      sym__backquoted_id,
    ACTIONS(4874), 1,
      sym_integer_literal,
    ACTIONS(6296), 1,
      anon_sym_LPAREN,
    ACTIONS(6298), 1,
      sym_operator_identifier,
    STATE(5136), 1,
      sym__annotated_type,
    STATE(5391), 1,
      sym__simple_type,
    STATE(5519), 1,
      sym__soft_identifier,
    STATE(5597), 1,
      sym_identifier,
    STATE(8415), 1,
      sym_annotated_type,
    STATE(10606), 1,
      sym__non_null_literal,
    STATE(10615), 1,
      sym_literal_type,
    STATE(12495), 1,
      sym__infix_type_choice,
    STATE(13404), 1,
      sym_template_body,
    STATE(13427), 1,
      sym__type,
    STATE(14915), 1,
      sym_parameter_types,
    STATE(17047), 1,
      sym_stable_identifier,
    ACTIONS(4876), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4878), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4880), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3157), 2,
      sym_comment,
      sym_block_comment,
    STATE(10073), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10505), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13434), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13465), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4864), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6267), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [101228] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4852), 1,
      sym__alpha_identifier,
    ACTIONS(4854), 1,
      anon_sym_COLON,
    ACTIONS(4856), 1,
      anon_sym_LBRACE,
    ACTIONS(4858), 1,
      anon_sym__,
    ACTIONS(4862), 1,
      anon_sym_LBRACK,
    ACTIONS(4870), 1,
      sym__backquoted_id,
    ACTIONS(4874), 1,
      sym_integer_literal,
    ACTIONS(6296), 1,
      anon_sym_LPAREN,
    ACTIONS(6298), 1,
      sym_operator_identifier,
    STATE(5136), 1,
      sym__annotated_type,
    STATE(5391), 1,
      sym__simple_type,
    STATE(5519), 1,
      sym__soft_identifier,
    STATE(5597), 1,
      sym_identifier,
    STATE(8415), 1,
      sym_annotated_type,
    STATE(10606), 1,
      sym__non_null_literal,
    STATE(10615), 1,
      sym_literal_type,
    STATE(12495), 1,
      sym__infix_type_choice,
    STATE(13404), 1,
      sym_template_body,
    STATE(13438), 1,
      sym__type,
    STATE(14915), 1,
      sym_parameter_types,
    STATE(17047), 1,
      sym_stable_identifier,
    ACTIONS(4876), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4878), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4880), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3158), 2,
      sym_comment,
      sym_block_comment,
    STATE(10073), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10505), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13434), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13465), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4864), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6267), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [101349] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4852), 1,
      sym__alpha_identifier,
    ACTIONS(4854), 1,
      anon_sym_COLON,
    ACTIONS(4856), 1,
      anon_sym_LBRACE,
    ACTIONS(4858), 1,
      anon_sym__,
    ACTIONS(4862), 1,
      anon_sym_LBRACK,
    ACTIONS(4870), 1,
      sym__backquoted_id,
    ACTIONS(4874), 1,
      sym_integer_literal,
    ACTIONS(6296), 1,
      anon_sym_LPAREN,
    ACTIONS(6298), 1,
      sym_operator_identifier,
    STATE(5136), 1,
      sym__annotated_type,
    STATE(5391), 1,
      sym__simple_type,
    STATE(5519), 1,
      sym__soft_identifier,
    STATE(5597), 1,
      sym_identifier,
    STATE(8415), 1,
      sym_annotated_type,
    STATE(10606), 1,
      sym__non_null_literal,
    STATE(10615), 1,
      sym_literal_type,
    STATE(12495), 1,
      sym__infix_type_choice,
    STATE(13404), 1,
      sym_template_body,
    STATE(13464), 1,
      sym__type,
    STATE(14915), 1,
      sym_parameter_types,
    STATE(17047), 1,
      sym_stable_identifier,
    ACTIONS(4876), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4878), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4880), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3159), 2,
      sym_comment,
      sym_block_comment,
    STATE(10073), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10505), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13434), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13465), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4864), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6267), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [101470] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15011), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3160), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [101591] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4852), 1,
      sym__alpha_identifier,
    ACTIONS(4854), 1,
      anon_sym_COLON,
    ACTIONS(4856), 1,
      anon_sym_LBRACE,
    ACTIONS(4858), 1,
      anon_sym__,
    ACTIONS(4862), 1,
      anon_sym_LBRACK,
    ACTIONS(4870), 1,
      sym__backquoted_id,
    ACTIONS(4874), 1,
      sym_integer_literal,
    ACTIONS(6296), 1,
      anon_sym_LPAREN,
    ACTIONS(6298), 1,
      sym_operator_identifier,
    STATE(5136), 1,
      sym__annotated_type,
    STATE(5391), 1,
      sym__simple_type,
    STATE(5519), 1,
      sym__soft_identifier,
    STATE(5597), 1,
      sym_identifier,
    STATE(8415), 1,
      sym_annotated_type,
    STATE(10606), 1,
      sym__non_null_literal,
    STATE(10615), 1,
      sym_literal_type,
    STATE(12495), 1,
      sym__infix_type_choice,
    STATE(13404), 1,
      sym_template_body,
    STATE(13466), 1,
      sym__type,
    STATE(14915), 1,
      sym_parameter_types,
    STATE(17047), 1,
      sym_stable_identifier,
    ACTIONS(4876), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4878), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4880), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3161), 2,
      sym_comment,
      sym_block_comment,
    STATE(10073), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10505), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13434), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13465), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4864), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6267), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [101712] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16385), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3162), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [101833] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16547), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3163), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [101954] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15097), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3164), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [102075] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6304), 1,
      anon_sym_LBRACK,
    ACTIONS(6308), 1,
      anon_sym_LPAREN,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    ACTIONS(6314), 1,
      sym_integer_literal,
    STATE(6970), 1,
      sym__simple_type,
    STATE(7534), 1,
      sym__annotated_type,
    STATE(7680), 1,
      sym__soft_identifier,
    STATE(7825), 1,
      sym_identifier,
    STATE(10180), 1,
      sym_annotated_type,
    STATE(11189), 1,
      sym__non_null_literal,
    STATE(11190), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12429), 1,
      sym__infix_type_choice,
    STATE(14365), 1,
      sym__type,
    STATE(15108), 1,
      sym_parameter_types,
    STATE(16467), 1,
      sym_stable_identifier,
    ACTIONS(6316), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6318), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6320), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3165), 2,
      sym_comment,
      sym_block_comment,
    STATE(10836), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11153), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8431), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [102196] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6250), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(12695), 1,
      sym__type,
    STATE(15060), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3166), 2,
      sym_comment,
      sym_block_comment,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [102317] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6322), 1,
      sym__alpha_identifier,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    ACTIONS(6336), 1,
      sym_integer_literal,
    STATE(6384), 1,
      sym__simple_type,
    STATE(6749), 1,
      sym__annotated_type,
    STATE(7031), 1,
      sym_identifier,
    STATE(7267), 1,
      sym__soft_identifier,
    STATE(9861), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11284), 1,
      sym__type,
    STATE(11291), 1,
      sym__non_null_literal,
    STATE(11292), 1,
      sym_literal_type,
    STATE(12368), 1,
      sym__infix_type_choice,
    STATE(15057), 1,
      sym_parameter_types,
    STATE(16266), 1,
      sym_stable_identifier,
    ACTIONS(6338), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6340), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6342), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3167), 2,
      sym_comment,
      sym_block_comment,
    STATE(10861), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11222), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7736), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [102438] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15271), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3168), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [102559] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16239), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3169), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [102680] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16246), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3170), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [102801] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6252), 1,
      sym__alpha_identifier,
    ACTIONS(6254), 1,
      anon_sym_COLON,
    ACTIONS(6256), 1,
      anon_sym_LBRACE,
    ACTIONS(6258), 1,
      anon_sym__,
    ACTIONS(6260), 1,
      anon_sym_LBRACK,
    ACTIONS(6264), 1,
      anon_sym_LPAREN,
    ACTIONS(6266), 1,
      sym__backquoted_id,
    ACTIONS(6268), 1,
      sym_operator_identifier,
    ACTIONS(6270), 1,
      sym_integer_literal,
    STATE(5450), 1,
      sym__simple_type,
    STATE(5492), 1,
      sym__soft_identifier,
    STATE(5705), 1,
      sym_identifier,
    STATE(5911), 1,
      sym__annotated_type,
    STATE(8761), 1,
      sym_annotated_type,
    STATE(10563), 1,
      sym__non_null_literal,
    STATE(10613), 1,
      sym_literal_type,
    STATE(10671), 1,
      sym_template_body,
    STATE(10980), 1,
      sym__type,
    STATE(12469), 1,
      sym__infix_type_choice,
    STATE(15433), 1,
      sym_parameter_types,
    STATE(16941), 1,
      sym_stable_identifier,
    ACTIONS(6272), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6274), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6276), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3171), 2,
      sym_comment,
      sym_block_comment,
    STATE(9865), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10635), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10850), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10815), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6262), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6211), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [102922] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15325), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3172), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [103043] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6252), 1,
      sym__alpha_identifier,
    ACTIONS(6254), 1,
      anon_sym_COLON,
    ACTIONS(6256), 1,
      anon_sym_LBRACE,
    ACTIONS(6258), 1,
      anon_sym__,
    ACTIONS(6260), 1,
      anon_sym_LBRACK,
    ACTIONS(6264), 1,
      anon_sym_LPAREN,
    ACTIONS(6266), 1,
      sym__backquoted_id,
    ACTIONS(6268), 1,
      sym_operator_identifier,
    ACTIONS(6270), 1,
      sym_integer_literal,
    STATE(5450), 1,
      sym__simple_type,
    STATE(5492), 1,
      sym__soft_identifier,
    STATE(5705), 1,
      sym_identifier,
    STATE(5911), 1,
      sym__annotated_type,
    STATE(8761), 1,
      sym_annotated_type,
    STATE(10563), 1,
      sym__non_null_literal,
    STATE(10613), 1,
      sym_literal_type,
    STATE(10671), 1,
      sym_template_body,
    STATE(11084), 1,
      sym__type,
    STATE(12469), 1,
      sym__infix_type_choice,
    STATE(15433), 1,
      sym_parameter_types,
    STATE(16941), 1,
      sym_stable_identifier,
    ACTIONS(6272), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6274), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6276), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3173), 2,
      sym_comment,
      sym_block_comment,
    STATE(9865), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10635), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10850), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10815), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6262), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6211), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [103164] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6250), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(12696), 1,
      sym__type,
    STATE(15060), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3174), 2,
      sym_comment,
      sym_block_comment,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [103285] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4852), 1,
      sym__alpha_identifier,
    ACTIONS(4854), 1,
      anon_sym_COLON,
    ACTIONS(4856), 1,
      anon_sym_LBRACE,
    ACTIONS(4858), 1,
      anon_sym__,
    ACTIONS(4862), 1,
      anon_sym_LBRACK,
    ACTIONS(4870), 1,
      sym__backquoted_id,
    ACTIONS(4874), 1,
      sym_integer_literal,
    ACTIONS(6296), 1,
      anon_sym_LPAREN,
    ACTIONS(6298), 1,
      sym_operator_identifier,
    STATE(5136), 1,
      sym__annotated_type,
    STATE(5391), 1,
      sym__simple_type,
    STATE(5519), 1,
      sym__soft_identifier,
    STATE(5597), 1,
      sym_identifier,
    STATE(8415), 1,
      sym_annotated_type,
    STATE(10606), 1,
      sym__non_null_literal,
    STATE(10615), 1,
      sym_literal_type,
    STATE(12495), 1,
      sym__infix_type_choice,
    STATE(13404), 1,
      sym_template_body,
    STATE(13411), 1,
      sym__type,
    STATE(14915), 1,
      sym_parameter_types,
    STATE(17047), 1,
      sym_stable_identifier,
    ACTIONS(4876), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4878), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4880), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3175), 2,
      sym_comment,
      sym_block_comment,
    STATE(10073), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10505), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13434), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13465), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4864), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6267), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [103406] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6322), 1,
      sym__alpha_identifier,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    ACTIONS(6336), 1,
      sym_integer_literal,
    STATE(6384), 1,
      sym__simple_type,
    STATE(6749), 1,
      sym__annotated_type,
    STATE(7031), 1,
      sym_identifier,
    STATE(7267), 1,
      sym__soft_identifier,
    STATE(9861), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11291), 1,
      sym__non_null_literal,
    STATE(11292), 1,
      sym_literal_type,
    STATE(11298), 1,
      sym__type,
    STATE(12368), 1,
      sym__infix_type_choice,
    STATE(15057), 1,
      sym_parameter_types,
    STATE(16266), 1,
      sym_stable_identifier,
    ACTIONS(6338), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6340), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6342), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3176), 2,
      sym_comment,
      sym_block_comment,
    STATE(10861), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11222), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7736), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [103527] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15454), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3177), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [103648] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6322), 1,
      sym__alpha_identifier,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    ACTIONS(6336), 1,
      sym_integer_literal,
    STATE(6384), 1,
      sym__simple_type,
    STATE(6749), 1,
      sym__annotated_type,
    STATE(7031), 1,
      sym_identifier,
    STATE(7267), 1,
      sym__soft_identifier,
    STATE(9861), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11291), 1,
      sym__non_null_literal,
    STATE(11292), 1,
      sym_literal_type,
    STATE(11302), 1,
      sym__type,
    STATE(12368), 1,
      sym__infix_type_choice,
    STATE(15057), 1,
      sym_parameter_types,
    STATE(16266), 1,
      sym_stable_identifier,
    ACTIONS(6338), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6340), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6342), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3178), 2,
      sym_comment,
      sym_block_comment,
    STATE(10861), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11222), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7736), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [103769] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(16805), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3179), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [103890] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6322), 1,
      sym__alpha_identifier,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    ACTIONS(6336), 1,
      sym_integer_literal,
    STATE(6384), 1,
      sym__simple_type,
    STATE(6749), 1,
      sym__annotated_type,
    STATE(7031), 1,
      sym_identifier,
    STATE(7267), 1,
      sym__soft_identifier,
    STATE(9861), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11291), 1,
      sym__non_null_literal,
    STATE(11292), 1,
      sym_literal_type,
    STATE(11303), 1,
      sym__type,
    STATE(12368), 1,
      sym__infix_type_choice,
    STATE(15057), 1,
      sym_parameter_types,
    STATE(16266), 1,
      sym_stable_identifier,
    ACTIONS(6338), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6340), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6342), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3180), 2,
      sym_comment,
      sym_block_comment,
    STATE(10861), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11222), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7736), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [104011] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(16817), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3181), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [104132] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6322), 1,
      sym__alpha_identifier,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    ACTIONS(6336), 1,
      sym_integer_literal,
    STATE(6384), 1,
      sym__simple_type,
    STATE(6749), 1,
      sym__annotated_type,
    STATE(7031), 1,
      sym_identifier,
    STATE(7267), 1,
      sym__soft_identifier,
    STATE(9861), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11291), 1,
      sym__non_null_literal,
    STATE(11292), 1,
      sym_literal_type,
    STATE(11304), 1,
      sym__type,
    STATE(12368), 1,
      sym__infix_type_choice,
    STATE(15057), 1,
      sym_parameter_types,
    STATE(16266), 1,
      sym_stable_identifier,
    ACTIONS(6338), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6340), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6342), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3182), 2,
      sym_comment,
      sym_block_comment,
    STATE(10861), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11222), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7736), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [104253] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15478), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3183), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [104374] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 9,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [104443] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1252), 1,
      sym_integer_literal,
    ACTIONS(6344), 1,
      sym__alpha_identifier,
    ACTIONS(6346), 1,
      anon_sym_COLON,
    ACTIONS(6348), 1,
      anon_sym_LBRACE,
    ACTIONS(6350), 1,
      anon_sym__,
    ACTIONS(6352), 1,
      anon_sym_LBRACK,
    ACTIONS(6356), 1,
      anon_sym_LPAREN,
    ACTIONS(6358), 1,
      sym__backquoted_id,
    ACTIONS(6360), 1,
      sym_operator_identifier,
    STATE(5615), 1,
      sym__simple_type,
    STATE(5826), 1,
      sym__annotated_type,
    STATE(6141), 1,
      sym__soft_identifier,
    STATE(6576), 1,
      sym_identifier,
    STATE(9227), 1,
      sym_annotated_type,
    STATE(10767), 1,
      sym_literal_type,
    STATE(10838), 1,
      sym__non_null_literal,
    STATE(11182), 1,
      sym_template_body,
    STATE(11567), 1,
      sym__type,
    STATE(12506), 1,
      sym__infix_type_choice,
    STATE(15062), 1,
      sym_parameter_types,
    STATE(17089), 1,
      sym_stable_identifier,
    ACTIONS(1254), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1256), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1260), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3185), 2,
      sym_comment,
      sym_block_comment,
    STATE(5352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8784), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10368), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6354), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7247), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [104564] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4882), 1,
      sym__alpha_identifier,
    ACTIONS(4884), 1,
      anon_sym_COLON,
    ACTIONS(4886), 1,
      anon_sym_LBRACE,
    ACTIONS(4888), 1,
      anon_sym__,
    ACTIONS(4892), 1,
      anon_sym_LBRACK,
    ACTIONS(4900), 1,
      sym__backquoted_id,
    ACTIONS(4904), 1,
      sym_integer_literal,
    ACTIONS(6362), 1,
      anon_sym_LPAREN,
    ACTIONS(6364), 1,
      sym_operator_identifier,
    STATE(5273), 1,
      sym__annotated_type,
    STATE(5446), 1,
      sym__simple_type,
    STATE(5522), 1,
      sym__soft_identifier,
    STATE(5657), 1,
      sym_identifier,
    STATE(8698), 1,
      sym_annotated_type,
    STATE(10444), 1,
      sym_literal_type,
    STATE(10485), 1,
      sym__non_null_literal,
    STATE(12497), 1,
      sym__infix_type_choice,
    STATE(13535), 1,
      sym__type,
    STATE(13587), 1,
      sym_template_body,
    STATE(14987), 1,
      sym_parameter_types,
    STATE(17059), 1,
      sym_stable_identifier,
    ACTIONS(4906), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4908), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4910), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3186), 2,
      sym_comment,
      sym_block_comment,
    STATE(10093), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10448), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13436), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13594), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4894), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6372), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [104685] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4882), 1,
      sym__alpha_identifier,
    ACTIONS(4884), 1,
      anon_sym_COLON,
    ACTIONS(4886), 1,
      anon_sym_LBRACE,
    ACTIONS(4888), 1,
      anon_sym__,
    ACTIONS(4892), 1,
      anon_sym_LBRACK,
    ACTIONS(4900), 1,
      sym__backquoted_id,
    ACTIONS(4904), 1,
      sym_integer_literal,
    ACTIONS(6362), 1,
      anon_sym_LPAREN,
    ACTIONS(6364), 1,
      sym_operator_identifier,
    STATE(5273), 1,
      sym__annotated_type,
    STATE(5446), 1,
      sym__simple_type,
    STATE(5522), 1,
      sym__soft_identifier,
    STATE(5657), 1,
      sym_identifier,
    STATE(8698), 1,
      sym_annotated_type,
    STATE(10444), 1,
      sym_literal_type,
    STATE(10485), 1,
      sym__non_null_literal,
    STATE(12497), 1,
      sym__infix_type_choice,
    STATE(13560), 1,
      sym__type,
    STATE(13587), 1,
      sym_template_body,
    STATE(14987), 1,
      sym_parameter_types,
    STATE(17059), 1,
      sym_stable_identifier,
    ACTIONS(4906), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4908), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4910), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3187), 2,
      sym_comment,
      sym_block_comment,
    STATE(10093), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10448), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13436), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13594), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4894), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6372), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [104806] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15641), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3188), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [104927] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17480), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3189), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [105048] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17502), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3190), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [105169] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6158), 1,
      anon_sym_COLON,
    ACTIONS(6160), 1,
      anon_sym_LBRACE,
    ACTIONS(6162), 1,
      anon_sym_LBRACK,
    ACTIONS(6164), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(7387), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(10986), 1,
      sym__non_null_literal,
    STATE(10988), 1,
      sym_literal_type,
    STATE(11158), 1,
      sym_template_body,
    STATE(11270), 1,
      sym__type,
    STATE(12334), 1,
      sym__infix_type_choice,
    STATE(15319), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3191), 2,
      sym_comment,
      sym_block_comment,
    STATE(10591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11237), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11264), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [105290] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15707), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3192), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [105411] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4882), 1,
      sym__alpha_identifier,
    ACTIONS(4884), 1,
      anon_sym_COLON,
    ACTIONS(4886), 1,
      anon_sym_LBRACE,
    ACTIONS(4888), 1,
      anon_sym__,
    ACTIONS(4892), 1,
      anon_sym_LBRACK,
    ACTIONS(4900), 1,
      sym__backquoted_id,
    ACTIONS(4904), 1,
      sym_integer_literal,
    ACTIONS(6362), 1,
      anon_sym_LPAREN,
    ACTIONS(6364), 1,
      sym_operator_identifier,
    STATE(5273), 1,
      sym__annotated_type,
    STATE(5446), 1,
      sym__simple_type,
    STATE(5522), 1,
      sym__soft_identifier,
    STATE(5657), 1,
      sym_identifier,
    STATE(8698), 1,
      sym_annotated_type,
    STATE(10444), 1,
      sym_literal_type,
    STATE(10485), 1,
      sym__non_null_literal,
    STATE(12497), 1,
      sym__infix_type_choice,
    STATE(13584), 1,
      sym__type,
    STATE(13587), 1,
      sym_template_body,
    STATE(14987), 1,
      sym_parameter_types,
    STATE(17059), 1,
      sym_stable_identifier,
    ACTIONS(4906), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4908), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4910), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3193), 2,
      sym_comment,
      sym_block_comment,
    STATE(10093), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10448), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13436), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13594), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4894), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6372), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [105532] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4882), 1,
      sym__alpha_identifier,
    ACTIONS(4884), 1,
      anon_sym_COLON,
    ACTIONS(4886), 1,
      anon_sym_LBRACE,
    ACTIONS(4888), 1,
      anon_sym__,
    ACTIONS(4892), 1,
      anon_sym_LBRACK,
    ACTIONS(4900), 1,
      sym__backquoted_id,
    ACTIONS(4904), 1,
      sym_integer_literal,
    ACTIONS(6362), 1,
      anon_sym_LPAREN,
    ACTIONS(6364), 1,
      sym_operator_identifier,
    STATE(5273), 1,
      sym__annotated_type,
    STATE(5446), 1,
      sym__simple_type,
    STATE(5522), 1,
      sym__soft_identifier,
    STATE(5657), 1,
      sym_identifier,
    STATE(8698), 1,
      sym_annotated_type,
    STATE(10444), 1,
      sym_literal_type,
    STATE(10485), 1,
      sym__non_null_literal,
    STATE(12497), 1,
      sym__infix_type_choice,
    STATE(13587), 1,
      sym_template_body,
    STATE(13588), 1,
      sym__type,
    STATE(14987), 1,
      sym_parameter_types,
    STATE(17059), 1,
      sym_stable_identifier,
    ACTIONS(4906), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4908), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4910), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3194), 2,
      sym_comment,
      sym_block_comment,
    STATE(10093), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10448), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13436), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13594), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4894), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6372), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [105653] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4698), 1,
      sym__alpha_identifier,
    ACTIONS(4700), 1,
      anon_sym_COLON,
    ACTIONS(4702), 1,
      anon_sym_LBRACE,
    ACTIONS(4704), 1,
      anon_sym__,
    ACTIONS(4708), 1,
      anon_sym_LBRACK,
    ACTIONS(4716), 1,
      sym__backquoted_id,
    ACTIONS(4720), 1,
      sym_integer_literal,
    ACTIONS(6366), 1,
      anon_sym_LPAREN,
    ACTIONS(6368), 1,
      sym_operator_identifier,
    STATE(5437), 1,
      sym__annotated_type,
    STATE(5453), 1,
      sym__simple_type,
    STATE(5498), 1,
      sym__soft_identifier,
    STATE(5876), 1,
      sym_identifier,
    STATE(8602), 1,
      sym_annotated_type,
    STATE(10590), 1,
      sym__non_null_literal,
    STATE(10652), 1,
      sym_literal_type,
    STATE(11142), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12473), 1,
      sym__infix_type_choice,
    STATE(15606), 1,
      sym_parameter_types,
    STATE(16963), 1,
      sym_stable_identifier,
    ACTIONS(4722), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4724), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4726), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3195), 2,
      sym_comment,
      sym_block_comment,
    STATE(9889), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10515), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4710), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6568), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [105774] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1506), 1,
      sym_integer_literal,
    ACTIONS(6370), 1,
      sym__alpha_identifier,
    ACTIONS(6372), 1,
      anon_sym_COLON,
    ACTIONS(6374), 1,
      anon_sym_LBRACE,
    ACTIONS(6376), 1,
      anon_sym__,
    ACTIONS(6378), 1,
      anon_sym_LBRACK,
    ACTIONS(6382), 1,
      anon_sym_LPAREN,
    ACTIONS(6384), 1,
      sym__backquoted_id,
    ACTIONS(6386), 1,
      sym_operator_identifier,
    STATE(5390), 1,
      sym__annotated_type,
    STATE(5425), 1,
      sym__simple_type,
    STATE(5485), 1,
      sym__soft_identifier,
    STATE(5665), 1,
      sym_identifier,
    STATE(8696), 1,
      sym_annotated_type,
    STATE(10458), 1,
      sym__non_null_literal,
    STATE(10643), 1,
      sym_literal_type,
    STATE(12457), 1,
      sym__infix_type_choice,
    STATE(13167), 1,
      sym_template_body,
    STATE(13296), 1,
      sym__type,
    STATE(15020), 1,
      sym_parameter_types,
    STATE(16818), 1,
      sym_stable_identifier,
    ACTIONS(1508), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1510), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1514), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3196), 2,
      sym_comment,
      sym_block_comment,
    STATE(8229), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8419), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9754), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13189), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6380), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6556), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [105895] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14794), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3197), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [106016] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6158), 1,
      anon_sym_COLON,
    ACTIONS(6160), 1,
      anon_sym_LBRACE,
    ACTIONS(6162), 1,
      anon_sym_LBRACK,
    ACTIONS(6164), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(7387), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(10986), 1,
      sym__non_null_literal,
    STATE(10988), 1,
      sym_literal_type,
    STATE(11158), 1,
      sym_template_body,
    STATE(11225), 1,
      sym__type,
    STATE(12334), 1,
      sym__infix_type_choice,
    STATE(15319), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3198), 2,
      sym_comment,
      sym_block_comment,
    STATE(10591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11237), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11264), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [106137] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17360), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3199), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [106258] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17531), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3200), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [106379] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6388), 1,
      sym__alpha_identifier,
    ACTIONS(6390), 1,
      anon_sym_COLON,
    ACTIONS(6392), 1,
      anon_sym_LBRACE,
    ACTIONS(6394), 1,
      anon_sym__,
    ACTIONS(6396), 1,
      anon_sym_LBRACK,
    ACTIONS(6400), 1,
      anon_sym_LPAREN,
    ACTIONS(6402), 1,
      sym__backquoted_id,
    ACTIONS(6404), 1,
      sym_operator_identifier,
    ACTIONS(6406), 1,
      sym_integer_literal,
    STATE(5646), 1,
      sym__simple_type,
    STATE(6195), 1,
      sym_identifier,
    STATE(6475), 1,
      sym__annotated_type,
    STATE(6548), 1,
      sym__soft_identifier,
    STATE(9396), 1,
      sym_annotated_type,
    STATE(10819), 1,
      sym__non_null_literal,
    STATE(10821), 1,
      sym_literal_type,
    STATE(11057), 1,
      sym_template_body,
    STATE(11092), 1,
      sym__type,
    STATE(12379), 1,
      sym__infix_type_choice,
    STATE(15012), 1,
      sym_parameter_types,
    STATE(16293), 1,
      sym_stable_identifier,
    ACTIONS(6408), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6410), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6412), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3201), 2,
      sym_comment,
      sym_block_comment,
    STATE(10173), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10710), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11104), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10976), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6398), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7147), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [106500] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15371), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3202), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [106621] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6218), 1,
      anon_sym_LBRACK,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(14274), 1,
      sym__type,
    STATE(15570), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3203), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [106742] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6414), 1,
      anon_sym_COLON,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(6418), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(14678), 1,
      sym__type,
    STATE(15021), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3204), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [106863] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6218), 1,
      anon_sym_LBRACK,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(14289), 1,
      sym__type,
    STATE(15570), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3205), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [106984] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4882), 1,
      sym__alpha_identifier,
    ACTIONS(4884), 1,
      anon_sym_COLON,
    ACTIONS(4886), 1,
      anon_sym_LBRACE,
    ACTIONS(4888), 1,
      anon_sym__,
    ACTIONS(4892), 1,
      anon_sym_LBRACK,
    ACTIONS(4900), 1,
      sym__backquoted_id,
    ACTIONS(4904), 1,
      sym_integer_literal,
    ACTIONS(6362), 1,
      anon_sym_LPAREN,
    ACTIONS(6364), 1,
      sym_operator_identifier,
    STATE(5273), 1,
      sym__annotated_type,
    STATE(5446), 1,
      sym__simple_type,
    STATE(5522), 1,
      sym__soft_identifier,
    STATE(5657), 1,
      sym_identifier,
    STATE(8698), 1,
      sym_annotated_type,
    STATE(10444), 1,
      sym_literal_type,
    STATE(10485), 1,
      sym__non_null_literal,
    STATE(12497), 1,
      sym__infix_type_choice,
    STATE(13406), 1,
      sym__type,
    STATE(13587), 1,
      sym_template_body,
    STATE(14987), 1,
      sym_parameter_types,
    STATE(17059), 1,
      sym_stable_identifier,
    ACTIONS(4906), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4908), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4910), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3206), 2,
      sym_comment,
      sym_block_comment,
    STATE(10093), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10448), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13436), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13594), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4894), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6372), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [107105] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4698), 1,
      sym__alpha_identifier,
    ACTIONS(4700), 1,
      anon_sym_COLON,
    ACTIONS(4702), 1,
      anon_sym_LBRACE,
    ACTIONS(4704), 1,
      anon_sym__,
    ACTIONS(4708), 1,
      anon_sym_LBRACK,
    ACTIONS(4716), 1,
      sym__backquoted_id,
    ACTIONS(4720), 1,
      sym_integer_literal,
    ACTIONS(6366), 1,
      anon_sym_LPAREN,
    ACTIONS(6368), 1,
      sym_operator_identifier,
    STATE(5437), 1,
      sym__annotated_type,
    STATE(5453), 1,
      sym__simple_type,
    STATE(5498), 1,
      sym__soft_identifier,
    STATE(5876), 1,
      sym_identifier,
    STATE(8602), 1,
      sym_annotated_type,
    STATE(10590), 1,
      sym__non_null_literal,
    STATE(10652), 1,
      sym_literal_type,
    STATE(11144), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12473), 1,
      sym__infix_type_choice,
    STATE(15606), 1,
      sym_parameter_types,
    STATE(16963), 1,
      sym_stable_identifier,
    ACTIONS(4722), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4724), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4726), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3207), 2,
      sym_comment,
      sym_block_comment,
    STATE(9889), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10515), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4710), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6568), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [107226] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15007), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3208), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [107347] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4698), 1,
      sym__alpha_identifier,
    ACTIONS(4700), 1,
      anon_sym_COLON,
    ACTIONS(4702), 1,
      anon_sym_LBRACE,
    ACTIONS(4704), 1,
      anon_sym__,
    ACTIONS(4708), 1,
      anon_sym_LBRACK,
    ACTIONS(4716), 1,
      sym__backquoted_id,
    ACTIONS(4720), 1,
      sym_integer_literal,
    ACTIONS(6366), 1,
      anon_sym_LPAREN,
    ACTIONS(6368), 1,
      sym_operator_identifier,
    STATE(5437), 1,
      sym__annotated_type,
    STATE(5453), 1,
      sym__simple_type,
    STATE(5498), 1,
      sym__soft_identifier,
    STATE(5876), 1,
      sym_identifier,
    STATE(8602), 1,
      sym_annotated_type,
    STATE(10590), 1,
      sym__non_null_literal,
    STATE(10652), 1,
      sym_literal_type,
    STATE(11146), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12473), 1,
      sym__infix_type_choice,
    STATE(15606), 1,
      sym_parameter_types,
    STATE(16963), 1,
      sym_stable_identifier,
    ACTIONS(4722), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4724), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4726), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3209), 2,
      sym_comment,
      sym_block_comment,
    STATE(9889), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10515), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4710), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6568), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [107468] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17074), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3210), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [107589] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4698), 1,
      sym__alpha_identifier,
    ACTIONS(4700), 1,
      anon_sym_COLON,
    ACTIONS(4702), 1,
      anon_sym_LBRACE,
    ACTIONS(4704), 1,
      anon_sym__,
    ACTIONS(4708), 1,
      anon_sym_LBRACK,
    ACTIONS(4716), 1,
      sym__backquoted_id,
    ACTIONS(4720), 1,
      sym_integer_literal,
    ACTIONS(6366), 1,
      anon_sym_LPAREN,
    ACTIONS(6368), 1,
      sym_operator_identifier,
    STATE(5437), 1,
      sym__annotated_type,
    STATE(5453), 1,
      sym__simple_type,
    STATE(5498), 1,
      sym__soft_identifier,
    STATE(5876), 1,
      sym_identifier,
    STATE(8602), 1,
      sym_annotated_type,
    STATE(10590), 1,
      sym__non_null_literal,
    STATE(10652), 1,
      sym_literal_type,
    STATE(11147), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12473), 1,
      sym__infix_type_choice,
    STATE(15606), 1,
      sym_parameter_types,
    STATE(16963), 1,
      sym_stable_identifier,
    ACTIONS(4722), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4724), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4726), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3211), 2,
      sym_comment,
      sym_block_comment,
    STATE(9889), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10515), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4710), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6568), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [107710] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16273), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3212), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [107831] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6388), 1,
      sym__alpha_identifier,
    ACTIONS(6390), 1,
      anon_sym_COLON,
    ACTIONS(6392), 1,
      anon_sym_LBRACE,
    ACTIONS(6394), 1,
      anon_sym__,
    ACTIONS(6396), 1,
      anon_sym_LBRACK,
    ACTIONS(6400), 1,
      anon_sym_LPAREN,
    ACTIONS(6402), 1,
      sym__backquoted_id,
    ACTIONS(6404), 1,
      sym_operator_identifier,
    ACTIONS(6406), 1,
      sym_integer_literal,
    STATE(5646), 1,
      sym__simple_type,
    STATE(6195), 1,
      sym_identifier,
    STATE(6475), 1,
      sym__annotated_type,
    STATE(6548), 1,
      sym__soft_identifier,
    STATE(9396), 1,
      sym_annotated_type,
    STATE(10819), 1,
      sym__non_null_literal,
    STATE(10821), 1,
      sym_literal_type,
    STATE(11039), 1,
      sym__type,
    STATE(11057), 1,
      sym_template_body,
    STATE(12379), 1,
      sym__infix_type_choice,
    STATE(15012), 1,
      sym_parameter_types,
    STATE(16293), 1,
      sym_stable_identifier,
    ACTIONS(6408), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6410), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6412), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3213), 2,
      sym_comment,
      sym_block_comment,
    STATE(10173), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10710), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11104), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10976), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6398), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7147), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [107952] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14779), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3214), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [108073] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6388), 1,
      sym__alpha_identifier,
    ACTIONS(6390), 1,
      anon_sym_COLON,
    ACTIONS(6392), 1,
      anon_sym_LBRACE,
    ACTIONS(6394), 1,
      anon_sym__,
    ACTIONS(6396), 1,
      anon_sym_LBRACK,
    ACTIONS(6400), 1,
      anon_sym_LPAREN,
    ACTIONS(6402), 1,
      sym__backquoted_id,
    ACTIONS(6404), 1,
      sym_operator_identifier,
    ACTIONS(6406), 1,
      sym_integer_literal,
    STATE(5646), 1,
      sym__simple_type,
    STATE(6195), 1,
      sym_identifier,
    STATE(6475), 1,
      sym__annotated_type,
    STATE(6548), 1,
      sym__soft_identifier,
    STATE(9396), 1,
      sym_annotated_type,
    STATE(10819), 1,
      sym__non_null_literal,
    STATE(10821), 1,
      sym_literal_type,
    STATE(11041), 1,
      sym__type,
    STATE(11057), 1,
      sym_template_body,
    STATE(12379), 1,
      sym__infix_type_choice,
    STATE(15012), 1,
      sym_parameter_types,
    STATE(16293), 1,
      sym_stable_identifier,
    ACTIONS(6408), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6410), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6412), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3215), 2,
      sym_comment,
      sym_block_comment,
    STATE(10173), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10710), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11104), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10976), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6398), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7147), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [108194] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4698), 1,
      sym__alpha_identifier,
    ACTIONS(4700), 1,
      anon_sym_COLON,
    ACTIONS(4702), 1,
      anon_sym_LBRACE,
    ACTIONS(4704), 1,
      anon_sym__,
    ACTIONS(4708), 1,
      anon_sym_LBRACK,
    ACTIONS(4716), 1,
      sym__backquoted_id,
    ACTIONS(4720), 1,
      sym_integer_literal,
    ACTIONS(6366), 1,
      anon_sym_LPAREN,
    ACTIONS(6368), 1,
      sym_operator_identifier,
    STATE(5437), 1,
      sym__annotated_type,
    STATE(5453), 1,
      sym__simple_type,
    STATE(5498), 1,
      sym__soft_identifier,
    STATE(5876), 1,
      sym_identifier,
    STATE(8602), 1,
      sym_annotated_type,
    STATE(10590), 1,
      sym__non_null_literal,
    STATE(10652), 1,
      sym_literal_type,
    STATE(11148), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12473), 1,
      sym__infix_type_choice,
    STATE(15606), 1,
      sym_parameter_types,
    STATE(16963), 1,
      sym_stable_identifier,
    ACTIONS(4722), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4724), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4726), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3216), 2,
      sym_comment,
      sym_block_comment,
    STATE(9889), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10515), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4710), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6568), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [108315] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6388), 1,
      sym__alpha_identifier,
    ACTIONS(6390), 1,
      anon_sym_COLON,
    ACTIONS(6392), 1,
      anon_sym_LBRACE,
    ACTIONS(6394), 1,
      anon_sym__,
    ACTIONS(6396), 1,
      anon_sym_LBRACK,
    ACTIONS(6400), 1,
      anon_sym_LPAREN,
    ACTIONS(6402), 1,
      sym__backquoted_id,
    ACTIONS(6404), 1,
      sym_operator_identifier,
    ACTIONS(6406), 1,
      sym_integer_literal,
    STATE(5646), 1,
      sym__simple_type,
    STATE(6195), 1,
      sym_identifier,
    STATE(6475), 1,
      sym__annotated_type,
    STATE(6548), 1,
      sym__soft_identifier,
    STATE(9396), 1,
      sym_annotated_type,
    STATE(10819), 1,
      sym__non_null_literal,
    STATE(10821), 1,
      sym_literal_type,
    STATE(11057), 1,
      sym_template_body,
    STATE(11065), 1,
      sym__type,
    STATE(12379), 1,
      sym__infix_type_choice,
    STATE(15012), 1,
      sym_parameter_types,
    STATE(16293), 1,
      sym_stable_identifier,
    ACTIONS(6408), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6410), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6412), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3217), 2,
      sym_comment,
      sym_block_comment,
    STATE(10173), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10710), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11104), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10976), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6398), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7147), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [108436] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6388), 1,
      sym__alpha_identifier,
    ACTIONS(6390), 1,
      anon_sym_COLON,
    ACTIONS(6392), 1,
      anon_sym_LBRACE,
    ACTIONS(6394), 1,
      anon_sym__,
    ACTIONS(6396), 1,
      anon_sym_LBRACK,
    ACTIONS(6400), 1,
      anon_sym_LPAREN,
    ACTIONS(6402), 1,
      sym__backquoted_id,
    ACTIONS(6404), 1,
      sym_operator_identifier,
    ACTIONS(6406), 1,
      sym_integer_literal,
    STATE(5646), 1,
      sym__simple_type,
    STATE(6195), 1,
      sym_identifier,
    STATE(6475), 1,
      sym__annotated_type,
    STATE(6548), 1,
      sym__soft_identifier,
    STATE(9396), 1,
      sym_annotated_type,
    STATE(10819), 1,
      sym__non_null_literal,
    STATE(10821), 1,
      sym_literal_type,
    STATE(11057), 1,
      sym_template_body,
    STATE(11066), 1,
      sym__type,
    STATE(12379), 1,
      sym__infix_type_choice,
    STATE(15012), 1,
      sym_parameter_types,
    STATE(16293), 1,
      sym_stable_identifier,
    ACTIONS(6408), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6410), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6412), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3218), 2,
      sym_comment,
      sym_block_comment,
    STATE(10173), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10710), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11104), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10976), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6398), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7147), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [108557] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1216), 1,
      sym_integer_literal,
    ACTIONS(6278), 1,
      sym__alpha_identifier,
    ACTIONS(6280), 1,
      anon_sym_COLON,
    ACTIONS(6282), 1,
      anon_sym_LBRACE,
    ACTIONS(6284), 1,
      anon_sym__,
    ACTIONS(6286), 1,
      anon_sym_LBRACK,
    ACTIONS(6290), 1,
      anon_sym_LPAREN,
    ACTIONS(6292), 1,
      sym__backquoted_id,
    ACTIONS(6294), 1,
      sym_operator_identifier,
    STATE(5075), 1,
      sym__simple_type,
    STATE(5077), 1,
      sym__annotated_type,
    STATE(5525), 1,
      sym__soft_identifier,
    STATE(5572), 1,
      sym_identifier,
    STATE(8337), 1,
      sym_annotated_type,
    STATE(10633), 1,
      sym__non_null_literal,
    STATE(10655), 1,
      sym_literal_type,
    STATE(12500), 1,
      sym__infix_type_choice,
    STATE(13050), 1,
      sym__type,
    STATE(13199), 1,
      sym_template_body,
    STATE(15024), 1,
      sym_parameter_types,
    STATE(17071), 1,
      sym_stable_identifier,
    ACTIONS(1218), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1220), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1224), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3219), 2,
      sym_comment,
      sym_block_comment,
    STATE(8139), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8608), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10111), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13116), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6477), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [108678] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1872), 1,
      sym_integer_literal,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6426), 1,
      anon_sym__,
    ACTIONS(6428), 1,
      anon_sym_LBRACK,
    ACTIONS(6432), 1,
      anon_sym_LPAREN,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(6436), 1,
      sym_operator_identifier,
    STATE(6914), 1,
      sym__simple_type,
    STATE(6978), 1,
      sym__annotated_type,
    STATE(7465), 1,
      sym_identifier,
    STATE(7913), 1,
      sym__soft_identifier,
    STATE(10061), 1,
      sym_annotated_type,
    STATE(11196), 1,
      sym_literal_type,
    STATE(11321), 1,
      sym__non_null_literal,
    STATE(12037), 1,
      sym_template_body,
    STATE(12459), 1,
      sym__type,
    STATE(12510), 1,
      sym__infix_type_choice,
    STATE(15063), 1,
      sym_parameter_types,
    STATE(17101), 1,
      sym_stable_identifier,
    ACTIONS(1874), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1876), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1880), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3220), 2,
      sym_comment,
      sym_block_comment,
    STATE(6282), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9797), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10719), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8446), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [108799] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15229), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3221), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [108920] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1216), 1,
      sym_integer_literal,
    ACTIONS(6278), 1,
      sym__alpha_identifier,
    ACTIONS(6280), 1,
      anon_sym_COLON,
    ACTIONS(6282), 1,
      anon_sym_LBRACE,
    ACTIONS(6284), 1,
      anon_sym__,
    ACTIONS(6286), 1,
      anon_sym_LBRACK,
    ACTIONS(6290), 1,
      anon_sym_LPAREN,
    ACTIONS(6292), 1,
      sym__backquoted_id,
    ACTIONS(6294), 1,
      sym_operator_identifier,
    STATE(5075), 1,
      sym__simple_type,
    STATE(5077), 1,
      sym__annotated_type,
    STATE(5525), 1,
      sym__soft_identifier,
    STATE(5572), 1,
      sym_identifier,
    STATE(8337), 1,
      sym_annotated_type,
    STATE(10633), 1,
      sym__non_null_literal,
    STATE(10655), 1,
      sym_literal_type,
    STATE(12500), 1,
      sym__infix_type_choice,
    STATE(13052), 1,
      sym__type,
    STATE(13199), 1,
      sym_template_body,
    STATE(15024), 1,
      sym_parameter_types,
    STATE(17071), 1,
      sym_stable_identifier,
    ACTIONS(1218), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1220), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1224), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3222), 2,
      sym_comment,
      sym_block_comment,
    STATE(8139), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8608), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10111), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13116), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6477), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [109041] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16322), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3223), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [109162] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1216), 1,
      sym_integer_literal,
    ACTIONS(6278), 1,
      sym__alpha_identifier,
    ACTIONS(6280), 1,
      anon_sym_COLON,
    ACTIONS(6282), 1,
      anon_sym_LBRACE,
    ACTIONS(6284), 1,
      anon_sym__,
    ACTIONS(6286), 1,
      anon_sym_LBRACK,
    ACTIONS(6290), 1,
      anon_sym_LPAREN,
    ACTIONS(6292), 1,
      sym__backquoted_id,
    ACTIONS(6294), 1,
      sym_operator_identifier,
    STATE(5075), 1,
      sym__simple_type,
    STATE(5077), 1,
      sym__annotated_type,
    STATE(5525), 1,
      sym__soft_identifier,
    STATE(5572), 1,
      sym_identifier,
    STATE(8337), 1,
      sym_annotated_type,
    STATE(10633), 1,
      sym__non_null_literal,
    STATE(10655), 1,
      sym_literal_type,
    STATE(12500), 1,
      sym__infix_type_choice,
    STATE(13053), 1,
      sym__type,
    STATE(13199), 1,
      sym_template_body,
    STATE(15024), 1,
      sym_parameter_types,
    STATE(17071), 1,
      sym_stable_identifier,
    ACTIONS(1218), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1220), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1224), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3224), 2,
      sym_comment,
      sym_block_comment,
    STATE(8139), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8608), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10111), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13116), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6477), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [109283] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16371), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3225), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [109404] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1216), 1,
      sym_integer_literal,
    ACTIONS(6278), 1,
      sym__alpha_identifier,
    ACTIONS(6280), 1,
      anon_sym_COLON,
    ACTIONS(6282), 1,
      anon_sym_LBRACE,
    ACTIONS(6284), 1,
      anon_sym__,
    ACTIONS(6286), 1,
      anon_sym_LBRACK,
    ACTIONS(6290), 1,
      anon_sym_LPAREN,
    ACTIONS(6292), 1,
      sym__backquoted_id,
    ACTIONS(6294), 1,
      sym_operator_identifier,
    STATE(5075), 1,
      sym__simple_type,
    STATE(5077), 1,
      sym__annotated_type,
    STATE(5525), 1,
      sym__soft_identifier,
    STATE(5572), 1,
      sym_identifier,
    STATE(8337), 1,
      sym_annotated_type,
    STATE(10633), 1,
      sym__non_null_literal,
    STATE(10655), 1,
      sym_literal_type,
    STATE(12500), 1,
      sym__infix_type_choice,
    STATE(13056), 1,
      sym__type,
    STATE(13199), 1,
      sym_template_body,
    STATE(15024), 1,
      sym_parameter_types,
    STATE(17071), 1,
      sym_stable_identifier,
    ACTIONS(1218), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1220), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1224), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3226), 2,
      sym_comment,
      sym_block_comment,
    STATE(8139), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8608), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10111), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13116), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6477), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [109525] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15069), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3227), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [109646] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6218), 1,
      anon_sym_LBRACK,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(14291), 1,
      sym__type,
    STATE(15570), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3228), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [109767] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1432), 1,
      sym_integer_literal,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    STATE(6294), 1,
      sym__annotated_type,
    STATE(6295), 1,
      sym__simple_type,
    STATE(6834), 1,
      sym__soft_identifier,
    STATE(7296), 1,
      sym_identifier,
    STATE(9681), 1,
      sym_annotated_type,
    STATE(10996), 1,
      sym__non_null_literal,
    STATE(11069), 1,
      sym_literal_type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12052), 1,
      sym__type,
    STATE(12445), 1,
      sym__infix_type_choice,
    STATE(15059), 1,
      sym_parameter_types,
    STATE(16630), 1,
      sym_stable_identifier,
    ACTIONS(1434), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1436), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1440), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3229), 2,
      sym_comment,
      sym_block_comment,
    STATE(5972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9688), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10449), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7652), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [109888] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym__alpha_identifier,
    ACTIONS(6458), 1,
      anon_sym_COLON,
    ACTIONS(6460), 1,
      anon_sym_LBRACE,
    ACTIONS(6462), 1,
      anon_sym__,
    ACTIONS(6464), 1,
      anon_sym_LBRACK,
    ACTIONS(6468), 1,
      anon_sym_LPAREN,
    ACTIONS(6470), 1,
      sym__backquoted_id,
    ACTIONS(6472), 1,
      sym_operator_identifier,
    ACTIONS(6474), 1,
      sym_integer_literal,
    STATE(5654), 1,
      sym__simple_type,
    STATE(6003), 1,
      sym_identifier,
    STATE(6313), 1,
      sym__soft_identifier,
    STATE(6510), 1,
      sym__annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(9520), 1,
      sym_annotated_type,
    STATE(10863), 1,
      sym__non_null_literal,
    STATE(10903), 1,
      sym_literal_type,
    STATE(11038), 1,
      sym__type,
    STATE(12319), 1,
      sym__infix_type_choice,
    STATE(14991), 1,
      sym_parameter_types,
    STATE(16863), 1,
      sym_stable_identifier,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3230), 2,
      sym_comment,
      sym_block_comment,
    STATE(10159), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10965), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6466), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [110009] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15432), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3231), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [110130] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17610), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3232), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [110251] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17638), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3233), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [110372] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15270), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3234), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [110493] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6172), 1,
      anon_sym_LBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(11878), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12386), 1,
      sym__infix_type_choice,
    STATE(15018), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3235), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [110614] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15605), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3236), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [110735] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1216), 1,
      sym_integer_literal,
    ACTIONS(6278), 1,
      sym__alpha_identifier,
    ACTIONS(6280), 1,
      anon_sym_COLON,
    ACTIONS(6282), 1,
      anon_sym_LBRACE,
    ACTIONS(6284), 1,
      anon_sym__,
    ACTIONS(6286), 1,
      anon_sym_LBRACK,
    ACTIONS(6290), 1,
      anon_sym_LPAREN,
    ACTIONS(6292), 1,
      sym__backquoted_id,
    ACTIONS(6294), 1,
      sym_operator_identifier,
    STATE(5075), 1,
      sym__simple_type,
    STATE(5077), 1,
      sym__annotated_type,
    STATE(5525), 1,
      sym__soft_identifier,
    STATE(5572), 1,
      sym_identifier,
    STATE(8337), 1,
      sym_annotated_type,
    STATE(10633), 1,
      sym__non_null_literal,
    STATE(10655), 1,
      sym_literal_type,
    STATE(12500), 1,
      sym__infix_type_choice,
    STATE(13040), 1,
      sym__type,
    STATE(13199), 1,
      sym_template_body,
    STATE(15024), 1,
      sym_parameter_types,
    STATE(17071), 1,
      sym_stable_identifier,
    ACTIONS(1218), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1220), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1224), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3237), 2,
      sym_comment,
      sym_block_comment,
    STATE(8139), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8608), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10111), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13116), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6477), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [110856] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(16706), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3238), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [110977] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6482), 1,
      sym__alpha_identifier,
    ACTIONS(6484), 1,
      anon_sym__,
    ACTIONS(6486), 1,
      anon_sym_LBRACK,
    ACTIONS(6490), 1,
      anon_sym_LPAREN,
    ACTIONS(6492), 1,
      sym__backquoted_id,
    ACTIONS(6494), 1,
      sym_operator_identifier,
    ACTIONS(6496), 1,
      sym_integer_literal,
    STATE(5945), 1,
      sym__simple_type,
    STATE(6020), 1,
      sym_identifier,
    STATE(6416), 1,
      sym__soft_identifier,
    STATE(6457), 1,
      sym__annotated_type,
    STATE(9690), 1,
      sym_annotated_type,
    STATE(10953), 1,
      sym__non_null_literal,
    STATE(11105), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12463), 1,
      sym__infix_type_choice,
    STATE(12989), 1,
      sym__type,
    STATE(15087), 1,
      sym_parameter_types,
    STATE(16929), 1,
      sym_stable_identifier,
    ACTIONS(6498), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6500), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6502), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3239), 2,
      sym_comment,
      sym_block_comment,
    STATE(10584), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11110), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6488), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7126), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [111098] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(16724), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3240), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [111219] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15457), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3241), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [111340] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6414), 1,
      anon_sym_COLON,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(6418), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(12989), 1,
      sym__type,
    STATE(15021), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3242), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [111461] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6158), 1,
      anon_sym_COLON,
    ACTIONS(6160), 1,
      anon_sym_LBRACE,
    ACTIONS(6162), 1,
      anon_sym_LBRACK,
    ACTIONS(6164), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(7387), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(10986), 1,
      sym__non_null_literal,
    STATE(10988), 1,
      sym_literal_type,
    STATE(11158), 1,
      sym_template_body,
    STATE(11277), 1,
      sym__type,
    STATE(12334), 1,
      sym__infix_type_choice,
    STATE(15319), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3243), 2,
      sym_comment,
      sym_block_comment,
    STATE(10591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11237), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11264), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [111582] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1252), 1,
      sym_integer_literal,
    ACTIONS(6344), 1,
      sym__alpha_identifier,
    ACTIONS(6346), 1,
      anon_sym_COLON,
    ACTIONS(6348), 1,
      anon_sym_LBRACE,
    ACTIONS(6350), 1,
      anon_sym__,
    ACTIONS(6352), 1,
      anon_sym_LBRACK,
    ACTIONS(6356), 1,
      anon_sym_LPAREN,
    ACTIONS(6358), 1,
      sym__backquoted_id,
    ACTIONS(6360), 1,
      sym_operator_identifier,
    STATE(5615), 1,
      sym__simple_type,
    STATE(5826), 1,
      sym__annotated_type,
    STATE(6141), 1,
      sym__soft_identifier,
    STATE(6576), 1,
      sym_identifier,
    STATE(9227), 1,
      sym_annotated_type,
    STATE(10767), 1,
      sym_literal_type,
    STATE(10838), 1,
      sym__non_null_literal,
    STATE(11144), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12506), 1,
      sym__infix_type_choice,
    STATE(15062), 1,
      sym_parameter_types,
    STATE(17089), 1,
      sym_stable_identifier,
    ACTIONS(1254), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1256), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1260), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3244), 2,
      sym_comment,
      sym_block_comment,
    STATE(5352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8784), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10368), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6354), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7247), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [111703] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6172), 1,
      anon_sym_LBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(11890), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12386), 1,
      sym__infix_type_choice,
    STATE(15018), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3245), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [111824] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6172), 1,
      anon_sym_LBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(11898), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12386), 1,
      sym__infix_type_choice,
    STATE(15018), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3246), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [111945] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6172), 1,
      anon_sym_LBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(11899), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12386), 1,
      sym__infix_type_choice,
    STATE(15018), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3247), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [112066] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14752), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3248), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [112187] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6172), 1,
      anon_sym_LBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(11900), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12386), 1,
      sym__infix_type_choice,
    STATE(15018), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3249), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [112308] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17426), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3250), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [112429] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1252), 1,
      sym_integer_literal,
    ACTIONS(6344), 1,
      sym__alpha_identifier,
    ACTIONS(6346), 1,
      anon_sym_COLON,
    ACTIONS(6348), 1,
      anon_sym_LBRACE,
    ACTIONS(6350), 1,
      anon_sym__,
    ACTIONS(6352), 1,
      anon_sym_LBRACK,
    ACTIONS(6356), 1,
      anon_sym_LPAREN,
    ACTIONS(6358), 1,
      sym__backquoted_id,
    ACTIONS(6360), 1,
      sym_operator_identifier,
    STATE(5615), 1,
      sym__simple_type,
    STATE(5826), 1,
      sym__annotated_type,
    STATE(6141), 1,
      sym__soft_identifier,
    STATE(6576), 1,
      sym_identifier,
    STATE(9227), 1,
      sym_annotated_type,
    STATE(10767), 1,
      sym_literal_type,
    STATE(10838), 1,
      sym__non_null_literal,
    STATE(11146), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12506), 1,
      sym__infix_type_choice,
    STATE(15062), 1,
      sym_parameter_types,
    STATE(17089), 1,
      sym_stable_identifier,
    ACTIONS(1254), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1256), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1260), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3251), 2,
      sym_comment,
      sym_block_comment,
    STATE(5352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8784), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10368), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6354), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7247), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [112550] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17460), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3252), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [112671] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(922), 1,
      sym_integer_literal,
    ACTIONS(6346), 1,
      anon_sym_COLON,
    ACTIONS(6348), 1,
      anon_sym_LBRACE,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6506), 1,
      anon_sym__,
    ACTIONS(6508), 1,
      anon_sym_LBRACK,
    ACTIONS(6512), 1,
      anon_sym_LPAREN,
    ACTIONS(6514), 1,
      sym__backquoted_id,
    ACTIONS(6516), 1,
      sym_operator_identifier,
    STATE(4404), 1,
      sym__annotated_type,
    STATE(4455), 1,
      sym__simple_type,
    STATE(4474), 1,
      sym__soft_identifier,
    STATE(4498), 1,
      sym_identifier,
    STATE(5768), 1,
      sym_annotated_type,
    STATE(8749), 1,
      sym_literal_type,
    STATE(9031), 1,
      sym__non_null_literal,
    STATE(11182), 1,
      sym_template_body,
    STATE(11567), 1,
      sym__type,
    STATE(12514), 1,
      sym__infix_type_choice,
    STATE(15089), 1,
      sym_parameter_types,
    STATE(17119), 1,
      sym_stable_identifier,
    ACTIONS(924), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(926), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(930), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3253), 2,
      sym_comment,
      sym_block_comment,
    STATE(5352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5805), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7492), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6510), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4591), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [112792] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15683), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3254), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [112913] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1252), 1,
      sym_integer_literal,
    ACTIONS(6344), 1,
      sym__alpha_identifier,
    ACTIONS(6346), 1,
      anon_sym_COLON,
    ACTIONS(6348), 1,
      anon_sym_LBRACE,
    ACTIONS(6350), 1,
      anon_sym__,
    ACTIONS(6352), 1,
      anon_sym_LBRACK,
    ACTIONS(6356), 1,
      anon_sym_LPAREN,
    ACTIONS(6358), 1,
      sym__backquoted_id,
    ACTIONS(6360), 1,
      sym_operator_identifier,
    STATE(5615), 1,
      sym__simple_type,
    STATE(5826), 1,
      sym__annotated_type,
    STATE(6141), 1,
      sym__soft_identifier,
    STATE(6576), 1,
      sym_identifier,
    STATE(9227), 1,
      sym_annotated_type,
    STATE(10767), 1,
      sym_literal_type,
    STATE(10838), 1,
      sym__non_null_literal,
    STATE(11147), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12506), 1,
      sym__infix_type_choice,
    STATE(15062), 1,
      sym_parameter_types,
    STATE(17089), 1,
      sym_stable_identifier,
    ACTIONS(1254), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1256), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1260), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3255), 2,
      sym_comment,
      sym_block_comment,
    STATE(5352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8784), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10368), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6354), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7247), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [113034] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1252), 1,
      sym_integer_literal,
    ACTIONS(6344), 1,
      sym__alpha_identifier,
    ACTIONS(6346), 1,
      anon_sym_COLON,
    ACTIONS(6348), 1,
      anon_sym_LBRACE,
    ACTIONS(6350), 1,
      anon_sym__,
    ACTIONS(6352), 1,
      anon_sym_LBRACK,
    ACTIONS(6356), 1,
      anon_sym_LPAREN,
    ACTIONS(6358), 1,
      sym__backquoted_id,
    ACTIONS(6360), 1,
      sym_operator_identifier,
    STATE(5615), 1,
      sym__simple_type,
    STATE(5826), 1,
      sym__annotated_type,
    STATE(6141), 1,
      sym__soft_identifier,
    STATE(6576), 1,
      sym_identifier,
    STATE(9227), 1,
      sym_annotated_type,
    STATE(10767), 1,
      sym_literal_type,
    STATE(10838), 1,
      sym__non_null_literal,
    STATE(11148), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12506), 1,
      sym__infix_type_choice,
    STATE(15062), 1,
      sym_parameter_types,
    STATE(17089), 1,
      sym_stable_identifier,
    ACTIONS(1254), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1256), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1260), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3256), 2,
      sym_comment,
      sym_block_comment,
    STATE(5352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8784), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10368), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6354), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7247), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [113155] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6134), 1,
      anon_sym_COLON,
    ACTIONS(6136), 1,
      anon_sym_LBRACE,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6140), 1,
      anon_sym_LBRACK,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6150), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(8699), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(11171), 1,
      sym__non_null_literal,
    STATE(11172), 1,
      sym_literal_type,
    STATE(11544), 1,
      sym__type,
    STATE(11576), 1,
      sym_template_body,
    STATE(12342), 1,
      sym__infix_type_choice,
    STATE(15615), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3257), 2,
      sym_comment,
      sym_block_comment,
    STATE(11119), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11526), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11592), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [113276] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14828), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3258), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [113397] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2042), 1,
      sym_integer_literal,
    ACTIONS(6518), 1,
      sym__alpha_identifier,
    ACTIONS(6520), 1,
      anon_sym_COLON,
    ACTIONS(6522), 1,
      anon_sym_LBRACE,
    ACTIONS(6524), 1,
      anon_sym__,
    ACTIONS(6526), 1,
      anon_sym_LBRACK,
    ACTIONS(6530), 1,
      anon_sym_LPAREN,
    ACTIONS(6532), 1,
      sym__backquoted_id,
    ACTIONS(6534), 1,
      sym_operator_identifier,
    STATE(7297), 1,
      sym__annotated_type,
    STATE(7378), 1,
      sym__simple_type,
    STATE(7649), 1,
      sym_identifier,
    STATE(7843), 1,
      sym__soft_identifier,
    STATE(9842), 1,
      sym_annotated_type,
    STATE(11159), 1,
      sym_literal_type,
    STATE(11175), 1,
      sym__non_null_literal,
    STATE(11868), 1,
      sym_template_body,
    STATE(11991), 1,
      sym__type,
    STATE(12478), 1,
      sym__infix_type_choice,
    STATE(15061), 1,
      sym_parameter_types,
    STATE(16974), 1,
      sym_stable_identifier,
    ACTIONS(2044), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2046), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2050), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3259), 2,
      sym_comment,
      sym_block_comment,
    STATE(6450), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9825), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10747), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6528), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [113518] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16542), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3260), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [113639] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(16728), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3261), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [113760] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14768), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3262), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [113881] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6158), 1,
      anon_sym_COLON,
    ACTIONS(6160), 1,
      anon_sym_LBRACE,
    ACTIONS(6162), 1,
      anon_sym_LBRACK,
    ACTIONS(6164), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(7387), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(10986), 1,
      sym__non_null_literal,
    STATE(10988), 1,
      sym_literal_type,
    STATE(11158), 1,
      sym_template_body,
    STATE(11279), 1,
      sym__type,
    STATE(12334), 1,
      sym__infix_type_choice,
    STATE(15319), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3263), 2,
      sym_comment,
      sym_block_comment,
    STATE(10591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11237), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11264), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [114002] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6158), 1,
      anon_sym_COLON,
    ACTIONS(6160), 1,
      anon_sym_LBRACE,
    ACTIONS(6162), 1,
      anon_sym_LBRACK,
    ACTIONS(6164), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(7387), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(10986), 1,
      sym__non_null_literal,
    STATE(10988), 1,
      sym_literal_type,
    STATE(11158), 1,
      sym_template_body,
    STATE(11280), 1,
      sym__type,
    STATE(12334), 1,
      sym__infix_type_choice,
    STATE(15319), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3264), 2,
      sym_comment,
      sym_block_comment,
    STATE(10591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11237), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11264), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [114123] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1506), 1,
      sym_integer_literal,
    ACTIONS(6370), 1,
      sym__alpha_identifier,
    ACTIONS(6372), 1,
      anon_sym_COLON,
    ACTIONS(6374), 1,
      anon_sym_LBRACE,
    ACTIONS(6376), 1,
      anon_sym__,
    ACTIONS(6378), 1,
      anon_sym_LBRACK,
    ACTIONS(6382), 1,
      anon_sym_LPAREN,
    ACTIONS(6384), 1,
      sym__backquoted_id,
    ACTIONS(6386), 1,
      sym_operator_identifier,
    STATE(5390), 1,
      sym__annotated_type,
    STATE(5425), 1,
      sym__simple_type,
    STATE(5485), 1,
      sym__soft_identifier,
    STATE(5665), 1,
      sym_identifier,
    STATE(8696), 1,
      sym_annotated_type,
    STATE(10458), 1,
      sym__non_null_literal,
    STATE(10643), 1,
      sym_literal_type,
    STATE(12457), 1,
      sym__infix_type_choice,
    STATE(13167), 1,
      sym_template_body,
    STATE(13300), 1,
      sym__type,
    STATE(15020), 1,
      sym_parameter_types,
    STATE(16818), 1,
      sym_stable_identifier,
    ACTIONS(1508), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1510), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1514), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3265), 2,
      sym_comment,
      sym_block_comment,
    STATE(8229), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8419), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9754), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13189), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6380), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6556), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [114244] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15617), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3266), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [114365] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4212), 1,
      anon_sym_COLON,
    ACTIONS(4214), 1,
      anon_sym_LBRACE,
    ACTIONS(4286), 1,
      sym__alpha_identifier,
    ACTIONS(4288), 1,
      anon_sym__,
    ACTIONS(4292), 1,
      anon_sym_LBRACK,
    ACTIONS(4298), 1,
      sym__backquoted_id,
    ACTIONS(4302), 1,
      sym_integer_literal,
    ACTIONS(6536), 1,
      anon_sym_LPAREN,
    ACTIONS(6538), 1,
      sym_operator_identifier,
    STATE(4439), 1,
      sym__annotated_type,
    STATE(4440), 1,
      sym__simple_type,
    STATE(4467), 1,
      sym__soft_identifier,
    STATE(4504), 1,
      sym_identifier,
    STATE(5824), 1,
      sym_annotated_type,
    STATE(9176), 1,
      sym__non_null_literal,
    STATE(9177), 1,
      sym_literal_type,
    STATE(11501), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12389), 1,
      sym__infix_type_choice,
    STATE(15019), 1,
      sym_parameter_types,
    STATE(16363), 1,
      sym_stable_identifier,
    ACTIONS(4304), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4306), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4310), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3267), 2,
      sym_comment,
      sym_block_comment,
    STATE(7606), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9064), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11717), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4294), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4713), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [114486] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17425), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3268), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [114607] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17449), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3269), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [114728] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6158), 1,
      anon_sym_COLON,
    ACTIONS(6160), 1,
      anon_sym_LBRACE,
    ACTIONS(6162), 1,
      anon_sym_LBRACK,
    ACTIONS(6164), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(7387), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(10986), 1,
      sym__non_null_literal,
    STATE(10988), 1,
      sym_literal_type,
    STATE(11158), 1,
      sym_template_body,
    STATE(11281), 1,
      sym__type,
    STATE(12334), 1,
      sym__infix_type_choice,
    STATE(15319), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3270), 2,
      sym_comment,
      sym_block_comment,
    STATE(10591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11237), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11264), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [114849] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14850), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3271), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [114970] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7460), 1,
      sym__annotated_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(11284), 1,
      sym__type,
    STATE(12373), 1,
      sym__infix_type_choice,
    STATE(15843), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3272), 2,
      sym_comment,
      sym_block_comment,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [115091] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1252), 1,
      sym_integer_literal,
    ACTIONS(6344), 1,
      sym__alpha_identifier,
    ACTIONS(6346), 1,
      anon_sym_COLON,
    ACTIONS(6348), 1,
      anon_sym_LBRACE,
    ACTIONS(6350), 1,
      anon_sym__,
    ACTIONS(6352), 1,
      anon_sym_LBRACK,
    ACTIONS(6356), 1,
      anon_sym_LPAREN,
    ACTIONS(6358), 1,
      sym__backquoted_id,
    ACTIONS(6360), 1,
      sym_operator_identifier,
    STATE(5615), 1,
      sym__simple_type,
    STATE(5826), 1,
      sym__annotated_type,
    STATE(6141), 1,
      sym__soft_identifier,
    STATE(6576), 1,
      sym_identifier,
    STATE(9227), 1,
      sym_annotated_type,
    STATE(10767), 1,
      sym_literal_type,
    STATE(10838), 1,
      sym__non_null_literal,
    STATE(11142), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12506), 1,
      sym__infix_type_choice,
    STATE(15062), 1,
      sym_parameter_types,
    STATE(17089), 1,
      sym_stable_identifier,
    ACTIONS(1254), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1256), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1260), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3273), 2,
      sym_comment,
      sym_block_comment,
    STATE(5352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8784), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10368), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6354), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7247), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [115212] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4664), 1,
      sym__alpha_identifier,
    ACTIONS(4666), 1,
      anon_sym_COLON,
    ACTIONS(4668), 1,
      anon_sym_LBRACE,
    ACTIONS(4670), 1,
      anon_sym__,
    ACTIONS(4674), 1,
      anon_sym_LBRACK,
    ACTIONS(4682), 1,
      sym__backquoted_id,
    ACTIONS(4686), 1,
      sym_integer_literal,
    ACTIONS(6542), 1,
      anon_sym_LPAREN,
    ACTIONS(6544), 1,
      sym_operator_identifier,
    STATE(4972), 1,
      sym__annotated_type,
    STATE(5002), 1,
      sym__simple_type,
    STATE(5067), 1,
      sym_identifier,
    STATE(5176), 1,
      sym__soft_identifier,
    STATE(7967), 1,
      sym_annotated_type,
    STATE(10369), 1,
      sym_literal_type,
    STATE(10429), 1,
      sym__non_null_literal,
    STATE(12460), 1,
      sym__infix_type_choice,
    STATE(13040), 1,
      sym__type,
    STATE(13199), 1,
      sym_template_body,
    STATE(15231), 1,
      sym_parameter_types,
    STATE(16905), 1,
      sym_stable_identifier,
    ACTIONS(4688), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4690), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4694), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3274), 2,
      sym_comment,
      sym_block_comment,
    STATE(9523), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10326), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13289), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13116), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4676), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5890), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [115333] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6482), 1,
      sym__alpha_identifier,
    ACTIONS(6484), 1,
      anon_sym__,
    ACTIONS(6486), 1,
      anon_sym_LBRACK,
    ACTIONS(6490), 1,
      anon_sym_LPAREN,
    ACTIONS(6492), 1,
      sym__backquoted_id,
    ACTIONS(6494), 1,
      sym_operator_identifier,
    ACTIONS(6496), 1,
      sym_integer_literal,
    STATE(5945), 1,
      sym__simple_type,
    STATE(6020), 1,
      sym_identifier,
    STATE(6416), 1,
      sym__soft_identifier,
    STATE(6457), 1,
      sym__annotated_type,
    STATE(9690), 1,
      sym_annotated_type,
    STATE(10953), 1,
      sym__non_null_literal,
    STATE(11105), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12463), 1,
      sym__infix_type_choice,
    STATE(12686), 1,
      sym__type,
    STATE(15087), 1,
      sym_parameter_types,
    STATE(16929), 1,
      sym_stable_identifier,
    ACTIONS(6498), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6500), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6502), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3275), 2,
      sym_comment,
      sym_block_comment,
    STATE(10584), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11110), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6488), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7126), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [115454] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7460), 1,
      sym__annotated_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(11298), 1,
      sym__type,
    STATE(12373), 1,
      sym__infix_type_choice,
    STATE(15843), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3276), 2,
      sym_comment,
      sym_block_comment,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [115575] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7460), 1,
      sym__annotated_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(11302), 1,
      sym__type,
    STATE(12373), 1,
      sym__infix_type_choice,
    STATE(15843), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3277), 2,
      sym_comment,
      sym_block_comment,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [115696] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14913), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3278), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [115817] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4212), 1,
      anon_sym_COLON,
    ACTIONS(4214), 1,
      anon_sym_LBRACE,
    ACTIONS(4286), 1,
      sym__alpha_identifier,
    ACTIONS(4288), 1,
      anon_sym__,
    ACTIONS(4292), 1,
      anon_sym_LBRACK,
    ACTIONS(4298), 1,
      sym__backquoted_id,
    ACTIONS(4302), 1,
      sym_integer_literal,
    ACTIONS(6536), 1,
      anon_sym_LPAREN,
    ACTIONS(6538), 1,
      sym_operator_identifier,
    STATE(4439), 1,
      sym__annotated_type,
    STATE(4440), 1,
      sym__simple_type,
    STATE(4467), 1,
      sym__soft_identifier,
    STATE(4504), 1,
      sym_identifier,
    STATE(5824), 1,
      sym_annotated_type,
    STATE(9176), 1,
      sym__non_null_literal,
    STATE(9177), 1,
      sym_literal_type,
    STATE(11533), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12389), 1,
      sym__infix_type_choice,
    STATE(15019), 1,
      sym_parameter_types,
    STATE(16363), 1,
      sym_stable_identifier,
    ACTIONS(4304), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4306), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4310), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3279), 2,
      sym_comment,
      sym_block_comment,
    STATE(7606), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9064), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11717), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4294), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4713), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [115938] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(16990), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3280), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [116059] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4212), 1,
      anon_sym_COLON,
    ACTIONS(4214), 1,
      anon_sym_LBRACE,
    ACTIONS(4286), 1,
      sym__alpha_identifier,
    ACTIONS(4288), 1,
      anon_sym__,
    ACTIONS(4292), 1,
      anon_sym_LBRACK,
    ACTIONS(4298), 1,
      sym__backquoted_id,
    ACTIONS(4302), 1,
      sym_integer_literal,
    ACTIONS(6536), 1,
      anon_sym_LPAREN,
    ACTIONS(6538), 1,
      sym_operator_identifier,
    STATE(4439), 1,
      sym__annotated_type,
    STATE(4440), 1,
      sym__simple_type,
    STATE(4467), 1,
      sym__soft_identifier,
    STATE(4504), 1,
      sym_identifier,
    STATE(5824), 1,
      sym_annotated_type,
    STATE(9176), 1,
      sym__non_null_literal,
    STATE(9177), 1,
      sym_literal_type,
    STATE(11536), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12389), 1,
      sym__infix_type_choice,
    STATE(15019), 1,
      sym_parameter_types,
    STATE(16363), 1,
      sym_stable_identifier,
    ACTIONS(4304), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4306), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4310), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3281), 2,
      sym_comment,
      sym_block_comment,
    STATE(7606), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9064), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11717), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4294), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4713), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [116180] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17055), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3282), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [116301] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4212), 1,
      anon_sym_COLON,
    ACTIONS(4214), 1,
      anon_sym_LBRACE,
    ACTIONS(4286), 1,
      sym__alpha_identifier,
    ACTIONS(4288), 1,
      anon_sym__,
    ACTIONS(4292), 1,
      anon_sym_LBRACK,
    ACTIONS(4298), 1,
      sym__backquoted_id,
    ACTIONS(4302), 1,
      sym_integer_literal,
    ACTIONS(6536), 1,
      anon_sym_LPAREN,
    ACTIONS(6538), 1,
      sym_operator_identifier,
    STATE(4439), 1,
      sym__annotated_type,
    STATE(4440), 1,
      sym__simple_type,
    STATE(4467), 1,
      sym__soft_identifier,
    STATE(4504), 1,
      sym_identifier,
    STATE(5824), 1,
      sym_annotated_type,
    STATE(9176), 1,
      sym__non_null_literal,
    STATE(9177), 1,
      sym_literal_type,
    STATE(11537), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12389), 1,
      sym__infix_type_choice,
    STATE(15019), 1,
      sym_parameter_types,
    STATE(16363), 1,
      sym_stable_identifier,
    ACTIONS(4304), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4306), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4310), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3283), 2,
      sym_comment,
      sym_block_comment,
    STATE(7606), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9064), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11717), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4294), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4713), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [116422] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14931), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3284), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [116543] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4212), 1,
      anon_sym_COLON,
    ACTIONS(4214), 1,
      anon_sym_LBRACE,
    ACTIONS(4286), 1,
      sym__alpha_identifier,
    ACTIONS(4288), 1,
      anon_sym__,
    ACTIONS(4292), 1,
      anon_sym_LBRACK,
    ACTIONS(4298), 1,
      sym__backquoted_id,
    ACTIONS(4302), 1,
      sym_integer_literal,
    ACTIONS(6536), 1,
      anon_sym_LPAREN,
    ACTIONS(6538), 1,
      sym_operator_identifier,
    STATE(4439), 1,
      sym__annotated_type,
    STATE(4440), 1,
      sym__simple_type,
    STATE(4467), 1,
      sym__soft_identifier,
    STATE(4504), 1,
      sym_identifier,
    STATE(5824), 1,
      sym_annotated_type,
    STATE(9176), 1,
      sym__non_null_literal,
    STATE(9177), 1,
      sym_literal_type,
    STATE(11538), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12389), 1,
      sym__infix_type_choice,
    STATE(15019), 1,
      sym_parameter_types,
    STATE(16363), 1,
      sym_stable_identifier,
    ACTIONS(4304), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4306), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4310), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3285), 2,
      sym_comment,
      sym_block_comment,
    STATE(7606), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9064), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11717), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4294), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4713), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [116664] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2042), 1,
      sym_integer_literal,
    ACTIONS(6518), 1,
      sym__alpha_identifier,
    ACTIONS(6520), 1,
      anon_sym_COLON,
    ACTIONS(6522), 1,
      anon_sym_LBRACE,
    ACTIONS(6524), 1,
      anon_sym__,
    ACTIONS(6526), 1,
      anon_sym_LBRACK,
    ACTIONS(6530), 1,
      anon_sym_LPAREN,
    ACTIONS(6532), 1,
      sym__backquoted_id,
    ACTIONS(6534), 1,
      sym_operator_identifier,
    STATE(7297), 1,
      sym__annotated_type,
    STATE(7378), 1,
      sym__simple_type,
    STATE(7649), 1,
      sym_identifier,
    STATE(7843), 1,
      sym__soft_identifier,
    STATE(9842), 1,
      sym_annotated_type,
    STATE(11159), 1,
      sym_literal_type,
    STATE(11175), 1,
      sym__non_null_literal,
    STATE(11868), 1,
      sym_template_body,
    STATE(12007), 1,
      sym__type,
    STATE(12478), 1,
      sym__infix_type_choice,
    STATE(15061), 1,
      sym_parameter_types,
    STATE(16974), 1,
      sym_stable_identifier,
    ACTIONS(2044), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2046), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2050), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3286), 2,
      sym_comment,
      sym_block_comment,
    STATE(6450), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9825), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10747), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6528), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [116785] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2042), 1,
      sym_integer_literal,
    ACTIONS(6518), 1,
      sym__alpha_identifier,
    ACTIONS(6520), 1,
      anon_sym_COLON,
    ACTIONS(6522), 1,
      anon_sym_LBRACE,
    ACTIONS(6524), 1,
      anon_sym__,
    ACTIONS(6526), 1,
      anon_sym_LBRACK,
    ACTIONS(6530), 1,
      anon_sym_LPAREN,
    ACTIONS(6532), 1,
      sym__backquoted_id,
    ACTIONS(6534), 1,
      sym_operator_identifier,
    STATE(7297), 1,
      sym__annotated_type,
    STATE(7378), 1,
      sym__simple_type,
    STATE(7649), 1,
      sym_identifier,
    STATE(7843), 1,
      sym__soft_identifier,
    STATE(9842), 1,
      sym_annotated_type,
    STATE(11159), 1,
      sym_literal_type,
    STATE(11175), 1,
      sym__non_null_literal,
    STATE(11868), 1,
      sym_template_body,
    STATE(12010), 1,
      sym__type,
    STATE(12478), 1,
      sym__infix_type_choice,
    STATE(15061), 1,
      sym_parameter_types,
    STATE(16974), 1,
      sym_stable_identifier,
    ACTIONS(2044), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2046), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2050), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3287), 2,
      sym_comment,
      sym_block_comment,
    STATE(6450), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9825), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10747), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6528), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [116906] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1872), 1,
      sym_integer_literal,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6426), 1,
      anon_sym__,
    ACTIONS(6428), 1,
      anon_sym_LBRACK,
    ACTIONS(6432), 1,
      anon_sym_LPAREN,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(6436), 1,
      sym_operator_identifier,
    STATE(6914), 1,
      sym__simple_type,
    STATE(6978), 1,
      sym__annotated_type,
    STATE(7465), 1,
      sym_identifier,
    STATE(7913), 1,
      sym__soft_identifier,
    STATE(10061), 1,
      sym_annotated_type,
    STATE(11196), 1,
      sym_literal_type,
    STATE(11321), 1,
      sym__non_null_literal,
    STATE(11929), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12510), 1,
      sym__infix_type_choice,
    STATE(15063), 1,
      sym_parameter_types,
    STATE(17101), 1,
      sym_stable_identifier,
    ACTIONS(1874), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1876), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1880), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3288), 2,
      sym_comment,
      sym_block_comment,
    STATE(6282), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9797), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10719), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8446), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [117027] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1102), 1,
      sym_integer_literal,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6546), 1,
      sym__alpha_identifier,
    ACTIONS(6548), 1,
      anon_sym__,
    ACTIONS(6550), 1,
      anon_sym_LBRACK,
    ACTIONS(6554), 1,
      anon_sym_LPAREN,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(6558), 1,
      sym_operator_identifier,
    STATE(4676), 1,
      sym__simple_type,
    STATE(4710), 1,
      sym__annotated_type,
    STATE(4934), 1,
      sym_identifier,
    STATE(4937), 1,
      sym__soft_identifier,
    STATE(6975), 1,
      sym_annotated_type,
    STATE(9786), 1,
      sym_literal_type,
    STATE(9814), 1,
      sym__non_null_literal,
    STATE(12037), 1,
      sym_template_body,
    STATE(12459), 1,
      sym__type,
    STATE(12516), 1,
      sym__infix_type_choice,
    STATE(15090), 1,
      sym_parameter_types,
    STATE(17125), 1,
      sym_stable_identifier,
    ACTIONS(1104), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1106), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1110), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3289), 2,
      sym_comment,
      sym_block_comment,
    STATE(6282), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7105), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8765), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5066), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [117148] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1872), 1,
      sym_integer_literal,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6426), 1,
      anon_sym__,
    ACTIONS(6428), 1,
      anon_sym_LBRACK,
    ACTIONS(6432), 1,
      anon_sym_LPAREN,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(6436), 1,
      sym_operator_identifier,
    STATE(6914), 1,
      sym__simple_type,
    STATE(6978), 1,
      sym__annotated_type,
    STATE(7465), 1,
      sym_identifier,
    STATE(7913), 1,
      sym__soft_identifier,
    STATE(10061), 1,
      sym_annotated_type,
    STATE(11196), 1,
      sym_literal_type,
    STATE(11321), 1,
      sym__non_null_literal,
    STATE(11935), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12510), 1,
      sym__infix_type_choice,
    STATE(15063), 1,
      sym_parameter_types,
    STATE(17101), 1,
      sym_stable_identifier,
    ACTIONS(1874), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1876), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1880), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3290), 2,
      sym_comment,
      sym_block_comment,
    STATE(6282), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9797), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10719), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8446), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [117269] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14986), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3291), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [117390] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17684), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3292), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [117511] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17694), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3293), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [117632] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7460), 1,
      sym__annotated_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(11303), 1,
      sym__type,
    STATE(12373), 1,
      sym__infix_type_choice,
    STATE(15843), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3294), 2,
      sym_comment,
      sym_block_comment,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [117753] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14994), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3295), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [117874] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7460), 1,
      sym__annotated_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(11304), 1,
      sym__type,
    STATE(12373), 1,
      sym__infix_type_choice,
    STATE(15843), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3296), 2,
      sym_comment,
      sym_block_comment,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [117995] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1872), 1,
      sym_integer_literal,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6426), 1,
      anon_sym__,
    ACTIONS(6428), 1,
      anon_sym_LBRACK,
    ACTIONS(6432), 1,
      anon_sym_LPAREN,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(6436), 1,
      sym_operator_identifier,
    STATE(6914), 1,
      sym__simple_type,
    STATE(6978), 1,
      sym__annotated_type,
    STATE(7465), 1,
      sym_identifier,
    STATE(7913), 1,
      sym__soft_identifier,
    STATE(10061), 1,
      sym_annotated_type,
    STATE(11196), 1,
      sym_literal_type,
    STATE(11321), 1,
      sym__non_null_literal,
    STATE(11937), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12510), 1,
      sym__infix_type_choice,
    STATE(15063), 1,
      sym_parameter_types,
    STATE(17101), 1,
      sym_stable_identifier,
    ACTIONS(1874), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1876), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1880), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3297), 2,
      sym_comment,
      sym_block_comment,
    STATE(6282), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9797), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10719), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8446), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [118116] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6564), 1,
      anon_sym_LBRACK,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(14332), 1,
      sym__type,
    STATE(15084), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3298), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [118237] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1872), 1,
      sym_integer_literal,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6426), 1,
      anon_sym__,
    ACTIONS(6428), 1,
      anon_sym_LBRACK,
    ACTIONS(6432), 1,
      anon_sym_LPAREN,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(6436), 1,
      sym_operator_identifier,
    STATE(6914), 1,
      sym__simple_type,
    STATE(6978), 1,
      sym__annotated_type,
    STATE(7465), 1,
      sym_identifier,
    STATE(7913), 1,
      sym__soft_identifier,
    STATE(10061), 1,
      sym_annotated_type,
    STATE(11196), 1,
      sym_literal_type,
    STATE(11321), 1,
      sym__non_null_literal,
    STATE(11942), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12510), 1,
      sym__infix_type_choice,
    STATE(15063), 1,
      sym_parameter_types,
    STATE(17101), 1,
      sym_stable_identifier,
    ACTIONS(1874), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1876), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1880), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3299), 2,
      sym_comment,
      sym_block_comment,
    STATE(6282), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9797), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10719), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8446), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [118358] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    ACTIONS(6574), 1,
      anon_sym_LBRACK,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(14059), 1,
      sym__type,
    STATE(15107), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3300), 2,
      sym_comment,
      sym_block_comment,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [118479] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15046), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3301), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [118600] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    ACTIONS(6576), 1,
      anon_sym_LBRACK,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(6890), 1,
      sym__annotated_type,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(12405), 1,
      sym__infix_type_choice,
    STATE(13959), 1,
      sym__type,
    STATE(15140), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3302), 2,
      sym_comment,
      sym_block_comment,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [118721] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16444), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3303), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [118842] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16476), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3304), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [118963] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15067), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3305), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [119084] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6564), 1,
      anon_sym_LBRACK,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11284), 1,
      sym__type,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(15084), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3306), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [119205] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2042), 1,
      sym_integer_literal,
    ACTIONS(6518), 1,
      sym__alpha_identifier,
    ACTIONS(6520), 1,
      anon_sym_COLON,
    ACTIONS(6522), 1,
      anon_sym_LBRACE,
    ACTIONS(6524), 1,
      anon_sym__,
    ACTIONS(6526), 1,
      anon_sym_LBRACK,
    ACTIONS(6530), 1,
      anon_sym_LPAREN,
    ACTIONS(6532), 1,
      sym__backquoted_id,
    ACTIONS(6534), 1,
      sym_operator_identifier,
    STATE(7297), 1,
      sym__annotated_type,
    STATE(7378), 1,
      sym__simple_type,
    STATE(7649), 1,
      sym_identifier,
    STATE(7843), 1,
      sym__soft_identifier,
    STATE(9842), 1,
      sym_annotated_type,
    STATE(11159), 1,
      sym_literal_type,
    STATE(11175), 1,
      sym__non_null_literal,
    STATE(11868), 1,
      sym_template_body,
    STATE(12013), 1,
      sym__type,
    STATE(12478), 1,
      sym__infix_type_choice,
    STATE(15061), 1,
      sym_parameter_types,
    STATE(16974), 1,
      sym_stable_identifier,
    ACTIONS(2044), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2046), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2050), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3307), 2,
      sym_comment,
      sym_block_comment,
    STATE(6450), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9825), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10747), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6528), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [119326] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6580), 1,
      anon_sym__,
    ACTIONS(6582), 1,
      anon_sym_LBRACK,
    ACTIONS(6586), 1,
      anon_sym_LPAREN,
    ACTIONS(6588), 1,
      sym__backquoted_id,
    ACTIONS(6590), 1,
      sym_operator_identifier,
    ACTIONS(6592), 1,
      sym_integer_literal,
    STATE(5708), 1,
      sym__simple_type,
    STATE(6199), 1,
      sym__soft_identifier,
    STATE(6337), 1,
      sym_identifier,
    STATE(6370), 1,
      sym__annotated_type,
    STATE(9519), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11031), 1,
      sym__non_null_literal,
    STATE(11032), 1,
      sym_literal_type,
    STATE(12402), 1,
      sym__infix_type_choice,
    STATE(13955), 1,
      sym__type,
    STATE(15123), 1,
      sym_parameter_types,
    STATE(16404), 1,
      sym_stable_identifier,
    ACTIONS(6594), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6596), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6598), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3308), 2,
      sym_comment,
      sym_block_comment,
    STATE(10604), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11005), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7227), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [119447] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1506), 1,
      sym_integer_literal,
    ACTIONS(6370), 1,
      sym__alpha_identifier,
    ACTIONS(6372), 1,
      anon_sym_COLON,
    ACTIONS(6374), 1,
      anon_sym_LBRACE,
    ACTIONS(6376), 1,
      anon_sym__,
    ACTIONS(6378), 1,
      anon_sym_LBRACK,
    ACTIONS(6382), 1,
      anon_sym_LPAREN,
    ACTIONS(6384), 1,
      sym__backquoted_id,
    ACTIONS(6386), 1,
      sym_operator_identifier,
    STATE(5390), 1,
      sym__annotated_type,
    STATE(5425), 1,
      sym__simple_type,
    STATE(5485), 1,
      sym__soft_identifier,
    STATE(5665), 1,
      sym_identifier,
    STATE(8696), 1,
      sym_annotated_type,
    STATE(10458), 1,
      sym__non_null_literal,
    STATE(10643), 1,
      sym_literal_type,
    STATE(12457), 1,
      sym__infix_type_choice,
    STATE(13167), 1,
      sym_template_body,
    STATE(13555), 1,
      sym__type,
    STATE(15020), 1,
      sym_parameter_types,
    STATE(16818), 1,
      sym_stable_identifier,
    ACTIONS(1508), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1510), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1514), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3309), 2,
      sym_comment,
      sym_block_comment,
    STATE(8229), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8419), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9754), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13189), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6380), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6556), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [119568] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6602), 1,
      anon_sym_COLON,
    ACTIONS(6604), 1,
      anon_sym_LBRACE,
    ACTIONS(6606), 1,
      anon_sym__,
    ACTIONS(6608), 1,
      anon_sym_LBRACK,
    ACTIONS(6612), 1,
      anon_sym_LPAREN,
    ACTIONS(6614), 1,
      sym__backquoted_id,
    ACTIONS(6616), 1,
      sym_operator_identifier,
    ACTIONS(6618), 1,
      sym_integer_literal,
    STATE(5326), 1,
      sym__simple_type,
    STATE(5721), 1,
      sym__annotated_type,
    STATE(5817), 1,
      sym__soft_identifier,
    STATE(5848), 1,
      sym_identifier,
    STATE(9098), 1,
      sym_annotated_type,
    STATE(10650), 1,
      sym__non_null_literal,
    STATE(10651), 1,
      sym_literal_type,
    STATE(10698), 1,
      sym_template_body,
    STATE(11073), 1,
      sym__type,
    STATE(12409), 1,
      sym__infix_type_choice,
    STATE(15275), 1,
      sym_parameter_types,
    STATE(16425), 1,
      sym_stable_identifier,
    ACTIONS(6620), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6622), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6624), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3310), 2,
      sym_comment,
      sym_block_comment,
    STATE(10108), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10517), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10947), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6610), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6472), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [119689] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6602), 1,
      anon_sym_COLON,
    ACTIONS(6604), 1,
      anon_sym_LBRACE,
    ACTIONS(6606), 1,
      anon_sym__,
    ACTIONS(6608), 1,
      anon_sym_LBRACK,
    ACTIONS(6612), 1,
      anon_sym_LPAREN,
    ACTIONS(6614), 1,
      sym__backquoted_id,
    ACTIONS(6616), 1,
      sym_operator_identifier,
    ACTIONS(6618), 1,
      sym_integer_literal,
    STATE(5326), 1,
      sym__simple_type,
    STATE(5721), 1,
      sym__annotated_type,
    STATE(5817), 1,
      sym__soft_identifier,
    STATE(5848), 1,
      sym_identifier,
    STATE(9098), 1,
      sym_annotated_type,
    STATE(10650), 1,
      sym__non_null_literal,
    STATE(10651), 1,
      sym_literal_type,
    STATE(10698), 1,
      sym_template_body,
    STATE(10998), 1,
      sym__type,
    STATE(12409), 1,
      sym__infix_type_choice,
    STATE(15275), 1,
      sym_parameter_types,
    STATE(16425), 1,
      sym_stable_identifier,
    ACTIONS(6620), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6622), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6624), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3311), 2,
      sym_comment,
      sym_block_comment,
    STATE(10108), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10517), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10947), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6610), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6472), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [119810] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15131), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3312), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [119931] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2042), 1,
      sym_integer_literal,
    ACTIONS(6518), 1,
      sym__alpha_identifier,
    ACTIONS(6520), 1,
      anon_sym_COLON,
    ACTIONS(6522), 1,
      anon_sym_LBRACE,
    ACTIONS(6524), 1,
      anon_sym__,
    ACTIONS(6526), 1,
      anon_sym_LBRACK,
    ACTIONS(6530), 1,
      anon_sym_LPAREN,
    ACTIONS(6532), 1,
      sym__backquoted_id,
    ACTIONS(6534), 1,
      sym_operator_identifier,
    STATE(7297), 1,
      sym__annotated_type,
    STATE(7378), 1,
      sym__simple_type,
    STATE(7649), 1,
      sym_identifier,
    STATE(7843), 1,
      sym__soft_identifier,
    STATE(9842), 1,
      sym_annotated_type,
    STATE(11159), 1,
      sym_literal_type,
    STATE(11175), 1,
      sym__non_null_literal,
    STATE(11868), 1,
      sym_template_body,
    STATE(12014), 1,
      sym__type,
    STATE(12478), 1,
      sym__infix_type_choice,
    STATE(15061), 1,
      sym_parameter_types,
    STATE(16974), 1,
      sym_stable_identifier,
    ACTIONS(2044), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2046), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2050), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3313), 2,
      sym_comment,
      sym_block_comment,
    STATE(6450), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9825), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10747), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6528), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [120052] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(16999), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3314), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [120173] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6482), 1,
      sym__alpha_identifier,
    ACTIONS(6484), 1,
      anon_sym__,
    ACTIONS(6486), 1,
      anon_sym_LBRACK,
    ACTIONS(6490), 1,
      anon_sym_LPAREN,
    ACTIONS(6492), 1,
      sym__backquoted_id,
    ACTIONS(6494), 1,
      sym_operator_identifier,
    ACTIONS(6496), 1,
      sym_integer_literal,
    STATE(5945), 1,
      sym__simple_type,
    STATE(6020), 1,
      sym_identifier,
    STATE(6416), 1,
      sym__soft_identifier,
    STATE(6457), 1,
      sym__annotated_type,
    STATE(9690), 1,
      sym_annotated_type,
    STATE(10953), 1,
      sym__non_null_literal,
    STATE(11105), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12463), 1,
      sym__infix_type_choice,
    STATE(12694), 1,
      sym__type,
    STATE(15087), 1,
      sym_parameter_types,
    STATE(16929), 1,
      sym_stable_identifier,
    ACTIONS(6498), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6500), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6502), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3315), 2,
      sym_comment,
      sym_block_comment,
    STATE(10584), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11110), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6488), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7126), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [120294] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17028), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3316), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [120415] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15148), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3317), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [120536] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6564), 1,
      anon_sym_LBRACK,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11298), 1,
      sym__type,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(15084), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3318), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [120657] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1872), 1,
      sym_integer_literal,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6426), 1,
      anon_sym__,
    ACTIONS(6428), 1,
      anon_sym_LBRACK,
    ACTIONS(6432), 1,
      anon_sym_LPAREN,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(6436), 1,
      sym_operator_identifier,
    STATE(6914), 1,
      sym__simple_type,
    STATE(6978), 1,
      sym__annotated_type,
    STATE(7465), 1,
      sym_identifier,
    STATE(7913), 1,
      sym__soft_identifier,
    STATE(10061), 1,
      sym_annotated_type,
    STATE(11196), 1,
      sym_literal_type,
    STATE(11321), 1,
      sym__non_null_literal,
    STATE(11811), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12510), 1,
      sym__infix_type_choice,
    STATE(15063), 1,
      sym_parameter_types,
    STATE(17101), 1,
      sym_stable_identifier,
    ACTIONS(1874), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1876), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1880), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3319), 2,
      sym_comment,
      sym_block_comment,
    STATE(6282), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9797), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10719), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8446), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [120778] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6564), 1,
      anon_sym_LBRACK,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11302), 1,
      sym__type,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(15084), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3320), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [120899] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6564), 1,
      anon_sym_LBRACK,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11303), 1,
      sym__type,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(15084), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3321), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [121020] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6564), 1,
      anon_sym_LBRACK,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11304), 1,
      sym__type,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(15084), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3322), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [121141] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15176), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3323), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [121262] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1030), 1,
      sym_integer_literal,
    ACTIONS(6626), 1,
      sym__alpha_identifier,
    ACTIONS(6628), 1,
      anon_sym_COLON,
    ACTIONS(6630), 1,
      anon_sym_LBRACE,
    ACTIONS(6632), 1,
      anon_sym__,
    ACTIONS(6634), 1,
      anon_sym_LBRACK,
    ACTIONS(6638), 1,
      anon_sym_LPAREN,
    ACTIONS(6640), 1,
      sym__backquoted_id,
    ACTIONS(6642), 1,
      sym_operator_identifier,
    STATE(4681), 1,
      sym__simple_type,
    STATE(4714), 1,
      sym__annotated_type,
    STATE(4939), 1,
      sym__soft_identifier,
    STATE(4959), 1,
      sym_identifier,
    STATE(7063), 1,
      sym_annotated_type,
    STATE(9988), 1,
      sym__non_null_literal,
    STATE(10039), 1,
      sym_literal_type,
    STATE(12259), 1,
      sym_template_body,
    STATE(12519), 1,
      sym__infix_type_choice,
    STATE(12929), 1,
      sym__type,
    STATE(15027), 1,
      sym_parameter_types,
    STATE(17137), 1,
      sym_stable_identifier,
    ACTIONS(1032), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1034), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1038), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3324), 2,
      sym_comment,
      sym_block_comment,
    STATE(7223), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7326), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9240), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12509), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5078), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [121383] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17271), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3325), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [121504] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15184), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3326), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [121625] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6482), 1,
      sym__alpha_identifier,
    ACTIONS(6484), 1,
      anon_sym__,
    ACTIONS(6486), 1,
      anon_sym_LBRACK,
    ACTIONS(6490), 1,
      anon_sym_LPAREN,
    ACTIONS(6492), 1,
      sym__backquoted_id,
    ACTIONS(6494), 1,
      sym_operator_identifier,
    ACTIONS(6496), 1,
      sym_integer_literal,
    STATE(5945), 1,
      sym__simple_type,
    STATE(6020), 1,
      sym_identifier,
    STATE(6416), 1,
      sym__soft_identifier,
    STATE(6457), 1,
      sym__annotated_type,
    STATE(9690), 1,
      sym_annotated_type,
    STATE(10953), 1,
      sym__non_null_literal,
    STATE(11105), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12463), 1,
      sym__infix_type_choice,
    STATE(12695), 1,
      sym__type,
    STATE(15087), 1,
      sym_parameter_types,
    STATE(16929), 1,
      sym_stable_identifier,
    ACTIONS(6498), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6500), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6502), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3327), 2,
      sym_comment,
      sym_block_comment,
    STATE(10584), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11110), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6488), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7126), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [121746] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3328), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 9,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [121815] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6218), 1,
      anon_sym_LBRACK,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(14332), 1,
      sym__type,
    STATE(15570), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3329), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [121936] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7460), 1,
      sym__annotated_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(12373), 1,
      sym__infix_type_choice,
    STATE(13989), 1,
      sym__type,
    STATE(15843), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3330), 2,
      sym_comment,
      sym_block_comment,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [122057] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(922), 1,
      sym_integer_literal,
    ACTIONS(6346), 1,
      anon_sym_COLON,
    ACTIONS(6348), 1,
      anon_sym_LBRACE,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6506), 1,
      anon_sym__,
    ACTIONS(6508), 1,
      anon_sym_LBRACK,
    ACTIONS(6512), 1,
      anon_sym_LPAREN,
    ACTIONS(6514), 1,
      sym__backquoted_id,
    ACTIONS(6516), 1,
      sym_operator_identifier,
    STATE(4404), 1,
      sym__annotated_type,
    STATE(4455), 1,
      sym__simple_type,
    STATE(4474), 1,
      sym__soft_identifier,
    STATE(4498), 1,
      sym_identifier,
    STATE(5768), 1,
      sym_annotated_type,
    STATE(8749), 1,
      sym_literal_type,
    STATE(9031), 1,
      sym__non_null_literal,
    STATE(11144), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12514), 1,
      sym__infix_type_choice,
    STATE(15089), 1,
      sym_parameter_types,
    STATE(17119), 1,
      sym_stable_identifier,
    ACTIONS(924), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(926), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(930), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3331), 2,
      sym_comment,
      sym_block_comment,
    STATE(5352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5805), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7492), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6510), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4591), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [122178] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15218), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3332), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [122299] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    ACTIONS(6644), 1,
      anon_sym_LBRACK,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(14059), 1,
      sym__type,
    STATE(15118), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3333), 2,
      sym_comment,
      sym_block_comment,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [122420] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17483), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3334), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [122541] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6564), 1,
      anon_sym_LBRACK,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(12710), 1,
      sym__type,
    STATE(15084), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3335), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [122662] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15225), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3336), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [122783] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(922), 1,
      sym_integer_literal,
    ACTIONS(6346), 1,
      anon_sym_COLON,
    ACTIONS(6348), 1,
      anon_sym_LBRACE,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6506), 1,
      anon_sym__,
    ACTIONS(6508), 1,
      anon_sym_LBRACK,
    ACTIONS(6512), 1,
      anon_sym_LPAREN,
    ACTIONS(6514), 1,
      sym__backquoted_id,
    ACTIONS(6516), 1,
      sym_operator_identifier,
    STATE(4404), 1,
      sym__annotated_type,
    STATE(4455), 1,
      sym__simple_type,
    STATE(4474), 1,
      sym__soft_identifier,
    STATE(4498), 1,
      sym_identifier,
    STATE(5768), 1,
      sym_annotated_type,
    STATE(8749), 1,
      sym_literal_type,
    STATE(9031), 1,
      sym__non_null_literal,
    STATE(11146), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12514), 1,
      sym__infix_type_choice,
    STATE(15089), 1,
      sym_parameter_types,
    STATE(17119), 1,
      sym_stable_identifier,
    ACTIONS(924), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(926), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(930), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3337), 2,
      sym_comment,
      sym_block_comment,
    STATE(5352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5805), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7492), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6510), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4591), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [122904] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(922), 1,
      sym_integer_literal,
    ACTIONS(6346), 1,
      anon_sym_COLON,
    ACTIONS(6348), 1,
      anon_sym_LBRACE,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6506), 1,
      anon_sym__,
    ACTIONS(6508), 1,
      anon_sym_LBRACK,
    ACTIONS(6512), 1,
      anon_sym_LPAREN,
    ACTIONS(6514), 1,
      sym__backquoted_id,
    ACTIONS(6516), 1,
      sym_operator_identifier,
    STATE(4404), 1,
      sym__annotated_type,
    STATE(4455), 1,
      sym__simple_type,
    STATE(4474), 1,
      sym__soft_identifier,
    STATE(4498), 1,
      sym_identifier,
    STATE(5768), 1,
      sym_annotated_type,
    STATE(8749), 1,
      sym_literal_type,
    STATE(9031), 1,
      sym__non_null_literal,
    STATE(11147), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12514), 1,
      sym__infix_type_choice,
    STATE(15089), 1,
      sym_parameter_types,
    STATE(17119), 1,
      sym_stable_identifier,
    ACTIONS(924), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(926), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(930), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3338), 2,
      sym_comment,
      sym_block_comment,
    STATE(5352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5805), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7492), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6510), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4591), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [123025] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(922), 1,
      sym_integer_literal,
    ACTIONS(6346), 1,
      anon_sym_COLON,
    ACTIONS(6348), 1,
      anon_sym_LBRACE,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6506), 1,
      anon_sym__,
    ACTIONS(6508), 1,
      anon_sym_LBRACK,
    ACTIONS(6512), 1,
      anon_sym_LPAREN,
    ACTIONS(6514), 1,
      sym__backquoted_id,
    ACTIONS(6516), 1,
      sym_operator_identifier,
    STATE(4404), 1,
      sym__annotated_type,
    STATE(4455), 1,
      sym__simple_type,
    STATE(4474), 1,
      sym__soft_identifier,
    STATE(4498), 1,
      sym_identifier,
    STATE(5768), 1,
      sym_annotated_type,
    STATE(8749), 1,
      sym_literal_type,
    STATE(9031), 1,
      sym__non_null_literal,
    STATE(11148), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12514), 1,
      sym__infix_type_choice,
    STATE(15089), 1,
      sym_parameter_types,
    STATE(17119), 1,
      sym_stable_identifier,
    ACTIONS(924), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(926), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(930), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3339), 2,
      sym_comment,
      sym_block_comment,
    STATE(5352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5805), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7492), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6510), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4591), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [123146] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15255), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3340), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [123267] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    ACTIONS(6574), 1,
      anon_sym_LBRACK,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11284), 1,
      sym__type,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(15107), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3341), 2,
      sym_comment,
      sym_block_comment,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [123388] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17688), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3342), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [123509] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15264), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3343), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [123630] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6482), 1,
      sym__alpha_identifier,
    ACTIONS(6484), 1,
      anon_sym__,
    ACTIONS(6486), 1,
      anon_sym_LBRACK,
    ACTIONS(6490), 1,
      anon_sym_LPAREN,
    ACTIONS(6492), 1,
      sym__backquoted_id,
    ACTIONS(6494), 1,
      sym_operator_identifier,
    ACTIONS(6496), 1,
      sym_integer_literal,
    STATE(5945), 1,
      sym__simple_type,
    STATE(6020), 1,
      sym_identifier,
    STATE(6416), 1,
      sym__soft_identifier,
    STATE(6457), 1,
      sym__annotated_type,
    STATE(9690), 1,
      sym_annotated_type,
    STATE(10953), 1,
      sym__non_null_literal,
    STATE(11105), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12463), 1,
      sym__infix_type_choice,
    STATE(12696), 1,
      sym__type,
    STATE(15087), 1,
      sym_parameter_types,
    STATE(16929), 1,
      sym_stable_identifier,
    ACTIONS(6498), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6500), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6502), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3344), 2,
      sym_comment,
      sym_block_comment,
    STATE(10584), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11110), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6488), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7126), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [123751] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym__alpha_identifier,
    ACTIONS(6458), 1,
      anon_sym_COLON,
    ACTIONS(6460), 1,
      anon_sym_LBRACE,
    ACTIONS(6462), 1,
      anon_sym__,
    ACTIONS(6464), 1,
      anon_sym_LBRACK,
    ACTIONS(6468), 1,
      anon_sym_LPAREN,
    ACTIONS(6470), 1,
      sym__backquoted_id,
    ACTIONS(6472), 1,
      sym_operator_identifier,
    ACTIONS(6474), 1,
      sym_integer_literal,
    STATE(5654), 1,
      sym__simple_type,
    STATE(6003), 1,
      sym_identifier,
    STATE(6313), 1,
      sym__soft_identifier,
    STATE(6510), 1,
      sym__annotated_type,
    STATE(8476), 1,
      sym__type,
    STATE(8541), 1,
      sym_template_body,
    STATE(9520), 1,
      sym_annotated_type,
    STATE(10863), 1,
      sym__non_null_literal,
    STATE(10903), 1,
      sym_literal_type,
    STATE(12319), 1,
      sym__infix_type_choice,
    STATE(14991), 1,
      sym_parameter_types,
    STATE(16863), 1,
      sym_stable_identifier,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3345), 2,
      sym_comment,
      sym_block_comment,
    STATE(10159), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10965), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6466), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [123872] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6218), 1,
      anon_sym_LBRACK,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(14293), 1,
      sym__type,
    STATE(15570), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3346), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [123993] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15289), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3347), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [124114] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15295), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3348), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [124235] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    ACTIONS(6574), 1,
      anon_sym_LBRACK,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11298), 1,
      sym__type,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(15107), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3349), 2,
      sym_comment,
      sym_block_comment,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [124356] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(922), 1,
      sym_integer_literal,
    ACTIONS(6346), 1,
      anon_sym_COLON,
    ACTIONS(6348), 1,
      anon_sym_LBRACE,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6506), 1,
      anon_sym__,
    ACTIONS(6508), 1,
      anon_sym_LBRACK,
    ACTIONS(6512), 1,
      anon_sym_LPAREN,
    ACTIONS(6514), 1,
      sym__backquoted_id,
    ACTIONS(6516), 1,
      sym_operator_identifier,
    STATE(4404), 1,
      sym__annotated_type,
    STATE(4455), 1,
      sym__simple_type,
    STATE(4474), 1,
      sym__soft_identifier,
    STATE(4498), 1,
      sym_identifier,
    STATE(5768), 1,
      sym_annotated_type,
    STATE(8749), 1,
      sym_literal_type,
    STATE(9031), 1,
      sym__non_null_literal,
    STATE(11142), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12514), 1,
      sym__infix_type_choice,
    STATE(15089), 1,
      sym_parameter_types,
    STATE(17119), 1,
      sym_stable_identifier,
    ACTIONS(924), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(926), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(930), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3350), 2,
      sym_comment,
      sym_block_comment,
    STATE(5352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5805), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7492), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6510), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4591), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [124477] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    ACTIONS(6574), 1,
      anon_sym_LBRACK,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11302), 1,
      sym__type,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(15107), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3351), 2,
      sym_comment,
      sym_block_comment,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [124598] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    ACTIONS(6574), 1,
      anon_sym_LBRACK,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11303), 1,
      sym__type,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(15107), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3352), 2,
      sym_comment,
      sym_block_comment,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [124719] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    ACTIONS(6574), 1,
      anon_sym_LBRACK,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11304), 1,
      sym__type,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(15107), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3353), 2,
      sym_comment,
      sym_block_comment,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [124840] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4732), 1,
      sym__alpha_identifier,
    ACTIONS(4734), 1,
      anon_sym_COLON,
    ACTIONS(4736), 1,
      anon_sym_LBRACE,
    ACTIONS(4738), 1,
      anon_sym__,
    ACTIONS(4742), 1,
      anon_sym_LBRACK,
    ACTIONS(4750), 1,
      sym__backquoted_id,
    ACTIONS(4754), 1,
      sym_integer_literal,
    ACTIONS(6646), 1,
      anon_sym_LPAREN,
    ACTIONS(6648), 1,
      sym_operator_identifier,
    STATE(6090), 1,
      sym__simple_type,
    STATE(6570), 1,
      sym__annotated_type,
    STATE(6727), 1,
      sym_identifier,
    STATE(7205), 1,
      sym__soft_identifier,
    STATE(9502), 1,
      sym_annotated_type,
    STATE(10959), 1,
      sym__non_null_literal,
    STATE(11086), 1,
      sym_literal_type,
    STATE(11811), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12480), 1,
      sym__infix_type_choice,
    STATE(14754), 1,
      sym_parameter_types,
    STATE(16996), 1,
      sym_stable_identifier,
    ACTIONS(4756), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4758), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4762), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3354), 2,
      sym_comment,
      sym_block_comment,
    STATE(10481), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11068), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11907), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4744), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7933), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [124961] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15324), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3355), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [125082] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1830), 1,
      sym_integer_literal,
    ACTIONS(6650), 1,
      sym__alpha_identifier,
    ACTIONS(6652), 1,
      anon_sym_COLON,
    ACTIONS(6654), 1,
      anon_sym_LBRACE,
    ACTIONS(6656), 1,
      anon_sym__,
    ACTIONS(6658), 1,
      anon_sym_LBRACK,
    ACTIONS(6662), 1,
      anon_sym_LPAREN,
    ACTIONS(6664), 1,
      sym__backquoted_id,
    ACTIONS(6666), 1,
      sym_operator_identifier,
    STATE(5598), 1,
      sym__simple_type,
    STATE(5942), 1,
      sym__annotated_type,
    STATE(6112), 1,
      sym_identifier,
    STATE(6233), 1,
      sym__soft_identifier,
    STATE(8943), 1,
      sym_annotated_type,
    STATE(10664), 1,
      sym__non_null_literal,
    STATE(10826), 1,
      sym_literal_type,
    STATE(12522), 1,
      sym__infix_type_choice,
    STATE(13404), 1,
      sym_template_body,
    STATE(13659), 1,
      sym__type,
    STATE(15028), 1,
      sym_parameter_types,
    STATE(17149), 1,
      sym_stable_identifier,
    ACTIONS(1832), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1834), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1838), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3356), 2,
      sym_comment,
      sym_block_comment,
    STATE(9185), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9294), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10278), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13465), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6660), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6764), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [125203] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15332), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3357), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [125324] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1506), 1,
      sym_integer_literal,
    ACTIONS(6370), 1,
      sym__alpha_identifier,
    ACTIONS(6372), 1,
      anon_sym_COLON,
    ACTIONS(6374), 1,
      anon_sym_LBRACE,
    ACTIONS(6376), 1,
      anon_sym__,
    ACTIONS(6378), 1,
      anon_sym_LBRACK,
    ACTIONS(6382), 1,
      anon_sym_LPAREN,
    ACTIONS(6384), 1,
      sym__backquoted_id,
    ACTIONS(6386), 1,
      sym_operator_identifier,
    STATE(5390), 1,
      sym__annotated_type,
    STATE(5425), 1,
      sym__simple_type,
    STATE(5485), 1,
      sym__soft_identifier,
    STATE(5665), 1,
      sym_identifier,
    STATE(8696), 1,
      sym_annotated_type,
    STATE(10458), 1,
      sym__non_null_literal,
    STATE(10643), 1,
      sym_literal_type,
    STATE(12457), 1,
      sym__infix_type_choice,
    STATE(13167), 1,
      sym_template_body,
    STATE(13301), 1,
      sym__type,
    STATE(15020), 1,
      sym_parameter_types,
    STATE(16818), 1,
      sym_stable_identifier,
    ACTIONS(1508), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1510), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1514), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3358), 2,
      sym_comment,
      sym_block_comment,
    STATE(8229), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8419), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9754), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13189), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6380), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6556), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [125445] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1506), 1,
      sym_integer_literal,
    ACTIONS(6370), 1,
      sym__alpha_identifier,
    ACTIONS(6372), 1,
      anon_sym_COLON,
    ACTIONS(6374), 1,
      anon_sym_LBRACE,
    ACTIONS(6376), 1,
      anon_sym__,
    ACTIONS(6378), 1,
      anon_sym_LBRACK,
    ACTIONS(6382), 1,
      anon_sym_LPAREN,
    ACTIONS(6384), 1,
      sym__backquoted_id,
    ACTIONS(6386), 1,
      sym_operator_identifier,
    STATE(5390), 1,
      sym__annotated_type,
    STATE(5425), 1,
      sym__simple_type,
    STATE(5485), 1,
      sym__soft_identifier,
    STATE(5665), 1,
      sym_identifier,
    STATE(8696), 1,
      sym_annotated_type,
    STATE(10458), 1,
      sym__non_null_literal,
    STATE(10643), 1,
      sym_literal_type,
    STATE(12457), 1,
      sym__infix_type_choice,
    STATE(13167), 1,
      sym_template_body,
    STATE(13302), 1,
      sym__type,
    STATE(15020), 1,
      sym_parameter_types,
    STATE(16818), 1,
      sym_stable_identifier,
    ACTIONS(1508), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1510), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1514), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3359), 2,
      sym_comment,
      sym_block_comment,
    STATE(8229), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8419), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9754), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13189), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6380), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6556), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [125566] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1102), 1,
      sym_integer_literal,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6546), 1,
      sym__alpha_identifier,
    ACTIONS(6548), 1,
      anon_sym__,
    ACTIONS(6550), 1,
      anon_sym_LBRACK,
    ACTIONS(6554), 1,
      anon_sym_LPAREN,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(6558), 1,
      sym_operator_identifier,
    STATE(4676), 1,
      sym__simple_type,
    STATE(4710), 1,
      sym__annotated_type,
    STATE(4934), 1,
      sym_identifier,
    STATE(4937), 1,
      sym__soft_identifier,
    STATE(6975), 1,
      sym_annotated_type,
    STATE(9786), 1,
      sym_literal_type,
    STATE(9814), 1,
      sym__non_null_literal,
    STATE(11929), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12516), 1,
      sym__infix_type_choice,
    STATE(15090), 1,
      sym_parameter_types,
    STATE(17125), 1,
      sym_stable_identifier,
    ACTIONS(1104), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1106), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1110), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3360), 2,
      sym_comment,
      sym_block_comment,
    STATE(6282), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7105), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8765), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5066), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [125687] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6322), 1,
      sym__alpha_identifier,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    ACTIONS(6336), 1,
      sym_integer_literal,
    STATE(6384), 1,
      sym__simple_type,
    STATE(6749), 1,
      sym__annotated_type,
    STATE(7031), 1,
      sym_identifier,
    STATE(7267), 1,
      sym__soft_identifier,
    STATE(9861), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11291), 1,
      sym__non_null_literal,
    STATE(11292), 1,
      sym_literal_type,
    STATE(12368), 1,
      sym__infix_type_choice,
    STATE(13955), 1,
      sym__type,
    STATE(15057), 1,
      sym_parameter_types,
    STATE(16266), 1,
      sym_stable_identifier,
    ACTIONS(6338), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6340), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6342), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3361), 2,
      sym_comment,
      sym_block_comment,
    STATE(10861), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11222), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7736), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [125808] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15368), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3362), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [125929] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7460), 1,
      sym__annotated_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(12373), 1,
      sym__infix_type_choice,
    STATE(13959), 1,
      sym__type,
    STATE(15843), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3363), 2,
      sym_comment,
      sym_block_comment,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [126050] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15377), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3364), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [126171] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1102), 1,
      sym_integer_literal,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6546), 1,
      sym__alpha_identifier,
    ACTIONS(6548), 1,
      anon_sym__,
    ACTIONS(6550), 1,
      anon_sym_LBRACK,
    ACTIONS(6554), 1,
      anon_sym_LPAREN,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(6558), 1,
      sym_operator_identifier,
    STATE(4676), 1,
      sym__simple_type,
    STATE(4710), 1,
      sym__annotated_type,
    STATE(4934), 1,
      sym_identifier,
    STATE(4937), 1,
      sym__soft_identifier,
    STATE(6975), 1,
      sym_annotated_type,
    STATE(9786), 1,
      sym_literal_type,
    STATE(9814), 1,
      sym__non_null_literal,
    STATE(11935), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12516), 1,
      sym__infix_type_choice,
    STATE(15090), 1,
      sym_parameter_types,
    STATE(17125), 1,
      sym_stable_identifier,
    ACTIONS(1104), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1106), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1110), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3365), 2,
      sym_comment,
      sym_block_comment,
    STATE(6282), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7105), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8765), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5066), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [126292] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1102), 1,
      sym_integer_literal,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6546), 1,
      sym__alpha_identifier,
    ACTIONS(6548), 1,
      anon_sym__,
    ACTIONS(6550), 1,
      anon_sym_LBRACK,
    ACTIONS(6554), 1,
      anon_sym_LPAREN,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(6558), 1,
      sym_operator_identifier,
    STATE(4676), 1,
      sym__simple_type,
    STATE(4710), 1,
      sym__annotated_type,
    STATE(4934), 1,
      sym_identifier,
    STATE(4937), 1,
      sym__soft_identifier,
    STATE(6975), 1,
      sym_annotated_type,
    STATE(9786), 1,
      sym_literal_type,
    STATE(9814), 1,
      sym__non_null_literal,
    STATE(11937), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12516), 1,
      sym__infix_type_choice,
    STATE(15090), 1,
      sym_parameter_types,
    STATE(17125), 1,
      sym_stable_identifier,
    ACTIONS(1104), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1106), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1110), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3366), 2,
      sym_comment,
      sym_block_comment,
    STATE(6282), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7105), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8765), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5066), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [126413] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1102), 1,
      sym_integer_literal,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6546), 1,
      sym__alpha_identifier,
    ACTIONS(6548), 1,
      anon_sym__,
    ACTIONS(6550), 1,
      anon_sym_LBRACK,
    ACTIONS(6554), 1,
      anon_sym_LPAREN,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(6558), 1,
      sym_operator_identifier,
    STATE(4676), 1,
      sym__simple_type,
    STATE(4710), 1,
      sym__annotated_type,
    STATE(4934), 1,
      sym_identifier,
    STATE(4937), 1,
      sym__soft_identifier,
    STATE(6975), 1,
      sym_annotated_type,
    STATE(9786), 1,
      sym_literal_type,
    STATE(9814), 1,
      sym__non_null_literal,
    STATE(11942), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12516), 1,
      sym__infix_type_choice,
    STATE(15090), 1,
      sym_parameter_types,
    STATE(17125), 1,
      sym_stable_identifier,
    ACTIONS(1104), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1106), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1110), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3367), 2,
      sym_comment,
      sym_block_comment,
    STATE(6282), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7105), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8765), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5066), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [126534] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6414), 1,
      anon_sym_COLON,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(6418), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(12686), 1,
      sym__type,
    STATE(15021), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3368), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [126655] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6218), 1,
      anon_sym_LBRACK,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(11284), 1,
      sym__type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(15570), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3369), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [126776] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15407), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3370), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [126897] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4732), 1,
      sym__alpha_identifier,
    ACTIONS(4734), 1,
      anon_sym_COLON,
    ACTIONS(4736), 1,
      anon_sym_LBRACE,
    ACTIONS(4738), 1,
      anon_sym__,
    ACTIONS(4742), 1,
      anon_sym_LBRACK,
    ACTIONS(4750), 1,
      sym__backquoted_id,
    ACTIONS(4754), 1,
      sym_integer_literal,
    ACTIONS(6646), 1,
      anon_sym_LPAREN,
    ACTIONS(6648), 1,
      sym_operator_identifier,
    STATE(6090), 1,
      sym__simple_type,
    STATE(6570), 1,
      sym__annotated_type,
    STATE(6727), 1,
      sym_identifier,
    STATE(7205), 1,
      sym__soft_identifier,
    STATE(9502), 1,
      sym_annotated_type,
    STATE(10959), 1,
      sym__non_null_literal,
    STATE(11086), 1,
      sym_literal_type,
    STATE(11929), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12480), 1,
      sym__infix_type_choice,
    STATE(14754), 1,
      sym_parameter_types,
    STATE(16996), 1,
      sym_stable_identifier,
    ACTIONS(4756), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4758), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4762), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3371), 2,
      sym_comment,
      sym_block_comment,
    STATE(10481), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11068), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11907), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4744), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7933), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [127018] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15414), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3372), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [127139] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6580), 1,
      anon_sym__,
    ACTIONS(6582), 1,
      anon_sym_LBRACK,
    ACTIONS(6586), 1,
      anon_sym_LPAREN,
    ACTIONS(6588), 1,
      sym__backquoted_id,
    ACTIONS(6590), 1,
      sym_operator_identifier,
    ACTIONS(6592), 1,
      sym_integer_literal,
    STATE(5708), 1,
      sym__simple_type,
    STATE(6199), 1,
      sym__soft_identifier,
    STATE(6337), 1,
      sym_identifier,
    STATE(6370), 1,
      sym__annotated_type,
    STATE(9519), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11031), 1,
      sym__non_null_literal,
    STATE(11032), 1,
      sym_literal_type,
    STATE(11284), 1,
      sym__type,
    STATE(12402), 1,
      sym__infix_type_choice,
    STATE(15123), 1,
      sym_parameter_types,
    STATE(16404), 1,
      sym_stable_identifier,
    ACTIONS(6594), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6596), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6598), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3373), 2,
      sym_comment,
      sym_block_comment,
    STATE(10604), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11005), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7227), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [127260] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4732), 1,
      sym__alpha_identifier,
    ACTIONS(4734), 1,
      anon_sym_COLON,
    ACTIONS(4736), 1,
      anon_sym_LBRACE,
    ACTIONS(4738), 1,
      anon_sym__,
    ACTIONS(4742), 1,
      anon_sym_LBRACK,
    ACTIONS(4750), 1,
      sym__backquoted_id,
    ACTIONS(4754), 1,
      sym_integer_literal,
    ACTIONS(6646), 1,
      anon_sym_LPAREN,
    ACTIONS(6648), 1,
      sym_operator_identifier,
    STATE(6090), 1,
      sym__simple_type,
    STATE(6570), 1,
      sym__annotated_type,
    STATE(6727), 1,
      sym_identifier,
    STATE(7205), 1,
      sym__soft_identifier,
    STATE(9502), 1,
      sym_annotated_type,
    STATE(10959), 1,
      sym__non_null_literal,
    STATE(11086), 1,
      sym_literal_type,
    STATE(11935), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12480), 1,
      sym__infix_type_choice,
    STATE(14754), 1,
      sym_parameter_types,
    STATE(16996), 1,
      sym_stable_identifier,
    ACTIONS(4756), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4758), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4762), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3374), 2,
      sym_comment,
      sym_block_comment,
    STATE(10481), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11068), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11907), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4744), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7933), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [127381] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15436), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3375), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [127502] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4732), 1,
      sym__alpha_identifier,
    ACTIONS(4734), 1,
      anon_sym_COLON,
    ACTIONS(4736), 1,
      anon_sym_LBRACE,
    ACTIONS(4738), 1,
      anon_sym__,
    ACTIONS(4742), 1,
      anon_sym_LBRACK,
    ACTIONS(4750), 1,
      sym__backquoted_id,
    ACTIONS(4754), 1,
      sym_integer_literal,
    ACTIONS(6646), 1,
      anon_sym_LPAREN,
    ACTIONS(6648), 1,
      sym_operator_identifier,
    STATE(6090), 1,
      sym__simple_type,
    STATE(6570), 1,
      sym__annotated_type,
    STATE(6727), 1,
      sym_identifier,
    STATE(7205), 1,
      sym__soft_identifier,
    STATE(9502), 1,
      sym_annotated_type,
    STATE(10959), 1,
      sym__non_null_literal,
    STATE(11086), 1,
      sym_literal_type,
    STATE(11937), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12480), 1,
      sym__infix_type_choice,
    STATE(14754), 1,
      sym_parameter_types,
    STATE(16996), 1,
      sym_stable_identifier,
    ACTIONS(4756), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4758), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4762), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3376), 2,
      sym_comment,
      sym_block_comment,
    STATE(10481), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11068), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11907), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4744), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7933), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [127623] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15438), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3377), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [127744] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4732), 1,
      sym__alpha_identifier,
    ACTIONS(4734), 1,
      anon_sym_COLON,
    ACTIONS(4736), 1,
      anon_sym_LBRACE,
    ACTIONS(4738), 1,
      anon_sym__,
    ACTIONS(4742), 1,
      anon_sym_LBRACK,
    ACTIONS(4750), 1,
      sym__backquoted_id,
    ACTIONS(4754), 1,
      sym_integer_literal,
    ACTIONS(6646), 1,
      anon_sym_LPAREN,
    ACTIONS(6648), 1,
      sym_operator_identifier,
    STATE(6090), 1,
      sym__simple_type,
    STATE(6570), 1,
      sym__annotated_type,
    STATE(6727), 1,
      sym_identifier,
    STATE(7205), 1,
      sym__soft_identifier,
    STATE(9502), 1,
      sym_annotated_type,
    STATE(10959), 1,
      sym__non_null_literal,
    STATE(11086), 1,
      sym_literal_type,
    STATE(11942), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12480), 1,
      sym__infix_type_choice,
    STATE(14754), 1,
      sym_parameter_types,
    STATE(16996), 1,
      sym_stable_identifier,
    ACTIONS(4756), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4758), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4762), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3378), 2,
      sym_comment,
      sym_block_comment,
    STATE(10481), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11068), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11907), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4744), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7933), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [127865] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6482), 1,
      sym__alpha_identifier,
    ACTIONS(6484), 1,
      anon_sym__,
    ACTIONS(6486), 1,
      anon_sym_LBRACK,
    ACTIONS(6490), 1,
      anon_sym_LPAREN,
    ACTIONS(6492), 1,
      sym__backquoted_id,
    ACTIONS(6494), 1,
      sym_operator_identifier,
    ACTIONS(6496), 1,
      sym_integer_literal,
    STATE(5945), 1,
      sym__simple_type,
    STATE(6020), 1,
      sym_identifier,
    STATE(6416), 1,
      sym__soft_identifier,
    STATE(6457), 1,
      sym__annotated_type,
    STATE(9690), 1,
      sym_annotated_type,
    STATE(10953), 1,
      sym__non_null_literal,
    STATE(11105), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12463), 1,
      sym__infix_type_choice,
    STATE(14010), 1,
      sym__type,
    STATE(15087), 1,
      sym_parameter_types,
    STATE(16929), 1,
      sym_stable_identifier,
    ACTIONS(6498), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6500), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6502), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3379), 2,
      sym_comment,
      sym_block_comment,
    STATE(10584), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11110), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6488), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7126), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [127986] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6602), 1,
      anon_sym_COLON,
    ACTIONS(6604), 1,
      anon_sym_LBRACE,
    ACTIONS(6606), 1,
      anon_sym__,
    ACTIONS(6608), 1,
      anon_sym_LBRACK,
    ACTIONS(6612), 1,
      anon_sym_LPAREN,
    ACTIONS(6614), 1,
      sym__backquoted_id,
    ACTIONS(6616), 1,
      sym_operator_identifier,
    ACTIONS(6618), 1,
      sym_integer_literal,
    STATE(5326), 1,
      sym__simple_type,
    STATE(5721), 1,
      sym__annotated_type,
    STATE(5817), 1,
      sym__soft_identifier,
    STATE(5848), 1,
      sym_identifier,
    STATE(9098), 1,
      sym_annotated_type,
    STATE(10650), 1,
      sym__non_null_literal,
    STATE(10651), 1,
      sym_literal_type,
    STATE(10698), 1,
      sym_template_body,
    STATE(10892), 1,
      sym__type,
    STATE(12409), 1,
      sym__infix_type_choice,
    STATE(15275), 1,
      sym_parameter_types,
    STATE(16425), 1,
      sym_stable_identifier,
    ACTIONS(6620), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6622), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6624), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3380), 2,
      sym_comment,
      sym_block_comment,
    STATE(10108), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10517), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10947), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6610), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6472), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [128107] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6580), 1,
      anon_sym__,
    ACTIONS(6582), 1,
      anon_sym_LBRACK,
    ACTIONS(6586), 1,
      anon_sym_LPAREN,
    ACTIONS(6588), 1,
      sym__backquoted_id,
    ACTIONS(6590), 1,
      sym_operator_identifier,
    ACTIONS(6592), 1,
      sym_integer_literal,
    STATE(5708), 1,
      sym__simple_type,
    STATE(6199), 1,
      sym__soft_identifier,
    STATE(6337), 1,
      sym_identifier,
    STATE(6370), 1,
      sym__annotated_type,
    STATE(9519), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11031), 1,
      sym__non_null_literal,
    STATE(11032), 1,
      sym_literal_type,
    STATE(11298), 1,
      sym__type,
    STATE(12402), 1,
      sym__infix_type_choice,
    STATE(15123), 1,
      sym_parameter_types,
    STATE(16404), 1,
      sym_stable_identifier,
    ACTIONS(6594), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6596), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6598), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3381), 2,
      sym_comment,
      sym_block_comment,
    STATE(10604), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11005), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7227), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [128228] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6580), 1,
      anon_sym__,
    ACTIONS(6582), 1,
      anon_sym_LBRACK,
    ACTIONS(6586), 1,
      anon_sym_LPAREN,
    ACTIONS(6588), 1,
      sym__backquoted_id,
    ACTIONS(6590), 1,
      sym_operator_identifier,
    ACTIONS(6592), 1,
      sym_integer_literal,
    STATE(5708), 1,
      sym__simple_type,
    STATE(6199), 1,
      sym__soft_identifier,
    STATE(6337), 1,
      sym_identifier,
    STATE(6370), 1,
      sym__annotated_type,
    STATE(9519), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11031), 1,
      sym__non_null_literal,
    STATE(11032), 1,
      sym_literal_type,
    STATE(11302), 1,
      sym__type,
    STATE(12402), 1,
      sym__infix_type_choice,
    STATE(15123), 1,
      sym_parameter_types,
    STATE(16404), 1,
      sym_stable_identifier,
    ACTIONS(6594), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6596), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6598), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3382), 2,
      sym_comment,
      sym_block_comment,
    STATE(10604), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11005), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7227), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [128349] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15453), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3383), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [128470] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6580), 1,
      anon_sym__,
    ACTIONS(6582), 1,
      anon_sym_LBRACK,
    ACTIONS(6586), 1,
      anon_sym_LPAREN,
    ACTIONS(6588), 1,
      sym__backquoted_id,
    ACTIONS(6590), 1,
      sym_operator_identifier,
    ACTIONS(6592), 1,
      sym_integer_literal,
    STATE(5708), 1,
      sym__simple_type,
    STATE(6199), 1,
      sym__soft_identifier,
    STATE(6337), 1,
      sym_identifier,
    STATE(6370), 1,
      sym__annotated_type,
    STATE(9519), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11031), 1,
      sym__non_null_literal,
    STATE(11032), 1,
      sym_literal_type,
    STATE(11303), 1,
      sym__type,
    STATE(12402), 1,
      sym__infix_type_choice,
    STATE(15123), 1,
      sym_parameter_types,
    STATE(16404), 1,
      sym_stable_identifier,
    ACTIONS(6594), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6596), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6598), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3384), 2,
      sym_comment,
      sym_block_comment,
    STATE(10604), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11005), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7227), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [128591] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15458), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3385), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [128712] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6580), 1,
      anon_sym__,
    ACTIONS(6582), 1,
      anon_sym_LBRACK,
    ACTIONS(6586), 1,
      anon_sym_LPAREN,
    ACTIONS(6588), 1,
      sym__backquoted_id,
    ACTIONS(6590), 1,
      sym_operator_identifier,
    ACTIONS(6592), 1,
      sym_integer_literal,
    STATE(5708), 1,
      sym__simple_type,
    STATE(6199), 1,
      sym__soft_identifier,
    STATE(6337), 1,
      sym_identifier,
    STATE(6370), 1,
      sym__annotated_type,
    STATE(9519), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11031), 1,
      sym__non_null_literal,
    STATE(11032), 1,
      sym_literal_type,
    STATE(11304), 1,
      sym__type,
    STATE(12402), 1,
      sym__infix_type_choice,
    STATE(15123), 1,
      sym_parameter_types,
    STATE(16404), 1,
      sym_stable_identifier,
    ACTIONS(6594), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6596), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6598), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3386), 2,
      sym_comment,
      sym_block_comment,
    STATE(10604), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11005), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7227), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [128833] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1102), 1,
      sym_integer_literal,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6546), 1,
      sym__alpha_identifier,
    ACTIONS(6548), 1,
      anon_sym__,
    ACTIONS(6550), 1,
      anon_sym_LBRACK,
    ACTIONS(6554), 1,
      anon_sym_LPAREN,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(6558), 1,
      sym_operator_identifier,
    STATE(4676), 1,
      sym__simple_type,
    STATE(4710), 1,
      sym__annotated_type,
    STATE(4934), 1,
      sym_identifier,
    STATE(4937), 1,
      sym__soft_identifier,
    STATE(6975), 1,
      sym_annotated_type,
    STATE(9786), 1,
      sym_literal_type,
    STATE(9814), 1,
      sym__non_null_literal,
    STATE(11811), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12516), 1,
      sym__infix_type_choice,
    STATE(15090), 1,
      sym_parameter_types,
    STATE(17125), 1,
      sym_stable_identifier,
    ACTIONS(1104), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1106), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1110), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3387), 2,
      sym_comment,
      sym_block_comment,
    STATE(6282), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7105), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8765), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5066), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [128954] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1594), 1,
      sym_integer_literal,
    ACTIONS(6668), 1,
      sym__alpha_identifier,
    ACTIONS(6670), 1,
      anon_sym_COLON,
    ACTIONS(6672), 1,
      anon_sym_LBRACE,
    ACTIONS(6674), 1,
      anon_sym__,
    ACTIONS(6676), 1,
      anon_sym_LBRACK,
    ACTIONS(6680), 1,
      anon_sym_LPAREN,
    ACTIONS(6682), 1,
      sym__backquoted_id,
    ACTIONS(6684), 1,
      sym_operator_identifier,
    STATE(5712), 1,
      sym__simple_type,
    STATE(5797), 1,
      sym__annotated_type,
    STATE(6018), 1,
      sym_identifier,
    STATE(6257), 1,
      sym__soft_identifier,
    STATE(9026), 1,
      sym_annotated_type,
    STATE(10720), 1,
      sym_literal_type,
    STATE(10749), 1,
      sym__non_null_literal,
    STATE(12529), 1,
      sym__infix_type_choice,
    STATE(13587), 1,
      sym_template_body,
    STATE(13784), 1,
      sym__type,
    STATE(15029), 1,
      sym_parameter_types,
    STATE(17167), 1,
      sym_stable_identifier,
    ACTIONS(1596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1602), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3388), 2,
      sym_comment,
      sym_block_comment,
    STATE(9215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9231), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10356), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13594), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6678), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6819), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [129075] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15477), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3389), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [129196] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 9,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [129265] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15483), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3391), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [129386] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6602), 1,
      anon_sym_COLON,
    ACTIONS(6604), 1,
      anon_sym_LBRACE,
    ACTIONS(6606), 1,
      anon_sym__,
    ACTIONS(6608), 1,
      anon_sym_LBRACK,
    ACTIONS(6612), 1,
      anon_sym_LPAREN,
    ACTIONS(6614), 1,
      sym__backquoted_id,
    ACTIONS(6616), 1,
      sym_operator_identifier,
    ACTIONS(6618), 1,
      sym_integer_literal,
    STATE(5326), 1,
      sym__simple_type,
    STATE(5721), 1,
      sym__annotated_type,
    STATE(5817), 1,
      sym__soft_identifier,
    STATE(5848), 1,
      sym_identifier,
    STATE(9098), 1,
      sym_annotated_type,
    STATE(10650), 1,
      sym__non_null_literal,
    STATE(10651), 1,
      sym_literal_type,
    STATE(10698), 1,
      sym_template_body,
    STATE(10893), 1,
      sym__type,
    STATE(12409), 1,
      sym__infix_type_choice,
    STATE(15275), 1,
      sym_parameter_types,
    STATE(16425), 1,
      sym_stable_identifier,
    ACTIONS(6620), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6622), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6624), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3392), 2,
      sym_comment,
      sym_block_comment,
    STATE(10108), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10517), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10947), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6610), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6472), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [129507] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1030), 1,
      sym_integer_literal,
    ACTIONS(6626), 1,
      sym__alpha_identifier,
    ACTIONS(6628), 1,
      anon_sym_COLON,
    ACTIONS(6630), 1,
      anon_sym_LBRACE,
    ACTIONS(6632), 1,
      anon_sym__,
    ACTIONS(6634), 1,
      anon_sym_LBRACK,
    ACTIONS(6638), 1,
      anon_sym_LPAREN,
    ACTIONS(6640), 1,
      sym__backquoted_id,
    ACTIONS(6642), 1,
      sym_operator_identifier,
    STATE(4681), 1,
      sym__simple_type,
    STATE(4714), 1,
      sym__annotated_type,
    STATE(4939), 1,
      sym__soft_identifier,
    STATE(4959), 1,
      sym_identifier,
    STATE(7063), 1,
      sym_annotated_type,
    STATE(9988), 1,
      sym__non_null_literal,
    STATE(10039), 1,
      sym_literal_type,
    STATE(12175), 1,
      sym__type,
    STATE(12259), 1,
      sym_template_body,
    STATE(12519), 1,
      sym__infix_type_choice,
    STATE(15027), 1,
      sym_parameter_types,
    STATE(17137), 1,
      sym_stable_identifier,
    ACTIONS(1032), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1034), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1038), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3393), 2,
      sym_comment,
      sym_block_comment,
    STATE(7223), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7326), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9240), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12509), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5078), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [129628] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6564), 1,
      anon_sym_LBRACK,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(14267), 1,
      sym__type,
    STATE(15084), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3394), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [129749] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1030), 1,
      sym_integer_literal,
    ACTIONS(6626), 1,
      sym__alpha_identifier,
    ACTIONS(6628), 1,
      anon_sym_COLON,
    ACTIONS(6630), 1,
      anon_sym_LBRACE,
    ACTIONS(6632), 1,
      anon_sym__,
    ACTIONS(6634), 1,
      anon_sym_LBRACK,
    ACTIONS(6638), 1,
      anon_sym_LPAREN,
    ACTIONS(6640), 1,
      sym__backquoted_id,
    ACTIONS(6642), 1,
      sym_operator_identifier,
    STATE(4681), 1,
      sym__simple_type,
    STATE(4714), 1,
      sym__annotated_type,
    STATE(4939), 1,
      sym__soft_identifier,
    STATE(4959), 1,
      sym_identifier,
    STATE(7063), 1,
      sym_annotated_type,
    STATE(9988), 1,
      sym__non_null_literal,
    STATE(10039), 1,
      sym_literal_type,
    STATE(12177), 1,
      sym__type,
    STATE(12259), 1,
      sym_template_body,
    STATE(12519), 1,
      sym__infix_type_choice,
    STATE(15027), 1,
      sym_parameter_types,
    STATE(17137), 1,
      sym_stable_identifier,
    ACTIONS(1032), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1034), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1038), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3395), 2,
      sym_comment,
      sym_block_comment,
    STATE(7223), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7326), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9240), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12509), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5078), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [129870] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15504), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3396), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [129991] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1030), 1,
      sym_integer_literal,
    ACTIONS(6626), 1,
      sym__alpha_identifier,
    ACTIONS(6628), 1,
      anon_sym_COLON,
    ACTIONS(6630), 1,
      anon_sym_LBRACE,
    ACTIONS(6632), 1,
      anon_sym__,
    ACTIONS(6634), 1,
      anon_sym_LBRACK,
    ACTIONS(6638), 1,
      anon_sym_LPAREN,
    ACTIONS(6640), 1,
      sym__backquoted_id,
    ACTIONS(6642), 1,
      sym_operator_identifier,
    STATE(4681), 1,
      sym__simple_type,
    STATE(4714), 1,
      sym__annotated_type,
    STATE(4939), 1,
      sym__soft_identifier,
    STATE(4959), 1,
      sym_identifier,
    STATE(7063), 1,
      sym_annotated_type,
    STATE(9988), 1,
      sym__non_null_literal,
    STATE(10039), 1,
      sym_literal_type,
    STATE(12179), 1,
      sym__type,
    STATE(12259), 1,
      sym_template_body,
    STATE(12519), 1,
      sym__infix_type_choice,
    STATE(15027), 1,
      sym_parameter_types,
    STATE(17137), 1,
      sym_stable_identifier,
    ACTIONS(1032), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1034), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1038), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3397), 2,
      sym_comment,
      sym_block_comment,
    STATE(7223), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7326), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9240), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12509), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5078), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [130112] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15512), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3398), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [130233] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6564), 1,
      anon_sym_LBRACK,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(14274), 1,
      sym__type,
    STATE(15084), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3399), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [130354] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1030), 1,
      sym_integer_literal,
    ACTIONS(6626), 1,
      sym__alpha_identifier,
    ACTIONS(6628), 1,
      anon_sym_COLON,
    ACTIONS(6630), 1,
      anon_sym_LBRACE,
    ACTIONS(6632), 1,
      anon_sym__,
    ACTIONS(6634), 1,
      anon_sym_LBRACK,
    ACTIONS(6638), 1,
      anon_sym_LPAREN,
    ACTIONS(6640), 1,
      sym__backquoted_id,
    ACTIONS(6642), 1,
      sym_operator_identifier,
    STATE(4681), 1,
      sym__simple_type,
    STATE(4714), 1,
      sym__annotated_type,
    STATE(4939), 1,
      sym__soft_identifier,
    STATE(4959), 1,
      sym_identifier,
    STATE(7063), 1,
      sym_annotated_type,
    STATE(9988), 1,
      sym__non_null_literal,
    STATE(10039), 1,
      sym_literal_type,
    STATE(12180), 1,
      sym__type,
    STATE(12259), 1,
      sym_template_body,
    STATE(12519), 1,
      sym__infix_type_choice,
    STATE(15027), 1,
      sym_parameter_types,
    STATE(17137), 1,
      sym_stable_identifier,
    ACTIONS(1032), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1034), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1038), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3400), 2,
      sym_comment,
      sym_block_comment,
    STATE(7223), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7326), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9240), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12509), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5078), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [130475] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6564), 1,
      anon_sym_LBRACK,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(14289), 1,
      sym__type,
    STATE(15084), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3401), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [130596] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    ACTIONS(6576), 1,
      anon_sym_LBRACK,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(6890), 1,
      sym__annotated_type,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11284), 1,
      sym__type,
    STATE(12405), 1,
      sym__infix_type_choice,
    STATE(15140), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3402), 2,
      sym_comment,
      sym_block_comment,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [130717] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15545), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3403), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [130838] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6564), 1,
      anon_sym_LBRACK,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(14291), 1,
      sym__type,
    STATE(15084), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3404), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [130959] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15558), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3405), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [131080] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6414), 1,
      anon_sym_COLON,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(6418), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(12694), 1,
      sym__type,
    STATE(15021), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3406), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [131201] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(4640), 1,
      sym__alpha_identifier,
    ACTIONS(4642), 1,
      anon_sym__,
    ACTIONS(4646), 1,
      anon_sym_LBRACK,
    ACTIONS(4652), 1,
      sym__backquoted_id,
    ACTIONS(4656), 1,
      sym_integer_literal,
    ACTIONS(6686), 1,
      anon_sym_LPAREN,
    ACTIONS(6688), 1,
      sym_operator_identifier,
    STATE(7244), 1,
      sym__annotated_type,
    STATE(7245), 1,
      sym__simple_type,
    STATE(7872), 1,
      sym__soft_identifier,
    STATE(7995), 1,
      sym_identifier,
    STATE(9803), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11164), 1,
      sym__non_null_literal,
    STATE(11165), 1,
      sym_literal_type,
    STATE(11284), 1,
      sym__type,
    STATE(12340), 1,
      sym__infix_type_choice,
    STATE(15510), 1,
      sym_parameter_types,
    STATE(17142), 1,
      sym_stable_identifier,
    ACTIONS(4658), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4660), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4662), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3407), 2,
      sym_comment,
      sym_block_comment,
    STATE(10734), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11317), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4648), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8425), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [131322] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8320), 1,
      sym__type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3408), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [131443] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15581), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3409), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [131564] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym__alpha_identifier,
    ACTIONS(6458), 1,
      anon_sym_COLON,
    ACTIONS(6460), 1,
      anon_sym_LBRACE,
    ACTIONS(6462), 1,
      anon_sym__,
    ACTIONS(6464), 1,
      anon_sym_LBRACK,
    ACTIONS(6468), 1,
      anon_sym_LPAREN,
    ACTIONS(6470), 1,
      sym__backquoted_id,
    ACTIONS(6472), 1,
      sym_operator_identifier,
    ACTIONS(6474), 1,
      sym_integer_literal,
    STATE(5654), 1,
      sym__simple_type,
    STATE(6003), 1,
      sym_identifier,
    STATE(6313), 1,
      sym__soft_identifier,
    STATE(6510), 1,
      sym__annotated_type,
    STATE(8320), 1,
      sym__type,
    STATE(8541), 1,
      sym_template_body,
    STATE(9520), 1,
      sym_annotated_type,
    STATE(10863), 1,
      sym__non_null_literal,
    STATE(10903), 1,
      sym_literal_type,
    STATE(12319), 1,
      sym__infix_type_choice,
    STATE(14991), 1,
      sym_parameter_types,
    STATE(16863), 1,
      sym_stable_identifier,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3410), 2,
      sym_comment,
      sym_block_comment,
    STATE(10159), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10965), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6466), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [131685] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15587), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3411), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [131806] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    ACTIONS(6576), 1,
      anon_sym_LBRACK,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(6890), 1,
      sym__annotated_type,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11298), 1,
      sym__type,
    STATE(12405), 1,
      sym__infix_type_choice,
    STATE(15140), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3412), 2,
      sym_comment,
      sym_block_comment,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [131927] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6414), 1,
      anon_sym_COLON,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(6418), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(12695), 1,
      sym__type,
    STATE(15021), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3413), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [132048] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    ACTIONS(6576), 1,
      anon_sym_LBRACK,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(6890), 1,
      sym__annotated_type,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11302), 1,
      sym__type,
    STATE(12405), 1,
      sym__infix_type_choice,
    STATE(15140), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3414), 2,
      sym_comment,
      sym_block_comment,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [132169] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    ACTIONS(6576), 1,
      anon_sym_LBRACK,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(6890), 1,
      sym__annotated_type,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11303), 1,
      sym__type,
    STATE(12405), 1,
      sym__infix_type_choice,
    STATE(15140), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3415), 2,
      sym_comment,
      sym_block_comment,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [132290] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    ACTIONS(6576), 1,
      anon_sym_LBRACK,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(6890), 1,
      sym__annotated_type,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11304), 1,
      sym__type,
    STATE(12405), 1,
      sym__infix_type_choice,
    STATE(15140), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3416), 2,
      sym_comment,
      sym_block_comment,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [132411] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15609), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3417), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [132532] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1138), 1,
      sym_integer_literal,
    ACTIONS(6690), 1,
      sym__alpha_identifier,
    ACTIONS(6692), 1,
      anon_sym_COLON,
    ACTIONS(6694), 1,
      anon_sym_LBRACE,
    ACTIONS(6696), 1,
      anon_sym__,
    ACTIONS(6698), 1,
      anon_sym_LBRACK,
    ACTIONS(6702), 1,
      anon_sym_LPAREN,
    ACTIONS(6704), 1,
      sym__backquoted_id,
    ACTIONS(6706), 1,
      sym_operator_identifier,
    STATE(4927), 1,
      sym__annotated_type,
    STATE(4955), 1,
      sym__simple_type,
    STATE(5112), 1,
      sym_identifier,
    STATE(5191), 1,
      sym__soft_identifier,
    STATE(8039), 1,
      sym_annotated_type,
    STATE(10305), 1,
      sym_literal_type,
    STATE(10365), 1,
      sym__non_null_literal,
    STATE(12540), 1,
      sym__infix_type_choice,
    STATE(12881), 1,
      sym_template_body,
    STATE(13272), 1,
      sym__type,
    STATE(15030), 1,
      sym_parameter_types,
    STATE(17215), 1,
      sym_stable_identifier,
    ACTIONS(1140), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1142), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1146), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3418), 2,
      sym_comment,
      sym_block_comment,
    STATE(7452), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7459), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9431), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12809), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5795), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [132653] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15620), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3419), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [132774] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1030), 1,
      sym_integer_literal,
    ACTIONS(6626), 1,
      sym__alpha_identifier,
    ACTIONS(6628), 1,
      anon_sym_COLON,
    ACTIONS(6630), 1,
      anon_sym_LBRACE,
    ACTIONS(6632), 1,
      anon_sym__,
    ACTIONS(6634), 1,
      anon_sym_LBRACK,
    ACTIONS(6638), 1,
      anon_sym_LPAREN,
    ACTIONS(6640), 1,
      sym__backquoted_id,
    ACTIONS(6642), 1,
      sym_operator_identifier,
    STATE(4681), 1,
      sym__simple_type,
    STATE(4714), 1,
      sym__annotated_type,
    STATE(4939), 1,
      sym__soft_identifier,
    STATE(4959), 1,
      sym_identifier,
    STATE(7063), 1,
      sym_annotated_type,
    STATE(9988), 1,
      sym__non_null_literal,
    STATE(10039), 1,
      sym_literal_type,
    STATE(12259), 1,
      sym_template_body,
    STATE(12285), 1,
      sym__type,
    STATE(12519), 1,
      sym__infix_type_choice,
    STATE(15027), 1,
      sym_parameter_types,
    STATE(17137), 1,
      sym_stable_identifier,
    ACTIONS(1032), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1034), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1038), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3420), 2,
      sym_comment,
      sym_block_comment,
    STATE(7223), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7326), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9240), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12509), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5078), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [132895] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6564), 1,
      anon_sym_LBRACK,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(14293), 1,
      sym__type,
    STATE(15084), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3421), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [133016] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4700), 1,
      anon_sym_COLON,
    ACTIONS(4702), 1,
      anon_sym_LBRACE,
    ACTIONS(4770), 1,
      sym__alpha_identifier,
    ACTIONS(4772), 1,
      anon_sym__,
    ACTIONS(4776), 1,
      anon_sym_LBRACK,
    ACTIONS(4782), 1,
      sym__backquoted_id,
    ACTIONS(4786), 1,
      sym_integer_literal,
    ACTIONS(6708), 1,
      anon_sym_LPAREN,
    ACTIONS(6710), 1,
      sym_operator_identifier,
    STATE(4279), 1,
      sym__simple_type,
    STATE(4380), 1,
      sym__annotated_type,
    STATE(4395), 1,
      sym_identifier,
    STATE(4399), 1,
      sym__soft_identifier,
    STATE(5134), 1,
      sym_annotated_type,
    STATE(8293), 1,
      sym__non_null_literal,
    STATE(8397), 1,
      sym_literal_type,
    STATE(11142), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12481), 1,
      sym__infix_type_choice,
    STATE(15025), 1,
      sym_parameter_types,
    STATE(17007), 1,
      sym_stable_identifier,
    ACTIONS(4788), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4790), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4792), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3422), 2,
      sym_comment,
      sym_block_comment,
    STATE(7263), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8127), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4778), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4539), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [133137] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6414), 1,
      anon_sym_COLON,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(6418), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(12696), 1,
      sym__type,
    STATE(15021), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3423), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [133258] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1506), 1,
      sym_integer_literal,
    ACTIONS(6370), 1,
      sym__alpha_identifier,
    ACTIONS(6372), 1,
      anon_sym_COLON,
    ACTIONS(6374), 1,
      anon_sym_LBRACE,
    ACTIONS(6376), 1,
      anon_sym__,
    ACTIONS(6378), 1,
      anon_sym_LBRACK,
    ACTIONS(6382), 1,
      anon_sym_LPAREN,
    ACTIONS(6384), 1,
      sym__backquoted_id,
    ACTIONS(6386), 1,
      sym_operator_identifier,
    STATE(5390), 1,
      sym__annotated_type,
    STATE(5425), 1,
      sym__simple_type,
    STATE(5485), 1,
      sym__soft_identifier,
    STATE(5665), 1,
      sym_identifier,
    STATE(8696), 1,
      sym_annotated_type,
    STATE(10458), 1,
      sym__non_null_literal,
    STATE(10643), 1,
      sym_literal_type,
    STATE(12457), 1,
      sym__infix_type_choice,
    STATE(13025), 1,
      sym__type,
    STATE(13167), 1,
      sym_template_body,
    STATE(15020), 1,
      sym_parameter_types,
    STATE(16818), 1,
      sym_stable_identifier,
    ACTIONS(1508), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1510), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1514), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3424), 2,
      sym_comment,
      sym_block_comment,
    STATE(8229), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8419), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9754), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13189), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6380), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6556), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [133379] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15665), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3425), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [133500] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    ACTIONS(6576), 1,
      anon_sym_LBRACK,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(6890), 1,
      sym__annotated_type,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(12405), 1,
      sym__infix_type_choice,
    STATE(13961), 1,
      sym__type,
    STATE(15140), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3426), 2,
      sym_comment,
      sym_block_comment,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [133621] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1830), 1,
      sym_integer_literal,
    ACTIONS(6650), 1,
      sym__alpha_identifier,
    ACTIONS(6652), 1,
      anon_sym_COLON,
    ACTIONS(6654), 1,
      anon_sym_LBRACE,
    ACTIONS(6656), 1,
      anon_sym__,
    ACTIONS(6658), 1,
      anon_sym_LBRACK,
    ACTIONS(6662), 1,
      anon_sym_LPAREN,
    ACTIONS(6664), 1,
      sym__backquoted_id,
    ACTIONS(6666), 1,
      sym_operator_identifier,
    STATE(5598), 1,
      sym__simple_type,
    STATE(5942), 1,
      sym__annotated_type,
    STATE(6112), 1,
      sym_identifier,
    STATE(6233), 1,
      sym__soft_identifier,
    STATE(8943), 1,
      sym_annotated_type,
    STATE(10664), 1,
      sym__non_null_literal,
    STATE(10826), 1,
      sym_literal_type,
    STATE(12522), 1,
      sym__infix_type_choice,
    STATE(13404), 1,
      sym_template_body,
    STATE(13427), 1,
      sym__type,
    STATE(15028), 1,
      sym_parameter_types,
    STATE(17149), 1,
      sym_stable_identifier,
    ACTIONS(1832), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1834), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1838), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3427), 2,
      sym_comment,
      sym_block_comment,
    STATE(9185), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9294), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10278), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13465), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6660), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6764), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [133742] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1830), 1,
      sym_integer_literal,
    ACTIONS(6650), 1,
      sym__alpha_identifier,
    ACTIONS(6652), 1,
      anon_sym_COLON,
    ACTIONS(6654), 1,
      anon_sym_LBRACE,
    ACTIONS(6656), 1,
      anon_sym__,
    ACTIONS(6658), 1,
      anon_sym_LBRACK,
    ACTIONS(6662), 1,
      anon_sym_LPAREN,
    ACTIONS(6664), 1,
      sym__backquoted_id,
    ACTIONS(6666), 1,
      sym_operator_identifier,
    STATE(5598), 1,
      sym__simple_type,
    STATE(5942), 1,
      sym__annotated_type,
    STATE(6112), 1,
      sym_identifier,
    STATE(6233), 1,
      sym__soft_identifier,
    STATE(8943), 1,
      sym_annotated_type,
    STATE(10664), 1,
      sym__non_null_literal,
    STATE(10826), 1,
      sym_literal_type,
    STATE(12522), 1,
      sym__infix_type_choice,
    STATE(13404), 1,
      sym_template_body,
    STATE(13438), 1,
      sym__type,
    STATE(15028), 1,
      sym_parameter_types,
    STATE(17149), 1,
      sym_stable_identifier,
    ACTIONS(1832), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1834), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1838), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3428), 2,
      sym_comment,
      sym_block_comment,
    STATE(9185), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9294), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10278), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13465), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6660), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6764), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [133863] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1830), 1,
      sym_integer_literal,
    ACTIONS(6650), 1,
      sym__alpha_identifier,
    ACTIONS(6652), 1,
      anon_sym_COLON,
    ACTIONS(6654), 1,
      anon_sym_LBRACE,
    ACTIONS(6656), 1,
      anon_sym__,
    ACTIONS(6658), 1,
      anon_sym_LBRACK,
    ACTIONS(6662), 1,
      anon_sym_LPAREN,
    ACTIONS(6664), 1,
      sym__backquoted_id,
    ACTIONS(6666), 1,
      sym_operator_identifier,
    STATE(5598), 1,
      sym__simple_type,
    STATE(5942), 1,
      sym__annotated_type,
    STATE(6112), 1,
      sym_identifier,
    STATE(6233), 1,
      sym__soft_identifier,
    STATE(8943), 1,
      sym_annotated_type,
    STATE(10664), 1,
      sym__non_null_literal,
    STATE(10826), 1,
      sym_literal_type,
    STATE(12522), 1,
      sym__infix_type_choice,
    STATE(13404), 1,
      sym_template_body,
    STATE(13464), 1,
      sym__type,
    STATE(15028), 1,
      sym_parameter_types,
    STATE(17149), 1,
      sym_stable_identifier,
    ACTIONS(1832), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1834), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1838), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3429), 2,
      sym_comment,
      sym_block_comment,
    STATE(9185), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9294), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10278), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13465), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6660), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6764), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [133984] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym__alpha_identifier,
    ACTIONS(6458), 1,
      anon_sym_COLON,
    ACTIONS(6460), 1,
      anon_sym_LBRACE,
    ACTIONS(6462), 1,
      anon_sym__,
    ACTIONS(6464), 1,
      anon_sym_LBRACK,
    ACTIONS(6468), 1,
      anon_sym_LPAREN,
    ACTIONS(6470), 1,
      sym__backquoted_id,
    ACTIONS(6472), 1,
      sym_operator_identifier,
    ACTIONS(6474), 1,
      sym_integer_literal,
    STATE(5654), 1,
      sym__simple_type,
    STATE(6003), 1,
      sym_identifier,
    STATE(6313), 1,
      sym__soft_identifier,
    STATE(6510), 1,
      sym__annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(9520), 1,
      sym_annotated_type,
    STATE(10863), 1,
      sym__non_null_literal,
    STATE(10903), 1,
      sym_literal_type,
    STATE(11095), 1,
      sym__type,
    STATE(12319), 1,
      sym__infix_type_choice,
    STATE(14991), 1,
      sym_parameter_types,
    STATE(16863), 1,
      sym_stable_identifier,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3430), 2,
      sym_comment,
      sym_block_comment,
    STATE(10159), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10965), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6466), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [134105] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15703), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3431), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [134226] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1830), 1,
      sym_integer_literal,
    ACTIONS(6650), 1,
      sym__alpha_identifier,
    ACTIONS(6652), 1,
      anon_sym_COLON,
    ACTIONS(6654), 1,
      anon_sym_LBRACE,
    ACTIONS(6656), 1,
      anon_sym__,
    ACTIONS(6658), 1,
      anon_sym_LBRACK,
    ACTIONS(6662), 1,
      anon_sym_LPAREN,
    ACTIONS(6664), 1,
      sym__backquoted_id,
    ACTIONS(6666), 1,
      sym_operator_identifier,
    STATE(5598), 1,
      sym__simple_type,
    STATE(5942), 1,
      sym__annotated_type,
    STATE(6112), 1,
      sym_identifier,
    STATE(6233), 1,
      sym__soft_identifier,
    STATE(8943), 1,
      sym_annotated_type,
    STATE(10664), 1,
      sym__non_null_literal,
    STATE(10826), 1,
      sym_literal_type,
    STATE(12522), 1,
      sym__infix_type_choice,
    STATE(13404), 1,
      sym_template_body,
    STATE(13466), 1,
      sym__type,
    STATE(15028), 1,
      sym_parameter_types,
    STATE(17149), 1,
      sym_stable_identifier,
    ACTIONS(1832), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1834), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1838), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3432), 2,
      sym_comment,
      sym_block_comment,
    STATE(9185), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9294), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10278), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13465), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6660), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6764), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [134347] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15713), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3433), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [134468] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6602), 1,
      anon_sym_COLON,
    ACTIONS(6604), 1,
      anon_sym_LBRACE,
    ACTIONS(6606), 1,
      anon_sym__,
    ACTIONS(6608), 1,
      anon_sym_LBRACK,
    ACTIONS(6612), 1,
      anon_sym_LPAREN,
    ACTIONS(6614), 1,
      sym__backquoted_id,
    ACTIONS(6616), 1,
      sym_operator_identifier,
    ACTIONS(6618), 1,
      sym_integer_literal,
    STATE(5326), 1,
      sym__simple_type,
    STATE(5721), 1,
      sym__annotated_type,
    STATE(5817), 1,
      sym__soft_identifier,
    STATE(5848), 1,
      sym_identifier,
    STATE(9098), 1,
      sym_annotated_type,
    STATE(10650), 1,
      sym__non_null_literal,
    STATE(10651), 1,
      sym_literal_type,
    STATE(10698), 1,
      sym_template_body,
    STATE(10772), 1,
      sym__type,
    STATE(12409), 1,
      sym__infix_type_choice,
    STATE(15275), 1,
      sym_parameter_types,
    STATE(16425), 1,
      sym_stable_identifier,
    ACTIONS(6620), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6622), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6624), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3434), 2,
      sym_comment,
      sym_block_comment,
    STATE(10108), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10517), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10947), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6610), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6472), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [134589] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym__alpha_identifier,
    ACTIONS(6458), 1,
      anon_sym_COLON,
    ACTIONS(6460), 1,
      anon_sym_LBRACE,
    ACTIONS(6462), 1,
      anon_sym__,
    ACTIONS(6464), 1,
      anon_sym_LBRACK,
    ACTIONS(6468), 1,
      anon_sym_LPAREN,
    ACTIONS(6470), 1,
      sym__backquoted_id,
    ACTIONS(6472), 1,
      sym_operator_identifier,
    ACTIONS(6474), 1,
      sym_integer_literal,
    STATE(5654), 1,
      sym__simple_type,
    STATE(6003), 1,
      sym_identifier,
    STATE(6313), 1,
      sym__soft_identifier,
    STATE(6510), 1,
      sym__annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(8560), 1,
      sym__type,
    STATE(9520), 1,
      sym_annotated_type,
    STATE(10863), 1,
      sym__non_null_literal,
    STATE(10903), 1,
      sym_literal_type,
    STATE(12319), 1,
      sym__infix_type_choice,
    STATE(14991), 1,
      sym_parameter_types,
    STATE(16863), 1,
      sym_stable_identifier,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3435), 2,
      sym_comment,
      sym_block_comment,
    STATE(10159), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10965), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6466), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [134710] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym__alpha_identifier,
    ACTIONS(6458), 1,
      anon_sym_COLON,
    ACTIONS(6460), 1,
      anon_sym_LBRACE,
    ACTIONS(6462), 1,
      anon_sym__,
    ACTIONS(6464), 1,
      anon_sym_LBRACK,
    ACTIONS(6468), 1,
      anon_sym_LPAREN,
    ACTIONS(6470), 1,
      sym__backquoted_id,
    ACTIONS(6472), 1,
      sym_operator_identifier,
    ACTIONS(6474), 1,
      sym_integer_literal,
    STATE(5654), 1,
      sym__simple_type,
    STATE(6003), 1,
      sym_identifier,
    STATE(6313), 1,
      sym__soft_identifier,
    STATE(6510), 1,
      sym__annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(8592), 1,
      sym__type,
    STATE(9520), 1,
      sym_annotated_type,
    STATE(10863), 1,
      sym__non_null_literal,
    STATE(10903), 1,
      sym_literal_type,
    STATE(12319), 1,
      sym__infix_type_choice,
    STATE(14991), 1,
      sym_parameter_types,
    STATE(16863), 1,
      sym_stable_identifier,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3436), 2,
      sym_comment,
      sym_block_comment,
    STATE(10159), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10965), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6466), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [134831] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15751), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3437), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [134952] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym__alpha_identifier,
    ACTIONS(6458), 1,
      anon_sym_COLON,
    ACTIONS(6460), 1,
      anon_sym_LBRACE,
    ACTIONS(6462), 1,
      anon_sym__,
    ACTIONS(6464), 1,
      anon_sym_LBRACK,
    ACTIONS(6468), 1,
      anon_sym_LPAREN,
    ACTIONS(6470), 1,
      sym__backquoted_id,
    ACTIONS(6472), 1,
      sym_operator_identifier,
    ACTIONS(6474), 1,
      sym_integer_literal,
    STATE(5654), 1,
      sym__simple_type,
    STATE(6003), 1,
      sym_identifier,
    STATE(6313), 1,
      sym__soft_identifier,
    STATE(6510), 1,
      sym__annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(8669), 1,
      sym__type,
    STATE(9520), 1,
      sym_annotated_type,
    STATE(10863), 1,
      sym__non_null_literal,
    STATE(10903), 1,
      sym_literal_type,
    STATE(12319), 1,
      sym__infix_type_choice,
    STATE(14991), 1,
      sym_parameter_types,
    STATE(16863), 1,
      sym_stable_identifier,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3438), 2,
      sym_comment,
      sym_block_comment,
    STATE(10159), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10965), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6466), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [135073] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15758), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3439), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [135194] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6182), 1,
      anon_sym_LBRACK,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(7246), 1,
      sym__annotated_type,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12466), 1,
      sym__infix_type_choice,
    STATE(12989), 1,
      sym__type,
    STATE(15109), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3440), 2,
      sym_comment,
      sym_block_comment,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [135315] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1830), 1,
      sym_integer_literal,
    ACTIONS(6650), 1,
      sym__alpha_identifier,
    ACTIONS(6652), 1,
      anon_sym_COLON,
    ACTIONS(6654), 1,
      anon_sym_LBRACE,
    ACTIONS(6656), 1,
      anon_sym__,
    ACTIONS(6658), 1,
      anon_sym_LBRACK,
    ACTIONS(6662), 1,
      anon_sym_LPAREN,
    ACTIONS(6664), 1,
      sym__backquoted_id,
    ACTIONS(6666), 1,
      sym_operator_identifier,
    STATE(5598), 1,
      sym__simple_type,
    STATE(5942), 1,
      sym__annotated_type,
    STATE(6112), 1,
      sym_identifier,
    STATE(6233), 1,
      sym__soft_identifier,
    STATE(8943), 1,
      sym_annotated_type,
    STATE(10664), 1,
      sym__non_null_literal,
    STATE(10826), 1,
      sym_literal_type,
    STATE(12522), 1,
      sym__infix_type_choice,
    STATE(13404), 1,
      sym_template_body,
    STATE(13411), 1,
      sym__type,
    STATE(15028), 1,
      sym_parameter_types,
    STATE(17149), 1,
      sym_stable_identifier,
    ACTIONS(1832), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1834), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1838), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3441), 2,
      sym_comment,
      sym_block_comment,
    STATE(9185), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9294), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10278), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13465), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6660), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6764), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [135436] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4700), 1,
      anon_sym_COLON,
    ACTIONS(4702), 1,
      anon_sym_LBRACE,
    ACTIONS(4770), 1,
      sym__alpha_identifier,
    ACTIONS(4772), 1,
      anon_sym__,
    ACTIONS(4776), 1,
      anon_sym_LBRACK,
    ACTIONS(4782), 1,
      sym__backquoted_id,
    ACTIONS(4786), 1,
      sym_integer_literal,
    ACTIONS(6708), 1,
      anon_sym_LPAREN,
    ACTIONS(6710), 1,
      sym_operator_identifier,
    STATE(4279), 1,
      sym__simple_type,
    STATE(4380), 1,
      sym__annotated_type,
    STATE(4395), 1,
      sym_identifier,
    STATE(4399), 1,
      sym__soft_identifier,
    STATE(5134), 1,
      sym_annotated_type,
    STATE(8293), 1,
      sym__non_null_literal,
    STATE(8397), 1,
      sym_literal_type,
    STATE(11144), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12481), 1,
      sym__infix_type_choice,
    STATE(15025), 1,
      sym_parameter_types,
    STATE(17007), 1,
      sym_stable_identifier,
    ACTIONS(4788), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4790), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4792), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3442), 2,
      sym_comment,
      sym_block_comment,
    STATE(7263), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8127), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4778), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4539), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [135557] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6602), 1,
      anon_sym_COLON,
    ACTIONS(6604), 1,
      anon_sym_LBRACE,
    ACTIONS(6606), 1,
      anon_sym__,
    ACTIONS(6608), 1,
      anon_sym_LBRACK,
    ACTIONS(6612), 1,
      anon_sym_LPAREN,
    ACTIONS(6614), 1,
      sym__backquoted_id,
    ACTIONS(6616), 1,
      sym_operator_identifier,
    ACTIONS(6618), 1,
      sym_integer_literal,
    STATE(5326), 1,
      sym__simple_type,
    STATE(5721), 1,
      sym__annotated_type,
    STATE(5817), 1,
      sym__soft_identifier,
    STATE(5848), 1,
      sym_identifier,
    STATE(9098), 1,
      sym_annotated_type,
    STATE(10650), 1,
      sym__non_null_literal,
    STATE(10651), 1,
      sym_literal_type,
    STATE(10698), 1,
      sym_template_body,
    STATE(10894), 1,
      sym__type,
    STATE(12409), 1,
      sym__infix_type_choice,
    STATE(15275), 1,
      sym_parameter_types,
    STATE(16425), 1,
      sym_stable_identifier,
    ACTIONS(6620), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6622), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6624), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3443), 2,
      sym_comment,
      sym_block_comment,
    STATE(10108), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10517), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10947), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6610), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6472), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [135678] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6602), 1,
      anon_sym_COLON,
    ACTIONS(6604), 1,
      anon_sym_LBRACE,
    ACTIONS(6606), 1,
      anon_sym__,
    ACTIONS(6608), 1,
      anon_sym_LBRACK,
    ACTIONS(6612), 1,
      anon_sym_LPAREN,
    ACTIONS(6614), 1,
      sym__backquoted_id,
    ACTIONS(6616), 1,
      sym_operator_identifier,
    ACTIONS(6618), 1,
      sym_integer_literal,
    STATE(5326), 1,
      sym__simple_type,
    STATE(5721), 1,
      sym__annotated_type,
    STATE(5817), 1,
      sym__soft_identifier,
    STATE(5848), 1,
      sym_identifier,
    STATE(9098), 1,
      sym_annotated_type,
    STATE(10650), 1,
      sym__non_null_literal,
    STATE(10651), 1,
      sym_literal_type,
    STATE(10693), 1,
      sym__type,
    STATE(10698), 1,
      sym_template_body,
    STATE(12409), 1,
      sym__infix_type_choice,
    STATE(15275), 1,
      sym_parameter_types,
    STATE(16425), 1,
      sym_stable_identifier,
    ACTIONS(6620), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6622), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6624), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3444), 2,
      sym_comment,
      sym_block_comment,
    STATE(10108), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10517), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10947), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6610), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6472), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [135799] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15798), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3445), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [135920] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6602), 1,
      anon_sym_COLON,
    ACTIONS(6604), 1,
      anon_sym_LBRACE,
    ACTIONS(6606), 1,
      anon_sym__,
    ACTIONS(6608), 1,
      anon_sym_LBRACK,
    ACTIONS(6612), 1,
      anon_sym_LPAREN,
    ACTIONS(6614), 1,
      sym__backquoted_id,
    ACTIONS(6616), 1,
      sym_operator_identifier,
    ACTIONS(6618), 1,
      sym_integer_literal,
    STATE(5326), 1,
      sym__simple_type,
    STATE(5721), 1,
      sym__annotated_type,
    STATE(5817), 1,
      sym__soft_identifier,
    STATE(5848), 1,
      sym_identifier,
    STATE(9098), 1,
      sym_annotated_type,
    STATE(10650), 1,
      sym__non_null_literal,
    STATE(10651), 1,
      sym_literal_type,
    STATE(10698), 1,
      sym_template_body,
    STATE(10852), 1,
      sym__type,
    STATE(12409), 1,
      sym__infix_type_choice,
    STATE(15275), 1,
      sym_parameter_types,
    STATE(16425), 1,
      sym_stable_identifier,
    ACTIONS(6620), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6622), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6624), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3446), 2,
      sym_comment,
      sym_block_comment,
    STATE(10108), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10517), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10947), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6610), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6472), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [136041] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15808), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3447), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [136162] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6602), 1,
      anon_sym_COLON,
    ACTIONS(6604), 1,
      anon_sym_LBRACE,
    ACTIONS(6606), 1,
      anon_sym__,
    ACTIONS(6608), 1,
      anon_sym_LBRACK,
    ACTIONS(6612), 1,
      anon_sym_LPAREN,
    ACTIONS(6614), 1,
      sym__backquoted_id,
    ACTIONS(6616), 1,
      sym_operator_identifier,
    ACTIONS(6618), 1,
      sym_integer_literal,
    STATE(5326), 1,
      sym__simple_type,
    STATE(5721), 1,
      sym__annotated_type,
    STATE(5817), 1,
      sym__soft_identifier,
    STATE(5848), 1,
      sym_identifier,
    STATE(9098), 1,
      sym_annotated_type,
    STATE(10650), 1,
      sym__non_null_literal,
    STATE(10651), 1,
      sym_literal_type,
    STATE(10698), 1,
      sym_template_body,
    STATE(10714), 1,
      sym__type,
    STATE(12409), 1,
      sym__infix_type_choice,
    STATE(15275), 1,
      sym_parameter_types,
    STATE(16425), 1,
      sym_stable_identifier,
    ACTIONS(6620), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6622), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6624), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3448), 2,
      sym_comment,
      sym_block_comment,
    STATE(10108), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10517), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10947), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6610), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6472), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [136283] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4700), 1,
      anon_sym_COLON,
    ACTIONS(4702), 1,
      anon_sym_LBRACE,
    ACTIONS(4770), 1,
      sym__alpha_identifier,
    ACTIONS(4772), 1,
      anon_sym__,
    ACTIONS(4776), 1,
      anon_sym_LBRACK,
    ACTIONS(4782), 1,
      sym__backquoted_id,
    ACTIONS(4786), 1,
      sym_integer_literal,
    ACTIONS(6708), 1,
      anon_sym_LPAREN,
    ACTIONS(6710), 1,
      sym_operator_identifier,
    STATE(4279), 1,
      sym__simple_type,
    STATE(4380), 1,
      sym__annotated_type,
    STATE(4395), 1,
      sym_identifier,
    STATE(4399), 1,
      sym__soft_identifier,
    STATE(5134), 1,
      sym_annotated_type,
    STATE(8293), 1,
      sym__non_null_literal,
    STATE(8397), 1,
      sym_literal_type,
    STATE(11146), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12481), 1,
      sym__infix_type_choice,
    STATE(15025), 1,
      sym_parameter_types,
    STATE(17007), 1,
      sym_stable_identifier,
    ACTIONS(4788), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4790), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4792), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3449), 2,
      sym_comment,
      sym_block_comment,
    STATE(7263), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8127), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4778), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4539), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [136404] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(4640), 1,
      sym__alpha_identifier,
    ACTIONS(4642), 1,
      anon_sym__,
    ACTIONS(4646), 1,
      anon_sym_LBRACK,
    ACTIONS(4652), 1,
      sym__backquoted_id,
    ACTIONS(4656), 1,
      sym_integer_literal,
    ACTIONS(6686), 1,
      anon_sym_LPAREN,
    ACTIONS(6688), 1,
      sym_operator_identifier,
    STATE(7244), 1,
      sym__annotated_type,
    STATE(7245), 1,
      sym__simple_type,
    STATE(7872), 1,
      sym__soft_identifier,
    STATE(7995), 1,
      sym_identifier,
    STATE(9803), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11164), 1,
      sym__non_null_literal,
    STATE(11165), 1,
      sym_literal_type,
    STATE(11298), 1,
      sym__type,
    STATE(12340), 1,
      sym__infix_type_choice,
    STATE(15510), 1,
      sym_parameter_types,
    STATE(17142), 1,
      sym_stable_identifier,
    ACTIONS(4658), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4660), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4662), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3450), 2,
      sym_comment,
      sym_block_comment,
    STATE(10734), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11317), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4648), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8425), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [136525] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1720), 1,
      sym_integer_literal,
    ACTIONS(6712), 1,
      sym__alpha_identifier,
    ACTIONS(6714), 1,
      anon_sym_COLON,
    ACTIONS(6716), 1,
      anon_sym_LBRACE,
    ACTIONS(6718), 1,
      anon_sym__,
    ACTIONS(6720), 1,
      anon_sym_LBRACK,
    ACTIONS(6724), 1,
      anon_sym_LPAREN,
    ACTIONS(6726), 1,
      sym__backquoted_id,
    ACTIONS(6728), 1,
      sym_operator_identifier,
    STATE(5508), 1,
      sym__annotated_type,
    STATE(5977), 1,
      sym__simple_type,
    STATE(6378), 1,
      sym__soft_identifier,
    STATE(6583), 1,
      sym_identifier,
    STATE(9268), 1,
      sym_annotated_type,
    STATE(10726), 1,
      sym__non_null_literal,
    STATE(10755), 1,
      sym_literal_type,
    STATE(12542), 1,
      sym__infix_type_choice,
    STATE(13617), 1,
      sym_template_body,
    STATE(13702), 1,
      sym__type,
    STATE(15031), 1,
      sym_parameter_types,
    STATE(17227), 1,
      sym_stable_identifier,
    ACTIONS(1722), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1724), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1728), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3451), 2,
      sym_comment,
      sym_block_comment,
    STATE(8768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9082), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10246), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13417), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6722), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7014), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [136646] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4700), 1,
      anon_sym_COLON,
    ACTIONS(4702), 1,
      anon_sym_LBRACE,
    ACTIONS(4770), 1,
      sym__alpha_identifier,
    ACTIONS(4772), 1,
      anon_sym__,
    ACTIONS(4776), 1,
      anon_sym_LBRACK,
    ACTIONS(4782), 1,
      sym__backquoted_id,
    ACTIONS(4786), 1,
      sym_integer_literal,
    ACTIONS(6708), 1,
      anon_sym_LPAREN,
    ACTIONS(6710), 1,
      sym_operator_identifier,
    STATE(4279), 1,
      sym__simple_type,
    STATE(4380), 1,
      sym__annotated_type,
    STATE(4395), 1,
      sym_identifier,
    STATE(4399), 1,
      sym__soft_identifier,
    STATE(5134), 1,
      sym_annotated_type,
    STATE(8293), 1,
      sym__non_null_literal,
    STATE(8397), 1,
      sym_literal_type,
    STATE(11147), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12481), 1,
      sym__infix_type_choice,
    STATE(15025), 1,
      sym_parameter_types,
    STATE(17007), 1,
      sym_stable_identifier,
    ACTIONS(4788), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4790), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4792), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3452), 2,
      sym_comment,
      sym_block_comment,
    STATE(7263), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8127), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4778), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4539), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [136767] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15832), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3453), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [136888] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4700), 1,
      anon_sym_COLON,
    ACTIONS(4702), 1,
      anon_sym_LBRACE,
    ACTIONS(4770), 1,
      sym__alpha_identifier,
    ACTIONS(4772), 1,
      anon_sym__,
    ACTIONS(4776), 1,
      anon_sym_LBRACK,
    ACTIONS(4782), 1,
      sym__backquoted_id,
    ACTIONS(4786), 1,
      sym_integer_literal,
    ACTIONS(6708), 1,
      anon_sym_LPAREN,
    ACTIONS(6710), 1,
      sym_operator_identifier,
    STATE(4279), 1,
      sym__simple_type,
    STATE(4380), 1,
      sym__annotated_type,
    STATE(4395), 1,
      sym_identifier,
    STATE(4399), 1,
      sym__soft_identifier,
    STATE(5134), 1,
      sym_annotated_type,
    STATE(8293), 1,
      sym__non_null_literal,
    STATE(8397), 1,
      sym_literal_type,
    STATE(11148), 1,
      sym__type,
    STATE(11182), 1,
      sym_template_body,
    STATE(12481), 1,
      sym__infix_type_choice,
    STATE(15025), 1,
      sym_parameter_types,
    STATE(17007), 1,
      sym_stable_identifier,
    ACTIONS(4788), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4790), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4792), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3454), 2,
      sym_comment,
      sym_block_comment,
    STATE(7263), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8127), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11326), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4778), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4539), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [137009] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15834), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3455), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [137130] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4254), 1,
      sym__alpha_identifier,
    ACTIONS(4256), 1,
      anon_sym_COLON,
    ACTIONS(4258), 1,
      anon_sym_LBRACE,
    ACTIONS(4260), 1,
      anon_sym__,
    ACTIONS(4264), 1,
      anon_sym_LBRACK,
    ACTIONS(4272), 1,
      sym__backquoted_id,
    ACTIONS(4276), 1,
      sym_integer_literal,
    ACTIONS(6730), 1,
      anon_sym_LPAREN,
    ACTIONS(6732), 1,
      sym_operator_identifier,
    STATE(4728), 1,
      sym__annotated_type,
    STATE(4744), 1,
      sym__simple_type,
    STATE(4846), 1,
      sym_identifier,
    STATE(4941), 1,
      sym__soft_identifier,
    STATE(7118), 1,
      sym_annotated_type,
    STATE(9780), 1,
      sym__non_null_literal,
    STATE(9969), 1,
      sym_literal_type,
    STATE(12524), 1,
      sym__infix_type_choice,
    STATE(12881), 1,
      sym_template_body,
    STATE(12906), 1,
      sym__type,
    STATE(15047), 1,
      sym_parameter_types,
    STATE(17161), 1,
      sym_stable_identifier,
    ACTIONS(4278), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4280), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4284), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3456), 2,
      sym_comment,
      sym_block_comment,
    STATE(9211), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9742), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12862), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12809), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4266), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5096), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [137251] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4254), 1,
      sym__alpha_identifier,
    ACTIONS(4256), 1,
      anon_sym_COLON,
    ACTIONS(4258), 1,
      anon_sym_LBRACE,
    ACTIONS(4260), 1,
      anon_sym__,
    ACTIONS(4264), 1,
      anon_sym_LBRACK,
    ACTIONS(4272), 1,
      sym__backquoted_id,
    ACTIONS(4276), 1,
      sym_integer_literal,
    ACTIONS(6730), 1,
      anon_sym_LPAREN,
    ACTIONS(6732), 1,
      sym_operator_identifier,
    STATE(4728), 1,
      sym__annotated_type,
    STATE(4744), 1,
      sym__simple_type,
    STATE(4846), 1,
      sym_identifier,
    STATE(4941), 1,
      sym__soft_identifier,
    STATE(7118), 1,
      sym_annotated_type,
    STATE(9780), 1,
      sym__non_null_literal,
    STATE(9969), 1,
      sym_literal_type,
    STATE(12524), 1,
      sym__infix_type_choice,
    STATE(12881), 1,
      sym_template_body,
    STATE(12915), 1,
      sym__type,
    STATE(15047), 1,
      sym_parameter_types,
    STATE(17161), 1,
      sym_stable_identifier,
    ACTIONS(4278), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4280), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4284), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3457), 2,
      sym_comment,
      sym_block_comment,
    STATE(9211), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9742), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12862), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12809), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4266), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5096), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [137372] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6388), 1,
      sym__alpha_identifier,
    ACTIONS(6390), 1,
      anon_sym_COLON,
    ACTIONS(6392), 1,
      anon_sym_LBRACE,
    ACTIONS(6394), 1,
      anon_sym__,
    ACTIONS(6396), 1,
      anon_sym_LBRACK,
    ACTIONS(6400), 1,
      anon_sym_LPAREN,
    ACTIONS(6402), 1,
      sym__backquoted_id,
    ACTIONS(6404), 1,
      sym_operator_identifier,
    ACTIONS(6406), 1,
      sym_integer_literal,
    STATE(5646), 1,
      sym__simple_type,
    STATE(6195), 1,
      sym_identifier,
    STATE(6475), 1,
      sym__annotated_type,
    STATE(6548), 1,
      sym__soft_identifier,
    STATE(9396), 1,
      sym_annotated_type,
    STATE(10819), 1,
      sym__non_null_literal,
    STATE(10821), 1,
      sym_literal_type,
    STATE(11054), 1,
      sym__type,
    STATE(11057), 1,
      sym_template_body,
    STATE(12379), 1,
      sym__infix_type_choice,
    STATE(15012), 1,
      sym_parameter_types,
    STATE(16293), 1,
      sym_stable_identifier,
    ACTIONS(6408), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6410), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6412), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3458), 2,
      sym_comment,
      sym_block_comment,
    STATE(10173), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10710), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11104), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10976), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6398), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7147), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [137493] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(4640), 1,
      sym__alpha_identifier,
    ACTIONS(4642), 1,
      anon_sym__,
    ACTIONS(4646), 1,
      anon_sym_LBRACK,
    ACTIONS(4652), 1,
      sym__backquoted_id,
    ACTIONS(4656), 1,
      sym_integer_literal,
    ACTIONS(6686), 1,
      anon_sym_LPAREN,
    ACTIONS(6688), 1,
      sym_operator_identifier,
    STATE(7244), 1,
      sym__annotated_type,
    STATE(7245), 1,
      sym__simple_type,
    STATE(7872), 1,
      sym__soft_identifier,
    STATE(7995), 1,
      sym_identifier,
    STATE(9803), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11164), 1,
      sym__non_null_literal,
    STATE(11165), 1,
      sym_literal_type,
    STATE(11302), 1,
      sym__type,
    STATE(12340), 1,
      sym__infix_type_choice,
    STATE(15510), 1,
      sym_parameter_types,
    STATE(17142), 1,
      sym_stable_identifier,
    ACTIONS(4658), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4660), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4662), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3459), 2,
      sym_comment,
      sym_block_comment,
    STATE(10734), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11317), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4648), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8425), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [137614] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(4640), 1,
      sym__alpha_identifier,
    ACTIONS(4642), 1,
      anon_sym__,
    ACTIONS(4646), 1,
      anon_sym_LBRACK,
    ACTIONS(4652), 1,
      sym__backquoted_id,
    ACTIONS(4656), 1,
      sym_integer_literal,
    ACTIONS(6686), 1,
      anon_sym_LPAREN,
    ACTIONS(6688), 1,
      sym_operator_identifier,
    STATE(7244), 1,
      sym__annotated_type,
    STATE(7245), 1,
      sym__simple_type,
    STATE(7872), 1,
      sym__soft_identifier,
    STATE(7995), 1,
      sym_identifier,
    STATE(9803), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11164), 1,
      sym__non_null_literal,
    STATE(11165), 1,
      sym_literal_type,
    STATE(11303), 1,
      sym__type,
    STATE(12340), 1,
      sym__infix_type_choice,
    STATE(15510), 1,
      sym_parameter_types,
    STATE(17142), 1,
      sym_stable_identifier,
    ACTIONS(4658), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4660), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4662), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3460), 2,
      sym_comment,
      sym_block_comment,
    STATE(10734), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11317), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4648), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8425), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [137735] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15848), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3461), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [137856] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4254), 1,
      sym__alpha_identifier,
    ACTIONS(4256), 1,
      anon_sym_COLON,
    ACTIONS(4258), 1,
      anon_sym_LBRACE,
    ACTIONS(4260), 1,
      anon_sym__,
    ACTIONS(4264), 1,
      anon_sym_LBRACK,
    ACTIONS(4272), 1,
      sym__backquoted_id,
    ACTIONS(4276), 1,
      sym_integer_literal,
    ACTIONS(6730), 1,
      anon_sym_LPAREN,
    ACTIONS(6732), 1,
      sym_operator_identifier,
    STATE(4728), 1,
      sym__annotated_type,
    STATE(4744), 1,
      sym__simple_type,
    STATE(4846), 1,
      sym_identifier,
    STATE(4941), 1,
      sym__soft_identifier,
    STATE(7118), 1,
      sym_annotated_type,
    STATE(9780), 1,
      sym__non_null_literal,
    STATE(9969), 1,
      sym_literal_type,
    STATE(12524), 1,
      sym__infix_type_choice,
    STATE(12881), 1,
      sym_template_body,
    STATE(12921), 1,
      sym__type,
    STATE(15047), 1,
      sym_parameter_types,
    STATE(17161), 1,
      sym_stable_identifier,
    ACTIONS(4278), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4280), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4284), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3462), 2,
      sym_comment,
      sym_block_comment,
    STATE(9211), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9742), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12862), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12809), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4266), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5096), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [137977] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15129), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3463), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [138098] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4254), 1,
      sym__alpha_identifier,
    ACTIONS(4256), 1,
      anon_sym_COLON,
    ACTIONS(4258), 1,
      anon_sym_LBRACE,
    ACTIONS(4260), 1,
      anon_sym__,
    ACTIONS(4264), 1,
      anon_sym_LBRACK,
    ACTIONS(4272), 1,
      sym__backquoted_id,
    ACTIONS(4276), 1,
      sym_integer_literal,
    ACTIONS(6730), 1,
      anon_sym_LPAREN,
    ACTIONS(6732), 1,
      sym_operator_identifier,
    STATE(4728), 1,
      sym__annotated_type,
    STATE(4744), 1,
      sym__simple_type,
    STATE(4846), 1,
      sym_identifier,
    STATE(4941), 1,
      sym__soft_identifier,
    STATE(7118), 1,
      sym_annotated_type,
    STATE(9780), 1,
      sym__non_null_literal,
    STATE(9969), 1,
      sym_literal_type,
    STATE(12524), 1,
      sym__infix_type_choice,
    STATE(12881), 1,
      sym_template_body,
    STATE(12930), 1,
      sym__type,
    STATE(15047), 1,
      sym_parameter_types,
    STATE(17161), 1,
      sym_stable_identifier,
    ACTIONS(4278), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4280), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4284), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3464), 2,
      sym_comment,
      sym_block_comment,
    STATE(9211), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9742), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12862), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12809), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4266), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5096), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [138219] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    ACTIONS(6644), 1,
      anon_sym_LBRACK,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(11284), 1,
      sym__type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(15118), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3465), 2,
      sym_comment,
      sym_block_comment,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [138340] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6158), 1,
      anon_sym_COLON,
    ACTIONS(6160), 1,
      anon_sym_LBRACE,
    ACTIONS(6162), 1,
      anon_sym_LBRACK,
    ACTIONS(6164), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(7387), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(10986), 1,
      sym__non_null_literal,
    STATE(10988), 1,
      sym_literal_type,
    STATE(11158), 1,
      sym_template_body,
    STATE(11954), 1,
      sym__type,
    STATE(12334), 1,
      sym__infix_type_choice,
    STATE(15319), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3466), 2,
      sym_comment,
      sym_block_comment,
    STATE(10591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11237), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11264), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [138461] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15044), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3467), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [138582] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(4640), 1,
      sym__alpha_identifier,
    ACTIONS(4642), 1,
      anon_sym__,
    ACTIONS(4646), 1,
      anon_sym_LBRACK,
    ACTIONS(4652), 1,
      sym__backquoted_id,
    ACTIONS(4656), 1,
      sym_integer_literal,
    ACTIONS(6686), 1,
      anon_sym_LPAREN,
    ACTIONS(6688), 1,
      sym_operator_identifier,
    STATE(7244), 1,
      sym__annotated_type,
    STATE(7245), 1,
      sym__simple_type,
    STATE(7872), 1,
      sym__soft_identifier,
    STATE(7995), 1,
      sym_identifier,
    STATE(9803), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11164), 1,
      sym__non_null_literal,
    STATE(11165), 1,
      sym_literal_type,
    STATE(11304), 1,
      sym__type,
    STATE(12340), 1,
      sym__infix_type_choice,
    STATE(15510), 1,
      sym_parameter_types,
    STATE(17142), 1,
      sym_stable_identifier,
    ACTIONS(4658), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4660), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4662), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3468), 2,
      sym_comment,
      sym_block_comment,
    STATE(10734), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11317), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4648), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8425), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [138703] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15137), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3469), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [138824] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3312), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6734), 1,
      anon_sym_COLON,
    ACTIONS(6736), 1,
      anon_sym_LBRACE,
    ACTIONS(6738), 1,
      anon_sym_LBRACK,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(9878), 1,
      sym__annotated_type,
    STATE(12417), 1,
      sym__infix_type_choice,
    STATE(13011), 1,
      sym__non_null_literal,
    STATE(13015), 1,
      sym_literal_type,
    STATE(15455), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17066), 1,
      sym__type,
    STATE(17378), 1,
      sym_template_body,
    ACTIONS(3314), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(3316), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(3320), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3470), 2,
      sym_comment,
      sym_block_comment,
    STATE(10820), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12330), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(16792), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(16879), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [138945] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6172), 1,
      anon_sym_LBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12386), 1,
      sym__infix_type_choice,
    STATE(15018), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17322), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3471), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [139066] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    ACTIONS(6644), 1,
      anon_sym_LBRACK,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(11298), 1,
      sym__type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(15118), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3472), 2,
      sym_comment,
      sym_block_comment,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [139187] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15601), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3473), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [139308] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    ACTIONS(6644), 1,
      anon_sym_LBRACK,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(11302), 1,
      sym__type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(15118), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3474), 2,
      sym_comment,
      sym_block_comment,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [139429] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14776), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3475), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [139550] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6414), 1,
      anon_sym_COLON,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(6418), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(13983), 1,
      sym__type,
    STATE(15021), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3476), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [139671] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4254), 1,
      sym__alpha_identifier,
    ACTIONS(4256), 1,
      anon_sym_COLON,
    ACTIONS(4258), 1,
      anon_sym_LBRACE,
    ACTIONS(4260), 1,
      anon_sym__,
    ACTIONS(4264), 1,
      anon_sym_LBRACK,
    ACTIONS(4272), 1,
      sym__backquoted_id,
    ACTIONS(4276), 1,
      sym_integer_literal,
    ACTIONS(6730), 1,
      anon_sym_LPAREN,
    ACTIONS(6732), 1,
      sym_operator_identifier,
    STATE(4728), 1,
      sym__annotated_type,
    STATE(4744), 1,
      sym__simple_type,
    STATE(4846), 1,
      sym_identifier,
    STATE(4941), 1,
      sym__soft_identifier,
    STATE(7118), 1,
      sym_annotated_type,
    STATE(9780), 1,
      sym__non_null_literal,
    STATE(9969), 1,
      sym_literal_type,
    STATE(12524), 1,
      sym__infix_type_choice,
    STATE(12881), 1,
      sym_template_body,
    STATE(12999), 1,
      sym__type,
    STATE(15047), 1,
      sym_parameter_types,
    STATE(17161), 1,
      sym_stable_identifier,
    ACTIONS(4278), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4280), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4284), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3477), 2,
      sym_comment,
      sym_block_comment,
    STATE(9211), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9742), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12862), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12809), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4266), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5096), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [139792] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14989), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3478), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [139913] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3312), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6734), 1,
      anon_sym_COLON,
    ACTIONS(6736), 1,
      anon_sym_LBRACE,
    ACTIONS(6738), 1,
      anon_sym_LBRACK,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(9878), 1,
      sym__annotated_type,
    STATE(12417), 1,
      sym__infix_type_choice,
    STATE(13011), 1,
      sym__non_null_literal,
    STATE(13015), 1,
      sym_literal_type,
    STATE(15455), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17097), 1,
      sym__type,
    STATE(17378), 1,
      sym_template_body,
    ACTIONS(3314), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(3316), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(3320), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3479), 2,
      sym_comment,
      sym_block_comment,
    STATE(10820), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12330), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(16792), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(16879), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [140034] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15017), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3480), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [140155] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3312), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6734), 1,
      anon_sym_COLON,
    ACTIONS(6736), 1,
      anon_sym_LBRACE,
    ACTIONS(6738), 1,
      anon_sym_LBRACK,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(9878), 1,
      sym__annotated_type,
    STATE(12417), 1,
      sym__infix_type_choice,
    STATE(13011), 1,
      sym__non_null_literal,
    STATE(13015), 1,
      sym_literal_type,
    STATE(15455), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17100), 1,
      sym__type,
    STATE(17378), 1,
      sym_template_body,
    ACTIONS(3314), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(3316), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(3320), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3481), 2,
      sym_comment,
      sym_block_comment,
    STATE(10820), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12330), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(16792), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(16879), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [140276] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3312), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6734), 1,
      anon_sym_COLON,
    ACTIONS(6736), 1,
      anon_sym_LBRACE,
    ACTIONS(6738), 1,
      anon_sym_LBRACK,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(9878), 1,
      sym__annotated_type,
    STATE(12417), 1,
      sym__infix_type_choice,
    STATE(13011), 1,
      sym__non_null_literal,
    STATE(13015), 1,
      sym_literal_type,
    STATE(15455), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17102), 1,
      sym__type,
    STATE(17378), 1,
      sym_template_body,
    ACTIONS(3314), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(3316), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(3320), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3482), 2,
      sym_comment,
      sym_block_comment,
    STATE(10820), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12330), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(16792), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(16879), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [140397] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3312), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6734), 1,
      anon_sym_COLON,
    ACTIONS(6736), 1,
      anon_sym_LBRACE,
    ACTIONS(6738), 1,
      anon_sym_LBRACK,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(9878), 1,
      sym__annotated_type,
    STATE(12417), 1,
      sym__infix_type_choice,
    STATE(13011), 1,
      sym__non_null_literal,
    STATE(13015), 1,
      sym_literal_type,
    STATE(15455), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17104), 1,
      sym__type,
    STATE(17378), 1,
      sym_template_body,
    ACTIONS(3314), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(3316), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(3320), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3483), 2,
      sym_comment,
      sym_block_comment,
    STATE(10820), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12330), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(16792), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(16879), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [140518] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15197), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3484), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [140639] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1664), 1,
      sym_integer_literal,
    ACTIONS(6740), 1,
      sym__alpha_identifier,
    ACTIONS(6742), 1,
      anon_sym_COLON,
    ACTIONS(6744), 1,
      anon_sym_LBRACE,
    ACTIONS(6746), 1,
      anon_sym__,
    ACTIONS(6748), 1,
      anon_sym_LBRACK,
    ACTIONS(6752), 1,
      anon_sym_LPAREN,
    ACTIONS(6754), 1,
      sym__backquoted_id,
    ACTIONS(6756), 1,
      sym_operator_identifier,
    STATE(6197), 1,
      sym__simple_type,
    STATE(6256), 1,
      sym__annotated_type,
    STATE(6959), 1,
      sym_identifier,
    STATE(7274), 1,
      sym__soft_identifier,
    STATE(9511), 1,
      sym_annotated_type,
    STATE(11029), 1,
      sym_literal_type,
    STATE(11085), 1,
      sym__non_null_literal,
    STATE(11664), 1,
      sym_template_body,
    STATE(12009), 1,
      sym__type,
    STATE(12544), 1,
      sym__infix_type_choice,
    STATE(15064), 1,
      sym_parameter_types,
    STATE(17239), 1,
      sym_stable_identifier,
    ACTIONS(1666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1672), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3485), 2,
      sym_comment,
      sym_block_comment,
    STATE(5571), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9685), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10483), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6750), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7605), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [140760] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15223), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3486), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [140881] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1594), 1,
      sym_integer_literal,
    ACTIONS(6668), 1,
      sym__alpha_identifier,
    ACTIONS(6670), 1,
      anon_sym_COLON,
    ACTIONS(6672), 1,
      anon_sym_LBRACE,
    ACTIONS(6674), 1,
      anon_sym__,
    ACTIONS(6676), 1,
      anon_sym_LBRACK,
    ACTIONS(6680), 1,
      anon_sym_LPAREN,
    ACTIONS(6682), 1,
      sym__backquoted_id,
    ACTIONS(6684), 1,
      sym_operator_identifier,
    STATE(5712), 1,
      sym__simple_type,
    STATE(5797), 1,
      sym__annotated_type,
    STATE(6018), 1,
      sym_identifier,
    STATE(6257), 1,
      sym__soft_identifier,
    STATE(9026), 1,
      sym_annotated_type,
    STATE(10720), 1,
      sym_literal_type,
    STATE(10749), 1,
      sym__non_null_literal,
    STATE(12529), 1,
      sym__infix_type_choice,
    STATE(13535), 1,
      sym__type,
    STATE(13587), 1,
      sym_template_body,
    STATE(15029), 1,
      sym_parameter_types,
    STATE(17167), 1,
      sym_stable_identifier,
    ACTIONS(1596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1602), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3487), 2,
      sym_comment,
      sym_block_comment,
    STATE(9215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9231), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10356), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13594), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6678), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6819), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [141002] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1594), 1,
      sym_integer_literal,
    ACTIONS(6668), 1,
      sym__alpha_identifier,
    ACTIONS(6670), 1,
      anon_sym_COLON,
    ACTIONS(6672), 1,
      anon_sym_LBRACE,
    ACTIONS(6674), 1,
      anon_sym__,
    ACTIONS(6676), 1,
      anon_sym_LBRACK,
    ACTIONS(6680), 1,
      anon_sym_LPAREN,
    ACTIONS(6682), 1,
      sym__backquoted_id,
    ACTIONS(6684), 1,
      sym_operator_identifier,
    STATE(5712), 1,
      sym__simple_type,
    STATE(5797), 1,
      sym__annotated_type,
    STATE(6018), 1,
      sym_identifier,
    STATE(6257), 1,
      sym__soft_identifier,
    STATE(9026), 1,
      sym_annotated_type,
    STATE(10720), 1,
      sym_literal_type,
    STATE(10749), 1,
      sym__non_null_literal,
    STATE(12529), 1,
      sym__infix_type_choice,
    STATE(13560), 1,
      sym__type,
    STATE(13587), 1,
      sym_template_body,
    STATE(15029), 1,
      sym_parameter_types,
    STATE(17167), 1,
      sym_stable_identifier,
    ACTIONS(1596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1602), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3488), 2,
      sym_comment,
      sym_block_comment,
    STATE(9215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9231), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10356), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13594), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6678), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6819), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [141123] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6388), 1,
      sym__alpha_identifier,
    ACTIONS(6390), 1,
      anon_sym_COLON,
    ACTIONS(6392), 1,
      anon_sym_LBRACE,
    ACTIONS(6394), 1,
      anon_sym__,
    ACTIONS(6396), 1,
      anon_sym_LBRACK,
    ACTIONS(6400), 1,
      anon_sym_LPAREN,
    ACTIONS(6402), 1,
      sym__backquoted_id,
    ACTIONS(6404), 1,
      sym_operator_identifier,
    ACTIONS(6406), 1,
      sym_integer_literal,
    STATE(5646), 1,
      sym__simple_type,
    STATE(6195), 1,
      sym_identifier,
    STATE(6475), 1,
      sym__annotated_type,
    STATE(6548), 1,
      sym__soft_identifier,
    STATE(9396), 1,
      sym_annotated_type,
    STATE(10819), 1,
      sym__non_null_literal,
    STATE(10821), 1,
      sym_literal_type,
    STATE(11057), 1,
      sym_template_body,
    STATE(11117), 1,
      sym__type,
    STATE(12379), 1,
      sym__infix_type_choice,
    STATE(15012), 1,
      sym_parameter_types,
    STATE(16293), 1,
      sym_stable_identifier,
    ACTIONS(6408), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6410), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6412), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3489), 2,
      sym_comment,
      sym_block_comment,
    STATE(10173), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10710), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11104), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10976), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6398), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7147), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [141244] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15363), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3490), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [141365] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1594), 1,
      sym_integer_literal,
    ACTIONS(6668), 1,
      sym__alpha_identifier,
    ACTIONS(6670), 1,
      anon_sym_COLON,
    ACTIONS(6672), 1,
      anon_sym_LBRACE,
    ACTIONS(6674), 1,
      anon_sym__,
    ACTIONS(6676), 1,
      anon_sym_LBRACK,
    ACTIONS(6680), 1,
      anon_sym_LPAREN,
    ACTIONS(6682), 1,
      sym__backquoted_id,
    ACTIONS(6684), 1,
      sym_operator_identifier,
    STATE(5712), 1,
      sym__simple_type,
    STATE(5797), 1,
      sym__annotated_type,
    STATE(6018), 1,
      sym_identifier,
    STATE(6257), 1,
      sym__soft_identifier,
    STATE(9026), 1,
      sym_annotated_type,
    STATE(10720), 1,
      sym_literal_type,
    STATE(10749), 1,
      sym__non_null_literal,
    STATE(12529), 1,
      sym__infix_type_choice,
    STATE(13584), 1,
      sym__type,
    STATE(13587), 1,
      sym_template_body,
    STATE(15029), 1,
      sym_parameter_types,
    STATE(17167), 1,
      sym_stable_identifier,
    ACTIONS(1596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1602), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3491), 2,
      sym_comment,
      sym_block_comment,
    STATE(9215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9231), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10356), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13594), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6678), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6819), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [141486] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15399), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3492), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [141607] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6564), 1,
      anon_sym_LBRACK,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(14374), 1,
      sym__type,
    STATE(15084), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3493), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [141728] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1594), 1,
      sym_integer_literal,
    ACTIONS(6668), 1,
      sym__alpha_identifier,
    ACTIONS(6670), 1,
      anon_sym_COLON,
    ACTIONS(6672), 1,
      anon_sym_LBRACE,
    ACTIONS(6674), 1,
      anon_sym__,
    ACTIONS(6676), 1,
      anon_sym_LBRACK,
    ACTIONS(6680), 1,
      anon_sym_LPAREN,
    ACTIONS(6682), 1,
      sym__backquoted_id,
    ACTIONS(6684), 1,
      sym_operator_identifier,
    STATE(5712), 1,
      sym__simple_type,
    STATE(5797), 1,
      sym__annotated_type,
    STATE(6018), 1,
      sym_identifier,
    STATE(6257), 1,
      sym__soft_identifier,
    STATE(9026), 1,
      sym_annotated_type,
    STATE(10720), 1,
      sym_literal_type,
    STATE(10749), 1,
      sym__non_null_literal,
    STATE(12529), 1,
      sym__infix_type_choice,
    STATE(13587), 1,
      sym_template_body,
    STATE(13588), 1,
      sym__type,
    STATE(15029), 1,
      sym_parameter_types,
    STATE(17167), 1,
      sym_stable_identifier,
    ACTIONS(1596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1602), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3494), 2,
      sym_comment,
      sym_block_comment,
    STATE(9215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9231), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10356), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13594), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6678), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6819), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [141849] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6158), 1,
      anon_sym_COLON,
    ACTIONS(6160), 1,
      anon_sym_LBRACE,
    ACTIONS(6162), 1,
      anon_sym_LBRACK,
    ACTIONS(6164), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(7387), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(10986), 1,
      sym__non_null_literal,
    STATE(10988), 1,
      sym_literal_type,
    STATE(11158), 1,
      sym_template_body,
    STATE(11961), 1,
      sym__type,
    STATE(12334), 1,
      sym__infix_type_choice,
    STATE(15319), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3495), 2,
      sym_comment,
      sym_block_comment,
    STATE(10591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11237), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11264), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [141970] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6172), 1,
      anon_sym_LBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12386), 1,
      sym__infix_type_choice,
    STATE(15018), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17355), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3496), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [142091] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    ACTIONS(6644), 1,
      anon_sym_LBRACK,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(11303), 1,
      sym__type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(15118), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3497), 2,
      sym_comment,
      sym_block_comment,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [142212] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15525), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3498), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [142333] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    ACTIONS(6576), 1,
      anon_sym_LBRACK,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(6890), 1,
      sym__annotated_type,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(12405), 1,
      sym__infix_type_choice,
    STATE(13989), 1,
      sym__type,
    STATE(15140), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3499), 2,
      sym_comment,
      sym_block_comment,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [142454] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15561), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3500), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [142575] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15318), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3501), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [142696] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    ACTIONS(6644), 1,
      anon_sym_LBRACK,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(11304), 1,
      sym__type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(15118), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3502), 2,
      sym_comment,
      sym_block_comment,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [142817] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6758), 1,
      anon_sym_LBRACK,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8856), 1,
      sym__annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(11878), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12424), 1,
      sym__infix_type_choice,
    STATE(15058), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3503), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [142938] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15846), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3504), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [143059] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14748), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3505), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [143180] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6250), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(14352), 1,
      sym__type,
    STATE(15060), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3506), 2,
      sym_comment,
      sym_block_comment,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [143301] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1594), 1,
      sym_integer_literal,
    ACTIONS(6668), 1,
      sym__alpha_identifier,
    ACTIONS(6670), 1,
      anon_sym_COLON,
    ACTIONS(6672), 1,
      anon_sym_LBRACE,
    ACTIONS(6674), 1,
      anon_sym__,
    ACTIONS(6676), 1,
      anon_sym_LBRACK,
    ACTIONS(6680), 1,
      anon_sym_LPAREN,
    ACTIONS(6682), 1,
      sym__backquoted_id,
    ACTIONS(6684), 1,
      sym_operator_identifier,
    STATE(5712), 1,
      sym__simple_type,
    STATE(5797), 1,
      sym__annotated_type,
    STATE(6018), 1,
      sym_identifier,
    STATE(6257), 1,
      sym__soft_identifier,
    STATE(9026), 1,
      sym_annotated_type,
    STATE(10720), 1,
      sym_literal_type,
    STATE(10749), 1,
      sym__non_null_literal,
    STATE(12529), 1,
      sym__infix_type_choice,
    STATE(13406), 1,
      sym__type,
    STATE(13587), 1,
      sym_template_body,
    STATE(15029), 1,
      sym_parameter_types,
    STATE(17167), 1,
      sym_stable_identifier,
    ACTIONS(1596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1602), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3507), 2,
      sym_comment,
      sym_block_comment,
    STATE(9215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9231), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10356), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13594), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6678), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6819), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [143422] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14812), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3508), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [143543] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14820), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3509), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [143664] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6758), 1,
      anon_sym_LBRACK,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8856), 1,
      sym__annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(11890), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12424), 1,
      sym__infix_type_choice,
    STATE(15058), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3510), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [143785] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1066), 1,
      sym_integer_literal,
    ACTIONS(6520), 1,
      anon_sym_COLON,
    ACTIONS(6522), 1,
      anon_sym_LBRACE,
    ACTIONS(6760), 1,
      sym__alpha_identifier,
    ACTIONS(6762), 1,
      anon_sym__,
    ACTIONS(6764), 1,
      anon_sym_LBRACK,
    ACTIONS(6768), 1,
      anon_sym_LPAREN,
    ACTIONS(6770), 1,
      sym__backquoted_id,
    ACTIONS(6772), 1,
      sym_operator_identifier,
    STATE(4677), 1,
      sym__simple_type,
    STATE(4746), 1,
      sym__annotated_type,
    STATE(4900), 1,
      sym_identifier,
    STATE(4925), 1,
      sym__soft_identifier,
    STATE(6971), 1,
      sym_annotated_type,
    STATE(9748), 1,
      sym__non_null_literal,
    STATE(9991), 1,
      sym_literal_type,
    STATE(11868), 1,
      sym_template_body,
    STATE(11991), 1,
      sym__type,
    STATE(12483), 1,
      sym__infix_type_choice,
    STATE(15088), 1,
      sym_parameter_types,
    STATE(17018), 1,
      sym_stable_identifier,
    ACTIONS(1068), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1070), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1074), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3511), 2,
      sym_comment,
      sym_block_comment,
    STATE(6450), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6808), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9235), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6766), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5278), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [143906] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6758), 1,
      anon_sym_LBRACK,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8856), 1,
      sym__annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(11898), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12424), 1,
      sym__infix_type_choice,
    STATE(15058), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3512), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [144027] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6758), 1,
      anon_sym_LBRACK,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8856), 1,
      sym__annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(11899), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12424), 1,
      sym__infix_type_choice,
    STATE(15058), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3513), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [144148] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6758), 1,
      anon_sym_LBRACK,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8856), 1,
      sym__annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(11900), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12424), 1,
      sym__infix_type_choice,
    STATE(15058), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3514), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [144269] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14879), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3515), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [144390] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14886), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3516), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [144511] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(994), 1,
      sym_integer_literal,
    ACTIONS(6742), 1,
      anon_sym_COLON,
    ACTIONS(6744), 1,
      anon_sym_LBRACE,
    ACTIONS(6774), 1,
      sym__alpha_identifier,
    ACTIONS(6776), 1,
      anon_sym__,
    ACTIONS(6778), 1,
      anon_sym_LBRACK,
    ACTIONS(6782), 1,
      anon_sym_LPAREN,
    ACTIONS(6784), 1,
      sym__backquoted_id,
    ACTIONS(6786), 1,
      sym_operator_identifier,
    STATE(4495), 1,
      sym__simple_type,
    STATE(4525), 1,
      sym__annotated_type,
    STATE(4574), 1,
      sym_identifier,
    STATE(4626), 1,
      sym__soft_identifier,
    STATE(6388), 1,
      sym_annotated_type,
    STATE(9458), 1,
      sym__non_null_literal,
    STATE(9707), 1,
      sym_literal_type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12009), 1,
      sym__type,
    STATE(12546), 1,
      sym__infix_type_choice,
    STATE(15091), 1,
      sym_parameter_types,
    STATE(17251), 1,
      sym_stable_identifier,
    ACTIONS(996), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(998), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1002), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3517), 2,
      sym_comment,
      sym_block_comment,
    STATE(5571), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6247), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8341), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6780), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4851), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [144632] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4312), 1,
      sym__alpha_identifier,
    ACTIONS(4314), 1,
      anon_sym_COLON,
    ACTIONS(4316), 1,
      anon_sym_LBRACE,
    ACTIONS(4318), 1,
      anon_sym__,
    ACTIONS(4322), 1,
      anon_sym_LBRACK,
    ACTIONS(4330), 1,
      sym__backquoted_id,
    ACTIONS(4334), 1,
      sym_integer_literal,
    ACTIONS(6788), 1,
      anon_sym_LPAREN,
    ACTIONS(6790), 1,
      sym_operator_identifier,
    STATE(5091), 1,
      sym__annotated_type,
    STATE(5344), 1,
      sym__simple_type,
    STATE(5532), 1,
      sym__soft_identifier,
    STATE(5857), 1,
      sym_identifier,
    STATE(8214), 1,
      sym_annotated_type,
    STATE(10543), 1,
      sym_literal_type,
    STATE(10644), 1,
      sym__non_null_literal,
    STATE(12533), 1,
      sym__infix_type_choice,
    STATE(13547), 1,
      sym__type,
    STATE(13617), 1,
      sym_template_body,
    STATE(15133), 1,
      sym_parameter_types,
    STATE(17179), 1,
      sym_stable_identifier,
    ACTIONS(4336), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4338), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4342), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3518), 2,
      sym_comment,
      sym_block_comment,
    STATE(9951), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10503), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13609), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13417), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4324), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6288), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [144753] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4312), 1,
      sym__alpha_identifier,
    ACTIONS(4314), 1,
      anon_sym_COLON,
    ACTIONS(4316), 1,
      anon_sym_LBRACE,
    ACTIONS(4318), 1,
      anon_sym__,
    ACTIONS(4322), 1,
      anon_sym_LBRACK,
    ACTIONS(4330), 1,
      sym__backquoted_id,
    ACTIONS(4334), 1,
      sym_integer_literal,
    ACTIONS(6788), 1,
      anon_sym_LPAREN,
    ACTIONS(6790), 1,
      sym_operator_identifier,
    STATE(5091), 1,
      sym__annotated_type,
    STATE(5344), 1,
      sym__simple_type,
    STATE(5532), 1,
      sym__soft_identifier,
    STATE(5857), 1,
      sym_identifier,
    STATE(8214), 1,
      sym_annotated_type,
    STATE(10543), 1,
      sym_literal_type,
    STATE(10644), 1,
      sym__non_null_literal,
    STATE(12533), 1,
      sym__infix_type_choice,
    STATE(13550), 1,
      sym__type,
    STATE(13617), 1,
      sym_template_body,
    STATE(15133), 1,
      sym_parameter_types,
    STATE(17179), 1,
      sym_stable_identifier,
    ACTIONS(4336), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4338), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4342), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3519), 2,
      sym_comment,
      sym_block_comment,
    STATE(9951), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10503), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13609), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13417), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4324), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6288), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [144874] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15347), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3520), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [144995] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14960), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3521), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [145116] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6218), 1,
      anon_sym_LBRACK,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(11298), 1,
      sym__type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(15570), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3522), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [145237] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14972), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3523), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [145358] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4312), 1,
      sym__alpha_identifier,
    ACTIONS(4314), 1,
      anon_sym_COLON,
    ACTIONS(4316), 1,
      anon_sym_LBRACE,
    ACTIONS(4318), 1,
      anon_sym__,
    ACTIONS(4322), 1,
      anon_sym_LBRACK,
    ACTIONS(4330), 1,
      sym__backquoted_id,
    ACTIONS(4334), 1,
      sym_integer_literal,
    ACTIONS(6788), 1,
      anon_sym_LPAREN,
    ACTIONS(6790), 1,
      sym_operator_identifier,
    STATE(5091), 1,
      sym__annotated_type,
    STATE(5344), 1,
      sym__simple_type,
    STATE(5532), 1,
      sym__soft_identifier,
    STATE(5857), 1,
      sym_identifier,
    STATE(8214), 1,
      sym_annotated_type,
    STATE(10543), 1,
      sym_literal_type,
    STATE(10644), 1,
      sym__non_null_literal,
    STATE(12533), 1,
      sym__infix_type_choice,
    STATE(13551), 1,
      sym__type,
    STATE(13617), 1,
      sym_template_body,
    STATE(15133), 1,
      sym_parameter_types,
    STATE(17179), 1,
      sym_stable_identifier,
    ACTIONS(4336), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4338), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4342), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3524), 2,
      sym_comment,
      sym_block_comment,
    STATE(9951), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10503), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13609), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13417), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4324), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6288), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [145479] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4312), 1,
      sym__alpha_identifier,
    ACTIONS(4314), 1,
      anon_sym_COLON,
    ACTIONS(4316), 1,
      anon_sym_LBRACE,
    ACTIONS(4318), 1,
      anon_sym__,
    ACTIONS(4322), 1,
      anon_sym_LBRACK,
    ACTIONS(4330), 1,
      sym__backquoted_id,
    ACTIONS(4334), 1,
      sym_integer_literal,
    ACTIONS(6788), 1,
      anon_sym_LPAREN,
    ACTIONS(6790), 1,
      sym_operator_identifier,
    STATE(5091), 1,
      sym__annotated_type,
    STATE(5344), 1,
      sym__simple_type,
    STATE(5532), 1,
      sym__soft_identifier,
    STATE(5857), 1,
      sym_identifier,
    STATE(8214), 1,
      sym_annotated_type,
    STATE(10543), 1,
      sym_literal_type,
    STATE(10644), 1,
      sym__non_null_literal,
    STATE(12533), 1,
      sym__infix_type_choice,
    STATE(13552), 1,
      sym__type,
    STATE(13617), 1,
      sym_template_body,
    STATE(15133), 1,
      sym_parameter_types,
    STATE(17179), 1,
      sym_stable_identifier,
    ACTIONS(4336), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4338), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4342), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3525), 2,
      sym_comment,
      sym_block_comment,
    STATE(9951), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10503), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13609), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13417), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4324), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6288), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [145600] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4664), 1,
      sym__alpha_identifier,
    ACTIONS(4666), 1,
      anon_sym_COLON,
    ACTIONS(4668), 1,
      anon_sym_LBRACE,
    ACTIONS(4670), 1,
      anon_sym__,
    ACTIONS(4674), 1,
      anon_sym_LBRACK,
    ACTIONS(4682), 1,
      sym__backquoted_id,
    ACTIONS(4686), 1,
      sym_integer_literal,
    ACTIONS(6542), 1,
      anon_sym_LPAREN,
    ACTIONS(6544), 1,
      sym_operator_identifier,
    STATE(4972), 1,
      sym__annotated_type,
    STATE(5002), 1,
      sym__simple_type,
    STATE(5067), 1,
      sym_identifier,
    STATE(5176), 1,
      sym__soft_identifier,
    STATE(7967), 1,
      sym_annotated_type,
    STATE(10369), 1,
      sym_literal_type,
    STATE(10429), 1,
      sym__non_null_literal,
    STATE(12460), 1,
      sym__infix_type_choice,
    STATE(13050), 1,
      sym__type,
    STATE(13199), 1,
      sym_template_body,
    STATE(15231), 1,
      sym_parameter_types,
    STATE(16905), 1,
      sym_stable_identifier,
    ACTIONS(4688), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4690), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4694), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3526), 2,
      sym_comment,
      sym_block_comment,
    STATE(9523), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10326), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13289), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13116), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4676), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5890), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [145721] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4664), 1,
      sym__alpha_identifier,
    ACTIONS(4666), 1,
      anon_sym_COLON,
    ACTIONS(4668), 1,
      anon_sym_LBRACE,
    ACTIONS(4670), 1,
      anon_sym__,
    ACTIONS(4674), 1,
      anon_sym_LBRACK,
    ACTIONS(4682), 1,
      sym__backquoted_id,
    ACTIONS(4686), 1,
      sym_integer_literal,
    ACTIONS(6542), 1,
      anon_sym_LPAREN,
    ACTIONS(6544), 1,
      sym_operator_identifier,
    STATE(4972), 1,
      sym__annotated_type,
    STATE(5002), 1,
      sym__simple_type,
    STATE(5067), 1,
      sym_identifier,
    STATE(5176), 1,
      sym__soft_identifier,
    STATE(7967), 1,
      sym_annotated_type,
    STATE(10369), 1,
      sym_literal_type,
    STATE(10429), 1,
      sym__non_null_literal,
    STATE(12460), 1,
      sym__infix_type_choice,
    STATE(13052), 1,
      sym__type,
    STATE(13199), 1,
      sym_template_body,
    STATE(15231), 1,
      sym_parameter_types,
    STATE(16905), 1,
      sym_stable_identifier,
    ACTIONS(4688), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4690), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4694), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3527), 2,
      sym_comment,
      sym_block_comment,
    STATE(9523), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10326), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13289), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13116), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4676), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5890), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [145842] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14995), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3528), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [145963] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6172), 1,
      anon_sym_LBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12386), 1,
      sym__infix_type_choice,
    STATE(13708), 1,
      sym__type,
    STATE(15018), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3529), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [146084] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15003), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3530), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [146205] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6182), 1,
      anon_sym_LBRACK,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(7246), 1,
      sym__annotated_type,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12466), 1,
      sym__infix_type_choice,
    STATE(12686), 1,
      sym__type,
    STATE(15109), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3531), 2,
      sym_comment,
      sym_block_comment,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [146326] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6218), 1,
      anon_sym_LBRACK,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(12710), 1,
      sym__type,
    STATE(15570), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3532), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [146447] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15039), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3533), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [146568] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15041), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3534), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [146689] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4312), 1,
      sym__alpha_identifier,
    ACTIONS(4314), 1,
      anon_sym_COLON,
    ACTIONS(4316), 1,
      anon_sym_LBRACE,
    ACTIONS(4318), 1,
      anon_sym__,
    ACTIONS(4322), 1,
      anon_sym_LBRACK,
    ACTIONS(4330), 1,
      sym__backquoted_id,
    ACTIONS(4334), 1,
      sym_integer_literal,
    ACTIONS(6788), 1,
      anon_sym_LPAREN,
    ACTIONS(6790), 1,
      sym_operator_identifier,
    STATE(5091), 1,
      sym__annotated_type,
    STATE(5344), 1,
      sym__simple_type,
    STATE(5532), 1,
      sym__soft_identifier,
    STATE(5857), 1,
      sym_identifier,
    STATE(8214), 1,
      sym_annotated_type,
    STATE(10543), 1,
      sym_literal_type,
    STATE(10644), 1,
      sym__non_null_literal,
    STATE(12533), 1,
      sym__infix_type_choice,
    STATE(13491), 1,
      sym__type,
    STATE(13617), 1,
      sym_template_body,
    STATE(15133), 1,
      sym_parameter_types,
    STATE(17179), 1,
      sym_stable_identifier,
    ACTIONS(4336), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4338), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4342), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3535), 2,
      sym_comment,
      sym_block_comment,
    STATE(9951), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10503), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13609), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13417), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4324), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6288), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [146810] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(6792), 1,
      sym__alpha_identifier,
    ACTIONS(6794), 1,
      anon_sym__,
    ACTIONS(6796), 1,
      anon_sym_LBRACK,
    ACTIONS(6800), 1,
      anon_sym_LPAREN,
    ACTIONS(6802), 1,
      sym__backquoted_id,
    ACTIONS(6804), 1,
      sym_operator_identifier,
    ACTIONS(6806), 1,
      sym_integer_literal,
    STATE(7421), 1,
      sym__simple_type,
    STATE(8149), 1,
      sym__soft_identifier,
    STATE(8152), 1,
      sym_identifier,
    STATE(8382), 1,
      sym__annotated_type,
    STATE(10572), 1,
      sym_annotated_type,
    STATE(11696), 1,
      sym__non_null_literal,
    STATE(11697), 1,
      sym_literal_type,
    STATE(11878), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12428), 1,
      sym__infix_type_choice,
    STATE(15085), 1,
      sym_parameter_types,
    STATE(16446), 1,
      sym_stable_identifier,
    ACTIONS(6808), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6812), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3536), 2,
      sym_comment,
      sym_block_comment,
    STATE(11046), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11463), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6798), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9214), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [146931] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1066), 1,
      sym_integer_literal,
    ACTIONS(6520), 1,
      anon_sym_COLON,
    ACTIONS(6522), 1,
      anon_sym_LBRACE,
    ACTIONS(6760), 1,
      sym__alpha_identifier,
    ACTIONS(6762), 1,
      anon_sym__,
    ACTIONS(6764), 1,
      anon_sym_LBRACK,
    ACTIONS(6768), 1,
      anon_sym_LPAREN,
    ACTIONS(6770), 1,
      sym__backquoted_id,
    ACTIONS(6772), 1,
      sym_operator_identifier,
    STATE(4677), 1,
      sym__simple_type,
    STATE(4746), 1,
      sym__annotated_type,
    STATE(4900), 1,
      sym_identifier,
    STATE(4925), 1,
      sym__soft_identifier,
    STATE(6971), 1,
      sym_annotated_type,
    STATE(9748), 1,
      sym__non_null_literal,
    STATE(9991), 1,
      sym_literal_type,
    STATE(11868), 1,
      sym_template_body,
    STATE(12007), 1,
      sym__type,
    STATE(12483), 1,
      sym__infix_type_choice,
    STATE(15088), 1,
      sym_parameter_types,
    STATE(17018), 1,
      sym_stable_identifier,
    ACTIONS(1068), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1070), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1074), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3537), 2,
      sym_comment,
      sym_block_comment,
    STATE(6450), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6808), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9235), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6766), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5278), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [147052] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15077), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3538), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [147173] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15093), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3539), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [147294] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1066), 1,
      sym_integer_literal,
    ACTIONS(6520), 1,
      anon_sym_COLON,
    ACTIONS(6522), 1,
      anon_sym_LBRACE,
    ACTIONS(6760), 1,
      sym__alpha_identifier,
    ACTIONS(6762), 1,
      anon_sym__,
    ACTIONS(6764), 1,
      anon_sym_LBRACK,
    ACTIONS(6768), 1,
      anon_sym_LPAREN,
    ACTIONS(6770), 1,
      sym__backquoted_id,
    ACTIONS(6772), 1,
      sym_operator_identifier,
    STATE(4677), 1,
      sym__simple_type,
    STATE(4746), 1,
      sym__annotated_type,
    STATE(4900), 1,
      sym_identifier,
    STATE(4925), 1,
      sym__soft_identifier,
    STATE(6971), 1,
      sym_annotated_type,
    STATE(9748), 1,
      sym__non_null_literal,
    STATE(9991), 1,
      sym_literal_type,
    STATE(11868), 1,
      sym_template_body,
    STATE(12010), 1,
      sym__type,
    STATE(12483), 1,
      sym__infix_type_choice,
    STATE(15088), 1,
      sym_parameter_types,
    STATE(17018), 1,
      sym_stable_identifier,
    ACTIONS(1068), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1070), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1074), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3540), 2,
      sym_comment,
      sym_block_comment,
    STATE(6450), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6808), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9235), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6766), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5278), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [147415] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1066), 1,
      sym_integer_literal,
    ACTIONS(6520), 1,
      anon_sym_COLON,
    ACTIONS(6522), 1,
      anon_sym_LBRACE,
    ACTIONS(6760), 1,
      sym__alpha_identifier,
    ACTIONS(6762), 1,
      anon_sym__,
    ACTIONS(6764), 1,
      anon_sym_LBRACK,
    ACTIONS(6768), 1,
      anon_sym_LPAREN,
    ACTIONS(6770), 1,
      sym__backquoted_id,
    ACTIONS(6772), 1,
      sym_operator_identifier,
    STATE(4677), 1,
      sym__simple_type,
    STATE(4746), 1,
      sym__annotated_type,
    STATE(4900), 1,
      sym_identifier,
    STATE(4925), 1,
      sym__soft_identifier,
    STATE(6971), 1,
      sym_annotated_type,
    STATE(9748), 1,
      sym__non_null_literal,
    STATE(9991), 1,
      sym_literal_type,
    STATE(11868), 1,
      sym_template_body,
    STATE(12013), 1,
      sym__type,
    STATE(12483), 1,
      sym__infix_type_choice,
    STATE(15088), 1,
      sym_parameter_types,
    STATE(17018), 1,
      sym_stable_identifier,
    ACTIONS(1068), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1070), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1074), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3541), 2,
      sym_comment,
      sym_block_comment,
    STATE(6450), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6808), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9235), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6766), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5278), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [147536] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1066), 1,
      sym_integer_literal,
    ACTIONS(6520), 1,
      anon_sym_COLON,
    ACTIONS(6522), 1,
      anon_sym_LBRACE,
    ACTIONS(6760), 1,
      sym__alpha_identifier,
    ACTIONS(6762), 1,
      anon_sym__,
    ACTIONS(6764), 1,
      anon_sym_LBRACK,
    ACTIONS(6768), 1,
      anon_sym_LPAREN,
    ACTIONS(6770), 1,
      sym__backquoted_id,
    ACTIONS(6772), 1,
      sym_operator_identifier,
    STATE(4677), 1,
      sym__simple_type,
    STATE(4746), 1,
      sym__annotated_type,
    STATE(4900), 1,
      sym_identifier,
    STATE(4925), 1,
      sym__soft_identifier,
    STATE(6971), 1,
      sym_annotated_type,
    STATE(9748), 1,
      sym__non_null_literal,
    STATE(9991), 1,
      sym_literal_type,
    STATE(11868), 1,
      sym_template_body,
    STATE(12014), 1,
      sym__type,
    STATE(12483), 1,
      sym__infix_type_choice,
    STATE(15088), 1,
      sym_parameter_types,
    STATE(17018), 1,
      sym_stable_identifier,
    ACTIONS(1068), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1070), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1074), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3542), 2,
      sym_comment,
      sym_block_comment,
    STATE(6450), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6808), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9235), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6766), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5278), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [147657] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15106), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3543), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [147778] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15114), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3544), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [147899] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4344), 1,
      sym__alpha_identifier,
    ACTIONS(4346), 1,
      anon_sym_COLON,
    ACTIONS(4348), 1,
      anon_sym_LBRACE,
    ACTIONS(4350), 1,
      anon_sym__,
    ACTIONS(4354), 1,
      anon_sym_LBRACK,
    ACTIONS(4362), 1,
      sym__backquoted_id,
    ACTIONS(4366), 1,
      sym_integer_literal,
    ACTIONS(6814), 1,
      anon_sym_LPAREN,
    ACTIONS(6816), 1,
      sym_operator_identifier,
    STATE(5613), 1,
      sym__annotated_type,
    STATE(5792), 1,
      sym__simple_type,
    STATE(6290), 1,
      sym__soft_identifier,
    STATE(6431), 1,
      sym_identifier,
    STATE(9068), 1,
      sym_annotated_type,
    STATE(10738), 1,
      sym_literal_type,
    STATE(10922), 1,
      sym__non_null_literal,
    STATE(11489), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12535), 1,
      sym__infix_type_choice,
    STATE(15178), 1,
      sym_parameter_types,
    STATE(17185), 1,
      sym_stable_identifier,
    ACTIONS(4368), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4370), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4374), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3545), 2,
      sym_comment,
      sym_block_comment,
    STATE(10202), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10795), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11677), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4356), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6857), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [148020] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4344), 1,
      sym__alpha_identifier,
    ACTIONS(4346), 1,
      anon_sym_COLON,
    ACTIONS(4348), 1,
      anon_sym_LBRACE,
    ACTIONS(4350), 1,
      anon_sym__,
    ACTIONS(4354), 1,
      anon_sym_LBRACK,
    ACTIONS(4362), 1,
      sym__backquoted_id,
    ACTIONS(4366), 1,
      sym_integer_literal,
    ACTIONS(6814), 1,
      anon_sym_LPAREN,
    ACTIONS(6816), 1,
      sym_operator_identifier,
    STATE(5613), 1,
      sym__annotated_type,
    STATE(5792), 1,
      sym__simple_type,
    STATE(6290), 1,
      sym__soft_identifier,
    STATE(6431), 1,
      sym_identifier,
    STATE(9068), 1,
      sym_annotated_type,
    STATE(10738), 1,
      sym_literal_type,
    STATE(10922), 1,
      sym__non_null_literal,
    STATE(11491), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12535), 1,
      sym__infix_type_choice,
    STATE(15178), 1,
      sym_parameter_types,
    STATE(17185), 1,
      sym_stable_identifier,
    ACTIONS(4368), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4370), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4374), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3546), 2,
      sym_comment,
      sym_block_comment,
    STATE(10202), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10795), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11677), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4356), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6857), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [148141] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4344), 1,
      sym__alpha_identifier,
    ACTIONS(4346), 1,
      anon_sym_COLON,
    ACTIONS(4348), 1,
      anon_sym_LBRACE,
    ACTIONS(4350), 1,
      anon_sym__,
    ACTIONS(4354), 1,
      anon_sym_LBRACK,
    ACTIONS(4362), 1,
      sym__backquoted_id,
    ACTIONS(4366), 1,
      sym_integer_literal,
    ACTIONS(6814), 1,
      anon_sym_LPAREN,
    ACTIONS(6816), 1,
      sym_operator_identifier,
    STATE(5613), 1,
      sym__annotated_type,
    STATE(5792), 1,
      sym__simple_type,
    STATE(6290), 1,
      sym__soft_identifier,
    STATE(6431), 1,
      sym_identifier,
    STATE(9068), 1,
      sym_annotated_type,
    STATE(10738), 1,
      sym_literal_type,
    STATE(10922), 1,
      sym__non_null_literal,
    STATE(11492), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12535), 1,
      sym__infix_type_choice,
    STATE(15178), 1,
      sym_parameter_types,
    STATE(17185), 1,
      sym_stable_identifier,
    ACTIONS(4368), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4370), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4374), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3547), 2,
      sym_comment,
      sym_block_comment,
    STATE(10202), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10795), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11677), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4356), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6857), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [148262] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(6792), 1,
      sym__alpha_identifier,
    ACTIONS(6794), 1,
      anon_sym__,
    ACTIONS(6796), 1,
      anon_sym_LBRACK,
    ACTIONS(6800), 1,
      anon_sym_LPAREN,
    ACTIONS(6802), 1,
      sym__backquoted_id,
    ACTIONS(6804), 1,
      sym_operator_identifier,
    ACTIONS(6806), 1,
      sym_integer_literal,
    STATE(7421), 1,
      sym__simple_type,
    STATE(8149), 1,
      sym__soft_identifier,
    STATE(8152), 1,
      sym_identifier,
    STATE(8382), 1,
      sym__annotated_type,
    STATE(10572), 1,
      sym_annotated_type,
    STATE(11696), 1,
      sym__non_null_literal,
    STATE(11697), 1,
      sym_literal_type,
    STATE(11890), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12428), 1,
      sym__infix_type_choice,
    STATE(15085), 1,
      sym_parameter_types,
    STATE(16446), 1,
      sym_stable_identifier,
    ACTIONS(6808), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6812), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3548), 2,
      sym_comment,
      sym_block_comment,
    STATE(11046), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11463), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6798), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9214), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [148383] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15145), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3549), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [148504] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15152), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3550), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [148625] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(6792), 1,
      sym__alpha_identifier,
    ACTIONS(6794), 1,
      anon_sym__,
    ACTIONS(6796), 1,
      anon_sym_LBRACK,
    ACTIONS(6800), 1,
      anon_sym_LPAREN,
    ACTIONS(6802), 1,
      sym__backquoted_id,
    ACTIONS(6804), 1,
      sym_operator_identifier,
    ACTIONS(6806), 1,
      sym_integer_literal,
    STATE(7421), 1,
      sym__simple_type,
    STATE(8149), 1,
      sym__soft_identifier,
    STATE(8152), 1,
      sym_identifier,
    STATE(8382), 1,
      sym__annotated_type,
    STATE(10572), 1,
      sym_annotated_type,
    STATE(11696), 1,
      sym__non_null_literal,
    STATE(11697), 1,
      sym_literal_type,
    STATE(11898), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12428), 1,
      sym__infix_type_choice,
    STATE(15085), 1,
      sym_parameter_types,
    STATE(16446), 1,
      sym_stable_identifier,
    ACTIONS(6808), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6812), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3551), 2,
      sym_comment,
      sym_block_comment,
    STATE(11046), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11463), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6798), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9214), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [148746] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(6792), 1,
      sym__alpha_identifier,
    ACTIONS(6794), 1,
      anon_sym__,
    ACTIONS(6796), 1,
      anon_sym_LBRACK,
    ACTIONS(6800), 1,
      anon_sym_LPAREN,
    ACTIONS(6802), 1,
      sym__backquoted_id,
    ACTIONS(6804), 1,
      sym_operator_identifier,
    ACTIONS(6806), 1,
      sym_integer_literal,
    STATE(7421), 1,
      sym__simple_type,
    STATE(8149), 1,
      sym__soft_identifier,
    STATE(8152), 1,
      sym_identifier,
    STATE(8382), 1,
      sym__annotated_type,
    STATE(10572), 1,
      sym_annotated_type,
    STATE(11696), 1,
      sym__non_null_literal,
    STATE(11697), 1,
      sym_literal_type,
    STATE(11899), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12428), 1,
      sym__infix_type_choice,
    STATE(15085), 1,
      sym_parameter_types,
    STATE(16446), 1,
      sym_stable_identifier,
    ACTIONS(6808), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6812), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3552), 2,
      sym_comment,
      sym_block_comment,
    STATE(11046), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11463), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6798), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9214), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [148867] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(6792), 1,
      sym__alpha_identifier,
    ACTIONS(6794), 1,
      anon_sym__,
    ACTIONS(6796), 1,
      anon_sym_LBRACK,
    ACTIONS(6800), 1,
      anon_sym_LPAREN,
    ACTIONS(6802), 1,
      sym__backquoted_id,
    ACTIONS(6804), 1,
      sym_operator_identifier,
    ACTIONS(6806), 1,
      sym_integer_literal,
    STATE(7421), 1,
      sym__simple_type,
    STATE(8149), 1,
      sym__soft_identifier,
    STATE(8152), 1,
      sym_identifier,
    STATE(8382), 1,
      sym__annotated_type,
    STATE(10572), 1,
      sym_annotated_type,
    STATE(11696), 1,
      sym__non_null_literal,
    STATE(11697), 1,
      sym_literal_type,
    STATE(11900), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12428), 1,
      sym__infix_type_choice,
    STATE(15085), 1,
      sym_parameter_types,
    STATE(16446), 1,
      sym_stable_identifier,
    ACTIONS(6808), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6812), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3553), 2,
      sym_comment,
      sym_block_comment,
    STATE(11046), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11463), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6798), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9214), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [148988] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15173), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3554), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [149109] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15177), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3555), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [149230] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6134), 1,
      anon_sym_COLON,
    ACTIONS(6136), 1,
      anon_sym_LBRACE,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6140), 1,
      anon_sym_LBRACK,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6150), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(8699), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(11171), 1,
      sym__non_null_literal,
    STATE(11172), 1,
      sym_literal_type,
    STATE(11576), 1,
      sym_template_body,
    STATE(11600), 1,
      sym__type,
    STATE(12342), 1,
      sym__infix_type_choice,
    STATE(15615), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3556), 2,
      sym_comment,
      sym_block_comment,
    STATE(11119), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11526), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11592), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [149351] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1304), 1,
      sym_integer_literal,
    ACTIONS(6114), 1,
      sym__alpha_identifier,
    ACTIONS(6116), 1,
      anon_sym_COLON,
    ACTIONS(6118), 1,
      anon_sym_LBRACE,
    ACTIONS(6120), 1,
      anon_sym__,
    ACTIONS(6122), 1,
      anon_sym_LBRACK,
    ACTIONS(6126), 1,
      anon_sym_LPAREN,
    ACTIONS(6128), 1,
      sym__backquoted_id,
    ACTIONS(6130), 1,
      sym_operator_identifier,
    STATE(4976), 1,
      sym__annotated_type,
    STATE(5030), 1,
      sym__simple_type,
    STATE(5135), 1,
      sym_identifier,
    STATE(5193), 1,
      sym__soft_identifier,
    STATE(7769), 1,
      sym_annotated_type,
    STATE(10265), 1,
      sym_literal_type,
    STATE(10325), 1,
      sym__non_null_literal,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(12873), 1,
      sym_template_body,
    STATE(13100), 1,
      sym__type,
    STATE(15033), 1,
      sym_parameter_types,
    STATE(17257), 1,
      sym_stable_identifier,
    ACTIONS(1306), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1308), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1312), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3557), 2,
      sym_comment,
      sym_block_comment,
    STATE(7638), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7829), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9590), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12811), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6124), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5886), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [149472] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15201), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3558), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [149593] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15209), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3559), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [149714] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      sym_integer_literal,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6564), 1,
      anon_sym_LBRACK,
    ACTIONS(6568), 1,
      anon_sym_LPAREN,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    STATE(4628), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(9642), 1,
      sym__non_null_literal,
    STATE(9643), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(12398), 1,
      sym__infix_type_choice,
    STATE(14263), 1,
      sym__type,
    STATE(15084), 1,
      sym_parameter_types,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(163), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(165), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(175), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3560), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7802), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8503), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [149835] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4344), 1,
      sym__alpha_identifier,
    ACTIONS(4346), 1,
      anon_sym_COLON,
    ACTIONS(4348), 1,
      anon_sym_LBRACE,
    ACTIONS(4350), 1,
      anon_sym__,
    ACTIONS(4354), 1,
      anon_sym_LBRACK,
    ACTIONS(4362), 1,
      sym__backquoted_id,
    ACTIONS(4366), 1,
      sym_integer_literal,
    ACTIONS(6814), 1,
      anon_sym_LPAREN,
    ACTIONS(6816), 1,
      sym_operator_identifier,
    STATE(5613), 1,
      sym__annotated_type,
    STATE(5792), 1,
      sym__simple_type,
    STATE(6290), 1,
      sym__soft_identifier,
    STATE(6431), 1,
      sym_identifier,
    STATE(9068), 1,
      sym_annotated_type,
    STATE(10738), 1,
      sym_literal_type,
    STATE(10922), 1,
      sym__non_null_literal,
    STATE(11493), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12535), 1,
      sym__infix_type_choice,
    STATE(15178), 1,
      sym_parameter_types,
    STATE(17185), 1,
      sym_stable_identifier,
    ACTIONS(4368), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4370), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4374), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3561), 2,
      sym_comment,
      sym_block_comment,
    STATE(10202), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10795), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11677), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4356), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6857), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [149956] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6218), 1,
      anon_sym_LBRACK,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(11302), 1,
      sym__type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(15570), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3562), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [150077] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15238), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3563), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [150198] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15242), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3564), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [150319] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6218), 1,
      anon_sym_LBRACK,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(11303), 1,
      sym__type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(15570), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3565), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [150440] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6218), 1,
      anon_sym_LBRACK,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(11304), 1,
      sym__type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(15570), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3566), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [150561] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15259), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3567), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [150682] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15262), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3568), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [150803] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15284), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3569), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [150924] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15288), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3570), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [151045] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15310), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3571), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [151166] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15315), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3572), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [151287] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6304), 1,
      anon_sym_LBRACK,
    ACTIONS(6308), 1,
      anon_sym_LPAREN,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    ACTIONS(6314), 1,
      sym_integer_literal,
    STATE(6970), 1,
      sym__simple_type,
    STATE(7534), 1,
      sym__annotated_type,
    STATE(7680), 1,
      sym__soft_identifier,
    STATE(7825), 1,
      sym_identifier,
    STATE(10180), 1,
      sym_annotated_type,
    STATE(11189), 1,
      sym__non_null_literal,
    STATE(11190), 1,
      sym_literal_type,
    STATE(11878), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12429), 1,
      sym__infix_type_choice,
    STATE(15108), 1,
      sym_parameter_types,
    STATE(16467), 1,
      sym_stable_identifier,
    ACTIONS(6316), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6318), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6320), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3573), 2,
      sym_comment,
      sym_block_comment,
    STATE(10836), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11153), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8431), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [151408] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15343), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3574), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [151529] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15348), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3575), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [151650] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4344), 1,
      sym__alpha_identifier,
    ACTIONS(4346), 1,
      anon_sym_COLON,
    ACTIONS(4348), 1,
      anon_sym_LBRACE,
    ACTIONS(4350), 1,
      anon_sym__,
    ACTIONS(4354), 1,
      anon_sym_LBRACK,
    ACTIONS(4362), 1,
      sym__backquoted_id,
    ACTIONS(4366), 1,
      sym_integer_literal,
    ACTIONS(6814), 1,
      anon_sym_LPAREN,
    ACTIONS(6816), 1,
      sym_operator_identifier,
    STATE(5613), 1,
      sym__annotated_type,
    STATE(5792), 1,
      sym__simple_type,
    STATE(6290), 1,
      sym__soft_identifier,
    STATE(6431), 1,
      sym_identifier,
    STATE(9068), 1,
      sym_annotated_type,
    STATE(10738), 1,
      sym_literal_type,
    STATE(10922), 1,
      sym__non_null_literal,
    STATE(11505), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12535), 1,
      sym__infix_type_choice,
    STATE(15178), 1,
      sym_parameter_types,
    STATE(17185), 1,
      sym_stable_identifier,
    ACTIONS(4368), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4370), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4374), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3576), 2,
      sym_comment,
      sym_block_comment,
    STATE(10202), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10795), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11677), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4356), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6857), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [151771] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15367), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3577), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [151892] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15372), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3578), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [152013] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6182), 1,
      anon_sym_LBRACK,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(7246), 1,
      sym__annotated_type,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12466), 1,
      sym__infix_type_choice,
    STATE(12694), 1,
      sym__type,
    STATE(15109), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3579), 2,
      sym_comment,
      sym_block_comment,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [152134] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6304), 1,
      anon_sym_LBRACK,
    ACTIONS(6308), 1,
      anon_sym_LPAREN,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    ACTIONS(6314), 1,
      sym_integer_literal,
    STATE(6970), 1,
      sym__simple_type,
    STATE(7534), 1,
      sym__annotated_type,
    STATE(7680), 1,
      sym__soft_identifier,
    STATE(7825), 1,
      sym_identifier,
    STATE(10180), 1,
      sym_annotated_type,
    STATE(11189), 1,
      sym__non_null_literal,
    STATE(11190), 1,
      sym_literal_type,
    STATE(11890), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12429), 1,
      sym__infix_type_choice,
    STATE(15108), 1,
      sym_parameter_types,
    STATE(16467), 1,
      sym_stable_identifier,
    ACTIONS(6316), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6318), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6320), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3580), 2,
      sym_comment,
      sym_block_comment,
    STATE(10836), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11153), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8431), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [152255] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6304), 1,
      anon_sym_LBRACK,
    ACTIONS(6308), 1,
      anon_sym_LPAREN,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    ACTIONS(6314), 1,
      sym_integer_literal,
    STATE(6970), 1,
      sym__simple_type,
    STATE(7534), 1,
      sym__annotated_type,
    STATE(7680), 1,
      sym__soft_identifier,
    STATE(7825), 1,
      sym_identifier,
    STATE(10180), 1,
      sym_annotated_type,
    STATE(11189), 1,
      sym__non_null_literal,
    STATE(11190), 1,
      sym_literal_type,
    STATE(11898), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12429), 1,
      sym__infix_type_choice,
    STATE(15108), 1,
      sym_parameter_types,
    STATE(16467), 1,
      sym_stable_identifier,
    ACTIONS(6316), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6318), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6320), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3581), 2,
      sym_comment,
      sym_block_comment,
    STATE(10836), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11153), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8431), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [152376] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15397), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3582), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [152497] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15400), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3583), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [152618] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6304), 1,
      anon_sym_LBRACK,
    ACTIONS(6308), 1,
      anon_sym_LPAREN,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    ACTIONS(6314), 1,
      sym_integer_literal,
    STATE(6970), 1,
      sym__simple_type,
    STATE(7534), 1,
      sym__annotated_type,
    STATE(7680), 1,
      sym__soft_identifier,
    STATE(7825), 1,
      sym_identifier,
    STATE(10180), 1,
      sym_annotated_type,
    STATE(11189), 1,
      sym__non_null_literal,
    STATE(11190), 1,
      sym_literal_type,
    STATE(11899), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12429), 1,
      sym__infix_type_choice,
    STATE(15108), 1,
      sym_parameter_types,
    STATE(16467), 1,
      sym_stable_identifier,
    ACTIONS(6316), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6318), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6320), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3584), 2,
      sym_comment,
      sym_block_comment,
    STATE(10836), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11153), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8431), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [152739] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6304), 1,
      anon_sym_LBRACK,
    ACTIONS(6308), 1,
      anon_sym_LPAREN,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    ACTIONS(6314), 1,
      sym_integer_literal,
    STATE(6970), 1,
      sym__simple_type,
    STATE(7534), 1,
      sym__annotated_type,
    STATE(7680), 1,
      sym__soft_identifier,
    STATE(7825), 1,
      sym_identifier,
    STATE(10180), 1,
      sym_annotated_type,
    STATE(11189), 1,
      sym__non_null_literal,
    STATE(11190), 1,
      sym_literal_type,
    STATE(11900), 1,
      sym__type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12429), 1,
      sym__infix_type_choice,
    STATE(15108), 1,
      sym_parameter_types,
    STATE(16467), 1,
      sym_stable_identifier,
    ACTIONS(6316), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6318), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6320), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3585), 2,
      sym_comment,
      sym_block_comment,
    STATE(10836), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11153), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8431), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [152860] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15410), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3586), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [152981] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15411), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3587), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [153102] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1360), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(5087), 1,
      sym__simple_type,
    STATE(5218), 1,
      sym__annotated_type,
    STATE(5538), 1,
      sym__soft_identifier,
    STATE(5956), 1,
      sym_identifier,
    STATE(8528), 1,
      sym_annotated_type,
    STATE(10533), 1,
      sym_literal_type,
    STATE(10609), 1,
      sym__non_null_literal,
    STATE(12550), 1,
      sym__infix_type_choice,
    STATE(13150), 1,
      sym_template_body,
    STATE(13504), 1,
      sym__type,
    STATE(15034), 1,
      sym_parameter_types,
    STATE(17275), 1,
      sym_stable_identifier,
    ACTIONS(1362), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1364), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1368), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3588), 2,
      sym_comment,
      sym_block_comment,
    STATE(8206), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8220), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9979), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13262), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6616), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [153223] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4346), 1,
      anon_sym_COLON,
    ACTIONS(4348), 1,
      anon_sym_LBRACE,
    ACTIONS(4408), 1,
      sym__alpha_identifier,
    ACTIONS(4410), 1,
      anon_sym__,
    ACTIONS(4414), 1,
      anon_sym_LBRACK,
    ACTIONS(4420), 1,
      sym__backquoted_id,
    ACTIONS(4424), 1,
      sym_integer_literal,
    ACTIONS(6818), 1,
      anon_sym_LPAREN,
    ACTIONS(6820), 1,
      sym_operator_identifier,
    STATE(4385), 1,
      sym__simple_type,
    STATE(4413), 1,
      sym__annotated_type,
    STATE(4469), 1,
      sym_identifier,
    STATE(4476), 1,
      sym__soft_identifier,
    STATE(5974), 1,
      sym_annotated_type,
    STATE(9225), 1,
      sym__non_null_literal,
    STATE(9317), 1,
      sym_literal_type,
    STATE(11489), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12537), 1,
      sym__infix_type_choice,
    STATE(15032), 1,
      sym_parameter_types,
    STATE(17191), 1,
      sym_stable_identifier,
    ACTIONS(4426), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4428), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4432), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3589), 2,
      sym_comment,
      sym_block_comment,
    STATE(7930), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8772), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11677), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4416), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4659), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [153344] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 9,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_DQUOTE,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [153413] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15422), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3591), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [153534] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15424), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3592), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [153655] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4346), 1,
      anon_sym_COLON,
    ACTIONS(4348), 1,
      anon_sym_LBRACE,
    ACTIONS(4408), 1,
      sym__alpha_identifier,
    ACTIONS(4410), 1,
      anon_sym__,
    ACTIONS(4414), 1,
      anon_sym_LBRACK,
    ACTIONS(4420), 1,
      sym__backquoted_id,
    ACTIONS(4424), 1,
      sym_integer_literal,
    ACTIONS(6818), 1,
      anon_sym_LPAREN,
    ACTIONS(6820), 1,
      sym_operator_identifier,
    STATE(4385), 1,
      sym__simple_type,
    STATE(4413), 1,
      sym__annotated_type,
    STATE(4469), 1,
      sym_identifier,
    STATE(4476), 1,
      sym__soft_identifier,
    STATE(5974), 1,
      sym_annotated_type,
    STATE(9225), 1,
      sym__non_null_literal,
    STATE(9317), 1,
      sym_literal_type,
    STATE(11491), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12537), 1,
      sym__infix_type_choice,
    STATE(15032), 1,
      sym_parameter_types,
    STATE(17191), 1,
      sym_stable_identifier,
    ACTIONS(4426), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4428), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4432), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3593), 2,
      sym_comment,
      sym_block_comment,
    STATE(7930), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8772), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11677), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4416), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4659), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [153776] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4346), 1,
      anon_sym_COLON,
    ACTIONS(4348), 1,
      anon_sym_LBRACE,
    ACTIONS(4408), 1,
      sym__alpha_identifier,
    ACTIONS(4410), 1,
      anon_sym__,
    ACTIONS(4414), 1,
      anon_sym_LBRACK,
    ACTIONS(4420), 1,
      sym__backquoted_id,
    ACTIONS(4424), 1,
      sym_integer_literal,
    ACTIONS(6818), 1,
      anon_sym_LPAREN,
    ACTIONS(6820), 1,
      sym_operator_identifier,
    STATE(4385), 1,
      sym__simple_type,
    STATE(4413), 1,
      sym__annotated_type,
    STATE(4469), 1,
      sym_identifier,
    STATE(4476), 1,
      sym__soft_identifier,
    STATE(5974), 1,
      sym_annotated_type,
    STATE(9225), 1,
      sym__non_null_literal,
    STATE(9317), 1,
      sym_literal_type,
    STATE(11492), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12537), 1,
      sym__infix_type_choice,
    STATE(15032), 1,
      sym_parameter_types,
    STATE(17191), 1,
      sym_stable_identifier,
    ACTIONS(4426), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4428), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4432), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3594), 2,
      sym_comment,
      sym_block_comment,
    STATE(7930), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8772), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11677), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4416), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4659), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [153897] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15435), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3595), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [154018] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15437), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3596), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [154139] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4346), 1,
      anon_sym_COLON,
    ACTIONS(4348), 1,
      anon_sym_LBRACE,
    ACTIONS(4408), 1,
      sym__alpha_identifier,
    ACTIONS(4410), 1,
      anon_sym__,
    ACTIONS(4414), 1,
      anon_sym_LBRACK,
    ACTIONS(4420), 1,
      sym__backquoted_id,
    ACTIONS(4424), 1,
      sym_integer_literal,
    ACTIONS(6818), 1,
      anon_sym_LPAREN,
    ACTIONS(6820), 1,
      sym_operator_identifier,
    STATE(4385), 1,
      sym__simple_type,
    STATE(4413), 1,
      sym__annotated_type,
    STATE(4469), 1,
      sym_identifier,
    STATE(4476), 1,
      sym__soft_identifier,
    STATE(5974), 1,
      sym_annotated_type,
    STATE(9225), 1,
      sym__non_null_literal,
    STATE(9317), 1,
      sym_literal_type,
    STATE(11493), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12537), 1,
      sym__infix_type_choice,
    STATE(15032), 1,
      sym_parameter_types,
    STATE(17191), 1,
      sym_stable_identifier,
    ACTIONS(4426), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4428), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4432), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3597), 2,
      sym_comment,
      sym_block_comment,
    STATE(7930), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8772), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11677), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4416), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4659), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [154260] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15446), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3598), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [154381] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15447), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3599), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [154502] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6182), 1,
      anon_sym_LBRACK,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(7246), 1,
      sym__annotated_type,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12466), 1,
      sym__infix_type_choice,
    STATE(12695), 1,
      sym__type,
    STATE(15109), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3600), 2,
      sym_comment,
      sym_block_comment,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [154623] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15461), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3601), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [154744] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15464), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3602), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [154865] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4376), 1,
      sym__alpha_identifier,
    ACTIONS(4378), 1,
      anon_sym_COLON,
    ACTIONS(4380), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      anon_sym__,
    ACTIONS(4386), 1,
      anon_sym_LBRACK,
    ACTIONS(4394), 1,
      sym__backquoted_id,
    ACTIONS(4398), 1,
      sym_integer_literal,
    ACTIONS(6822), 1,
      anon_sym_LPAREN,
    ACTIONS(6824), 1,
      sym_operator_identifier,
    STATE(4887), 1,
      sym__simple_type,
    STATE(4899), 1,
      sym__annotated_type,
    STATE(5049), 1,
      sym__soft_identifier,
    STATE(5197), 1,
      sym_identifier,
    STATE(7877), 1,
      sym_annotated_type,
    STATE(10234), 1,
      sym_literal_type,
    STATE(10289), 1,
      sym__non_null_literal,
    STATE(12639), 1,
      sym__infix_type_choice,
    STATE(13025), 1,
      sym__type,
    STATE(13167), 1,
      sym_template_body,
    STATE(15643), 1,
      sym_parameter_types,
    STATE(16509), 1,
      sym_stable_identifier,
    ACTIONS(4400), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4402), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4406), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3603), 2,
      sym_comment,
      sym_block_comment,
    STATE(9591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10144), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13130), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13189), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5943), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [154986] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15476), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3604), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [155107] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15480), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3605), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [155228] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4346), 1,
      anon_sym_COLON,
    ACTIONS(4348), 1,
      anon_sym_LBRACE,
    ACTIONS(4408), 1,
      sym__alpha_identifier,
    ACTIONS(4410), 1,
      anon_sym__,
    ACTIONS(4414), 1,
      anon_sym_LBRACK,
    ACTIONS(4420), 1,
      sym__backquoted_id,
    ACTIONS(4424), 1,
      sym_integer_literal,
    ACTIONS(6818), 1,
      anon_sym_LPAREN,
    ACTIONS(6820), 1,
      sym_operator_identifier,
    STATE(4385), 1,
      sym__simple_type,
    STATE(4413), 1,
      sym__annotated_type,
    STATE(4469), 1,
      sym_identifier,
    STATE(4476), 1,
      sym__soft_identifier,
    STATE(5974), 1,
      sym_annotated_type,
    STATE(9225), 1,
      sym__non_null_literal,
    STATE(9317), 1,
      sym_literal_type,
    STATE(11505), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12537), 1,
      sym__infix_type_choice,
    STATE(15032), 1,
      sym_parameter_types,
    STATE(17191), 1,
      sym_stable_identifier,
    ACTIONS(4426), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4428), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4432), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3606), 2,
      sym_comment,
      sym_block_comment,
    STATE(7930), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8772), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11677), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4416), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4659), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [155349] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4734), 1,
      anon_sym_COLON,
    ACTIONS(4736), 1,
      anon_sym_LBRACE,
    ACTIONS(4794), 1,
      sym__alpha_identifier,
    ACTIONS(4796), 1,
      anon_sym__,
    ACTIONS(4800), 1,
      anon_sym_LBRACK,
    ACTIONS(4806), 1,
      sym__backquoted_id,
    ACTIONS(4810), 1,
      sym_integer_literal,
    ACTIONS(6826), 1,
      anon_sym_LPAREN,
    ACTIONS(6828), 1,
      sym_operator_identifier,
    STATE(4477), 1,
      sym__simple_type,
    STATE(4561), 1,
      sym__annotated_type,
    STATE(4605), 1,
      sym__soft_identifier,
    STATE(4610), 1,
      sym_identifier,
    STATE(6171), 1,
      sym_annotated_type,
    STATE(9652), 1,
      sym__non_null_literal,
    STATE(9661), 1,
      sym_literal_type,
    STATE(11811), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12485), 1,
      sym__infix_type_choice,
    STATE(15026), 1,
      sym_parameter_types,
    STATE(17024), 1,
      sym_stable_identifier,
    ACTIONS(4812), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4814), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4816), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3607), 2,
      sym_comment,
      sym_block_comment,
    STATE(8488), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9443), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11907), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4802), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4813), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [155470] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6134), 1,
      anon_sym_COLON,
    ACTIONS(6136), 1,
      anon_sym_LBRACE,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6140), 1,
      anon_sym_LBRACK,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6150), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(8699), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(11171), 1,
      sym__non_null_literal,
    STATE(11172), 1,
      sym_literal_type,
    STATE(11576), 1,
      sym_template_body,
    STATE(11606), 1,
      sym__type,
    STATE(12342), 1,
      sym__infix_type_choice,
    STATE(15615), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3608), 2,
      sym_comment,
      sym_block_comment,
    STATE(11119), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11526), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11592), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [155591] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15495), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3609), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [155712] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15497), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3610), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [155833] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6134), 1,
      anon_sym_COLON,
    ACTIONS(6136), 1,
      anon_sym_LBRACE,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6140), 1,
      anon_sym_LBRACK,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6150), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(8699), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(11171), 1,
      sym__non_null_literal,
    STATE(11172), 1,
      sym_literal_type,
    STATE(11576), 1,
      sym_template_body,
    STATE(11608), 1,
      sym__type,
    STATE(12342), 1,
      sym__infix_type_choice,
    STATE(15615), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3611), 2,
      sym_comment,
      sym_block_comment,
    STATE(11119), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11526), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11592), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [155954] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6182), 1,
      anon_sym_LBRACK,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(7246), 1,
      sym__annotated_type,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12466), 1,
      sym__infix_type_choice,
    STATE(12696), 1,
      sym__type,
    STATE(15109), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3612), 2,
      sym_comment,
      sym_block_comment,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [156075] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4376), 1,
      sym__alpha_identifier,
    ACTIONS(4378), 1,
      anon_sym_COLON,
    ACTIONS(4380), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      anon_sym__,
    ACTIONS(4386), 1,
      anon_sym_LBRACK,
    ACTIONS(4394), 1,
      sym__backquoted_id,
    ACTIONS(4398), 1,
      sym_integer_literal,
    ACTIONS(6822), 1,
      anon_sym_LPAREN,
    ACTIONS(6824), 1,
      sym_operator_identifier,
    STATE(4887), 1,
      sym__simple_type,
    STATE(4899), 1,
      sym__annotated_type,
    STATE(5049), 1,
      sym__soft_identifier,
    STATE(5197), 1,
      sym_identifier,
    STATE(7877), 1,
      sym_annotated_type,
    STATE(10234), 1,
      sym_literal_type,
    STATE(10289), 1,
      sym__non_null_literal,
    STATE(12639), 1,
      sym__infix_type_choice,
    STATE(13167), 1,
      sym_template_body,
    STATE(13296), 1,
      sym__type,
    STATE(15643), 1,
      sym_parameter_types,
    STATE(16509), 1,
      sym_stable_identifier,
    ACTIONS(4400), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4402), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4406), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3613), 2,
      sym_comment,
      sym_block_comment,
    STATE(9591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10144), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13130), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13189), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5943), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [156196] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15514), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3614), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [156317] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15518), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3615), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [156438] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4376), 1,
      sym__alpha_identifier,
    ACTIONS(4378), 1,
      anon_sym_COLON,
    ACTIONS(4380), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      anon_sym__,
    ACTIONS(4386), 1,
      anon_sym_LBRACK,
    ACTIONS(4394), 1,
      sym__backquoted_id,
    ACTIONS(4398), 1,
      sym_integer_literal,
    ACTIONS(6822), 1,
      anon_sym_LPAREN,
    ACTIONS(6824), 1,
      sym_operator_identifier,
    STATE(4887), 1,
      sym__simple_type,
    STATE(4899), 1,
      sym__annotated_type,
    STATE(5049), 1,
      sym__soft_identifier,
    STATE(5197), 1,
      sym_identifier,
    STATE(7877), 1,
      sym_annotated_type,
    STATE(10234), 1,
      sym_literal_type,
    STATE(10289), 1,
      sym__non_null_literal,
    STATE(12639), 1,
      sym__infix_type_choice,
    STATE(13167), 1,
      sym_template_body,
    STATE(13300), 1,
      sym__type,
    STATE(15643), 1,
      sym_parameter_types,
    STATE(16509), 1,
      sym_stable_identifier,
    ACTIONS(4400), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4402), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4406), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3616), 2,
      sym_comment,
      sym_block_comment,
    STATE(9591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10144), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13130), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13189), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5943), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [156559] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4376), 1,
      sym__alpha_identifier,
    ACTIONS(4378), 1,
      anon_sym_COLON,
    ACTIONS(4380), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      anon_sym__,
    ACTIONS(4386), 1,
      anon_sym_LBRACK,
    ACTIONS(4394), 1,
      sym__backquoted_id,
    ACTIONS(4398), 1,
      sym_integer_literal,
    ACTIONS(6822), 1,
      anon_sym_LPAREN,
    ACTIONS(6824), 1,
      sym_operator_identifier,
    STATE(4887), 1,
      sym__simple_type,
    STATE(4899), 1,
      sym__annotated_type,
    STATE(5049), 1,
      sym__soft_identifier,
    STATE(5197), 1,
      sym_identifier,
    STATE(7877), 1,
      sym_annotated_type,
    STATE(10234), 1,
      sym_literal_type,
    STATE(10289), 1,
      sym__non_null_literal,
    STATE(12639), 1,
      sym__infix_type_choice,
    STATE(13167), 1,
      sym_template_body,
    STATE(13301), 1,
      sym__type,
    STATE(15643), 1,
      sym_parameter_types,
    STATE(16509), 1,
      sym_stable_identifier,
    ACTIONS(4400), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4402), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4406), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3617), 2,
      sym_comment,
      sym_block_comment,
    STATE(9591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10144), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13130), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13189), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5943), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [156680] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4376), 1,
      sym__alpha_identifier,
    ACTIONS(4378), 1,
      anon_sym_COLON,
    ACTIONS(4380), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      anon_sym__,
    ACTIONS(4386), 1,
      anon_sym_LBRACK,
    ACTIONS(4394), 1,
      sym__backquoted_id,
    ACTIONS(4398), 1,
      sym_integer_literal,
    ACTIONS(6822), 1,
      anon_sym_LPAREN,
    ACTIONS(6824), 1,
      sym_operator_identifier,
    STATE(4887), 1,
      sym__simple_type,
    STATE(4899), 1,
      sym__annotated_type,
    STATE(5049), 1,
      sym__soft_identifier,
    STATE(5197), 1,
      sym_identifier,
    STATE(7877), 1,
      sym_annotated_type,
    STATE(10234), 1,
      sym_literal_type,
    STATE(10289), 1,
      sym__non_null_literal,
    STATE(12639), 1,
      sym__infix_type_choice,
    STATE(13167), 1,
      sym_template_body,
    STATE(13302), 1,
      sym__type,
    STATE(15643), 1,
      sym_parameter_types,
    STATE(16509), 1,
      sym_stable_identifier,
    ACTIONS(4400), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4402), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4406), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3618), 2,
      sym_comment,
      sym_block_comment,
    STATE(9591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10144), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13130), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13189), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5943), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [156801] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15542), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3619), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [156922] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15554), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3620), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [157043] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6134), 1,
      anon_sym_COLON,
    ACTIONS(6136), 1,
      anon_sym_LBRACE,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6140), 1,
      anon_sym_LBRACK,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6150), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(8699), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(11171), 1,
      sym__non_null_literal,
    STATE(11172), 1,
      sym_literal_type,
    STATE(11576), 1,
      sym_template_body,
    STATE(11609), 1,
      sym__type,
    STATE(12342), 1,
      sym__infix_type_choice,
    STATE(15615), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3621), 2,
      sym_comment,
      sym_block_comment,
    STATE(11119), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11526), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11592), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [157164] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15567), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3622), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [157285] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15569), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3623), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [157406] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6134), 1,
      anon_sym_COLON,
    ACTIONS(6136), 1,
      anon_sym_LBRACE,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6140), 1,
      anon_sym_LBRACK,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6150), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(8699), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(11171), 1,
      sym__non_null_literal,
    STATE(11172), 1,
      sym_literal_type,
    STATE(11576), 1,
      sym_template_body,
    STATE(11610), 1,
      sym__type,
    STATE(12342), 1,
      sym__infix_type_choice,
    STATE(15615), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3624), 2,
      sym_comment,
      sym_block_comment,
    STATE(11119), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11526), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11592), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [157527] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6218), 1,
      anon_sym_LBRACK,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(14267), 1,
      sym__type,
    STATE(15570), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3625), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [157648] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15576), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3626), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [157769] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15579), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3627), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [157890] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6832), 1,
      anon_sym_COLON,
    ACTIONS(6834), 1,
      anon_sym_LBRACE,
    ACTIONS(6836), 1,
      anon_sym__,
    ACTIONS(6838), 1,
      anon_sym_LBRACK,
    ACTIONS(6842), 1,
      anon_sym_LPAREN,
    ACTIONS(6844), 1,
      sym__backquoted_id,
    ACTIONS(6846), 1,
      sym_operator_identifier,
    ACTIONS(6848), 1,
      sym_integer_literal,
    STATE(8371), 1,
      sym__simple_type,
    STATE(8809), 1,
      sym__soft_identifier,
    STATE(8868), 1,
      sym_identifier,
    STATE(9195), 1,
      sym__annotated_type,
    STATE(10851), 1,
      sym_annotated_type,
    STATE(12356), 1,
      sym_literal_type,
    STATE(12487), 1,
      sym__non_null_literal,
    STATE(12538), 1,
      sym__infix_type_choice,
    STATE(15219), 1,
      sym_parameter_types,
    STATE(15945), 1,
      sym_template_body,
    STATE(16025), 1,
      sym__type,
    STATE(17197), 1,
      sym_stable_identifier,
    ACTIONS(6850), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6852), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6854), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3628), 2,
      sym_comment,
      sym_block_comment,
    STATE(11571), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11704), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12601), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16097), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6840), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9436), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [158011] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15591), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3629), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [158132] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15596), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3630), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [158253] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6832), 1,
      anon_sym_COLON,
    ACTIONS(6834), 1,
      anon_sym_LBRACE,
    ACTIONS(6836), 1,
      anon_sym__,
    ACTIONS(6838), 1,
      anon_sym_LBRACK,
    ACTIONS(6842), 1,
      anon_sym_LPAREN,
    ACTIONS(6844), 1,
      sym__backquoted_id,
    ACTIONS(6846), 1,
      sym_operator_identifier,
    ACTIONS(6848), 1,
      sym_integer_literal,
    STATE(8371), 1,
      sym__simple_type,
    STATE(8809), 1,
      sym__soft_identifier,
    STATE(8868), 1,
      sym_identifier,
    STATE(9195), 1,
      sym__annotated_type,
    STATE(10851), 1,
      sym_annotated_type,
    STATE(12356), 1,
      sym_literal_type,
    STATE(12487), 1,
      sym__non_null_literal,
    STATE(12538), 1,
      sym__infix_type_choice,
    STATE(15219), 1,
      sym_parameter_types,
    STATE(15945), 1,
      sym_template_body,
    STATE(16144), 1,
      sym__type,
    STATE(17197), 1,
      sym_stable_identifier,
    ACTIONS(6850), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6852), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6854), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3631), 2,
      sym_comment,
      sym_block_comment,
    STATE(11571), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11704), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12601), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16097), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6840), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9436), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [158374] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2042), 1,
      sym_integer_literal,
    ACTIONS(6518), 1,
      sym__alpha_identifier,
    ACTIONS(6520), 1,
      anon_sym_COLON,
    ACTIONS(6522), 1,
      anon_sym_LBRACE,
    ACTIONS(6524), 1,
      anon_sym__,
    ACTIONS(6526), 1,
      anon_sym_LBRACK,
    ACTIONS(6530), 1,
      anon_sym_LPAREN,
    ACTIONS(6532), 1,
      sym__backquoted_id,
    ACTIONS(6534), 1,
      sym_operator_identifier,
    STATE(7297), 1,
      sym__annotated_type,
    STATE(7378), 1,
      sym__simple_type,
    STATE(7649), 1,
      sym_identifier,
    STATE(7843), 1,
      sym__soft_identifier,
    STATE(9842), 1,
      sym_annotated_type,
    STATE(11159), 1,
      sym_literal_type,
    STATE(11175), 1,
      sym__non_null_literal,
    STATE(11868), 1,
      sym_template_body,
    STATE(12478), 1,
      sym__infix_type_choice,
    STATE(12612), 1,
      sym__type,
    STATE(15061), 1,
      sym_parameter_types,
    STATE(16974), 1,
      sym_stable_identifier,
    ACTIONS(2044), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2046), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2050), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3632), 2,
      sym_comment,
      sym_block_comment,
    STATE(6450), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9825), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10747), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6528), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [158495] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6832), 1,
      anon_sym_COLON,
    ACTIONS(6834), 1,
      anon_sym_LBRACE,
    ACTIONS(6836), 1,
      anon_sym__,
    ACTIONS(6838), 1,
      anon_sym_LBRACK,
    ACTIONS(6842), 1,
      anon_sym_LPAREN,
    ACTIONS(6844), 1,
      sym__backquoted_id,
    ACTIONS(6846), 1,
      sym_operator_identifier,
    ACTIONS(6848), 1,
      sym_integer_literal,
    STATE(8371), 1,
      sym__simple_type,
    STATE(8809), 1,
      sym__soft_identifier,
    STATE(8868), 1,
      sym_identifier,
    STATE(9195), 1,
      sym__annotated_type,
    STATE(10851), 1,
      sym_annotated_type,
    STATE(12356), 1,
      sym_literal_type,
    STATE(12487), 1,
      sym__non_null_literal,
    STATE(12538), 1,
      sym__infix_type_choice,
    STATE(15219), 1,
      sym_parameter_types,
    STATE(15921), 1,
      sym__type,
    STATE(15945), 1,
      sym_template_body,
    STATE(17197), 1,
      sym_stable_identifier,
    ACTIONS(6850), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6852), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6854), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3633), 2,
      sym_comment,
      sym_block_comment,
    STATE(11571), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11704), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12601), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16097), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6840), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9436), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [158616] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15607), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3634), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [158737] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15608), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3635), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [158858] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4138), 1,
      sym__alpha_identifier,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(4144), 1,
      anon_sym__,
    ACTIONS(4148), 1,
      anon_sym_LBRACK,
    ACTIONS(4156), 1,
      sym__backquoted_id,
    ACTIONS(4160), 1,
      sym_integer_literal,
    ACTIONS(6856), 1,
      anon_sym_LPAREN,
    ACTIONS(6858), 1,
      sym_operator_identifier,
    STATE(5771), 1,
      sym__simple_type,
    STATE(5791), 1,
      sym__annotated_type,
    STATE(6041), 1,
      sym__soft_identifier,
    STATE(6244), 1,
      sym_identifier,
    STATE(9212), 1,
      sym_annotated_type,
    STATE(10773), 1,
      sym_literal_type,
    STATE(10898), 1,
      sym__non_null_literal,
    STATE(12156), 1,
      sym_template_body,
    STATE(12437), 1,
      sym__infix_type_choice,
    STATE(12989), 1,
      sym__type,
    STATE(14851), 1,
      sym_parameter_types,
    STATE(16550), 1,
      sym_stable_identifier,
    ACTIONS(4162), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4164), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4168), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3636), 2,
      sym_comment,
      sym_block_comment,
    STATE(10288), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10717), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4150), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7341), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [158979] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6832), 1,
      anon_sym_COLON,
    ACTIONS(6834), 1,
      anon_sym_LBRACE,
    ACTIONS(6836), 1,
      anon_sym__,
    ACTIONS(6838), 1,
      anon_sym_LBRACK,
    ACTIONS(6842), 1,
      anon_sym_LPAREN,
    ACTIONS(6844), 1,
      sym__backquoted_id,
    ACTIONS(6846), 1,
      sym_operator_identifier,
    ACTIONS(6848), 1,
      sym_integer_literal,
    STATE(8371), 1,
      sym__simple_type,
    STATE(8809), 1,
      sym__soft_identifier,
    STATE(8868), 1,
      sym_identifier,
    STATE(9195), 1,
      sym__annotated_type,
    STATE(10851), 1,
      sym_annotated_type,
    STATE(12356), 1,
      sym_literal_type,
    STATE(12487), 1,
      sym__non_null_literal,
    STATE(12538), 1,
      sym__infix_type_choice,
    STATE(15219), 1,
      sym_parameter_types,
    STATE(15932), 1,
      sym__type,
    STATE(15945), 1,
      sym_template_body,
    STATE(17197), 1,
      sym_stable_identifier,
    ACTIONS(6850), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6852), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6854), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3637), 2,
      sym_comment,
      sym_block_comment,
    STATE(11571), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11704), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12601), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16097), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6840), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9436), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [159100] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15629), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3638), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [159221] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15636), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3639), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [159342] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7460), 1,
      sym__annotated_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(12373), 1,
      sym__infix_type_choice,
    STATE(13961), 1,
      sym__type,
    STATE(15843), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3640), 2,
      sym_comment,
      sym_block_comment,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [159463] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4734), 1,
      anon_sym_COLON,
    ACTIONS(4736), 1,
      anon_sym_LBRACE,
    ACTIONS(4794), 1,
      sym__alpha_identifier,
    ACTIONS(4796), 1,
      anon_sym__,
    ACTIONS(4800), 1,
      anon_sym_LBRACK,
    ACTIONS(4806), 1,
      sym__backquoted_id,
    ACTIONS(4810), 1,
      sym_integer_literal,
    ACTIONS(6826), 1,
      anon_sym_LPAREN,
    ACTIONS(6828), 1,
      sym_operator_identifier,
    STATE(4477), 1,
      sym__simple_type,
    STATE(4561), 1,
      sym__annotated_type,
    STATE(4605), 1,
      sym__soft_identifier,
    STATE(4610), 1,
      sym_identifier,
    STATE(6171), 1,
      sym_annotated_type,
    STATE(9652), 1,
      sym__non_null_literal,
    STATE(9661), 1,
      sym_literal_type,
    STATE(11929), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12485), 1,
      sym__infix_type_choice,
    STATE(15026), 1,
      sym_parameter_types,
    STATE(17024), 1,
      sym_stable_identifier,
    ACTIONS(4812), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4814), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4816), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3641), 2,
      sym_comment,
      sym_block_comment,
    STATE(8488), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9443), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11907), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4802), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4813), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [159584] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15677), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3642), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [159705] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15688), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3643), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [159826] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4138), 1,
      sym__alpha_identifier,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(4144), 1,
      anon_sym__,
    ACTIONS(4148), 1,
      anon_sym_LBRACK,
    ACTIONS(4156), 1,
      sym__backquoted_id,
    ACTIONS(4160), 1,
      sym_integer_literal,
    ACTIONS(6856), 1,
      anon_sym_LPAREN,
    ACTIONS(6858), 1,
      sym_operator_identifier,
    STATE(5771), 1,
      sym__simple_type,
    STATE(5791), 1,
      sym__annotated_type,
    STATE(6041), 1,
      sym__soft_identifier,
    STATE(6244), 1,
      sym_identifier,
    STATE(9212), 1,
      sym_annotated_type,
    STATE(10773), 1,
      sym_literal_type,
    STATE(10898), 1,
      sym__non_null_literal,
    STATE(12156), 1,
      sym_template_body,
    STATE(12437), 1,
      sym__infix_type_choice,
    STATE(12686), 1,
      sym__type,
    STATE(14851), 1,
      sym_parameter_types,
    STATE(16550), 1,
      sym_stable_identifier,
    ACTIONS(4162), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4164), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4168), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3644), 2,
      sym_comment,
      sym_block_comment,
    STATE(10288), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10717), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4150), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7341), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [159947] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15727), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3645), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [160068] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15733), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3646), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [160189] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4138), 1,
      sym__alpha_identifier,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(4144), 1,
      anon_sym__,
    ACTIONS(4148), 1,
      anon_sym_LBRACK,
    ACTIONS(4156), 1,
      sym__backquoted_id,
    ACTIONS(4160), 1,
      sym_integer_literal,
    ACTIONS(6856), 1,
      anon_sym_LPAREN,
    ACTIONS(6858), 1,
      sym_operator_identifier,
    STATE(5771), 1,
      sym__simple_type,
    STATE(5791), 1,
      sym__annotated_type,
    STATE(6041), 1,
      sym__soft_identifier,
    STATE(6244), 1,
      sym_identifier,
    STATE(9212), 1,
      sym_annotated_type,
    STATE(10773), 1,
      sym_literal_type,
    STATE(10898), 1,
      sym__non_null_literal,
    STATE(12156), 1,
      sym_template_body,
    STATE(12437), 1,
      sym__infix_type_choice,
    STATE(12694), 1,
      sym__type,
    STATE(14851), 1,
      sym_parameter_types,
    STATE(16550), 1,
      sym_stable_identifier,
    ACTIONS(4162), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4164), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4168), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3647), 2,
      sym_comment,
      sym_block_comment,
    STATE(10288), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10717), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4150), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7341), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [160310] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4138), 1,
      sym__alpha_identifier,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(4144), 1,
      anon_sym__,
    ACTIONS(4148), 1,
      anon_sym_LBRACK,
    ACTIONS(4156), 1,
      sym__backquoted_id,
    ACTIONS(4160), 1,
      sym_integer_literal,
    ACTIONS(6856), 1,
      anon_sym_LPAREN,
    ACTIONS(6858), 1,
      sym_operator_identifier,
    STATE(5771), 1,
      sym__simple_type,
    STATE(5791), 1,
      sym__annotated_type,
    STATE(6041), 1,
      sym__soft_identifier,
    STATE(6244), 1,
      sym_identifier,
    STATE(9212), 1,
      sym_annotated_type,
    STATE(10773), 1,
      sym_literal_type,
    STATE(10898), 1,
      sym__non_null_literal,
    STATE(12156), 1,
      sym_template_body,
    STATE(12437), 1,
      sym__infix_type_choice,
    STATE(12695), 1,
      sym__type,
    STATE(14851), 1,
      sym_parameter_types,
    STATE(16550), 1,
      sym_stable_identifier,
    ACTIONS(4162), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4164), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4168), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3648), 2,
      sym_comment,
      sym_block_comment,
    STATE(10288), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10717), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4150), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7341), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [160431] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4138), 1,
      sym__alpha_identifier,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(4144), 1,
      anon_sym__,
    ACTIONS(4148), 1,
      anon_sym_LBRACK,
    ACTIONS(4156), 1,
      sym__backquoted_id,
    ACTIONS(4160), 1,
      sym_integer_literal,
    ACTIONS(6856), 1,
      anon_sym_LPAREN,
    ACTIONS(6858), 1,
      sym_operator_identifier,
    STATE(5771), 1,
      sym__simple_type,
    STATE(5791), 1,
      sym__annotated_type,
    STATE(6041), 1,
      sym__soft_identifier,
    STATE(6244), 1,
      sym_identifier,
    STATE(9212), 1,
      sym_annotated_type,
    STATE(10773), 1,
      sym_literal_type,
    STATE(10898), 1,
      sym__non_null_literal,
    STATE(12156), 1,
      sym_template_body,
    STATE(12437), 1,
      sym__infix_type_choice,
    STATE(12696), 1,
      sym__type,
    STATE(14851), 1,
      sym_parameter_types,
    STATE(16550), 1,
      sym_stable_identifier,
    ACTIONS(4162), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4164), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4168), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3649), 2,
      sym_comment,
      sym_block_comment,
    STATE(10288), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10717), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4150), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7341), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [160552] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15768), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3650), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [160673] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15779), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3651), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [160794] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4434), 1,
      sym__alpha_identifier,
    ACTIONS(4436), 1,
      anon_sym_COLON,
    ACTIONS(4438), 1,
      anon_sym_LBRACE,
    ACTIONS(4440), 1,
      anon_sym__,
    ACTIONS(4444), 1,
      anon_sym_LBRACK,
    ACTIONS(4452), 1,
      sym__backquoted_id,
    ACTIONS(4456), 1,
      sym_integer_literal,
    ACTIONS(6860), 1,
      anon_sym_LPAREN,
    ACTIONS(6862), 1,
      sym_operator_identifier,
    STATE(4590), 1,
      sym__simple_type,
    STATE(4592), 1,
      sym__annotated_type,
    STATE(4870), 1,
      sym_identifier,
    STATE(4948), 1,
      sym__soft_identifier,
    STATE(7281), 1,
      sym_annotated_type,
    STATE(10057), 1,
      sym__non_null_literal,
    STATE(10116), 1,
      sym_literal_type,
    STATE(12539), 1,
      sym__infix_type_choice,
    STATE(12873), 1,
      sym_template_body,
    STATE(12894), 1,
      sym__type,
    STATE(15256), 1,
      sym_parameter_types,
    STATE(17203), 1,
      sym_stable_identifier,
    ACTIONS(4458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4464), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3652), 2,
      sym_comment,
      sym_block_comment,
    STATE(8888), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9862), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12943), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12811), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4446), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5122), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [160915] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15828), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3653), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [161036] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15830), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3654), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [161157] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(16772), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3655), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [161278] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4734), 1,
      anon_sym_COLON,
    ACTIONS(4736), 1,
      anon_sym_LBRACE,
    ACTIONS(4794), 1,
      sym__alpha_identifier,
    ACTIONS(4796), 1,
      anon_sym__,
    ACTIONS(4800), 1,
      anon_sym_LBRACK,
    ACTIONS(4806), 1,
      sym__backquoted_id,
    ACTIONS(4810), 1,
      sym_integer_literal,
    ACTIONS(6826), 1,
      anon_sym_LPAREN,
    ACTIONS(6828), 1,
      sym_operator_identifier,
    STATE(4477), 1,
      sym__simple_type,
    STATE(4561), 1,
      sym__annotated_type,
    STATE(4605), 1,
      sym__soft_identifier,
    STATE(4610), 1,
      sym_identifier,
    STATE(6171), 1,
      sym_annotated_type,
    STATE(9652), 1,
      sym__non_null_literal,
    STATE(9661), 1,
      sym_literal_type,
    STATE(11935), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12485), 1,
      sym__infix_type_choice,
    STATE(15026), 1,
      sym_parameter_types,
    STATE(17024), 1,
      sym_stable_identifier,
    ACTIONS(4812), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4814), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4816), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3656), 2,
      sym_comment,
      sym_block_comment,
    STATE(8488), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9443), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11907), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4802), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4813), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [161399] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14733), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3657), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [161520] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14734), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3658), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [161641] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4734), 1,
      anon_sym_COLON,
    ACTIONS(4736), 1,
      anon_sym_LBRACE,
    ACTIONS(4794), 1,
      sym__alpha_identifier,
    ACTIONS(4796), 1,
      anon_sym__,
    ACTIONS(4800), 1,
      anon_sym_LBRACK,
    ACTIONS(4806), 1,
      sym__backquoted_id,
    ACTIONS(4810), 1,
      sym_integer_literal,
    ACTIONS(6826), 1,
      anon_sym_LPAREN,
    ACTIONS(6828), 1,
      sym_operator_identifier,
    STATE(4477), 1,
      sym__simple_type,
    STATE(4561), 1,
      sym__annotated_type,
    STATE(4605), 1,
      sym__soft_identifier,
    STATE(4610), 1,
      sym_identifier,
    STATE(6171), 1,
      sym_annotated_type,
    STATE(9652), 1,
      sym__non_null_literal,
    STATE(9661), 1,
      sym_literal_type,
    STATE(11937), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12485), 1,
      sym__infix_type_choice,
    STATE(15026), 1,
      sym_parameter_types,
    STATE(17024), 1,
      sym_stable_identifier,
    ACTIONS(4812), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4814), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4816), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3659), 2,
      sym_comment,
      sym_block_comment,
    STATE(8488), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9443), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11907), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4802), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4813), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [161762] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4734), 1,
      anon_sym_COLON,
    ACTIONS(4736), 1,
      anon_sym_LBRACE,
    ACTIONS(4794), 1,
      sym__alpha_identifier,
    ACTIONS(4796), 1,
      anon_sym__,
    ACTIONS(4800), 1,
      anon_sym_LBRACK,
    ACTIONS(4806), 1,
      sym__backquoted_id,
    ACTIONS(4810), 1,
      sym_integer_literal,
    ACTIONS(6826), 1,
      anon_sym_LPAREN,
    ACTIONS(6828), 1,
      sym_operator_identifier,
    STATE(4477), 1,
      sym__simple_type,
    STATE(4561), 1,
      sym__annotated_type,
    STATE(4605), 1,
      sym__soft_identifier,
    STATE(4610), 1,
      sym_identifier,
    STATE(6171), 1,
      sym_annotated_type,
    STATE(9652), 1,
      sym__non_null_literal,
    STATE(9661), 1,
      sym_literal_type,
    STATE(11942), 1,
      sym__type,
    STATE(12037), 1,
      sym_template_body,
    STATE(12485), 1,
      sym__infix_type_choice,
    STATE(15026), 1,
      sym_parameter_types,
    STATE(17024), 1,
      sym_stable_identifier,
    ACTIONS(4812), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4814), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4816), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3660), 2,
      sym_comment,
      sym_block_comment,
    STATE(8488), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9443), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11907), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12132), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4802), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4813), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [161883] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3312), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6734), 1,
      anon_sym_COLON,
    ACTIONS(6736), 1,
      anon_sym_LBRACE,
    ACTIONS(6738), 1,
      anon_sym_LBRACK,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(9878), 1,
      sym__annotated_type,
    STATE(12417), 1,
      sym__infix_type_choice,
    STATE(13011), 1,
      sym__non_null_literal,
    STATE(13015), 1,
      sym_literal_type,
    STATE(15455), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17378), 1,
      sym_template_body,
    STATE(17629), 1,
      sym__type,
    ACTIONS(3314), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(3316), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(3320), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3661), 2,
      sym_comment,
      sym_block_comment,
    STATE(10820), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12330), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(16792), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(16879), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [162004] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14739), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3662), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [162125] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14740), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3663), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [162246] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4434), 1,
      sym__alpha_identifier,
    ACTIONS(4436), 1,
      anon_sym_COLON,
    ACTIONS(4438), 1,
      anon_sym_LBRACE,
    ACTIONS(4440), 1,
      anon_sym__,
    ACTIONS(4444), 1,
      anon_sym_LBRACK,
    ACTIONS(4452), 1,
      sym__backquoted_id,
    ACTIONS(4456), 1,
      sym_integer_literal,
    ACTIONS(6860), 1,
      anon_sym_LPAREN,
    ACTIONS(6862), 1,
      sym_operator_identifier,
    STATE(4590), 1,
      sym__simple_type,
    STATE(4592), 1,
      sym__annotated_type,
    STATE(4870), 1,
      sym_identifier,
    STATE(4948), 1,
      sym__soft_identifier,
    STATE(7281), 1,
      sym_annotated_type,
    STATE(10057), 1,
      sym__non_null_literal,
    STATE(10116), 1,
      sym_literal_type,
    STATE(12539), 1,
      sym__infix_type_choice,
    STATE(12873), 1,
      sym_template_body,
    STATE(12907), 1,
      sym__type,
    STATE(15256), 1,
      sym_parameter_types,
    STATE(17203), 1,
      sym_stable_identifier,
    ACTIONS(4458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4464), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3664), 2,
      sym_comment,
      sym_block_comment,
    STATE(8888), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9862), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12943), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12811), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4446), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5122), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [162367] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14744), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3665), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [162488] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14745), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3666), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [162609] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4468), 1,
      sym__alpha_identifier,
    ACTIONS(4470), 1,
      anon_sym_COLON,
    ACTIONS(4472), 1,
      anon_sym_LBRACE,
    ACTIONS(4474), 1,
      anon_sym__,
    ACTIONS(4478), 1,
      anon_sym_LBRACK,
    ACTIONS(4486), 1,
      sym__backquoted_id,
    ACTIONS(4490), 1,
      sym_integer_literal,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym_operator_identifier,
    STATE(6206), 1,
      sym__simple_type,
    STATE(6248), 1,
      sym__annotated_type,
    STATE(6759), 1,
      sym__soft_identifier,
    STATE(6938), 1,
      sym_identifier,
    STATE(9655), 1,
      sym_annotated_type,
    STATE(10968), 1,
      sym_literal_type,
    STATE(11044), 1,
      sym__non_null_literal,
    STATE(11868), 1,
      sym_template_body,
    STATE(11991), 1,
      sym__type,
    STATE(12441), 1,
      sym__infix_type_choice,
    STATE(15622), 1,
      sym_parameter_types,
    STATE(16590), 1,
      sym_stable_identifier,
    ACTIONS(4492), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4494), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4498), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3667), 2,
      sym_comment,
      sym_block_comment,
    STATE(10450), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11090), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12157), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4480), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8071), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [162730] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16472), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3668), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [162851] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4434), 1,
      sym__alpha_identifier,
    ACTIONS(4436), 1,
      anon_sym_COLON,
    ACTIONS(4438), 1,
      anon_sym_LBRACE,
    ACTIONS(4440), 1,
      anon_sym__,
    ACTIONS(4444), 1,
      anon_sym_LBRACK,
    ACTIONS(4452), 1,
      sym__backquoted_id,
    ACTIONS(4456), 1,
      sym_integer_literal,
    ACTIONS(6860), 1,
      anon_sym_LPAREN,
    ACTIONS(6862), 1,
      sym_operator_identifier,
    STATE(4590), 1,
      sym__simple_type,
    STATE(4592), 1,
      sym__annotated_type,
    STATE(4870), 1,
      sym_identifier,
    STATE(4948), 1,
      sym__soft_identifier,
    STATE(7281), 1,
      sym_annotated_type,
    STATE(10057), 1,
      sym__non_null_literal,
    STATE(10116), 1,
      sym_literal_type,
    STATE(12539), 1,
      sym__infix_type_choice,
    STATE(12873), 1,
      sym_template_body,
    STATE(12912), 1,
      sym__type,
    STATE(15256), 1,
      sym_parameter_types,
    STATE(17203), 1,
      sym_stable_identifier,
    ACTIONS(4458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4464), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3669), 2,
      sym_comment,
      sym_block_comment,
    STATE(8888), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9862), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12943), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12811), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4446), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5122), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [162972] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14751), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3670), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [163093] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14753), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3671), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [163214] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4434), 1,
      sym__alpha_identifier,
    ACTIONS(4436), 1,
      anon_sym_COLON,
    ACTIONS(4438), 1,
      anon_sym_LBRACE,
    ACTIONS(4440), 1,
      anon_sym__,
    ACTIONS(4444), 1,
      anon_sym_LBRACK,
    ACTIONS(4452), 1,
      sym__backquoted_id,
    ACTIONS(4456), 1,
      sym_integer_literal,
    ACTIONS(6860), 1,
      anon_sym_LPAREN,
    ACTIONS(6862), 1,
      sym_operator_identifier,
    STATE(4590), 1,
      sym__simple_type,
    STATE(4592), 1,
      sym__annotated_type,
    STATE(4870), 1,
      sym_identifier,
    STATE(4948), 1,
      sym__soft_identifier,
    STATE(7281), 1,
      sym_annotated_type,
    STATE(10057), 1,
      sym__non_null_literal,
    STATE(10116), 1,
      sym_literal_type,
    STATE(12539), 1,
      sym__infix_type_choice,
    STATE(12873), 1,
      sym_template_body,
    STATE(12914), 1,
      sym__type,
    STATE(15256), 1,
      sym_parameter_types,
    STATE(17203), 1,
      sym_stable_identifier,
    ACTIONS(4458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4464), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3672), 2,
      sym_comment,
      sym_block_comment,
    STATE(8888), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9862), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12943), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12811), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4446), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5122), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [163335] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4434), 1,
      sym__alpha_identifier,
    ACTIONS(4436), 1,
      anon_sym_COLON,
    ACTIONS(4438), 1,
      anon_sym_LBRACE,
    ACTIONS(4440), 1,
      anon_sym__,
    ACTIONS(4444), 1,
      anon_sym_LBRACK,
    ACTIONS(4452), 1,
      sym__backquoted_id,
    ACTIONS(4456), 1,
      sym_integer_literal,
    ACTIONS(6860), 1,
      anon_sym_LPAREN,
    ACTIONS(6862), 1,
      sym_operator_identifier,
    STATE(4590), 1,
      sym__simple_type,
    STATE(4592), 1,
      sym__annotated_type,
    STATE(4870), 1,
      sym_identifier,
    STATE(4948), 1,
      sym__soft_identifier,
    STATE(7281), 1,
      sym_annotated_type,
    STATE(10057), 1,
      sym__non_null_literal,
    STATE(10116), 1,
      sym_literal_type,
    STATE(12539), 1,
      sym__infix_type_choice,
    STATE(12873), 1,
      sym_template_body,
    STATE(12924), 1,
      sym__type,
    STATE(15256), 1,
      sym_parameter_types,
    STATE(17203), 1,
      sym_stable_identifier,
    ACTIONS(4458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4464), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3673), 2,
      sym_comment,
      sym_block_comment,
    STATE(8888), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9862), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12943), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12811), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4446), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5122), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [163456] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14757), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3674), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [163577] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14759), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3675), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [163698] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4468), 1,
      sym__alpha_identifier,
    ACTIONS(4470), 1,
      anon_sym_COLON,
    ACTIONS(4472), 1,
      anon_sym_LBRACE,
    ACTIONS(4474), 1,
      anon_sym__,
    ACTIONS(4478), 1,
      anon_sym_LBRACK,
    ACTIONS(4486), 1,
      sym__backquoted_id,
    ACTIONS(4490), 1,
      sym_integer_literal,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym_operator_identifier,
    STATE(6206), 1,
      sym__simple_type,
    STATE(6248), 1,
      sym__annotated_type,
    STATE(6759), 1,
      sym__soft_identifier,
    STATE(6938), 1,
      sym_identifier,
    STATE(9655), 1,
      sym_annotated_type,
    STATE(10968), 1,
      sym_literal_type,
    STATE(11044), 1,
      sym__non_null_literal,
    STATE(11868), 1,
      sym_template_body,
    STATE(12007), 1,
      sym__type,
    STATE(12441), 1,
      sym__infix_type_choice,
    STATE(15622), 1,
      sym_parameter_types,
    STATE(16590), 1,
      sym_stable_identifier,
    ACTIONS(4492), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4494), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4498), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3676), 2,
      sym_comment,
      sym_block_comment,
    STATE(10450), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11090), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12157), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4480), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8071), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [163819] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4468), 1,
      sym__alpha_identifier,
    ACTIONS(4470), 1,
      anon_sym_COLON,
    ACTIONS(4472), 1,
      anon_sym_LBRACE,
    ACTIONS(4474), 1,
      anon_sym__,
    ACTIONS(4478), 1,
      anon_sym_LBRACK,
    ACTIONS(4486), 1,
      sym__backquoted_id,
    ACTIONS(4490), 1,
      sym_integer_literal,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym_operator_identifier,
    STATE(6206), 1,
      sym__simple_type,
    STATE(6248), 1,
      sym__annotated_type,
    STATE(6759), 1,
      sym__soft_identifier,
    STATE(6938), 1,
      sym_identifier,
    STATE(9655), 1,
      sym_annotated_type,
    STATE(10968), 1,
      sym_literal_type,
    STATE(11044), 1,
      sym__non_null_literal,
    STATE(11868), 1,
      sym_template_body,
    STATE(12010), 1,
      sym__type,
    STATE(12441), 1,
      sym__infix_type_choice,
    STATE(15622), 1,
      sym_parameter_types,
    STATE(16590), 1,
      sym_stable_identifier,
    ACTIONS(4492), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4494), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4498), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3677), 2,
      sym_comment,
      sym_block_comment,
    STATE(10450), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11090), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12157), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4480), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8071), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [163940] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14764), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3678), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [164061] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14765), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3679), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [164182] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4468), 1,
      sym__alpha_identifier,
    ACTIONS(4470), 1,
      anon_sym_COLON,
    ACTIONS(4472), 1,
      anon_sym_LBRACE,
    ACTIONS(4474), 1,
      anon_sym__,
    ACTIONS(4478), 1,
      anon_sym_LBRACK,
    ACTIONS(4486), 1,
      sym__backquoted_id,
    ACTIONS(4490), 1,
      sym_integer_literal,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym_operator_identifier,
    STATE(6206), 1,
      sym__simple_type,
    STATE(6248), 1,
      sym__annotated_type,
    STATE(6759), 1,
      sym__soft_identifier,
    STATE(6938), 1,
      sym_identifier,
    STATE(9655), 1,
      sym_annotated_type,
    STATE(10968), 1,
      sym_literal_type,
    STATE(11044), 1,
      sym__non_null_literal,
    STATE(11868), 1,
      sym_template_body,
    STATE(12013), 1,
      sym__type,
    STATE(12441), 1,
      sym__infix_type_choice,
    STATE(15622), 1,
      sym_parameter_types,
    STATE(16590), 1,
      sym_stable_identifier,
    ACTIONS(4492), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4494), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4498), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3680), 2,
      sym_comment,
      sym_block_comment,
    STATE(10450), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11090), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12157), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4480), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8071), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [164303] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4468), 1,
      sym__alpha_identifier,
    ACTIONS(4470), 1,
      anon_sym_COLON,
    ACTIONS(4472), 1,
      anon_sym_LBRACE,
    ACTIONS(4474), 1,
      anon_sym__,
    ACTIONS(4478), 1,
      anon_sym_LBRACK,
    ACTIONS(4486), 1,
      sym__backquoted_id,
    ACTIONS(4490), 1,
      sym_integer_literal,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym_operator_identifier,
    STATE(6206), 1,
      sym__simple_type,
    STATE(6248), 1,
      sym__annotated_type,
    STATE(6759), 1,
      sym__soft_identifier,
    STATE(6938), 1,
      sym_identifier,
    STATE(9655), 1,
      sym_annotated_type,
    STATE(10968), 1,
      sym_literal_type,
    STATE(11044), 1,
      sym__non_null_literal,
    STATE(11868), 1,
      sym_template_body,
    STATE(12014), 1,
      sym__type,
    STATE(12441), 1,
      sym__infix_type_choice,
    STATE(15622), 1,
      sym_parameter_types,
    STATE(16590), 1,
      sym_stable_identifier,
    ACTIONS(4492), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4494), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4498), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3681), 2,
      sym_comment,
      sym_block_comment,
    STATE(10450), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11090), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12157), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4480), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8071), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [164424] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14769), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3682), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [164545] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14772), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3683), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [164666] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6414), 1,
      anon_sym_COLON,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(6418), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(14622), 1,
      sym__type,
    STATE(15021), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3684), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [164787] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(6792), 1,
      sym__alpha_identifier,
    ACTIONS(6794), 1,
      anon_sym__,
    ACTIONS(6796), 1,
      anon_sym_LBRACK,
    ACTIONS(6800), 1,
      anon_sym_LPAREN,
    ACTIONS(6802), 1,
      sym__backquoted_id,
    ACTIONS(6804), 1,
      sym_operator_identifier,
    ACTIONS(6806), 1,
      sym_integer_literal,
    STATE(7421), 1,
      sym__simple_type,
    STATE(8149), 1,
      sym__soft_identifier,
    STATE(8152), 1,
      sym_identifier,
    STATE(8382), 1,
      sym__annotated_type,
    STATE(10572), 1,
      sym_annotated_type,
    STATE(11696), 1,
      sym__non_null_literal,
    STATE(11697), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12428), 1,
      sym__infix_type_choice,
    STATE(14625), 1,
      sym__type,
    STATE(15085), 1,
      sym_parameter_types,
    STATE(16446), 1,
      sym_stable_identifier,
    ACTIONS(6808), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6812), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3685), 2,
      sym_comment,
      sym_block_comment,
    STATE(11046), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11463), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6798), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9214), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [164908] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14778), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3686), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [165029] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14780), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3687), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [165150] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6182), 1,
      anon_sym_LBRACK,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(7246), 1,
      sym__annotated_type,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12466), 1,
      sym__infix_type_choice,
    STATE(14047), 1,
      sym__type,
    STATE(15109), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3688), 2,
      sym_comment,
      sym_block_comment,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [165271] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1138), 1,
      sym_integer_literal,
    ACTIONS(6690), 1,
      sym__alpha_identifier,
    ACTIONS(6692), 1,
      anon_sym_COLON,
    ACTIONS(6694), 1,
      anon_sym_LBRACE,
    ACTIONS(6696), 1,
      anon_sym__,
    ACTIONS(6698), 1,
      anon_sym_LBRACK,
    ACTIONS(6702), 1,
      anon_sym_LPAREN,
    ACTIONS(6704), 1,
      sym__backquoted_id,
    ACTIONS(6706), 1,
      sym_operator_identifier,
    STATE(4927), 1,
      sym__annotated_type,
    STATE(4955), 1,
      sym__simple_type,
    STATE(5112), 1,
      sym_identifier,
    STATE(5191), 1,
      sym__soft_identifier,
    STATE(8039), 1,
      sym_annotated_type,
    STATE(10305), 1,
      sym_literal_type,
    STATE(10365), 1,
      sym__non_null_literal,
    STATE(12540), 1,
      sym__infix_type_choice,
    STATE(12881), 1,
      sym_template_body,
    STATE(12999), 1,
      sym__type,
    STATE(15030), 1,
      sym_parameter_types,
    STATE(17215), 1,
      sym_stable_identifier,
    ACTIONS(1140), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1142), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1146), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3689), 2,
      sym_comment,
      sym_block_comment,
    STATE(7452), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7459), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9431), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12809), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5795), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [165392] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14786), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3690), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [165513] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14788), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3691), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [165634] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6414), 1,
      anon_sym_COLON,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(6418), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(14447), 1,
      sym__type,
    STATE(15021), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3692), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [165755] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6758), 1,
      anon_sym_LBRACK,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8856), 1,
      sym__annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12424), 1,
      sym__infix_type_choice,
    STATE(14880), 1,
      sym__type,
    STATE(15058), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3693), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [165876] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14793), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3694), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [165997] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14796), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3695), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [166118] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1432), 1,
      sym_integer_literal,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    STATE(6294), 1,
      sym__annotated_type,
    STATE(6295), 1,
      sym__simple_type,
    STATE(6834), 1,
      sym__soft_identifier,
    STATE(7296), 1,
      sym_identifier,
    STATE(9681), 1,
      sym_annotated_type,
    STATE(10996), 1,
      sym__non_null_literal,
    STATE(11069), 1,
      sym_literal_type,
    STATE(11501), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12445), 1,
      sym__infix_type_choice,
    STATE(15059), 1,
      sym_parameter_types,
    STATE(16630), 1,
      sym_stable_identifier,
    ACTIONS(1434), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1436), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1440), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3696), 2,
      sym_comment,
      sym_block_comment,
    STATE(5972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9688), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10449), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7652), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [166239] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14802), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3697), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [166360] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14804), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3698), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [166481] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1138), 1,
      sym_integer_literal,
    ACTIONS(6690), 1,
      sym__alpha_identifier,
    ACTIONS(6692), 1,
      anon_sym_COLON,
    ACTIONS(6694), 1,
      anon_sym_LBRACE,
    ACTIONS(6696), 1,
      anon_sym__,
    ACTIONS(6698), 1,
      anon_sym_LBRACK,
    ACTIONS(6702), 1,
      anon_sym_LPAREN,
    ACTIONS(6704), 1,
      sym__backquoted_id,
    ACTIONS(6706), 1,
      sym_operator_identifier,
    STATE(4927), 1,
      sym__annotated_type,
    STATE(4955), 1,
      sym__simple_type,
    STATE(5112), 1,
      sym_identifier,
    STATE(5191), 1,
      sym__soft_identifier,
    STATE(8039), 1,
      sym_annotated_type,
    STATE(10305), 1,
      sym_literal_type,
    STATE(10365), 1,
      sym__non_null_literal,
    STATE(12540), 1,
      sym__infix_type_choice,
    STATE(12881), 1,
      sym_template_body,
    STATE(12906), 1,
      sym__type,
    STATE(15030), 1,
      sym_parameter_types,
    STATE(17215), 1,
      sym_stable_identifier,
    ACTIONS(1140), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1142), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1146), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3699), 2,
      sym_comment,
      sym_block_comment,
    STATE(7452), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7459), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9431), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12809), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5795), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [166602] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1138), 1,
      sym_integer_literal,
    ACTIONS(6690), 1,
      sym__alpha_identifier,
    ACTIONS(6692), 1,
      anon_sym_COLON,
    ACTIONS(6694), 1,
      anon_sym_LBRACE,
    ACTIONS(6696), 1,
      anon_sym__,
    ACTIONS(6698), 1,
      anon_sym_LBRACK,
    ACTIONS(6702), 1,
      anon_sym_LPAREN,
    ACTIONS(6704), 1,
      sym__backquoted_id,
    ACTIONS(6706), 1,
      sym_operator_identifier,
    STATE(4927), 1,
      sym__annotated_type,
    STATE(4955), 1,
      sym__simple_type,
    STATE(5112), 1,
      sym_identifier,
    STATE(5191), 1,
      sym__soft_identifier,
    STATE(8039), 1,
      sym_annotated_type,
    STATE(10305), 1,
      sym_literal_type,
    STATE(10365), 1,
      sym__non_null_literal,
    STATE(12540), 1,
      sym__infix_type_choice,
    STATE(12881), 1,
      sym_template_body,
    STATE(12915), 1,
      sym__type,
    STATE(15030), 1,
      sym_parameter_types,
    STATE(17215), 1,
      sym_stable_identifier,
    ACTIONS(1140), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1142), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1146), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3700), 2,
      sym_comment,
      sym_block_comment,
    STATE(7452), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7459), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9431), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12809), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5795), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [166723] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14809), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3701), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [166844] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14810), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3702), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [166965] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1138), 1,
      sym_integer_literal,
    ACTIONS(6690), 1,
      sym__alpha_identifier,
    ACTIONS(6692), 1,
      anon_sym_COLON,
    ACTIONS(6694), 1,
      anon_sym_LBRACE,
    ACTIONS(6696), 1,
      anon_sym__,
    ACTIONS(6698), 1,
      anon_sym_LBRACK,
    ACTIONS(6702), 1,
      anon_sym_LPAREN,
    ACTIONS(6704), 1,
      sym__backquoted_id,
    ACTIONS(6706), 1,
      sym_operator_identifier,
    STATE(4927), 1,
      sym__annotated_type,
    STATE(4955), 1,
      sym__simple_type,
    STATE(5112), 1,
      sym_identifier,
    STATE(5191), 1,
      sym__soft_identifier,
    STATE(8039), 1,
      sym_annotated_type,
    STATE(10305), 1,
      sym_literal_type,
    STATE(10365), 1,
      sym__non_null_literal,
    STATE(12540), 1,
      sym__infix_type_choice,
    STATE(12881), 1,
      sym_template_body,
    STATE(12921), 1,
      sym__type,
    STATE(15030), 1,
      sym_parameter_types,
    STATE(17215), 1,
      sym_stable_identifier,
    ACTIONS(1140), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1142), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1146), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3703), 2,
      sym_comment,
      sym_block_comment,
    STATE(7452), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7459), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9431), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12809), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5795), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [167086] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1138), 1,
      sym_integer_literal,
    ACTIONS(6690), 1,
      sym__alpha_identifier,
    ACTIONS(6692), 1,
      anon_sym_COLON,
    ACTIONS(6694), 1,
      anon_sym_LBRACE,
    ACTIONS(6696), 1,
      anon_sym__,
    ACTIONS(6698), 1,
      anon_sym_LBRACK,
    ACTIONS(6702), 1,
      anon_sym_LPAREN,
    ACTIONS(6704), 1,
      sym__backquoted_id,
    ACTIONS(6706), 1,
      sym_operator_identifier,
    STATE(4927), 1,
      sym__annotated_type,
    STATE(4955), 1,
      sym__simple_type,
    STATE(5112), 1,
      sym_identifier,
    STATE(5191), 1,
      sym__soft_identifier,
    STATE(8039), 1,
      sym_annotated_type,
    STATE(10305), 1,
      sym_literal_type,
    STATE(10365), 1,
      sym__non_null_literal,
    STATE(12540), 1,
      sym__infix_type_choice,
    STATE(12881), 1,
      sym_template_body,
    STATE(12930), 1,
      sym__type,
    STATE(15030), 1,
      sym_parameter_types,
    STATE(17215), 1,
      sym_stable_identifier,
    ACTIONS(1140), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1142), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1146), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3704), 2,
      sym_comment,
      sym_block_comment,
    STATE(7452), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7459), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9431), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12809), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5795), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [167207] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(958), 1,
      sym_integer_literal,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6868), 1,
      sym__alpha_identifier,
    ACTIONS(6870), 1,
      anon_sym__,
    ACTIONS(6872), 1,
      anon_sym_LBRACK,
    ACTIONS(6876), 1,
      anon_sym_LPAREN,
    ACTIONS(6878), 1,
      sym__backquoted_id,
    ACTIONS(6880), 1,
      sym_operator_identifier,
    STATE(4537), 1,
      sym__annotated_type,
    STATE(4541), 1,
      sym__simple_type,
    STATE(4620), 1,
      sym__soft_identifier,
    STATE(4757), 1,
      sym_identifier,
    STATE(6245), 1,
      sym_annotated_type,
    STATE(9435), 1,
      sym_literal_type,
    STATE(9542), 1,
      sym__non_null_literal,
    STATE(11707), 1,
      sym_template_body,
    STATE(12052), 1,
      sym__type,
    STATE(12450), 1,
      sym__infix_type_choice,
    STATE(15086), 1,
      sym_parameter_types,
    STATE(16746), 1,
      sym_stable_identifier,
    ACTIONS(960), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(962), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(966), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3705), 2,
      sym_comment,
      sym_block_comment,
    STATE(5972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6215), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8289), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6874), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4890), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [167328] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14816), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3706), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [167449] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14817), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3707), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [167570] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1432), 1,
      sym_integer_literal,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    STATE(6294), 1,
      sym__annotated_type,
    STATE(6295), 1,
      sym__simple_type,
    STATE(6834), 1,
      sym__soft_identifier,
    STATE(7296), 1,
      sym_identifier,
    STATE(9681), 1,
      sym_annotated_type,
    STATE(10996), 1,
      sym__non_null_literal,
    STATE(11069), 1,
      sym_literal_type,
    STATE(11533), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12445), 1,
      sym__infix_type_choice,
    STATE(15059), 1,
      sym_parameter_types,
    STATE(16630), 1,
      sym_stable_identifier,
    ACTIONS(1434), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1436), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1440), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3708), 2,
      sym_comment,
      sym_block_comment,
    STATE(5972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9688), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10449), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7652), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [167691] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1432), 1,
      sym_integer_literal,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    STATE(6294), 1,
      sym__annotated_type,
    STATE(6295), 1,
      sym__simple_type,
    STATE(6834), 1,
      sym__soft_identifier,
    STATE(7296), 1,
      sym_identifier,
    STATE(9681), 1,
      sym_annotated_type,
    STATE(10996), 1,
      sym__non_null_literal,
    STATE(11069), 1,
      sym_literal_type,
    STATE(11536), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12445), 1,
      sym__infix_type_choice,
    STATE(15059), 1,
      sym_parameter_types,
    STATE(16630), 1,
      sym_stable_identifier,
    ACTIONS(1434), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1436), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1440), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3709), 2,
      sym_comment,
      sym_block_comment,
    STATE(5972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9688), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10449), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7652), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [167812] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1432), 1,
      sym_integer_literal,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    STATE(6294), 1,
      sym__annotated_type,
    STATE(6295), 1,
      sym__simple_type,
    STATE(6834), 1,
      sym__soft_identifier,
    STATE(7296), 1,
      sym_identifier,
    STATE(9681), 1,
      sym_annotated_type,
    STATE(10996), 1,
      sym__non_null_literal,
    STATE(11069), 1,
      sym_literal_type,
    STATE(11537), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12445), 1,
      sym__infix_type_choice,
    STATE(15059), 1,
      sym_parameter_types,
    STATE(16630), 1,
      sym_stable_identifier,
    ACTIONS(1434), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1436), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1440), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3710), 2,
      sym_comment,
      sym_block_comment,
    STATE(5972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9688), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10449), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7652), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [167933] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14821), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3711), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [168054] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14823), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3712), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [168175] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1432), 1,
      sym_integer_literal,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    STATE(6294), 1,
      sym__annotated_type,
    STATE(6295), 1,
      sym__simple_type,
    STATE(6834), 1,
      sym__soft_identifier,
    STATE(7296), 1,
      sym_identifier,
    STATE(9681), 1,
      sym_annotated_type,
    STATE(10996), 1,
      sym__non_null_literal,
    STATE(11069), 1,
      sym_literal_type,
    STATE(11538), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12445), 1,
      sym__infix_type_choice,
    STATE(15059), 1,
      sym_parameter_types,
    STATE(16630), 1,
      sym_stable_identifier,
    ACTIONS(1434), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1436), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1440), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3713), 2,
      sym_comment,
      sym_block_comment,
    STATE(5972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9688), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10449), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7652), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [168296] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(6792), 1,
      sym__alpha_identifier,
    ACTIONS(6794), 1,
      anon_sym__,
    ACTIONS(6796), 1,
      anon_sym_LBRACK,
    ACTIONS(6800), 1,
      anon_sym_LPAREN,
    ACTIONS(6802), 1,
      sym__backquoted_id,
    ACTIONS(6804), 1,
      sym_operator_identifier,
    ACTIONS(6806), 1,
      sym_integer_literal,
    STATE(7421), 1,
      sym__simple_type,
    STATE(8149), 1,
      sym__soft_identifier,
    STATE(8152), 1,
      sym_identifier,
    STATE(8382), 1,
      sym__annotated_type,
    STATE(10572), 1,
      sym_annotated_type,
    STATE(11696), 1,
      sym__non_null_literal,
    STATE(11697), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12428), 1,
      sym__infix_type_choice,
    STATE(14654), 1,
      sym__type,
    STATE(15085), 1,
      sym_parameter_types,
    STATE(16446), 1,
      sym_stable_identifier,
    ACTIONS(6808), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6812), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3714), 2,
      sym_comment,
      sym_block_comment,
    STATE(11046), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11463), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6798), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9214), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [168417] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4664), 1,
      sym__alpha_identifier,
    ACTIONS(4666), 1,
      anon_sym_COLON,
    ACTIONS(4668), 1,
      anon_sym_LBRACE,
    ACTIONS(4670), 1,
      anon_sym__,
    ACTIONS(4674), 1,
      anon_sym_LBRACK,
    ACTIONS(4682), 1,
      sym__backquoted_id,
    ACTIONS(4686), 1,
      sym_integer_literal,
    ACTIONS(6542), 1,
      anon_sym_LPAREN,
    ACTIONS(6544), 1,
      sym_operator_identifier,
    STATE(4972), 1,
      sym__annotated_type,
    STATE(5002), 1,
      sym__simple_type,
    STATE(5067), 1,
      sym_identifier,
    STATE(5176), 1,
      sym__soft_identifier,
    STATE(7967), 1,
      sym_annotated_type,
    STATE(10369), 1,
      sym_literal_type,
    STATE(10429), 1,
      sym__non_null_literal,
    STATE(12460), 1,
      sym__infix_type_choice,
    STATE(13053), 1,
      sym__type,
    STATE(13199), 1,
      sym_template_body,
    STATE(15231), 1,
      sym_parameter_types,
    STATE(16905), 1,
      sym_stable_identifier,
    ACTIONS(4688), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4690), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4694), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3715), 2,
      sym_comment,
      sym_block_comment,
    STATE(9523), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10326), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13289), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13116), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4676), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5890), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [168538] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14830), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3716), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [168659] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14833), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3717), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [168780] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(13708), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3718), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [168901] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14839), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3719), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [169022] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14840), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3720), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [169143] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1720), 1,
      sym_integer_literal,
    ACTIONS(6712), 1,
      sym__alpha_identifier,
    ACTIONS(6714), 1,
      anon_sym_COLON,
    ACTIONS(6716), 1,
      anon_sym_LBRACE,
    ACTIONS(6718), 1,
      anon_sym__,
    ACTIONS(6720), 1,
      anon_sym_LBRACK,
    ACTIONS(6724), 1,
      anon_sym_LPAREN,
    ACTIONS(6726), 1,
      sym__backquoted_id,
    ACTIONS(6728), 1,
      sym_operator_identifier,
    STATE(5508), 1,
      sym__annotated_type,
    STATE(5977), 1,
      sym__simple_type,
    STATE(6378), 1,
      sym__soft_identifier,
    STATE(6583), 1,
      sym_identifier,
    STATE(9268), 1,
      sym_annotated_type,
    STATE(10726), 1,
      sym__non_null_literal,
    STATE(10755), 1,
      sym_literal_type,
    STATE(12542), 1,
      sym__infix_type_choice,
    STATE(13491), 1,
      sym__type,
    STATE(13617), 1,
      sym_template_body,
    STATE(15031), 1,
      sym_parameter_types,
    STATE(17227), 1,
      sym_stable_identifier,
    ACTIONS(1722), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1724), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1728), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3721), 2,
      sym_comment,
      sym_block_comment,
    STATE(8768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9082), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10246), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13417), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6722), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7014), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [169264] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6832), 1,
      anon_sym_COLON,
    ACTIONS(6834), 1,
      anon_sym_LBRACE,
    ACTIONS(6836), 1,
      anon_sym__,
    ACTIONS(6838), 1,
      anon_sym_LBRACK,
    ACTIONS(6842), 1,
      anon_sym_LPAREN,
    ACTIONS(6844), 1,
      sym__backquoted_id,
    ACTIONS(6846), 1,
      sym_operator_identifier,
    ACTIONS(6848), 1,
      sym_integer_literal,
    STATE(8371), 1,
      sym__simple_type,
    STATE(8809), 1,
      sym__soft_identifier,
    STATE(8868), 1,
      sym_identifier,
    STATE(9195), 1,
      sym__annotated_type,
    STATE(10851), 1,
      sym_annotated_type,
    STATE(12356), 1,
      sym_literal_type,
    STATE(12487), 1,
      sym__non_null_literal,
    STATE(12538), 1,
      sym__infix_type_choice,
    STATE(15219), 1,
      sym_parameter_types,
    STATE(15945), 1,
      sym_template_body,
    STATE(16068), 1,
      sym__type,
    STATE(17197), 1,
      sym_stable_identifier,
    ACTIONS(6850), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6852), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6854), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3722), 2,
      sym_comment,
      sym_block_comment,
    STATE(11571), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11704), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12601), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16097), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6840), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9436), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [169385] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14845), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3723), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [169506] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14846), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3724), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [169627] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4470), 1,
      anon_sym_COLON,
    ACTIONS(4472), 1,
      anon_sym_LBRACE,
    ACTIONS(4510), 1,
      sym__alpha_identifier,
    ACTIONS(4512), 1,
      anon_sym__,
    ACTIONS(4516), 1,
      anon_sym_LBRACK,
    ACTIONS(4522), 1,
      sym__backquoted_id,
    ACTIONS(4526), 1,
      sym_integer_literal,
    ACTIONS(6882), 1,
      anon_sym_LPAREN,
    ACTIONS(6884), 1,
      sym_operator_identifier,
    STATE(4536), 1,
      sym__annotated_type,
    STATE(4538), 1,
      sym__simple_type,
    STATE(4572), 1,
      sym__soft_identifier,
    STATE(4611), 1,
      sym_identifier,
    STATE(6644), 1,
      sym_annotated_type,
    STATE(9406), 1,
      sym_literal_type,
    STATE(9524), 1,
      sym__non_null_literal,
    STATE(11868), 1,
      sym_template_body,
    STATE(11991), 1,
      sym__type,
    STATE(12448), 1,
      sym__infix_type_choice,
    STATE(15022), 1,
      sym_parameter_types,
    STATE(16708), 1,
      sym_stable_identifier,
    ACTIONS(4528), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4530), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4534), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3725), 2,
      sym_comment,
      sym_block_comment,
    STATE(8135), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9713), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12157), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4518), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4978), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [169748] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14853), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3726), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [169869] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14855), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3727), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [169990] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15296), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3728), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [170111] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1720), 1,
      sym_integer_literal,
    ACTIONS(6712), 1,
      sym__alpha_identifier,
    ACTIONS(6714), 1,
      anon_sym_COLON,
    ACTIONS(6716), 1,
      anon_sym_LBRACE,
    ACTIONS(6718), 1,
      anon_sym__,
    ACTIONS(6720), 1,
      anon_sym_LBRACK,
    ACTIONS(6724), 1,
      anon_sym_LPAREN,
    ACTIONS(6726), 1,
      sym__backquoted_id,
    ACTIONS(6728), 1,
      sym_operator_identifier,
    STATE(5508), 1,
      sym__annotated_type,
    STATE(5977), 1,
      sym__simple_type,
    STATE(6378), 1,
      sym__soft_identifier,
    STATE(6583), 1,
      sym_identifier,
    STATE(9268), 1,
      sym_annotated_type,
    STATE(10726), 1,
      sym__non_null_literal,
    STATE(10755), 1,
      sym_literal_type,
    STATE(12542), 1,
      sym__infix_type_choice,
    STATE(13547), 1,
      sym__type,
    STATE(13617), 1,
      sym_template_body,
    STATE(15031), 1,
      sym_parameter_types,
    STATE(17227), 1,
      sym_stable_identifier,
    ACTIONS(1722), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1724), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1728), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3729), 2,
      sym_comment,
      sym_block_comment,
    STATE(8768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9082), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10246), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13417), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6722), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7014), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [170232] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1720), 1,
      sym_integer_literal,
    ACTIONS(6712), 1,
      sym__alpha_identifier,
    ACTIONS(6714), 1,
      anon_sym_COLON,
    ACTIONS(6716), 1,
      anon_sym_LBRACE,
    ACTIONS(6718), 1,
      anon_sym__,
    ACTIONS(6720), 1,
      anon_sym_LBRACK,
    ACTIONS(6724), 1,
      anon_sym_LPAREN,
    ACTIONS(6726), 1,
      sym__backquoted_id,
    ACTIONS(6728), 1,
      sym_operator_identifier,
    STATE(5508), 1,
      sym__annotated_type,
    STATE(5977), 1,
      sym__simple_type,
    STATE(6378), 1,
      sym__soft_identifier,
    STATE(6583), 1,
      sym_identifier,
    STATE(9268), 1,
      sym_annotated_type,
    STATE(10726), 1,
      sym__non_null_literal,
    STATE(10755), 1,
      sym_literal_type,
    STATE(12542), 1,
      sym__infix_type_choice,
    STATE(13550), 1,
      sym__type,
    STATE(13617), 1,
      sym_template_body,
    STATE(15031), 1,
      sym_parameter_types,
    STATE(17227), 1,
      sym_stable_identifier,
    ACTIONS(1722), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1724), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1728), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3730), 2,
      sym_comment,
      sym_block_comment,
    STATE(8768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9082), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10246), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13417), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6722), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7014), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [170353] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14862), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3731), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [170474] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14863), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3732), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [170595] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1720), 1,
      sym_integer_literal,
    ACTIONS(6712), 1,
      sym__alpha_identifier,
    ACTIONS(6714), 1,
      anon_sym_COLON,
    ACTIONS(6716), 1,
      anon_sym_LBRACE,
    ACTIONS(6718), 1,
      anon_sym__,
    ACTIONS(6720), 1,
      anon_sym_LBRACK,
    ACTIONS(6724), 1,
      anon_sym_LPAREN,
    ACTIONS(6726), 1,
      sym__backquoted_id,
    ACTIONS(6728), 1,
      sym_operator_identifier,
    STATE(5508), 1,
      sym__annotated_type,
    STATE(5977), 1,
      sym__simple_type,
    STATE(6378), 1,
      sym__soft_identifier,
    STATE(6583), 1,
      sym_identifier,
    STATE(9268), 1,
      sym_annotated_type,
    STATE(10726), 1,
      sym__non_null_literal,
    STATE(10755), 1,
      sym_literal_type,
    STATE(12542), 1,
      sym__infix_type_choice,
    STATE(13551), 1,
      sym__type,
    STATE(13617), 1,
      sym_template_body,
    STATE(15031), 1,
      sym_parameter_types,
    STATE(17227), 1,
      sym_stable_identifier,
    ACTIONS(1722), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1724), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1728), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3733), 2,
      sym_comment,
      sym_block_comment,
    STATE(8768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9082), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10246), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13417), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6722), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7014), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [170716] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1720), 1,
      sym_integer_literal,
    ACTIONS(6712), 1,
      sym__alpha_identifier,
    ACTIONS(6714), 1,
      anon_sym_COLON,
    ACTIONS(6716), 1,
      anon_sym_LBRACE,
    ACTIONS(6718), 1,
      anon_sym__,
    ACTIONS(6720), 1,
      anon_sym_LBRACK,
    ACTIONS(6724), 1,
      anon_sym_LPAREN,
    ACTIONS(6726), 1,
      sym__backquoted_id,
    ACTIONS(6728), 1,
      sym_operator_identifier,
    STATE(5508), 1,
      sym__annotated_type,
    STATE(5977), 1,
      sym__simple_type,
    STATE(6378), 1,
      sym__soft_identifier,
    STATE(6583), 1,
      sym_identifier,
    STATE(9268), 1,
      sym_annotated_type,
    STATE(10726), 1,
      sym__non_null_literal,
    STATE(10755), 1,
      sym_literal_type,
    STATE(12542), 1,
      sym__infix_type_choice,
    STATE(13552), 1,
      sym__type,
    STATE(13617), 1,
      sym_template_body,
    STATE(15031), 1,
      sym_parameter_types,
    STATE(17227), 1,
      sym_stable_identifier,
    ACTIONS(1722), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1724), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1728), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3734), 2,
      sym_comment,
      sym_block_comment,
    STATE(8768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9082), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10246), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13417), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6722), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7014), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [170837] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4470), 1,
      anon_sym_COLON,
    ACTIONS(4472), 1,
      anon_sym_LBRACE,
    ACTIONS(4510), 1,
      sym__alpha_identifier,
    ACTIONS(4512), 1,
      anon_sym__,
    ACTIONS(4516), 1,
      anon_sym_LBRACK,
    ACTIONS(4522), 1,
      sym__backquoted_id,
    ACTIONS(4526), 1,
      sym_integer_literal,
    ACTIONS(6882), 1,
      anon_sym_LPAREN,
    ACTIONS(6884), 1,
      sym_operator_identifier,
    STATE(4536), 1,
      sym__annotated_type,
    STATE(4538), 1,
      sym__simple_type,
    STATE(4572), 1,
      sym__soft_identifier,
    STATE(4611), 1,
      sym_identifier,
    STATE(6644), 1,
      sym_annotated_type,
    STATE(9406), 1,
      sym_literal_type,
    STATE(9524), 1,
      sym__non_null_literal,
    STATE(11868), 1,
      sym_template_body,
    STATE(12007), 1,
      sym__type,
    STATE(12448), 1,
      sym__infix_type_choice,
    STATE(15022), 1,
      sym_parameter_types,
    STATE(16708), 1,
      sym_stable_identifier,
    ACTIONS(4528), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4530), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4534), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3735), 2,
      sym_comment,
      sym_block_comment,
    STATE(8135), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9713), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12157), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4518), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4978), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [170958] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14869), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3736), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [171079] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14871), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3737), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [171200] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4470), 1,
      anon_sym_COLON,
    ACTIONS(4472), 1,
      anon_sym_LBRACE,
    ACTIONS(4510), 1,
      sym__alpha_identifier,
    ACTIONS(4512), 1,
      anon_sym__,
    ACTIONS(4516), 1,
      anon_sym_LBRACK,
    ACTIONS(4522), 1,
      sym__backquoted_id,
    ACTIONS(4526), 1,
      sym_integer_literal,
    ACTIONS(6882), 1,
      anon_sym_LPAREN,
    ACTIONS(6884), 1,
      sym_operator_identifier,
    STATE(4536), 1,
      sym__annotated_type,
    STATE(4538), 1,
      sym__simple_type,
    STATE(4572), 1,
      sym__soft_identifier,
    STATE(4611), 1,
      sym_identifier,
    STATE(6644), 1,
      sym_annotated_type,
    STATE(9406), 1,
      sym_literal_type,
    STATE(9524), 1,
      sym__non_null_literal,
    STATE(11868), 1,
      sym_template_body,
    STATE(12010), 1,
      sym__type,
    STATE(12448), 1,
      sym__infix_type_choice,
    STATE(15022), 1,
      sym_parameter_types,
    STATE(16708), 1,
      sym_stable_identifier,
    ACTIONS(4528), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4530), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4534), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3738), 2,
      sym_comment,
      sym_block_comment,
    STATE(8135), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9713), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12157), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4518), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4978), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [171321] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4470), 1,
      anon_sym_COLON,
    ACTIONS(4472), 1,
      anon_sym_LBRACE,
    ACTIONS(4510), 1,
      sym__alpha_identifier,
    ACTIONS(4512), 1,
      anon_sym__,
    ACTIONS(4516), 1,
      anon_sym_LBRACK,
    ACTIONS(4522), 1,
      sym__backquoted_id,
    ACTIONS(4526), 1,
      sym_integer_literal,
    ACTIONS(6882), 1,
      anon_sym_LPAREN,
    ACTIONS(6884), 1,
      sym_operator_identifier,
    STATE(4536), 1,
      sym__annotated_type,
    STATE(4538), 1,
      sym__simple_type,
    STATE(4572), 1,
      sym__soft_identifier,
    STATE(4611), 1,
      sym_identifier,
    STATE(6644), 1,
      sym_annotated_type,
    STATE(9406), 1,
      sym_literal_type,
    STATE(9524), 1,
      sym__non_null_literal,
    STATE(11868), 1,
      sym_template_body,
    STATE(12013), 1,
      sym__type,
    STATE(12448), 1,
      sym__infix_type_choice,
    STATE(15022), 1,
      sym_parameter_types,
    STATE(16708), 1,
      sym_stable_identifier,
    ACTIONS(4528), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4530), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4534), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3739), 2,
      sym_comment,
      sym_block_comment,
    STATE(8135), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9713), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12157), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4518), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4978), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [171442] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4470), 1,
      anon_sym_COLON,
    ACTIONS(4472), 1,
      anon_sym_LBRACE,
    ACTIONS(4510), 1,
      sym__alpha_identifier,
    ACTIONS(4512), 1,
      anon_sym__,
    ACTIONS(4516), 1,
      anon_sym_LBRACK,
    ACTIONS(4522), 1,
      sym__backquoted_id,
    ACTIONS(4526), 1,
      sym_integer_literal,
    ACTIONS(6882), 1,
      anon_sym_LPAREN,
    ACTIONS(6884), 1,
      sym_operator_identifier,
    STATE(4536), 1,
      sym__annotated_type,
    STATE(4538), 1,
      sym__simple_type,
    STATE(4572), 1,
      sym__soft_identifier,
    STATE(4611), 1,
      sym_identifier,
    STATE(6644), 1,
      sym_annotated_type,
    STATE(9406), 1,
      sym_literal_type,
    STATE(9524), 1,
      sym__non_null_literal,
    STATE(11868), 1,
      sym_template_body,
    STATE(12014), 1,
      sym__type,
    STATE(12448), 1,
      sym__infix_type_choice,
    STATE(15022), 1,
      sym_parameter_types,
    STATE(16708), 1,
      sym_stable_identifier,
    ACTIONS(4528), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4530), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4534), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3740), 2,
      sym_comment,
      sym_block_comment,
    STATE(8135), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9713), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12157), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4518), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4978), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [171563] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14875), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3741), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [171684] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14876), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3742), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [171805] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8476), 1,
      sym__type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3743), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [171926] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(4140), 1,
      anon_sym_COLON,
    ACTIONS(4142), 1,
      anon_sym_LBRACE,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6250), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(12989), 1,
      sym__type,
    STATE(15060), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3744), 2,
      sym_comment,
      sym_block_comment,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12971), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [172047] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4664), 1,
      sym__alpha_identifier,
    ACTIONS(4666), 1,
      anon_sym_COLON,
    ACTIONS(4668), 1,
      anon_sym_LBRACE,
    ACTIONS(4670), 1,
      anon_sym__,
    ACTIONS(4674), 1,
      anon_sym_LBRACK,
    ACTIONS(4682), 1,
      sym__backquoted_id,
    ACTIONS(4686), 1,
      sym_integer_literal,
    ACTIONS(6542), 1,
      anon_sym_LPAREN,
    ACTIONS(6544), 1,
      sym_operator_identifier,
    STATE(4972), 1,
      sym__annotated_type,
    STATE(5002), 1,
      sym__simple_type,
    STATE(5067), 1,
      sym_identifier,
    STATE(5176), 1,
      sym__soft_identifier,
    STATE(7967), 1,
      sym_annotated_type,
    STATE(10369), 1,
      sym_literal_type,
    STATE(10429), 1,
      sym__non_null_literal,
    STATE(12460), 1,
      sym__infix_type_choice,
    STATE(13056), 1,
      sym__type,
    STATE(13199), 1,
      sym_template_body,
    STATE(15231), 1,
      sym_parameter_types,
    STATE(16905), 1,
      sym_stable_identifier,
    ACTIONS(4688), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4690), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4694), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3745), 2,
      sym_comment,
      sym_block_comment,
    STATE(9523), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10326), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13289), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13116), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4676), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5890), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [172168] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14882), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3746), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [172289] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14883), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3747), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [172410] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4820), 1,
      sym__alpha_identifier,
    ACTIONS(4822), 1,
      anon_sym_COLON,
    ACTIONS(4824), 1,
      anon_sym_LBRACE,
    ACTIONS(4826), 1,
      anon_sym__,
    ACTIONS(4830), 1,
      anon_sym_LBRACK,
    ACTIONS(4838), 1,
      sym__backquoted_id,
    ACTIONS(4842), 1,
      sym_integer_literal,
    ACTIONS(6886), 1,
      anon_sym_LPAREN,
    ACTIONS(6888), 1,
      sym_operator_identifier,
    STATE(4479), 1,
      sym__simple_type,
    STATE(4564), 1,
      sym__annotated_type,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(4630), 1,
      sym_identifier,
    STATE(5999), 1,
      sym_annotated_type,
    STATE(9362), 1,
      sym__non_null_literal,
    STATE(9672), 1,
      sym_literal_type,
    STATE(12175), 1,
      sym__type,
    STATE(12259), 1,
      sym_template_body,
    STATE(12488), 1,
      sym__infix_type_choice,
    STATE(14829), 1,
      sym_parameter_types,
    STATE(17030), 1,
      sym_stable_identifier,
    ACTIONS(4844), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4846), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4850), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3748), 2,
      sym_comment,
      sym_block_comment,
    STATE(8521), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9588), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12383), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12509), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4832), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4830), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [172531] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14888), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3749), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [172652] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14891), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3750), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [172773] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6414), 1,
      anon_sym_COLON,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(6418), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(14600), 1,
      sym__type,
    STATE(15021), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3751), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [172894] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1664), 1,
      sym_integer_literal,
    ACTIONS(6740), 1,
      sym__alpha_identifier,
    ACTIONS(6742), 1,
      anon_sym_COLON,
    ACTIONS(6744), 1,
      anon_sym_LBRACE,
    ACTIONS(6746), 1,
      anon_sym__,
    ACTIONS(6748), 1,
      anon_sym_LBRACK,
    ACTIONS(6752), 1,
      anon_sym_LPAREN,
    ACTIONS(6754), 1,
      sym__backquoted_id,
    ACTIONS(6756), 1,
      sym_operator_identifier,
    STATE(6197), 1,
      sym__simple_type,
    STATE(6256), 1,
      sym__annotated_type,
    STATE(6959), 1,
      sym_identifier,
    STATE(7274), 1,
      sym__soft_identifier,
    STATE(9511), 1,
      sym_annotated_type,
    STATE(11029), 1,
      sym_literal_type,
    STATE(11085), 1,
      sym__non_null_literal,
    STATE(11505), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12544), 1,
      sym__infix_type_choice,
    STATE(15064), 1,
      sym_parameter_types,
    STATE(17239), 1,
      sym_stable_identifier,
    ACTIONS(1666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1672), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3752), 2,
      sym_comment,
      sym_block_comment,
    STATE(5571), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9685), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10483), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6750), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7605), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [173015] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4820), 1,
      sym__alpha_identifier,
    ACTIONS(4822), 1,
      anon_sym_COLON,
    ACTIONS(4824), 1,
      anon_sym_LBRACE,
    ACTIONS(4826), 1,
      anon_sym__,
    ACTIONS(4830), 1,
      anon_sym_LBRACK,
    ACTIONS(4838), 1,
      sym__backquoted_id,
    ACTIONS(4842), 1,
      sym_integer_literal,
    ACTIONS(6886), 1,
      anon_sym_LPAREN,
    ACTIONS(6888), 1,
      sym_operator_identifier,
    STATE(4479), 1,
      sym__simple_type,
    STATE(4564), 1,
      sym__annotated_type,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(4630), 1,
      sym_identifier,
    STATE(5999), 1,
      sym_annotated_type,
    STATE(9362), 1,
      sym__non_null_literal,
    STATE(9672), 1,
      sym_literal_type,
    STATE(12177), 1,
      sym__type,
    STATE(12259), 1,
      sym_template_body,
    STATE(12488), 1,
      sym__infix_type_choice,
    STATE(14829), 1,
      sym_parameter_types,
    STATE(17030), 1,
      sym_stable_identifier,
    ACTIONS(4844), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4846), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4850), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3753), 2,
      sym_comment,
      sym_block_comment,
    STATE(8521), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9588), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12383), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12509), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4832), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4830), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [173136] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14895), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3754), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [173257] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14896), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3755), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [173378] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(958), 1,
      sym_integer_literal,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6868), 1,
      sym__alpha_identifier,
    ACTIONS(6870), 1,
      anon_sym__,
    ACTIONS(6872), 1,
      anon_sym_LBRACK,
    ACTIONS(6876), 1,
      anon_sym_LPAREN,
    ACTIONS(6878), 1,
      sym__backquoted_id,
    ACTIONS(6880), 1,
      sym_operator_identifier,
    STATE(4537), 1,
      sym__annotated_type,
    STATE(4541), 1,
      sym__simple_type,
    STATE(4620), 1,
      sym__soft_identifier,
    STATE(4757), 1,
      sym_identifier,
    STATE(6245), 1,
      sym_annotated_type,
    STATE(9435), 1,
      sym_literal_type,
    STATE(9542), 1,
      sym__non_null_literal,
    STATE(11501), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12450), 1,
      sym__infix_type_choice,
    STATE(15086), 1,
      sym_parameter_types,
    STATE(16746), 1,
      sym_stable_identifier,
    ACTIONS(960), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(962), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(966), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3756), 2,
      sym_comment,
      sym_block_comment,
    STATE(5972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6215), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8289), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6874), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4890), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [173499] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4820), 1,
      sym__alpha_identifier,
    ACTIONS(4822), 1,
      anon_sym_COLON,
    ACTIONS(4824), 1,
      anon_sym_LBRACE,
    ACTIONS(4826), 1,
      anon_sym__,
    ACTIONS(4830), 1,
      anon_sym_LBRACK,
    ACTIONS(4838), 1,
      sym__backquoted_id,
    ACTIONS(4842), 1,
      sym_integer_literal,
    ACTIONS(6886), 1,
      anon_sym_LPAREN,
    ACTIONS(6888), 1,
      sym_operator_identifier,
    STATE(4479), 1,
      sym__simple_type,
    STATE(4564), 1,
      sym__annotated_type,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(4630), 1,
      sym_identifier,
    STATE(5999), 1,
      sym_annotated_type,
    STATE(9362), 1,
      sym__non_null_literal,
    STATE(9672), 1,
      sym_literal_type,
    STATE(12179), 1,
      sym__type,
    STATE(12259), 1,
      sym_template_body,
    STATE(12488), 1,
      sym__infix_type_choice,
    STATE(14829), 1,
      sym_parameter_types,
    STATE(17030), 1,
      sym_stable_identifier,
    ACTIONS(4844), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4846), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4850), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3757), 2,
      sym_comment,
      sym_block_comment,
    STATE(8521), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9588), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12383), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12509), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4832), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4830), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [173620] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14903), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3758), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [173741] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14904), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3759), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [173862] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4820), 1,
      sym__alpha_identifier,
    ACTIONS(4822), 1,
      anon_sym_COLON,
    ACTIONS(4824), 1,
      anon_sym_LBRACE,
    ACTIONS(4826), 1,
      anon_sym__,
    ACTIONS(4830), 1,
      anon_sym_LBRACK,
    ACTIONS(4838), 1,
      sym__backquoted_id,
    ACTIONS(4842), 1,
      sym_integer_literal,
    ACTIONS(6886), 1,
      anon_sym_LPAREN,
    ACTIONS(6888), 1,
      sym_operator_identifier,
    STATE(4479), 1,
      sym__simple_type,
    STATE(4564), 1,
      sym__annotated_type,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(4630), 1,
      sym_identifier,
    STATE(5999), 1,
      sym_annotated_type,
    STATE(9362), 1,
      sym__non_null_literal,
    STATE(9672), 1,
      sym_literal_type,
    STATE(12180), 1,
      sym__type,
    STATE(12259), 1,
      sym_template_body,
    STATE(12488), 1,
      sym__infix_type_choice,
    STATE(14829), 1,
      sym_parameter_types,
    STATE(17030), 1,
      sym_stable_identifier,
    ACTIONS(4844), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4846), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4850), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3760), 2,
      sym_comment,
      sym_block_comment,
    STATE(8521), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9588), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12383), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12509), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4832), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4830), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [173983] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1664), 1,
      sym_integer_literal,
    ACTIONS(6740), 1,
      sym__alpha_identifier,
    ACTIONS(6742), 1,
      anon_sym_COLON,
    ACTIONS(6744), 1,
      anon_sym_LBRACE,
    ACTIONS(6746), 1,
      anon_sym__,
    ACTIONS(6748), 1,
      anon_sym_LBRACK,
    ACTIONS(6752), 1,
      anon_sym_LPAREN,
    ACTIONS(6754), 1,
      sym__backquoted_id,
    ACTIONS(6756), 1,
      sym_operator_identifier,
    STATE(6197), 1,
      sym__simple_type,
    STATE(6256), 1,
      sym__annotated_type,
    STATE(6959), 1,
      sym_identifier,
    STATE(7274), 1,
      sym__soft_identifier,
    STATE(9511), 1,
      sym_annotated_type,
    STATE(11029), 1,
      sym_literal_type,
    STATE(11085), 1,
      sym__non_null_literal,
    STATE(11489), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12544), 1,
      sym__infix_type_choice,
    STATE(15064), 1,
      sym_parameter_types,
    STATE(17239), 1,
      sym_stable_identifier,
    ACTIONS(1666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1672), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3761), 2,
      sym_comment,
      sym_block_comment,
    STATE(5571), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9685), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10483), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6750), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7605), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [174104] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1664), 1,
      sym_integer_literal,
    ACTIONS(6740), 1,
      sym__alpha_identifier,
    ACTIONS(6742), 1,
      anon_sym_COLON,
    ACTIONS(6744), 1,
      anon_sym_LBRACE,
    ACTIONS(6746), 1,
      anon_sym__,
    ACTIONS(6748), 1,
      anon_sym_LBRACK,
    ACTIONS(6752), 1,
      anon_sym_LPAREN,
    ACTIONS(6754), 1,
      sym__backquoted_id,
    ACTIONS(6756), 1,
      sym_operator_identifier,
    STATE(6197), 1,
      sym__simple_type,
    STATE(6256), 1,
      sym__annotated_type,
    STATE(6959), 1,
      sym_identifier,
    STATE(7274), 1,
      sym__soft_identifier,
    STATE(9511), 1,
      sym_annotated_type,
    STATE(11029), 1,
      sym_literal_type,
    STATE(11085), 1,
      sym__non_null_literal,
    STATE(11491), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12544), 1,
      sym__infix_type_choice,
    STATE(15064), 1,
      sym_parameter_types,
    STATE(17239), 1,
      sym_stable_identifier,
    ACTIONS(1666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1672), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3762), 2,
      sym_comment,
      sym_block_comment,
    STATE(5571), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9685), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10483), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6750), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7605), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [174225] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14907), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3763), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [174346] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(958), 1,
      sym_integer_literal,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6868), 1,
      sym__alpha_identifier,
    ACTIONS(6870), 1,
      anon_sym__,
    ACTIONS(6872), 1,
      anon_sym_LBRACK,
    ACTIONS(6876), 1,
      anon_sym_LPAREN,
    ACTIONS(6878), 1,
      sym__backquoted_id,
    ACTIONS(6880), 1,
      sym_operator_identifier,
    STATE(4537), 1,
      sym__annotated_type,
    STATE(4541), 1,
      sym__simple_type,
    STATE(4620), 1,
      sym__soft_identifier,
    STATE(4757), 1,
      sym_identifier,
    STATE(6245), 1,
      sym_annotated_type,
    STATE(9435), 1,
      sym_literal_type,
    STATE(9542), 1,
      sym__non_null_literal,
    STATE(11533), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12450), 1,
      sym__infix_type_choice,
    STATE(15086), 1,
      sym_parameter_types,
    STATE(16746), 1,
      sym_stable_identifier,
    ACTIONS(960), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(962), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(966), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3764), 2,
      sym_comment,
      sym_block_comment,
    STATE(5972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6215), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8289), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6874), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4890), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [174467] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(958), 1,
      sym_integer_literal,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6868), 1,
      sym__alpha_identifier,
    ACTIONS(6870), 1,
      anon_sym__,
    ACTIONS(6872), 1,
      anon_sym_LBRACK,
    ACTIONS(6876), 1,
      anon_sym_LPAREN,
    ACTIONS(6878), 1,
      sym__backquoted_id,
    ACTIONS(6880), 1,
      sym_operator_identifier,
    STATE(4537), 1,
      sym__annotated_type,
    STATE(4541), 1,
      sym__simple_type,
    STATE(4620), 1,
      sym__soft_identifier,
    STATE(4757), 1,
      sym_identifier,
    STATE(6245), 1,
      sym_annotated_type,
    STATE(9435), 1,
      sym_literal_type,
    STATE(9542), 1,
      sym__non_null_literal,
    STATE(11536), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12450), 1,
      sym__infix_type_choice,
    STATE(15086), 1,
      sym_parameter_types,
    STATE(16746), 1,
      sym_stable_identifier,
    ACTIONS(960), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(962), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(966), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3765), 2,
      sym_comment,
      sym_block_comment,
    STATE(5972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6215), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8289), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6874), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4890), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [174588] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14912), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3766), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [174709] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(958), 1,
      sym_integer_literal,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6868), 1,
      sym__alpha_identifier,
    ACTIONS(6870), 1,
      anon_sym__,
    ACTIONS(6872), 1,
      anon_sym_LBRACK,
    ACTIONS(6876), 1,
      anon_sym_LPAREN,
    ACTIONS(6878), 1,
      sym__backquoted_id,
    ACTIONS(6880), 1,
      sym_operator_identifier,
    STATE(4537), 1,
      sym__annotated_type,
    STATE(4541), 1,
      sym__simple_type,
    STATE(4620), 1,
      sym__soft_identifier,
    STATE(4757), 1,
      sym_identifier,
    STATE(6245), 1,
      sym_annotated_type,
    STATE(9435), 1,
      sym_literal_type,
    STATE(9542), 1,
      sym__non_null_literal,
    STATE(11537), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12450), 1,
      sym__infix_type_choice,
    STATE(15086), 1,
      sym_parameter_types,
    STATE(16746), 1,
      sym_stable_identifier,
    ACTIONS(960), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(962), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(966), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3767), 2,
      sym_comment,
      sym_block_comment,
    STATE(5972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6215), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8289), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6874), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4890), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [174830] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(958), 1,
      sym_integer_literal,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6868), 1,
      sym__alpha_identifier,
    ACTIONS(6870), 1,
      anon_sym__,
    ACTIONS(6872), 1,
      anon_sym_LBRACK,
    ACTIONS(6876), 1,
      anon_sym_LPAREN,
    ACTIONS(6878), 1,
      sym__backquoted_id,
    ACTIONS(6880), 1,
      sym_operator_identifier,
    STATE(4537), 1,
      sym__annotated_type,
    STATE(4541), 1,
      sym__simple_type,
    STATE(4620), 1,
      sym__soft_identifier,
    STATE(4757), 1,
      sym_identifier,
    STATE(6245), 1,
      sym_annotated_type,
    STATE(9435), 1,
      sym_literal_type,
    STATE(9542), 1,
      sym__non_null_literal,
    STATE(11538), 1,
      sym__type,
    STATE(11707), 1,
      sym_template_body,
    STATE(12450), 1,
      sym__infix_type_choice,
    STATE(15086), 1,
      sym_parameter_types,
    STATE(16746), 1,
      sym_stable_identifier,
    ACTIONS(960), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(962), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(966), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3768), 2,
      sym_comment,
      sym_block_comment,
    STATE(5972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6215), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8289), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11654), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6874), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4890), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [174951] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1664), 1,
      sym_integer_literal,
    ACTIONS(6740), 1,
      sym__alpha_identifier,
    ACTIONS(6742), 1,
      anon_sym_COLON,
    ACTIONS(6744), 1,
      anon_sym_LBRACE,
    ACTIONS(6746), 1,
      anon_sym__,
    ACTIONS(6748), 1,
      anon_sym_LBRACK,
    ACTIONS(6752), 1,
      anon_sym_LPAREN,
    ACTIONS(6754), 1,
      sym__backquoted_id,
    ACTIONS(6756), 1,
      sym_operator_identifier,
    STATE(6197), 1,
      sym__simple_type,
    STATE(6256), 1,
      sym__annotated_type,
    STATE(6959), 1,
      sym_identifier,
    STATE(7274), 1,
      sym__soft_identifier,
    STATE(9511), 1,
      sym_annotated_type,
    STATE(11029), 1,
      sym_literal_type,
    STATE(11085), 1,
      sym__non_null_literal,
    STATE(11492), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12544), 1,
      sym__infix_type_choice,
    STATE(15064), 1,
      sym_parameter_types,
    STATE(17239), 1,
      sym_stable_identifier,
    ACTIONS(1666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1672), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3769), 2,
      sym_comment,
      sym_block_comment,
    STATE(5571), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9685), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10483), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6750), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7605), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [175072] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14917), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3770), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [175193] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6414), 1,
      anon_sym_COLON,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(6418), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(14604), 1,
      sym__type,
    STATE(15021), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3771), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [175314] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6414), 1,
      anon_sym_COLON,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(6418), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(14608), 1,
      sym__type,
    STATE(15021), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3772), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [175435] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14919), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3773), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [175556] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6414), 1,
      anon_sym_COLON,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(6418), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(14611), 1,
      sym__type,
    STATE(15021), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3774), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [175677] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14923), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3775), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [175798] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(541), 1,
      sym_integer_literal,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6186), 1,
      anon_sym_LPAREN,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(6414), 1,
      anon_sym_COLON,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(6418), 1,
      anon_sym_LBRACK,
    STATE(5873), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(10504), 1,
      sym__non_null_literal,
    STATE(10540), 1,
      sym_literal_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(12462), 1,
      sym__infix_type_choice,
    STATE(14628), 1,
      sym__type,
    STATE(15021), 1,
      sym_parameter_types,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(543), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(545), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(555), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3776), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9490), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9817), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12937), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [175919] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14926), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3777), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [176040] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4540), 1,
      sym__alpha_identifier,
    ACTIONS(4542), 1,
      anon_sym_COLON,
    ACTIONS(4544), 1,
      anon_sym_LBRACE,
    ACTIONS(4546), 1,
      anon_sym__,
    ACTIONS(4550), 1,
      anon_sym_LBRACK,
    ACTIONS(4558), 1,
      sym__backquoted_id,
    ACTIONS(4562), 1,
      sym_integer_literal,
    ACTIONS(6890), 1,
      anon_sym_LPAREN,
    ACTIONS(6892), 1,
      sym_operator_identifier,
    STATE(4958), 1,
      sym__annotated_type,
    STATE(4984), 1,
      sym__simple_type,
    STATE(5050), 1,
      sym_identifier,
    STATE(5155), 1,
      sym__soft_identifier,
    STATE(7631), 1,
      sym_annotated_type,
    STATE(10262), 1,
      sym__non_null_literal,
    STATE(10394), 1,
      sym_literal_type,
    STATE(12452), 1,
      sym__infix_type_choice,
    STATE(13138), 1,
      sym_template_body,
    STATE(13158), 1,
      sym__type,
    STATE(15013), 1,
      sym_parameter_types,
    STATE(16782), 1,
      sym_stable_identifier,
    ACTIONS(4564), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4566), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4570), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3778), 2,
      sym_comment,
      sym_block_comment,
    STATE(9468), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10280), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13185), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13212), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5928), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [176161] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14928), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3779), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [176282] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1664), 1,
      sym_integer_literal,
    ACTIONS(6740), 1,
      sym__alpha_identifier,
    ACTIONS(6742), 1,
      anon_sym_COLON,
    ACTIONS(6744), 1,
      anon_sym_LBRACE,
    ACTIONS(6746), 1,
      anon_sym__,
    ACTIONS(6748), 1,
      anon_sym_LBRACK,
    ACTIONS(6752), 1,
      anon_sym_LPAREN,
    ACTIONS(6754), 1,
      sym__backquoted_id,
    ACTIONS(6756), 1,
      sym_operator_identifier,
    STATE(6197), 1,
      sym__simple_type,
    STATE(6256), 1,
      sym__annotated_type,
    STATE(6959), 1,
      sym_identifier,
    STATE(7274), 1,
      sym__soft_identifier,
    STATE(9511), 1,
      sym_annotated_type,
    STATE(11029), 1,
      sym_literal_type,
    STATE(11085), 1,
      sym__non_null_literal,
    STATE(11493), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12544), 1,
      sym__infix_type_choice,
    STATE(15064), 1,
      sym_parameter_types,
    STATE(17239), 1,
      sym_stable_identifier,
    ACTIONS(1666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1672), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3780), 2,
      sym_comment,
      sym_block_comment,
    STATE(5571), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9685), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10483), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6750), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7605), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [176403] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14932), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3781), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [176524] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6218), 1,
      anon_sym_LBRACK,
    ACTIONS(6222), 1,
      anon_sym_LPAREN,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    STATE(6711), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11064), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym_literal_type,
    STATE(12357), 1,
      sym__infix_type_choice,
    STATE(14263), 1,
      sym__type,
    STATE(15570), 1,
      sym_parameter_types,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3782), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10455), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [176645] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14936), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3783), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [176766] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14938), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3784), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [176887] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4540), 1,
      sym__alpha_identifier,
    ACTIONS(4542), 1,
      anon_sym_COLON,
    ACTIONS(4544), 1,
      anon_sym_LBRACE,
    ACTIONS(4546), 1,
      anon_sym__,
    ACTIONS(4550), 1,
      anon_sym_LBRACK,
    ACTIONS(4558), 1,
      sym__backquoted_id,
    ACTIONS(4562), 1,
      sym_integer_literal,
    ACTIONS(6890), 1,
      anon_sym_LPAREN,
    ACTIONS(6892), 1,
      sym_operator_identifier,
    STATE(4958), 1,
      sym__annotated_type,
    STATE(4984), 1,
      sym__simple_type,
    STATE(5050), 1,
      sym_identifier,
    STATE(5155), 1,
      sym__soft_identifier,
    STATE(7631), 1,
      sym_annotated_type,
    STATE(10262), 1,
      sym__non_null_literal,
    STATE(10394), 1,
      sym_literal_type,
    STATE(12452), 1,
      sym__infix_type_choice,
    STATE(13138), 1,
      sym_template_body,
    STATE(13284), 1,
      sym__type,
    STATE(15013), 1,
      sym_parameter_types,
    STATE(16782), 1,
      sym_stable_identifier,
    ACTIONS(4564), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4566), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4570), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3785), 2,
      sym_comment,
      sym_block_comment,
    STATE(9468), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10280), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13185), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13212), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5928), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [177008] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14941), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3786), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [177129] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14943), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3787), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [177250] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14946), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3788), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [177371] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14949), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3789), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [177492] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14952), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3790), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [177613] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14954), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3791), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [177734] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14956), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3792), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [177855] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14958), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3793), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [177976] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14961), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3794), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [178097] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14963), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3795), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [178218] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14967), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3796), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [178339] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14969), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3797), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [178460] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14971), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3798), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [178581] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14974), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3799), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [178702] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(14976), 1,
      sym__type,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3800), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [178823] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4540), 1,
      sym__alpha_identifier,
    ACTIONS(4542), 1,
      anon_sym_COLON,
    ACTIONS(4544), 1,
      anon_sym_LBRACE,
    ACTIONS(4546), 1,
      anon_sym__,
    ACTIONS(4550), 1,
      anon_sym_LBRACK,
    ACTIONS(4558), 1,
      sym__backquoted_id,
    ACTIONS(4562), 1,
      sym_integer_literal,
    ACTIONS(6890), 1,
      anon_sym_LPAREN,
    ACTIONS(6892), 1,
      sym_operator_identifier,
    STATE(4958), 1,
      sym__annotated_type,
    STATE(4984), 1,
      sym__simple_type,
    STATE(5050), 1,
      sym_identifier,
    STATE(5155), 1,
      sym__soft_identifier,
    STATE(7631), 1,
      sym_annotated_type,
    STATE(10262), 1,
      sym__non_null_literal,
    STATE(10394), 1,
      sym_literal_type,
    STATE(12452), 1,
      sym__infix_type_choice,
    STATE(13138), 1,
      sym_template_body,
    STATE(13311), 1,
      sym__type,
    STATE(15013), 1,
      sym_parameter_types,
    STATE(16782), 1,
      sym_stable_identifier,
    ACTIONS(4564), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4566), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4570), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3801), 2,
      sym_comment,
      sym_block_comment,
    STATE(9468), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10280), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13185), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13212), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5928), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [178944] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15509), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3802), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [179065] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4540), 1,
      sym__alpha_identifier,
    ACTIONS(4542), 1,
      anon_sym_COLON,
    ACTIONS(4544), 1,
      anon_sym_LBRACE,
    ACTIONS(4546), 1,
      anon_sym__,
    ACTIONS(4550), 1,
      anon_sym_LBRACK,
    ACTIONS(4558), 1,
      sym__backquoted_id,
    ACTIONS(4562), 1,
      sym_integer_literal,
    ACTIONS(6890), 1,
      anon_sym_LPAREN,
    ACTIONS(6892), 1,
      sym_operator_identifier,
    STATE(4958), 1,
      sym__annotated_type,
    STATE(4984), 1,
      sym__simple_type,
    STATE(5050), 1,
      sym_identifier,
    STATE(5155), 1,
      sym__soft_identifier,
    STATE(7631), 1,
      sym_annotated_type,
    STATE(10262), 1,
      sym__non_null_literal,
    STATE(10394), 1,
      sym_literal_type,
    STATE(12452), 1,
      sym__infix_type_choice,
    STATE(13138), 1,
      sym_template_body,
    STATE(13314), 1,
      sym__type,
    STATE(15013), 1,
      sym_parameter_types,
    STATE(16782), 1,
      sym_stable_identifier,
    ACTIONS(4564), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4566), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4570), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3803), 2,
      sym_comment,
      sym_block_comment,
    STATE(9468), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10280), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13185), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13212), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5928), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [179186] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16291), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3804), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [179307] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4540), 1,
      sym__alpha_identifier,
    ACTIONS(4542), 1,
      anon_sym_COLON,
    ACTIONS(4544), 1,
      anon_sym_LBRACE,
    ACTIONS(4546), 1,
      anon_sym__,
    ACTIONS(4550), 1,
      anon_sym_LBRACK,
    ACTIONS(4558), 1,
      sym__backquoted_id,
    ACTIONS(4562), 1,
      sym_integer_literal,
    ACTIONS(6890), 1,
      anon_sym_LPAREN,
    ACTIONS(6892), 1,
      sym_operator_identifier,
    STATE(4958), 1,
      sym__annotated_type,
    STATE(4984), 1,
      sym__simple_type,
    STATE(5050), 1,
      sym_identifier,
    STATE(5155), 1,
      sym__soft_identifier,
    STATE(7631), 1,
      sym_annotated_type,
    STATE(10262), 1,
      sym__non_null_literal,
    STATE(10394), 1,
      sym_literal_type,
    STATE(12452), 1,
      sym__infix_type_choice,
    STATE(13138), 1,
      sym_template_body,
    STATE(13318), 1,
      sym__type,
    STATE(15013), 1,
      sym_parameter_types,
    STATE(16782), 1,
      sym_stable_identifier,
    ACTIONS(4564), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4566), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4570), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3805), 2,
      sym_comment,
      sym_block_comment,
    STATE(9468), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10280), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13185), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13212), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5928), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [179428] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4572), 1,
      sym__alpha_identifier,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(4578), 1,
      anon_sym__,
    ACTIONS(4582), 1,
      anon_sym_LBRACK,
    ACTIONS(4590), 1,
      sym__backquoted_id,
    ACTIONS(4594), 1,
      sym_integer_literal,
    ACTIONS(6894), 1,
      anon_sym_LPAREN,
    ACTIONS(6896), 1,
      sym_operator_identifier,
    STATE(4694), 1,
      sym__annotated_type,
    STATE(4753), 1,
      sym__simple_type,
    STATE(5024), 1,
      sym_identifier,
    STATE(5025), 1,
      sym__soft_identifier,
    STATE(6780), 1,
      sym_annotated_type,
    STATE(9897), 1,
      sym__non_null_literal,
    STATE(9912), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11284), 1,
      sym__type,
    STATE(12346), 1,
      sym__infix_type_choice,
    STATE(15016), 1,
      sym_parameter_types,
    STATE(17351), 1,
      sym_stable_identifier,
    ACTIONS(4596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4600), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3806), 2,
      sym_comment,
      sym_block_comment,
    STATE(9287), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10030), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5296), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [179549] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16296), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3807), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [179670] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15341), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3808), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [179791] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(994), 1,
      sym_integer_literal,
    ACTIONS(6742), 1,
      anon_sym_COLON,
    ACTIONS(6744), 1,
      anon_sym_LBRACE,
    ACTIONS(6774), 1,
      sym__alpha_identifier,
    ACTIONS(6776), 1,
      anon_sym__,
    ACTIONS(6778), 1,
      anon_sym_LBRACK,
    ACTIONS(6782), 1,
      anon_sym_LPAREN,
    ACTIONS(6784), 1,
      sym__backquoted_id,
    ACTIONS(6786), 1,
      sym_operator_identifier,
    STATE(4495), 1,
      sym__simple_type,
    STATE(4525), 1,
      sym__annotated_type,
    STATE(4574), 1,
      sym_identifier,
    STATE(4626), 1,
      sym__soft_identifier,
    STATE(6388), 1,
      sym_annotated_type,
    STATE(9458), 1,
      sym__non_null_literal,
    STATE(9707), 1,
      sym_literal_type,
    STATE(11505), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12546), 1,
      sym__infix_type_choice,
    STATE(15091), 1,
      sym_parameter_types,
    STATE(17251), 1,
      sym_stable_identifier,
    ACTIONS(996), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(998), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1002), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3809), 2,
      sym_comment,
      sym_block_comment,
    STATE(5571), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6247), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8341), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6780), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4851), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [179912] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6158), 1,
      anon_sym_COLON,
    ACTIONS(6160), 1,
      anon_sym_LBRACE,
    ACTIONS(6162), 1,
      anon_sym_LBRACK,
    ACTIONS(6164), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(7387), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(10986), 1,
      sym__non_null_literal,
    STATE(10988), 1,
      sym_literal_type,
    STATE(11158), 1,
      sym_template_body,
    STATE(11843), 1,
      sym__type,
    STATE(12334), 1,
      sym__infix_type_choice,
    STATE(15319), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3810), 2,
      sym_comment,
      sym_block_comment,
    STATE(10591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11237), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11264), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [180033] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6172), 1,
      anon_sym_LBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12386), 1,
      sym__infix_type_choice,
    STATE(15018), 1,
      sym_parameter_types,
    STATE(16395), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3811), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [180154] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6158), 1,
      anon_sym_COLON,
    ACTIONS(6160), 1,
      anon_sym_LBRACE,
    ACTIONS(6162), 1,
      anon_sym_LBRACK,
    ACTIONS(6164), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(7387), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(10986), 1,
      sym__non_null_literal,
    STATE(10988), 1,
      sym_literal_type,
    STATE(11158), 1,
      sym_template_body,
    STATE(11844), 1,
      sym__type,
    STATE(12334), 1,
      sym__infix_type_choice,
    STATE(15319), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3812), 2,
      sym_comment,
      sym_block_comment,
    STATE(10591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11237), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11264), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [180275] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6172), 1,
      anon_sym_LBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12386), 1,
      sym__infix_type_choice,
    STATE(15018), 1,
      sym_parameter_types,
    STATE(16401), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3813), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [180396] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(994), 1,
      sym_integer_literal,
    ACTIONS(6742), 1,
      anon_sym_COLON,
    ACTIONS(6744), 1,
      anon_sym_LBRACE,
    ACTIONS(6774), 1,
      sym__alpha_identifier,
    ACTIONS(6776), 1,
      anon_sym__,
    ACTIONS(6778), 1,
      anon_sym_LBRACK,
    ACTIONS(6782), 1,
      anon_sym_LPAREN,
    ACTIONS(6784), 1,
      sym__backquoted_id,
    ACTIONS(6786), 1,
      sym_operator_identifier,
    STATE(4495), 1,
      sym__simple_type,
    STATE(4525), 1,
      sym__annotated_type,
    STATE(4574), 1,
      sym_identifier,
    STATE(4626), 1,
      sym__soft_identifier,
    STATE(6388), 1,
      sym_annotated_type,
    STATE(9458), 1,
      sym__non_null_literal,
    STATE(9707), 1,
      sym_literal_type,
    STATE(11489), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12546), 1,
      sym__infix_type_choice,
    STATE(15091), 1,
      sym_parameter_types,
    STATE(17251), 1,
      sym_stable_identifier,
    ACTIONS(996), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(998), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1002), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3814), 2,
      sym_comment,
      sym_block_comment,
    STATE(5571), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6247), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8341), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6780), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4851), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [180517] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(994), 1,
      sym_integer_literal,
    ACTIONS(6742), 1,
      anon_sym_COLON,
    ACTIONS(6744), 1,
      anon_sym_LBRACE,
    ACTIONS(6774), 1,
      sym__alpha_identifier,
    ACTIONS(6776), 1,
      anon_sym__,
    ACTIONS(6778), 1,
      anon_sym_LBRACK,
    ACTIONS(6782), 1,
      anon_sym_LPAREN,
    ACTIONS(6784), 1,
      sym__backquoted_id,
    ACTIONS(6786), 1,
      sym_operator_identifier,
    STATE(4495), 1,
      sym__simple_type,
    STATE(4525), 1,
      sym__annotated_type,
    STATE(4574), 1,
      sym_identifier,
    STATE(4626), 1,
      sym__soft_identifier,
    STATE(6388), 1,
      sym_annotated_type,
    STATE(9458), 1,
      sym__non_null_literal,
    STATE(9707), 1,
      sym_literal_type,
    STATE(11491), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12546), 1,
      sym__infix_type_choice,
    STATE(15091), 1,
      sym_parameter_types,
    STATE(17251), 1,
      sym_stable_identifier,
    ACTIONS(996), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(998), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1002), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3815), 2,
      sym_comment,
      sym_block_comment,
    STATE(5571), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6247), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8341), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6780), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4851), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [180638] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(994), 1,
      sym_integer_literal,
    ACTIONS(6742), 1,
      anon_sym_COLON,
    ACTIONS(6744), 1,
      anon_sym_LBRACE,
    ACTIONS(6774), 1,
      sym__alpha_identifier,
    ACTIONS(6776), 1,
      anon_sym__,
    ACTIONS(6778), 1,
      anon_sym_LBRACK,
    ACTIONS(6782), 1,
      anon_sym_LPAREN,
    ACTIONS(6784), 1,
      sym__backquoted_id,
    ACTIONS(6786), 1,
      sym_operator_identifier,
    STATE(4495), 1,
      sym__simple_type,
    STATE(4525), 1,
      sym__annotated_type,
    STATE(4574), 1,
      sym_identifier,
    STATE(4626), 1,
      sym__soft_identifier,
    STATE(6388), 1,
      sym_annotated_type,
    STATE(9458), 1,
      sym__non_null_literal,
    STATE(9707), 1,
      sym_literal_type,
    STATE(11492), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12546), 1,
      sym__infix_type_choice,
    STATE(15091), 1,
      sym_parameter_types,
    STATE(17251), 1,
      sym_stable_identifier,
    ACTIONS(996), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(998), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1002), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3816), 2,
      sym_comment,
      sym_block_comment,
    STATE(5571), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6247), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8341), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6780), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4851), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [180759] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4572), 1,
      sym__alpha_identifier,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(4578), 1,
      anon_sym__,
    ACTIONS(4582), 1,
      anon_sym_LBRACK,
    ACTIONS(4590), 1,
      sym__backquoted_id,
    ACTIONS(4594), 1,
      sym_integer_literal,
    ACTIONS(6894), 1,
      anon_sym_LPAREN,
    ACTIONS(6896), 1,
      sym_operator_identifier,
    STATE(4694), 1,
      sym__annotated_type,
    STATE(4753), 1,
      sym__simple_type,
    STATE(5024), 1,
      sym_identifier,
    STATE(5025), 1,
      sym__soft_identifier,
    STATE(6780), 1,
      sym_annotated_type,
    STATE(9897), 1,
      sym__non_null_literal,
    STATE(9912), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11298), 1,
      sym__type,
    STATE(12346), 1,
      sym__infix_type_choice,
    STATE(15016), 1,
      sym_parameter_types,
    STATE(17351), 1,
      sym_stable_identifier,
    ACTIONS(4596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4600), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3817), 2,
      sym_comment,
      sym_block_comment,
    STATE(9287), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10030), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5296), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [180880] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4572), 1,
      sym__alpha_identifier,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(4578), 1,
      anon_sym__,
    ACTIONS(4582), 1,
      anon_sym_LBRACK,
    ACTIONS(4590), 1,
      sym__backquoted_id,
    ACTIONS(4594), 1,
      sym_integer_literal,
    ACTIONS(6894), 1,
      anon_sym_LPAREN,
    ACTIONS(6896), 1,
      sym_operator_identifier,
    STATE(4694), 1,
      sym__annotated_type,
    STATE(4753), 1,
      sym__simple_type,
    STATE(5024), 1,
      sym_identifier,
    STATE(5025), 1,
      sym__soft_identifier,
    STATE(6780), 1,
      sym_annotated_type,
    STATE(9897), 1,
      sym__non_null_literal,
    STATE(9912), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11302), 1,
      sym__type,
    STATE(12346), 1,
      sym__infix_type_choice,
    STATE(15016), 1,
      sym_parameter_types,
    STATE(17351), 1,
      sym_stable_identifier,
    ACTIONS(4596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4600), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3818), 2,
      sym_comment,
      sym_block_comment,
    STATE(9287), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10030), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5296), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [181001] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4572), 1,
      sym__alpha_identifier,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(4578), 1,
      anon_sym__,
    ACTIONS(4582), 1,
      anon_sym_LBRACK,
    ACTIONS(4590), 1,
      sym__backquoted_id,
    ACTIONS(4594), 1,
      sym_integer_literal,
    ACTIONS(6894), 1,
      anon_sym_LPAREN,
    ACTIONS(6896), 1,
      sym_operator_identifier,
    STATE(4694), 1,
      sym__annotated_type,
    STATE(4753), 1,
      sym__simple_type,
    STATE(5024), 1,
      sym_identifier,
    STATE(5025), 1,
      sym__soft_identifier,
    STATE(6780), 1,
      sym_annotated_type,
    STATE(9897), 1,
      sym__non_null_literal,
    STATE(9912), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11303), 1,
      sym__type,
    STATE(12346), 1,
      sym__infix_type_choice,
    STATE(15016), 1,
      sym_parameter_types,
    STATE(17351), 1,
      sym_stable_identifier,
    ACTIONS(4596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4600), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3819), 2,
      sym_comment,
      sym_block_comment,
    STATE(9287), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10030), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5296), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [181122] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4572), 1,
      sym__alpha_identifier,
    ACTIONS(4574), 1,
      anon_sym_COLON,
    ACTIONS(4576), 1,
      anon_sym_LBRACE,
    ACTIONS(4578), 1,
      anon_sym__,
    ACTIONS(4582), 1,
      anon_sym_LBRACK,
    ACTIONS(4590), 1,
      sym__backquoted_id,
    ACTIONS(4594), 1,
      sym_integer_literal,
    ACTIONS(6894), 1,
      anon_sym_LPAREN,
    ACTIONS(6896), 1,
      sym_operator_identifier,
    STATE(4694), 1,
      sym__annotated_type,
    STATE(4753), 1,
      sym__simple_type,
    STATE(5024), 1,
      sym_identifier,
    STATE(5025), 1,
      sym__soft_identifier,
    STATE(6780), 1,
      sym_annotated_type,
    STATE(9897), 1,
      sym__non_null_literal,
    STATE(9912), 1,
      sym_literal_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11304), 1,
      sym__type,
    STATE(12346), 1,
      sym__infix_type_choice,
    STATE(15016), 1,
      sym_parameter_types,
    STATE(17351), 1,
      sym_stable_identifier,
    ACTIONS(4596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4600), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3820), 2,
      sym_comment,
      sym_block_comment,
    STATE(9287), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10030), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11180), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11216), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5296), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [181243] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6252), 1,
      sym__alpha_identifier,
    ACTIONS(6254), 1,
      anon_sym_COLON,
    ACTIONS(6256), 1,
      anon_sym_LBRACE,
    ACTIONS(6258), 1,
      anon_sym__,
    ACTIONS(6260), 1,
      anon_sym_LBRACK,
    ACTIONS(6264), 1,
      anon_sym_LPAREN,
    ACTIONS(6266), 1,
      sym__backquoted_id,
    ACTIONS(6268), 1,
      sym_operator_identifier,
    ACTIONS(6270), 1,
      sym_integer_literal,
    STATE(5450), 1,
      sym__simple_type,
    STATE(5492), 1,
      sym__soft_identifier,
    STATE(5705), 1,
      sym_identifier,
    STATE(5911), 1,
      sym__annotated_type,
    STATE(8761), 1,
      sym_annotated_type,
    STATE(10563), 1,
      sym__non_null_literal,
    STATE(10613), 1,
      sym_literal_type,
    STATE(10671), 1,
      sym_template_body,
    STATE(10743), 1,
      sym__type,
    STATE(12469), 1,
      sym__infix_type_choice,
    STATE(15433), 1,
      sym_parameter_types,
    STATE(16941), 1,
      sym_stable_identifier,
    ACTIONS(6272), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6274), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6276), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3821), 2,
      sym_comment,
      sym_block_comment,
    STATE(9865), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10635), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10850), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10815), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6262), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6211), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [181364] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6252), 1,
      sym__alpha_identifier,
    ACTIONS(6254), 1,
      anon_sym_COLON,
    ACTIONS(6256), 1,
      anon_sym_LBRACE,
    ACTIONS(6258), 1,
      anon_sym__,
    ACTIONS(6260), 1,
      anon_sym_LBRACK,
    ACTIONS(6264), 1,
      anon_sym_LPAREN,
    ACTIONS(6266), 1,
      sym__backquoted_id,
    ACTIONS(6268), 1,
      sym_operator_identifier,
    ACTIONS(6270), 1,
      sym_integer_literal,
    STATE(5450), 1,
      sym__simple_type,
    STATE(5492), 1,
      sym__soft_identifier,
    STATE(5705), 1,
      sym_identifier,
    STATE(5911), 1,
      sym__annotated_type,
    STATE(8761), 1,
      sym_annotated_type,
    STATE(10563), 1,
      sym__non_null_literal,
    STATE(10613), 1,
      sym_literal_type,
    STATE(10671), 1,
      sym_template_body,
    STATE(10744), 1,
      sym__type,
    STATE(12469), 1,
      sym__infix_type_choice,
    STATE(15433), 1,
      sym_parameter_types,
    STATE(16941), 1,
      sym_stable_identifier,
    ACTIONS(6272), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6274), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6276), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3822), 2,
      sym_comment,
      sym_block_comment,
    STATE(9865), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10635), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10850), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10815), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6262), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6211), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [181485] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(994), 1,
      sym_integer_literal,
    ACTIONS(6742), 1,
      anon_sym_COLON,
    ACTIONS(6744), 1,
      anon_sym_LBRACE,
    ACTIONS(6774), 1,
      sym__alpha_identifier,
    ACTIONS(6776), 1,
      anon_sym__,
    ACTIONS(6778), 1,
      anon_sym_LBRACK,
    ACTIONS(6782), 1,
      anon_sym_LPAREN,
    ACTIONS(6784), 1,
      sym__backquoted_id,
    ACTIONS(6786), 1,
      sym_operator_identifier,
    STATE(4495), 1,
      sym__simple_type,
    STATE(4525), 1,
      sym__annotated_type,
    STATE(4574), 1,
      sym_identifier,
    STATE(4626), 1,
      sym__soft_identifier,
    STATE(6388), 1,
      sym_annotated_type,
    STATE(9458), 1,
      sym__non_null_literal,
    STATE(9707), 1,
      sym_literal_type,
    STATE(11493), 1,
      sym__type,
    STATE(11664), 1,
      sym_template_body,
    STATE(12546), 1,
      sym__infix_type_choice,
    STATE(15091), 1,
      sym_parameter_types,
    STATE(17251), 1,
      sym_stable_identifier,
    ACTIONS(996), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(998), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1002), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3823), 2,
      sym_comment,
      sym_block_comment,
    STATE(5571), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6247), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8341), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11784), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6780), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4851), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [181606] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1066), 1,
      sym_integer_literal,
    ACTIONS(6520), 1,
      anon_sym_COLON,
    ACTIONS(6522), 1,
      anon_sym_LBRACE,
    ACTIONS(6760), 1,
      sym__alpha_identifier,
    ACTIONS(6762), 1,
      anon_sym__,
    ACTIONS(6764), 1,
      anon_sym_LBRACK,
    ACTIONS(6768), 1,
      anon_sym_LPAREN,
    ACTIONS(6770), 1,
      sym__backquoted_id,
    ACTIONS(6772), 1,
      sym_operator_identifier,
    STATE(4677), 1,
      sym__simple_type,
    STATE(4746), 1,
      sym__annotated_type,
    STATE(4900), 1,
      sym_identifier,
    STATE(4925), 1,
      sym__soft_identifier,
    STATE(6971), 1,
      sym_annotated_type,
    STATE(9748), 1,
      sym__non_null_literal,
    STATE(9991), 1,
      sym_literal_type,
    STATE(11868), 1,
      sym_template_body,
    STATE(12483), 1,
      sym__infix_type_choice,
    STATE(12612), 1,
      sym__type,
    STATE(15088), 1,
      sym_parameter_types,
    STATE(17018), 1,
      sym_stable_identifier,
    ACTIONS(1068), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1070), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1074), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3824), 2,
      sym_comment,
      sym_block_comment,
    STATE(6450), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6808), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9235), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11882), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6766), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5278), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [181727] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15614), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3825), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [181848] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17002), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3826), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [181969] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17009), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3827), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [182090] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1304), 1,
      sym_integer_literal,
    ACTIONS(6114), 1,
      sym__alpha_identifier,
    ACTIONS(6116), 1,
      anon_sym_COLON,
    ACTIONS(6118), 1,
      anon_sym_LBRACE,
    ACTIONS(6120), 1,
      anon_sym__,
    ACTIONS(6122), 1,
      anon_sym_LBRACK,
    ACTIONS(6126), 1,
      anon_sym_LPAREN,
    ACTIONS(6128), 1,
      sym__backquoted_id,
    ACTIONS(6130), 1,
      sym_operator_identifier,
    STATE(4976), 1,
      sym__annotated_type,
    STATE(5030), 1,
      sym__simple_type,
    STATE(5135), 1,
      sym_identifier,
    STATE(5193), 1,
      sym__soft_identifier,
    STATE(7769), 1,
      sym_annotated_type,
    STATE(10265), 1,
      sym_literal_type,
    STATE(10325), 1,
      sym__non_null_literal,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(12873), 1,
      sym_template_body,
    STATE(12894), 1,
      sym__type,
    STATE(15033), 1,
      sym_parameter_types,
    STATE(17257), 1,
      sym_stable_identifier,
    ACTIONS(1306), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1308), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1312), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3828), 2,
      sym_comment,
      sym_block_comment,
    STATE(7638), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7829), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9590), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12811), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6124), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5886), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [182211] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15523), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3829), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [182332] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6252), 1,
      sym__alpha_identifier,
    ACTIONS(6254), 1,
      anon_sym_COLON,
    ACTIONS(6256), 1,
      anon_sym_LBRACE,
    ACTIONS(6258), 1,
      anon_sym__,
    ACTIONS(6260), 1,
      anon_sym_LBRACK,
    ACTIONS(6264), 1,
      anon_sym_LPAREN,
    ACTIONS(6266), 1,
      sym__backquoted_id,
    ACTIONS(6268), 1,
      sym_operator_identifier,
    ACTIONS(6270), 1,
      sym_integer_literal,
    STATE(5450), 1,
      sym__simple_type,
    STATE(5492), 1,
      sym__soft_identifier,
    STATE(5705), 1,
      sym_identifier,
    STATE(5911), 1,
      sym__annotated_type,
    STATE(8761), 1,
      sym_annotated_type,
    STATE(10563), 1,
      sym__non_null_literal,
    STATE(10613), 1,
      sym_literal_type,
    STATE(10671), 1,
      sym_template_body,
    STATE(10913), 1,
      sym__type,
    STATE(12469), 1,
      sym__infix_type_choice,
    STATE(15433), 1,
      sym_parameter_types,
    STATE(16941), 1,
      sym_stable_identifier,
    ACTIONS(6272), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6274), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6276), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3830), 2,
      sym_comment,
      sym_block_comment,
    STATE(9865), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10635), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10850), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10815), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6262), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6211), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [182453] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6158), 1,
      anon_sym_COLON,
    ACTIONS(6160), 1,
      anon_sym_LBRACE,
    ACTIONS(6162), 1,
      anon_sym_LBRACK,
    ACTIONS(6164), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(7387), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(10986), 1,
      sym__non_null_literal,
    STATE(10988), 1,
      sym_literal_type,
    STATE(11158), 1,
      sym_template_body,
    STATE(11925), 1,
      sym__type,
    STATE(12334), 1,
      sym__infix_type_choice,
    STATE(15319), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3831), 2,
      sym_comment,
      sym_block_comment,
    STATE(10591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11237), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11264), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [182574] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6172), 1,
      anon_sym_LBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12386), 1,
      sym__infix_type_choice,
    STATE(15018), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17075), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3832), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [182695] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6144), 1,
      anon_sym_LPAREN,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(6158), 1,
      anon_sym_COLON,
    ACTIONS(6160), 1,
      anon_sym_LBRACE,
    ACTIONS(6162), 1,
      anon_sym_LBRACK,
    ACTIONS(6164), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(7387), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(10986), 1,
      sym__non_null_literal,
    STATE(10988), 1,
      sym_literal_type,
    STATE(11158), 1,
      sym_template_body,
    STATE(11926), 1,
      sym__type,
    STATE(12334), 1,
      sym__infix_type_choice,
    STATE(15319), 1,
      sym_parameter_types,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3833), 2,
      sym_comment,
      sym_block_comment,
    STATE(10591), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11237), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11264), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [182816] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4172), 1,
      anon_sym_COLON,
    ACTIONS(4174), 1,
      anon_sym_LBRACE,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(6172), 1,
      anon_sym_LBRACK,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12172), 1,
      sym_template_body,
    STATE(12386), 1,
      sym__infix_type_choice,
    STATE(15018), 1,
      sym_parameter_types,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(17078), 1,
      sym__type,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3834), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11856), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [182937] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 10,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [183006] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4820), 1,
      sym__alpha_identifier,
    ACTIONS(4822), 1,
      anon_sym_COLON,
    ACTIONS(4824), 1,
      anon_sym_LBRACE,
    ACTIONS(4826), 1,
      anon_sym__,
    ACTIONS(4830), 1,
      anon_sym_LBRACK,
    ACTIONS(4838), 1,
      sym__backquoted_id,
    ACTIONS(4842), 1,
      sym_integer_literal,
    ACTIONS(6886), 1,
      anon_sym_LPAREN,
    ACTIONS(6888), 1,
      sym_operator_identifier,
    STATE(4479), 1,
      sym__simple_type,
    STATE(4564), 1,
      sym__annotated_type,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(4630), 1,
      sym_identifier,
    STATE(5999), 1,
      sym_annotated_type,
    STATE(9362), 1,
      sym__non_null_literal,
    STATE(9672), 1,
      sym_literal_type,
    STATE(12259), 1,
      sym_template_body,
    STATE(12285), 1,
      sym__type,
    STATE(12488), 1,
      sym__infix_type_choice,
    STATE(14829), 1,
      sym_parameter_types,
    STATE(17030), 1,
      sym_stable_identifier,
    ACTIONS(4844), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4846), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4850), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3836), 2,
      sym_comment,
      sym_block_comment,
    STATE(8521), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(9588), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12383), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12509), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4832), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4830), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [183127] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1304), 1,
      sym_integer_literal,
    ACTIONS(6114), 1,
      sym__alpha_identifier,
    ACTIONS(6116), 1,
      anon_sym_COLON,
    ACTIONS(6118), 1,
      anon_sym_LBRACE,
    ACTIONS(6120), 1,
      anon_sym__,
    ACTIONS(6122), 1,
      anon_sym_LBRACK,
    ACTIONS(6126), 1,
      anon_sym_LPAREN,
    ACTIONS(6128), 1,
      sym__backquoted_id,
    ACTIONS(6130), 1,
      sym_operator_identifier,
    STATE(4976), 1,
      sym__annotated_type,
    STATE(5030), 1,
      sym__simple_type,
    STATE(5135), 1,
      sym_identifier,
    STATE(5193), 1,
      sym__soft_identifier,
    STATE(7769), 1,
      sym_annotated_type,
    STATE(10265), 1,
      sym_literal_type,
    STATE(10325), 1,
      sym__non_null_literal,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(12873), 1,
      sym_template_body,
    STATE(12907), 1,
      sym__type,
    STATE(15033), 1,
      sym_parameter_types,
    STATE(17257), 1,
      sym_stable_identifier,
    ACTIONS(1306), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1308), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1312), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3837), 2,
      sym_comment,
      sym_block_comment,
    STATE(7638), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7829), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9590), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12811), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6124), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5886), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [183248] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1304), 1,
      sym_integer_literal,
    ACTIONS(6114), 1,
      sym__alpha_identifier,
    ACTIONS(6116), 1,
      anon_sym_COLON,
    ACTIONS(6118), 1,
      anon_sym_LBRACE,
    ACTIONS(6120), 1,
      anon_sym__,
    ACTIONS(6122), 1,
      anon_sym_LBRACK,
    ACTIONS(6126), 1,
      anon_sym_LPAREN,
    ACTIONS(6128), 1,
      sym__backquoted_id,
    ACTIONS(6130), 1,
      sym_operator_identifier,
    STATE(4976), 1,
      sym__annotated_type,
    STATE(5030), 1,
      sym__simple_type,
    STATE(5135), 1,
      sym_identifier,
    STATE(5193), 1,
      sym__soft_identifier,
    STATE(7769), 1,
      sym_annotated_type,
    STATE(10265), 1,
      sym_literal_type,
    STATE(10325), 1,
      sym__non_null_literal,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(12873), 1,
      sym_template_body,
    STATE(12912), 1,
      sym__type,
    STATE(15033), 1,
      sym_parameter_types,
    STATE(17257), 1,
      sym_stable_identifier,
    ACTIONS(1306), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1308), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1312), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3838), 2,
      sym_comment,
      sym_block_comment,
    STATE(7638), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7829), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9590), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12811), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6124), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5886), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [183369] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1304), 1,
      sym_integer_literal,
    ACTIONS(6114), 1,
      sym__alpha_identifier,
    ACTIONS(6116), 1,
      anon_sym_COLON,
    ACTIONS(6118), 1,
      anon_sym_LBRACE,
    ACTIONS(6120), 1,
      anon_sym__,
    ACTIONS(6122), 1,
      anon_sym_LBRACK,
    ACTIONS(6126), 1,
      anon_sym_LPAREN,
    ACTIONS(6128), 1,
      sym__backquoted_id,
    ACTIONS(6130), 1,
      sym_operator_identifier,
    STATE(4976), 1,
      sym__annotated_type,
    STATE(5030), 1,
      sym__simple_type,
    STATE(5135), 1,
      sym_identifier,
    STATE(5193), 1,
      sym__soft_identifier,
    STATE(7769), 1,
      sym_annotated_type,
    STATE(10265), 1,
      sym_literal_type,
    STATE(10325), 1,
      sym__non_null_literal,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(12873), 1,
      sym_template_body,
    STATE(12914), 1,
      sym__type,
    STATE(15033), 1,
      sym_parameter_types,
    STATE(17257), 1,
      sym_stable_identifier,
    ACTIONS(1306), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1308), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1312), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3839), 2,
      sym_comment,
      sym_block_comment,
    STATE(7638), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7829), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9590), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12811), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(6124), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5886), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [183490] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(864), 1,
      sym_integer_literal,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(4960), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    STATE(5021), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8541), 1,
      sym_template_body,
    STATE(10102), 1,
      sym__non_null_literal,
    STATE(10105), 1,
      sym_literal_type,
    STATE(12206), 1,
      sym__infix_type_choice,
    STATE(15196), 1,
      sym_parameter_types,
    STATE(15658), 1,
      sym__type,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(878), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3840), 2,
      sym_comment,
      sym_block_comment,
    STATE(8137), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9275), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8589), 4,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [183611] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 8,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [183679] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3842), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 8,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_DQUOTE,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [183747] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 8,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_DQUOTE,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [183815] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 8,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_DQUOTE,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [183883] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 9,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [183951] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6900), 1,
      anon_sym_LBRACE,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6912), 1,
      anon_sym_LPAREN,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16021), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3846), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [184066] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(6924), 1,
      anon_sym_LBRACE,
    ACTIONS(6926), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15969), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3847), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [184181] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(6928), 1,
      anon_sym_LBRACE,
    ACTIONS(6930), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16022), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3848), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [184296] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(6932), 1,
      anon_sym_LBRACE,
    ACTIONS(6934), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16111), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3849), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [184411] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 36,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [184474] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4134), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 8,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_DQUOTE,
    ACTIONS(4130), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [184541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 36,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [184604] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(6940), 1,
      anon_sym_LBRACE,
    ACTIONS(6942), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16099), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3853), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [184719] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(6944), 1,
      anon_sym_LBRACE,
    ACTIONS(6946), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16098), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3854), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [184834] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(6948), 1,
      anon_sym_LBRACE,
    ACTIONS(6950), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15906), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3855), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [184949] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(6952), 1,
      anon_sym_LBRACE,
    ACTIONS(6954), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15912), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3856), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [185064] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(6956), 1,
      anon_sym_LBRACE,
    ACTIONS(6958), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15871), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3857), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [185179] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(6960), 1,
      anon_sym_LBRACE,
    ACTIONS(6962), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16133), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3858), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [185294] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(6964), 1,
      anon_sym_LBRACE,
    ACTIONS(6966), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15901), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3859), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [185409] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(6968), 1,
      anon_sym_LBRACE,
    ACTIONS(6970), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15979), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3860), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [185524] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(6972), 1,
      anon_sym_LBRACE,
    ACTIONS(6974), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15939), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3861), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [185639] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(6976), 1,
      anon_sym_LBRACE,
    ACTIONS(6978), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16112), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3862), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [185754] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(6980), 1,
      anon_sym_LBRACE,
    ACTIONS(6982), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16143), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3863), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [185869] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(6984), 1,
      anon_sym_LBRACE,
    ACTIONS(6986), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15982), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3864), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [185984] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(6988), 1,
      anon_sym_LBRACE,
    ACTIONS(6990), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15996), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3865), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [186099] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(6992), 1,
      anon_sym_LBRACE,
    ACTIONS(6994), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16011), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3866), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [186214] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(6996), 1,
      anon_sym_LBRACE,
    ACTIONS(6998), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16041), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3867), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [186329] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7000), 1,
      anon_sym_LBRACE,
    ACTIONS(7002), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15892), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3868), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [186444] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7004), 1,
      anon_sym_LBRACE,
    ACTIONS(7006), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16093), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3869), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [186559] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7008), 1,
      anon_sym_LBRACE,
    ACTIONS(7010), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16145), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3870), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [186674] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7012), 1,
      anon_sym_LBRACE,
    ACTIONS(7014), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15859), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3871), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [186789] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7016), 1,
      anon_sym_LBRACE,
    ACTIONS(7018), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15870), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3872), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [186904] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7020), 1,
      anon_sym_LBRACE,
    ACTIONS(7022), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15917), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3873), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [187019] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7024), 1,
      anon_sym_LBRACE,
    ACTIONS(7026), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15949), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3874), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [187134] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7028), 1,
      anon_sym_LBRACE,
    ACTIONS(7030), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15966), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3875), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [187249] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7032), 1,
      anon_sym_LBRACE,
    ACTIONS(7034), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15851), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3876), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [187364] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7036), 1,
      anon_sym_LBRACE,
    ACTIONS(7038), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15884), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3877), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [187479] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7040), 1,
      anon_sym_LBRACE,
    ACTIONS(7042), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15914), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3878), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [187594] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7044), 1,
      anon_sym_LBRACE,
    ACTIONS(7046), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16072), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3879), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [187709] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7048), 1,
      anon_sym_LBRACE,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16061), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3880), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [187824] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7052), 1,
      anon_sym_LBRACE,
    ACTIONS(7054), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16120), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3881), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [187939] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7056), 1,
      anon_sym_LBRACE,
    ACTIONS(7058), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15907), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3882), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [188054] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7060), 1,
      anon_sym_LBRACE,
    ACTIONS(7062), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16141), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3883), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [188169] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7064), 1,
      anon_sym_LBRACE,
    ACTIONS(7066), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15944), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3884), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [188284] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7068), 1,
      anon_sym_LBRACE,
    ACTIONS(7070), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16046), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3885), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [188399] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7072), 1,
      anon_sym_LBRACE,
    ACTIONS(7074), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15903), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3886), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [188514] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7076), 1,
      anon_sym_LBRACE,
    ACTIONS(7078), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15923), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3887), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [188629] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7080), 1,
      anon_sym_LBRACE,
    ACTIONS(7082), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15999), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3888), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [188744] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7084), 1,
      anon_sym_LBRACE,
    ACTIONS(7086), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16004), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3889), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [188859] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7088), 1,
      anon_sym_LBRACE,
    ACTIONS(7090), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16027), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3890), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [188974] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7092), 1,
      anon_sym_LBRACE,
    ACTIONS(7094), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15852), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3891), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [189089] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7096), 1,
      anon_sym_LBRACE,
    ACTIONS(7098), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16062), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3892), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [189204] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7100), 1,
      anon_sym_LBRACE,
    ACTIONS(7102), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16106), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3893), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [189319] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7104), 1,
      anon_sym_LBRACE,
    ACTIONS(7106), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15965), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3894), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [189434] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7108), 1,
      anon_sym_LBRACE,
    ACTIONS(7110), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15934), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3895), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [189549] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7112), 1,
      anon_sym_LBRACE,
    ACTIONS(7114), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15995), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3896), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [189664] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7116), 1,
      anon_sym_LBRACE,
    ACTIONS(7118), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15894), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3897), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [189779] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7120), 1,
      anon_sym_LBRACE,
    ACTIONS(7122), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16104), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3898), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [189894] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7124), 1,
      anon_sym_LBRACE,
    ACTIONS(7126), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15938), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3899), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [190009] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7128), 1,
      anon_sym_LBRACE,
    ACTIONS(7130), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16122), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3900), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [190124] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7132), 1,
      anon_sym_LBRACE,
    ACTIONS(7134), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15964), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3901), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [190239] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7136), 1,
      anon_sym_LBRACE,
    ACTIONS(7138), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15867), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3902), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [190354] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7140), 1,
      anon_sym_LBRACE,
    ACTIONS(7142), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(16039), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3903), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [190469] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7144), 1,
      anon_sym_LBRACE,
    ACTIONS(7146), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14360), 1,
      sym_enumerator,
    STATE(15891), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3904), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [190584] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17674), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3905), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [190696] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17362), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3906), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [190808] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17820), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3907), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [190920] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16559), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3908), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [191032] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16560), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3909), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [191144] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17838), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3910), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [191256] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16632), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3911), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [191368] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16660), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3912), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [191480] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16661), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3913), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [191592] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17082), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3914), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [191704] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16748), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3915), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [191816] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16749), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3916), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [191928] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16411), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3917), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [192040] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16413), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3918), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [192152] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17443), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3919), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [192264] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17445), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3920), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [192376] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16841), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3921), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [192488] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16844), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3922), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [192600] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17374), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3923), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [192712] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17403), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3924), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [192824] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17382), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3925), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [192936] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17405), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3926), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [193048] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16957), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3927), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [193160] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16964), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3928), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [193272] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16179), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3929), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [193384] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17338), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3930), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [193496] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17108), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3931), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [193608] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 35,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [193670] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17114), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3933), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [193782] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17339), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3934), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [193894] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16180), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3935), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [194006] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17208), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3936), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [194118] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17213), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3937), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [194230] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17309), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3938), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [194342] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17461), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3939), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [194454] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16681), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3940), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [194566] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17311), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3941), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [194678] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17313), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3942), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [194790] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17734), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3943), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [194902] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16691), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3944), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [195014] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16432), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3945), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [195126] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16864), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3946), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [195238] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16897), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3947), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [195350] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17418), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3948), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [195462] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17422), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3949), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [195574] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17651), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3950), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [195686] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14050), 1,
      sym_enumerator,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    ACTIONS(7160), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(3951), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [195796] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16217), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3952), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [195908] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17520), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3953), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [196020] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17522), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3954), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [196132] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16281), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3955), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [196244] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17671), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3956), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [196356] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17611), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3957), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [196468] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17612), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3958), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [196580] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17662), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3959), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [196692] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14050), 1,
      sym_enumerator,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    ACTIONS(7162), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(3960), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [196802] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17680), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3961), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [196914] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17715), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3962), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [197026] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17717), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3963), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [197138] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17556), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3964), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [197250] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17627), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3965), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [197362] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16360), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3966), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [197474] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16294), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3967), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [197586] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17832), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3968), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [197698] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17833), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3969), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [197810] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16298), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3970), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [197922] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16414), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3971), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [198034] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16429), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3972), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [198146] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17872), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3973), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [198258] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17873), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3974), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [198370] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16791), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3975), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [198482] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 35,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [198544] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16888), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3977), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [198656] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16891), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3978), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [198768] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17617), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3979), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [198880] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17538), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3980), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [198992] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16184), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3981), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [199104] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16977), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3982), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [199216] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16987), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3983), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [199328] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16299), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3984), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [199440] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16301), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3985), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [199552] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17845), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3986), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [199664] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16189), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3987), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [199776] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16163), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3988), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [199888] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16167), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3989), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [200000] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17088), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3990), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [200112] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17310), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3991), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [200224] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17366), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3992), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [200336] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17381), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3993), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [200448] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17148), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3994), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [200560] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16257), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3995), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [200672] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17216), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3996), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [200784] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16447), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3997), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [200896] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16479), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3998), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [201008] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17250), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3999), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [201120] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17253), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4000), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [201232] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16427), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4001), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [201344] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16828), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4002), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [201456] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16428), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4003), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [201568] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17092), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4004), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [201680] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16263), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4005), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [201792] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17116), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4006), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [201904] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17565), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4007), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [202016] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14050), 1,
      sym_enumerator,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    ACTIONS(7164), 2,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
    STATE(4008), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [202126] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17364), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4009), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [202238] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17616), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4010), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [202350] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17586), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4011), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [202462] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14050), 1,
      sym_enumerator,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    ACTIONS(7166), 2,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
    STATE(4012), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [202572] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17471), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4013), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [202684] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17472), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4014), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [202796] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16809), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4015), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [202908] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17023), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4016), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [203020] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16370), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4017), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [203132] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16969), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4018), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [203244] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7152), 1,
      sym_operator_identifier,
    ACTIONS(7154), 1,
      sym_null_literal,
    STATE(5591), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(9968), 1,
      sym_stable_identifier,
    STATE(10094), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16975), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4019), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10172), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [203356] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 35,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [203418] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4021), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 35,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [203480] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(17347), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4022), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [203592] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16347), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4023), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [203704] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6922), 1,
      sym__indent,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14372), 1,
      sym_enumerator,
    STATE(16785), 1,
      sym_enumerators,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4024), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [203816] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7168), 1,
      anon_sym_case,
    ACTIONS(7170), 1,
      anon_sym_if,
    ACTIONS(7172), 1,
      sym_operator_identifier,
    ACTIONS(7174), 1,
      sym_null_literal,
    ACTIONS(7176), 1,
      sym__outdent,
    STATE(7674), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10896), 1,
      sym_stable_identifier,
    STATE(10904), 1,
      sym_wildcard,
    STATE(14012), 1,
      aux_sym_enumerator_repeat1,
    STATE(14518), 1,
      sym_guard,
    STATE(15066), 1,
      sym_enumerator,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4025), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11056), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [203925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 34,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [203986] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 34,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [204047] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 34,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [204108] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 35,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [204169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 34,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [204230] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 35,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [204291] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7168), 1,
      anon_sym_case,
    ACTIONS(7170), 1,
      anon_sym_if,
    ACTIONS(7172), 1,
      sym_operator_identifier,
    ACTIONS(7174), 1,
      sym_null_literal,
    ACTIONS(7178), 1,
      sym__outdent,
    STATE(7674), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10896), 1,
      sym_stable_identifier,
    STATE(10904), 1,
      sym_wildcard,
    STATE(14012), 1,
      aux_sym_enumerator_repeat1,
    STATE(14518), 1,
      sym_guard,
    STATE(15066), 1,
      sym_enumerator,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4032), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11056), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [204400] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 35,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [204461] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 35,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [204522] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 34,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [204582] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4036), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 34,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [204642] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4037), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 34,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [204702] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 34,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [204762] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4039), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 34,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [204822] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_case,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(6918), 1,
      sym_operator_identifier,
    ACTIONS(6920), 1,
      sym_null_literal,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10754), 1,
      sym_wildcard,
    STATE(10856), 1,
      sym_stable_identifier,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14050), 1,
      sym_enumerator,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4040), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11124), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [204928] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 34,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [204988] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7168), 1,
      anon_sym_case,
    ACTIONS(7170), 1,
      anon_sym_if,
    ACTIONS(7172), 1,
      sym_operator_identifier,
    ACTIONS(7174), 1,
      sym_null_literal,
    STATE(7674), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10896), 1,
      sym_stable_identifier,
    STATE(10904), 1,
      sym_wildcard,
    STATE(14012), 1,
      aux_sym_enumerator_repeat1,
    STATE(14518), 1,
      sym_guard,
    STATE(14541), 1,
      sym_enumerator,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4042), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11056), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [205094] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 33,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [205154] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4044), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 33,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [205214] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 34,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [205274] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6910), 1,
      anon_sym_if,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(7148), 1,
      anon_sym_case,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7156), 1,
      sym_operator_identifier,
    ACTIONS(7158), 1,
      sym_null_literal,
    STATE(7701), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10794), 1,
      sym_stable_identifier,
    STATE(10802), 1,
      sym_wildcard,
    STATE(13371), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(14050), 1,
      sym_enumerator,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4046), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11027), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [205380] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7168), 1,
      anon_sym_case,
    ACTIONS(7170), 1,
      anon_sym_if,
    ACTIONS(7172), 1,
      sym_operator_identifier,
    ACTIONS(7174), 1,
      sym_null_literal,
    STATE(7674), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10896), 1,
      sym_stable_identifier,
    STATE(10904), 1,
      sym_wildcard,
    STATE(14012), 1,
      aux_sym_enumerator_repeat1,
    STATE(14518), 1,
      sym_guard,
    STATE(15066), 1,
      sym_enumerator,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4047), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11056), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [205486] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 34,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [205546] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 33,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [205605] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 33,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [205664] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 10,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 34,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [205723] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 10,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 34,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [205782] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 33,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [205841] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 33,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [205900] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 33,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [205959] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4056), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 44,
      anon_sym_enum,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_object,
      anon_sym_given,
      anon_sym_EQ_GT,
      anon_sym_as,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_do,
  [206016] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 33,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [206075] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 33,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [206134] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 33,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [206193] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 33,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [206252] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 33,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [206311] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 44,
      anon_sym_enum,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_object,
      anon_sym_given,
      anon_sym_EQ_GT,
      anon_sym_as,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_do,
  [206368] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 32,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [206426] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 32,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [206484] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7182), 1,
      anon_sym_object,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7188), 1,
      anon_sym_class,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(233), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4065), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [206584] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 32,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [206642] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7202), 1,
      anon_sym_object,
    ACTIONS(7204), 1,
      anon_sym_class,
    ACTIONS(7206), 1,
      sym_operator_identifier,
    ACTIONS(7208), 1,
      sym_null_literal,
    STATE(265), 1,
      sym__case_pattern,
    STATE(7298), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10632), 1,
      sym_stable_identifier,
    STATE(10658), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4067), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10880), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [206742] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 10,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 33,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [206800] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2516), 1,
      anon_sym_LBRACK,
    STATE(4069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7213), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 5,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_then,
    ACTIONS(7218), 5,
      sym__indent,
      sym__simple_multiline_string,
      sym__simple_string,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7210), 8,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
    ACTIONS(7216), 21,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_implicit,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [206866] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 10,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 33,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [206924] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 32,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [206982] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 32,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [207040] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4073), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 9,
      sym__indent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7220), 34,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [207098] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4074), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 32,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [207156] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4075), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 31,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [207213] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 10,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 32,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [207270] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 31,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [207327] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4078), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 10,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 32,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [207384] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7238), 1,
      sym_operator_identifier,
    ACTIONS(7240), 1,
      sym_null_literal,
    STATE(6665), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(11024), 1,
      sym_stable_identifier,
    STATE(11082), 1,
      sym_wildcard,
    STATE(15980), 1,
      sym_identifiers,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4079), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11309), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [207478] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7242), 1,
      sym_operator_identifier,
    ACTIONS(7244), 1,
      sym_null_literal,
    STATE(6695), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10954), 1,
      sym_stable_identifier,
    STATE(10958), 1,
      sym_wildcard,
    STATE(15863), 1,
      sym_identifiers,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4080), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11325), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [207572] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2234), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4081), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [207666] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7246), 1,
      anon_sym_RPAREN,
    ACTIONS(7248), 1,
      sym_operator_identifier,
    ACTIONS(7250), 1,
      sym_null_literal,
    STATE(7309), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10523), 1,
      sym_stable_identifier,
    STATE(10524), 1,
      sym_wildcard,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4082), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10902), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [207760] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2065), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4083), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [207854] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7252), 1,
      anon_sym_RPAREN,
    ACTIONS(7254), 1,
      sym_operator_identifier,
    ACTIONS(7256), 1,
      sym_null_literal,
    STATE(7994), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10790), 1,
      sym_stable_identifier,
    STATE(10816), 1,
      sym_wildcard,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4084), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10995), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [207948] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2252), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4085), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208042] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2226), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4086), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208136] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2052), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4087), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208230] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2130), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4088), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208324] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7258), 1,
      sym_operator_identifier,
    ACTIONS(7260), 1,
      sym_null_literal,
    STATE(6716), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(11004), 1,
      sym_wildcard,
    STATE(11123), 1,
      sym_stable_identifier,
    STATE(15955), 1,
      sym_identifiers,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4089), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11265), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208418] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 8,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7220), 33,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [208474] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7254), 1,
      sym_operator_identifier,
    ACTIONS(7256), 1,
      sym_null_literal,
    ACTIONS(7262), 1,
      anon_sym_RPAREN,
    STATE(7994), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10790), 1,
      sym_stable_identifier,
    STATE(10816), 1,
      sym_wildcard,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4091), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10995), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208568] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2159), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4092), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208662] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2198), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4093), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208756] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2043), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4094), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208850] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2258), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4095), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208944] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7206), 1,
      sym_operator_identifier,
    ACTIONS(7208), 1,
      sym_null_literal,
    STATE(265), 1,
      sym__case_pattern,
    STATE(7298), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10632), 1,
      sym_stable_identifier,
    STATE(10658), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4096), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10880), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [209038] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(233), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4097), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [209132] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2212), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4098), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [209226] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2182), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4099), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [209320] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7254), 1,
      sym_operator_identifier,
    ACTIONS(7256), 1,
      sym_null_literal,
    ACTIONS(7264), 1,
      anon_sym_RPAREN,
    STATE(7994), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10790), 1,
      sym_stable_identifier,
    STATE(10816), 1,
      sym_wildcard,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4100), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10995), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [209414] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2238), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4101), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [209508] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2039), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4102), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [209602] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(7292), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(11072), 1,
      sym_stable_identifier,
    STATE(11121), 1,
      sym_wildcard,
    STATE(15876), 1,
      sym_identifiers,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4103), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11294), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [209696] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2112), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4104), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [209790] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(7293), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10969), 1,
      sym_stable_identifier,
    STATE(11014), 1,
      sym_wildcard,
    STATE(15883), 1,
      sym_identifiers,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4105), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11295), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [209884] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2104), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4106), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [209978] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2058), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4107), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [210072] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2048), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4108), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [210166] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2263), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4109), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [210260] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7274), 1,
      sym_operator_identifier,
    ACTIONS(7276), 1,
      sym_null_literal,
    STATE(6717), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10960), 1,
      sym_wildcard,
    STATE(11126), 1,
      sym_stable_identifier,
    STATE(15908), 1,
      sym_identifiers,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4110), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11136), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [210354] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7278), 1,
      sym_operator_identifier,
    ACTIONS(7280), 1,
      sym_null_literal,
    STATE(6694), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(11106), 1,
      sym_stable_identifier,
    STATE(11132), 1,
      sym_wildcard,
    STATE(15858), 1,
      sym_identifiers,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4111), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11324), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [210448] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2082), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4112), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [210542] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7282), 1,
      anon_sym_RPAREN,
    ACTIONS(7284), 1,
      sym_operator_identifier,
    ACTIONS(7286), 1,
      sym_null_literal,
    STATE(6671), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10579), 1,
      sym_stable_identifier,
    STATE(10583), 1,
      sym_wildcard,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4113), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10752), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [210636] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2205), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4114), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [210730] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2150), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4115), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [210824] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7288), 1,
      anon_sym_RPAREN,
    ACTIONS(7290), 1,
      sym_operator_identifier,
    ACTIONS(7292), 1,
      sym_null_literal,
    STATE(7104), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10497), 1,
      sym_stable_identifier,
    STATE(10509), 1,
      sym_wildcard,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4116), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10742), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [210918] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2177), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4117), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [211012] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2168), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4118), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [211106] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2220), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4119), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [211200] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2266), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4120), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [211294] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7294), 1,
      sym_operator_identifier,
    ACTIONS(7296), 1,
      sym_null_literal,
    STATE(6958), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(11127), 1,
      sym_wildcard,
    STATE(11129), 1,
      sym_stable_identifier,
    STATE(16070), 1,
      sym_identifiers,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4121), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11195), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [211388] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2120), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4122), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [211482] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7254), 1,
      sym_operator_identifier,
    ACTIONS(7256), 1,
      sym_null_literal,
    ACTIONS(7298), 1,
      anon_sym_RPAREN,
    STATE(7994), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10790), 1,
      sym_stable_identifier,
    STATE(10816), 1,
      sym_wildcard,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4123), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10995), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [211576] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2062), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4124), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [211670] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7254), 1,
      sym_operator_identifier,
    ACTIONS(7256), 1,
      sym_null_literal,
    ACTIONS(7300), 1,
      anon_sym_RPAREN,
    STATE(7994), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10790), 1,
      sym_stable_identifier,
    STATE(10816), 1,
      sym_wildcard,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4125), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10995), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [211764] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2077), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4126), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [211858] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2245), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4127), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [211952] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2140), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4128), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [212046] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7254), 1,
      sym_operator_identifier,
    ACTIONS(7256), 1,
      sym_null_literal,
    ACTIONS(7302), 1,
      anon_sym_RPAREN,
    STATE(7994), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10790), 1,
      sym_stable_identifier,
    STATE(10816), 1,
      sym_wildcard,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4129), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10995), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [212140] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7304), 1,
      sym_operator_identifier,
    ACTIONS(7306), 1,
      sym_null_literal,
    STATE(6664), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10951), 1,
      sym_wildcard,
    STATE(11013), 1,
      sym_stable_identifier,
    STATE(15976), 1,
      sym_identifiers,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4130), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11308), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [212234] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2190), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4131), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [212328] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2036), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4132), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [212422] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7308), 1,
      sym_operator_identifier,
    ACTIONS(7310), 1,
      sym_null_literal,
    STATE(6941), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10963), 1,
      sym_stable_identifier,
    STATE(11081), 1,
      sym_wildcard,
    STATE(16016), 1,
      sym_identifiers,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4133), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11188), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [212516] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2095), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4134), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [212610] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2270), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4135), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [212704] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7198), 1,
      sym_operator_identifier,
    ACTIONS(7200), 1,
      sym_null_literal,
    STATE(2274), 1,
      sym__case_pattern,
    STATE(7177), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10566), 1,
      sym_stable_identifier,
    STATE(10603), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4136), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10735), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [212798] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7314), 1,
      anon_sym_COLON,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(7324), 1,
      anon_sym_LPAREN,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(7328), 1,
      sym_operator_identifier,
    ACTIONS(7330), 1,
      sym__automatic_semicolon,
    STATE(4356), 1,
      sym__given_constructor,
    STATE(10660), 1,
      sym_identifier,
    STATE(10729), 1,
      sym__simple_type,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11611), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14119), 1,
      sym_type_parameters,
    STATE(14129), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14294), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16267), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17576), 1,
      sym_template_body,
    STATE(4137), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [212905] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7314), 1,
      anon_sym_COLON,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(7324), 1,
      anon_sym_LPAREN,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(7328), 1,
      sym_operator_identifier,
    ACTIONS(7330), 1,
      sym__automatic_semicolon,
    STATE(4354), 1,
      sym__given_constructor,
    STATE(10660), 1,
      sym_identifier,
    STATE(10729), 1,
      sym__simple_type,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11595), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14119), 1,
      sym_type_parameters,
    STATE(14129), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14400), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16267), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17576), 1,
      sym_template_body,
    STATE(4138), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [213012] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7332), 1,
      sym_operator_identifier,
    ACTIONS(7334), 1,
      sym_null_literal,
    STATE(6892), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10457), 1,
      sym_stable_identifier,
    STATE(10494), 1,
      sym_wildcard,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4139), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10708), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [213103] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7336), 1,
      sym_operator_identifier,
    ACTIONS(7338), 1,
      sym_null_literal,
    STATE(7763), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10692), 1,
      sym_stable_identifier,
    STATE(10764), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4140), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10973), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [213194] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4132), 9,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(7340), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [213251] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7342), 1,
      sym_operator_identifier,
    ACTIONS(7344), 1,
      sym_null_literal,
    STATE(7779), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10737), 1,
      sym_stable_identifier,
    STATE(10745), 1,
      sym_wildcard,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4142), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10985), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [213342] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7346), 1,
      sym_operator_identifier,
    ACTIONS(7348), 1,
      sym_null_literal,
    STATE(7737), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10753), 1,
      sym_wildcard,
    STATE(10845), 1,
      sym_stable_identifier,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4143), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11055), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [213433] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      sym_integer_literal,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7184), 1,
      anon_sym__,
    ACTIONS(7186), 1,
      anon_sym_given,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    ACTIONS(7194), 1,
      anon_sym_SQUOTE,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(7350), 1,
      sym_operator_identifier,
    ACTIONS(7352), 1,
      sym_null_literal,
    STATE(7772), 1,
      sym_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(10677), 1,
      sym_wildcard,
    STATE(10923), 1,
      sym_stable_identifier,
    ACTIONS(6152), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6154), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6156), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4144), 2,
      sym_comment,
      sym_block_comment,
    STATE(11205), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16319), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10975), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [213524] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4132), 9,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(7354), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [213581] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4132), 9,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(7354), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [213638] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7356), 1,
      sym_operator_identifier,
    ACTIONS(7358), 1,
      sym_null_literal,
    STATE(6243), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10129), 1,
      sym_wildcard,
    STATE(10436), 1,
      sym_stable_identifier,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4147), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10459), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [213729] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7360), 1,
      sym_operator_identifier,
    ACTIONS(7362), 1,
      sym_null_literal,
    STATE(7683), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10780), 1,
      sym_stable_identifier,
    STATE(10842), 1,
      sym_wildcard,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4148), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11130), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [213820] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7314), 1,
      anon_sym_COLON,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(7330), 1,
      sym__automatic_semicolon,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7370), 1,
      anon_sym_LPAREN,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(7374), 1,
      sym_operator_identifier,
    STATE(4359), 1,
      sym__given_constructor,
    STATE(10890), 1,
      sym_identifier,
    STATE(11037), 1,
      sym__simple_type,
    STATE(11249), 1,
      sym__annotated_type,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(13188), 1,
      sym_annotated_type,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14119), 1,
      sym_type_parameters,
    STATE(14129), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14602), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17515), 1,
      sym__constructor_application,
    STATE(17576), 1,
      sym_template_body,
    STATE(17819), 1,
      sym_stable_identifier,
    STATE(4149), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11824), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [213927] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7314), 1,
      anon_sym_COLON,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(7330), 1,
      sym__automatic_semicolon,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7370), 1,
      anon_sym_LPAREN,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(7374), 1,
      sym_operator_identifier,
    STATE(4360), 1,
      sym__given_constructor,
    STATE(10890), 1,
      sym_identifier,
    STATE(11037), 1,
      sym__simple_type,
    STATE(11251), 1,
      sym__annotated_type,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(13188), 1,
      sym_annotated_type,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14119), 1,
      sym_type_parameters,
    STATE(14129), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14731), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17515), 1,
      sym__constructor_application,
    STATE(17576), 1,
      sym_template_body,
    STATE(17819), 1,
      sym_stable_identifier,
    STATE(4150), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11824), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [214034] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      sym_operator_identifier,
    ACTIONS(7378), 1,
      sym_null_literal,
    STATE(7706), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10665), 1,
      sym_wildcard,
    STATE(10928), 1,
      sym_stable_identifier,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4151), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11102), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [214125] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7380), 1,
      sym_operator_identifier,
    ACTIONS(7382), 1,
      sym_null_literal,
    STATE(6131), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10158), 1,
      sym_stable_identifier,
    STATE(10226), 1,
      sym_wildcard,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4152), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10656), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [214216] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7384), 1,
      sym_operator_identifier,
    ACTIONS(7386), 1,
      sym_null_literal,
    STATE(6756), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10581), 1,
      sym_wildcard,
    STATE(10600), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4153), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10783), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [214307] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7388), 1,
      sym_operator_identifier,
    ACTIONS(7390), 1,
      sym_null_literal,
    STATE(7301), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10470), 1,
      sym_stable_identifier,
    STATE(10472), 1,
      sym_wildcard,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4154), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10945), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [214398] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7314), 1,
      anon_sym_COLON,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(7330), 1,
      sym__automatic_semicolon,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7370), 1,
      anon_sym_LPAREN,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(7374), 1,
      sym_operator_identifier,
    STATE(4297), 1,
      sym__given_constructor,
    STATE(10890), 1,
      sym_identifier,
    STATE(11037), 1,
      sym__simple_type,
    STATE(11472), 1,
      sym__annotated_type,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(13188), 1,
      sym_annotated_type,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14119), 1,
      sym_type_parameters,
    STATE(14129), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14456), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17515), 1,
      sym__constructor_application,
    STATE(17576), 1,
      sym_template_body,
    STATE(17819), 1,
      sym_stable_identifier,
    STATE(4155), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11824), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [214505] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4132), 9,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(7340), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [214562] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7392), 1,
      sym_operator_identifier,
    ACTIONS(7394), 1,
      sym_null_literal,
    STATE(6901), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10531), 1,
      sym_wildcard,
    STATE(10577), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4157), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10667), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [214653] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4132), 9,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(7354), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [214710] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7314), 1,
      anon_sym_COLON,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(7324), 1,
      anon_sym_LPAREN,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(7328), 1,
      sym_operator_identifier,
    ACTIONS(7330), 1,
      sym__automatic_semicolon,
    STATE(4357), 1,
      sym__given_constructor,
    STATE(10660), 1,
      sym_identifier,
    STATE(10729), 1,
      sym__simple_type,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11613), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14119), 1,
      sym_type_parameters,
    STATE(14129), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14354), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16267), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17576), 1,
      sym_template_body,
    STATE(4159), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [214817] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7314), 1,
      anon_sym_COLON,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(7330), 1,
      sym__automatic_semicolon,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7370), 1,
      anon_sym_LPAREN,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(7374), 1,
      sym_operator_identifier,
    STATE(4358), 1,
      sym__given_constructor,
    STATE(10890), 1,
      sym_identifier,
    STATE(11037), 1,
      sym__simple_type,
    STATE(11247), 1,
      sym__annotated_type,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(13188), 1,
      sym_annotated_type,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14119), 1,
      sym_type_parameters,
    STATE(14129), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14456), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17515), 1,
      sym__constructor_application,
    STATE(17576), 1,
      sym_template_body,
    STATE(17819), 1,
      sym_stable_identifier,
    STATE(4160), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11824), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [214924] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4161), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 32,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_EQ_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [214979] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4132), 9,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(7396), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [215036] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7314), 1,
      anon_sym_COLON,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(7324), 1,
      anon_sym_LPAREN,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(7328), 1,
      sym_operator_identifier,
    ACTIONS(7330), 1,
      sym__automatic_semicolon,
    STATE(4349), 1,
      sym__given_constructor,
    STATE(10660), 1,
      sym_identifier,
    STATE(10729), 1,
      sym__simple_type,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11473), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14119), 1,
      sym_type_parameters,
    STATE(14129), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14294), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16267), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17576), 1,
      sym_template_body,
    STATE(4163), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [215143] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 32,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_EQ_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [215198] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7314), 1,
      anon_sym_COLON,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(7324), 1,
      anon_sym_LPAREN,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(7328), 1,
      sym_operator_identifier,
    ACTIONS(7330), 1,
      sym__automatic_semicolon,
    STATE(4364), 1,
      sym__given_constructor,
    STATE(10660), 1,
      sym_identifier,
    STATE(10729), 1,
      sym__simple_type,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11305), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14119), 1,
      sym_type_parameters,
    STATE(14129), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14400), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16267), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17576), 1,
      sym_template_body,
    STATE(4165), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [215305] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4166), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4132), 9,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(7396), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [215362] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7254), 1,
      sym_operator_identifier,
    ACTIONS(7256), 1,
      sym_null_literal,
    STATE(7994), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10790), 1,
      sym_stable_identifier,
    STATE(10816), 1,
      sym_wildcard,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4167), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10995), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [215453] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4132), 9,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(7340), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [215510] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7398), 1,
      sym_operator_identifier,
    ACTIONS(7400), 1,
      sym_null_literal,
    STATE(6669), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10526), 1,
      sym_stable_identifier,
    STATE(10532), 1,
      sym_wildcard,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4169), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10871), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [215601] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7314), 1,
      anon_sym_COLON,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(7324), 1,
      anon_sym_LPAREN,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(7328), 1,
      sym_operator_identifier,
    ACTIONS(7330), 1,
      sym__automatic_semicolon,
    STATE(4365), 1,
      sym__given_constructor,
    STATE(10660), 1,
      sym_identifier,
    STATE(10729), 1,
      sym__simple_type,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11312), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14119), 1,
      sym_type_parameters,
    STATE(14129), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14294), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16267), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17576), 1,
      sym_template_body,
    STATE(4170), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [215708] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7314), 1,
      anon_sym_COLON,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(7324), 1,
      anon_sym_LPAREN,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(7328), 1,
      sym_operator_identifier,
    ACTIONS(7330), 1,
      sym__automatic_semicolon,
    STATE(4352), 1,
      sym__given_constructor,
    STATE(10660), 1,
      sym_identifier,
    STATE(10729), 1,
      sym__simple_type,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11462), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14119), 1,
      sym_type_parameters,
    STATE(14129), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14400), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16267), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17576), 1,
      sym_template_body,
    STATE(4171), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [215815] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7314), 1,
      anon_sym_COLON,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(7330), 1,
      sym__automatic_semicolon,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7370), 1,
      anon_sym_LPAREN,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(7374), 1,
      sym_operator_identifier,
    STATE(4302), 1,
      sym__given_constructor,
    STATE(10890), 1,
      sym_identifier,
    STATE(11037), 1,
      sym__simple_type,
    STATE(11514), 1,
      sym__annotated_type,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(13188), 1,
      sym_annotated_type,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14119), 1,
      sym_type_parameters,
    STATE(14129), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14602), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17515), 1,
      sym__constructor_application,
    STATE(17576), 1,
      sym_template_body,
    STATE(17819), 1,
      sym_stable_identifier,
    STATE(4172), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11824), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [215922] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6474), 1,
      sym_integer_literal,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6904), 1,
      anon_sym__,
    ACTIONS(6906), 1,
      anon_sym_given,
    ACTIONS(6914), 1,
      anon_sym_SQUOTE,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(7150), 1,
      anon_sym_LPAREN,
    ACTIONS(7402), 1,
      sym_operator_identifier,
    ACTIONS(7404), 1,
      sym_null_literal,
    STATE(6189), 1,
      sym_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10253), 1,
      sym_wildcard,
    STATE(10281), 1,
      sym_stable_identifier,
    ACTIONS(6476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4173), 2,
      sym_comment,
      sym_block_comment,
    STATE(10847), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16825), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10592), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [216013] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      sym_integer_literal,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7226), 1,
      anon_sym__,
    ACTIONS(7228), 1,
      anon_sym_given,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    ACTIONS(7234), 1,
      anon_sym_SQUOTE,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(7406), 1,
      sym_operator_identifier,
    ACTIONS(7408), 1,
      sym_null_literal,
    STATE(6909), 1,
      sym_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10452), 1,
      sym_wildcard,
    STATE(10608), 1,
      sym_stable_identifier,
    ACTIONS(6166), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6168), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6170), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4174), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17561), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10684), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [216104] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7314), 1,
      anon_sym_COLON,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(7324), 1,
      anon_sym_LPAREN,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(7328), 1,
      sym_operator_identifier,
    ACTIONS(7330), 1,
      sym__automatic_semicolon,
    STATE(4366), 1,
      sym__given_constructor,
    STATE(10660), 1,
      sym_identifier,
    STATE(10729), 1,
      sym__simple_type,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11458), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14119), 1,
      sym_type_parameters,
    STATE(14129), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14354), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16267), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17576), 1,
      sym_template_body,
    STATE(4175), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [216211] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7314), 1,
      anon_sym_COLON,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(7330), 1,
      sym__automatic_semicolon,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7370), 1,
      anon_sym_LPAREN,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(7374), 1,
      sym_operator_identifier,
    STATE(4306), 1,
      sym__given_constructor,
    STATE(10890), 1,
      sym_identifier,
    STATE(11037), 1,
      sym__simple_type,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(11570), 1,
      sym__annotated_type,
    STATE(13188), 1,
      sym_annotated_type,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14119), 1,
      sym_type_parameters,
    STATE(14129), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14731), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17515), 1,
      sym__constructor_application,
    STATE(17576), 1,
      sym_template_body,
    STATE(17819), 1,
      sym_stable_identifier,
    STATE(4176), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11824), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [216318] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4132), 9,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(7396), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [216375] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7314), 1,
      anon_sym_COLON,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(7324), 1,
      anon_sym_LPAREN,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(7328), 1,
      sym_operator_identifier,
    ACTIONS(7330), 1,
      sym__automatic_semicolon,
    STATE(4373), 1,
      sym__given_constructor,
    STATE(10660), 1,
      sym_identifier,
    STATE(10729), 1,
      sym__simple_type,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11719), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14119), 1,
      sym_type_parameters,
    STATE(14129), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14354), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16267), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17576), 1,
      sym_template_body,
    STATE(4178), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [216482] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 39,
      anon_sym_enum,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_EQ_GT,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [216534] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6690), 1,
      sym__alpha_identifier,
    ACTIONS(6696), 1,
      anon_sym__,
    ACTIONS(6704), 1,
      sym__backquoted_id,
    ACTIONS(6706), 1,
      sym_operator_identifier,
    ACTIONS(7412), 1,
      anon_sym_LPAREN,
    ACTIONS(7414), 1,
      sym_integer_literal,
    STATE(4898), 1,
      sym__annotated_type,
    STATE(4955), 1,
      sym__simple_type,
    STATE(5112), 1,
      sym_identifier,
    STATE(5191), 1,
      sym__soft_identifier,
    STATE(8039), 1,
      sym_annotated_type,
    STATE(8216), 1,
      sym__infix_type_choice,
    STATE(9697), 1,
      sym__non_null_literal,
    STATE(17215), 1,
      sym_stable_identifier,
    ACTIONS(7416), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7418), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7420), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4180), 2,
      sym_comment,
      sym_block_comment,
    STATE(9693), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9568), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5795), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [216625] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4408), 1,
      sym__alpha_identifier,
    ACTIONS(4410), 1,
      anon_sym__,
    ACTIONS(4420), 1,
      sym__backquoted_id,
    ACTIONS(6820), 1,
      sym_operator_identifier,
    ACTIONS(7422), 1,
      anon_sym_LPAREN,
    ACTIONS(7424), 1,
      sym_integer_literal,
    STATE(4385), 1,
      sym__simple_type,
    STATE(4409), 1,
      sym__annotated_type,
    STATE(4469), 1,
      sym_identifier,
    STATE(4476), 1,
      sym__soft_identifier,
    STATE(5974), 1,
      sym_annotated_type,
    STATE(6489), 1,
      sym__infix_type_choice,
    STATE(7693), 1,
      sym__non_null_literal,
    STATE(17191), 1,
      sym_stable_identifier,
    ACTIONS(7426), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7428), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7430), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4181), 2,
      sym_comment,
      sym_block_comment,
    STATE(7714), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7483), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4416), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4659), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [216716] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4572), 1,
      sym__alpha_identifier,
    ACTIONS(4578), 1,
      anon_sym__,
    ACTIONS(4590), 1,
      sym__backquoted_id,
    ACTIONS(6896), 1,
      sym_operator_identifier,
    ACTIONS(7432), 1,
      anon_sym_LPAREN,
    ACTIONS(7434), 1,
      sym_integer_literal,
    STATE(4642), 1,
      sym__annotated_type,
    STATE(4753), 1,
      sym__simple_type,
    STATE(5024), 1,
      sym_identifier,
    STATE(5025), 1,
      sym__soft_identifier,
    STATE(6780), 1,
      sym_annotated_type,
    STATE(8011), 1,
      sym__infix_type_choice,
    STATE(9121), 1,
      sym__non_null_literal,
    STATE(17351), 1,
      sym_stable_identifier,
    ACTIONS(7436), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7438), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7440), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4182), 2,
      sym_comment,
      sym_block_comment,
    STATE(9210), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9033), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5296), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [216807] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4434), 1,
      sym__alpha_identifier,
    ACTIONS(4440), 1,
      anon_sym__,
    ACTIONS(4452), 1,
      sym__backquoted_id,
    ACTIONS(6862), 1,
      sym_operator_identifier,
    ACTIONS(7442), 1,
      anon_sym_LPAREN,
    ACTIONS(7444), 1,
      sym_integer_literal,
    STATE(4579), 1,
      sym__annotated_type,
    STATE(4590), 1,
      sym__simple_type,
    STATE(4870), 1,
      sym_identifier,
    STATE(4948), 1,
      sym__soft_identifier,
    STATE(7281), 1,
      sym_annotated_type,
    STATE(7999), 1,
      sym__infix_type_choice,
    STATE(9263), 1,
      sym__non_null_literal,
    STATE(17203), 1,
      sym_stable_identifier,
    ACTIONS(7446), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7448), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7450), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4183), 2,
      sym_comment,
      sym_block_comment,
    STATE(9271), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8739), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4446), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5122), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [216898] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym__alpha_identifier,
    ACTIONS(6462), 1,
      anon_sym__,
    ACTIONS(6470), 1,
      sym__backquoted_id,
    ACTIONS(6472), 1,
      sym_operator_identifier,
    ACTIONS(7452), 1,
      anon_sym_LPAREN,
    ACTIONS(7454), 1,
      sym_integer_literal,
    STATE(5654), 1,
      sym__simple_type,
    STATE(6003), 1,
      sym_identifier,
    STATE(6067), 1,
      sym__annotated_type,
    STATE(6313), 1,
      sym__soft_identifier,
    STATE(9480), 1,
      sym__infix_type_choice,
    STATE(9520), 1,
      sym_annotated_type,
    STATE(10197), 1,
      sym__non_null_literal,
    STATE(16863), 1,
      sym_stable_identifier,
    ACTIONS(7456), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7458), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7460), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4184), 2,
      sym_comment,
      sym_block_comment,
    STATE(10311), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10204), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6466), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [216989] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4286), 1,
      sym__alpha_identifier,
    ACTIONS(4288), 1,
      anon_sym__,
    ACTIONS(4298), 1,
      sym__backquoted_id,
    ACTIONS(6538), 1,
      sym_operator_identifier,
    ACTIONS(7462), 1,
      anon_sym_LPAREN,
    ACTIONS(7464), 1,
      sym_integer_literal,
    STATE(4435), 1,
      sym__annotated_type,
    STATE(4440), 1,
      sym__simple_type,
    STATE(4467), 1,
      sym__soft_identifier,
    STATE(4504), 1,
      sym_identifier,
    STATE(5824), 1,
      sym_annotated_type,
    STATE(6432), 1,
      sym__infix_type_choice,
    STATE(7474), 1,
      sym__non_null_literal,
    STATE(16363), 1,
      sym_stable_identifier,
    ACTIONS(7466), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7468), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7470), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4185), 2,
      sym_comment,
      sym_block_comment,
    STATE(7729), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7521), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4294), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4713), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [217080] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4640), 1,
      sym__alpha_identifier,
    ACTIONS(4642), 1,
      anon_sym__,
    ACTIONS(4652), 1,
      sym__backquoted_id,
    ACTIONS(6688), 1,
      sym_operator_identifier,
    ACTIONS(7472), 1,
      anon_sym_LPAREN,
    ACTIONS(7474), 1,
      sym_integer_literal,
    STATE(7245), 1,
      sym__simple_type,
    STATE(7305), 1,
      sym__annotated_type,
    STATE(7872), 1,
      sym__soft_identifier,
    STATE(7995), 1,
      sym_identifier,
    STATE(9803), 1,
      sym_annotated_type,
    STATE(10274), 1,
      sym__infix_type_choice,
    STATE(10897), 1,
      sym__non_null_literal,
    STATE(17142), 1,
      sym_stable_identifier,
    ACTIONS(7476), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7478), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7480), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4186), 2,
      sym_comment,
      sym_block_comment,
    STATE(10866), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10757), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4648), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8425), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [217171] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(7482), 1,
      anon_sym_LPAREN,
    ACTIONS(7484), 1,
      sym_integer_literal,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(7216), 1,
      sym__annotated_type,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(9835), 1,
      sym__non_null_literal,
    STATE(9985), 1,
      sym__infix_type_choice,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(7486), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7488), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7490), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4187), 2,
      sym_comment,
      sym_block_comment,
    STATE(9918), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9774), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [217262] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    ACTIONS(7492), 1,
      anon_sym_LPAREN,
    ACTIONS(7494), 1,
      sym_integer_literal,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7393), 1,
      sym__annotated_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10191), 1,
      sym__infix_type_choice,
    STATE(10654), 1,
      sym__non_null_literal,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(7496), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7498), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7500), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4188), 2,
      sym_comment,
      sym_block_comment,
    STATE(10545), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10462), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [217353] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6370), 1,
      sym__alpha_identifier,
    ACTIONS(6376), 1,
      anon_sym__,
    ACTIONS(6384), 1,
      sym__backquoted_id,
    ACTIONS(6386), 1,
      sym_operator_identifier,
    ACTIONS(7502), 1,
      anon_sym_LPAREN,
    ACTIONS(7504), 1,
      sym_integer_literal,
    STATE(5383), 1,
      sym__annotated_type,
    STATE(5425), 1,
      sym__simple_type,
    STATE(5485), 1,
      sym__soft_identifier,
    STATE(5665), 1,
      sym_identifier,
    STATE(8696), 1,
      sym_annotated_type,
    STATE(9041), 1,
      sym__infix_type_choice,
    STATE(10122), 1,
      sym__non_null_literal,
    STATE(16818), 1,
      sym_stable_identifier,
    ACTIONS(7506), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7508), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7510), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4189), 2,
      sym_comment,
      sym_block_comment,
    STATE(9893), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10012), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6380), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6556), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [217444] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4254), 1,
      sym__alpha_identifier,
    ACTIONS(4260), 1,
      anon_sym__,
    ACTIONS(4272), 1,
      sym__backquoted_id,
    ACTIONS(6732), 1,
      sym_operator_identifier,
    ACTIONS(7512), 1,
      anon_sym_LPAREN,
    ACTIONS(7514), 1,
      sym_integer_literal,
    STATE(4724), 1,
      sym__annotated_type,
    STATE(4744), 1,
      sym__simple_type,
    STATE(4846), 1,
      sym_identifier,
    STATE(4941), 1,
      sym__soft_identifier,
    STATE(7118), 1,
      sym_annotated_type,
    STATE(7916), 1,
      sym__infix_type_choice,
    STATE(9151), 1,
      sym__non_null_literal,
    STATE(17161), 1,
      sym_stable_identifier,
    ACTIONS(7516), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7518), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7520), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4190), 2,
      sym_comment,
      sym_block_comment,
    STATE(9161), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8760), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4266), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5096), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [217535] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6580), 1,
      anon_sym__,
    ACTIONS(6588), 1,
      sym__backquoted_id,
    ACTIONS(6590), 1,
      sym_operator_identifier,
    ACTIONS(7522), 1,
      anon_sym_LPAREN,
    ACTIONS(7524), 1,
      sym_integer_literal,
    STATE(5708), 1,
      sym__simple_type,
    STATE(6199), 1,
      sym__soft_identifier,
    STATE(6337), 1,
      sym_identifier,
    STATE(6611), 1,
      sym__annotated_type,
    STATE(9519), 1,
      sym_annotated_type,
    STATE(10015), 1,
      sym__infix_type_choice,
    STATE(10554), 1,
      sym__non_null_literal,
    STATE(16404), 1,
      sym_stable_identifier,
    ACTIONS(7526), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7528), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7530), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4191), 2,
      sym_comment,
      sym_block_comment,
    STATE(10499), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10556), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7227), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [217626] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(7532), 1,
      anon_sym_LPAREN,
    ACTIONS(7534), 1,
      sym_integer_literal,
    STATE(5011), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8475), 1,
      sym__infix_type_choice,
    STATE(8857), 1,
      sym__non_null_literal,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(7536), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7538), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7540), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4192), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9239), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [217717] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6344), 1,
      sym__alpha_identifier,
    ACTIONS(6350), 1,
      anon_sym__,
    ACTIONS(6358), 1,
      sym__backquoted_id,
    ACTIONS(6360), 1,
      sym_operator_identifier,
    ACTIONS(7542), 1,
      anon_sym_LPAREN,
    ACTIONS(7544), 1,
      sym_integer_literal,
    STATE(5615), 1,
      sym__simple_type,
    STATE(5887), 1,
      sym__annotated_type,
    STATE(6141), 1,
      sym__soft_identifier,
    STATE(6576), 1,
      sym_identifier,
    STATE(9227), 1,
      sym_annotated_type,
    STATE(9709), 1,
      sym__infix_type_choice,
    STATE(10237), 1,
      sym__non_null_literal,
    STATE(17089), 1,
      sym_stable_identifier,
    ACTIONS(7546), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7548), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7550), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4193), 2,
      sym_comment,
      sym_block_comment,
    STATE(10363), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10400), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6354), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7247), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [217808] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(7552), 1,
      anon_sym_LPAREN,
    ACTIONS(7554), 1,
      sym_integer_literal,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5449), 1,
      sym__annotated_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(9182), 1,
      sym__infix_type_choice,
    STATE(9866), 1,
      sym__non_null_literal,
    STATE(17593), 1,
      sym_stable_identifier,
    ACTIONS(7556), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7558), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7560), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4194), 2,
      sym_comment,
      sym_block_comment,
    STATE(9973), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9933), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [217899] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6712), 1,
      sym__alpha_identifier,
    ACTIONS(6718), 1,
      anon_sym__,
    ACTIONS(6726), 1,
      sym__backquoted_id,
    ACTIONS(6728), 1,
      sym_operator_identifier,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7564), 1,
      sym_integer_literal,
    STATE(5467), 1,
      sym__annotated_type,
    STATE(5977), 1,
      sym__simple_type,
    STATE(6378), 1,
      sym__soft_identifier,
    STATE(6583), 1,
      sym_identifier,
    STATE(9268), 1,
      sym_annotated_type,
    STATE(9372), 1,
      sym__infix_type_choice,
    STATE(10385), 1,
      sym__non_null_literal,
    STATE(17227), 1,
      sym_stable_identifier,
    ACTIONS(7566), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7568), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7570), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4195), 2,
      sym_comment,
      sym_block_comment,
    STATE(10380), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10139), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6722), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7014), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [217990] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    ACTIONS(7572), 1,
      anon_sym_LPAREN,
    ACTIONS(7574), 1,
      sym_integer_literal,
    STATE(4622), 1,
      sym__annotated_type,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(7655), 1,
      sym__infix_type_choice,
    STATE(8681), 1,
      sym__non_null_literal,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(7576), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7578), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7580), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4196), 2,
      sym_comment,
      sym_block_comment,
    STATE(8252), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8246), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [218081] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4468), 1,
      sym__alpha_identifier,
    ACTIONS(4474), 1,
      anon_sym__,
    ACTIONS(4486), 1,
      sym__backquoted_id,
    ACTIONS(6866), 1,
      sym_operator_identifier,
    ACTIONS(7582), 1,
      anon_sym_LPAREN,
    ACTIONS(7584), 1,
      sym_integer_literal,
    STATE(6182), 1,
      sym__annotated_type,
    STATE(6206), 1,
      sym__simple_type,
    STATE(6759), 1,
      sym__soft_identifier,
    STATE(6938), 1,
      sym_identifier,
    STATE(9655), 1,
      sym_annotated_type,
    STATE(9939), 1,
      sym__infix_type_choice,
    STATE(10530), 1,
      sym__non_null_literal,
    STATE(16590), 1,
      sym_stable_identifier,
    ACTIONS(7586), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7588), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7590), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4197), 2,
      sym_comment,
      sym_block_comment,
    STATE(10559), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10480), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4480), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8071), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [218172] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(7592), 1,
      anon_sym_LPAREN,
    ACTIONS(7594), 1,
      sym_integer_literal,
    STATE(6223), 1,
      sym__annotated_type,
    STATE(6295), 1,
      sym__simple_type,
    STATE(6834), 1,
      sym__soft_identifier,
    STATE(7296), 1,
      sym_identifier,
    STATE(9681), 1,
      sym_annotated_type,
    STATE(10110), 1,
      sym__infix_type_choice,
    STATE(10589), 1,
      sym__non_null_literal,
    STATE(16630), 1,
      sym_stable_identifier,
    ACTIONS(7596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7600), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4198), 2,
      sym_comment,
      sym_block_comment,
    STATE(10649), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10647), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7652), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [218263] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4312), 1,
      sym__alpha_identifier,
    ACTIONS(4318), 1,
      anon_sym__,
    ACTIONS(4330), 1,
      sym__backquoted_id,
    ACTIONS(6790), 1,
      sym_operator_identifier,
    ACTIONS(7602), 1,
      anon_sym_LPAREN,
    ACTIONS(7604), 1,
      sym_integer_literal,
    STATE(5063), 1,
      sym__annotated_type,
    STATE(5344), 1,
      sym__simple_type,
    STATE(5532), 1,
      sym__soft_identifier,
    STATE(5857), 1,
      sym_identifier,
    STATE(8214), 1,
      sym_annotated_type,
    STATE(8717), 1,
      sym__infix_type_choice,
    STATE(9938), 1,
      sym__non_null_literal,
    STATE(17179), 1,
      sym_stable_identifier,
    ACTIONS(7606), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7608), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7610), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4199), 2,
      sym_comment,
      sym_block_comment,
    STATE(9953), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10117), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4324), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6288), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [218354] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4770), 1,
      sym__alpha_identifier,
    ACTIONS(4772), 1,
      anon_sym__,
    ACTIONS(4782), 1,
      sym__backquoted_id,
    ACTIONS(6710), 1,
      sym_operator_identifier,
    ACTIONS(7612), 1,
      anon_sym_LPAREN,
    ACTIONS(7614), 1,
      sym_integer_literal,
    STATE(4279), 1,
      sym__simple_type,
    STATE(4379), 1,
      sym__annotated_type,
    STATE(4395), 1,
      sym_identifier,
    STATE(4399), 1,
      sym__soft_identifier,
    STATE(5134), 1,
      sym_annotated_type,
    STATE(5893), 1,
      sym__infix_type_choice,
    STATE(7363), 1,
      sym__non_null_literal,
    STATE(17007), 1,
      sym_stable_identifier,
    ACTIONS(7616), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7618), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7620), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4200), 2,
      sym_comment,
      sym_block_comment,
    STATE(6760), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7239), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4778), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4539), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [218445] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4344), 1,
      sym__alpha_identifier,
    ACTIONS(4350), 1,
      anon_sym__,
    ACTIONS(4362), 1,
      sym__backquoted_id,
    ACTIONS(6816), 1,
      sym_operator_identifier,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7624), 1,
      sym_integer_literal,
    STATE(5535), 1,
      sym__annotated_type,
    STATE(5792), 1,
      sym__simple_type,
    STATE(6290), 1,
      sym__soft_identifier,
    STATE(6431), 1,
      sym_identifier,
    STATE(9068), 1,
      sym_annotated_type,
    STATE(9570), 1,
      sym__infix_type_choice,
    STATE(10152), 1,
      sym__non_null_literal,
    STATE(17185), 1,
      sym_stable_identifier,
    ACTIONS(7626), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7628), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7630), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4201), 2,
      sym_comment,
      sym_block_comment,
    STATE(10177), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10151), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4356), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6857), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [218536] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    ACTIONS(7632), 1,
      anon_sym_LPAREN,
    ACTIONS(7634), 1,
      sym_integer_literal,
    STATE(6970), 1,
      sym__simple_type,
    STATE(7469), 1,
      sym__annotated_type,
    STATE(7680), 1,
      sym__soft_identifier,
    STATE(7825), 1,
      sym_identifier,
    STATE(10180), 1,
      sym_annotated_type,
    STATE(10183), 1,
      sym__infix_type_choice,
    STATE(10915), 1,
      sym__non_null_literal,
    STATE(16467), 1,
      sym_stable_identifier,
    ACTIONS(7636), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7638), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7640), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4202), 2,
      sym_comment,
      sym_block_comment,
    STATE(10702), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10727), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8431), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [218627] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    ACTIONS(7492), 1,
      anon_sym_LPAREN,
    ACTIONS(7494), 1,
      sym_integer_literal,
    STATE(6667), 1,
      sym__annotated_type,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(10283), 1,
      sym__infix_type_choice,
    STATE(10654), 1,
      sym__non_null_literal,
    STATE(16238), 1,
      sym_stable_identifier,
    ACTIONS(7496), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7498), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7500), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4203), 2,
      sym_comment,
      sym_block_comment,
    STATE(10545), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10462), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [218718] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    ACTIONS(7642), 1,
      anon_sym_LPAREN,
    ACTIONS(7644), 1,
      sym_integer_literal,
    STATE(5087), 1,
      sym__simple_type,
    STATE(5211), 1,
      sym__annotated_type,
    STATE(5538), 1,
      sym__soft_identifier,
    STATE(5956), 1,
      sym_identifier,
    STATE(8528), 1,
      sym_annotated_type,
    STATE(8759), 1,
      sym__infix_type_choice,
    STATE(10038), 1,
      sym__non_null_literal,
    STATE(17275), 1,
      sym_stable_identifier,
    ACTIONS(7646), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7648), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7650), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4204), 2,
      sym_comment,
      sym_block_comment,
    STATE(9922), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9811), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6616), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [218809] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6114), 1,
      sym__alpha_identifier,
    ACTIONS(6120), 1,
      anon_sym__,
    ACTIONS(6128), 1,
      sym__backquoted_id,
    ACTIONS(6130), 1,
      sym_operator_identifier,
    ACTIONS(7652), 1,
      anon_sym_LPAREN,
    ACTIONS(7654), 1,
      sym_integer_literal,
    STATE(4957), 1,
      sym__annotated_type,
    STATE(5030), 1,
      sym__simple_type,
    STATE(5135), 1,
      sym_identifier,
    STATE(5193), 1,
      sym__soft_identifier,
    STATE(7769), 1,
      sym_annotated_type,
    STATE(8250), 1,
      sym__infix_type_choice,
    STATE(9560), 1,
      sym__non_null_literal,
    STATE(17257), 1,
      sym_stable_identifier,
    ACTIONS(7656), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7658), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7660), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4205), 2,
      sym_comment,
      sym_block_comment,
    STATE(9724), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9651), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6124), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5886), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [218900] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6774), 1,
      sym__alpha_identifier,
    ACTIONS(6776), 1,
      anon_sym__,
    ACTIONS(6784), 1,
      sym__backquoted_id,
    ACTIONS(6786), 1,
      sym_operator_identifier,
    ACTIONS(7662), 1,
      anon_sym_LPAREN,
    ACTIONS(7664), 1,
      sym_integer_literal,
    STATE(4495), 1,
      sym__simple_type,
    STATE(4523), 1,
      sym__annotated_type,
    STATE(4574), 1,
      sym_identifier,
    STATE(4626), 1,
      sym__soft_identifier,
    STATE(6388), 1,
      sym_annotated_type,
    STATE(6866), 1,
      sym__infix_type_choice,
    STATE(8113), 1,
      sym__non_null_literal,
    STATE(17251), 1,
      sym_stable_identifier,
    ACTIONS(7666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7670), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4206), 2,
      sym_comment,
      sym_block_comment,
    STATE(8109), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8396), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6780), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4851), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [218991] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6650), 1,
      sym__alpha_identifier,
    ACTIONS(6656), 1,
      anon_sym__,
    ACTIONS(6664), 1,
      sym__backquoted_id,
    ACTIONS(6666), 1,
      sym_operator_identifier,
    ACTIONS(7672), 1,
      anon_sym_LPAREN,
    ACTIONS(7674), 1,
      sym_integer_literal,
    STATE(5598), 1,
      sym__simple_type,
    STATE(5756), 1,
      sym__annotated_type,
    STATE(6112), 1,
      sym_identifier,
    STATE(6233), 1,
      sym__soft_identifier,
    STATE(8943), 1,
      sym_annotated_type,
    STATE(9366), 1,
      sym__infix_type_choice,
    STATE(10435), 1,
      sym__non_null_literal,
    STATE(17149), 1,
      sym_stable_identifier,
    ACTIONS(7676), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7678), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7680), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4207), 2,
      sym_comment,
      sym_block_comment,
    STATE(10186), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10140), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6660), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6764), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [219082] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    ACTIONS(7572), 1,
      anon_sym_LPAREN,
    ACTIONS(7574), 1,
      sym_integer_literal,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(6869), 1,
      sym__annotated_type,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(8681), 1,
      sym__non_null_literal,
    STATE(9984), 1,
      sym__infix_type_choice,
    STATE(16383), 1,
      sym_stable_identifier,
    ACTIONS(7576), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7578), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7580), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4208), 2,
      sym_comment,
      sym_block_comment,
    STATE(8252), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8246), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [219173] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4510), 1,
      sym__alpha_identifier,
    ACTIONS(4512), 1,
      anon_sym__,
    ACTIONS(4522), 1,
      sym__backquoted_id,
    ACTIONS(6884), 1,
      sym_operator_identifier,
    ACTIONS(7682), 1,
      anon_sym_LPAREN,
    ACTIONS(7684), 1,
      sym_integer_literal,
    STATE(4529), 1,
      sym__annotated_type,
    STATE(4538), 1,
      sym__simple_type,
    STATE(4572), 1,
      sym__soft_identifier,
    STATE(4611), 1,
      sym_identifier,
    STATE(6644), 1,
      sym_annotated_type,
    STATE(7022), 1,
      sym__infix_type_choice,
    STATE(8491), 1,
      sym__non_null_literal,
    STATE(16708), 1,
      sym_stable_identifier,
    ACTIONS(7686), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7688), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7690), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4209), 2,
      sym_comment,
      sym_block_comment,
    STATE(8153), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8302), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4518), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4978), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [219264] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(7532), 1,
      anon_sym_LPAREN,
    ACTIONS(7534), 1,
      sym_integer_literal,
    STATE(5011), 1,
      sym__annotated_type,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8857), 1,
      sym__non_null_literal,
    STATE(11712), 1,
      sym__infix_type_choice,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(7536), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7538), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7540), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4210), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9239), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [219355] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(7692), 1,
      anon_sym_LPAREN,
    ACTIONS(7694), 1,
      sym_integer_literal,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6369), 1,
      sym__annotated_type,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(9549), 1,
      sym__infix_type_choice,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(10389), 1,
      sym__non_null_literal,
    STATE(17060), 1,
      sym_stable_identifier,
    ACTIONS(7696), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7698), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7700), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4211), 2,
      sym_comment,
      sym_block_comment,
    STATE(10337), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10319), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [219446] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6760), 1,
      sym__alpha_identifier,
    ACTIONS(6762), 1,
      anon_sym__,
    ACTIONS(6770), 1,
      sym__backquoted_id,
    ACTIONS(6772), 1,
      sym_operator_identifier,
    ACTIONS(7702), 1,
      anon_sym_LPAREN,
    ACTIONS(7704), 1,
      sym_integer_literal,
    STATE(4677), 1,
      sym__simple_type,
    STATE(4743), 1,
      sym__annotated_type,
    STATE(4900), 1,
      sym_identifier,
    STATE(4925), 1,
      sym__soft_identifier,
    STATE(6971), 1,
      sym_annotated_type,
    STATE(7923), 1,
      sym__infix_type_choice,
    STATE(9280), 1,
      sym__non_null_literal,
    STATE(17018), 1,
      sym_stable_identifier,
    ACTIONS(7706), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7708), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7710), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4212), 2,
      sym_comment,
      sym_block_comment,
    STATE(8862), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9204), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6766), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5278), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [219537] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6626), 1,
      sym__alpha_identifier,
    ACTIONS(6632), 1,
      anon_sym__,
    ACTIONS(6640), 1,
      sym__backquoted_id,
    ACTIONS(6642), 1,
      sym_operator_identifier,
    ACTIONS(7712), 1,
      anon_sym_LPAREN,
    ACTIONS(7714), 1,
      sym_integer_literal,
    STATE(4681), 1,
      sym__simple_type,
    STATE(4695), 1,
      sym__annotated_type,
    STATE(4939), 1,
      sym__soft_identifier,
    STATE(4959), 1,
      sym_identifier,
    STATE(7063), 1,
      sym_annotated_type,
    STATE(7983), 1,
      sym__infix_type_choice,
    STATE(9101), 1,
      sym__non_null_literal,
    STATE(17137), 1,
      sym_stable_identifier,
    ACTIONS(7716), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7718), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7720), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4213), 2,
      sym_comment,
      sym_block_comment,
    STATE(9119), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9077), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5078), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [219628] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6506), 1,
      anon_sym__,
    ACTIONS(6514), 1,
      sym__backquoted_id,
    ACTIONS(6516), 1,
      sym_operator_identifier,
    ACTIONS(7722), 1,
      anon_sym_LPAREN,
    ACTIONS(7724), 1,
      sym_integer_literal,
    STATE(4383), 1,
      sym__annotated_type,
    STATE(4455), 1,
      sym__simple_type,
    STATE(4474), 1,
      sym__soft_identifier,
    STATE(4498), 1,
      sym_identifier,
    STATE(5768), 1,
      sym_annotated_type,
    STATE(6537), 1,
      sym__infix_type_choice,
    STATE(7446), 1,
      sym__non_null_literal,
    STATE(17119), 1,
      sym_stable_identifier,
    ACTIONS(7726), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7728), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7730), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4214), 2,
      sym_comment,
      sym_block_comment,
    STATE(7509), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7927), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6510), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4591), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [219719] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(7532), 1,
      anon_sym_LPAREN,
    ACTIONS(7534), 1,
      sym_integer_literal,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(8775), 1,
      sym__annotated_type,
    STATE(8857), 1,
      sym__non_null_literal,
    STATE(10716), 1,
      sym__infix_type_choice,
    STATE(16640), 1,
      sym_stable_identifier,
    ACTIONS(7536), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7538), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7540), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4215), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9239), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [219810] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6546), 1,
      sym__alpha_identifier,
    ACTIONS(6548), 1,
      anon_sym__,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(6558), 1,
      sym_operator_identifier,
    ACTIONS(7732), 1,
      anon_sym_LPAREN,
    ACTIONS(7734), 1,
      sym_integer_literal,
    STATE(4676), 1,
      sym__simple_type,
    STATE(4686), 1,
      sym__annotated_type,
    STATE(4934), 1,
      sym_identifier,
    STATE(4937), 1,
      sym__soft_identifier,
    STATE(6975), 1,
      sym_annotated_type,
    STATE(7415), 1,
      sym__infix_type_choice,
    STATE(9072), 1,
      sym__non_null_literal,
    STATE(17125), 1,
      sym_stable_identifier,
    ACTIONS(7736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4216), 2,
      sym_comment,
      sym_block_comment,
    STATE(9095), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8839), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5066), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [219901] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6518), 1,
      sym__alpha_identifier,
    ACTIONS(6524), 1,
      anon_sym__,
    ACTIONS(6532), 1,
      sym__backquoted_id,
    ACTIONS(6534), 1,
      sym_operator_identifier,
    ACTIONS(7742), 1,
      anon_sym_LPAREN,
    ACTIONS(7744), 1,
      sym_integer_literal,
    STATE(7268), 1,
      sym__annotated_type,
    STATE(7378), 1,
      sym__simple_type,
    STATE(7649), 1,
      sym_identifier,
    STATE(7843), 1,
      sym__soft_identifier,
    STATE(9842), 1,
      sym_annotated_type,
    STATE(10224), 1,
      sym__infix_type_choice,
    STATE(10905), 1,
      sym__non_null_literal,
    STATE(16974), 1,
      sym_stable_identifier,
    ACTIONS(7746), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7748), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7750), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4217), 2,
      sym_comment,
      sym_block_comment,
    STATE(10778), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10869), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6528), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [219992] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4376), 1,
      sym__alpha_identifier,
    ACTIONS(4382), 1,
      anon_sym__,
    ACTIONS(4394), 1,
      sym__backquoted_id,
    ACTIONS(6824), 1,
      sym_operator_identifier,
    ACTIONS(7752), 1,
      anon_sym_LPAREN,
    ACTIONS(7754), 1,
      sym_integer_literal,
    STATE(4887), 1,
      sym__simple_type,
    STATE(4889), 1,
      sym__annotated_type,
    STATE(5049), 1,
      sym__soft_identifier,
    STATE(5197), 1,
      sym_identifier,
    STATE(7877), 1,
      sym_annotated_type,
    STATE(8628), 1,
      sym__infix_type_choice,
    STATE(9515), 1,
      sym__non_null_literal,
    STATE(16509), 1,
      sym_stable_identifier,
    ACTIONS(7756), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7758), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7760), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4218), 2,
      sym_comment,
      sym_block_comment,
    STATE(9678), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9360), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5943), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [220083] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6836), 1,
      anon_sym__,
    ACTIONS(6844), 1,
      sym__backquoted_id,
    ACTIONS(6846), 1,
      sym_operator_identifier,
    ACTIONS(7762), 1,
      anon_sym_LPAREN,
    ACTIONS(7764), 1,
      sym_integer_literal,
    STATE(8371), 1,
      sym__simple_type,
    STATE(8809), 1,
      sym__soft_identifier,
    STATE(8868), 1,
      sym_identifier,
    STATE(9048), 1,
      sym__annotated_type,
    STATE(10851), 1,
      sym_annotated_type,
    STATE(10991), 1,
      sym__infix_type_choice,
    STATE(11532), 1,
      sym__non_null_literal,
    STATE(17197), 1,
      sym_stable_identifier,
    ACTIONS(7766), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7768), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7770), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4219), 2,
      sym_comment,
      sym_block_comment,
    STATE(11540), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11546), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6840), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9436), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [220174] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6668), 1,
      sym__alpha_identifier,
    ACTIONS(6674), 1,
      anon_sym__,
    ACTIONS(6682), 1,
      sym__backquoted_id,
    ACTIONS(6684), 1,
      sym_operator_identifier,
    ACTIONS(7772), 1,
      anon_sym_LPAREN,
    ACTIONS(7774), 1,
      sym_integer_literal,
    STATE(5566), 1,
      sym__annotated_type,
    STATE(5712), 1,
      sym__simple_type,
    STATE(6018), 1,
      sym_identifier,
    STATE(6257), 1,
      sym__soft_identifier,
    STATE(9026), 1,
      sym_annotated_type,
    STATE(9473), 1,
      sym__infix_type_choice,
    STATE(10341), 1,
      sym__non_null_literal,
    STATE(17167), 1,
      sym_stable_identifier,
    ACTIONS(7776), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7778), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7780), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4220), 2,
      sym_comment,
      sym_block_comment,
    STATE(10411), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10409), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6678), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6819), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [220265] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4664), 1,
      sym__alpha_identifier,
    ACTIONS(4670), 1,
      anon_sym__,
    ACTIONS(4682), 1,
      sym__backquoted_id,
    ACTIONS(6544), 1,
      sym_operator_identifier,
    ACTIONS(7782), 1,
      anon_sym_LPAREN,
    ACTIONS(7784), 1,
      sym_integer_literal,
    STATE(4961), 1,
      sym__annotated_type,
    STATE(5002), 1,
      sym__simple_type,
    STATE(5067), 1,
      sym_identifier,
    STATE(5176), 1,
      sym__soft_identifier,
    STATE(7967), 1,
      sym_annotated_type,
    STATE(8558), 1,
      sym__infix_type_choice,
    STATE(9363), 1,
      sym__non_null_literal,
    STATE(16905), 1,
      sym_stable_identifier,
    ACTIONS(7786), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7788), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7790), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4221), 2,
      sym_comment,
      sym_block_comment,
    STATE(9575), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9485), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4676), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5890), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [220356] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6252), 1,
      sym__alpha_identifier,
    ACTIONS(6258), 1,
      anon_sym__,
    ACTIONS(6266), 1,
      sym__backquoted_id,
    ACTIONS(6268), 1,
      sym_operator_identifier,
    ACTIONS(7792), 1,
      anon_sym_LPAREN,
    ACTIONS(7794), 1,
      sym_integer_literal,
    STATE(5450), 1,
      sym__simple_type,
    STATE(5492), 1,
      sym__soft_identifier,
    STATE(5705), 1,
      sym_identifier,
    STATE(5892), 1,
      sym__annotated_type,
    STATE(8761), 1,
      sym_annotated_type,
    STATE(9110), 1,
      sym__infix_type_choice,
    STATE(10082), 1,
      sym__non_null_literal,
    STATE(16941), 1,
      sym_stable_identifier,
    ACTIONS(7796), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7798), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7800), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4222), 2,
      sym_comment,
      sym_block_comment,
    STATE(10004), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9830), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6262), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6211), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [220447] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6868), 1,
      sym__alpha_identifier,
    ACTIONS(6870), 1,
      anon_sym__,
    ACTIONS(6878), 1,
      sym__backquoted_id,
    ACTIONS(6880), 1,
      sym_operator_identifier,
    ACTIONS(7802), 1,
      anon_sym_LPAREN,
    ACTIONS(7804), 1,
      sym_integer_literal,
    STATE(4534), 1,
      sym__annotated_type,
    STATE(4541), 1,
      sym__simple_type,
    STATE(4620), 1,
      sym__soft_identifier,
    STATE(4757), 1,
      sym_identifier,
    STATE(6245), 1,
      sym_annotated_type,
    STATE(7049), 1,
      sym__infix_type_choice,
    STATE(8286), 1,
      sym__non_null_literal,
    STATE(16746), 1,
      sym_stable_identifier,
    ACTIONS(7806), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7808), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7810), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4223), 2,
      sym_comment,
      sym_block_comment,
    STATE(8329), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8645), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6874), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4890), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [220538] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6606), 1,
      anon_sym__,
    ACTIONS(6614), 1,
      sym__backquoted_id,
    ACTIONS(6616), 1,
      sym_operator_identifier,
    ACTIONS(7812), 1,
      anon_sym_LPAREN,
    ACTIONS(7814), 1,
      sym_integer_literal,
    STATE(5326), 1,
      sym__simple_type,
    STATE(5713), 1,
      sym__annotated_type,
    STATE(5817), 1,
      sym__soft_identifier,
    STATE(5848), 1,
      sym_identifier,
    STATE(9098), 1,
      sym_annotated_type,
    STATE(9285), 1,
      sym__infix_type_choice,
    STATE(10118), 1,
      sym__non_null_literal,
    STATE(16425), 1,
      sym_stable_identifier,
    ACTIONS(7816), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7818), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7820), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4224), 2,
      sym_comment,
      sym_block_comment,
    STATE(10000), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10084), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6610), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6472), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [220629] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4540), 1,
      sym__alpha_identifier,
    ACTIONS(4546), 1,
      anon_sym__,
    ACTIONS(4558), 1,
      sym__backquoted_id,
    ACTIONS(6892), 1,
      sym_operator_identifier,
    ACTIONS(7822), 1,
      anon_sym_LPAREN,
    ACTIONS(7824), 1,
      sym_integer_literal,
    STATE(4947), 1,
      sym__annotated_type,
    STATE(4984), 1,
      sym__simple_type,
    STATE(5050), 1,
      sym_identifier,
    STATE(5155), 1,
      sym__soft_identifier,
    STATE(7631), 1,
      sym_annotated_type,
    STATE(8207), 1,
      sym__infix_type_choice,
    STATE(9700), 1,
      sym__non_null_literal,
    STATE(16782), 1,
      sym_stable_identifier,
    ACTIONS(7826), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7828), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7830), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4225), 2,
      sym_comment,
      sym_block_comment,
    STATE(9389), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9423), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5928), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [220720] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4602), 1,
      sym__alpha_identifier,
    ACTIONS(4608), 1,
      anon_sym__,
    ACTIONS(4620), 1,
      sym__backquoted_id,
    ACTIONS(6176), 1,
      sym_operator_identifier,
    ACTIONS(7832), 1,
      anon_sym_LPAREN,
    ACTIONS(7834), 1,
      sym_integer_literal,
    STATE(4966), 1,
      sym__annotated_type,
    STATE(5035), 1,
      sym__simple_type,
    STATE(5163), 1,
      sym_identifier,
    STATE(5195), 1,
      sym__soft_identifier,
    STATE(8014), 1,
      sym_annotated_type,
    STATE(8161), 1,
      sym__infix_type_choice,
    STATE(9587), 1,
      sym__non_null_literal,
    STATE(17269), 1,
      sym_stable_identifier,
    ACTIONS(7836), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7838), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7840), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4226), 2,
      sym_comment,
      sym_block_comment,
    STATE(9539), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9358), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5955), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [220811] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6192), 1,
      sym__alpha_identifier,
    ACTIONS(6198), 1,
      anon_sym__,
    ACTIONS(6206), 1,
      sym__backquoted_id,
    ACTIONS(6208), 1,
      sym_operator_identifier,
    ACTIONS(7842), 1,
      anon_sym_LPAREN,
    ACTIONS(7844), 1,
      sym_integer_literal,
    STATE(5313), 1,
      sym__simple_type,
    STATE(5460), 1,
      sym__annotated_type,
    STATE(5503), 1,
      sym_identifier,
    STATE(5516), 1,
      sym__soft_identifier,
    STATE(8264), 1,
      sym_annotated_type,
    STATE(9254), 1,
      sym__infix_type_choice,
    STATE(10107), 1,
      sym__non_null_literal,
    STATE(17035), 1,
      sym_stable_identifier,
    ACTIONS(7846), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7848), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7850), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4227), 2,
      sym_comment,
      sym_block_comment,
    STATE(9788), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10034), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6202), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6134), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [220902] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4732), 1,
      sym__alpha_identifier,
    ACTIONS(4738), 1,
      anon_sym__,
    ACTIONS(4750), 1,
      sym__backquoted_id,
    ACTIONS(6648), 1,
      sym_operator_identifier,
    ACTIONS(7852), 1,
      anon_sym_LPAREN,
    ACTIONS(7854), 1,
      sym_integer_literal,
    STATE(6090), 1,
      sym__simple_type,
    STATE(6540), 1,
      sym__annotated_type,
    STATE(6727), 1,
      sym_identifier,
    STATE(7205), 1,
      sym__soft_identifier,
    STATE(9502), 1,
      sym_annotated_type,
    STATE(9903), 1,
      sym__infix_type_choice,
    STATE(10477), 1,
      sym__non_null_literal,
    STATE(16996), 1,
      sym_stable_identifier,
    ACTIONS(7856), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7858), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7860), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4228), 2,
      sym_comment,
      sym_block_comment,
    STATE(10607), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10447), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4744), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7933), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [220993] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6322), 1,
      sym__alpha_identifier,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    ACTIONS(7862), 1,
      anon_sym_LPAREN,
    ACTIONS(7864), 1,
      sym_integer_literal,
    STATE(6384), 1,
      sym__simple_type,
    STATE(6734), 1,
      sym__annotated_type,
    STATE(7031), 1,
      sym_identifier,
    STATE(7267), 1,
      sym__soft_identifier,
    STATE(9861), 1,
      sym_annotated_type,
    STATE(10427), 1,
      sym__infix_type_choice,
    STATE(10784), 1,
      sym__non_null_literal,
    STATE(16266), 1,
      sym_stable_identifier,
    ACTIONS(7866), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7868), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7870), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4229), 2,
      sym_comment,
      sym_block_comment,
    STATE(10899), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10766), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7736), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [221084] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4210), 1,
      sym__alpha_identifier,
    ACTIONS(4216), 1,
      anon_sym__,
    ACTIONS(4228), 1,
      sym__backquoted_id,
    ACTIONS(6248), 1,
      sym_operator_identifier,
    ACTIONS(7872), 1,
      anon_sym_LPAREN,
    ACTIONS(7874), 1,
      sym_integer_literal,
    STATE(5546), 1,
      sym__simple_type,
    STATE(5689), 1,
      sym__annotated_type,
    STATE(6312), 1,
      sym_identifier,
    STATE(6658), 1,
      sym__soft_identifier,
    STATE(8878), 1,
      sym_annotated_type,
    STATE(9521), 1,
      sym__infix_type_choice,
    STATE(10388), 1,
      sym__non_null_literal,
    STATE(16208), 1,
      sym_stable_identifier,
    ACTIONS(7876), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7878), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7880), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4230), 2,
      sym_comment,
      sym_block_comment,
    STATE(10277), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10392), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4222), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7079), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [221175] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4820), 1,
      sym__alpha_identifier,
    ACTIONS(4826), 1,
      anon_sym__,
    ACTIONS(4838), 1,
      sym__backquoted_id,
    ACTIONS(6888), 1,
      sym_operator_identifier,
    ACTIONS(7882), 1,
      anon_sym_LPAREN,
    ACTIONS(7884), 1,
      sym_integer_literal,
    STATE(4479), 1,
      sym__simple_type,
    STATE(4558), 1,
      sym__annotated_type,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(4630), 1,
      sym_identifier,
    STATE(5999), 1,
      sym_annotated_type,
    STATE(7289), 1,
      sym__infix_type_choice,
    STATE(8689), 1,
      sym__non_null_literal,
    STATE(17030), 1,
      sym_stable_identifier,
    ACTIONS(7886), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7888), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7890), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4231), 2,
      sym_comment,
      sym_block_comment,
    STATE(8248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8462), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4832), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4830), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [221266] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6792), 1,
      sym__alpha_identifier,
    ACTIONS(6794), 1,
      anon_sym__,
    ACTIONS(6802), 1,
      sym__backquoted_id,
    ACTIONS(6804), 1,
      sym_operator_identifier,
    ACTIONS(7892), 1,
      anon_sym_LPAREN,
    ACTIONS(7894), 1,
      sym_integer_literal,
    STATE(7421), 1,
      sym__simple_type,
    STATE(8149), 1,
      sym__soft_identifier,
    STATE(8152), 1,
      sym_identifier,
    STATE(8219), 1,
      sym__annotated_type,
    STATE(10479), 1,
      sym__infix_type_choice,
    STATE(10572), 1,
      sym_annotated_type,
    STATE(10974), 1,
      sym__non_null_literal,
    STATE(16446), 1,
      sym_stable_identifier,
    ACTIONS(7896), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7898), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7900), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4232), 2,
      sym_comment,
      sym_block_comment,
    STATE(11008), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11120), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6798), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9214), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [221357] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4794), 1,
      sym__alpha_identifier,
    ACTIONS(4796), 1,
      anon_sym__,
    ACTIONS(4806), 1,
      sym__backquoted_id,
    ACTIONS(6828), 1,
      sym_operator_identifier,
    ACTIONS(7902), 1,
      anon_sym_LPAREN,
    ACTIONS(7904), 1,
      sym_integer_literal,
    STATE(4477), 1,
      sym__simple_type,
    STATE(4557), 1,
      sym__annotated_type,
    STATE(4605), 1,
      sym__soft_identifier,
    STATE(4610), 1,
      sym_identifier,
    STATE(6171), 1,
      sym_annotated_type,
    STATE(7269), 1,
      sym__infix_type_choice,
    STATE(8664), 1,
      sym__non_null_literal,
    STATE(17024), 1,
      sym_stable_identifier,
    ACTIONS(7906), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7908), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7910), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4233), 2,
      sym_comment,
      sym_block_comment,
    STATE(8172), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8417), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4802), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4813), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [221448] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6278), 1,
      sym__alpha_identifier,
    ACTIONS(6284), 1,
      anon_sym__,
    ACTIONS(6292), 1,
      sym__backquoted_id,
    ACTIONS(6294), 1,
      sym_operator_identifier,
    ACTIONS(7912), 1,
      anon_sym_LPAREN,
    ACTIONS(7914), 1,
      sym_integer_literal,
    STATE(5075), 1,
      sym__simple_type,
    STATE(5200), 1,
      sym__annotated_type,
    STATE(5525), 1,
      sym__soft_identifier,
    STATE(5572), 1,
      sym_identifier,
    STATE(8337), 1,
      sym_annotated_type,
    STATE(9290), 1,
      sym__infix_type_choice,
    STATE(10123), 1,
      sym__non_null_literal,
    STATE(17071), 1,
      sym_stable_identifier,
    ACTIONS(7916), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7918), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7920), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4234), 2,
      sym_comment,
      sym_block_comment,
    STATE(10025), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10087), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6477), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [221539] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6426), 1,
      anon_sym__,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(6436), 1,
      sym_operator_identifier,
    ACTIONS(7922), 1,
      anon_sym_LPAREN,
    ACTIONS(7924), 1,
      sym_integer_literal,
    STATE(6914), 1,
      sym__simple_type,
    STATE(7366), 1,
      sym__annotated_type,
    STATE(7465), 1,
      sym_identifier,
    STATE(7913), 1,
      sym__soft_identifier,
    STATE(10061), 1,
      sym_annotated_type,
    STATE(10438), 1,
      sym__infix_type_choice,
    STATE(10918), 1,
      sym__non_null_literal,
    STATE(17101), 1,
      sym_stable_identifier,
    ACTIONS(7926), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7928), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7930), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4235), 2,
      sym_comment,
      sym_block_comment,
    STATE(10873), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10946), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8446), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [221630] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4698), 1,
      sym__alpha_identifier,
    ACTIONS(4704), 1,
      anon_sym__,
    ACTIONS(4716), 1,
      sym__backquoted_id,
    ACTIONS(6368), 1,
      sym_operator_identifier,
    ACTIONS(7932), 1,
      anon_sym_LPAREN,
    ACTIONS(7934), 1,
      sym_integer_literal,
    STATE(5429), 1,
      sym__annotated_type,
    STATE(5453), 1,
      sym__simple_type,
    STATE(5498), 1,
      sym__soft_identifier,
    STATE(5876), 1,
      sym_identifier,
    STATE(8602), 1,
      sym_annotated_type,
    STATE(9128), 1,
      sym__infix_type_choice,
    STATE(9820), 1,
      sym__non_null_literal,
    STATE(16963), 1,
      sym_stable_identifier,
    ACTIONS(7936), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7938), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7940), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4236), 2,
      sym_comment,
      sym_block_comment,
    STATE(10114), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9732), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4710), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6568), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [221721] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(7482), 1,
      anon_sym_LPAREN,
    ACTIONS(7484), 1,
      sym_integer_literal,
    STATE(5858), 1,
      sym__annotated_type,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(9513), 1,
      sym__infix_type_choice,
    STATE(9835), 1,
      sym__non_null_literal,
    STATE(16917), 1,
      sym_stable_identifier,
    ACTIONS(7486), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7488), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7490), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4237), 2,
      sym_comment,
      sym_block_comment,
    STATE(9918), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9774), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [221812] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4138), 1,
      sym__alpha_identifier,
    ACTIONS(4144), 1,
      anon_sym__,
    ACTIONS(4156), 1,
      sym__backquoted_id,
    ACTIONS(6858), 1,
      sym_operator_identifier,
    ACTIONS(7942), 1,
      anon_sym_LPAREN,
    ACTIONS(7944), 1,
      sym_integer_literal,
    STATE(5771), 1,
      sym__simple_type,
    STATE(5774), 1,
      sym__annotated_type,
    STATE(6041), 1,
      sym__soft_identifier,
    STATE(6244), 1,
      sym_identifier,
    STATE(9212), 1,
      sym_annotated_type,
    STATE(9504), 1,
      sym__infix_type_choice,
    STATE(10231), 1,
      sym__non_null_literal,
    STATE(16550), 1,
      sym_stable_identifier,
    ACTIONS(7946), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7948), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7950), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4238), 2,
      sym_comment,
      sym_block_comment,
    STATE(10328), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10313), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4150), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7341), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [221903] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6740), 1,
      sym__alpha_identifier,
    ACTIONS(6746), 1,
      anon_sym__,
    ACTIONS(6754), 1,
      sym__backquoted_id,
    ACTIONS(6756), 1,
      sym_operator_identifier,
    ACTIONS(7952), 1,
      anon_sym_LPAREN,
    ACTIONS(7954), 1,
      sym_integer_literal,
    STATE(6197), 1,
      sym__simple_type,
    STATE(6657), 1,
      sym__annotated_type,
    STATE(6959), 1,
      sym_identifier,
    STATE(7274), 1,
      sym__soft_identifier,
    STATE(9511), 1,
      sym_annotated_type,
    STATE(10065), 1,
      sym__infix_type_choice,
    STATE(10641), 1,
      sym__non_null_literal,
    STATE(17239), 1,
      sym_stable_identifier,
    ACTIONS(7956), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7958), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7960), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4239), 2,
      sym_comment,
      sym_block_comment,
    STATE(10639), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10547), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6750), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7605), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [221994] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4852), 1,
      sym__alpha_identifier,
    ACTIONS(4858), 1,
      anon_sym__,
    ACTIONS(4870), 1,
      sym__backquoted_id,
    ACTIONS(6298), 1,
      sym_operator_identifier,
    ACTIONS(7962), 1,
      anon_sym_LPAREN,
    ACTIONS(7964), 1,
      sym_integer_literal,
    STATE(5239), 1,
      sym__annotated_type,
    STATE(5391), 1,
      sym__simple_type,
    STATE(5519), 1,
      sym__soft_identifier,
    STATE(5597), 1,
      sym_identifier,
    STATE(8415), 1,
      sym_annotated_type,
    STATE(9264), 1,
      sym__infix_type_choice,
    STATE(9940), 1,
      sym__non_null_literal,
    STATE(17047), 1,
      sym_stable_identifier,
    ACTIONS(7966), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7968), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7970), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4240), 2,
      sym_comment,
      sym_block_comment,
    STATE(9869), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10048), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4864), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6267), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [222085] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4882), 1,
      sym__alpha_identifier,
    ACTIONS(4888), 1,
      anon_sym__,
    ACTIONS(4900), 1,
      sym__backquoted_id,
    ACTIONS(6364), 1,
      sym_operator_identifier,
    ACTIONS(7972), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      sym_integer_literal,
    STATE(5261), 1,
      sym__annotated_type,
    STATE(5446), 1,
      sym__simple_type,
    STATE(5522), 1,
      sym__soft_identifier,
    STATE(5657), 1,
      sym_identifier,
    STATE(8698), 1,
      sym_annotated_type,
    STATE(9274), 1,
      sym__infix_type_choice,
    STATE(10076), 1,
      sym__non_null_literal,
    STATE(17059), 1,
      sym_stable_identifier,
    ACTIONS(7976), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7978), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7980), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4241), 2,
      sym_comment,
      sym_block_comment,
    STATE(9930), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10063), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(4894), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6372), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [222176] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6388), 1,
      sym__alpha_identifier,
    ACTIONS(6394), 1,
      anon_sym__,
    ACTIONS(6402), 1,
      sym__backquoted_id,
    ACTIONS(6404), 1,
      sym_operator_identifier,
    ACTIONS(7982), 1,
      anon_sym_LPAREN,
    ACTIONS(7984), 1,
      sym_integer_literal,
    STATE(5646), 1,
      sym__simple_type,
    STATE(6195), 1,
      sym_identifier,
    STATE(6429), 1,
      sym__annotated_type,
    STATE(6548), 1,
      sym__soft_identifier,
    STATE(9396), 1,
      sym_annotated_type,
    STATE(9537), 1,
      sym__infix_type_choice,
    STATE(10359), 1,
      sym__non_null_literal,
    STATE(16293), 1,
      sym_stable_identifier,
    ACTIONS(7986), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7988), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(7990), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4242), 2,
      sym_comment,
      sym_block_comment,
    STATE(10269), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10203), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6398), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7147), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [222267] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6482), 1,
      sym__alpha_identifier,
    ACTIONS(6484), 1,
      anon_sym__,
    ACTIONS(6492), 1,
      sym__backquoted_id,
    ACTIONS(6494), 1,
      sym_operator_identifier,
    ACTIONS(7992), 1,
      anon_sym_LPAREN,
    ACTIONS(7994), 1,
      sym_integer_literal,
    STATE(5945), 1,
      sym__simple_type,
    STATE(6020), 1,
      sym_identifier,
    STATE(6408), 1,
      sym__annotated_type,
    STATE(6416), 1,
      sym__soft_identifier,
    STATE(9690), 1,
      sym_annotated_type,
    STATE(9801), 1,
      sym__infix_type_choice,
    STATE(10634), 1,
      sym__non_null_literal,
    STATE(16929), 1,
      sym_stable_identifier,
    ACTIONS(7996), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7998), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(8000), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4243), 2,
      sym_comment,
      sym_block_comment,
    STATE(10511), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10498), 3,
      sym_compound_type,
      sym_infix_type,
      sym_literal_type,
    ACTIONS(6488), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7126), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [222358] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8004), 8,
      sym__indent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(8002), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [222410] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(4245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 35,
      anon_sym_enum,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [222461] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8010), 1,
      anon_sym_LBRACE,
    ACTIONS(8012), 1,
      anon_sym_LBRACK,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8016), 1,
      anon_sym_def,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8032), 1,
      sym__indent,
    STATE(4325), 1,
      sym_type_parameters,
    STATE(4338), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8141), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(14153), 1,
      sym__function_declaration,
    STATE(16318), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4246), 2,
      sym_comment,
      sym_block_comment,
    STATE(14216), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [222553] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(473), 1,
      sym__alpha_identifier,
    ACTIONS(537), 1,
      sym__backquoted_id,
    ACTIONS(8036), 1,
      sym_operator_identifier,
    STATE(5776), 1,
      sym__soft_identifier,
    STATE(9546), 1,
      sym_identifier,
    STATE(4247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(659), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(4132), 6,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_DQUOTE,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(8034), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [222617] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8010), 1,
      anon_sym_LBRACE,
    ACTIONS(8012), 1,
      anon_sym_LBRACK,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8032), 1,
      sym__indent,
    ACTIONS(8038), 1,
      anon_sym_def,
    STATE(4332), 1,
      sym_type_parameters,
    STATE(4382), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8662), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(13937), 1,
      sym__function_declaration,
    STATE(17346), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4248), 2,
      sym_comment,
      sym_block_comment,
    STATE(14216), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [222709] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 35,
      anon_sym_enum,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [222757] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8012), 1,
      anon_sym_LBRACK,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8042), 1,
      anon_sym_LBRACE,
    ACTIONS(8044), 1,
      anon_sym_def,
    ACTIONS(8046), 1,
      sym__indent,
    STATE(4318), 1,
      sym_type_parameters,
    STATE(4319), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8461), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(14121), 1,
      sym__function_declaration,
    STATE(16161), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4250), 2,
      sym_comment,
      sym_block_comment,
    STATE(14533), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [222849] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8010), 1,
      anon_sym_LBRACE,
    ACTIONS(8012), 1,
      anon_sym_LBRACK,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8032), 1,
      sym__indent,
    ACTIONS(8038), 1,
      anon_sym_def,
    STATE(4298), 1,
      sym_type_parameters,
    STATE(4299), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8662), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(14148), 1,
      sym__function_declaration,
    STATE(17346), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4251), 2,
      sym_comment,
      sym_block_comment,
    STATE(14216), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [222941] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8012), 1,
      anon_sym_LBRACK,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8042), 1,
      anon_sym_LBRACE,
    ACTIONS(8044), 1,
      anon_sym_def,
    ACTIONS(8046), 1,
      sym__indent,
    STATE(4361), 1,
      sym_type_parameters,
    STATE(4362), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8461), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(13993), 1,
      sym__function_declaration,
    STATE(16161), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4252), 2,
      sym_comment,
      sym_block_comment,
    STATE(14533), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [223033] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(8052), 1,
      sym_operator_identifier,
    STATE(4512), 1,
      sym__soft_identifier,
    STATE(7120), 1,
      sym_identifier,
    STATE(4253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4132), 6,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_DQUOTE,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(8048), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [223097] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8060), 1,
      anon_sym_implicit,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8070), 1,
      anon_sym_using,
    ACTIONS(8072), 1,
      anon_sym_RPAREN,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15166), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4254), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [223188] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8082), 1,
      anon_sym_LBRACK,
    ACTIONS(8084), 1,
      anon_sym_AT,
    ACTIONS(8086), 1,
      anon_sym_LPAREN,
    ACTIONS(8088), 1,
      anon_sym_POUND,
    STATE(4562), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4648), 1,
      sym_type_arguments,
    STATE(4895), 1,
      sym_annotation,
    STATE(5746), 1,
      sym_arguments,
    STATE(4255), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [223253] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8090), 1,
      anon_sym_enum,
    ACTIONS(8092), 1,
      anon_sym_case,
    ACTIONS(8094), 1,
      anon_sym_object,
    ACTIONS(8096), 1,
      anon_sym_given,
    ACTIONS(8098), 1,
      anon_sym_class,
    ACTIONS(8100), 1,
      anon_sym_trait,
    ACTIONS(8102), 1,
      anon_sym_val,
    ACTIONS(8104), 1,
      anon_sym_var,
    ACTIONS(8106), 1,
      anon_sym_type,
    ACTIONS(8108), 1,
      anon_sym_def,
    ACTIONS(8110), 1,
      anon_sym_opaque,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(6349), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(12781), 1,
      sym_modifiers,
    STATE(16203), 1,
      sym_opaque_modifier,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4256), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [223346] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8116), 1,
      anon_sym_with,
    STATE(4333), 1,
      aux_sym_compound_type_repeat1,
    STATE(5746), 1,
      sym_arguments,
    STATE(5966), 1,
      sym_template_body,
    STATE(5967), 1,
      sym__refinement,
    STATE(4257), 2,
      sym_comment,
      sym_block_comment,
    STATE(5869), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [223407] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8118), 1,
      anon_sym_implicit,
    ACTIONS(8120), 1,
      anon_sym_using,
    ACTIONS(8122), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15646), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [223498] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8124), 1,
      anon_sym_implicit,
    ACTIONS(8126), 1,
      anon_sym_using,
    ACTIONS(8128), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15529), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [223589] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8130), 1,
      anon_sym_implicit,
    ACTIONS(8132), 1,
      anon_sym_using,
    ACTIONS(8134), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15547), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4260), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [223680] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8102), 1,
      anon_sym_val,
    ACTIONS(8104), 1,
      anon_sym_var,
    ACTIONS(8110), 1,
      anon_sym_opaque,
    ACTIONS(8136), 1,
      anon_sym_enum,
    ACTIONS(8138), 1,
      anon_sym_case,
    ACTIONS(8140), 1,
      anon_sym_object,
    ACTIONS(8142), 1,
      anon_sym_given,
    ACTIONS(8144), 1,
      anon_sym_class,
    ACTIONS(8146), 1,
      anon_sym_trait,
    ACTIONS(8148), 1,
      anon_sym_type,
    ACTIONS(8150), 1,
      anon_sym_def,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(6349), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(12968), 1,
      sym_modifiers,
    STATE(17620), 1,
      sym_opaque_modifier,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4261), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [223773] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8090), 1,
      anon_sym_enum,
    ACTIONS(8092), 1,
      anon_sym_case,
    ACTIONS(8094), 1,
      anon_sym_object,
    ACTIONS(8098), 1,
      anon_sym_class,
    ACTIONS(8100), 1,
      anon_sym_trait,
    ACTIONS(8102), 1,
      anon_sym_val,
    ACTIONS(8104), 1,
      anon_sym_var,
    ACTIONS(8106), 1,
      anon_sym_type,
    ACTIONS(8108), 1,
      anon_sym_def,
    ACTIONS(8110), 1,
      anon_sym_opaque,
    ACTIONS(8152), 1,
      anon_sym_given,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(6349), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(12966), 1,
      sym_modifiers,
    STATE(16203), 1,
      sym_opaque_modifier,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4262), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [223866] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(8052), 1,
      sym_operator_identifier,
    STATE(4512), 1,
      sym__soft_identifier,
    STATE(7120), 1,
      sym_identifier,
    STATE(4263), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4132), 5,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_DQUOTE,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(8048), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [223929] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8158), 1,
      anon_sym_LBRACK,
    ACTIONS(8160), 1,
      anon_sym_LPAREN,
    ACTIONS(8162), 1,
      anon_sym_POUND,
    STATE(4386), 1,
      aux_sym_annotation_repeat1,
    STATE(4543), 1,
      sym_type_arguments,
    STATE(4691), 1,
      sym_arguments,
    STATE(4264), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [223990] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8102), 1,
      anon_sym_val,
    ACTIONS(8104), 1,
      anon_sym_var,
    ACTIONS(8110), 1,
      anon_sym_opaque,
    ACTIONS(8136), 1,
      anon_sym_enum,
    ACTIONS(8140), 1,
      anon_sym_object,
    ACTIONS(8144), 1,
      anon_sym_class,
    ACTIONS(8146), 1,
      anon_sym_trait,
    ACTIONS(8148), 1,
      anon_sym_type,
    ACTIONS(8150), 1,
      anon_sym_def,
    ACTIONS(8164), 1,
      anon_sym_case,
    ACTIONS(8166), 1,
      anon_sym_given,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(6349), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(12996), 1,
      sym_modifiers,
    STATE(17620), 1,
      sym_opaque_modifier,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4265), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [224083] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8090), 1,
      anon_sym_enum,
    ACTIONS(8094), 1,
      anon_sym_object,
    ACTIONS(8096), 1,
      anon_sym_given,
    ACTIONS(8098), 1,
      anon_sym_class,
    ACTIONS(8100), 1,
      anon_sym_trait,
    ACTIONS(8102), 1,
      anon_sym_val,
    ACTIONS(8104), 1,
      anon_sym_var,
    ACTIONS(8106), 1,
      anon_sym_type,
    ACTIONS(8108), 1,
      anon_sym_def,
    ACTIONS(8110), 1,
      anon_sym_opaque,
    ACTIONS(8168), 1,
      anon_sym_case,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(6349), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(12781), 1,
      sym_modifiers,
    STATE(16203), 1,
      sym_opaque_modifier,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4266), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [224176] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(5730), 1,
      sym_interpolated_string,
    STATE(15429), 1,
      sym__interpolated_string_start,
    STATE(15431), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4267), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [224237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8176), 1,
      anon_sym_DOT,
    STATE(4268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [224286] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8178), 1,
      anon_sym_implicit,
    ACTIONS(8180), 1,
      anon_sym_using,
    ACTIONS(8182), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [224377] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8184), 1,
      anon_sym_implicit,
    ACTIONS(8186), 1,
      anon_sym_using,
    ACTIONS(8188), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15374), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [224468] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8190), 1,
      anon_sym_implicit,
    ACTIONS(8192), 1,
      anon_sym_using,
    ACTIONS(8194), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15349), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4271), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [224559] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8196), 1,
      anon_sym_implicit,
    ACTIONS(8198), 1,
      anon_sym_using,
    ACTIONS(8200), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(14908), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [224650] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8202), 1,
      anon_sym_implicit,
    ACTIONS(8204), 1,
      anon_sym_using,
    ACTIONS(8206), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(14781), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4273), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [224741] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8208), 1,
      anon_sym_implicit,
    ACTIONS(8210), 1,
      anon_sym_using,
    ACTIONS(8212), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15373), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [224832] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8102), 1,
      anon_sym_val,
    ACTIONS(8104), 1,
      anon_sym_var,
    ACTIONS(8110), 1,
      anon_sym_opaque,
    ACTIONS(8136), 1,
      anon_sym_enum,
    ACTIONS(8138), 1,
      anon_sym_case,
    ACTIONS(8140), 1,
      anon_sym_object,
    ACTIONS(8144), 1,
      anon_sym_class,
    ACTIONS(8146), 1,
      anon_sym_trait,
    ACTIONS(8148), 1,
      anon_sym_type,
    ACTIONS(8150), 1,
      anon_sym_def,
    ACTIONS(8166), 1,
      anon_sym_given,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(6349), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(12996), 1,
      sym_modifiers,
    STATE(17620), 1,
      sym_opaque_modifier,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4275), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [224925] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8102), 1,
      anon_sym_val,
    ACTIONS(8104), 1,
      anon_sym_var,
    ACTIONS(8110), 1,
      anon_sym_opaque,
    ACTIONS(8136), 1,
      anon_sym_enum,
    ACTIONS(8138), 1,
      anon_sym_case,
    ACTIONS(8140), 1,
      anon_sym_object,
    ACTIONS(8144), 1,
      anon_sym_class,
    ACTIONS(8146), 1,
      anon_sym_trait,
    ACTIONS(8214), 1,
      anon_sym_given,
    ACTIONS(8216), 1,
      anon_sym_type,
    ACTIONS(8218), 1,
      anon_sym_def,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(6349), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(13014), 1,
      sym_modifiers,
    STATE(16557), 1,
      sym_opaque_modifier,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4276), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [225018] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [225064] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6323), 1,
      sym_interpolated_string,
    STATE(15174), 1,
      sym__interpolated_string_start,
    STATE(15175), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [225124] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8158), 1,
      anon_sym_LBRACK,
    ACTIONS(8162), 1,
      anon_sym_POUND,
    ACTIONS(8222), 1,
      anon_sym_AT,
    STATE(4493), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4543), 1,
      sym_type_arguments,
    STATE(4933), 1,
      sym_annotation,
    STATE(4279), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [225184] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8224), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15674), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4280), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [225270] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8224), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15674), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4281), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [225356] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8226), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4282), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [225442] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8228), 1,
      anon_sym_with,
    STATE(4428), 1,
      aux_sym_compound_type_repeat1,
    STATE(6374), 1,
      sym_arguments,
    STATE(6385), 1,
      sym_template_body,
    STATE(6391), 1,
      sym__refinement,
    STATE(4283), 2,
      sym_comment,
      sym_block_comment,
    STATE(6463), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [225502] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8230), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4284), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [225588] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8232), 1,
      anon_sym_LBRACK,
    ACTIONS(8234), 1,
      anon_sym_AT,
    ACTIONS(8236), 1,
      anon_sym_LPAREN,
    ACTIONS(8238), 1,
      anon_sym_POUND,
    STATE(4602), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4825), 1,
      sym_type_arguments,
    STATE(5293), 1,
      sym_annotation,
    STATE(6374), 1,
      sym_arguments,
    STATE(4285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [225652] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8082), 1,
      anon_sym_LBRACK,
    ACTIONS(8088), 1,
      anon_sym_POUND,
    ACTIONS(8240), 1,
      anon_sym_LPAREN,
    STATE(4487), 1,
      aux_sym_annotation_repeat1,
    STATE(4648), 1,
      sym_type_arguments,
    STATE(5041), 1,
      sym_arguments,
    STATE(4286), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [225712] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8242), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4287), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [225798] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8244), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4288), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [225884] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8082), 1,
      anon_sym_LBRACK,
    ACTIONS(8084), 1,
      anon_sym_AT,
    ACTIONS(8088), 1,
      anon_sym_POUND,
    STATE(4562), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4648), 1,
      sym_type_arguments,
    STATE(4895), 1,
      sym_annotation,
    STATE(4289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [225944] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8248), 1,
      anon_sym_COLON,
    ACTIONS(8250), 1,
      anon_sym_LBRACE,
    ACTIONS(8254), 1,
      anon_sym_with,
    STATE(4826), 1,
      aux_sym_compound_type_repeat1,
    STATE(6989), 1,
      sym_template_body,
    STATE(7041), 1,
      sym__refinement,
    STATE(4290), 2,
      sym_comment,
      sym_block_comment,
    STATE(6931), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [226006] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [226052] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8258), 1,
      anon_sym_LBRACK,
    ACTIONS(8260), 1,
      anon_sym_LPAREN,
    ACTIONS(8262), 1,
      anon_sym_POUND,
    STATE(4506), 1,
      aux_sym_annotation_repeat1,
    STATE(4595), 1,
      sym_type_arguments,
    STATE(4769), 1,
      sym_arguments,
    STATE(4292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [226112] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8264), 1,
      anon_sym_LBRACK,
    ACTIONS(8266), 1,
      anon_sym_LPAREN,
    ACTIONS(8268), 1,
      anon_sym_POUND,
    STATE(4556), 1,
      aux_sym_annotation_repeat1,
    STATE(4672), 1,
      sym_type_arguments,
    STATE(4823), 1,
      sym_arguments,
    STATE(4293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [226172] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4294), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [226218] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4295), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [226264] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8010), 1,
      anon_sym_LBRACE,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8016), 1,
      anon_sym_def,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8032), 1,
      sym__indent,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8141), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10126), 1,
      aux_sym_extension_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(14153), 1,
      sym__function_declaration,
    STATE(16318), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4296), 2,
      sym_comment,
      sym_block_comment,
    STATE(14331), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [226350] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(8274), 1,
      anon_sym_COLON,
    ACTIONS(8276), 1,
      anon_sym_LPAREN,
    ACTIONS(8278), 1,
      sym_operator_identifier,
    STATE(11037), 1,
      sym__simple_type,
    STATE(11504), 1,
      sym__annotated_type,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(11545), 1,
      sym_identifier,
    STATE(13188), 1,
      sym_annotated_type,
    STATE(14558), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17515), 1,
      sym__constructor_application,
    STATE(17576), 1,
      sym_template_body,
    STATE(17819), 1,
      sym_stable_identifier,
    STATE(4297), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11824), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [226436] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8010), 1,
      anon_sym_LBRACE,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8032), 1,
      sym__indent,
    ACTIONS(8038), 1,
      anon_sym_def,
    STATE(4301), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8662), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(14148), 1,
      sym__function_declaration,
    STATE(17346), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4298), 2,
      sym_comment,
      sym_block_comment,
    STATE(14375), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [226522] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8010), 1,
      anon_sym_LBRACE,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8032), 1,
      sym__indent,
    ACTIONS(8038), 1,
      anon_sym_def,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8662), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10126), 1,
      aux_sym_extension_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(14148), 1,
      sym__function_declaration,
    STATE(17346), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4299), 2,
      sym_comment,
      sym_block_comment,
    STATE(14385), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [226608] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8280), 1,
      sym__alpha_identifier,
    ACTIONS(8282), 1,
      anon_sym_COLON,
    ACTIONS(8284), 1,
      anon_sym_LBRACE,
    ACTIONS(8286), 1,
      anon_sym__,
    ACTIONS(8290), 1,
      anon_sym_LPAREN,
    ACTIONS(8292), 1,
      sym__backquoted_id,
    ACTIONS(8294), 1,
      sym_operator_identifier,
    STATE(10562), 1,
      sym__simple_type,
    STATE(10763), 1,
      sym__annotated_type,
    STATE(11152), 1,
      sym_identifier,
    STATE(11176), 1,
      sym__soft_identifier,
    STATE(11952), 1,
      sym__constructor_application,
    STATE(12260), 1,
      sym_compound_type,
    STATE(12709), 1,
      sym_annotated_type,
    STATE(12757), 1,
      sym__structural_type,
    STATE(12994), 1,
      sym_template_body,
    STATE(13147), 1,
      sym__constructor_applications,
    STATE(17410), 1,
      sym_stable_identifier,
    STATE(4300), 2,
      sym_comment,
      sym_block_comment,
    STATE(12646), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11603), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [226694] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8010), 1,
      anon_sym_LBRACE,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8032), 1,
      sym__indent,
    ACTIONS(8038), 1,
      anon_sym_def,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8662), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10126), 1,
      aux_sym_extension_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(14148), 1,
      sym__function_declaration,
    STATE(17346), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4301), 2,
      sym_comment,
      sym_block_comment,
    STATE(14331), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [226780] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(8274), 1,
      anon_sym_COLON,
    ACTIONS(8276), 1,
      anon_sym_LPAREN,
    ACTIONS(8278), 1,
      sym_operator_identifier,
    STATE(11037), 1,
      sym__simple_type,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(11545), 1,
      sym_identifier,
    STATE(11556), 1,
      sym__annotated_type,
    STATE(13188), 1,
      sym_annotated_type,
    STATE(14698), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17515), 1,
      sym__constructor_application,
    STATE(17576), 1,
      sym_template_body,
    STATE(17819), 1,
      sym_stable_identifier,
    STATE(4302), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11824), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [226866] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8296), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4303), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [226952] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8188), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15374), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4304), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227038] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8188), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15374), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4305), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227124] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(8274), 1,
      anon_sym_COLON,
    ACTIONS(8276), 1,
      anon_sym_LPAREN,
    ACTIONS(8278), 1,
      sym_operator_identifier,
    STATE(11037), 1,
      sym__simple_type,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(11545), 1,
      sym_identifier,
    STATE(11596), 1,
      sym__annotated_type,
    STATE(13188), 1,
      sym_annotated_type,
    STATE(14459), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17515), 1,
      sym__constructor_application,
    STATE(17576), 1,
      sym_template_body,
    STATE(17819), 1,
      sym_stable_identifier,
    STATE(4306), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11824), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [227210] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8298), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15391), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4307), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227296] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8298), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15391), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4308), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227382] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8300), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4309), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227468] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8302), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15401), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4310), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227554] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8302), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15401), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4311), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227640] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8304), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4312), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227726] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8306), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4313), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227812] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8308), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4314), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227898] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8310), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4315), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227984] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8312), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4316), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [228070] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8314), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4317), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [228156] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8042), 1,
      anon_sym_LBRACE,
    ACTIONS(8044), 1,
      anon_sym_def,
    ACTIONS(8046), 1,
      sym__indent,
    STATE(4322), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8461), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(14121), 1,
      sym__function_declaration,
    STATE(16161), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4318), 2,
      sym_comment,
      sym_block_comment,
    STATE(14512), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [228242] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8042), 1,
      anon_sym_LBRACE,
    ACTIONS(8044), 1,
      anon_sym_def,
    ACTIONS(8046), 1,
      sym__indent,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8461), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10126), 1,
      aux_sym_extension_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(14121), 1,
      sym__function_declaration,
    STATE(16161), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4319), 2,
      sym_comment,
      sym_block_comment,
    STATE(14528), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [228328] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8316), 1,
      sym__alpha_identifier,
    ACTIONS(8318), 1,
      anon_sym_COLON,
    ACTIONS(8320), 1,
      anon_sym_LBRACE,
    ACTIONS(8322), 1,
      anon_sym__,
    ACTIONS(8326), 1,
      anon_sym_LPAREN,
    ACTIONS(8328), 1,
      sym__backquoted_id,
    ACTIONS(8330), 1,
      sym_operator_identifier,
    STATE(10895), 1,
      sym__simple_type,
    STATE(11043), 1,
      sym__annotated_type,
    STATE(11509), 1,
      sym_identifier,
    STATE(11550), 1,
      sym__soft_identifier,
    STATE(12585), 1,
      sym__constructor_application,
    STATE(12725), 1,
      sym_compound_type,
    STATE(13070), 1,
      sym__structural_type,
    STATE(13134), 1,
      sym_annotated_type,
    STATE(13266), 1,
      sym_template_body,
    STATE(13448), 1,
      sym__constructor_applications,
    STATE(16853), 1,
      sym_stable_identifier,
    STATE(4320), 2,
      sym_comment,
      sym_block_comment,
    STATE(13197), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8324), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11787), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [228414] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8332), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4321), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [228500] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8042), 1,
      anon_sym_LBRACE,
    ACTIONS(8044), 1,
      anon_sym_def,
    ACTIONS(8046), 1,
      sym__indent,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8461), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10126), 1,
      aux_sym_extension_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(14121), 1,
      sym__function_declaration,
    STATE(16161), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4322), 2,
      sym_comment,
      sym_block_comment,
    STATE(14619), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [228586] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8134), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15547), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4323), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [228672] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8134), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15547), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4324), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [228758] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8010), 1,
      anon_sym_LBRACE,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8016), 1,
      anon_sym_def,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8032), 1,
      sym__indent,
    STATE(4296), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8141), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(14153), 1,
      sym__function_declaration,
    STATE(16318), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4325), 2,
      sym_comment,
      sym_block_comment,
    STATE(14375), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [228844] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8302), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4326), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [228930] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8300), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15560), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4327), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [229016] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8300), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15560), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4328), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [229102] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8334), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4329), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [229188] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8336), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4330), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [229274] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8338), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4331), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [229360] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8010), 1,
      anon_sym_LBRACE,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8032), 1,
      sym__indent,
    ACTIONS(8038), 1,
      anon_sym_def,
    STATE(4335), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8662), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(13937), 1,
      sym__function_declaration,
    STATE(17346), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4332), 2,
      sym_comment,
      sym_block_comment,
    STATE(14375), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [229446] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8116), 1,
      anon_sym_with,
    STATE(5029), 1,
      aux_sym_compound_type_repeat1,
    STATE(5966), 1,
      sym_template_body,
    STATE(5970), 1,
      sym__refinement,
    STATE(4333), 2,
      sym_comment,
      sym_block_comment,
    STATE(5869), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [229504] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(8340), 1,
      anon_sym_COLON,
    ACTIONS(8342), 1,
      anon_sym_LBRACE,
    ACTIONS(8344), 1,
      anon_sym_LPAREN,
    ACTIONS(8346), 1,
      sym_operator_identifier,
    STATE(11161), 1,
      sym_identifier,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11293), 1,
      sym__simple_type,
    STATE(11615), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(13663), 1,
      sym__constructor_application,
    STATE(13933), 1,
      sym_compound_type,
    STATE(14026), 1,
      sym__structural_type,
    STATE(14033), 1,
      sym_template_body,
    STATE(14067), 1,
      sym__constructor_applications,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(4334), 2,
      sym_comment,
      sym_block_comment,
    STATE(14130), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [229590] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8010), 1,
      anon_sym_LBRACE,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8032), 1,
      sym__indent,
    ACTIONS(8038), 1,
      anon_sym_def,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8662), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10126), 1,
      aux_sym_extension_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(13937), 1,
      sym__function_declaration,
    STATE(17346), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4335), 2,
      sym_comment,
      sym_block_comment,
    STATE(14331), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [229676] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8122), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15646), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4336), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [229762] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8122), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15646), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4337), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [229848] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8010), 1,
      anon_sym_LBRACE,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8016), 1,
      anon_sym_def,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8032), 1,
      sym__indent,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8141), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10126), 1,
      aux_sym_extension_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(14153), 1,
      sym__function_declaration,
    STATE(16318), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4338), 2,
      sym_comment,
      sym_block_comment,
    STATE(14385), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [229934] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8348), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4339), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [230020] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8348), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15678), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4340), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [230106] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8348), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15678), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4341), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [230192] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8350), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4342), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [230278] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8352), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4343), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [230364] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8354), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4344), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [230450] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(8276), 1,
      anon_sym_LPAREN,
    ACTIONS(8278), 1,
      sym_operator_identifier,
    ACTIONS(8356), 1,
      anon_sym_COLON,
    ACTIONS(8358), 1,
      anon_sym_LBRACE,
    STATE(11301), 1,
      sym__simple_type,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(11545), 1,
      sym_identifier,
    STATE(11583), 1,
      sym__annotated_type,
    STATE(13188), 1,
      sym_annotated_type,
    STATE(13780), 1,
      sym__constructor_application,
    STATE(13889), 1,
      sym_compound_type,
    STATE(14038), 1,
      sym__constructor_applications,
    STATE(14060), 1,
      sym_template_body,
    STATE(14084), 1,
      sym__structural_type,
    STATE(17819), 1,
      sym_stable_identifier,
    STATE(4345), 2,
      sym_comment,
      sym_block_comment,
    STATE(14051), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11824), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [230536] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(8340), 1,
      anon_sym_COLON,
    ACTIONS(8342), 1,
      anon_sym_LBRACE,
    ACTIONS(8344), 1,
      anon_sym_LPAREN,
    ACTIONS(8346), 1,
      sym_operator_identifier,
    STATE(11161), 1,
      sym_identifier,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11293), 1,
      sym__simple_type,
    STATE(11615), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(13642), 1,
      sym__constructor_application,
    STATE(13933), 1,
      sym_compound_type,
    STATE(14026), 1,
      sym__structural_type,
    STATE(14033), 1,
      sym_template_body,
    STATE(14067), 1,
      sym__constructor_applications,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(4346), 2,
      sym_comment,
      sym_block_comment,
    STATE(14130), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [230622] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(8276), 1,
      anon_sym_LPAREN,
    ACTIONS(8278), 1,
      sym_operator_identifier,
    ACTIONS(8356), 1,
      anon_sym_COLON,
    ACTIONS(8358), 1,
      anon_sym_LBRACE,
    STATE(11301), 1,
      sym__simple_type,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(11545), 1,
      sym_identifier,
    STATE(11583), 1,
      sym__annotated_type,
    STATE(13188), 1,
      sym_annotated_type,
    STATE(13658), 1,
      sym__constructor_application,
    STATE(13889), 1,
      sym_compound_type,
    STATE(14038), 1,
      sym__constructor_applications,
    STATE(14060), 1,
      sym_template_body,
    STATE(14084), 1,
      sym__structural_type,
    STATE(17819), 1,
      sym_stable_identifier,
    STATE(4347), 2,
      sym_comment,
      sym_block_comment,
    STATE(14051), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11824), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [230708] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6520), 1,
      sym_interpolated_string,
    STATE(15099), 1,
      sym__interpolated_string_start,
    STATE(15101), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [230768] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(8274), 1,
      anon_sym_COLON,
    ACTIONS(8344), 1,
      anon_sym_LPAREN,
    ACTIONS(8346), 1,
      sym_operator_identifier,
    STATE(10729), 1,
      sym__simple_type,
    STATE(11161), 1,
      sym_identifier,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11713), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(14405), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16267), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17576), 1,
      sym_template_body,
    STATE(4349), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [230854] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8072), 1,
      anon_sym_RPAREN,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15166), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4350), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [230940] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8072), 1,
      anon_sym_RPAREN,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15166), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4351), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [231026] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(8274), 1,
      anon_sym_COLON,
    ACTIONS(8344), 1,
      anon_sym_LPAREN,
    ACTIONS(8346), 1,
      sym_operator_identifier,
    STATE(10729), 1,
      sym__simple_type,
    STATE(11161), 1,
      sym_identifier,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11558), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(14261), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16267), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17576), 1,
      sym_template_body,
    STATE(4352), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [231112] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4353), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [231158] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(8274), 1,
      anon_sym_COLON,
    ACTIONS(8344), 1,
      anon_sym_LPAREN,
    ACTIONS(8346), 1,
      sym_operator_identifier,
    STATE(10729), 1,
      sym__simple_type,
    STATE(11161), 1,
      sym_identifier,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11604), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(14261), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16267), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17576), 1,
      sym_template_body,
    STATE(4354), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [231244] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [231290] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(8274), 1,
      anon_sym_COLON,
    ACTIONS(8344), 1,
      anon_sym_LPAREN,
    ACTIONS(8346), 1,
      sym_operator_identifier,
    STATE(10729), 1,
      sym__simple_type,
    STATE(11161), 1,
      sym_identifier,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11612), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(14405), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16267), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17576), 1,
      sym_template_body,
    STATE(4356), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [231376] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(8274), 1,
      anon_sym_COLON,
    ACTIONS(8344), 1,
      anon_sym_LPAREN,
    ACTIONS(8346), 1,
      sym_operator_identifier,
    STATE(10729), 1,
      sym__simple_type,
    STATE(11161), 1,
      sym_identifier,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11616), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(14167), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16267), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17576), 1,
      sym_template_body,
    STATE(4357), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [231462] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(8274), 1,
      anon_sym_COLON,
    ACTIONS(8276), 1,
      anon_sym_LPAREN,
    ACTIONS(8278), 1,
      sym_operator_identifier,
    STATE(11037), 1,
      sym__simple_type,
    STATE(11248), 1,
      sym__annotated_type,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(11545), 1,
      sym_identifier,
    STATE(13188), 1,
      sym_annotated_type,
    STATE(14558), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17515), 1,
      sym__constructor_application,
    STATE(17576), 1,
      sym_template_body,
    STATE(17819), 1,
      sym_stable_identifier,
    STATE(4358), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11824), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [231548] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(8274), 1,
      anon_sym_COLON,
    ACTIONS(8276), 1,
      anon_sym_LPAREN,
    ACTIONS(8278), 1,
      sym_operator_identifier,
    STATE(11037), 1,
      sym__simple_type,
    STATE(11250), 1,
      sym__annotated_type,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(11545), 1,
      sym_identifier,
    STATE(13188), 1,
      sym_annotated_type,
    STATE(14698), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17515), 1,
      sym__constructor_application,
    STATE(17576), 1,
      sym_template_body,
    STATE(17819), 1,
      sym_stable_identifier,
    STATE(4359), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11824), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [231634] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(8274), 1,
      anon_sym_COLON,
    ACTIONS(8276), 1,
      anon_sym_LPAREN,
    ACTIONS(8278), 1,
      sym_operator_identifier,
    STATE(11037), 1,
      sym__simple_type,
    STATE(11252), 1,
      sym__annotated_type,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(11545), 1,
      sym_identifier,
    STATE(13188), 1,
      sym_annotated_type,
    STATE(14459), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17515), 1,
      sym__constructor_application,
    STATE(17576), 1,
      sym_template_body,
    STATE(17819), 1,
      sym_stable_identifier,
    STATE(4360), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11824), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [231720] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8042), 1,
      anon_sym_LBRACE,
    ACTIONS(8044), 1,
      anon_sym_def,
    ACTIONS(8046), 1,
      sym__indent,
    STATE(4363), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8461), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(13993), 1,
      sym__function_declaration,
    STATE(16161), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4361), 2,
      sym_comment,
      sym_block_comment,
    STATE(14512), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [231806] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8042), 1,
      anon_sym_LBRACE,
    ACTIONS(8044), 1,
      anon_sym_def,
    ACTIONS(8046), 1,
      sym__indent,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8461), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10126), 1,
      aux_sym_extension_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(13993), 1,
      sym__function_declaration,
    STATE(16161), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4362), 2,
      sym_comment,
      sym_block_comment,
    STATE(14528), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [231892] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8042), 1,
      anon_sym_LBRACE,
    ACTIONS(8044), 1,
      anon_sym_def,
    ACTIONS(8046), 1,
      sym__indent,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8461), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10126), 1,
      aux_sym_extension_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(13993), 1,
      sym__function_declaration,
    STATE(16161), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4363), 2,
      sym_comment,
      sym_block_comment,
    STATE(14619), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [231978] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(8274), 1,
      anon_sym_COLON,
    ACTIONS(8344), 1,
      anon_sym_LPAREN,
    ACTIONS(8346), 1,
      sym_operator_identifier,
    STATE(10729), 1,
      sym__simple_type,
    STATE(11161), 1,
      sym_identifier,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11310), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(14261), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16267), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17576), 1,
      sym_template_body,
    STATE(4364), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [232064] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(8274), 1,
      anon_sym_COLON,
    ACTIONS(8344), 1,
      anon_sym_LPAREN,
    ACTIONS(8346), 1,
      sym_operator_identifier,
    STATE(10729), 1,
      sym__simple_type,
    STATE(11161), 1,
      sym_identifier,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11313), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(14405), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16267), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17576), 1,
      sym_template_body,
    STATE(4365), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [232150] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(8274), 1,
      anon_sym_COLON,
    ACTIONS(8344), 1,
      anon_sym_LPAREN,
    ACTIONS(8346), 1,
      sym_operator_identifier,
    STATE(10729), 1,
      sym__simple_type,
    STATE(11161), 1,
      sym_identifier,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11315), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(14167), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16267), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17576), 1,
      sym_template_body,
    STATE(4366), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [232236] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [232282] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [232328] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4369), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [232374] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8370), 1,
      anon_sym_LBRACK,
    ACTIONS(8372), 1,
      anon_sym_AT,
    ACTIONS(8374), 1,
      anon_sym_LPAREN,
    ACTIONS(8376), 1,
      anon_sym_POUND,
    STATE(4627), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4982), 1,
      sym_type_arguments,
    STATE(5367), 1,
      sym_annotation,
    STATE(6430), 1,
      sym_arguments,
    STATE(4370), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [232438] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8378), 1,
      sym__alpha_identifier,
    ACTIONS(8380), 1,
      anon_sym_COLON,
    ACTIONS(8382), 1,
      anon_sym_LBRACE,
    ACTIONS(8384), 1,
      anon_sym__,
    ACTIONS(8388), 1,
      anon_sym_LPAREN,
    ACTIONS(8390), 1,
      sym__backquoted_id,
    ACTIONS(8392), 1,
      sym_operator_identifier,
    STATE(12073), 1,
      sym__simple_type,
    STATE(12329), 1,
      sym__annotated_type,
    STATE(13074), 1,
      sym_identifier,
    STATE(13178), 1,
      sym__soft_identifier,
    STATE(13674), 1,
      sym__constructor_application,
    STATE(13914), 1,
      sym_compound_type,
    STATE(14057), 1,
      sym_annotated_type,
    STATE(14078), 1,
      sym_template_body,
    STATE(14158), 1,
      sym__structural_type,
    STATE(14269), 1,
      sym__constructor_applications,
    STATE(17206), 1,
      sym_stable_identifier,
    STATE(4371), 2,
      sym_comment,
      sym_block_comment,
    STATE(14037), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8386), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13352), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [232524] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [232570] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(8274), 1,
      anon_sym_COLON,
    ACTIONS(8344), 1,
      anon_sym_LPAREN,
    ACTIONS(8346), 1,
      sym_operator_identifier,
    STATE(10729), 1,
      sym__simple_type,
    STATE(11161), 1,
      sym_identifier,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11653), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(14167), 1,
      sym__structural_instance,
    STATE(14874), 1,
      sym_compound_type,
    STATE(16267), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(16859), 1,
      sym__structural_type,
    STATE(17576), 1,
      sym_template_body,
    STATE(4373), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [232656] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8396), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15200), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4374), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [232742] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8396), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15200), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4375), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [232828] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8398), 1,
      anon_sym_with,
    STATE(4389), 1,
      aux_sym_compound_type_repeat1,
    STATE(6236), 1,
      sym_template_body,
    STATE(6237), 1,
      sym__refinement,
    STATE(6430), 1,
      sym_arguments,
    STATE(4376), 2,
      sym_comment,
      sym_block_comment,
    STATE(6014), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [232888] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    ACTIONS(8224), 1,
      anon_sym_RPAREN,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4377), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [232974] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8400), 1,
      anon_sym_LBRACK,
    ACTIONS(8402), 1,
      anon_sym_LPAREN,
    ACTIONS(8404), 1,
      anon_sym_POUND,
    STATE(4552), 1,
      aux_sym_annotation_repeat1,
    STATE(4715), 1,
      sym_type_arguments,
    STATE(5012), 1,
      sym_arguments,
    STATE(4378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [233034] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8248), 1,
      anon_sym_COLON,
    ACTIONS(8250), 1,
      anon_sym_LBRACE,
    ACTIONS(8254), 1,
      anon_sym_with,
    STATE(4290), 1,
      aux_sym_compound_type_repeat1,
    STATE(6989), 1,
      sym_template_body,
    STATE(6990), 1,
      sym__refinement,
    STATE(4379), 2,
      sym_comment,
      sym_block_comment,
    STATE(6931), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [233096] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8248), 1,
      anon_sym_COLON,
    ACTIONS(8250), 1,
      anon_sym_LBRACE,
    ACTIONS(8254), 1,
      anon_sym_with,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(4290), 1,
      aux_sym_compound_type_repeat1,
    STATE(6989), 1,
      sym_template_body,
    STATE(6990), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4380), 2,
      sym_comment,
      sym_block_comment,
    STATE(6931), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 8,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [233164] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4381), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [233210] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8010), 1,
      anon_sym_LBRACE,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8030), 1,
      anon_sym_LPAREN,
    ACTIONS(8032), 1,
      sym__indent,
    ACTIONS(8038), 1,
      anon_sym_def,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(8662), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10126), 1,
      aux_sym_extension_definition_repeat1,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(13937), 1,
      sym__function_declaration,
    STATE(17346), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4382), 2,
      sym_comment,
      sym_block_comment,
    STATE(14385), 3,
      sym__extension_template_body,
      sym_function_definition,
      sym_function_declaration,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [233296] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8416), 1,
      anon_sym_COLON,
    ACTIONS(8418), 1,
      anon_sym_LBRACE,
    ACTIONS(8420), 1,
      anon_sym_with,
    STATE(4391), 1,
      aux_sym_compound_type_repeat1,
    STATE(7591), 1,
      sym_template_body,
    STATE(7595), 1,
      sym__refinement,
    STATE(4383), 2,
      sym_comment,
      sym_block_comment,
    STATE(7581), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [233357] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(4384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [233406] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8264), 1,
      anon_sym_LBRACK,
    ACTIONS(8268), 1,
      anon_sym_POUND,
    ACTIONS(8424), 1,
      anon_sym_AT,
    STATE(4576), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4672), 1,
      sym_type_arguments,
    STATE(5053), 1,
      sym_annotation,
    STATE(4385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [233465] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8160), 1,
      anon_sym_LPAREN,
    STATE(4387), 1,
      aux_sym_annotation_repeat1,
    STATE(4691), 1,
      sym_arguments,
    STATE(4386), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [233518] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8434), 1,
      anon_sym_LPAREN,
    STATE(4691), 1,
      sym_arguments,
    STATE(4387), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [233569] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8437), 1,
      anon_sym_LBRACK,
    ACTIONS(8439), 1,
      anon_sym_LPAREN,
    ACTIONS(8441), 1,
      anon_sym_POUND,
    STATE(4636), 1,
      aux_sym_annotation_repeat1,
    STATE(4815), 1,
      sym_type_arguments,
    STATE(5419), 1,
      sym_arguments,
    STATE(4388), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [233628] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8398), 1,
      anon_sym_with,
    STATE(5328), 1,
      aux_sym_compound_type_repeat1,
    STATE(6236), 1,
      sym_template_body,
    STATE(6253), 1,
      sym__refinement,
    STATE(4389), 2,
      sym_comment,
      sym_block_comment,
    STATE(6014), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [233685] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8443), 1,
      anon_sym_LBRACK,
    ACTIONS(8445), 1,
      anon_sym_LPAREN,
    ACTIONS(8447), 1,
      anon_sym_POUND,
    STATE(4709), 1,
      aux_sym_annotation_repeat1,
    STATE(4836), 1,
      sym_type_arguments,
    STATE(5432), 1,
      sym_arguments,
    STATE(4390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [233744] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8416), 1,
      anon_sym_COLON,
    ACTIONS(8418), 1,
      anon_sym_LBRACE,
    ACTIONS(8420), 1,
      anon_sym_with,
    STATE(5349), 1,
      aux_sym_compound_type_repeat1,
    STATE(7591), 1,
      sym_template_body,
    STATE(7618), 1,
      sym__refinement,
    STATE(4391), 2,
      sym_comment,
      sym_block_comment,
    STATE(7581), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [233805] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(8076), 1,
      sym_operator_identifier,
    STATE(4511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12001), 1,
      sym_modifiers,
    STATE(14659), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(16015), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8058), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4392), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [233888] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8370), 1,
      anon_sym_LBRACK,
    ACTIONS(8372), 1,
      anon_sym_AT,
    ACTIONS(8376), 1,
      anon_sym_POUND,
    STATE(4627), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4982), 1,
      sym_type_arguments,
    STATE(5367), 1,
      sym_annotation,
    STATE(4393), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [233947] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8449), 1,
      anon_sym_COLON,
    ACTIONS(8451), 1,
      anon_sym_LBRACE,
    ACTIONS(8453), 1,
      anon_sym_with,
    STATE(5463), 1,
      aux_sym_compound_type_repeat1,
    STATE(7988), 1,
      sym_template_body,
    STATE(8012), 1,
      sym__refinement,
    STATE(4394), 2,
      sym_comment,
      sym_block_comment,
    STATE(7950), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [234008] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8455), 1,
      anon_sym_DOT,
    STATE(4395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [234057] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8370), 1,
      anon_sym_LBRACK,
    ACTIONS(8376), 1,
      anon_sym_POUND,
    ACTIONS(8457), 1,
      anon_sym_LPAREN,
    STATE(4614), 1,
      aux_sym_annotation_repeat1,
    STATE(4982), 1,
      sym_type_arguments,
    STATE(5088), 1,
      sym_arguments,
    STATE(4396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [234116] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8459), 1,
      anon_sym_LBRACK,
    ACTIONS(8461), 1,
      anon_sym_LPAREN,
    ACTIONS(8463), 1,
      anon_sym_POUND,
    STATE(4631), 1,
      aux_sym_annotation_repeat1,
    STATE(4855), 1,
      sym_type_arguments,
    STATE(5149), 1,
      sym_arguments,
    STATE(4397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [234175] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [234222] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [234269] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8465), 1,
      sym__alpha_identifier,
    ACTIONS(8467), 1,
      anon_sym_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8471), 1,
      anon_sym__,
    ACTIONS(8475), 1,
      anon_sym_LPAREN,
    ACTIONS(8477), 1,
      sym__backquoted_id,
    ACTIONS(8479), 1,
      sym_operator_identifier,
    STATE(4496), 1,
      sym__annotated_type,
    STATE(4518), 1,
      sym__simple_type,
    STATE(5629), 1,
      sym__constructor_application,
    STATE(5699), 1,
      sym__soft_identifier,
    STATE(5780), 1,
      sym_identifier,
    STATE(7025), 1,
      sym_annotated_type,
    STATE(7028), 1,
      sym_compound_type,
    STATE(7444), 1,
      sym_template_body,
    STATE(7563), 1,
      sym__structural_type,
    STATE(16486), 1,
      sym_stable_identifier,
    STATE(4400), 2,
      sym_comment,
      sym_block_comment,
    STATE(7553), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8473), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5877), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [234352] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 32,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [234397] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8280), 1,
      sym__alpha_identifier,
    ACTIONS(8286), 1,
      anon_sym__,
    ACTIONS(8290), 1,
      anon_sym_LPAREN,
    ACTIONS(8292), 1,
      sym__backquoted_id,
    ACTIONS(8294), 1,
      sym_operator_identifier,
    ACTIONS(8483), 1,
      anon_sym_COLON,
    ACTIONS(8485), 1,
      anon_sym_LBRACE,
    STATE(10564), 1,
      sym__simple_type,
    STATE(10689), 1,
      sym__annotated_type,
    STATE(11152), 1,
      sym_identifier,
    STATE(11176), 1,
      sym__soft_identifier,
    STATE(12709), 1,
      sym_annotated_type,
    STATE(12759), 1,
      sym_compound_type,
    STATE(13028), 1,
      sym__constructor_application,
    STATE(13033), 1,
      sym_template_body,
    STATE(13149), 1,
      sym__structural_type,
    STATE(17410), 1,
      sym_stable_identifier,
    STATE(4402), 2,
      sym_comment,
      sym_block_comment,
    STATE(13295), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11603), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [234480] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8280), 1,
      sym__alpha_identifier,
    ACTIONS(8282), 1,
      anon_sym_COLON,
    ACTIONS(8284), 1,
      anon_sym_LBRACE,
    ACTIONS(8286), 1,
      anon_sym__,
    ACTIONS(8290), 1,
      anon_sym_LPAREN,
    ACTIONS(8292), 1,
      sym__backquoted_id,
    ACTIONS(8294), 1,
      sym_operator_identifier,
    STATE(10562), 1,
      sym__simple_type,
    STATE(10763), 1,
      sym__annotated_type,
    STATE(11152), 1,
      sym_identifier,
    STATE(11176), 1,
      sym__soft_identifier,
    STATE(12260), 1,
      sym_compound_type,
    STATE(12709), 1,
      sym_annotated_type,
    STATE(12757), 1,
      sym__structural_type,
    STATE(12994), 1,
      sym_template_body,
    STATE(13029), 1,
      sym__constructor_application,
    STATE(17410), 1,
      sym_stable_identifier,
    STATE(4403), 2,
      sym_comment,
      sym_block_comment,
    STATE(12646), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11603), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [234563] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8416), 1,
      anon_sym_COLON,
    ACTIONS(8418), 1,
      anon_sym_LBRACE,
    ACTIONS(8420), 1,
      anon_sym_with,
    STATE(4391), 1,
      aux_sym_compound_type_repeat1,
    STATE(7591), 1,
      sym_template_body,
    STATE(7595), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4404), 2,
      sym_comment,
      sym_block_comment,
    STATE(7581), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [234630] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4946), 1,
      anon_sym_COLON,
    ACTIONS(4948), 1,
      anon_sym_LBRACE,
    ACTIONS(8487), 1,
      sym__alpha_identifier,
    ACTIONS(8489), 1,
      anon_sym__,
    ACTIONS(8493), 1,
      anon_sym_LPAREN,
    ACTIONS(8495), 1,
      sym__backquoted_id,
    ACTIONS(8497), 1,
      sym_operator_identifier,
    STATE(5348), 1,
      sym__annotated_type,
    STATE(5410), 1,
      sym__simple_type,
    STATE(7596), 1,
      sym__constructor_application,
    STATE(7616), 1,
      sym__soft_identifier,
    STATE(8045), 1,
      sym_identifier,
    STATE(9153), 1,
      sym_compound_type,
    STATE(9288), 1,
      sym_annotated_type,
    STATE(9373), 1,
      sym_template_body,
    STATE(9598), 1,
      sym__structural_type,
    STATE(16768), 1,
      sym_stable_identifier,
    STATE(4405), 2,
      sym_comment,
      sym_block_comment,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8491), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8075), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [234713] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [234760] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8316), 1,
      sym__alpha_identifier,
    ACTIONS(8322), 1,
      anon_sym__,
    ACTIONS(8326), 1,
      anon_sym_LPAREN,
    ACTIONS(8328), 1,
      sym__backquoted_id,
    ACTIONS(8330), 1,
      sym_operator_identifier,
    ACTIONS(8499), 1,
      anon_sym_COLON,
    ACTIONS(8501), 1,
      anon_sym_LBRACE,
    STATE(10843), 1,
      sym__simple_type,
    STATE(10964), 1,
      sym__annotated_type,
    STATE(11509), 1,
      sym_identifier,
    STATE(11550), 1,
      sym__soft_identifier,
    STATE(13134), 1,
      sym_annotated_type,
    STATE(13196), 1,
      sym_compound_type,
    STATE(13412), 1,
      sym__structural_type,
    STATE(13499), 1,
      sym_template_body,
    STATE(13590), 1,
      sym__constructor_application,
    STATE(16853), 1,
      sym_stable_identifier,
    STATE(4407), 2,
      sym_comment,
      sym_block_comment,
    STATE(13512), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8324), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11787), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [234843] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8316), 1,
      sym__alpha_identifier,
    ACTIONS(8318), 1,
      anon_sym_COLON,
    ACTIONS(8320), 1,
      anon_sym_LBRACE,
    ACTIONS(8322), 1,
      anon_sym__,
    ACTIONS(8326), 1,
      anon_sym_LPAREN,
    ACTIONS(8328), 1,
      sym__backquoted_id,
    ACTIONS(8330), 1,
      sym_operator_identifier,
    STATE(10895), 1,
      sym__simple_type,
    STATE(11043), 1,
      sym__annotated_type,
    STATE(11509), 1,
      sym_identifier,
    STATE(11550), 1,
      sym__soft_identifier,
    STATE(12725), 1,
      sym_compound_type,
    STATE(13070), 1,
      sym__structural_type,
    STATE(13134), 1,
      sym_annotated_type,
    STATE(13266), 1,
      sym_template_body,
    STATE(13610), 1,
      sym__constructor_application,
    STATE(16853), 1,
      sym_stable_identifier,
    STATE(4408), 2,
      sym_comment,
      sym_block_comment,
    STATE(13197), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8324), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11787), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [234926] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8449), 1,
      anon_sym_COLON,
    ACTIONS(8451), 1,
      anon_sym_LBRACE,
    ACTIONS(8453), 1,
      anon_sym_with,
    STATE(4394), 1,
      aux_sym_compound_type_repeat1,
    STATE(7988), 1,
      sym_template_body,
    STATE(7991), 1,
      sym__refinement,
    STATE(4409), 2,
      sym_comment,
      sym_block_comment,
    STATE(7950), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [234987] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(8503), 1,
      sym__alpha_identifier,
    ACTIONS(8505), 1,
      anon_sym__,
    ACTIONS(8509), 1,
      anon_sym_LPAREN,
    ACTIONS(8511), 1,
      sym__backquoted_id,
    ACTIONS(8513), 1,
      sym_operator_identifier,
    STATE(5418), 1,
      sym__annotated_type,
    STATE(5454), 1,
      sym__simple_type,
    STATE(7788), 1,
      sym__soft_identifier,
    STATE(7804), 1,
      sym_identifier,
    STATE(7870), 1,
      sym__constructor_application,
    STATE(8796), 1,
      sym_annotated_type,
    STATE(9291), 1,
      sym_compound_type,
    STATE(9603), 1,
      sym_template_body,
    STATE(9701), 1,
      sym__structural_type,
    STATE(16966), 1,
      sym_stable_identifier,
    STATE(4410), 2,
      sym_comment,
      sym_block_comment,
    STATE(5972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8507), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [235070] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4411), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [235117] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8515), 1,
      anon_sym_LBRACK,
    ACTIONS(8517), 1,
      anon_sym_LPAREN,
    ACTIONS(8519), 1,
      anon_sym_POUND,
    STATE(4569), 1,
      aux_sym_annotation_repeat1,
    STATE(5038), 1,
      sym_type_arguments,
    STATE(5113), 1,
      sym_arguments,
    STATE(4412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [235176] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8449), 1,
      anon_sym_COLON,
    ACTIONS(8451), 1,
      anon_sym_LBRACE,
    ACTIONS(8453), 1,
      anon_sym_with,
    STATE(4394), 1,
      aux_sym_compound_type_repeat1,
    STATE(7988), 1,
      sym_template_body,
    STATE(7991), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4413), 2,
      sym_comment,
      sym_block_comment,
    STATE(7950), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 7,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [235243] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(8344), 1,
      anon_sym_LPAREN,
    ACTIONS(8346), 1,
      sym_operator_identifier,
    STATE(9100), 1,
      sym_compound_type,
    STATE(9540), 1,
      sym__structural_type,
    STATE(10807), 1,
      sym_template_body,
    STATE(11161), 1,
      sym_identifier,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11306), 1,
      sym__simple_type,
    STATE(11579), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(14350), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(4414), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [235326] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(8340), 1,
      anon_sym_COLON,
    ACTIONS(8342), 1,
      anon_sym_LBRACE,
    ACTIONS(8344), 1,
      anon_sym_LPAREN,
    ACTIONS(8346), 1,
      sym_operator_identifier,
    STATE(11161), 1,
      sym_identifier,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11293), 1,
      sym__simple_type,
    STATE(11615), 1,
      sym__annotated_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(13933), 1,
      sym_compound_type,
    STATE(14026), 1,
      sym__structural_type,
    STATE(14033), 1,
      sym_template_body,
    STATE(14096), 1,
      sym__constructor_application,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(4415), 2,
      sym_comment,
      sym_block_comment,
    STATE(14130), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [235409] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8521), 1,
      anon_sym_LBRACK,
    ACTIONS(8523), 1,
      anon_sym_LPAREN,
    ACTIONS(8525), 1,
      anon_sym_POUND,
    STATE(4583), 1,
      aux_sym_annotation_repeat1,
    STATE(4905), 1,
      sym_type_arguments,
    STATE(5138), 1,
      sym_arguments,
    STATE(4416), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [235468] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8527), 1,
      sym__alpha_identifier,
    ACTIONS(8529), 1,
      anon_sym_COLON,
    ACTIONS(8531), 1,
      anon_sym_LBRACE,
    ACTIONS(8533), 1,
      anon_sym__,
    ACTIONS(8537), 1,
      anon_sym_LPAREN,
    ACTIONS(8539), 1,
      sym__backquoted_id,
    ACTIONS(8541), 1,
      sym_operator_identifier,
    STATE(4283), 1,
      sym__annotated_type,
    STATE(4285), 1,
      sym__simple_type,
    STATE(4758), 1,
      sym__constructor_application,
    STATE(4810), 1,
      sym_identifier,
    STATE(5008), 1,
      sym__soft_identifier,
    STATE(5479), 1,
      sym_compound_type,
    STATE(5624), 1,
      sym_annotated_type,
    STATE(6571), 1,
      sym__structural_type,
    STATE(6628), 1,
      sym_template_body,
    STATE(17280), 1,
      sym_stable_identifier,
    STATE(4417), 2,
      sym_comment,
      sym_block_comment,
    STATE(6463), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8535), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4820), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [235551] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6414), 1,
      anon_sym_COLON,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(8276), 1,
      anon_sym_LPAREN,
    ACTIONS(8278), 1,
      sym_operator_identifier,
    STATE(8423), 1,
      sym_compound_type,
    STATE(9071), 1,
      sym__structural_type,
    STATE(11319), 1,
      sym__simple_type,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(11545), 1,
      sym_identifier,
    STATE(11635), 1,
      sym__annotated_type,
    STATE(12156), 1,
      sym_template_body,
    STATE(13188), 1,
      sym_annotated_type,
    STATE(14390), 1,
      sym__constructor_application,
    STATE(17819), 1,
      sym_stable_identifier,
    STATE(4418), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11824), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [235634] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(8276), 1,
      anon_sym_LPAREN,
    ACTIONS(8278), 1,
      sym_operator_identifier,
    ACTIONS(8356), 1,
      anon_sym_COLON,
    ACTIONS(8358), 1,
      anon_sym_LBRACE,
    STATE(11301), 1,
      sym__simple_type,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(11545), 1,
      sym_identifier,
    STATE(11583), 1,
      sym__annotated_type,
    STATE(13188), 1,
      sym_annotated_type,
    STATE(13889), 1,
      sym_compound_type,
    STATE(14060), 1,
      sym_template_body,
    STATE(14084), 1,
      sym__structural_type,
    STATE(14133), 1,
      sym__constructor_application,
    STATE(17819), 1,
      sym_stable_identifier,
    STATE(4419), 2,
      sym_comment,
      sym_block_comment,
    STATE(14051), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11824), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [235717] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6372), 1,
      anon_sym_COLON,
    ACTIONS(6374), 1,
      anon_sym_LBRACE,
    ACTIONS(8543), 1,
      sym__alpha_identifier,
    ACTIONS(8545), 1,
      anon_sym__,
    ACTIONS(8549), 1,
      anon_sym_LPAREN,
    ACTIONS(8551), 1,
      sym__backquoted_id,
    ACTIONS(8553), 1,
      sym_operator_identifier,
    STATE(4656), 1,
      sym__annotated_type,
    STATE(4748), 1,
      sym__simple_type,
    STATE(6037), 1,
      sym__constructor_application,
    STATE(6060), 1,
      sym_identifier,
    STATE(6081), 1,
      sym__soft_identifier,
    STATE(7670), 1,
      sym_compound_type,
    STATE(7953), 1,
      sym_annotated_type,
    STATE(8300), 1,
      sym__structural_type,
    STATE(8601), 1,
      sym_template_body,
    STATE(17711), 1,
      sym_stable_identifier,
    STATE(4420), 2,
      sym_comment,
      sym_block_comment,
    STATE(8419), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8547), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6107), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [235800] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6414), 1,
      anon_sym_COLON,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(8555), 1,
      sym__alpha_identifier,
    ACTIONS(8557), 1,
      anon_sym__,
    ACTIONS(8561), 1,
      anon_sym_LPAREN,
    ACTIONS(8563), 1,
      sym__backquoted_id,
    ACTIONS(8565), 1,
      sym_operator_identifier,
    STATE(5226), 1,
      sym__annotated_type,
    STATE(5256), 1,
      sym__simple_type,
    STATE(7451), 1,
      sym_identifier,
    STATE(7612), 1,
      sym__soft_identifier,
    STATE(7951), 1,
      sym__constructor_application,
    STATE(8423), 1,
      sym_compound_type,
    STATE(8792), 1,
      sym_annotated_type,
    STATE(9071), 1,
      sym__structural_type,
    STATE(9647), 1,
      sym_template_body,
    STATE(17871), 1,
      sym_stable_identifier,
    STATE(4421), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8559), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7570), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [235883] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6520), 1,
      anon_sym_COLON,
    ACTIONS(6522), 1,
      anon_sym_LBRACE,
    ACTIONS(8567), 1,
      sym__alpha_identifier,
    ACTIONS(8569), 1,
      anon_sym__,
    ACTIONS(8573), 1,
      anon_sym_LPAREN,
    ACTIONS(8575), 1,
      sym__backquoted_id,
    ACTIONS(8577), 1,
      sym_operator_identifier,
    STATE(5616), 1,
      sym__annotated_type,
    STATE(5640), 1,
      sym__simple_type,
    STATE(8201), 1,
      sym__soft_identifier,
    STATE(8332), 1,
      sym_identifier,
    STATE(8492), 1,
      sym__constructor_application,
    STATE(9547), 1,
      sym_annotated_type,
    STATE(9554), 1,
      sym_compound_type,
    STATE(9839), 1,
      sym__structural_type,
    STATE(9900), 1,
      sym_template_body,
    STATE(16178), 1,
      sym_stable_identifier,
    STATE(4422), 2,
      sym_comment,
      sym_block_comment,
    STATE(6450), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8571), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8702), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [235966] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8579), 1,
      sym__alpha_identifier,
    ACTIONS(8581), 1,
      anon_sym_COLON,
    ACTIONS(8583), 1,
      anon_sym_LBRACE,
    ACTIONS(8585), 1,
      anon_sym__,
    ACTIONS(8589), 1,
      anon_sym_LPAREN,
    ACTIONS(8591), 1,
      sym__backquoted_id,
    ACTIONS(8593), 1,
      sym_operator_identifier,
    STATE(4426), 1,
      sym__annotated_type,
    STATE(4437), 1,
      sym__simple_type,
    STATE(5225), 1,
      sym__constructor_application,
    STATE(5231), 1,
      sym__soft_identifier,
    STATE(5372), 1,
      sym_identifier,
    STATE(6238), 1,
      sym_annotated_type,
    STATE(6454), 1,
      sym_compound_type,
    STATE(6692), 1,
      sym_template_body,
    STATE(6782), 1,
      sym__structural_type,
    STATE(16340), 1,
      sym_stable_identifier,
    STATE(4423), 2,
      sym_comment,
      sym_block_comment,
    STATE(6878), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8587), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5387), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [236049] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6194), 1,
      anon_sym_COLON,
    ACTIONS(6196), 1,
      anon_sym_LBRACE,
    ACTIONS(8595), 1,
      sym__alpha_identifier,
    ACTIONS(8597), 1,
      anon_sym__,
    ACTIONS(8601), 1,
      anon_sym_LPAREN,
    ACTIONS(8603), 1,
      sym__backquoted_id,
    ACTIONS(8605), 1,
      sym_operator_identifier,
    STATE(4607), 1,
      sym__annotated_type,
    STATE(4624), 1,
      sym__simple_type,
    STATE(6265), 1,
      sym__constructor_application,
    STATE(6423), 1,
      sym_identifier,
    STATE(6470), 1,
      sym__soft_identifier,
    STATE(7692), 1,
      sym_compound_type,
    STATE(7846), 1,
      sym_annotated_type,
    STATE(8358), 1,
      sym__structural_type,
    STATE(8451), 1,
      sym_template_body,
    STATE(16488), 1,
      sym_stable_identifier,
    STATE(4424), 2,
      sym_comment,
      sym_block_comment,
    STATE(8355), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8599), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6546), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [236132] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6280), 1,
      anon_sym_COLON,
    ACTIONS(6282), 1,
      anon_sym_LBRACE,
    ACTIONS(8607), 1,
      sym__alpha_identifier,
    ACTIONS(8609), 1,
      anon_sym__,
    ACTIONS(8613), 1,
      anon_sym_LPAREN,
    ACTIONS(8615), 1,
      sym__backquoted_id,
    ACTIONS(8617), 1,
      sym_operator_identifier,
    STATE(4615), 1,
      sym__annotated_type,
    STATE(4635), 1,
      sym__simple_type,
    STATE(6361), 1,
      sym__constructor_application,
    STATE(6383), 1,
      sym__soft_identifier,
    STATE(6474), 1,
      sym_identifier,
    STATE(7786), 1,
      sym_compound_type,
    STATE(7906), 1,
      sym_annotated_type,
    STATE(8102), 1,
      sym__structural_type,
    STATE(8426), 1,
      sym_template_body,
    STATE(16530), 1,
      sym_stable_identifier,
    STATE(4425), 2,
      sym_comment,
      sym_block_comment,
    STATE(8139), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8611), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6585), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [236215] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8619), 1,
      anon_sym_with,
    STATE(4521), 1,
      aux_sym_compound_type_repeat1,
    STATE(6791), 1,
      sym_arguments,
    STATE(7035), 1,
      sym_template_body,
    STATE(7036), 1,
      sym__refinement,
    STATE(4426), 2,
      sym_comment,
      sym_block_comment,
    STATE(6878), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [236274] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4427), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 25,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [236321] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8228), 1,
      anon_sym_with,
    STATE(5267), 1,
      aux_sym_compound_type_repeat1,
    STATE(6385), 1,
      sym_template_body,
    STATE(6419), 1,
      sym__refinement,
    STATE(4428), 2,
      sym_comment,
      sym_block_comment,
    STATE(6463), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [236378] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(8625), 1,
      sym__alpha_identifier,
    ACTIONS(8627), 1,
      anon_sym__,
    ACTIONS(8631), 1,
      anon_sym_LPAREN,
    ACTIONS(8633), 1,
      sym__backquoted_id,
    ACTIONS(8635), 1,
      sym_operator_identifier,
    STATE(5681), 1,
      sym__annotated_type,
    STATE(5715), 1,
      sym__simple_type,
    STATE(8303), 1,
      sym__soft_identifier,
    STATE(8376), 1,
      sym__constructor_application,
    STATE(8432), 1,
      sym_identifier,
    STATE(9332), 1,
      sym_compound_type,
    STATE(9665), 1,
      sym_annotated_type,
    STATE(9818), 1,
      sym__structural_type,
    STATE(9970), 1,
      sym_template_body,
    STATE(16610), 1,
      sym_stable_identifier,
    STATE(4429), 2,
      sym_comment,
      sym_block_comment,
    STATE(6282), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8629), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8693), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [236461] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8637), 1,
      sym__alpha_identifier,
    ACTIONS(8639), 1,
      anon_sym_COLON,
    ACTIONS(8641), 1,
      anon_sym_LBRACE,
    ACTIONS(8643), 1,
      anon_sym__,
    ACTIONS(8647), 1,
      anon_sym_LPAREN,
    ACTIONS(8649), 1,
      sym__backquoted_id,
    ACTIONS(8651), 1,
      sym_operator_identifier,
    STATE(7412), 1,
      sym__simple_type,
    STATE(8057), 1,
      sym__annotated_type,
    STATE(9867), 1,
      sym__soft_identifier,
    STATE(10044), 1,
      sym__constructor_application,
    STATE(10066), 1,
      sym_identifier,
    STATE(10612), 1,
      sym_annotated_type,
    STATE(10624), 1,
      sym_compound_type,
    STATE(10771), 1,
      sym_template_body,
    STATE(10909), 1,
      sym__structural_type,
    STATE(16670), 1,
      sym_stable_identifier,
    STATE(4430), 2,
      sym_comment,
      sym_block_comment,
    STATE(10876), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8645), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9783), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [236544] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8653), 1,
      sym__alpha_identifier,
    ACTIONS(8655), 1,
      anon_sym_COLON,
    ACTIONS(8657), 1,
      anon_sym_LBRACE,
    ACTIONS(8659), 1,
      anon_sym__,
    ACTIONS(8663), 1,
      anon_sym_LPAREN,
    ACTIONS(8665), 1,
      sym__backquoted_id,
    ACTIONS(8667), 1,
      sym_operator_identifier,
    STATE(4255), 1,
      sym__simple_type,
    STATE(4257), 1,
      sym__annotated_type,
    STATE(4637), 1,
      sym__constructor_application,
    STATE(4727), 1,
      sym__soft_identifier,
    STATE(4750), 1,
      sym_identifier,
    STATE(5332), 1,
      sym_compound_type,
    STATE(5455), 1,
      sym_annotated_type,
    STATE(5679), 1,
      sym_template_body,
    STATE(5741), 1,
      sym__structural_type,
    STATE(16689), 1,
      sym_stable_identifier,
    STATE(4431), 2,
      sym_comment,
      sym_block_comment,
    STATE(5869), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8661), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4741), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [236627] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8669), 1,
      sym__alpha_identifier,
    ACTIONS(8671), 1,
      anon_sym_COLON,
    ACTIONS(8673), 1,
      anon_sym_LBRACE,
    ACTIONS(8675), 1,
      anon_sym__,
    ACTIONS(8679), 1,
      anon_sym_LPAREN,
    ACTIONS(8681), 1,
      sym__backquoted_id,
    ACTIONS(8683), 1,
      sym_operator_identifier,
    STATE(4450), 1,
      sym__annotated_type,
    STATE(4452), 1,
      sym__simple_type,
    STATE(5137), 1,
      sym__soft_identifier,
    STATE(5320), 1,
      sym__constructor_application,
    STATE(5462), 1,
      sym_identifier,
    STATE(6106), 1,
      sym_compound_type,
    STATE(6205), 1,
      sym_annotated_type,
    STATE(6882), 1,
      sym_template_body,
    STATE(6985), 1,
      sym__structural_type,
    STATE(16727), 1,
      sym_stable_identifier,
    STATE(4432), 2,
      sym_comment,
      sym_block_comment,
    STATE(7225), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8677), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5243), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [236710] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6628), 1,
      anon_sym_COLON,
    ACTIONS(6630), 1,
      anon_sym_LBRACE,
    ACTIONS(8685), 1,
      sym__alpha_identifier,
    ACTIONS(8687), 1,
      anon_sym__,
    ACTIONS(8691), 1,
      anon_sym_LPAREN,
    ACTIONS(8693), 1,
      sym__backquoted_id,
    ACTIONS(8695), 1,
      sym_operator_identifier,
    STATE(4453), 1,
      sym__simple_type,
    STATE(4454), 1,
      sym__annotated_type,
    STATE(5145), 1,
      sym__soft_identifier,
    STATE(5245), 1,
      sym_identifier,
    STATE(5325), 1,
      sym__constructor_application,
    STATE(6154), 1,
      sym_compound_type,
    STATE(6220), 1,
      sym_annotated_type,
    STATE(6915), 1,
      sym_template_body,
    STATE(7030), 1,
      sym__structural_type,
    STATE(16764), 1,
      sym_stable_identifier,
    STATE(4433), 2,
      sym_comment,
      sym_block_comment,
    STATE(7326), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8689), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5378), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [236793] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6652), 1,
      anon_sym_COLON,
    ACTIONS(6654), 1,
      anon_sym_LBRACE,
    ACTIONS(8697), 1,
      sym__alpha_identifier,
    ACTIONS(8699), 1,
      anon_sym__,
    ACTIONS(8703), 1,
      anon_sym_LPAREN,
    ACTIONS(8705), 1,
      sym__backquoted_id,
    ACTIONS(8707), 1,
      sym_operator_identifier,
    STATE(4894), 1,
      sym__simple_type,
    STATE(4896), 1,
      sym__annotated_type,
    STATE(6945), 1,
      sym__constructor_application,
    STATE(7069), 1,
      sym_identifier,
    STATE(7122), 1,
      sym__soft_identifier,
    STATE(8328), 1,
      sym_annotated_type,
    STATE(8700), 1,
      sym_compound_type,
    STATE(8795), 1,
      sym_template_body,
    STATE(8993), 1,
      sym__structural_type,
    STATE(16800), 1,
      sym_stable_identifier,
    STATE(4434), 2,
      sym_comment,
      sym_block_comment,
    STATE(9294), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8701), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7218), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [236876] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8709), 1,
      anon_sym_COLON,
    ACTIONS(8711), 1,
      anon_sym_LBRACE,
    ACTIONS(8713), 1,
      anon_sym_with,
    STATE(4456), 1,
      aux_sym_compound_type_repeat1,
    STATE(7628), 1,
      sym_template_body,
    STATE(7629), 1,
      sym__refinement,
    STATE(4435), 2,
      sym_comment,
      sym_block_comment,
    STATE(7905), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [236937] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6670), 1,
      anon_sym_COLON,
    ACTIONS(6672), 1,
      anon_sym_LBRACE,
    ACTIONS(8715), 1,
      sym__alpha_identifier,
    ACTIONS(8717), 1,
      anon_sym__,
    ACTIONS(8721), 1,
      anon_sym_LPAREN,
    ACTIONS(8723), 1,
      sym__backquoted_id,
    ACTIONS(8725), 1,
      sym_operator_identifier,
    STATE(4913), 1,
      sym__simple_type,
    STATE(4915), 1,
      sym__annotated_type,
    STATE(6897), 1,
      sym_identifier,
    STATE(6966), 1,
      sym__constructor_application,
    STATE(7174), 1,
      sym__soft_identifier,
    STATE(8456), 1,
      sym_compound_type,
    STATE(8623), 1,
      sym_annotated_type,
    STATE(8845), 1,
      sym_template_body,
    STATE(9047), 1,
      sym__structural_type,
    STATE(16889), 1,
      sym_stable_identifier,
    STATE(4436), 2,
      sym_comment,
      sym_block_comment,
    STATE(9215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8719), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6899), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [237020] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8727), 1,
      anon_sym_LBRACK,
    ACTIONS(8729), 1,
      anon_sym_AT,
    ACTIONS(8731), 1,
      anon_sym_LPAREN,
    ACTIONS(8733), 1,
      anon_sym_POUND,
    STATE(5047), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5392), 1,
      sym_type_arguments,
    STATE(5840), 1,
      sym_annotation,
    STATE(6791), 1,
      sym_arguments,
    STATE(4437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [237083] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6692), 1,
      anon_sym_COLON,
    ACTIONS(6694), 1,
      anon_sym_LBRACE,
    ACTIONS(8735), 1,
      sym__alpha_identifier,
    ACTIONS(8737), 1,
      anon_sym__,
    ACTIONS(8741), 1,
      anon_sym_LPAREN,
    ACTIONS(8743), 1,
      sym__backquoted_id,
    ACTIONS(8745), 1,
      sym_operator_identifier,
    STATE(4532), 1,
      sym__simple_type,
    STATE(4535), 1,
      sym__annotated_type,
    STATE(5520), 1,
      sym__soft_identifier,
    STATE(5547), 1,
      sym_identifier,
    STATE(5760), 1,
      sym__constructor_application,
    STATE(7146), 1,
      sym_compound_type,
    STATE(7323), 1,
      sym_annotated_type,
    STATE(7485), 1,
      sym_template_body,
    STATE(7768), 1,
      sym__structural_type,
    STATE(17053), 1,
      sym_stable_identifier,
    STATE(4438), 2,
      sym_comment,
      sym_block_comment,
    STATE(7459), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8739), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5835), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [237166] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8709), 1,
      anon_sym_COLON,
    ACTIONS(8711), 1,
      anon_sym_LBRACE,
    ACTIONS(8713), 1,
      anon_sym_with,
    STATE(4456), 1,
      aux_sym_compound_type_repeat1,
    STATE(7628), 1,
      sym_template_body,
    STATE(7629), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4439), 2,
      sym_comment,
      sym_block_comment,
    STATE(7905), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 7,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [237233] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8400), 1,
      anon_sym_LBRACK,
    ACTIONS(8404), 1,
      anon_sym_POUND,
    ACTIONS(8747), 1,
      anon_sym_AT,
    STATE(4690), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4715), 1,
      sym_type_arguments,
    STATE(5384), 1,
      sym_annotation,
    STATE(4440), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [237292] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6714), 1,
      anon_sym_COLON,
    ACTIONS(6716), 1,
      anon_sym_LBRACE,
    ACTIONS(8749), 1,
      sym__alpha_identifier,
    ACTIONS(8751), 1,
      anon_sym__,
    ACTIONS(8755), 1,
      anon_sym_LPAREN,
    ACTIONS(8757), 1,
      sym__backquoted_id,
    ACTIONS(8759), 1,
      sym_operator_identifier,
    STATE(4942), 1,
      sym__simple_type,
    STATE(4949), 1,
      sym__annotated_type,
    STATE(7011), 1,
      sym__constructor_application,
    STATE(7068), 1,
      sym_identifier,
    STATE(7238), 1,
      sym__soft_identifier,
    STATE(8111), 1,
      sym_compound_type,
    STATE(8315), 1,
      sym_annotated_type,
    STATE(8902), 1,
      sym_template_body,
    STATE(9099), 1,
      sym__structural_type,
    STATE(17065), 1,
      sym_stable_identifier,
    STATE(4441), 2,
      sym_comment,
      sym_block_comment,
    STATE(8768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8753), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7119), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [237375] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6742), 1,
      anon_sym_COLON,
    ACTIONS(6744), 1,
      anon_sym_LBRACE,
    ACTIONS(8761), 1,
      sym__alpha_identifier,
    ACTIONS(8763), 1,
      anon_sym__,
    ACTIONS(8767), 1,
      anon_sym_LPAREN,
    ACTIONS(8769), 1,
      sym__backquoted_id,
    ACTIONS(8771), 1,
      sym_operator_identifier,
    STATE(5381), 1,
      sym__simple_type,
    STATE(5385), 1,
      sym__annotated_type,
    STATE(7576), 1,
      sym__constructor_application,
    STATE(7705), 1,
      sym_identifier,
    STATE(7907), 1,
      sym__soft_identifier,
    STATE(9115), 1,
      sym_compound_type,
    STATE(9156), 1,
      sym_annotated_type,
    STATE(9365), 1,
      sym_template_body,
    STATE(9553), 1,
      sym__structural_type,
    STATE(17083), 1,
      sym_stable_identifier,
    STATE(4442), 2,
      sym_comment,
      sym_block_comment,
    STATE(5571), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8765), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7863), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [237458] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8773), 1,
      sym__alpha_identifier,
    ACTIONS(8775), 1,
      anon_sym_COLON,
    ACTIONS(8777), 1,
      anon_sym_LBRACE,
    ACTIONS(8779), 1,
      anon_sym__,
    ACTIONS(8783), 1,
      anon_sym_LPAREN,
    ACTIONS(8785), 1,
      sym__backquoted_id,
    ACTIONS(8787), 1,
      sym_operator_identifier,
    STATE(4370), 1,
      sym__simple_type,
    STATE(4376), 1,
      sym__annotated_type,
    STATE(4893), 1,
      sym_identifier,
    STATE(4907), 1,
      sym__constructor_application,
    STATE(4931), 1,
      sym__soft_identifier,
    STATE(5703), 1,
      sym_annotated_type,
    STATE(5870), 1,
      sym_compound_type,
    STATE(6196), 1,
      sym_template_body,
    STATE(6421), 1,
      sym__structural_type,
    STATE(17113), 1,
      sym_stable_identifier,
    STATE(4443), 2,
      sym_comment,
      sym_block_comment,
    STATE(6014), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8781), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4979), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [237541] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6116), 1,
      anon_sym_COLON,
    ACTIONS(6118), 1,
      anon_sym_LBRACE,
    ACTIONS(8789), 1,
      sym__alpha_identifier,
    ACTIONS(8791), 1,
      anon_sym__,
    ACTIONS(8795), 1,
      anon_sym_LPAREN,
    ACTIONS(8797), 1,
      sym__backquoted_id,
    ACTIONS(8799), 1,
      sym_operator_identifier,
    STATE(4540), 1,
      sym__simple_type,
    STATE(4547), 1,
      sym__annotated_type,
    STATE(5528), 1,
      sym__soft_identifier,
    STATE(5809), 1,
      sym__constructor_application,
    STATE(5927), 1,
      sym_identifier,
    STATE(7015), 1,
      sym_annotated_type,
    STATE(7226), 1,
      sym_compound_type,
    STATE(7658), 1,
      sym_template_body,
    STATE(7879), 1,
      sym__structural_type,
    STATE(17131), 1,
      sym_stable_identifier,
    STATE(4444), 2,
      sym_comment,
      sym_block_comment,
    STATE(7638), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8793), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5865), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [237624] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(892), 1,
      anon_sym_LBRACE,
    ACTIONS(8086), 1,
      anon_sym_LPAREN,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8809), 1,
      anon_sym_DOT,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(8817), 1,
      sym_operator_identifier,
    STATE(1769), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4445), 2,
      sym_comment,
      sym_block_comment,
    STATE(5686), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8807), 8,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [237695] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(8819), 1,
      sym__alpha_identifier,
    ACTIONS(8821), 1,
      anon_sym__,
    ACTIONS(8825), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      sym__backquoted_id,
    ACTIONS(8829), 1,
      sym_operator_identifier,
    STATE(4712), 1,
      sym__simple_type,
    STATE(4732), 1,
      sym__annotated_type,
    STATE(6229), 1,
      sym_identifier,
    STATE(6289), 1,
      sym__constructor_application,
    STATE(6351), 1,
      sym__soft_identifier,
    STATE(7934), 1,
      sym_compound_type,
    STATE(7985), 1,
      sym_annotated_type,
    STATE(8385), 1,
      sym__structural_type,
    STATE(8473), 1,
      sym_template_body,
    STATE(17209), 1,
      sym_stable_identifier,
    STATE(4446), 2,
      sym_comment,
      sym_block_comment,
    STATE(8220), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8823), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6140), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [237778] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(892), 1,
      anon_sym_LBRACE,
    ACTIONS(8086), 1,
      anon_sym_LPAREN,
    ACTIONS(8809), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4447), 2,
      sym_comment,
      sym_block_comment,
    STATE(5686), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [237837] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(892), 1,
      anon_sym_LBRACE,
    ACTIONS(8086), 1,
      anon_sym_LPAREN,
    ACTIONS(8809), 1,
      anon_sym_DOT,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4448), 2,
      sym_comment,
      sym_block_comment,
    STATE(5686), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [237898] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8232), 1,
      anon_sym_LBRACK,
    ACTIONS(8238), 1,
      anon_sym_POUND,
    ACTIONS(8839), 1,
      anon_sym_LPAREN,
    STATE(4649), 1,
      aux_sym_annotation_repeat1,
    STATE(4825), 1,
      sym_type_arguments,
    STATE(5327), 1,
      sym_arguments,
    STATE(4449), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [237957] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8841), 1,
      anon_sym_with,
    STATE(4491), 1,
      aux_sym_compound_type_repeat1,
    STATE(6993), 1,
      sym_arguments,
    STATE(7379), 1,
      sym_template_body,
    STATE(7380), 1,
      sym__refinement,
    STATE(4450), 2,
      sym_comment,
      sym_block_comment,
    STATE(7225), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [238016] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6789), 1,
      sym_interpolated_string,
    STATE(15449), 1,
      sym__interpolated_string_start,
    STATE(15451), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [238075] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8843), 1,
      anon_sym_LBRACK,
    ACTIONS(8845), 1,
      anon_sym_AT,
    ACTIONS(8847), 1,
      anon_sym_LPAREN,
    ACTIONS(8849), 1,
      anon_sym_POUND,
    STATE(4763), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5262), 1,
      sym_type_arguments,
    STATE(5561), 1,
      sym_annotation,
    STATE(6993), 1,
      sym_arguments,
    STATE(4452), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [238138] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8851), 1,
      anon_sym_LBRACK,
    ACTIONS(8853), 1,
      anon_sym_AT,
    ACTIONS(8855), 1,
      anon_sym_LPAREN,
    ACTIONS(8857), 1,
      anon_sym_POUND,
    STATE(4772), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5401), 1,
      sym_type_arguments,
    STATE(5540), 1,
      sym_annotation,
    STATE(7037), 1,
      sym_arguments,
    STATE(4453), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [238201] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8859), 1,
      anon_sym_with,
    STATE(4480), 1,
      aux_sym_compound_type_repeat1,
    STATE(6784), 1,
      sym_template_body,
    STATE(6790), 1,
      sym__refinement,
    STATE(7037), 1,
      sym_arguments,
    STATE(4454), 2,
      sym_comment,
      sym_block_comment,
    STATE(7326), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [238260] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8258), 1,
      anon_sym_LBRACK,
    ACTIONS(8262), 1,
      anon_sym_POUND,
    ACTIONS(8861), 1,
      anon_sym_AT,
    STATE(4595), 1,
      sym_type_arguments,
    STATE(4679), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5376), 1,
      sym_annotation,
    STATE(4455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [238319] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8709), 1,
      anon_sym_COLON,
    ACTIONS(8711), 1,
      anon_sym_LBRACE,
    ACTIONS(8713), 1,
      anon_sym_with,
    STATE(5357), 1,
      aux_sym_compound_type_repeat1,
    STATE(7628), 1,
      sym_template_body,
    STATE(7637), 1,
      sym__refinement,
    STATE(4456), 2,
      sym_comment,
      sym_block_comment,
    STATE(7905), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [238380] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8871), 1,
      anon_sym_inline,
    ACTIONS(8874), 1,
      anon_sym_infix,
    ACTIONS(8877), 1,
      anon_sym_open,
    ACTIONS(8880), 1,
      anon_sym_transparent,
    ACTIONS(8883), 1,
      sym__backquoted_id,
    ACTIONS(8868), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4457), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_modifiers_repeat1,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8865), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
    ACTIONS(8863), 13,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      sym__alpha_identifier,
      sym_operator_identifier,
  [238441] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8232), 1,
      anon_sym_LBRACK,
    ACTIONS(8234), 1,
      anon_sym_AT,
    ACTIONS(8238), 1,
      anon_sym_POUND,
    STATE(4602), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4825), 1,
      sym_type_arguments,
    STATE(5293), 1,
      sym_annotation,
    STATE(4458), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [238500] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6212), 1,
      anon_sym_COLON,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(8885), 1,
      sym__alpha_identifier,
    ACTIONS(8887), 1,
      anon_sym__,
    ACTIONS(8891), 1,
      anon_sym_LPAREN,
    ACTIONS(8893), 1,
      sym__backquoted_id,
    ACTIONS(8895), 1,
      sym_operator_identifier,
    STATE(6309), 1,
      sym__simple_type,
    STATE(6525), 1,
      sym__annotated_type,
    STATE(8971), 1,
      sym_identifier,
    STATE(8990), 1,
      sym__soft_identifier,
    STATE(9055), 1,
      sym__constructor_application,
    STATE(9100), 1,
      sym_compound_type,
    STATE(9540), 1,
      sym__structural_type,
    STATE(9795), 1,
      sym_annotated_type,
    STATE(10290), 1,
      sym_template_body,
    STATE(17521), 1,
      sym_stable_identifier,
    STATE(4459), 2,
      sym_comment,
      sym_block_comment,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8889), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9102), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [238583] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6969), 1,
      sym_interpolated_string,
    STATE(15593), 1,
      sym__interpolated_string_start,
    STATE(15595), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4460), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [238642] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8378), 1,
      sym__alpha_identifier,
    ACTIONS(8384), 1,
      anon_sym__,
    ACTIONS(8388), 1,
      anon_sym_LPAREN,
    ACTIONS(8390), 1,
      sym__backquoted_id,
    ACTIONS(8392), 1,
      sym_operator_identifier,
    ACTIONS(8897), 1,
      anon_sym_COLON,
    ACTIONS(8899), 1,
      anon_sym_LBRACE,
    STATE(11873), 1,
      sym__simple_type,
    STATE(12324), 1,
      sym__annotated_type,
    STATE(13074), 1,
      sym_identifier,
    STATE(13178), 1,
      sym__soft_identifier,
    STATE(14057), 1,
      sym_annotated_type,
    STATE(14087), 1,
      sym_compound_type,
    STATE(14212), 1,
      sym__constructor_application,
    STATE(14353), 1,
      sym__structural_type,
    STATE(14356), 1,
      sym_template_body,
    STATE(17206), 1,
      sym_stable_identifier,
    STATE(4461), 2,
      sym_comment,
      sym_block_comment,
    STATE(14185), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8386), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13352), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [238725] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6992), 1,
      sym_interpolated_string,
    STATE(14749), 1,
      sym__interpolated_string_start,
    STATE(14750), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4462), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [238784] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8378), 1,
      sym__alpha_identifier,
    ACTIONS(8380), 1,
      anon_sym_COLON,
    ACTIONS(8382), 1,
      anon_sym_LBRACE,
    ACTIONS(8384), 1,
      anon_sym__,
    ACTIONS(8388), 1,
      anon_sym_LPAREN,
    ACTIONS(8390), 1,
      sym__backquoted_id,
    ACTIONS(8392), 1,
      sym_operator_identifier,
    STATE(12073), 1,
      sym__simple_type,
    STATE(12329), 1,
      sym__annotated_type,
    STATE(13074), 1,
      sym_identifier,
    STATE(13178), 1,
      sym__soft_identifier,
    STATE(13914), 1,
      sym_compound_type,
    STATE(14057), 1,
      sym_annotated_type,
    STATE(14078), 1,
      sym_template_body,
    STATE(14158), 1,
      sym__structural_type,
    STATE(14213), 1,
      sym__constructor_application,
    STATE(17206), 1,
      sym_stable_identifier,
    STATE(4463), 2,
      sym_comment,
      sym_block_comment,
    STATE(14037), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8386), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13352), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [238867] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 25,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [238914] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 25,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [238961] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6346), 1,
      anon_sym_COLON,
    ACTIONS(6348), 1,
      anon_sym_LBRACE,
    ACTIONS(8909), 1,
      sym__alpha_identifier,
    ACTIONS(8911), 1,
      anon_sym__,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8917), 1,
      sym__backquoted_id,
    ACTIONS(8919), 1,
      sym_operator_identifier,
    STATE(4837), 1,
      sym__annotated_type,
    STATE(4860), 1,
      sym__simple_type,
    STATE(6699), 1,
      sym__soft_identifier,
    STATE(6785), 1,
      sym__constructor_application,
    STATE(7258), 1,
      sym_identifier,
    STATE(8292), 1,
      sym_compound_type,
    STATE(8430), 1,
      sym_annotated_type,
    STATE(9163), 1,
      sym_template_body,
    STATE(9298), 1,
      sym__structural_type,
    STATE(16570), 1,
      sym_stable_identifier,
    STATE(4466), 2,
      sym_comment,
      sym_block_comment,
    STATE(5352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8913), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7360), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [239044] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239090] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8921), 1,
      anon_sym_LBRACK,
    ACTIONS(8923), 1,
      anon_sym_LPAREN,
    ACTIONS(8925), 1,
      anon_sym_POUND,
    STATE(4838), 1,
      aux_sym_annotation_repeat1,
    STATE(5125), 1,
      sym_type_arguments,
    STATE(5836), 1,
      sym_arguments,
    STATE(4468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [239148] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8927), 1,
      anon_sym_DOT,
    STATE(4469), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239196] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [239242] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4471), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [239288] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4472), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239334] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [239380] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239426] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4475), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239472] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239518] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8437), 1,
      anon_sym_LBRACK,
    ACTIONS(8441), 1,
      anon_sym_POUND,
    ACTIONS(8929), 1,
      anon_sym_AT,
    STATE(4815), 1,
      sym_type_arguments,
    STATE(4929), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5541), 1,
      sym_annotation,
    STATE(4477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239576] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8935), 1,
      anon_sym_AT,
    STATE(4895), 1,
      sym_annotation,
    STATE(4478), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239626] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8443), 1,
      anon_sym_LBRACK,
    ACTIONS(8447), 1,
      anon_sym_POUND,
    ACTIONS(8938), 1,
      anon_sym_AT,
    STATE(4836), 1,
      sym_type_arguments,
    STATE(4951), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5544), 1,
      sym_annotation,
    STATE(4479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [239684] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8859), 1,
      anon_sym_with,
    STATE(5856), 1,
      aux_sym_compound_type_repeat1,
    STATE(6784), 1,
      sym_template_body,
    STATE(6852), 1,
      sym__refinement,
    STATE(4480), 2,
      sym_comment,
      sym_block_comment,
    STATE(7326), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [239740] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8940), 1,
      anon_sym_COLON,
    ACTIONS(8942), 1,
      anon_sym_LBRACE,
    ACTIONS(8944), 1,
      anon_sym_with,
    STATE(5971), 1,
      aux_sym_compound_type_repeat1,
    STATE(8641), 1,
      sym_template_body,
    STATE(8654), 1,
      sym__refinement,
    STATE(4481), 2,
      sym_comment,
      sym_block_comment,
    STATE(8270), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239800] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(7598), 1,
      sym_interpolated_string,
    STATE(15304), 1,
      sym__interpolated_string_start,
    STATE(15305), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239858] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(5730), 1,
      sym_interpolated_string,
    STATE(15429), 1,
      sym__interpolated_string_start,
    STATE(15431), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8946), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4483), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239916] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4484), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [239962] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(7773), 1,
      sym_interpolated_string,
    STATE(15213), 1,
      sym__interpolated_string_start,
    STATE(15214), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [240020] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8727), 1,
      anon_sym_LBRACK,
    ACTIONS(8729), 1,
      anon_sym_AT,
    ACTIONS(8733), 1,
      anon_sym_POUND,
    STATE(5047), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5392), 1,
      sym_type_arguments,
    STATE(5840), 1,
      sym_annotation,
    STATE(4486), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240078] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8240), 1,
      anon_sym_LPAREN,
    STATE(4488), 1,
      aux_sym_annotation_repeat1,
    STATE(5041), 1,
      sym_arguments,
    STATE(4487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240130] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8948), 1,
      anon_sym_LPAREN,
    STATE(5041), 1,
      sym_arguments,
    STATE(4488), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240180] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(5730), 1,
      sym_interpolated_string,
    STATE(15429), 1,
      sym__interpolated_string_start,
    STATE(15431), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8951), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [240238] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4490), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240284] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8841), 1,
      anon_sym_with,
    STATE(5980), 1,
      aux_sym_compound_type_repeat1,
    STATE(7379), 1,
      sym_template_body,
    STATE(7384), 1,
      sym__refinement,
    STATE(4491), 2,
      sym_comment,
      sym_block_comment,
    STATE(7225), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240340] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8843), 1,
      anon_sym_LBRACK,
    ACTIONS(8849), 1,
      anon_sym_POUND,
    ACTIONS(8955), 1,
      anon_sym_LPAREN,
    STATE(4800), 1,
      aux_sym_annotation_repeat1,
    STATE(5262), 1,
      sym_type_arguments,
    STATE(5664), 1,
      sym_arguments,
    STATE(4492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240398] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8222), 1,
      anon_sym_AT,
    STATE(4516), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4933), 1,
      sym_annotation,
    STATE(4493), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240450] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8851), 1,
      anon_sym_LBRACK,
    ACTIONS(8857), 1,
      anon_sym_POUND,
    ACTIONS(8961), 1,
      anon_sym_LPAREN,
    STATE(4909), 1,
      aux_sym_annotation_repeat1,
    STATE(5401), 1,
      sym_type_arguments,
    STATE(5933), 1,
      sym_arguments,
    STATE(4494), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [240508] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8459), 1,
      anon_sym_LBRACK,
    ACTIONS(8463), 1,
      anon_sym_POUND,
    ACTIONS(8963), 1,
      anon_sym_AT,
    STATE(4855), 1,
      sym_type_arguments,
    STATE(5032), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5513), 1,
      sym_annotation,
    STATE(4495), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240566] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8965), 1,
      anon_sym_with,
    STATE(4673), 1,
      aux_sym_compound_type_repeat1,
    STATE(7662), 1,
      sym_template_body,
    STATE(7664), 1,
      sym__refinement,
    STATE(7665), 1,
      sym_arguments,
    STATE(4496), 2,
      sym_comment,
      sym_block_comment,
    STATE(7553), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240624] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8967), 1,
      anon_sym_COLON,
    ACTIONS(8969), 1,
      anon_sym_LBRACE,
    ACTIONS(8971), 1,
      anon_sym_with,
    STATE(5990), 1,
      aux_sym_compound_type_repeat1,
    STATE(8305), 1,
      sym_template_body,
    STATE(8551), 1,
      sym__refinement,
    STATE(4497), 2,
      sym_comment,
      sym_block_comment,
    STATE(8657), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240684] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8973), 1,
      anon_sym_DOT,
    STATE(4498), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240732] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(4499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240780] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8975), 1,
      anon_sym_LBRACK,
    ACTIONS(8977), 1,
      anon_sym_LPAREN,
    ACTIONS(8979), 1,
      anon_sym_POUND,
    STATE(4911), 1,
      aux_sym_annotation_repeat1,
    STATE(5284), 1,
      sym_type_arguments,
    STATE(5860), 1,
      sym_arguments,
    STATE(4500), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240838] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4501), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240884] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240930] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240976] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8987), 1,
      anon_sym_DOT,
    STATE(4504), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241024] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(936), 1,
      anon_sym_LBRACE,
    ACTIONS(8236), 1,
      anon_sym_LPAREN,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8989), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4505), 2,
      sym_comment,
      sym_block_comment,
    STATE(6647), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241084] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8260), 1,
      anon_sym_LPAREN,
    STATE(4507), 1,
      aux_sym_annotation_repeat1,
    STATE(4769), 1,
      sym_arguments,
    STATE(4506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241136] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8991), 1,
      anon_sym_LPAREN,
    STATE(4769), 1,
      sym_arguments,
    STATE(4507), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241186] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4508), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241232] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8455), 1,
      anon_sym_DOT,
    ACTIONS(8996), 1,
      anon_sym_EQ_GT,
    STATE(4509), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241282] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8998), 1,
      anon_sym_LBRACK,
    ACTIONS(9000), 1,
      anon_sym_LPAREN,
    ACTIONS(9002), 1,
      anon_sym_POUND,
    STATE(4777), 1,
      aux_sym_annotation_repeat1,
    STATE(5069), 1,
      sym_type_arguments,
    STATE(5578), 1,
      sym_arguments,
    STATE(4510), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241340] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(8064), 1,
      anon_sym_infix,
    ACTIONS(8066), 1,
      anon_sym_open,
    ACTIONS(8068), 1,
      anon_sym_transparent,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(9006), 1,
      sym_operator_identifier,
    STATE(6745), 1,
      aux_sym_modifiers_repeat1,
    STATE(9008), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12143), 1,
      sym_modifiers,
    STATE(14559), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(8056), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(9004), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4511), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [241420] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_as,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [241466] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9008), 1,
      anon_sym_LBRACK,
    ACTIONS(9010), 1,
      anon_sym_LPAREN,
    ACTIONS(9012), 1,
      anon_sym_POUND,
    STATE(4878), 1,
      aux_sym_annotation_repeat1,
    STATE(5303), 1,
      sym_type_arguments,
    STATE(5732), 1,
      sym_arguments,
    STATE(4513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241524] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9014), 1,
      anon_sym_LBRACK,
    ACTIONS(9016), 1,
      anon_sym_LPAREN,
    ACTIONS(9018), 1,
      anon_sym_POUND,
    STATE(4791), 1,
      aux_sym_annotation_repeat1,
    STATE(5081), 1,
      sym_type_arguments,
    STATE(5625), 1,
      sym_arguments,
    STATE(4514), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [241582] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9020), 1,
      anon_sym_COLON,
    ACTIONS(9022), 1,
      anon_sym_LBRACE,
    ACTIONS(9024), 1,
      anon_sym_with,
    STATE(5466), 1,
      aux_sym_compound_type_repeat1,
    STATE(8422), 1,
      sym__refinement,
    STATE(8658), 1,
      sym_template_body,
    STATE(4515), 2,
      sym_comment,
      sym_block_comment,
    STATE(8190), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241642] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9026), 1,
      anon_sym_AT,
    STATE(4933), 1,
      sym_annotation,
    STATE(4516), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241692] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9029), 1,
      anon_sym_LBRACK,
    ACTIONS(9031), 1,
      anon_sym_LPAREN,
    ACTIONS(9033), 1,
      anon_sym_POUND,
    STATE(4806), 1,
      aux_sym_annotation_repeat1,
    STATE(5098), 1,
      sym_type_arguments,
    STATE(5661), 1,
      sym_arguments,
    STATE(4517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [241750] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9035), 1,
      anon_sym_LBRACK,
    ACTIONS(9037), 1,
      anon_sym_AT,
    ACTIONS(9039), 1,
      anon_sym_LPAREN,
    ACTIONS(9041), 1,
      anon_sym_POUND,
    STATE(5366), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5903), 1,
      sym_type_arguments,
    STATE(6590), 1,
      sym_annotation,
    STATE(7665), 1,
      sym_arguments,
    STATE(4518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241812] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9043), 1,
      anon_sym_LPAREN,
    STATE(4823), 1,
      sym_arguments,
    STATE(4519), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241862] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(972), 1,
      anon_sym_LBRACE,
    ACTIONS(8374), 1,
      anon_sym_LPAREN,
    ACTIONS(9046), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4520), 2,
      sym_comment,
      sym_block_comment,
    STATE(6202), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241920] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8619), 1,
      anon_sym_with,
    STATE(5784), 1,
      aux_sym_compound_type_repeat1,
    STATE(7035), 1,
      sym_template_body,
    STATE(7045), 1,
      sym__refinement,
    STATE(4521), 2,
      sym_comment,
      sym_block_comment,
    STATE(6878), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241976] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(972), 1,
      anon_sym_LBRACE,
    ACTIONS(8374), 1,
      anon_sym_LPAREN,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9046), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4522), 2,
      sym_comment,
      sym_block_comment,
    STATE(6202), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242036] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9020), 1,
      anon_sym_COLON,
    ACTIONS(9022), 1,
      anon_sym_LBRACE,
    ACTIONS(9024), 1,
      anon_sym_with,
    STATE(4515), 1,
      aux_sym_compound_type_repeat1,
    STATE(8658), 1,
      sym_template_body,
    STATE(8663), 1,
      sym__refinement,
    STATE(4523), 2,
      sym_comment,
      sym_block_comment,
    STATE(8190), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242096] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8843), 1,
      anon_sym_LBRACK,
    ACTIONS(8845), 1,
      anon_sym_AT,
    ACTIONS(8849), 1,
      anon_sym_POUND,
    STATE(4763), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5262), 1,
      sym_type_arguments,
    STATE(5561), 1,
      sym_annotation,
    STATE(4524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242154] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9020), 1,
      anon_sym_COLON,
    ACTIONS(9022), 1,
      anon_sym_LBRACE,
    ACTIONS(9024), 1,
      anon_sym_with,
    STATE(4515), 1,
      aux_sym_compound_type_repeat1,
    STATE(8658), 1,
      sym_template_body,
    STATE(8663), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4525), 2,
      sym_comment,
      sym_block_comment,
    STATE(8190), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [242220] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [242266] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8851), 1,
      anon_sym_LBRACK,
    ACTIONS(8853), 1,
      anon_sym_AT,
    ACTIONS(8857), 1,
      anon_sym_POUND,
    STATE(4772), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5401), 1,
      sym_type_arguments,
    STATE(5540), 1,
      sym_annotation,
    STATE(4527), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [242324] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9048), 1,
      anon_sym_COLON,
    ACTIONS(9050), 1,
      anon_sym_LBRACE,
    ACTIONS(9052), 1,
      anon_sym_with,
    STATE(5949), 1,
      aux_sym_compound_type_repeat1,
    STATE(8094), 1,
      sym_template_body,
    STATE(8176), 1,
      sym__refinement,
    STATE(4528), 2,
      sym_comment,
      sym_block_comment,
    STATE(8243), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242384] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8940), 1,
      anon_sym_COLON,
    ACTIONS(8942), 1,
      anon_sym_LBRACE,
    ACTIONS(8944), 1,
      anon_sym_with,
    STATE(4481), 1,
      aux_sym_compound_type_repeat1,
    STATE(8641), 1,
      sym_template_body,
    STATE(8642), 1,
      sym__refinement,
    STATE(4529), 2,
      sym_comment,
      sym_block_comment,
    STATE(8270), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242444] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [242490] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9054), 1,
      anon_sym_COLON,
    ACTIONS(9056), 1,
      anon_sym_LBRACE,
    ACTIONS(9058), 1,
      anon_sym_with,
    STATE(5501), 1,
      aux_sym_compound_type_repeat1,
    STATE(8298), 1,
      sym_template_body,
    STATE(8365), 1,
      sym__refinement,
    STATE(4531), 2,
      sym_comment,
      sym_block_comment,
    STATE(8346), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [242550] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9060), 1,
      anon_sym_LBRACK,
    ACTIONS(9062), 1,
      anon_sym_AT,
    ACTIONS(9064), 1,
      anon_sym_LPAREN,
    ACTIONS(9066), 1,
      anon_sym_POUND,
    STATE(5202), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5839), 1,
      sym_type_arguments,
    STATE(6164), 1,
      sym_annotation,
    STATE(7776), 1,
      sym_arguments,
    STATE(4532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [242612] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4533), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242658] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8967), 1,
      anon_sym_COLON,
    ACTIONS(8969), 1,
      anon_sym_LBRACE,
    ACTIONS(8971), 1,
      anon_sym_with,
    STATE(4497), 1,
      aux_sym_compound_type_repeat1,
    STATE(8305), 1,
      sym_template_body,
    STATE(8651), 1,
      sym__refinement,
    STATE(4534), 2,
      sym_comment,
      sym_block_comment,
    STATE(8657), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242718] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9070), 1,
      anon_sym_with,
    STATE(4754), 1,
      aux_sym_compound_type_repeat1,
    STATE(7426), 1,
      sym__refinement,
    STATE(7776), 1,
      sym_arguments,
    STATE(8003), 1,
      sym_template_body,
    STATE(4535), 2,
      sym_comment,
      sym_block_comment,
    STATE(7459), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [242776] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8940), 1,
      anon_sym_COLON,
    ACTIONS(8942), 1,
      anon_sym_LBRACE,
    ACTIONS(8944), 1,
      anon_sym_with,
    STATE(4481), 1,
      aux_sym_compound_type_repeat1,
    STATE(8641), 1,
      sym_template_body,
    STATE(8642), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4536), 2,
      sym_comment,
      sym_block_comment,
    STATE(8270), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [242842] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8967), 1,
      anon_sym_COLON,
    ACTIONS(8969), 1,
      anon_sym_LBRACE,
    ACTIONS(8971), 1,
      anon_sym_with,
    STATE(4497), 1,
      aux_sym_compound_type_repeat1,
    STATE(8305), 1,
      sym_template_body,
    STATE(8651), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4537), 2,
      sym_comment,
      sym_block_comment,
    STATE(8657), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [242908] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8515), 1,
      anon_sym_LBRACK,
    ACTIONS(8519), 1,
      anon_sym_POUND,
    ACTIONS(9072), 1,
      anon_sym_AT,
    STATE(5038), 1,
      sym_type_arguments,
    STATE(5046), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5590), 1,
      sym_annotation,
    STATE(4538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242966] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4539), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243012] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9076), 1,
      anon_sym_LBRACK,
    ACTIONS(9078), 1,
      anon_sym_AT,
    ACTIONS(9080), 1,
      anon_sym_LPAREN,
    ACTIONS(9082), 1,
      anon_sym_POUND,
    STATE(5369), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5923), 1,
      sym_type_arguments,
    STATE(6410), 1,
      sym_annotation,
    STATE(7884), 1,
      sym_arguments,
    STATE(4540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [243074] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8521), 1,
      anon_sym_LBRACK,
    ACTIONS(8525), 1,
      anon_sym_POUND,
    ACTIONS(9084), 1,
      anon_sym_AT,
    STATE(4905), 1,
      sym_type_arguments,
    STATE(4923), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5635), 1,
      sym_annotation,
    STATE(4541), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243132] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243178] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4543), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243224] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243270] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4545), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243316] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243362] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9094), 1,
      anon_sym_with,
    STATE(4747), 1,
      aux_sym_compound_type_repeat1,
    STATE(7702), 1,
      sym_template_body,
    STATE(7704), 1,
      sym__refinement,
    STATE(7884), 1,
      sym_arguments,
    STATE(4547), 2,
      sym_comment,
      sym_block_comment,
    STATE(7638), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [243420] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(4548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243468] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(4549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243516] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8727), 1,
      anon_sym_LBRACK,
    ACTIONS(8733), 1,
      anon_sym_POUND,
    ACTIONS(9096), 1,
      anon_sym_LPAREN,
    STATE(5004), 1,
      aux_sym_annotation_repeat1,
    STATE(5392), 1,
      sym_type_arguments,
    STATE(5913), 1,
      sym_arguments,
    STATE(4550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243574] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243620] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8402), 1,
      anon_sym_LPAREN,
    STATE(4553), 1,
      aux_sym_annotation_repeat1,
    STATE(5012), 1,
      sym_arguments,
    STATE(4552), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243672] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9100), 1,
      anon_sym_LPAREN,
    STATE(5012), 1,
      sym_arguments,
    STATE(4553), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243722] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9103), 1,
      anon_sym_LBRACK,
    ACTIONS(9105), 1,
      anon_sym_LPAREN,
    ACTIONS(9107), 1,
      anon_sym_POUND,
    STATE(5017), 1,
      aux_sym_annotation_repeat1,
    STATE(5409), 1,
      sym_type_arguments,
    STATE(5936), 1,
      sym_arguments,
    STATE(4554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243780] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243826] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8266), 1,
      anon_sym_LPAREN,
    STATE(4519), 1,
      aux_sym_annotation_repeat1,
    STATE(4823), 1,
      sym_arguments,
    STATE(4556), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243878] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9048), 1,
      anon_sym_COLON,
    ACTIONS(9050), 1,
      anon_sym_LBRACE,
    ACTIONS(9052), 1,
      anon_sym_with,
    STATE(4528), 1,
      aux_sym_compound_type_repeat1,
    STATE(8094), 1,
      sym_template_body,
    STATE(8117), 1,
      sym__refinement,
    STATE(4557), 2,
      sym_comment,
      sym_block_comment,
    STATE(8243), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243938] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9054), 1,
      anon_sym_COLON,
    ACTIONS(9056), 1,
      anon_sym_LBRACE,
    ACTIONS(9058), 1,
      anon_sym_with,
    STATE(4531), 1,
      aux_sym_compound_type_repeat1,
    STATE(8298), 1,
      sym_template_body,
    STATE(8301), 1,
      sym__refinement,
    STATE(4558), 2,
      sym_comment,
      sym_block_comment,
    STATE(8346), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [243998] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(936), 1,
      anon_sym_LBRACE,
    ACTIONS(8236), 1,
      anon_sym_LPAREN,
    ACTIONS(8989), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4559), 2,
      sym_comment,
      sym_block_comment,
    STATE(6647), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244056] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(7626), 1,
      sym_interpolated_string,
    STATE(14984), 1,
      sym__interpolated_string_start,
    STATE(14985), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4560), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [244114] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9048), 1,
      anon_sym_COLON,
    ACTIONS(9050), 1,
      anon_sym_LBRACE,
    ACTIONS(9052), 1,
      anon_sym_with,
    STATE(4528), 1,
      aux_sym_compound_type_repeat1,
    STATE(8094), 1,
      sym_template_body,
    STATE(8117), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4561), 2,
      sym_comment,
      sym_block_comment,
    STATE(8243), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [244180] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8084), 1,
      anon_sym_AT,
    STATE(4478), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4895), 1,
      sym_annotation,
    STATE(4562), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244232] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(936), 1,
      anon_sym_LBRACE,
    ACTIONS(8236), 1,
      anon_sym_LPAREN,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(8989), 1,
      anon_sym_DOT,
    ACTIONS(9109), 1,
      sym_operator_identifier,
    STATE(1667), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4563), 2,
      sym_comment,
      sym_block_comment,
    STATE(6647), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8807), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [244302] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9054), 1,
      anon_sym_COLON,
    ACTIONS(9056), 1,
      anon_sym_LBRACE,
    ACTIONS(9058), 1,
      anon_sym_with,
    STATE(4531), 1,
      aux_sym_compound_type_repeat1,
    STATE(8298), 1,
      sym_template_body,
    STATE(8301), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4564), 2,
      sym_comment,
      sym_block_comment,
    STATE(8346), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 7,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [244368] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(972), 1,
      anon_sym_LBRACE,
    ACTIONS(8374), 1,
      anon_sym_LPAREN,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9046), 1,
      anon_sym_DOT,
    ACTIONS(9111), 1,
      sym_operator_identifier,
    STATE(1710), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4565), 2,
      sym_comment,
      sym_block_comment,
    STATE(6202), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8807), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [244438] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9113), 1,
      anon_sym_AT,
    STATE(5293), 1,
      sym_annotation,
    STATE(4566), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244487] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9116), 1,
      anon_sym_COLON,
    ACTIONS(9118), 1,
      anon_sym_LBRACE,
    ACTIONS(9120), 1,
      anon_sym_with,
    STATE(6353), 1,
      aux_sym_compound_type_repeat1,
    STATE(9011), 1,
      sym_template_body,
    STATE(9019), 1,
      sym__refinement,
    STATE(4567), 2,
      sym_comment,
      sym_block_comment,
    STATE(8812), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [244546] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9122), 1,
      anon_sym_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(9126), 1,
      anon_sym_POUND,
    STATE(5236), 1,
      aux_sym_annotation_repeat1,
    STATE(5588), 1,
      sym_type_arguments,
    STATE(6204), 1,
      sym_arguments,
    STATE(4568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8154), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [244603] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8517), 1,
      anon_sym_LPAREN,
    STATE(4570), 1,
      aux_sym_annotation_repeat1,
    STATE(5113), 1,
      sym_arguments,
    STATE(4569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244654] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9128), 1,
      anon_sym_LPAREN,
    STATE(5113), 1,
      sym_arguments,
    STATE(4570), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244703] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1044), 1,
      anon_sym_LBRACE,
    ACTIONS(8731), 1,
      anon_sym_LPAREN,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9131), 1,
      anon_sym_DOT,
    ACTIONS(9133), 1,
      sym_operator_identifier,
    STATE(1676), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4571), 2,
      sym_comment,
      sym_block_comment,
    STATE(6706), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8807), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [244772] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4572), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244817] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244862] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9135), 1,
      anon_sym_DOT,
    STATE(4574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244909] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9137), 1,
      anon_sym_LBRACK,
    ACTIONS(9139), 1,
      anon_sym_LPAREN,
    ACTIONS(9141), 1,
      anon_sym_POUND,
    STATE(4355), 1,
      sym_type_arguments,
    STATE(4401), 1,
      sym_arguments,
    STATE(5551), 1,
      aux_sym_annotation_repeat1,
    STATE(4575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 24,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [244964] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8424), 1,
      anon_sym_AT,
    STATE(4584), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5053), 1,
      sym_annotation,
    STATE(4576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245015] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4577), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245060] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245105] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9143), 1,
      anon_sym_COLON,
    ACTIONS(9145), 1,
      anon_sym_LBRACE,
    ACTIONS(9147), 1,
      anon_sym_with,
    STATE(4612), 1,
      aux_sym_compound_type_repeat1,
    STATE(9281), 1,
      sym_template_body,
    STATE(9284), 1,
      sym__refinement,
    STATE(4579), 2,
      sym_comment,
      sym_block_comment,
    STATE(9029), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [245164] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4580), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [245209] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245254] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [245299] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8523), 1,
      anon_sym_LPAREN,
    STATE(4585), 1,
      aux_sym_annotation_repeat1,
    STATE(5138), 1,
      sym_arguments,
    STATE(4583), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245350] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9149), 1,
      anon_sym_AT,
    STATE(5053), 1,
      sym_annotation,
    STATE(4584), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245399] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9152), 1,
      anon_sym_LPAREN,
    STATE(5138), 1,
      sym_arguments,
    STATE(4585), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245448] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1044), 1,
      anon_sym_LBRACE,
    ACTIONS(8731), 1,
      anon_sym_LPAREN,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9131), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4586), 2,
      sym_comment,
      sym_block_comment,
    STATE(6706), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245507] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9155), 1,
      anon_sym_COLON,
    ACTIONS(9157), 1,
      anon_sym_LBRACE,
    ACTIONS(9159), 1,
      anon_sym_with,
    STATE(6465), 1,
      aux_sym_compound_type_repeat1,
    STATE(9074), 1,
      sym_template_body,
    STATE(9087), 1,
      sym__refinement,
    STATE(4587), 2,
      sym_comment,
      sym_block_comment,
    STATE(8911), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [245566] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4588), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245611] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9161), 1,
      anon_sym_AT,
    STATE(5367), 1,
      sym_annotation,
    STATE(4589), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245660] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8921), 1,
      anon_sym_LBRACK,
    ACTIONS(8925), 1,
      anon_sym_POUND,
    ACTIONS(9164), 1,
      anon_sym_AT,
    STATE(5052), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5125), 1,
      sym_type_arguments,
    STATE(6227), 1,
      sym_annotation,
    STATE(4590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [245717] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245762] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9143), 1,
      anon_sym_COLON,
    ACTIONS(9145), 1,
      anon_sym_LBRACE,
    ACTIONS(9147), 1,
      anon_sym_with,
    STATE(4612), 1,
      aux_sym_compound_type_repeat1,
    STATE(9281), 1,
      sym_template_body,
    STATE(9284), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4592), 2,
      sym_comment,
      sym_block_comment,
    STATE(9029), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [245827] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4593), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245872] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4594), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [245917] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245962] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246007] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [246052] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246097] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246142] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9166), 1,
      anon_sym_AT,
    STATE(5376), 1,
      sym_annotation,
    STATE(4600), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246191] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246236] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8234), 1,
      anon_sym_AT,
    STATE(4566), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5293), 1,
      sym_annotation,
    STATE(4602), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246287] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9076), 1,
      anon_sym_LBRACK,
    ACTIONS(9078), 1,
      anon_sym_AT,
    ACTIONS(9082), 1,
      anon_sym_POUND,
    STATE(5369), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5923), 1,
      sym_type_arguments,
    STATE(6410), 1,
      sym_annotation,
    STATE(4603), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [246344] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246389] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246434] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4606), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [246479] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9169), 1,
      anon_sym_with,
    STATE(4988), 1,
      aux_sym_compound_type_repeat1,
    STATE(8159), 1,
      sym_template_body,
    STATE(8160), 1,
      sym__refinement,
    STATE(8515), 1,
      sym_arguments,
    STATE(4607), 2,
      sym_comment,
      sym_block_comment,
    STATE(8355), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [246536] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [246581] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9171), 1,
      anon_sym_COLON,
    ACTIONS(9173), 1,
      anon_sym_LBRACE,
    ACTIONS(9175), 1,
      anon_sym_with,
    STATE(6493), 1,
      aux_sym_compound_type_repeat1,
    STATE(9178), 1,
      sym_template_body,
    STATE(9196), 1,
      sym__refinement,
    STATE(4609), 2,
      sym_comment,
      sym_block_comment,
    STATE(8791), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246640] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9177), 1,
      anon_sym_DOT,
    STATE(4610), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246687] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9179), 1,
      anon_sym_DOT,
    STATE(4611), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246734] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9143), 1,
      anon_sym_COLON,
    ACTIONS(9145), 1,
      anon_sym_LBRACE,
    ACTIONS(9147), 1,
      anon_sym_with,
    STATE(6132), 1,
      aux_sym_compound_type_repeat1,
    STATE(9281), 1,
      sym_template_body,
    STATE(9306), 1,
      sym__refinement,
    STATE(4612), 2,
      sym_comment,
      sym_block_comment,
    STATE(9029), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [246793] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8313), 1,
      sym_interpolated_string,
    STATE(15827), 1,
      sym__interpolated_string_start,
    STATE(15829), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4613), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [246850] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8457), 1,
      anon_sym_LPAREN,
    STATE(4616), 1,
      aux_sym_annotation_repeat1,
    STATE(5088), 1,
      sym_arguments,
    STATE(4614), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246901] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9181), 1,
      anon_sym_with,
    STATE(5003), 1,
      aux_sym_compound_type_repeat1,
    STATE(8151), 1,
      sym_arguments,
    STATE(8244), 1,
      sym_template_body,
    STATE(8245), 1,
      sym__refinement,
    STATE(4615), 2,
      sym_comment,
      sym_block_comment,
    STATE(8139), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [246958] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9183), 1,
      anon_sym_LPAREN,
    STATE(5088), 1,
      sym_arguments,
    STATE(4616), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247007] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9186), 1,
      anon_sym_LBRACK,
    ACTIONS(9188), 1,
      anon_sym_LPAREN,
    ACTIONS(9190), 1,
      anon_sym_POUND,
    STATE(5181), 1,
      aux_sym_annotation_repeat1,
    STATE(5946), 1,
      sym_type_arguments,
    STATE(6565), 1,
      sym_arguments,
    STATE(4617), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8154), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [247064] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4618), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247109] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9192), 1,
      anon_sym_LBRACK,
    ACTIONS(9194), 1,
      anon_sym_LPAREN,
    ACTIONS(9196), 1,
      anon_sym_POUND,
    STATE(5142), 1,
      aux_sym_annotation_repeat1,
    STATE(5799), 1,
      sym_type_arguments,
    STATE(6387), 1,
      sym_arguments,
    STATE(4619), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [247166] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247211] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4621), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247256] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9198), 1,
      anon_sym_COLON,
    ACTIONS(9200), 1,
      anon_sym_LBRACE,
    ACTIONS(9202), 1,
      anon_sym_with,
    STATE(4689), 1,
      aux_sym_compound_type_repeat1,
    STATE(8291), 1,
      sym_template_body,
    STATE(8296), 1,
      sym__refinement,
    STATE(4622), 2,
      sym_comment,
      sym_block_comment,
    STATE(8383), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247315] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(4623), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [247362] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9204), 1,
      anon_sym_LBRACK,
    ACTIONS(9206), 1,
      anon_sym_AT,
    ACTIONS(9208), 1,
      anon_sym_LPAREN,
    ACTIONS(9210), 1,
      anon_sym_POUND,
    STATE(5875), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6551), 1,
      sym_type_arguments,
    STATE(7256), 1,
      sym_annotation,
    STATE(8515), 1,
      sym_arguments,
    STATE(4624), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [247423] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247468] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247513] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8372), 1,
      anon_sym_AT,
    STATE(4589), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5367), 1,
      sym_annotation,
    STATE(4627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247564] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9198), 1,
      anon_sym_COLON,
    ACTIONS(9200), 1,
      anon_sym_LBRACE,
    ACTIONS(9202), 1,
      anon_sym_with,
    STATE(4689), 1,
      aux_sym_compound_type_repeat1,
    STATE(8291), 1,
      sym_template_body,
    STATE(8296), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4628), 2,
      sym_comment,
      sym_block_comment,
    STATE(8383), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_EQ,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [247629] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9035), 1,
      anon_sym_LBRACK,
    ACTIONS(9037), 1,
      anon_sym_AT,
    ACTIONS(9041), 1,
      anon_sym_POUND,
    STATE(5366), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5903), 1,
      sym_type_arguments,
    STATE(6590), 1,
      sym_annotation,
    STATE(4629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247686] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9212), 1,
      anon_sym_DOT,
    STATE(4630), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [247733] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8461), 1,
      anon_sym_LPAREN,
    STATE(4650), 1,
      aux_sym_annotation_repeat1,
    STATE(5149), 1,
      sym_arguments,
    STATE(4631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247784] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8996), 1,
      anon_sym_EQ_GT,
    STATE(4632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [247876] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [247921] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9214), 1,
      anon_sym_LBRACK,
    ACTIONS(9216), 1,
      anon_sym_AT,
    ACTIONS(9218), 1,
      anon_sym_LPAREN,
    ACTIONS(9220), 1,
      anon_sym_POUND,
    STATE(5897), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6592), 1,
      sym_type_arguments,
    STATE(7294), 1,
      sym_annotation,
    STATE(8151), 1,
      sym_arguments,
    STATE(4635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [247982] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8439), 1,
      anon_sym_LPAREN,
    STATE(4668), 1,
      aux_sym_annotation_repeat1,
    STATE(5419), 1,
      sym_arguments,
    STATE(4636), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248033] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9224), 1,
      anon_sym_COLON,
    ACTIONS(9227), 1,
      anon_sym_LBRACE,
    STATE(5690), 1,
      sym_template_body,
    STATE(4637), 2,
      sym_comment,
      sym_block_comment,
    STATE(5869), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 17,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248086] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1080), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(8847), 1,
      anon_sym_LPAREN,
    ACTIONS(9232), 1,
      anon_sym_DOT,
    ACTIONS(9234), 1,
      sym_operator_identifier,
    STATE(1777), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4638), 2,
      sym_comment,
      sym_block_comment,
    STATE(6886), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8807), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [248155] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9103), 1,
      anon_sym_LBRACK,
    ACTIONS(9107), 1,
      anon_sym_POUND,
    ACTIONS(9236), 1,
      anon_sym_AT,
    STATE(5379), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5409), 1,
      sym_type_arguments,
    STATE(6659), 1,
      sym_annotation,
    STATE(4639), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248212] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9076), 1,
      anon_sym_LBRACK,
    ACTIONS(9082), 1,
      anon_sym_POUND,
    ACTIONS(9238), 1,
      anon_sym_LPAREN,
    STATE(5105), 1,
      aux_sym_annotation_repeat1,
    STATE(5923), 1,
      sym_type_arguments,
    STATE(6187), 1,
      sym_arguments,
    STATE(4640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [248269] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1080), 1,
      anon_sym_LBRACE,
    ACTIONS(8847), 1,
      anon_sym_LPAREN,
    ACTIONS(9232), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4641), 2,
      sym_comment,
      sym_block_comment,
    STATE(6886), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248326] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9171), 1,
      anon_sym_COLON,
    ACTIONS(9173), 1,
      anon_sym_LBRACE,
    ACTIONS(9175), 1,
      anon_sym_with,
    STATE(4609), 1,
      aux_sym_compound_type_repeat1,
    STATE(9178), 1,
      sym_template_body,
    STATE(9179), 1,
      sym__refinement,
    STATE(4642), 2,
      sym_comment,
      sym_block_comment,
    STATE(8791), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248385] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1008), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(8855), 1,
      anon_sym_LPAREN,
    ACTIONS(9240), 1,
      anon_sym_DOT,
    ACTIONS(9242), 1,
      sym_operator_identifier,
    STATE(1784), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4643), 2,
      sym_comment,
      sym_block_comment,
    STATE(6919), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8807), 7,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [248454] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1080), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8847), 1,
      anon_sym_LPAREN,
    ACTIONS(9232), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4644), 2,
      sym_comment,
      sym_block_comment,
    STATE(6886), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248513] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1008), 1,
      anon_sym_LBRACE,
    ACTIONS(8855), 1,
      anon_sym_LPAREN,
    ACTIONS(9240), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4645), 2,
      sym_comment,
      sym_block_comment,
    STATE(6919), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [248570] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4646), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248615] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9244), 1,
      anon_sym_LBRACK,
    ACTIONS(9246), 1,
      anon_sym_LPAREN,
    ACTIONS(9248), 1,
      anon_sym_POUND,
    STATE(5186), 1,
      aux_sym_annotation_repeat1,
    STATE(5951), 1,
      sym_type_arguments,
    STATE(6143), 1,
      sym_arguments,
    STATE(4647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [248672] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4648), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248717] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8839), 1,
      anon_sym_LPAREN,
    STATE(4652), 1,
      aux_sym_annotation_repeat1,
    STATE(5327), 1,
      sym_arguments,
    STATE(4649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248768] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9250), 1,
      anon_sym_LPAREN,
    STATE(5149), 1,
      sym_arguments,
    STATE(4650), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248817] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1008), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8855), 1,
      anon_sym_LPAREN,
    ACTIONS(9240), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4651), 2,
      sym_comment,
      sym_block_comment,
    STATE(6919), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [248876] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9253), 1,
      anon_sym_LPAREN,
    STATE(5327), 1,
      sym_arguments,
    STATE(4652), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248970] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249015] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249060] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9256), 1,
      anon_sym_with,
    STATE(4857), 1,
      aux_sym_compound_type_repeat1,
    STATE(8218), 1,
      sym_arguments,
    STATE(8353), 1,
      sym_template_body,
    STATE(8354), 1,
      sym__refinement,
    STATE(4656), 2,
      sym_comment,
      sym_block_comment,
    STATE(8419), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [249117] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9035), 1,
      anon_sym_LBRACK,
    ACTIONS(9041), 1,
      anon_sym_POUND,
    ACTIONS(9258), 1,
      anon_sym_LPAREN,
    STATE(5203), 1,
      aux_sym_annotation_repeat1,
    STATE(5903), 1,
      sym_type_arguments,
    STATE(6638), 1,
      sym_arguments,
    STATE(4657), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249174] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(5730), 1,
      sym_interpolated_string,
    STATE(15429), 1,
      sym__interpolated_string_start,
    STATE(15431), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9260), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [249231] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4659), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249276] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4660), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249321] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4661), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249366] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4662), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249411] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4663), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249456] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8927), 1,
      anon_sym_DOT,
    ACTIONS(9262), 1,
      anon_sym_EQ_GT,
    STATE(4664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249505] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8442), 1,
      sym_interpolated_string,
    STATE(15634), 1,
      sym__interpolated_string_start,
    STATE(15635), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [249562] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9060), 1,
      anon_sym_LBRACK,
    ACTIONS(9066), 1,
      anon_sym_POUND,
    ACTIONS(9264), 1,
      anon_sym_LPAREN,
    STATE(5459), 1,
      aux_sym_annotation_repeat1,
    STATE(5839), 1,
      sym_type_arguments,
    STATE(6633), 1,
      sym_arguments,
    STATE(4666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [249619] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249664] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9266), 1,
      anon_sym_LPAREN,
    STATE(5419), 1,
      sym_arguments,
    STATE(4668), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249713] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6992), 1,
      sym_interpolated_string,
    STATE(14749), 1,
      sym__interpolated_string_start,
    STATE(14750), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9269), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4669), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [249770] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [249815] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249860] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249905] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8965), 1,
      anon_sym_with,
    STATE(6327), 1,
      aux_sym_compound_type_repeat1,
    STATE(7662), 1,
      sym_template_body,
    STATE(7743), 1,
      sym__refinement,
    STATE(4673), 2,
      sym_comment,
      sym_block_comment,
    STATE(7553), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249960] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250005] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4675), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250050] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8998), 1,
      anon_sym_LBRACK,
    ACTIONS(9002), 1,
      anon_sym_POUND,
    ACTIONS(9271), 1,
      anon_sym_AT,
    STATE(5069), 1,
      sym_type_arguments,
    STATE(5363), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6367), 1,
      sym_annotation,
    STATE(4676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250107] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8975), 1,
      anon_sym_LBRACK,
    ACTIONS(8979), 1,
      anon_sym_POUND,
    ACTIONS(9273), 1,
      anon_sym_AT,
    STATE(5150), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5284), 1,
      sym_type_arguments,
    STATE(6175), 1,
      sym_annotation,
    STATE(4677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250164] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4678), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250209] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8861), 1,
      anon_sym_AT,
    STATE(4600), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5376), 1,
      sym_annotation,
    STATE(4679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250260] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9275), 1,
      anon_sym_COLON,
    ACTIONS(9277), 1,
      anon_sym_LBRACE,
    ACTIONS(9279), 1,
      anon_sym_with,
    STATE(6379), 1,
      aux_sym_compound_type_repeat1,
    STATE(8745), 1,
      sym_template_body,
    STATE(8756), 1,
      sym__refinement,
    STATE(4680), 2,
      sym_comment,
      sym_block_comment,
    STATE(8777), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250319] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9014), 1,
      anon_sym_LBRACK,
    ACTIONS(9018), 1,
      anon_sym_POUND,
    ACTIONS(9281), 1,
      anon_sym_AT,
    STATE(5081), 1,
      sym_type_arguments,
    STATE(5380), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6471), 1,
      sym_annotation,
    STATE(4681), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [250376] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9060), 1,
      anon_sym_LBRACK,
    ACTIONS(9062), 1,
      anon_sym_AT,
    ACTIONS(9066), 1,
      anon_sym_POUND,
    STATE(5202), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5839), 1,
      sym_type_arguments,
    STATE(6164), 1,
      sym_annotation,
    STATE(4682), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [250433] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250478] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8987), 1,
      anon_sym_DOT,
    ACTIONS(9283), 1,
      anon_sym_EQ_GT,
    STATE(4684), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250527] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [250572] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9285), 1,
      anon_sym_COLON,
    ACTIONS(9287), 1,
      anon_sym_LBRACE,
    ACTIONS(9289), 1,
      anon_sym_with,
    STATE(4737), 1,
      aux_sym_compound_type_repeat1,
    STATE(8891), 1,
      sym_template_body,
    STATE(8892), 1,
      sym__refinement,
    STATE(4686), 2,
      sym_comment,
      sym_block_comment,
    STATE(8737), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250631] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250676] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250721] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9198), 1,
      anon_sym_COLON,
    ACTIONS(9200), 1,
      anon_sym_LBRACE,
    ACTIONS(9202), 1,
      anon_sym_with,
    STATE(6263), 1,
      aux_sym_compound_type_repeat1,
    STATE(8291), 1,
      sym_template_body,
    STATE(8333), 1,
      sym__refinement,
    STATE(4689), 2,
      sym_comment,
      sym_block_comment,
    STATE(8383), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250780] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8747), 1,
      anon_sym_AT,
    STATE(4703), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5384), 1,
      sym_annotation,
    STATE(4690), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4691), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250876] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250921] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4693), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250966] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9171), 1,
      anon_sym_COLON,
    ACTIONS(9173), 1,
      anon_sym_LBRACE,
    ACTIONS(9175), 1,
      anon_sym_with,
    STATE(4609), 1,
      aux_sym_compound_type_repeat1,
    STATE(9178), 1,
      sym_template_body,
    STATE(9179), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4694), 2,
      sym_comment,
      sym_block_comment,
    STATE(8791), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [251031] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9116), 1,
      anon_sym_COLON,
    ACTIONS(9118), 1,
      anon_sym_LBRACE,
    ACTIONS(9120), 1,
      anon_sym_with,
    STATE(4567), 1,
      aux_sym_compound_type_repeat1,
    STATE(9011), 1,
      sym_template_body,
    STATE(9012), 1,
      sym__refinement,
    STATE(4695), 2,
      sym_comment,
      sym_block_comment,
    STATE(8812), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [251090] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251135] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8142), 1,
      sym_interpolated_string,
    STATE(15471), 1,
      sym__interpolated_string_start,
    STATE(15472), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [251192] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9293), 1,
      anon_sym_LBRACK,
    ACTIONS(9295), 1,
      anon_sym_LPAREN,
    ACTIONS(9297), 1,
      anon_sym_POUND,
    STATE(5151), 1,
      aux_sym_annotation_repeat1,
    STATE(5896), 1,
      sym_type_arguments,
    STATE(6607), 1,
      sym_arguments,
    STATE(4698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [251249] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6520), 1,
      sym_interpolated_string,
    STATE(15099), 1,
      sym__interpolated_string_start,
    STATE(15101), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9299), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4699), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251306] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4700), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251351] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251396] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(4702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251443] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9301), 1,
      anon_sym_AT,
    STATE(5384), 1,
      sym_annotation,
    STATE(4703), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251492] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251537] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251582] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9304), 1,
      anon_sym_LBRACK,
    ACTIONS(9306), 1,
      anon_sym_LPAREN,
    ACTIONS(9308), 1,
      anon_sym_POUND,
    STATE(5255), 1,
      aux_sym_annotation_repeat1,
    STATE(5931), 1,
      sym_type_arguments,
    STATE(6336), 1,
      sym_arguments,
    STATE(4706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [251639] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(7626), 1,
      sym_interpolated_string,
    STATE(14984), 1,
      sym__interpolated_string_start,
    STATE(14985), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9310), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [251696] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6323), 1,
      sym_interpolated_string,
    STATE(15174), 1,
      sym__interpolated_string_start,
    STATE(15175), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9312), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4708), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251753] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8445), 1,
      anon_sym_LPAREN,
    STATE(4733), 1,
      aux_sym_annotation_repeat1,
    STATE(5432), 1,
      sym_arguments,
    STATE(4709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [251804] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9285), 1,
      anon_sym_COLON,
    ACTIONS(9287), 1,
      anon_sym_LBRACE,
    ACTIONS(9289), 1,
      anon_sym_with,
    STATE(4737), 1,
      aux_sym_compound_type_repeat1,
    STATE(8891), 1,
      sym_template_body,
    STATE(8892), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4710), 2,
      sym_comment,
      sym_block_comment,
    STATE(8737), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [251869] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(4711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251916] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9314), 1,
      anon_sym_LBRACK,
    ACTIONS(9316), 1,
      anon_sym_AT,
    ACTIONS(9318), 1,
      anon_sym_LPAREN,
    ACTIONS(9320), 1,
      anon_sym_POUND,
    STATE(5476), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6145), 1,
      sym_type_arguments,
    STATE(6676), 1,
      sym_annotation,
    STATE(8398), 1,
      sym_arguments,
    STATE(4712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [251977] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4713), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252022] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9116), 1,
      anon_sym_COLON,
    ACTIONS(9118), 1,
      anon_sym_LBRACE,
    ACTIONS(9120), 1,
      anon_sym_with,
    STATE(4567), 1,
      aux_sym_compound_type_repeat1,
    STATE(9011), 1,
      sym_template_body,
    STATE(9012), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4714), 2,
      sym_comment,
      sym_block_comment,
    STATE(8812), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [252087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252132] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252177] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252222] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252267] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4719), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252312] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(4720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252359] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4721), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252404] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252449] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252494] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9155), 1,
      anon_sym_COLON,
    ACTIONS(9157), 1,
      anon_sym_LBRACE,
    ACTIONS(9159), 1,
      anon_sym_with,
    STATE(4587), 1,
      aux_sym_compound_type_repeat1,
    STATE(9074), 1,
      sym_template_body,
    STATE(9076), 1,
      sym__refinement,
    STATE(4724), 2,
      sym_comment,
      sym_block_comment,
    STATE(8911), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [252553] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252598] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4726), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252643] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252688] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9155), 1,
      anon_sym_COLON,
    ACTIONS(9157), 1,
      anon_sym_LBRACE,
    ACTIONS(9159), 1,
      anon_sym_with,
    STATE(4587), 1,
      aux_sym_compound_type_repeat1,
    STATE(9074), 1,
      sym_template_body,
    STATE(9076), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4728), 2,
      sym_comment,
      sym_block_comment,
    STATE(8911), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [252753] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252798] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252843] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(4731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252890] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9322), 1,
      anon_sym_with,
    STATE(4768), 1,
      aux_sym_compound_type_repeat1,
    STATE(8093), 1,
      sym_template_body,
    STATE(8132), 1,
      sym__refinement,
    STATE(8398), 1,
      sym_arguments,
    STATE(4732), 2,
      sym_comment,
      sym_block_comment,
    STATE(8220), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [252947] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9324), 1,
      anon_sym_LPAREN,
    STATE(5432), 1,
      sym_arguments,
    STATE(4733), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [252996] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253041] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(7626), 1,
      sym_interpolated_string,
    STATE(14984), 1,
      sym__interpolated_string_start,
    STATE(14985), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9327), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4735), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [253098] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253143] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9285), 1,
      anon_sym_COLON,
    ACTIONS(9287), 1,
      anon_sym_LBRACE,
    ACTIONS(9289), 1,
      anon_sym_with,
    STATE(6254), 1,
      aux_sym_compound_type_repeat1,
    STATE(8891), 1,
      sym_template_body,
    STATE(8901), 1,
      sym__refinement,
    STATE(4737), 2,
      sym_comment,
      sym_block_comment,
    STATE(8737), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253202] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(4738), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253249] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9329), 1,
      anon_sym_LBRACK,
    ACTIONS(9331), 1,
      anon_sym_LPAREN,
    ACTIONS(9333), 1,
      anon_sym_POUND,
    STATE(5156), 1,
      aux_sym_annotation_repeat1,
    STATE(5961), 1,
      sym_type_arguments,
    STATE(6519), 1,
      sym_arguments,
    STATE(4739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [253306] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8119), 1,
      sym_interpolated_string,
    STATE(15252), 1,
      sym__interpolated_string_start,
    STATE(15253), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [253363] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253408] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4742), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253453] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9275), 1,
      anon_sym_COLON,
    ACTIONS(9277), 1,
      anon_sym_LBRACE,
    ACTIONS(9279), 1,
      anon_sym_with,
    STATE(4680), 1,
      aux_sym_compound_type_repeat1,
    STATE(8745), 1,
      sym_template_body,
    STATE(8746), 1,
      sym__refinement,
    STATE(4743), 2,
      sym_comment,
      sym_block_comment,
    STATE(8777), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253512] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9029), 1,
      anon_sym_LBRACK,
    ACTIONS(9033), 1,
      anon_sym_POUND,
    ACTIONS(9335), 1,
      anon_sym_AT,
    STATE(5098), 1,
      sym_type_arguments,
    STATE(5416), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6574), 1,
      sym_annotation,
    STATE(4744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [253569] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4745), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253614] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9275), 1,
      anon_sym_COLON,
    ACTIONS(9277), 1,
      anon_sym_LBRACE,
    ACTIONS(9279), 1,
      anon_sym_with,
    STATE(4680), 1,
      aux_sym_compound_type_repeat1,
    STATE(8745), 1,
      sym_template_body,
    STATE(8746), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4746), 2,
      sym_comment,
      sym_block_comment,
    STATE(8777), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [253679] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9094), 1,
      anon_sym_with,
    STATE(6284), 1,
      aux_sym_compound_type_repeat1,
    STATE(7702), 1,
      sym_template_body,
    STATE(7718), 1,
      sym__refinement,
    STATE(4747), 2,
      sym_comment,
      sym_block_comment,
    STATE(7638), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [253734] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9337), 1,
      anon_sym_LBRACK,
    ACTIONS(9339), 1,
      anon_sym_AT,
    ACTIONS(9341), 1,
      anon_sym_LPAREN,
    ACTIONS(9343), 1,
      anon_sym_POUND,
    STATE(5710), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6118), 1,
      sym_type_arguments,
    STATE(6961), 1,
      sym_annotation,
    STATE(8218), 1,
      sym_arguments,
    STATE(4748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [253795] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6520), 1,
      sym_interpolated_string,
    STATE(15099), 1,
      sym__interpolated_string_start,
    STATE(15101), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9345), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4749), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [253852] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9347), 1,
      anon_sym_DOT,
    STATE(4750), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253899] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253944] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6323), 1,
      sym_interpolated_string,
    STATE(15174), 1,
      sym__interpolated_string_start,
    STATE(15175), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9349), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [254001] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9008), 1,
      anon_sym_LBRACK,
    ACTIONS(9012), 1,
      anon_sym_POUND,
    ACTIONS(9351), 1,
      anon_sym_AT,
    STATE(5279), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5303), 1,
      sym_type_arguments,
    STATE(6621), 1,
      sym_annotation,
    STATE(4753), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254058] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9070), 1,
      anon_sym_with,
    STATE(6529), 1,
      aux_sym_compound_type_repeat1,
    STATE(7525), 1,
      sym__refinement,
    STATE(8003), 1,
      sym_template_body,
    STATE(4754), 2,
      sym_comment,
      sym_block_comment,
    STATE(7459), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [254113] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1044), 1,
      anon_sym_LBRACE,
    ACTIONS(8731), 1,
      anon_sym_LPAREN,
    ACTIONS(9131), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4755), 2,
      sym_comment,
      sym_block_comment,
    STATE(6706), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254170] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4756), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254215] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9353), 1,
      anon_sym_DOT,
    STATE(4757), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254262] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9355), 1,
      anon_sym_COLON,
    ACTIONS(9358), 1,
      anon_sym_LBRACE,
    STATE(6642), 1,
      sym_template_body,
    STATE(4758), 2,
      sym_comment,
      sym_block_comment,
    STATE(6463), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 16,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254314] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(892), 1,
      anon_sym_LBRACE,
    ACTIONS(8086), 1,
      anon_sym_LPAREN,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8809), 1,
      anon_sym_DOT,
    ACTIONS(9361), 1,
      sym__alpha_identifier,
    ACTIONS(9369), 1,
      anon_sym_EQ,
    ACTIONS(9371), 1,
      sym__backquoted_id,
    ACTIONS(9373), 1,
      sym_operator_identifier,
    STATE(529), 1,
      sym_identifier,
    STATE(3852), 1,
      sym__soft_identifier,
    STATE(4759), 2,
      sym_comment,
      sym_block_comment,
    STATE(5686), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9367), 5,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9365), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [254382] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254426] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6969), 1,
      sym_interpolated_string,
    STATE(15593), 1,
      sym__interpolated_string_start,
    STATE(15595), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9375), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4761), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [254482] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254526] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8845), 1,
      anon_sym_AT,
    STATE(4885), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5561), 1,
      sym_annotation,
    STATE(4763), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254576] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [254620] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4765), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254664] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4766), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254708] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4767), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254752] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9322), 1,
      anon_sym_with,
    STATE(7338), 1,
      aux_sym_compound_type_repeat1,
    STATE(8093), 1,
      sym_template_body,
    STATE(8429), 1,
      sym__refinement,
    STATE(4768), 2,
      sym_comment,
      sym_block_comment,
    STATE(8220), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [254806] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254850] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254894] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(4771), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [254940] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8853), 1,
      anon_sym_AT,
    STATE(5023), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5540), 1,
      sym_annotation,
    STATE(4772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [254990] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4773), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255034] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255078] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255122] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9377), 1,
      anon_sym_COLON,
    ACTIONS(9379), 1,
      anon_sym_LBRACE,
    ACTIONS(9381), 1,
      anon_sym_with,
    STATE(7375), 1,
      aux_sym_compound_type_repeat1,
    STATE(9579), 1,
      sym_template_body,
    STATE(9608), 1,
      sym__refinement,
    STATE(4776), 2,
      sym_comment,
      sym_block_comment,
    STATE(9469), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [255180] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9000), 1,
      anon_sym_LPAREN,
    STATE(4778), 1,
      aux_sym_annotation_repeat1,
    STATE(5578), 1,
      sym_arguments,
    STATE(4777), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255230] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9383), 1,
      anon_sym_LPAREN,
    STATE(5578), 1,
      sym_arguments,
    STATE(4778), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255278] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255322] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255366] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255410] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9283), 1,
      anon_sym_EQ_GT,
    STATE(4782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255456] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255500] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255544] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [255588] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9179), 1,
      anon_sym_DOT,
    ACTIONS(9386), 1,
      anon_sym_EQ_GT,
    STATE(4786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255636] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [255680] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4788), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [255724] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255768] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255812] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9016), 1,
      anon_sym_LPAREN,
    STATE(4795), 1,
      aux_sym_annotation_repeat1,
    STATE(5625), 1,
      sym_arguments,
    STATE(4791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [255862] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255906] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(4793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [255952] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255996] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9388), 1,
      anon_sym_LPAREN,
    STATE(5625), 1,
      sym_arguments,
    STATE(4795), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [256044] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256088] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(107), 1,
      anon_sym_LBRACE,
    ACTIONS(9039), 1,
      anon_sym_LPAREN,
    ACTIONS(9391), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4797), 2,
      sym_comment,
      sym_block_comment,
    STATE(7569), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256144] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4798), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256188] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [256232] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8955), 1,
      anon_sym_LPAREN,
    STATE(4845), 1,
      aux_sym_annotation_repeat1,
    STATE(5664), 1,
      sym_arguments,
    STATE(4800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256282] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [256326] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256370] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4803), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256414] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9393), 1,
      anon_sym_COLON,
    ACTIONS(9395), 1,
      anon_sym_LBRACE,
    ACTIONS(9397), 1,
      anon_sym_with,
    STATE(6743), 1,
      aux_sym_compound_type_repeat1,
    STATE(9619), 1,
      sym_template_body,
    STATE(9638), 1,
      sym__refinement,
    STATE(4804), 2,
      sym_comment,
      sym_block_comment,
    STATE(9556), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [256472] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256516] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9031), 1,
      anon_sym_LPAREN,
    STATE(4812), 1,
      aux_sym_annotation_repeat1,
    STATE(5661), 1,
      sym_arguments,
    STATE(4806), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [256566] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4807), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256610] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256654] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4809), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [256698] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9399), 1,
      anon_sym_DOT,
    STATE(4810), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256744] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256788] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9401), 1,
      anon_sym_LPAREN,
    STATE(5661), 1,
      sym_arguments,
    STATE(4812), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [256836] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256880] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4814), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256924] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4815), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256968] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9404), 1,
      anon_sym_COLON,
    ACTIONS(9406), 1,
      anon_sym_LBRACE,
    ACTIONS(9408), 1,
      anon_sym_with,
    STATE(6755), 1,
      aux_sym_compound_type_repeat1,
    STATE(9550), 1,
      sym__refinement,
    STATE(9699), 1,
      sym_template_body,
    STATE(4816), 2,
      sym_comment,
      sym_block_comment,
    STATE(9574), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [257026] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9410), 1,
      anon_sym_LBRACK,
    ACTIONS(9412), 1,
      anon_sym_LPAREN,
    ACTIONS(9414), 1,
      anon_sym_POUND,
    STATE(5717), 1,
      aux_sym_annotation_repeat1,
    STATE(6341), 1,
      sym_type_arguments,
    STATE(6946), 1,
      sym_arguments,
    STATE(4817), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [257082] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4818), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257126] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257170] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257214] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257258] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4822), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257302] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4823), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257346] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257390] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257434] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9420), 1,
      anon_sym_with,
    STATE(4826), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257480] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4827), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257524] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4828), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257568] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257612] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [257656] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9423), 1,
      anon_sym_LBRACK,
    ACTIONS(9425), 1,
      anon_sym_LPAREN,
    ACTIONS(9427), 1,
      anon_sym_POUND,
    STATE(6038), 1,
      aux_sym_annotation_repeat1,
    STATE(6315), 1,
      sym_type_arguments,
    STATE(7980), 1,
      sym_arguments,
    STATE(4831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [257712] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257756] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(4833), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [257802] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4834), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257846] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [257890] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [257934] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9429), 1,
      anon_sym_with,
    STATE(5442), 1,
      aux_sym_compound_type_repeat1,
    STATE(9192), 1,
      sym_template_body,
    STATE(9193), 1,
      sym__refinement,
    STATE(9315), 1,
      sym_arguments,
    STATE(4837), 2,
      sym_comment,
      sym_block_comment,
    STATE(5352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [257990] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8923), 1,
      anon_sym_LPAREN,
    STATE(4839), 1,
      aux_sym_annotation_repeat1,
    STATE(5836), 1,
      sym_arguments,
    STATE(4838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [258040] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9431), 1,
      anon_sym_LPAREN,
    STATE(5836), 1,
      sym_arguments,
    STATE(4839), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [258088] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9314), 1,
      anon_sym_LBRACK,
    ACTIONS(9320), 1,
      anon_sym_POUND,
    ACTIONS(9434), 1,
      anon_sym_LPAREN,
    STATE(5846), 1,
      aux_sym_annotation_repeat1,
    STATE(6145), 1,
      sym_type_arguments,
    STATE(7038), 1,
      sym_arguments,
    STATE(4840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [258144] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258188] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4842), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258232] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258276] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(107), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9039), 1,
      anon_sym_LPAREN,
    ACTIONS(9391), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4844), 2,
      sym_comment,
      sym_block_comment,
    STATE(7569), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258334] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9436), 1,
      anon_sym_LPAREN,
    STATE(5664), 1,
      sym_arguments,
    STATE(4845), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258382] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9439), 1,
      anon_sym_DOT,
    STATE(4846), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [258428] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4847), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258472] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8142), 1,
      sym_interpolated_string,
    STATE(15471), 1,
      sym__interpolated_string_start,
    STATE(15472), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9441), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [258528] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4849), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [258572] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9204), 1,
      anon_sym_LBRACK,
    ACTIONS(9206), 1,
      anon_sym_AT,
    ACTIONS(9210), 1,
      anon_sym_POUND,
    STATE(5875), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6551), 1,
      sym_type_arguments,
    STATE(7256), 1,
      sym_annotation,
    STATE(4850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [258628] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258672] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258716] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4853), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258760] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4854), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258806] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4855), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258850] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4856), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258894] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9256), 1,
      anon_sym_with,
    STATE(6865), 1,
      aux_sym_compound_type_repeat1,
    STATE(8353), 1,
      sym_template_body,
    STATE(8400), 1,
      sym__refinement,
    STATE(4857), 2,
      sym_comment,
      sym_block_comment,
    STATE(8419), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [258948] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4858), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258992] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9177), 1,
      anon_sym_DOT,
    ACTIONS(9449), 1,
      anon_sym_EQ_GT,
    STATE(4859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259040] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9451), 1,
      anon_sym_LBRACK,
    ACTIONS(9453), 1,
      anon_sym_AT,
    ACTIONS(9455), 1,
      anon_sym_LPAREN,
    ACTIONS(9457), 1,
      anon_sym_POUND,
    STATE(6530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7362), 1,
      sym_type_arguments,
    STATE(7990), 1,
      sym_annotation,
    STATE(9315), 1,
      sym_arguments,
    STATE(4860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [259100] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259144] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259188] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [259232] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4864), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259276] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9212), 1,
      anon_sym_DOT,
    ACTIONS(9459), 1,
      anon_sym_EQ_GT,
    STATE(4865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [259324] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(4866), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259370] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(9312), 1,
      sym_interpolated_string,
    STATE(15540), 1,
      sym__interpolated_string_start,
    STATE(15578), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9461), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [259426] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259470] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4869), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259514] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9463), 1,
      anon_sym_DOT,
    STATE(4870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [259560] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4871), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [259604] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [259648] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4873), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259692] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259736] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(4875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259782] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9465), 1,
      anon_sym_LBRACK,
    ACTIONS(9467), 1,
      anon_sym_LPAREN,
    ACTIONS(9469), 1,
      anon_sym_POUND,
    STATE(5777), 1,
      aux_sym_annotation_repeat1,
    STATE(6626), 1,
      sym_type_arguments,
    STATE(6949), 1,
      sym_arguments,
    STATE(4876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [259838] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9471), 1,
      anon_sym_COLON,
    ACTIONS(9473), 1,
      anon_sym_LBRACE,
    ACTIONS(9475), 1,
      anon_sym_with,
    STATE(6839), 1,
      aux_sym_compound_type_repeat1,
    STATE(9401), 1,
      sym_template_body,
    STATE(9636), 1,
      sym__refinement,
    STATE(4877), 2,
      sym_comment,
      sym_block_comment,
    STATE(9414), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [259896] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9010), 1,
      anon_sym_LPAREN,
    STATE(4879), 1,
      aux_sym_annotation_repeat1,
    STATE(5732), 1,
      sym_arguments,
    STATE(4878), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259946] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9477), 1,
      anon_sym_LPAREN,
    STATE(5732), 1,
      sym_arguments,
    STATE(4879), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259994] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(4880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260040] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1116), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9064), 1,
      anon_sym_LPAREN,
    ACTIONS(9480), 1,
      anon_sym_DOT,
    ACTIONS(9482), 1,
      sym_operator_identifier,
    STATE(1662), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4881), 2,
      sym_comment,
      sym_block_comment,
    STATE(7491), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8807), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [260108] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260152] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8119), 1,
      sym_interpolated_string,
    STATE(15252), 1,
      sym__interpolated_string_start,
    STATE(15253), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9484), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4883), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [260208] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1116), 1,
      anon_sym_LBRACE,
    ACTIONS(9064), 1,
      anon_sym_LPAREN,
    ACTIONS(9480), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4884), 2,
      sym_comment,
      sym_block_comment,
    STATE(7491), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [260264] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9486), 1,
      anon_sym_AT,
    STATE(5561), 1,
      sym_annotation,
    STATE(4885), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260312] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9489), 1,
      anon_sym_LBRACK,
    ACTIONS(9491), 1,
      anon_sym_LPAREN,
    ACTIONS(9493), 1,
      anon_sym_POUND,
    STATE(5763), 1,
      aux_sym_annotation_repeat1,
    STATE(6066), 1,
      sym_type_arguments,
    STATE(6996), 1,
      sym_arguments,
    STATE(4886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8154), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [260368] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9186), 1,
      anon_sym_LBRACK,
    ACTIONS(9190), 1,
      anon_sym_POUND,
    ACTIONS(9495), 1,
      anon_sym_AT,
    STATE(5888), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5946), 1,
      sym_type_arguments,
    STATE(7276), 1,
      sym_annotation,
    STATE(4887), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [260424] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1116), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9064), 1,
      anon_sym_LPAREN,
    ACTIONS(9480), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4888), 2,
      sym_comment,
      sym_block_comment,
    STATE(7491), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [260482] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9497), 1,
      anon_sym_COLON,
    ACTIONS(9499), 1,
      anon_sym_LBRACE,
    ACTIONS(9501), 1,
      anon_sym_with,
    STATE(4994), 1,
      aux_sym_compound_type_repeat1,
    STATE(9576), 1,
      sym_template_body,
    STATE(9577), 1,
      sym__refinement,
    STATE(4889), 2,
      sym_comment,
      sym_block_comment,
    STATE(9716), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8406), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [260540] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260584] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4891), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [260628] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9503), 1,
      anon_sym_LBRACK,
    ACTIONS(9505), 1,
      anon_sym_LPAREN,
    ACTIONS(9507), 1,
      anon_sym_POUND,
    STATE(5477), 1,
      aux_sym_annotation_repeat1,
    STATE(6076), 1,
      sym_type_arguments,
    STATE(7124), 1,
      sym_arguments,
    STATE(4892), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [260684] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9509), 1,
      anon_sym_DOT,
    STATE(4893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260730] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9511), 1,
      anon_sym_LBRACK,
    ACTIONS(9513), 1,
      anon_sym_AT,
    ACTIONS(9515), 1,
      anon_sym_LPAREN,
    ACTIONS(9517), 1,
      anon_sym_POUND,
    STATE(6376), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7266), 1,
      sym_type_arguments,
    STATE(7448), 1,
      sym_annotation,
    STATE(9006), 1,
      sym_arguments,
    STATE(4894), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [260790] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260834] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9523), 1,
      anon_sym_with,
    STATE(5315), 1,
      aux_sym_compound_type_repeat1,
    STATE(9006), 1,
      sym_arguments,
    STATE(9261), 1,
      sym_template_body,
    STATE(9267), 1,
      sym__refinement,
    STATE(4896), 2,
      sym_comment,
      sym_block_comment,
    STATE(9294), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [260890] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9337), 1,
      anon_sym_LBRACK,
    ACTIONS(9343), 1,
      anon_sym_POUND,
    ACTIONS(9525), 1,
      anon_sym_LPAREN,
    STATE(5781), 1,
      aux_sym_annotation_repeat1,
    STATE(6118), 1,
      sym_type_arguments,
    STATE(7039), 1,
      sym_arguments,
    STATE(4897), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8154), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [260946] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9377), 1,
      anon_sym_COLON,
    ACTIONS(9379), 1,
      anon_sym_LBRACE,
    ACTIONS(9381), 1,
      anon_sym_with,
    STATE(4776), 1,
      aux_sym_compound_type_repeat1,
    STATE(9579), 1,
      sym_template_body,
    STATE(9586), 1,
      sym__refinement,
    STATE(4898), 2,
      sym_comment,
      sym_block_comment,
    STATE(9469), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [261004] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9497), 1,
      anon_sym_COLON,
    ACTIONS(9499), 1,
      anon_sym_LBRACE,
    ACTIONS(9501), 1,
      anon_sym_with,
    STATE(4994), 1,
      aux_sym_compound_type_repeat1,
    STATE(9576), 1,
      sym_template_body,
    STATE(9577), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4899), 2,
      sym_comment,
      sym_block_comment,
    STATE(9716), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8412), 6,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [261068] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9527), 1,
      anon_sym_DOT,
    STATE(4900), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261114] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9262), 1,
      anon_sym_EQ_GT,
    STATE(4901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261160] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4902), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261204] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261248] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261292] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4905), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261336] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261380] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9529), 1,
      anon_sym_COLON,
    ACTIONS(9532), 1,
      anon_sym_LBRACE,
    STATE(6208), 1,
      sym_template_body,
    STATE(4907), 2,
      sym_comment,
      sym_block_comment,
    STATE(6014), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 16,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261432] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1282), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9080), 1,
      anon_sym_LPAREN,
    ACTIONS(9535), 1,
      anon_sym_DOT,
    ACTIONS(9537), 1,
      sym_operator_identifier,
    STATE(1722), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4908), 2,
      sym_comment,
      sym_block_comment,
    STATE(7666), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8807), 6,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [261500] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8961), 1,
      anon_sym_LPAREN,
    STATE(4910), 1,
      aux_sym_annotation_repeat1,
    STATE(5933), 1,
      sym_arguments,
    STATE(4909), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [261550] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9539), 1,
      anon_sym_LPAREN,
    STATE(5933), 1,
      sym_arguments,
    STATE(4910), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [261598] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8977), 1,
      anon_sym_LPAREN,
    STATE(4912), 1,
      aux_sym_annotation_repeat1,
    STATE(5860), 1,
      sym_arguments,
    STATE(4911), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261648] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9542), 1,
      anon_sym_LPAREN,
    STATE(5860), 1,
      sym_arguments,
    STATE(4912), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261696] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9545), 1,
      anon_sym_LBRACK,
    ACTIONS(9547), 1,
      anon_sym_AT,
    ACTIONS(9549), 1,
      anon_sym_LPAREN,
    ACTIONS(9551), 1,
      anon_sym_POUND,
    STATE(5996), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6916), 1,
      sym_type_arguments,
    STATE(7862), 1,
      sym_annotation,
    STATE(9051), 1,
      sym_arguments,
    STATE(4913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [261756] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1282), 1,
      anon_sym_LBRACE,
    ACTIONS(9080), 1,
      anon_sym_LPAREN,
    ACTIONS(9535), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4914), 2,
      sym_comment,
      sym_block_comment,
    STATE(7666), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [261812] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9553), 1,
      anon_sym_with,
    STATE(5058), 1,
      aux_sym_compound_type_repeat1,
    STATE(8762), 1,
      sym_template_body,
    STATE(8764), 1,
      sym__refinement,
    STATE(9051), 1,
      sym_arguments,
    STATE(4915), 2,
      sym_comment,
      sym_block_comment,
    STATE(9215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [261868] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261912] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261956] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6789), 1,
      sym_interpolated_string,
    STATE(15449), 1,
      sym__interpolated_string_start,
    STATE(15451), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9555), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [262012] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262056] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262100] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1282), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9080), 1,
      anon_sym_LPAREN,
    ACTIONS(9535), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(4921), 2,
      sym_comment,
      sym_block_comment,
    STATE(7666), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [262158] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4922), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [262202] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9084), 1,
      anon_sym_AT,
    STATE(5037), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5635), 1,
      sym_annotation,
    STATE(4923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262252] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262296] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262340] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262384] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9377), 1,
      anon_sym_COLON,
    ACTIONS(9379), 1,
      anon_sym_LBRACE,
    ACTIONS(9381), 1,
      anon_sym_with,
    STATE(4776), 1,
      aux_sym_compound_type_repeat1,
    STATE(9579), 1,
      sym_template_body,
    STATE(9586), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4927), 2,
      sym_comment,
      sym_block_comment,
    STATE(9469), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [262448] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4928), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262492] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8929), 1,
      anon_sym_AT,
    STATE(4962), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5541), 1,
      sym_annotation,
    STATE(4929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262542] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262586] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262630] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262674] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262718] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9557), 1,
      anon_sym_DOT,
    STATE(4934), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262764] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4935), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262808] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262852] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4937), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262896] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4938), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [262940] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [262984] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4940), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [263028] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4941), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [263072] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9559), 1,
      anon_sym_LBRACK,
    ACTIONS(9561), 1,
      anon_sym_AT,
    ACTIONS(9563), 1,
      anon_sym_LPAREN,
    ACTIONS(9565), 1,
      anon_sym_POUND,
    STATE(6102), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7125), 1,
      sym_type_arguments,
    STATE(7691), 1,
      sym_annotation,
    STATE(9105), 1,
      sym_arguments,
    STATE(4942), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [263132] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9567), 1,
      anon_sym_DOT,
    STATE(4943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263178] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263222] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263266] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4946), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [263310] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9471), 1,
      anon_sym_COLON,
    ACTIONS(9473), 1,
      anon_sym_LBRACE,
    ACTIONS(9475), 1,
      anon_sym_with,
    STATE(4877), 1,
      aux_sym_compound_type_repeat1,
    STATE(9401), 1,
      sym_template_body,
    STATE(9404), 1,
      sym__refinement,
    STATE(4947), 2,
      sym_comment,
      sym_block_comment,
    STATE(9414), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [263368] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [263412] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9569), 1,
      anon_sym_with,
    STATE(5324), 1,
      aux_sym_compound_type_repeat1,
    STATE(9103), 1,
      sym_template_body,
    STATE(9104), 1,
      sym__refinement,
    STATE(9105), 1,
      sym_arguments,
    STATE(4949), 2,
      sym_comment,
      sym_block_comment,
    STATE(8768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [263468] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9571), 1,
      anon_sym_AT,
    STATE(5840), 1,
      sym_annotation,
    STATE(4950), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263516] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8938), 1,
      anon_sym_AT,
    STATE(4971), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5544), 1,
      sym_annotation,
    STATE(4951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [263566] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263610] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9574), 1,
      anon_sym_LBRACK,
    ACTIONS(9576), 1,
      anon_sym_LPAREN,
    ACTIONS(9578), 1,
      anon_sym_POUND,
    STATE(5937), 1,
      aux_sym_annotation_repeat1,
    STATE(6156), 1,
      sym_type_arguments,
    STATE(7206), 1,
      sym_arguments,
    STATE(4953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [263666] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(9312), 1,
      sym_interpolated_string,
    STATE(15540), 1,
      sym__interpolated_string_start,
    STATE(15578), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [263722] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9192), 1,
      anon_sym_LBRACK,
    ACTIONS(9196), 1,
      anon_sym_POUND,
    ACTIONS(9580), 1,
      anon_sym_AT,
    STATE(5573), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5799), 1,
      sym_type_arguments,
    STATE(6700), 1,
      sym_annotation,
    STATE(4955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [263778] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263822] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9393), 1,
      anon_sym_COLON,
    ACTIONS(9395), 1,
      anon_sym_LBRACE,
    ACTIONS(9397), 1,
      anon_sym_with,
    STATE(4804), 1,
      aux_sym_compound_type_repeat1,
    STATE(9619), 1,
      sym_template_body,
    STATE(9620), 1,
      sym__refinement,
    STATE(4957), 2,
      sym_comment,
      sym_block_comment,
    STATE(9556), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [263880] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9471), 1,
      anon_sym_COLON,
    ACTIONS(9473), 1,
      anon_sym_LBRACE,
    ACTIONS(9475), 1,
      anon_sym_with,
    STATE(4877), 1,
      aux_sym_compound_type_repeat1,
    STATE(9401), 1,
      sym_template_body,
    STATE(9404), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4958), 2,
      sym_comment,
      sym_block_comment,
    STATE(9414), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [263944] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9582), 1,
      anon_sym_DOT,
    STATE(4959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [263990] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9584), 1,
      anon_sym_LBRACK,
    ACTIONS(9586), 1,
      anon_sym_LPAREN,
    ACTIONS(9588), 1,
      anon_sym_POUND,
    STATE(5958), 1,
      aux_sym_annotation_repeat1,
    STATE(6272), 1,
      sym_type_arguments,
    STATE(7222), 1,
      sym_arguments,
    STATE(4960), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8154), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [264046] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9590), 1,
      anon_sym_COLON,
    ACTIONS(9592), 1,
      anon_sym_LBRACE,
    ACTIONS(9594), 1,
      anon_sym_with,
    STATE(5036), 1,
      aux_sym_compound_type_repeat1,
    STATE(9380), 1,
      sym_template_body,
    STATE(9393), 1,
      sym__refinement,
    STATE(4961), 2,
      sym_comment,
      sym_block_comment,
    STATE(9599), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [264104] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9596), 1,
      anon_sym_AT,
    STATE(5541), 1,
      sym_annotation,
    STATE(4962), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [264152] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9214), 1,
      anon_sym_LBRACK,
    ACTIONS(9220), 1,
      anon_sym_POUND,
    ACTIONS(9599), 1,
      anon_sym_LPAREN,
    STATE(5722), 1,
      aux_sym_annotation_repeat1,
    STATE(6592), 1,
      sym_type_arguments,
    STATE(6826), 1,
      sym_arguments,
    STATE(4963), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [264208] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4964), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [264252] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4965), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [264296] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9404), 1,
      anon_sym_COLON,
    ACTIONS(9406), 1,
      anon_sym_LBRACE,
    ACTIONS(9408), 1,
      anon_sym_with,
    STATE(4816), 1,
      aux_sym_compound_type_repeat1,
    STATE(9699), 1,
      sym_template_body,
    STATE(9705), 1,
      sym__refinement,
    STATE(4966), 2,
      sym_comment,
      sym_block_comment,
    STATE(9574), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [264354] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4967), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [264400] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [264444] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [264488] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9601), 1,
      anon_sym_LBRACK,
    ACTIONS(9603), 1,
      anon_sym_LPAREN,
    ACTIONS(9605), 1,
      anon_sym_POUND,
    STATE(5555), 1,
      aux_sym_annotation_repeat1,
    STATE(6542), 1,
      sym_type_arguments,
    STATE(7346), 1,
      sym_arguments,
    STATE(4970), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8154), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [264544] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9607), 1,
      anon_sym_AT,
    STATE(5544), 1,
      sym_annotation,
    STATE(4971), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [264592] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9590), 1,
      anon_sym_COLON,
    ACTIONS(9592), 1,
      anon_sym_LBRACE,
    ACTIONS(9594), 1,
      anon_sym_with,
    STATE(5036), 1,
      aux_sym_compound_type_repeat1,
    STATE(9380), 1,
      sym_template_body,
    STATE(9393), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4972), 2,
      sym_comment,
      sym_block_comment,
    STATE(9599), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [264656] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9610), 1,
      anon_sym_LBRACK,
    ACTIONS(9612), 1,
      anon_sym_LPAREN,
    ACTIONS(9614), 1,
      anon_sym_POUND,
    STATE(5614), 1,
      aux_sym_annotation_repeat1,
    STATE(6392), 1,
      sym_type_arguments,
    STATE(7299), 1,
      sym_arguments,
    STATE(4973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [264712] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [264756] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [264800] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9393), 1,
      anon_sym_COLON,
    ACTIONS(9395), 1,
      anon_sym_LBRACE,
    ACTIONS(9397), 1,
      anon_sym_with,
    STATE(4804), 1,
      aux_sym_compound_type_repeat1,
    STATE(9619), 1,
      sym_template_body,
    STATE(9620), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4976), 2,
      sym_comment,
      sym_block_comment,
    STATE(9556), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [264864] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [264908] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4978), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [264952] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4979), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [264996] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4980), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265040] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265084] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4982), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265128] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265172] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9244), 1,
      anon_sym_LBRACK,
    ACTIONS(9248), 1,
      anon_sym_POUND,
    ACTIONS(9616), 1,
      anon_sym_AT,
    STATE(5577), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5951), 1,
      sym_type_arguments,
    STATE(7288), 1,
      sym_annotation,
    STATE(4984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [265228] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265272] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265316] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9337), 1,
      anon_sym_LBRACK,
    ACTIONS(9339), 1,
      anon_sym_AT,
    ACTIONS(9343), 1,
      anon_sym_POUND,
    STATE(5710), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6118), 1,
      sym_type_arguments,
    STATE(6961), 1,
      sym_annotation,
    STATE(4987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [265372] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9169), 1,
      anon_sym_with,
    STATE(7184), 1,
      aux_sym_compound_type_repeat1,
    STATE(8159), 1,
      sym_template_body,
    STATE(8167), 1,
      sym__refinement,
    STATE(4988), 2,
      sym_comment,
      sym_block_comment,
    STATE(8355), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [265426] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4989), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265470] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9404), 1,
      anon_sym_COLON,
    ACTIONS(9406), 1,
      anon_sym_LBRACE,
    ACTIONS(9408), 1,
      anon_sym_with,
    STATE(4816), 1,
      aux_sym_compound_type_repeat1,
    STATE(9699), 1,
      sym_template_body,
    STATE(9705), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4990), 2,
      sym_comment,
      sym_block_comment,
    STATE(9574), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [265534] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6789), 1,
      sym_interpolated_string,
    STATE(15449), 1,
      sym__interpolated_string_start,
    STATE(15451), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9618), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265590] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8910), 1,
      sym_interpolated_string,
    STATE(14822), 1,
      sym__interpolated_string_start,
    STATE(14827), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4992), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [265646] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4993), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [265690] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9497), 1,
      anon_sym_COLON,
    ACTIONS(9499), 1,
      anon_sym_LBRACE,
    ACTIONS(9501), 1,
      anon_sym_with,
    STATE(7196), 1,
      aux_sym_compound_type_repeat1,
    STATE(9576), 1,
      sym_template_body,
    STATE(9583), 1,
      sym__refinement,
    STATE(4994), 2,
      sym_comment,
      sym_block_comment,
    STATE(9716), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8246), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [265748] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8142), 1,
      sym_interpolated_string,
    STATE(15471), 1,
      sym__interpolated_string_start,
    STATE(15472), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9620), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [265804] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9622), 1,
      anon_sym_COLON,
    ACTIONS(9624), 1,
      anon_sym_LBRACE,
    ACTIONS(9626), 1,
      anon_sym_with,
    STATE(7290), 1,
      aux_sym_compound_type_repeat1,
    STATE(9198), 1,
      sym_template_body,
    STATE(9243), 1,
      sym__refinement,
    STATE(4996), 2,
      sym_comment,
      sym_block_comment,
    STATE(9246), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8246), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [265862] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [265906] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8967), 1,
      sym_interpolated_string,
    STATE(14910), 1,
      sym__interpolated_string_start,
    STATE(14911), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [265962] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266006] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(892), 1,
      anon_sym_LBRACE,
    ACTIONS(8086), 1,
      anon_sym_LPAREN,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8809), 1,
      anon_sym_DOT,
    ACTIONS(9361), 1,
      sym__alpha_identifier,
    ACTIONS(9371), 1,
      sym__backquoted_id,
    ACTIONS(9373), 1,
      sym_operator_identifier,
    ACTIONS(9628), 1,
      anon_sym_EQ,
    STATE(529), 1,
      sym_identifier,
    STATE(3852), 1,
      sym__soft_identifier,
    STATE(5000), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(5686), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9365), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(9367), 7,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [266074] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9630), 1,
      anon_sym_LBRACK,
    ACTIONS(9632), 1,
      anon_sym_LPAREN,
    ACTIONS(9634), 1,
      anon_sym_POUND,
    STATE(5639), 1,
      aux_sym_annotation_repeat1,
    STATE(6500), 1,
      sym_type_arguments,
    STATE(6663), 1,
      sym_arguments,
    STATE(5001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [266130] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9304), 1,
      anon_sym_LBRACK,
    ACTIONS(9308), 1,
      anon_sym_POUND,
    ACTIONS(9636), 1,
      anon_sym_AT,
    STATE(5863), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5931), 1,
      sym_type_arguments,
    STATE(7364), 1,
      sym_annotation,
    STATE(5002), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [266186] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9181), 1,
      anon_sym_with,
    STATE(7214), 1,
      aux_sym_compound_type_repeat1,
    STATE(8244), 1,
      sym_template_body,
    STATE(8260), 1,
      sym__refinement,
    STATE(5003), 2,
      sym_comment,
      sym_block_comment,
    STATE(8139), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [266240] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9096), 1,
      anon_sym_LPAREN,
    STATE(5007), 1,
      aux_sym_annotation_repeat1,
    STATE(5913), 1,
      sym_arguments,
    STATE(5004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266290] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266336] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6969), 1,
      sym_interpolated_string,
    STATE(15593), 1,
      sym__interpolated_string_start,
    STATE(15595), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9638), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5006), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266392] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9640), 1,
      anon_sym_LPAREN,
    STATE(5913), 1,
      sym_arguments,
    STATE(5007), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266440] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5008), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266484] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9214), 1,
      anon_sym_LBRACK,
    ACTIONS(9216), 1,
      anon_sym_AT,
    ACTIONS(9220), 1,
      anon_sym_POUND,
    STATE(5897), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6592), 1,
      sym_type_arguments,
    STATE(7294), 1,
      sym_annotation,
    STATE(5009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [266540] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9643), 1,
      anon_sym_AT,
    STATE(5590), 1,
      sym_annotation,
    STATE(5010), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266588] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9622), 1,
      anon_sym_COLON,
    ACTIONS(9624), 1,
      anon_sym_LBRACE,
    ACTIONS(9626), 1,
      anon_sym_with,
    STATE(4996), 1,
      aux_sym_compound_type_repeat1,
    STATE(9198), 1,
      sym_template_body,
    STATE(9203), 1,
      sym__refinement,
    STATE(5011), 2,
      sym_comment,
      sym_block_comment,
    STATE(9246), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8406), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [266646] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5012), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266690] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8119), 1,
      sym_interpolated_string,
    STATE(15252), 1,
      sym__interpolated_string_start,
    STATE(15253), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9646), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5013), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [266746] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5014), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266790] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5015), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266834] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5016), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266878] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9105), 1,
      anon_sym_LPAREN,
    STATE(5018), 1,
      aux_sym_annotation_repeat1,
    STATE(5936), 1,
      sym_arguments,
    STATE(5017), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266928] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9648), 1,
      anon_sym_LPAREN,
    STATE(5936), 1,
      sym_arguments,
    STATE(5018), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266976] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5019), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [267020] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [267064] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9622), 1,
      anon_sym_COLON,
    ACTIONS(9624), 1,
      anon_sym_LBRACE,
    ACTIONS(9626), 1,
      anon_sym_with,
    STATE(4996), 1,
      aux_sym_compound_type_repeat1,
    STATE(9198), 1,
      sym_template_body,
    STATE(9203), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5021), 2,
      sym_comment,
      sym_block_comment,
    STATE(9246), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8412), 4,
      anon_sym_while,
      anon_sym_EQ,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8410), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [267128] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9122), 1,
      anon_sym_LBRACK,
    ACTIONS(9126), 1,
      anon_sym_POUND,
    ACTIONS(9651), 1,
      anon_sym_AT,
    STATE(5588), 1,
      sym_type_arguments,
    STATE(5904), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7329), 1,
      sym_annotation,
    STATE(5022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [267184] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9653), 1,
      anon_sym_AT,
    STATE(5540), 1,
      sym_annotation,
    STATE(5023), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [267232] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9656), 1,
      anon_sym_DOT,
    STATE(5024), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [267278] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5025), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [267322] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6323), 1,
      sym_interpolated_string,
    STATE(15174), 1,
      sym__interpolated_string_start,
    STATE(15175), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9658), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [267378] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9660), 1,
      anon_sym_LBRACK,
    ACTIONS(9662), 1,
      anon_sym_LPAREN,
    ACTIONS(9664), 1,
      anon_sym_POUND,
    STATE(6478), 1,
      sym_type_arguments,
    STATE(6593), 1,
      aux_sym_annotation_repeat1,
    STATE(8001), 1,
      sym_arguments,
    STATE(5027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [267434] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [267478] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9666), 1,
      anon_sym_with,
    STATE(5029), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [267524] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9293), 1,
      anon_sym_LBRACK,
    ACTIONS(9297), 1,
      anon_sym_POUND,
    ACTIONS(9669), 1,
      anon_sym_AT,
    STATE(5482), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5896), 1,
      sym_type_arguments,
    STATE(6781), 1,
      sym_annotation,
    STATE(5030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [267580] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(7773), 1,
      sym_interpolated_string,
    STATE(15213), 1,
      sym__interpolated_string_start,
    STATE(15214), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9671), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [267636] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8963), 1,
      anon_sym_AT,
    STATE(5045), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5513), 1,
      sym_annotation,
    STATE(5032), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [267686] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6520), 1,
      sym_interpolated_string,
    STATE(15099), 1,
      sym__interpolated_string_start,
    STATE(15101), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9673), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [267742] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [267788] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9329), 1,
      anon_sym_LBRACK,
    ACTIONS(9333), 1,
      anon_sym_POUND,
    ACTIONS(9675), 1,
      anon_sym_AT,
    STATE(5490), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5961), 1,
      sym_type_arguments,
    STATE(6796), 1,
      sym_annotation,
    STATE(5035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [267844] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9590), 1,
      anon_sym_COLON,
    ACTIONS(9592), 1,
      anon_sym_LBRACE,
    ACTIONS(9594), 1,
      anon_sym_with,
    STATE(6698), 1,
      aux_sym_compound_type_repeat1,
    STATE(9380), 1,
      sym_template_body,
    STATE(9455), 1,
      sym__refinement,
    STATE(5036), 2,
      sym_comment,
      sym_block_comment,
    STATE(9599), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [267902] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9677), 1,
      anon_sym_AT,
    STATE(5635), 1,
      sym_annotation,
    STATE(5037), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [267950] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [267994] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9314), 1,
      anon_sym_LBRACK,
    ACTIONS(9316), 1,
      anon_sym_AT,
    ACTIONS(9320), 1,
      anon_sym_POUND,
    STATE(5476), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6145), 1,
      sym_type_arguments,
    STATE(6676), 1,
      sym_annotation,
    STATE(5039), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [268050] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268096] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268140] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5042), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268184] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(9027), 1,
      sym_interpolated_string,
    STATE(15042), 1,
      sym__interpolated_string_start,
    STATE(15045), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [268240] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9204), 1,
      anon_sym_LBRACK,
    ACTIONS(9210), 1,
      anon_sym_POUND,
    ACTIONS(9680), 1,
      anon_sym_LPAREN,
    STATE(5989), 1,
      aux_sym_annotation_repeat1,
    STATE(6551), 1,
      sym_type_arguments,
    STATE(7383), 1,
      sym_arguments,
    STATE(5044), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [268296] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9682), 1,
      anon_sym_AT,
    STATE(5513), 1,
      sym_annotation,
    STATE(5045), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268344] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9072), 1,
      anon_sym_AT,
    STATE(5010), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5590), 1,
      sym_annotation,
    STATE(5046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268394] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8729), 1,
      anon_sym_AT,
    STATE(4950), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5840), 1,
      sym_annotation,
    STATE(5047), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268444] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268487] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [268530] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9685), 1,
      anon_sym_DOT,
    STATE(5050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [268575] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268620] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9164), 1,
      anon_sym_AT,
    STATE(5064), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6227), 1,
      sym_annotation,
    STATE(5052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [268669] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268712] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9559), 1,
      anon_sym_LBRACK,
    ACTIONS(9565), 1,
      anon_sym_POUND,
    ACTIONS(9687), 1,
      anon_sym_LPAREN,
    STATE(6612), 1,
      aux_sym_annotation_repeat1,
    STATE(7125), 1,
      sym_type_arguments,
    STATE(7998), 1,
      sym_arguments,
    STATE(5054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [268767] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268810] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5056), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268853] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268896] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9553), 1,
      anon_sym_with,
    STATE(7694), 1,
      aux_sym_compound_type_repeat1,
    STATE(8762), 1,
      sym_template_body,
    STATE(8815), 1,
      sym__refinement,
    STATE(5058), 2,
      sym_comment,
      sym_block_comment,
    STATE(9215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [268949] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [268992] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [269035] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [269078] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [269121] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9689), 1,
      anon_sym_COLON,
    ACTIONS(9691), 1,
      anon_sym_LBRACE,
    ACTIONS(9693), 1,
      anon_sym_with,
    STATE(5065), 1,
      aux_sym_compound_type_repeat1,
    STATE(9886), 1,
      sym_template_body,
    STATE(9888), 1,
      sym__refinement,
    STATE(5063), 2,
      sym_comment,
      sym_block_comment,
    STATE(10103), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [269178] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9695), 1,
      anon_sym_AT,
    STATE(6227), 1,
      sym_annotation,
    STATE(5064), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [269225] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9689), 1,
      anon_sym_COLON,
    ACTIONS(9691), 1,
      anon_sym_LBRACE,
    ACTIONS(9693), 1,
      anon_sym_with,
    STATE(7858), 1,
      aux_sym_compound_type_repeat1,
    STATE(9886), 1,
      sym_template_body,
    STATE(9901), 1,
      sym__refinement,
    STATE(5065), 2,
      sym_comment,
      sym_block_comment,
    STATE(10103), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [269282] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [269325] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9698), 1,
      anon_sym_DOT,
    STATE(5067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [269370] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [269413] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [269456] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [269499] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [269542] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [269585] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5073), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [269628] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5074), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [269671] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9630), 1,
      anon_sym_LBRACK,
    ACTIONS(9634), 1,
      anon_sym_POUND,
    ACTIONS(9700), 1,
      anon_sym_AT,
    STATE(6173), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6500), 1,
      sym_type_arguments,
    STATE(7839), 1,
      sym_annotation,
    STATE(5075), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [269726] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(9467), 1,
      sym_interpolated_string,
    STATE(15127), 1,
      sym__interpolated_string_start,
    STATE(15128), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [269781] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9702), 1,
      anon_sym_COLON,
    ACTIONS(9704), 1,
      anon_sym_LBRACE,
    ACTIONS(9706), 1,
      anon_sym_with,
    STATE(5347), 1,
      aux_sym_compound_type_repeat1,
    STATE(9924), 1,
      sym_template_body,
    STATE(9927), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5077), 2,
      sym_comment,
      sym_block_comment,
    STATE(9925), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [269844] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5078), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [269887] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9708), 1,
      anon_sym_LBRACK,
    ACTIONS(9710), 1,
      anon_sym_LPAREN,
    ACTIONS(9712), 1,
      anon_sym_POUND,
    STATE(6015), 1,
      aux_sym_annotation_repeat1,
    STATE(7254), 1,
      sym_type_arguments,
    STATE(7900), 1,
      sym_arguments,
    STATE(5079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [269942] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [269985] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5081), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [270028] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [270071] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5083), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [270114] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [270157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [270200] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [270245] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9503), 1,
      anon_sym_LBRACK,
    ACTIONS(9507), 1,
      anon_sym_POUND,
    ACTIONS(9714), 1,
      anon_sym_AT,
    STATE(6076), 1,
      sym_type_arguments,
    STATE(6363), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7751), 1,
      sym_annotation,
    STATE(5087), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [270300] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5088), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [270343] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5089), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [270386] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [270429] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9689), 1,
      anon_sym_COLON,
    ACTIONS(9691), 1,
      anon_sym_LBRACE,
    ACTIONS(9693), 1,
      anon_sym_with,
    STATE(5065), 1,
      aux_sym_compound_type_repeat1,
    STATE(9886), 1,
      sym_template_body,
    STATE(9888), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5091), 2,
      sym_comment,
      sym_block_comment,
    STATE(10103), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [270492] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9451), 1,
      anon_sym_LBRACK,
    ACTIONS(9453), 1,
      anon_sym_AT,
    ACTIONS(9457), 1,
      anon_sym_POUND,
    STATE(6530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7362), 1,
      sym_type_arguments,
    STATE(7990), 1,
      sym_annotation,
    STATE(5092), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [270547] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5093), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [270590] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [270633] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5095), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [270676] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [270719] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5097), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [270762] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [270805] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5099), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [270848] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [270891] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5101), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [270936] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [270979] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5103), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [271022] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5104), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [271065] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9238), 1,
      anon_sym_LPAREN,
    STATE(5106), 1,
      aux_sym_annotation_repeat1,
    STATE(6187), 1,
      sym_arguments,
    STATE(5105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [271114] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9716), 1,
      anon_sym_LPAREN,
    STATE(6187), 1,
      sym_arguments,
    STATE(5106), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [271161] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9719), 1,
      anon_sym_COLON,
    ACTIONS(9721), 1,
      anon_sym_LBRACE,
    ACTIONS(9723), 1,
      anon_sym_with,
    STATE(5302), 1,
      aux_sym_compound_type_repeat1,
    STATE(10054), 1,
      sym_template_body,
    STATE(10055), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5107), 2,
      sym_comment,
      sym_block_comment,
    STATE(10078), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8412), 5,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_EQ,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [271224] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [271267] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5109), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [271310] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [271353] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [271396] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9725), 1,
      anon_sym_DOT,
    STATE(5112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [271441] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [271484] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5114), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [271527] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9727), 1,
      anon_sym_LBRACK,
    ACTIONS(9729), 1,
      anon_sym_LPAREN,
    ACTIONS(9731), 1,
      anon_sym_POUND,
    STATE(6462), 1,
      aux_sym_annotation_repeat1,
    STATE(6766), 1,
      sym_type_arguments,
    STATE(7929), 1,
      sym_arguments,
    STATE(5115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8154), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [271582] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [271625] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [271668] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5118), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [271711] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9737), 1,
      anon_sym_LBRACK,
    ACTIONS(9739), 1,
      anon_sym_LPAREN,
    ACTIONS(9741), 1,
      anon_sym_POUND,
    STATE(6589), 1,
      aux_sym_annotation_repeat1,
    STATE(6825), 1,
      sym_type_arguments,
    STATE(8079), 1,
      sym_arguments,
    STATE(5119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [271766] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9743), 1,
      anon_sym_LBRACK,
    ACTIONS(9745), 1,
      anon_sym_LPAREN,
    ACTIONS(9747), 1,
      anon_sym_POUND,
    STATE(6436), 1,
      aux_sym_annotation_repeat1,
    STATE(7345), 1,
      sym_type_arguments,
    STATE(7703), 1,
      sym_arguments,
    STATE(5120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [271821] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5121), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [271864] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5122), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [271907] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [271950] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9749), 1,
      anon_sym_COLON,
    ACTIONS(9751), 1,
      anon_sym_LBRACE,
    ACTIONS(9753), 1,
      anon_sym_with,
    STATE(7501), 1,
      aux_sym_compound_type_repeat1,
    STATE(9790), 1,
      sym__refinement,
    STATE(10104), 1,
      sym_template_body,
    STATE(5124), 2,
      sym_comment,
      sym_block_comment,
    STATE(9887), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [272007] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [272050] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5126), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [272093] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [272136] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [272179] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5129), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [272222] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5130), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [272265] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9755), 1,
      anon_sym_LBRACK,
    ACTIONS(9757), 1,
      anon_sym_LPAREN,
    ACTIONS(9759), 1,
      anon_sym_POUND,
    STATE(6147), 1,
      aux_sym_annotation_repeat1,
    STATE(6860), 1,
      sym_type_arguments,
    STATE(7447), 1,
      sym_arguments,
    STATE(5131), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [272320] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5132), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [272363] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [272406] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5134), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [272449] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9761), 1,
      anon_sym_DOT,
    STATE(5135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [272494] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9763), 1,
      anon_sym_COLON,
    ACTIONS(9765), 1,
      anon_sym_LBRACE,
    ACTIONS(9767), 1,
      anon_sym_with,
    STATE(5252), 1,
      aux_sym_compound_type_repeat1,
    STATE(9747), 1,
      sym_template_body,
    STATE(9759), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5136), 2,
      sym_comment,
      sym_block_comment,
    STATE(9914), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8412), 5,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [272557] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5137), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [272600] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [272643] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [272686] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [272731] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [272774] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9194), 1,
      anon_sym_LPAREN,
    STATE(5143), 1,
      aux_sym_annotation_repeat1,
    STATE(6387), 1,
      sym_arguments,
    STATE(5142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [272823] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9769), 1,
      anon_sym_LPAREN,
    STATE(6387), 1,
      sym_arguments,
    STATE(5143), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [272870] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9772), 1,
      anon_sym_LBRACK,
    ACTIONS(9774), 1,
      anon_sym_LPAREN,
    ACTIONS(9776), 1,
      anon_sym_POUND,
    STATE(6440), 1,
      aux_sym_annotation_repeat1,
    STATE(7020), 1,
      sym_type_arguments,
    STATE(7634), 1,
      sym_arguments,
    STATE(5144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [272925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [272968] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [273011] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [273054] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9778), 1,
      anon_sym_COLON,
    ACTIONS(9780), 1,
      anon_sym_LBRACE,
    ACTIONS(9782), 1,
      anon_sym_with,
    STATE(7965), 1,
      aux_sym_compound_type_repeat1,
    STATE(9778), 1,
      sym__refinement,
    STATE(9782), 1,
      sym_template_body,
    STATE(5148), 2,
      sym_comment,
      sym_block_comment,
    STATE(9798), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [273111] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5149), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [273154] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9273), 1,
      anon_sym_AT,
    STATE(5189), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6175), 1,
      sym_annotation,
    STATE(5150), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [273203] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9295), 1,
      anon_sym_LPAREN,
    STATE(5152), 1,
      aux_sym_annotation_repeat1,
    STATE(6607), 1,
      sym_arguments,
    STATE(5151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [273252] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9784), 1,
      anon_sym_LPAREN,
    STATE(6607), 1,
      sym_arguments,
    STATE(5152), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [273299] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [273342] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [273385] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5155), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [273428] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9331), 1,
      anon_sym_LPAREN,
    STATE(5159), 1,
      aux_sym_annotation_repeat1,
    STATE(6519), 1,
      sym_arguments,
    STATE(5156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [273477] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [273520] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [273565] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9787), 1,
      anon_sym_LPAREN,
    STATE(6519), 1,
      sym_arguments,
    STATE(5159), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [273612] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5160), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [273655] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5161), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [273698] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [273741] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9790), 1,
      anon_sym_DOT,
    STATE(5163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [273786] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [273829] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [273872] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5166), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [273915] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [273960] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [274003] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5169), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [274046] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [274089] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5171), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [274132] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [274175] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [274218] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [274261] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5175), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [274304] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [274347] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [274390] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [274433] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [274476] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [274519] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9188), 1,
      anon_sym_LPAREN,
    STATE(5183), 1,
      aux_sym_annotation_repeat1,
    STATE(6565), 1,
      sym_arguments,
    STATE(5181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8426), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [274568] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8313), 1,
      sym_interpolated_string,
    STATE(15827), 1,
      sym__interpolated_string_start,
    STATE(15829), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9792), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5182), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [274623] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9794), 1,
      anon_sym_LPAREN,
    STATE(6565), 1,
      sym_arguments,
    STATE(5183), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8430), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [274670] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [274713] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [274756] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9246), 1,
      anon_sym_LPAREN,
    STATE(5187), 1,
      aux_sym_annotation_repeat1,
    STATE(6143), 1,
      sym_arguments,
    STATE(5186), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [274805] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9797), 1,
      anon_sym_LPAREN,
    STATE(6143), 1,
      sym_arguments,
    STATE(5187), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [274852] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9511), 1,
      anon_sym_LBRACK,
    ACTIONS(9517), 1,
      anon_sym_POUND,
    ACTIONS(9800), 1,
      anon_sym_LPAREN,
    STATE(6332), 1,
      aux_sym_annotation_repeat1,
    STATE(7266), 1,
      sym_type_arguments,
    STATE(7908), 1,
      sym_arguments,
    STATE(5188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8154), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [274907] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9802), 1,
      anon_sym_AT,
    STATE(6175), 1,
      sym_annotation,
    STATE(5189), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [274954] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5190), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [274997] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [275040] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [275083] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [275126] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [275169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [275212] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9805), 1,
      anon_sym_DOT,
    STATE(5196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [275257] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9807), 1,
      anon_sym_DOT,
    STATE(5197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [275302] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1484), 1,
      anon_sym_LBRACE,
    ACTIONS(9341), 1,
      anon_sym_LPAREN,
    ACTIONS(9809), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5198), 2,
      sym_comment,
      sym_block_comment,
    STATE(8599), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8831), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [275357] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9451), 1,
      anon_sym_LBRACK,
    ACTIONS(9457), 1,
      anon_sym_POUND,
    ACTIONS(9811), 1,
      anon_sym_LPAREN,
    STATE(6047), 1,
      aux_sym_annotation_repeat1,
    STATE(7362), 1,
      sym_type_arguments,
    STATE(7633), 1,
      sym_arguments,
    STATE(5199), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [275412] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9702), 1,
      anon_sym_COLON,
    ACTIONS(9704), 1,
      anon_sym_LBRACE,
    ACTIONS(9706), 1,
      anon_sym_with,
    STATE(5347), 1,
      aux_sym_compound_type_repeat1,
    STATE(9924), 1,
      sym_template_body,
    STATE(9927), 1,
      sym__refinement,
    STATE(5200), 2,
      sym_comment,
      sym_block_comment,
    STATE(9925), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [275469] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [275514] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9062), 1,
      anon_sym_AT,
    STATE(5232), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6164), 1,
      sym_annotation,
    STATE(5202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [275563] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9258), 1,
      anon_sym_LPAREN,
    STATE(5212), 1,
      aux_sym_annotation_repeat1,
    STATE(6638), 1,
      sym_arguments,
    STATE(5203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [275612] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [275657] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(936), 1,
      anon_sym_LBRACE,
    ACTIONS(8236), 1,
      anon_sym_LPAREN,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8989), 1,
      anon_sym_DOT,
    ACTIONS(9813), 1,
      sym__alpha_identifier,
    ACTIONS(9817), 1,
      anon_sym_EQ,
    ACTIONS(9819), 1,
      sym__backquoted_id,
    ACTIONS(9821), 1,
      sym_operator_identifier,
    STATE(530), 1,
      sym_identifier,
    STATE(3932), 1,
      sym__soft_identifier,
    STATE(5205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(6647), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9367), 6,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9815), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [275724] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1116), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9064), 1,
      anon_sym_LPAREN,
    ACTIONS(9480), 1,
      anon_sym_DOT,
    ACTIONS(9823), 1,
      sym__alpha_identifier,
    ACTIONS(9827), 1,
      anon_sym_EQ,
    ACTIONS(9829), 1,
      sym__backquoted_id,
    ACTIONS(9831), 1,
      sym_operator_identifier,
    STATE(535), 1,
      sym_identifier,
    STATE(4031), 1,
      sym__soft_identifier,
    STATE(5206), 2,
      sym_comment,
      sym_block_comment,
    STATE(7491), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 5,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9825), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [275791] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6992), 1,
      sym_interpolated_string,
    STATE(14749), 1,
      sym__interpolated_string_start,
    STATE(14750), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9833), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5207), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [275846] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(972), 1,
      anon_sym_LBRACE,
    ACTIONS(8374), 1,
      anon_sym_LPAREN,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9046), 1,
      anon_sym_DOT,
    ACTIONS(9835), 1,
      sym__alpha_identifier,
    ACTIONS(9839), 1,
      anon_sym_EQ,
    ACTIONS(9841), 1,
      sym__backquoted_id,
    ACTIONS(9843), 1,
      sym_operator_identifier,
    STATE(531), 1,
      sym_identifier,
    STATE(3976), 1,
      sym__soft_identifier,
    STATE(5208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(6202), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9367), 6,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9837), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [275913] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8967), 1,
      sym_interpolated_string,
    STATE(14910), 1,
      sym__interpolated_string_start,
    STATE(14911), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9845), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [275968] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(9027), 1,
      sym_interpolated_string,
    STATE(15042), 1,
      sym__interpolated_string_start,
    STATE(15045), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9847), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [276023] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9749), 1,
      anon_sym_COLON,
    ACTIONS(9751), 1,
      anon_sym_LBRACE,
    ACTIONS(9753), 1,
      anon_sym_with,
    STATE(5124), 1,
      aux_sym_compound_type_repeat1,
    STATE(10104), 1,
      sym_template_body,
    STATE(10109), 1,
      sym__refinement,
    STATE(5211), 2,
      sym_comment,
      sym_block_comment,
    STATE(9887), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [276080] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9849), 1,
      anon_sym_LPAREN,
    STATE(6638), 1,
      sym_arguments,
    STATE(5212), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [276127] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [276170] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5214), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [276213] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9545), 1,
      anon_sym_LBRACK,
    ACTIONS(9551), 1,
      anon_sym_POUND,
    ACTIONS(9852), 1,
      anon_sym_LPAREN,
    STATE(6109), 1,
      aux_sym_annotation_repeat1,
    STATE(6916), 1,
      sym_type_arguments,
    STATE(7557), 1,
      sym_arguments,
    STATE(5215), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [276268] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(107), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9039), 1,
      anon_sym_LPAREN,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(9367), 1,
      anon_sym_match,
    ACTIONS(9391), 1,
      anon_sym_DOT,
    ACTIONS(9854), 1,
      sym__alpha_identifier,
    ACTIONS(9860), 1,
      sym__backquoted_id,
    ACTIONS(9862), 1,
      sym_operator_identifier,
    STATE(553), 1,
      sym_identifier,
    STATE(4043), 1,
      sym__soft_identifier,
    STATE(5216), 2,
      sym_comment,
      sym_block_comment,
    STATE(7569), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8803), 4,
      anon_sym_COLON,
      anon_sym_if,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9856), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [276337] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(9717), 1,
      sym_interpolated_string,
    STATE(15257), 1,
      sym__interpolated_string_start,
    STATE(15276), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [276392] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9749), 1,
      anon_sym_COLON,
    ACTIONS(9751), 1,
      anon_sym_LBRACE,
    ACTIONS(9753), 1,
      anon_sym_with,
    STATE(5124), 1,
      aux_sym_compound_type_repeat1,
    STATE(10104), 1,
      sym_template_body,
    STATE(10109), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5218), 2,
      sym_comment,
      sym_block_comment,
    STATE(9887), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [276455] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(936), 1,
      anon_sym_LBRACE,
    ACTIONS(8236), 1,
      anon_sym_LPAREN,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8989), 1,
      anon_sym_DOT,
    ACTIONS(9813), 1,
      sym__alpha_identifier,
    ACTIONS(9819), 1,
      sym__backquoted_id,
    ACTIONS(9821), 1,
      sym_operator_identifier,
    ACTIONS(9864), 1,
      anon_sym_EQ,
    STATE(530), 1,
      sym_identifier,
    STATE(3932), 1,
      sym__soft_identifier,
    STATE(5219), 2,
      sym_comment,
      sym_block_comment,
    STATE(6647), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9367), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9363), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9815), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [276522] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9511), 1,
      anon_sym_LBRACK,
    ACTIONS(9513), 1,
      anon_sym_AT,
    ACTIONS(9517), 1,
      anon_sym_POUND,
    STATE(6376), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7266), 1,
      sym_type_arguments,
    STATE(7448), 1,
      sym_annotation,
    STATE(5220), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [276577] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5221), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [276620] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6992), 1,
      sym_interpolated_string,
    STATE(14749), 1,
      sym__interpolated_string_start,
    STATE(14750), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9866), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [276675] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(972), 1,
      anon_sym_LBRACE,
    ACTIONS(8374), 1,
      anon_sym_LPAREN,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9046), 1,
      anon_sym_DOT,
    ACTIONS(9835), 1,
      sym__alpha_identifier,
    ACTIONS(9841), 1,
      sym__backquoted_id,
    ACTIONS(9843), 1,
      sym_operator_identifier,
    ACTIONS(9868), 1,
      anon_sym_EQ,
    STATE(531), 1,
      sym_identifier,
    STATE(3976), 1,
      sym__soft_identifier,
    STATE(5223), 2,
      sym_comment,
      sym_block_comment,
    STATE(6202), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9367), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(9363), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9837), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [276742] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [276785] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9870), 1,
      anon_sym_COLON,
    ACTIONS(9873), 1,
      anon_sym_LBRACE,
    STATE(6718), 1,
      sym_template_body,
    STATE(5225), 2,
      sym_comment,
      sym_block_comment,
    STATE(6878), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 15,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [276836] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9876), 1,
      anon_sym_with,
    STATE(5709), 1,
      aux_sym_compound_type_repeat1,
    STATE(8728), 1,
      sym_template_body,
    STATE(8729), 1,
      sym__refinement,
    STATE(9085), 1,
      sym_arguments,
    STATE(5226), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [276891] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5227), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [276934] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1484), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9341), 1,
      anon_sym_LPAREN,
    ACTIONS(9809), 1,
      anon_sym_DOT,
    ACTIONS(9878), 1,
      sym_operator_identifier,
    STATE(1703), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    STATE(8599), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8807), 6,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [277001] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277044] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5231), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277130] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9880), 1,
      anon_sym_AT,
    STATE(6164), 1,
      sym_annotation,
    STATE(5232), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [277177] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9883), 1,
      anon_sym_COLON,
    ACTIONS(9885), 1,
      anon_sym_LBRACE,
    ACTIONS(9887), 1,
      anon_sym_with,
    STATE(7819), 1,
      aux_sym_compound_type_repeat1,
    STATE(9807), 1,
      sym__refinement,
    STATE(9959), 1,
      sym_template_body,
    STATE(5233), 2,
      sym_comment,
      sym_block_comment,
    STATE(9773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [277234] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(7598), 1,
      sym_interpolated_string,
    STATE(15304), 1,
      sym__interpolated_string_start,
    STATE(15305), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9889), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5234), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277289] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277332] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    STATE(5242), 1,
      aux_sym_annotation_repeat1,
    STATE(6204), 1,
      sym_arguments,
    STATE(5236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8426), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [277381] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5237), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277424] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9386), 1,
      anon_sym_EQ_GT,
    STATE(5238), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277469] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9763), 1,
      anon_sym_COLON,
    ACTIONS(9765), 1,
      anon_sym_LBRACE,
    ACTIONS(9767), 1,
      anon_sym_with,
    STATE(5252), 1,
      aux_sym_compound_type_repeat1,
    STATE(9747), 1,
      sym_template_body,
    STATE(9759), 1,
      sym__refinement,
    STATE(5239), 2,
      sym_comment,
      sym_block_comment,
    STATE(9914), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [277526] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(7598), 1,
      sym_interpolated_string,
    STATE(15304), 1,
      sym__interpolated_string_start,
    STATE(15305), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9891), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [277581] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277624] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9897), 1,
      anon_sym_LPAREN,
    STATE(6204), 1,
      sym_arguments,
    STATE(5242), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8430), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [277671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5243), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277714] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277757] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9904), 1,
      anon_sym_DOT,
    STATE(5245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [277802] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6789), 1,
      sym_interpolated_string,
    STATE(15449), 1,
      sym__interpolated_string_start,
    STATE(15451), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9906), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5246), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [277857] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1374), 1,
      anon_sym_LBRACE,
    ACTIONS(9208), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5247), 2,
      sym_comment,
      sym_block_comment,
    STATE(8511), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [277912] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5248), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277955] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277998] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1374), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9208), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_DOT,
    ACTIONS(9918), 1,
      sym_operator_identifier,
    STATE(1712), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5250), 2,
      sym_comment,
      sym_block_comment,
    STATE(8511), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8807), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [278065] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1374), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9208), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5251), 2,
      sym_comment,
      sym_block_comment,
    STATE(8511), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [278122] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9763), 1,
      anon_sym_COLON,
    ACTIONS(9765), 1,
      anon_sym_LBRACE,
    ACTIONS(9767), 1,
      anon_sym_with,
    STATE(7922), 1,
      aux_sym_compound_type_repeat1,
    STATE(9747), 1,
      sym_template_body,
    STATE(9843), 1,
      sym__refinement,
    STATE(5252), 2,
      sym_comment,
      sym_block_comment,
    STATE(9914), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [278179] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [278222] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5254), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [278267] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9306), 1,
      anon_sym_LPAREN,
    STATE(5263), 1,
      aux_sym_annotation_repeat1,
    STATE(6336), 1,
      sym_arguments,
    STATE(5255), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [278316] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9920), 1,
      anon_sym_LBRACK,
    ACTIONS(9922), 1,
      anon_sym_AT,
    ACTIONS(9924), 1,
      anon_sym_LPAREN,
    ACTIONS(9926), 1,
      anon_sym_POUND,
    STATE(6950), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7593), 1,
      sym_type_arguments,
    STATE(8105), 1,
      sym_annotation,
    STATE(9085), 1,
      sym_arguments,
    STATE(5256), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [278375] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1194), 1,
      anon_sym_LBRACE,
    ACTIONS(9218), 1,
      anon_sym_LPAREN,
    ACTIONS(9928), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5257), 2,
      sym_comment,
      sym_block_comment,
    STATE(8407), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [278430] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [278473] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9930), 1,
      anon_sym_LBRACK,
    ACTIONS(9932), 1,
      anon_sym_LPAREN,
    ACTIONS(9934), 1,
      anon_sym_POUND,
    STATE(6768), 1,
      aux_sym_annotation_repeat1,
    STATE(6820), 1,
      sym_type_arguments,
    STATE(8185), 1,
      sym_arguments,
    STATE(5259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8154), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [278528] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1194), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9218), 1,
      anon_sym_LPAREN,
    ACTIONS(9928), 1,
      anon_sym_DOT,
    ACTIONS(9936), 1,
      sym_operator_identifier,
    STATE(1745), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5260), 2,
      sym_comment,
      sym_block_comment,
    STATE(8407), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8807), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [278595] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9938), 1,
      anon_sym_COLON,
    ACTIONS(9940), 1,
      anon_sym_LBRACE,
    ACTIONS(9942), 1,
      anon_sym_with,
    STATE(5304), 1,
      aux_sym_compound_type_repeat1,
    STATE(9733), 1,
      sym__refinement,
    STATE(10121), 1,
      sym_template_body,
    STATE(5261), 2,
      sym_comment,
      sym_block_comment,
    STATE(9806), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [278652] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5262), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [278695] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9944), 1,
      anon_sym_LPAREN,
    STATE(6336), 1,
      sym_arguments,
    STATE(5263), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [278742] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5264), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [278785] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(107), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9039), 1,
      anon_sym_LPAREN,
    ACTIONS(9391), 1,
      anon_sym_DOT,
    ACTIONS(9947), 1,
      sym_operator_identifier,
    STATE(1789), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5265), 2,
      sym_comment,
      sym_block_comment,
    STATE(7569), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8807), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8805), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [278852] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1194), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9218), 1,
      anon_sym_LPAREN,
    ACTIONS(9928), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5266), 2,
      sym_comment,
      sym_block_comment,
    STATE(8407), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [278909] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9949), 1,
      anon_sym_with,
    STATE(5267), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [278954] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [278997] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9952), 1,
      anon_sym_AT,
    STATE(6590), 1,
      sym_annotation,
    STATE(5269), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279044] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5271), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279130] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8442), 1,
      sym_interpolated_string,
    STATE(15634), 1,
      sym__interpolated_string_start,
    STATE(15635), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(9955), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
  [279185] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9938), 1,
      anon_sym_COLON,
    ACTIONS(9940), 1,
      anon_sym_LBRACE,
    ACTIONS(9942), 1,
      anon_sym_with,
    STATE(5304), 1,
      aux_sym_compound_type_repeat1,
    STATE(9733), 1,
      sym__refinement,
    STATE(10121), 1,
      sym_template_body,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5273), 2,
      sym_comment,
      sym_block_comment,
    STATE(9806), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [279248] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279291] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279334] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5276), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279377] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [279420] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279463] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9351), 1,
      anon_sym_AT,
    STATE(5317), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6621), 1,
      sym_annotation,
    STATE(5279), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279512] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9961), 1,
      anon_sym_LPAREN,
    STATE(6633), 1,
      sym_arguments,
    STATE(5280), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [279559] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5281), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279602] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5282), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279645] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9489), 1,
      anon_sym_LBRACK,
    ACTIONS(9493), 1,
      anon_sym_POUND,
    ACTIONS(9964), 1,
      anon_sym_AT,
    STATE(6066), 1,
      sym_type_arguments,
    STATE(6584), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8032), 1,
      sym_annotation,
    STATE(5283), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [279700] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5284), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279743] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279786] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5286), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279829] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279872] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5288), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279915] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279958] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5290), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [280001] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [280044] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [280087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [280130] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(9512), 1,
      sym_interpolated_string,
    STATE(15002), 1,
      sym__interpolated_string_start,
    STATE(15006), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5294), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [280185] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5295), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [280228] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5296), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [280271] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9883), 1,
      anon_sym_COLON,
    ACTIONS(9885), 1,
      anon_sym_LBRACE,
    ACTIONS(9887), 1,
      anon_sym_with,
    STATE(5233), 1,
      aux_sym_compound_type_repeat1,
    STATE(9952), 1,
      sym__refinement,
    STATE(9959), 1,
      sym_template_body,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5297), 2,
      sym_comment,
      sym_block_comment,
    STATE(9773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [280334] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9966), 1,
      anon_sym_LBRACK,
    ACTIONS(9968), 1,
      anon_sym_LPAREN,
    ACTIONS(9970), 1,
      anon_sym_POUND,
    STATE(6715), 1,
      sym_type_arguments,
    STATE(6835), 1,
      aux_sym_annotation_repeat1,
    STATE(8165), 1,
      sym_arguments,
    STATE(5298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8154), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [280389] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9972), 1,
      anon_sym_LBRACK,
    ACTIONS(9974), 1,
      anon_sym_LPAREN,
    ACTIONS(9976), 1,
      anon_sym_POUND,
    STATE(6851), 1,
      aux_sym_annotation_repeat1,
    STATE(7160), 1,
      sym_type_arguments,
    STATE(8308), 1,
      sym_arguments,
    STATE(5299), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [280444] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5300), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [280487] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9545), 1,
      anon_sym_LBRACK,
    ACTIONS(9547), 1,
      anon_sym_AT,
    ACTIONS(9551), 1,
      anon_sym_POUND,
    STATE(5996), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6916), 1,
      sym_type_arguments,
    STATE(7862), 1,
      sym_annotation,
    STATE(5301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [280542] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9719), 1,
      anon_sym_COLON,
    ACTIONS(9721), 1,
      anon_sym_LBRACE,
    ACTIONS(9723), 1,
      anon_sym_with,
    STATE(7834), 1,
      aux_sym_compound_type_repeat1,
    STATE(10054), 1,
      sym_template_body,
    STATE(10067), 1,
      sym__refinement,
    STATE(5302), 2,
      sym_comment,
      sym_block_comment,
    STATE(10078), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [280599] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [280642] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9938), 1,
      anon_sym_COLON,
    ACTIONS(9940), 1,
      anon_sym_LBRACE,
    ACTIONS(9942), 1,
      anon_sym_with,
    STATE(8050), 1,
      aux_sym_compound_type_repeat1,
    STATE(9760), 1,
      sym__refinement,
    STATE(10121), 1,
      sym_template_body,
    STATE(5304), 2,
      sym_comment,
      sym_block_comment,
    STATE(9806), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [280699] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    STATE(4457), 1,
      aux_sym_modifiers_repeat1,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(5305), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
    ACTIONS(9978), 10,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
  [280756] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [280799] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [280842] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [280885] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [280928] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9656), 1,
      anon_sym_DOT,
    ACTIONS(9980), 1,
      anon_sym_EQ_GT,
    STATE(5310), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [280975] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5311), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281018] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5312), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281061] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9574), 1,
      anon_sym_LBRACK,
    ACTIONS(9578), 1,
      anon_sym_POUND,
    ACTIONS(9982), 1,
      anon_sym_AT,
    STATE(6156), 1,
      sym_type_arguments,
    STATE(6319), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8077), 1,
      sym_annotation,
    STATE(5313), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [281116] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5314), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [281159] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9523), 1,
      anon_sym_with,
    STATE(7891), 1,
      aux_sym_compound_type_repeat1,
    STATE(8734), 1,
      sym__refinement,
    STATE(9261), 1,
      sym_template_body,
    STATE(5315), 2,
      sym_comment,
      sym_block_comment,
    STATE(9294), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8246), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [281212] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [281255] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9984), 1,
      anon_sym_AT,
    STATE(6621), 1,
      sym_annotation,
    STATE(5317), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281302] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5318), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [281345] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9449), 1,
      anon_sym_EQ_GT,
    STATE(5319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281390] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9987), 1,
      anon_sym_COLON,
    ACTIONS(9990), 1,
      anon_sym_LBRACE,
    STATE(6893), 1,
      sym_template_body,
    STATE(5320), 2,
      sym_comment,
      sym_block_comment,
    STATE(7225), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 15,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281441] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281484] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9459), 1,
      anon_sym_EQ_GT,
    STATE(5322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [281529] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(892), 1,
      anon_sym_LBRACE,
    ACTIONS(8086), 1,
      anon_sym_LPAREN,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8809), 1,
      anon_sym_DOT,
    ACTIONS(9361), 1,
      sym__alpha_identifier,
    ACTIONS(9371), 1,
      sym__backquoted_id,
    ACTIONS(9373), 1,
      sym_operator_identifier,
    ACTIONS(9993), 1,
      anon_sym_EQ,
    STATE(529), 1,
      sym_identifier,
    STATE(3852), 1,
      sym__soft_identifier,
    STATE(5323), 2,
      sym_comment,
      sym_block_comment,
    STATE(5686), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 5,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9365), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [281596] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9569), 1,
      anon_sym_with,
    STATE(7535), 1,
      aux_sym_compound_type_repeat1,
    STATE(9103), 1,
      sym_template_body,
    STATE(9118), 1,
      sym__refinement,
    STATE(5324), 2,
      sym_comment,
      sym_block_comment,
    STATE(8768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [281649] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9995), 1,
      anon_sym_COLON,
    ACTIONS(9998), 1,
      anon_sym_LBRACE,
    STATE(6922), 1,
      sym_template_body,
    STATE(5325), 2,
      sym_comment,
      sym_block_comment,
    STATE(7326), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 7,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 16,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [281700] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9660), 1,
      anon_sym_LBRACK,
    ACTIONS(9664), 1,
      anon_sym_POUND,
    ACTIONS(10001), 1,
      anon_sym_AT,
    STATE(6478), 1,
      sym_type_arguments,
    STATE(7162), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8225), 1,
      sym_annotation,
    STATE(5326), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [281755] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5327), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281798] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10003), 1,
      anon_sym_with,
    STATE(5328), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281843] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5329), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [281886] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1008), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8855), 1,
      anon_sym_LPAREN,
    ACTIONS(9240), 1,
      anon_sym_DOT,
    ACTIONS(10006), 1,
      sym__alpha_identifier,
    ACTIONS(10010), 1,
      anon_sym_EQ,
    ACTIONS(10012), 1,
      sym__backquoted_id,
    ACTIONS(10014), 1,
      sym_operator_identifier,
    STATE(532), 1,
      sym_identifier,
    STATE(4034), 1,
      sym__soft_identifier,
    STATE(5330), 2,
      sym_comment,
      sym_block_comment,
    STATE(6919), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9367), 5,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10008), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [281953] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5331), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [281996] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5746), 1,
      sym_arguments,
    STATE(5332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282041] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9439), 1,
      anon_sym_DOT,
    ACTIONS(10016), 1,
      anon_sym_EQ_GT,
    STATE(5333), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [282088] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282131] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5335), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [282174] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1484), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9341), 1,
      anon_sym_LPAREN,
    ACTIONS(9809), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5336), 2,
      sym_comment,
      sym_block_comment,
    STATE(8599), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8835), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [282231] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [282274] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5338), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282317] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(9410), 1,
      sym_interpolated_string,
    STATE(15502), 1,
      sym__interpolated_string_start,
    STATE(15503), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5339), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [282372] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282415] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282458] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5342), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282501] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5343), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282544] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9410), 1,
      anon_sym_LBRACK,
    ACTIONS(9414), 1,
      anon_sym_POUND,
    ACTIONS(10018), 1,
      anon_sym_AT,
    STATE(6341), 1,
      sym_type_arguments,
    STATE(6552), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7938), 1,
      sym_annotation,
    STATE(5344), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [282599] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1116), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9064), 1,
      anon_sym_LPAREN,
    ACTIONS(9480), 1,
      anon_sym_DOT,
    ACTIONS(9823), 1,
      sym__alpha_identifier,
    ACTIONS(9829), 1,
      sym__backquoted_id,
    ACTIONS(9831), 1,
      sym_operator_identifier,
    ACTIONS(10020), 1,
      anon_sym_EQ,
    STATE(535), 1,
      sym_identifier,
    STATE(4031), 1,
      sym__soft_identifier,
    STATE(5345), 2,
      sym_comment,
      sym_block_comment,
    STATE(7491), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 5,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9825), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [282666] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(6969), 1,
      sym_interpolated_string,
    STATE(15593), 1,
      sym__interpolated_string_start,
    STATE(15595), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10022), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [282721] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9702), 1,
      anon_sym_COLON,
    ACTIONS(9704), 1,
      anon_sym_LBRACE,
    ACTIONS(9706), 1,
      anon_sym_with,
    STATE(7642), 1,
      aux_sym_compound_type_repeat1,
    STATE(9924), 1,
      sym_template_body,
    STATE(9944), 1,
      sym__refinement,
    STATE(5347), 2,
      sym_comment,
      sym_block_comment,
    STATE(9925), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [282778] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10024), 1,
      anon_sym_with,
    STATE(5622), 1,
      aux_sym_compound_type_repeat1,
    STATE(9621), 1,
      sym_arguments,
    STATE(9728), 1,
      sym_template_body,
    STATE(9729), 1,
      sym__refinement,
    STATE(5348), 2,
      sym_comment,
      sym_block_comment,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [282833] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10026), 1,
      anon_sym_with,
    STATE(5349), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282878] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5350), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282921] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5351), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282964] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283007] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5353), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283052] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5354), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283095] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9463), 1,
      anon_sym_DOT,
    ACTIONS(10037), 1,
      anon_sym_EQ_GT,
    STATE(5355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [283142] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5356), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283185] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10043), 1,
      anon_sym_with,
    STATE(5357), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283230] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283273] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283316] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5360), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283359] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5361), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283402] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5362), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283445] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9271), 1,
      anon_sym_AT,
    STATE(5400), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6367), 1,
      sym_annotation,
    STATE(5363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283494] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1338), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9318), 1,
      anon_sym_LPAREN,
    ACTIONS(10054), 1,
      anon_sym_DOT,
    ACTIONS(10056), 1,
      sym_operator_identifier,
    STATE(1695), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5364), 2,
      sym_comment,
      sym_block_comment,
    STATE(8493), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8807), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [283561] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10060), 1,
      anon_sym_end,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(10064), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15868), 1,
      sym_identifier,
    STATE(5365), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(834), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [283614] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9037), 1,
      anon_sym_AT,
    STATE(5269), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6590), 1,
      sym_annotation,
    STATE(5366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283663] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283706] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10060), 1,
      anon_sym_end,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(10066), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16001), 1,
      sym_identifier,
    STATE(5368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(834), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [283759] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9078), 1,
      anon_sym_AT,
    STATE(5407), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6410), 1,
      sym_annotation,
    STATE(5369), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [283808] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1338), 1,
      anon_sym_LBRACE,
    ACTIONS(9318), 1,
      anon_sym_LPAREN,
    ACTIONS(10054), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5370), 2,
      sym_comment,
      sym_block_comment,
    STATE(8493), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [283863] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10060), 1,
      anon_sym_end,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(10068), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15853), 1,
      sym_identifier,
    STATE(5371), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(834), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [283916] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10070), 1,
      anon_sym_DOT,
    STATE(5372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283961] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10060), 1,
      anon_sym_end,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(10072), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16108), 1,
      sym_identifier,
    STATE(5373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(834), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [284014] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1338), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9318), 1,
      anon_sym_LPAREN,
    ACTIONS(10054), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5374), 2,
      sym_comment,
      sym_block_comment,
    STATE(8493), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [284071] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5375), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284114] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5376), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284157] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8967), 1,
      sym_interpolated_string,
    STATE(14910), 1,
      sym__interpolated_string_start,
    STATE(14911), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10074), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5377), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [284212] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [284255] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9236), 1,
      anon_sym_AT,
    STATE(5389), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6659), 1,
      sym_annotation,
    STATE(5379), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284304] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9281), 1,
      anon_sym_AT,
    STATE(5431), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6471), 1,
      sym_annotation,
    STATE(5380), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [284353] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10076), 1,
      anon_sym_LBRACK,
    ACTIONS(10078), 1,
      anon_sym_AT,
    ACTIONS(10080), 1,
      anon_sym_LPAREN,
    ACTIONS(10082), 1,
      anon_sym_POUND,
    STATE(6783), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7868), 1,
      sym_type_arguments,
    STATE(8392), 1,
      sym_annotation,
    STATE(9557), 1,
      sym_arguments,
    STATE(5381), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [284412] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5382), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284455] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10084), 1,
      anon_sym_COLON,
    ACTIONS(10086), 1,
      anon_sym_LBRACE,
    ACTIONS(10088), 1,
      anon_sym_with,
    STATE(5397), 1,
      aux_sym_compound_type_repeat1,
    STATE(10070), 1,
      sym_template_body,
    STATE(10071), 1,
      sym__refinement,
    STATE(5383), 2,
      sym_comment,
      sym_block_comment,
    STATE(9929), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [284512] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284555] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10090), 1,
      anon_sym_with,
    STATE(5807), 1,
      aux_sym_compound_type_repeat1,
    STATE(9557), 1,
      sym_arguments,
    STATE(9648), 1,
      sym_template_body,
    STATE(9649), 1,
      sym__refinement,
    STATE(5385), 2,
      sym_comment,
      sym_block_comment,
    STATE(5571), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [284610] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5386), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284653] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5387), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284696] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10060), 1,
      anon_sym_end,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(10092), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16069), 1,
      sym_identifier,
    STATE(5388), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(834), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [284749] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10094), 1,
      anon_sym_AT,
    STATE(6659), 1,
      sym_annotation,
    STATE(5389), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284796] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10084), 1,
      anon_sym_COLON,
    ACTIONS(10086), 1,
      anon_sym_LBRACE,
    ACTIONS(10088), 1,
      anon_sym_with,
    STATE(5397), 1,
      aux_sym_compound_type_repeat1,
    STATE(10070), 1,
      sym_template_body,
    STATE(10071), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5390), 2,
      sym_comment,
      sym_block_comment,
    STATE(9929), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8412), 5,
      anon_sym_while,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [284859] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9584), 1,
      anon_sym_LBRACK,
    ACTIONS(9588), 1,
      anon_sym_POUND,
    ACTIONS(10097), 1,
      anon_sym_AT,
    STATE(6272), 1,
      sym_type_arguments,
    STATE(6518), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7725), 1,
      sym_annotation,
    STATE(5391), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [284914] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5392), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284957] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5393), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285000] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5394), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285043] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285086] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285129] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10084), 1,
      anon_sym_COLON,
    ACTIONS(10086), 1,
      anon_sym_LBRACE,
    ACTIONS(10088), 1,
      anon_sym_with,
    STATE(7982), 1,
      aux_sym_compound_type_repeat1,
    STATE(9850), 1,
      sym__refinement,
    STATE(10070), 1,
      sym_template_body,
    STATE(5397), 2,
      sym_comment,
      sym_block_comment,
    STATE(9929), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [285186] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285229] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10101), 1,
      anon_sym_LBRACK,
    ACTIONS(10103), 1,
      sym__backquoted_id,
    STATE(6434), 1,
      sym_access_qualifier,
    STATE(5399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10099), 25,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [285276] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10105), 1,
      anon_sym_AT,
    STATE(6367), 1,
      sym_annotation,
    STATE(5400), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285323] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [285366] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10108), 1,
      anon_sym_LBRACK,
    ACTIONS(10110), 1,
      anon_sym_LPAREN,
    ACTIONS(10112), 1,
      anon_sym_POUND,
    STATE(6401), 1,
      aux_sym_annotation_repeat1,
    STATE(7088), 1,
      sym_type_arguments,
    STATE(7830), 1,
      sym_arguments,
    STATE(5402), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [285421] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285464] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [285507] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(9717), 1,
      sym_interpolated_string,
    STATE(15257), 1,
      sym__interpolated_string_start,
    STATE(15276), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10114), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5405), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [285562] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285605] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10116), 1,
      anon_sym_AT,
    STATE(6410), 1,
      sym_annotation,
    STATE(5407), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [285652] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5408), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [285695] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285738] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10119), 1,
      anon_sym_LBRACK,
    ACTIONS(10121), 1,
      anon_sym_AT,
    ACTIONS(10123), 1,
      anon_sym_LPAREN,
    ACTIONS(10125), 1,
      anon_sym_POUND,
    STATE(7086), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7442), 1,
      sym_type_arguments,
    STATE(8444), 1,
      sym_annotation,
    STATE(9621), 1,
      sym_arguments,
    STATE(5410), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [285797] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5411), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285840] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285883] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5413), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285926] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5769), 1,
      sym__end_marker,
    STATE(5414), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285971] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5415), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [286014] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9335), 1,
      anon_sym_AT,
    STATE(5447), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6574), 1,
      sym_annotation,
    STATE(5416), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [286063] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [286106] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10131), 1,
      anon_sym_with,
    STATE(5630), 1,
      aux_sym_compound_type_repeat1,
    STATE(9439), 1,
      sym_template_body,
    STATE(9441), 1,
      sym__refinement,
    STATE(9538), 1,
      sym_arguments,
    STATE(5418), 2,
      sym_comment,
      sym_block_comment,
    STATE(5972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [286161] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [286204] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [286247] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [286290] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5422), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [286335] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5423), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [286378] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10133), 1,
      anon_sym_LBRACK,
    ACTIONS(10135), 1,
      anon_sym_LPAREN,
    ACTIONS(10137), 1,
      anon_sym_POUND,
    STATE(7152), 1,
      sym_type_arguments,
    STATE(7249), 1,
      aux_sym_annotation_repeat1,
    STATE(8349), 1,
      sym_arguments,
    STATE(5424), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [286433] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9601), 1,
      anon_sym_LBRACK,
    ACTIONS(9605), 1,
      anon_sym_POUND,
    ACTIONS(10139), 1,
      anon_sym_AT,
    STATE(6542), 1,
      sym_type_arguments,
    STATE(6625), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7958), 1,
      sym_annotation,
    STATE(5425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [286488] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5426), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [286531] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5427), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [286574] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5428), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [286617] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9778), 1,
      anon_sym_COLON,
    ACTIONS(9780), 1,
      anon_sym_LBRACE,
    ACTIONS(9782), 1,
      anon_sym_with,
    STATE(5148), 1,
      aux_sym_compound_type_repeat1,
    STATE(9734), 1,
      sym__refinement,
    STATE(9782), 1,
      sym_template_body,
    STATE(5429), 2,
      sym_comment,
      sym_block_comment,
    STATE(9798), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [286674] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5430), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [286717] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10141), 1,
      anon_sym_AT,
    STATE(6471), 1,
      sym_annotation,
    STATE(5431), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [286764] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5432), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [286807] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5433), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [286850] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5434), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [286893] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5435), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [286936] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5436), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [286979] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9778), 1,
      anon_sym_COLON,
    ACTIONS(9780), 1,
      anon_sym_LBRACE,
    ACTIONS(9782), 1,
      anon_sym_with,
    STATE(5148), 1,
      aux_sym_compound_type_repeat1,
    STATE(9734), 1,
      sym__refinement,
    STATE(9782), 1,
      sym_template_body,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5437), 2,
      sym_comment,
      sym_block_comment,
    STATE(9798), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_STAR,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [287042] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [287085] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5439), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [287128] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(9027), 1,
      sym_interpolated_string,
    STATE(15042), 1,
      sym__interpolated_string_start,
    STATE(15045), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10144), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5440), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [287183] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5441), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [287226] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9429), 1,
      anon_sym_with,
    STATE(7917), 1,
      aux_sym_compound_type_repeat1,
    STATE(9192), 1,
      sym_template_body,
    STATE(9202), 1,
      sym__refinement,
    STATE(5352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5442), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8252), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [287279] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(9467), 1,
      sym_interpolated_string,
    STATE(15127), 1,
      sym__interpolated_string_start,
    STATE(15128), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10146), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5443), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [287334] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10148), 1,
      anon_sym_LBRACK,
    ACTIONS(10150), 1,
      anon_sym_LPAREN,
    ACTIONS(10152), 1,
      anon_sym_POUND,
    STATE(7230), 1,
      sym_type_arguments,
    STATE(7314), 1,
      aux_sym_annotation_repeat1,
    STATE(8527), 1,
      sym_arguments,
    STATE(5444), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [287389] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5445), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [287432] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9610), 1,
      anon_sym_LBRACK,
    ACTIONS(9614), 1,
      anon_sym_POUND,
    ACTIONS(10154), 1,
      anon_sym_AT,
    STATE(6052), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6392), 1,
      sym_type_arguments,
    STATE(7467), 1,
      sym_annotation,
    STATE(5446), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [287487] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10156), 1,
      anon_sym_AT,
    STATE(6574), 1,
      sym_annotation,
    STATE(5447), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [287534] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9559), 1,
      anon_sym_LBRACK,
    ACTIONS(9561), 1,
      anon_sym_AT,
    ACTIONS(9565), 1,
      anon_sym_POUND,
    STATE(6102), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7125), 1,
      sym_type_arguments,
    STATE(7691), 1,
      sym_annotation,
    STATE(5448), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [287589] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9719), 1,
      anon_sym_COLON,
    ACTIONS(9721), 1,
      anon_sym_LBRACE,
    ACTIONS(9723), 1,
      anon_sym_with,
    STATE(5302), 1,
      aux_sym_compound_type_repeat1,
    STATE(10054), 1,
      sym_template_body,
    STATE(10055), 1,
      sym__refinement,
    STATE(5449), 2,
      sym_comment,
      sym_block_comment,
    STATE(10078), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [287646] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9423), 1,
      anon_sym_LBRACK,
    ACTIONS(9427), 1,
      anon_sym_POUND,
    ACTIONS(10159), 1,
      anon_sym_AT,
    STATE(6315), 1,
      sym_type_arguments,
    STATE(6677), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8213), 1,
      sym_annotation,
    STATE(5450), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [287701] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [287744] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5452), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [287787] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9465), 1,
      anon_sym_LBRACK,
    ACTIONS(9469), 1,
      anon_sym_POUND,
    ACTIONS(10161), 1,
      anon_sym_AT,
    STATE(6033), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6626), 1,
      sym_type_arguments,
    STATE(7969), 1,
      sym_annotation,
    STATE(5453), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [287842] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10163), 1,
      anon_sym_LBRACK,
    ACTIONS(10165), 1,
      anon_sym_AT,
    ACTIONS(10167), 1,
      anon_sym_LPAREN,
    ACTIONS(10169), 1,
      anon_sym_POUND,
    STATE(6828), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7993), 1,
      sym_type_arguments,
    STATE(8391), 1,
      sym_annotation,
    STATE(9538), 1,
      sym_arguments,
    STATE(5454), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [287901] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [287944] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5456), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [287989] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5457), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [288034] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5458), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [288079] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9264), 1,
      anon_sym_LPAREN,
    STATE(5280), 1,
      aux_sym_annotation_repeat1,
    STATE(6633), 1,
      sym_arguments,
    STATE(5459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [288128] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9883), 1,
      anon_sym_COLON,
    ACTIONS(9885), 1,
      anon_sym_LBRACE,
    ACTIONS(9887), 1,
      anon_sym_with,
    STATE(5233), 1,
      aux_sym_compound_type_repeat1,
    STATE(9952), 1,
      sym__refinement,
    STATE(9959), 1,
      sym_template_body,
    STATE(5460), 2,
      sym_comment,
      sym_block_comment,
    STATE(9773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [288185] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5461), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [288228] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10171), 1,
      anon_sym_DOT,
    STATE(5462), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [288273] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10173), 1,
      anon_sym_with,
    STATE(5463), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [288318] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10176), 1,
      anon_sym_LBRACK,
    ACTIONS(10178), 1,
      anon_sym_LPAREN,
    ACTIONS(10180), 1,
      anon_sym_POUND,
    STATE(6526), 1,
      aux_sym_annotation_repeat1,
    STATE(7089), 1,
      sym_type_arguments,
    STATE(7774), 1,
      sym_arguments,
    STATE(5464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [288373] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [288415] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10182), 1,
      anon_sym_with,
    STATE(5466), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [288459] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10185), 1,
      anon_sym_COLON,
    ACTIONS(10187), 1,
      anon_sym_LBRACE,
    ACTIONS(10189), 1,
      anon_sym_with,
    STATE(5599), 1,
      aux_sym_compound_type_repeat1,
    STATE(10238), 1,
      sym__refinement,
    STATE(10299), 1,
      sym_template_body,
    STATE(5467), 2,
      sym_comment,
      sym_block_comment,
    STATE(10207), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [288515] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [288557] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5469), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [288599] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [288641] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5471), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [288683] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5472), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [288725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [288767] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [288809] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10191), 1,
      anon_sym_LBRACK,
    ACTIONS(10193), 1,
      anon_sym_LPAREN,
    ACTIONS(10195), 1,
      anon_sym_POUND,
    STATE(7278), 1,
      aux_sym_annotation_repeat1,
    STATE(7549), 1,
      sym_type_arguments,
    STATE(8428), 1,
      sym_arguments,
    STATE(5475), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [288863] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9316), 1,
      anon_sym_AT,
    STATE(5773), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6676), 1,
      sym_annotation,
    STATE(5476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [288911] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9505), 1,
      anon_sym_LPAREN,
    STATE(5478), 1,
      aux_sym_annotation_repeat1,
    STATE(7124), 1,
      sym_arguments,
    STATE(5477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [288959] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10197), 1,
      anon_sym_LPAREN,
    STATE(7124), 1,
      sym_arguments,
    STATE(5478), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [289005] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6374), 1,
      sym_arguments,
    STATE(5479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [289049] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5480), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [289091] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [289133] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9669), 1,
      anon_sym_AT,
    STATE(5552), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6781), 1,
      sym_annotation,
    STATE(5482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [289181] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5483), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [289223] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5484), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [289267] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [289309] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5486), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [289351] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [289393] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5488), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [289435] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [289477] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9675), 1,
      anon_sym_AT,
    STATE(5574), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6796), 1,
      sym_annotation,
    STATE(5490), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [289525] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [289567] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [289609] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5493), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [289651] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5494), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [289693] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5495), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [289735] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5496), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [289777] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5497), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [289819] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5498), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [289861] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [289903] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5500), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [289945] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10200), 1,
      anon_sym_with,
    STATE(5501), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [289989] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9090), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [290031] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10203), 1,
      anon_sym_DOT,
    STATE(5503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [290075] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5504), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [290117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5505), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [290159] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [290201] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5507), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [290243] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10185), 1,
      anon_sym_COLON,
    ACTIONS(10187), 1,
      anon_sym_LBRACE,
    ACTIONS(10189), 1,
      anon_sym_with,
    STATE(5599), 1,
      aux_sym_compound_type_repeat1,
    STATE(10238), 1,
      sym__refinement,
    STATE(10299), 1,
      sym_template_body,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5508), 2,
      sym_comment,
      sym_block_comment,
    STATE(10207), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8412), 3,
      anon_sym_case,
      anon_sym_if,
      anon_sym_finally,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [290305] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5509), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [290347] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5510), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [290389] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5511), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [290431] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [290473] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [290515] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5514), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [290557] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5515), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [290599] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5516), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [290641] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [290683] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [290725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5519), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [290767] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5520), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [290809] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [290851] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5522), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [290893] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5523), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [290935] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [290977] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5525), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [291019] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [291061] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5527), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [291103] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [291145] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5529), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [291187] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [291229] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5531), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [291271] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [291313] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5533), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [291355] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5534), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [291397] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10205), 1,
      anon_sym_COLON,
    ACTIONS(10207), 1,
      anon_sym_LBRACE,
    ACTIONS(10209), 1,
      anon_sym_with,
    STATE(5825), 1,
      aux_sym_compound_type_repeat1,
    STATE(10417), 1,
      sym_template_body,
    STATE(10426), 1,
      sym__refinement,
    STATE(5535), 2,
      sym_comment,
      sym_block_comment,
    STATE(10171), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [291453] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [291497] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5537), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [291539] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [291581] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(9856), 1,
      sym_interpolated_string,
    STATE(15258), 1,
      sym__interpolated_string_start,
    STATE(15263), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10211), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5539), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [291635] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [291677] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5541), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [291719] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [291761] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5543), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [291803] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [291845] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10213), 1,
      anon_sym_COLON,
    ACTIONS(10215), 1,
      anon_sym_LBRACE,
    ACTIONS(10217), 1,
      anon_sym_with,
    STATE(5731), 1,
      aux_sym_compound_type_repeat1,
    STATE(10330), 1,
      sym_template_body,
    STATE(10344), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5545), 2,
      sym_comment,
      sym_block_comment,
    STATE(10379), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8412), 3,
      anon_sym_STAR,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [291907] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10108), 1,
      anon_sym_LBRACK,
    ACTIONS(10112), 1,
      anon_sym_POUND,
    ACTIONS(10219), 1,
      anon_sym_AT,
    STATE(6995), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7088), 1,
      sym_type_arguments,
    STATE(8682), 1,
      sym_annotation,
    STATE(5546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [291961] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10221), 1,
      anon_sym_DOT,
    STATE(5547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [292005] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [292047] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [292089] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [292131] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9139), 1,
      anon_sym_LPAREN,
    STATE(4401), 1,
      sym_arguments,
    STATE(5827), 1,
      aux_sym_annotation_repeat1,
    STATE(5551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 24,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [292177] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10223), 1,
      anon_sym_AT,
    STATE(6781), 1,
      sym_annotation,
    STATE(5552), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [292223] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10226), 1,
      anon_sym_COLON,
    ACTIONS(10229), 1,
      anon_sym_EQ_GT,
    ACTIONS(10231), 1,
      anon_sym_QMARK_EQ_GT,
    STATE(9512), 1,
      sym_interpolated_string,
    STATE(15002), 1,
      sym__interpolated_string_start,
    STATE(15006), 1,
      sym__interpolated_multiline_string_start,
    STATE(17044), 1,
      sym__self_type_ascription,
    STATE(5553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [292283] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [292325] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9603), 1,
      anon_sym_LPAREN,
    STATE(5560), 1,
      aux_sym_annotation_repeat1,
    STATE(7346), 1,
      sym_arguments,
    STATE(5555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8426), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [292373] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(9512), 1,
      sym_interpolated_string,
    STATE(15002), 1,
      sym__interpolated_string_start,
    STATE(15006), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10233), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5556), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [292427] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1044), 1,
      anon_sym_LBRACE,
    ACTIONS(8731), 1,
      anon_sym_LPAREN,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9131), 1,
      anon_sym_DOT,
    ACTIONS(10235), 1,
      sym__alpha_identifier,
    ACTIONS(10239), 1,
      anon_sym_EQ,
    ACTIONS(10241), 1,
      sym__backquoted_id,
    ACTIONS(10243), 1,
      sym_operator_identifier,
    STATE(533), 1,
      sym_identifier,
    STATE(4027), 1,
      sym__soft_identifier,
    STATE(5557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(6706), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9367), 5,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(10237), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [292493] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1194), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9218), 1,
      anon_sym_LPAREN,
    ACTIONS(9928), 1,
      anon_sym_DOT,
    ACTIONS(10245), 1,
      sym__alpha_identifier,
    ACTIONS(10249), 1,
      anon_sym_EQ,
    ACTIONS(10251), 1,
      sym__backquoted_id,
    ACTIONS(10253), 1,
      sym_operator_identifier,
    STATE(538), 1,
      sym_identifier,
    STATE(4045), 1,
      sym__soft_identifier,
    STATE(5558), 2,
      sym_comment,
      sym_block_comment,
    STATE(8407), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10247), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [292559] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1080), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8847), 1,
      anon_sym_LPAREN,
    ACTIONS(9232), 1,
      anon_sym_DOT,
    ACTIONS(10255), 1,
      sym__alpha_identifier,
    ACTIONS(10259), 1,
      anon_sym_EQ,
    ACTIONS(10261), 1,
      sym__backquoted_id,
    ACTIONS(10263), 1,
      sym_operator_identifier,
    STATE(534), 1,
      sym_identifier,
    STATE(4030), 1,
      sym__soft_identifier,
    STATE(5559), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(6886), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9367), 5,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(10257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [292625] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10265), 1,
      anon_sym_LPAREN,
    STATE(7346), 1,
      sym_arguments,
    STATE(5560), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8430), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [292671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5561), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [292713] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1338), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9318), 1,
      anon_sym_LPAREN,
    ACTIONS(10054), 1,
      anon_sym_DOT,
    ACTIONS(10268), 1,
      sym__alpha_identifier,
    ACTIONS(10272), 1,
      anon_sym_EQ,
    ACTIONS(10274), 1,
      sym__backquoted_id,
    ACTIONS(10276), 1,
      sym_operator_identifier,
    STATE(543), 1,
      sym_identifier,
    STATE(4041), 1,
      sym__soft_identifier,
    STATE(5562), 2,
      sym_comment,
      sym_block_comment,
    STATE(8493), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(10270), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [292779] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10278), 1,
      anon_sym_COLON,
    ACTIONS(10280), 1,
      anon_sym_LBRACE,
    ACTIONS(10282), 1,
      anon_sym_with,
    STATE(8183), 1,
      aux_sym_compound_type_repeat1,
    STATE(10264), 1,
      sym_template_body,
    STATE(10398), 1,
      sym__refinement,
    STATE(5563), 2,
      sym_comment,
      sym_block_comment,
    STATE(10205), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [292835] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10284), 1,
      anon_sym_COLON,
    ACTIONS(10286), 1,
      anon_sym_LBRACE,
    ACTIONS(10288), 1,
      anon_sym_with,
    STATE(8131), 1,
      aux_sym_compound_type_repeat1,
    STATE(9908), 1,
      sym_template_body,
    STATE(9948), 1,
      sym__refinement,
    STATE(5564), 2,
      sym_comment,
      sym_block_comment,
    STATE(10043), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [292891] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(7773), 1,
      sym_interpolated_string,
    STATE(15213), 1,
      sym__interpolated_string_start,
    STATE(15214), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10290), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5565), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [292945] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10278), 1,
      anon_sym_COLON,
    ACTIONS(10280), 1,
      anon_sym_LBRACE,
    ACTIONS(10282), 1,
      anon_sym_with,
    STATE(5563), 1,
      aux_sym_compound_type_repeat1,
    STATE(10264), 1,
      sym_template_body,
    STATE(10272), 1,
      sym__refinement,
    STATE(5566), 2,
      sym_comment,
      sym_block_comment,
    STATE(10205), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293001] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5567), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [293043] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [293085] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [293127] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5570), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [293169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [293211] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10292), 1,
      anon_sym_DOT,
    STATE(5572), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293255] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9580), 1,
      anon_sym_AT,
    STATE(5918), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6700), 1,
      sym_annotation,
    STATE(5573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293303] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10294), 1,
      anon_sym_AT,
    STATE(6796), 1,
      sym_annotation,
    STATE(5574), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293349] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [293391] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(7598), 1,
      sym_interpolated_string,
    STATE(15304), 1,
      sym__interpolated_string_start,
    STATE(15305), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10297), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293445] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 1,
      anon_sym_AT,
    STATE(5617), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7288), 1,
      sym_annotation,
    STATE(5577), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [293493] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [293535] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293577] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(9512), 1,
      sym_interpolated_string,
    STATE(15002), 1,
      sym__interpolated_string_start,
    STATE(15006), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10299), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5580), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293631] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1044), 1,
      anon_sym_LBRACE,
    ACTIONS(8731), 1,
      anon_sym_LPAREN,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9131), 1,
      anon_sym_DOT,
    ACTIONS(10235), 1,
      sym__alpha_identifier,
    ACTIONS(10241), 1,
      sym__backquoted_id,
    ACTIONS(10243), 1,
      sym_operator_identifier,
    ACTIONS(10301), 1,
      anon_sym_EQ,
    STATE(533), 1,
      sym_identifier,
    STATE(4027), 1,
      sym__soft_identifier,
    STATE(5581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
    STATE(6706), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(10237), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [293697] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1080), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8847), 1,
      anon_sym_LPAREN,
    ACTIONS(9232), 1,
      anon_sym_DOT,
    ACTIONS(10255), 1,
      sym__alpha_identifier,
    ACTIONS(10261), 1,
      sym__backquoted_id,
    ACTIONS(10263), 1,
      sym_operator_identifier,
    ACTIONS(10303), 1,
      anon_sym_EQ,
    STATE(534), 1,
      sym_identifier,
    STATE(4030), 1,
      sym__soft_identifier,
    STATE(5582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
    STATE(6886), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(10257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [293763] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5583), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [293805] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5584), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [293847] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(7773), 1,
      sym_interpolated_string,
    STATE(15213), 1,
      sym__interpolated_string_start,
    STATE(15214), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10305), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5585), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293901] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [293943] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5587), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293987] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5588), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9086), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [294029] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5589), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294071] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294113] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10323), 1,
      anon_sym_RPAREN,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10970), 1,
      sym_interpolated_string,
    STATE(15473), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(15611), 1,
      sym__interpolated_string_start,
    STATE(15612), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10321), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(5591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [294193] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5593), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294279] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10331), 1,
      anon_sym_AT,
    STATE(7329), 1,
      sym_annotation,
    STATE(5594), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8931), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [294325] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294367] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294409] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10334), 1,
      anon_sym_DOT,
    STATE(5597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [294453] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9727), 1,
      anon_sym_LBRACK,
    ACTIONS(9731), 1,
      anon_sym_POUND,
    ACTIONS(10336), 1,
      anon_sym_AT,
    STATE(6766), 1,
      sym_type_arguments,
    STATE(7108), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8212), 1,
      sym_annotation,
    STATE(5598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [294507] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10185), 1,
      anon_sym_COLON,
    ACTIONS(10187), 1,
      anon_sym_LBRACE,
    ACTIONS(10189), 1,
      anon_sym_with,
    STATE(8288), 1,
      aux_sym_compound_type_repeat1,
    STATE(10166), 1,
      sym__refinement,
    STATE(10299), 1,
      sym_template_body,
    STATE(5599), 2,
      sym_comment,
      sym_block_comment,
    STATE(10207), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [294563] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294605] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [294647] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5602), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [294691] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5603), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9098), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [294733] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294775] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294817] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5606), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [294859] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5607), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_as,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [294901] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294943] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5609), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294985] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5610), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [295027] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5611), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [295069] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [295111] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10205), 1,
      anon_sym_COLON,
    ACTIONS(10207), 1,
      anon_sym_LBRACE,
    ACTIONS(10209), 1,
      anon_sym_with,
    STATE(5825), 1,
      aux_sym_compound_type_repeat1,
    STATE(10417), 1,
      sym_template_body,
    STATE(10426), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5613), 2,
      sym_comment,
      sym_block_comment,
    STATE(10171), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8412), 3,
      anon_sym_STAR,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [295173] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9612), 1,
      anon_sym_LPAREN,
    STATE(5828), 1,
      aux_sym_annotation_repeat1,
    STATE(7299), 1,
      sym_arguments,
    STATE(5614), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [295221] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9708), 1,
      anon_sym_LBRACK,
    ACTIONS(9712), 1,
      anon_sym_POUND,
    ACTIONS(10338), 1,
      anon_sym_AT,
    STATE(6822), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7254), 1,
      sym_type_arguments,
    STATE(8164), 1,
      sym_annotation,
    STATE(5615), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [295275] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10340), 1,
      anon_sym_with,
    STATE(6042), 1,
      aux_sym_compound_type_repeat1,
    STATE(9761), 1,
      sym_template_body,
    STATE(9765), 1,
      sym__refinement,
    STATE(9860), 1,
      sym_arguments,
    STATE(5616), 2,
      sym_comment,
      sym_block_comment,
    STATE(6450), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [295329] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10342), 1,
      anon_sym_AT,
    STATE(7288), 1,
      sym_annotation,
    STATE(5617), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [295375] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10119), 1,
      anon_sym_LBRACK,
    ACTIONS(10125), 1,
      anon_sym_POUND,
    ACTIONS(10345), 1,
      anon_sym_LPAREN,
    STATE(6752), 1,
      aux_sym_annotation_repeat1,
    STATE(7442), 1,
      sym_type_arguments,
    STATE(8557), 1,
      sym_arguments,
    STATE(5618), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8154), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [295429] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9685), 1,
      anon_sym_DOT,
    ACTIONS(10347), 1,
      anon_sym_EQ_GT,
    STATE(5619), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [295475] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [295517] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5621), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [295559] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10024), 1,
      anon_sym_with,
    STATE(8340), 1,
      aux_sym_compound_type_repeat1,
    STATE(9484), 1,
      sym__refinement,
    STATE(9728), 1,
      sym_template_body,
    STATE(5622), 2,
      sym_comment,
      sym_block_comment,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8246), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [295611] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5623), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [295653] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5624), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [295695] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [295737] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [295779] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [295821] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [295863] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10349), 1,
      anon_sym_COLON,
    ACTIONS(10352), 1,
      anon_sym_LBRACE,
    STATE(7756), 1,
      sym_template_body,
    STATE(5629), 2,
      sym_comment,
      sym_block_comment,
    STATE(7553), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 14,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [295913] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10131), 1,
      anon_sym_with,
    STATE(8675), 1,
      aux_sym_compound_type_repeat1,
    STATE(9439), 1,
      sym_template_body,
    STATE(9594), 1,
      sym__refinement,
    STATE(5630), 2,
      sym_comment,
      sym_block_comment,
    STATE(5972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [295965] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [296007] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [296049] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9698), 1,
      anon_sym_DOT,
    ACTIONS(10355), 1,
      anon_sym_EQ_GT,
    STATE(5633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [296095] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [296137] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [296179] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5636), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [296221] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [296263] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1194), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9218), 1,
      anon_sym_LPAREN,
    ACTIONS(9928), 1,
      anon_sym_DOT,
    ACTIONS(10245), 1,
      sym__alpha_identifier,
    ACTIONS(10251), 1,
      sym__backquoted_id,
    ACTIONS(10253), 1,
      sym_operator_identifier,
    ACTIONS(10357), 1,
      anon_sym_EQ,
    STATE(538), 1,
      sym_identifier,
    STATE(4045), 1,
      sym__soft_identifier,
    STATE(5638), 2,
      sym_comment,
      sym_block_comment,
    STATE(8407), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_case,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10247), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [296329] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9632), 1,
      anon_sym_LPAREN,
    STATE(5669), 1,
      aux_sym_annotation_repeat1,
    STATE(6663), 1,
      sym_arguments,
    STATE(5639), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [296377] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10359), 1,
      anon_sym_LBRACK,
    ACTIONS(10361), 1,
      anon_sym_AT,
    ACTIONS(10363), 1,
      anon_sym_LPAREN,
    ACTIONS(10365), 1,
      anon_sym_POUND,
    STATE(7463), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8143), 1,
      sym_type_arguments,
    STATE(8953), 1,
      sym_annotation,
    STATE(9860), 1,
      sym_arguments,
    STATE(5640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [296435] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1230), 1,
      anon_sym_LBRACE,
    ACTIONS(9455), 1,
      anon_sym_LPAREN,
    ACTIONS(10367), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5641), 2,
      sym_comment,
      sym_block_comment,
    STATE(9170), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [296489] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5642), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [296531] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [296573] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10163), 1,
      anon_sym_LBRACK,
    ACTIONS(10169), 1,
      anon_sym_POUND,
    ACTIONS(10369), 1,
      anon_sym_LPAREN,
    STATE(6793), 1,
      aux_sym_annotation_repeat1,
    STATE(7993), 1,
      sym_type_arguments,
    STATE(8122), 1,
      sym_arguments,
    STATE(5644), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [296627] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1230), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9455), 1,
      anon_sym_LPAREN,
    ACTIONS(10367), 1,
      anon_sym_DOT,
    ACTIONS(10371), 1,
      sym_operator_identifier,
    STATE(1754), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5645), 2,
      sym_comment,
      sym_block_comment,
    STATE(9170), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8807), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [296693] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10133), 1,
      anon_sym_LBRACK,
    ACTIONS(10137), 1,
      anon_sym_POUND,
    ACTIONS(10373), 1,
      anon_sym_AT,
    STATE(7152), 1,
      sym_type_arguments,
    STATE(7630), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9066), 1,
      sym_annotation,
    STATE(5646), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [296747] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [296789] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1230), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9455), 1,
      anon_sym_LPAREN,
    ACTIONS(10367), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5648), 2,
      sym_comment,
      sym_block_comment,
    STATE(9170), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [296845] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [296887] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [296929] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10226), 1,
      anon_sym_COLON,
    ACTIONS(10231), 1,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(10375), 1,
      anon_sym_EQ_GT,
    STATE(9512), 1,
      sym_interpolated_string,
    STATE(15002), 1,
      sym__interpolated_string_start,
    STATE(15006), 1,
      sym__interpolated_multiline_string_start,
    STATE(16353), 1,
      sym__self_type_ascription,
    STATE(5651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [296989] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [297031] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [297073] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9930), 1,
      anon_sym_LBRACK,
    ACTIONS(9934), 1,
      anon_sym_POUND,
    ACTIONS(10377), 1,
      anon_sym_AT,
    STATE(6820), 1,
      sym_type_arguments,
    STATE(7489), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8995), 1,
      sym_annotation,
    STATE(5654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [297127] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1230), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9455), 1,
      anon_sym_LPAREN,
    ACTIONS(10367), 1,
      anon_sym_DOT,
    ACTIONS(10379), 1,
      sym__alpha_identifier,
    ACTIONS(10383), 1,
      anon_sym_EQ,
    ACTIONS(10385), 1,
      sym__backquoted_id,
    ACTIONS(10387), 1,
      sym_operator_identifier,
    STATE(539), 1,
      sym_identifier,
    STATE(4048), 1,
      sym__soft_identifier,
    STATE(5655), 2,
      sym_comment,
      sym_block_comment,
    STATE(9170), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10381), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [297193] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [297235] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10389), 1,
      anon_sym_DOT,
    STATE(5657), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [297279] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [297321] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5659), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [297363] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5660), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [297405] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5661), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [297447] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5662), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [297489] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5663), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9088), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [297531] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [297573] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10391), 1,
      anon_sym_DOT,
    STATE(5665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [297617] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10393), 1,
      anon_sym_LBRACK,
    ACTIONS(10395), 1,
      anon_sym_LPAREN,
    ACTIONS(10397), 1,
      anon_sym_POUND,
    STATE(6805), 1,
      aux_sym_annotation_repeat1,
    STATE(7388), 1,
      sym_type_arguments,
    STATE(8268), 1,
      sym_arguments,
    STATE(5666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [297671] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [297715] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5668), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [297757] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10399), 1,
      anon_sym_LPAREN,
    STATE(6663), 1,
      sym_arguments,
    STATE(5669), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [297803] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [297845] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [297889] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6433), 1,
      sym__end_marker,
    STATE(5672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [297933] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9980), 1,
      anon_sym_EQ_GT,
    STATE(5673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [297977] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [298019] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5675), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [298061] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [298103] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298145] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5678), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [298187] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298229] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5680), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [298271] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10410), 1,
      anon_sym_with,
    STATE(6591), 1,
      aux_sym_compound_type_repeat1,
    STATE(9762), 1,
      sym_arguments,
    STATE(9992), 1,
      sym_template_body,
    STATE(9993), 1,
      sym__refinement,
    STATE(5681), 2,
      sym_comment,
      sym_block_comment,
    STATE(6282), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [298325] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5682), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [298367] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298409] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5684), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298451] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298493] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5686), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298535] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298577] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298619] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10213), 1,
      anon_sym_COLON,
    ACTIONS(10215), 1,
      anon_sym_LBRACE,
    ACTIONS(10217), 1,
      anon_sym_with,
    STATE(5731), 1,
      aux_sym_compound_type_repeat1,
    STATE(10330), 1,
      sym_template_body,
    STATE(10344), 1,
      sym__refinement,
    STATE(5689), 2,
      sym_comment,
      sym_block_comment,
    STATE(10379), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [298675] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5690), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298717] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5691), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298759] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298801] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5693), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298843] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5694), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298885] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5695), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298927] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298969] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [299011] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [299053] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5699), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [299095] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5700), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [299137] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(9856), 1,
      sym_interpolated_string,
    STATE(15258), 1,
      sym__interpolated_string_start,
    STATE(15263), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [299191] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [299233] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5703), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [299275] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    STATE(5704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [299319] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10462), 1,
      anon_sym_DOT,
    STATE(5705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [299363] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [299405] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [299449] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10148), 1,
      anon_sym_LBRACK,
    ACTIONS(10152), 1,
      anon_sym_POUND,
    ACTIONS(10464), 1,
      anon_sym_AT,
    STATE(7230), 1,
      sym_type_arguments,
    STATE(7778), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9131), 1,
      sym_annotation,
    STATE(5708), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [299503] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9876), 1,
      anon_sym_with,
    STATE(8561), 1,
      aux_sym_compound_type_repeat1,
    STATE(8728), 1,
      sym_template_body,
    STATE(8733), 1,
      sym__refinement,
    STATE(5709), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [299555] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9339), 1,
      anon_sym_AT,
    STATE(5745), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6961), 1,
      sym_annotation,
    STATE(5710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8957), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [299603] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [299645] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9737), 1,
      anon_sym_LBRACK,
    ACTIONS(9741), 1,
      anon_sym_POUND,
    ACTIONS(10466), 1,
      anon_sym_AT,
    STATE(6825), 1,
      sym_type_arguments,
    STATE(7179), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8336), 1,
      sym_annotation,
    STATE(5712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [299699] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10468), 1,
      anon_sym_LBRACE,
    ACTIONS(10470), 1,
      anon_sym_with,
    STATE(5851), 1,
      aux_sym_compound_type_repeat1,
    STATE(9755), 1,
      sym_template_body,
    STATE(9757), 1,
      sym__refinement,
    STATE(5713), 2,
      sym_comment,
      sym_block_comment,
    STATE(10017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [299753] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10472), 1,
      anon_sym_AT,
    STATE(7364), 1,
      sym_annotation,
    STATE(5714), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [299799] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10475), 1,
      anon_sym_LBRACK,
    ACTIONS(10477), 1,
      anon_sym_AT,
    ACTIONS(10479), 1,
      anon_sym_LPAREN,
    ACTIONS(10481), 1,
      anon_sym_POUND,
    STATE(7979), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8464), 1,
      sym_type_arguments,
    STATE(9293), 1,
      sym_annotation,
    STATE(9762), 1,
      sym_arguments,
    STATE(5715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [299857] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [299899] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9412), 1,
      anon_sym_LPAREN,
    STATE(5739), 1,
      aux_sym_annotation_repeat1,
    STATE(6946), 1,
      sym_arguments,
    STATE(5717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [299947] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [299989] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5719), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [300033] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1808), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9515), 1,
      anon_sym_LPAREN,
    ACTIONS(10483), 1,
      anon_sym_DOT,
    ACTIONS(10485), 1,
      sym_operator_identifier,
    STATE(1793), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    STATE(8804), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8807), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [300099] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10468), 1,
      anon_sym_LBRACE,
    ACTIONS(10470), 1,
      anon_sym_with,
    ACTIONS(10487), 1,
      anon_sym_COLON,
    STATE(5851), 1,
      aux_sym_compound_type_repeat1,
    STATE(9755), 1,
      sym_template_body,
    STATE(9757), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5721), 2,
      sym_comment,
      sym_block_comment,
    STATE(10017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [300161] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9599), 1,
      anon_sym_LPAREN,
    STATE(5843), 1,
      aux_sym_annotation_repeat1,
    STATE(6826), 1,
      sym_arguments,
    STATE(5722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [300209] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300293] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [300335] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(10092), 1,
      sym_interpolated_string,
    STATE(14993), 1,
      sym__interpolated_string_start,
    STATE(14996), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10490), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5726), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [300389] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1808), 1,
      anon_sym_LBRACE,
    ACTIONS(9515), 1,
      anon_sym_LPAREN,
    ACTIONS(10483), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5727), 2,
      sym_comment,
      sym_block_comment,
    STATE(8804), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8831), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [300443] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1572), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9549), 1,
      anon_sym_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOT,
    ACTIONS(10494), 1,
      sym_operator_identifier,
    STATE(1743), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5728), 2,
      sym_comment,
      sym_block_comment,
    STATE(8852), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8807), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [300509] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300551] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300593] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10213), 1,
      anon_sym_COLON,
    ACTIONS(10215), 1,
      anon_sym_LBRACE,
    ACTIONS(10217), 1,
      anon_sym_with,
    STATE(8606), 1,
      aux_sym_compound_type_repeat1,
    STATE(10330), 1,
      sym_template_body,
    STATE(10401), 1,
      sym__refinement,
    STATE(5731), 2,
      sym_comment,
      sym_block_comment,
    STATE(10379), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [300649] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300691] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1808), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9515), 1,
      anon_sym_LPAREN,
    ACTIONS(10483), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5733), 2,
      sym_comment,
      sym_block_comment,
    STATE(8804), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8835), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [300747] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300789] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5735), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [300831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300873] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300915] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5738), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300957] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10516), 1,
      anon_sym_LPAREN,
    STATE(6946), 1,
      sym_arguments,
    STATE(5739), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [301003] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [301045] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [301087] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1572), 1,
      anon_sym_LBRACE,
    ACTIONS(9549), 1,
      anon_sym_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5742), 2,
      sym_comment,
      sym_block_comment,
    STATE(8852), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [301141] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [301183] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [301225] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10519), 1,
      anon_sym_AT,
    STATE(6961), 1,
      sym_annotation,
    STATE(5745), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8931), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [301271] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [301313] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1572), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9549), 1,
      anon_sym_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5747), 2,
      sym_comment,
      sym_block_comment,
    STATE(8852), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [301369] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10016), 1,
      anon_sym_EQ_GT,
    STATE(5748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [301413] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10076), 1,
      anon_sym_LBRACK,
    ACTIONS(10082), 1,
      anon_sym_POUND,
    ACTIONS(10526), 1,
      anon_sym_LPAREN,
    STATE(6684), 1,
      aux_sym_annotation_repeat1,
    STATE(7868), 1,
      sym_type_arguments,
    STATE(8272), 1,
      sym_arguments,
    STATE(5749), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [301467] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5750), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [301509] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [301551] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [301593] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5753), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [301637] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5754), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [301679] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5755), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [301721] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10528), 1,
      anon_sym_COLON,
    ACTIONS(10530), 1,
      anon_sym_LBRACE,
    ACTIONS(10532), 1,
      anon_sym_with,
    STATE(5982), 1,
      aux_sym_compound_type_repeat1,
    STATE(10419), 1,
      sym_template_body,
    STATE(10422), 1,
      sym__refinement,
    STATE(5756), 2,
      sym_comment,
      sym_block_comment,
    STATE(10358), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8406), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [301777] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5757), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [301819] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5758), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [301861] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [301903] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10534), 1,
      anon_sym_COLON,
    ACTIONS(10537), 1,
      anon_sym_LBRACE,
    STATE(7500), 1,
      sym_template_body,
    STATE(5760), 2,
      sym_comment,
      sym_block_comment,
    STATE(7459), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 15,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [301953] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1698), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9563), 1,
      anon_sym_LPAREN,
    ACTIONS(10540), 1,
      anon_sym_DOT,
    ACTIONS(10542), 1,
      sym_operator_identifier,
    STATE(1683), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5761), 2,
      sym_comment,
      sym_block_comment,
    STATE(8909), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8807), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [302019] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [302061] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9491), 1,
      anon_sym_LPAREN,
    STATE(5767), 1,
      aux_sym_annotation_repeat1,
    STATE(6996), 1,
      sym_arguments,
    STATE(5763), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8426), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [302109] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [302151] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5765), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [302193] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5766), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [302235] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10544), 1,
      anon_sym_LPAREN,
    STATE(6996), 1,
      sym_arguments,
    STATE(5767), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8430), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [302281] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5768), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [302323] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [302365] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1698), 1,
      anon_sym_LBRACE,
    ACTIONS(9563), 1,
      anon_sym_LPAREN,
    ACTIONS(10540), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5770), 2,
      sym_comment,
      sym_block_comment,
    STATE(8909), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [302419] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9743), 1,
      anon_sym_LBRACK,
    ACTIONS(9747), 1,
      anon_sym_POUND,
    ACTIONS(10547), 1,
      anon_sym_AT,
    STATE(7265), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7345), 1,
      sym_type_arguments,
    STATE(8512), 1,
      sym_annotation,
    STATE(5771), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [302473] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1698), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9563), 1,
      anon_sym_LPAREN,
    ACTIONS(10540), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(5772), 2,
      sym_comment,
      sym_block_comment,
    STATE(8909), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [302529] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10549), 1,
      anon_sym_AT,
    STATE(6676), 1,
      sym_annotation,
    STATE(5773), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [302575] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10552), 1,
      anon_sym_COLON,
    ACTIONS(10554), 1,
      anon_sym_LBRACE,
    ACTIONS(10556), 1,
      anon_sym_with,
    STATE(5925), 1,
      aux_sym_compound_type_repeat1,
    STATE(10349), 1,
      sym_template_body,
    STATE(10350), 1,
      sym__refinement,
    STATE(5774), 2,
      sym_comment,
      sym_block_comment,
    STATE(10157), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [302631] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [302673] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5776), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_as,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [302715] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9467), 1,
      anon_sym_LPAREN,
    STATE(5788), 1,
      aux_sym_annotation_repeat1,
    STATE(6949), 1,
      sym_arguments,
    STATE(5777), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [302763] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [302805] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10119), 1,
      anon_sym_LBRACK,
    ACTIONS(10121), 1,
      anon_sym_AT,
    ACTIONS(10125), 1,
      anon_sym_POUND,
    STATE(7086), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7442), 1,
      sym_type_arguments,
    STATE(8444), 1,
      sym_annotation,
    STATE(5779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [302859] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10558), 1,
      anon_sym_DOT,
    STATE(5780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [302903] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9525), 1,
      anon_sym_LPAREN,
    STATE(5785), 1,
      aux_sym_annotation_repeat1,
    STATE(7039), 1,
      sym_arguments,
    STATE(5781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8426), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [302951] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [302993] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [303037] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10560), 1,
      anon_sym_with,
    STATE(5784), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [303081] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10563), 1,
      anon_sym_LPAREN,
    STATE(7039), 1,
      sym_arguments,
    STATE(5785), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8430), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [303127] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [303169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [303211] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10566), 1,
      anon_sym_LPAREN,
    STATE(6949), 1,
      sym_arguments,
    STATE(5788), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [303257] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [303299] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [303341] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10552), 1,
      anon_sym_COLON,
    ACTIONS(10554), 1,
      anon_sym_LBRACE,
    ACTIONS(10556), 1,
      anon_sym_with,
    STATE(5925), 1,
      aux_sym_compound_type_repeat1,
    STATE(10349), 1,
      sym_template_body,
    STATE(10350), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5791), 2,
      sym_comment,
      sym_block_comment,
    STATE(10157), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8412), 3,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [303403] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9755), 1,
      anon_sym_LBRACK,
    ACTIONS(9759), 1,
      anon_sym_POUND,
    ACTIONS(10569), 1,
      anon_sym_AT,
    STATE(6860), 1,
      sym_type_arguments,
    STATE(7219), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8439), 1,
      sym_annotation,
    STATE(5792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [303457] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [303501] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10037), 1,
      anon_sym_EQ_GT,
    STATE(5794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [303545] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5795), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [303587] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [303629] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10278), 1,
      anon_sym_COLON,
    ACTIONS(10280), 1,
      anon_sym_LBRACE,
    ACTIONS(10282), 1,
      anon_sym_with,
    STATE(5563), 1,
      aux_sym_compound_type_repeat1,
    STATE(10264), 1,
      sym_template_body,
    STATE(10272), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5797), 2,
      sym_comment,
      sym_block_comment,
    STATE(10205), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8412), 3,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [303691] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5798), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [303733] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [303775] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [303817] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9966), 1,
      anon_sym_LBRACK,
    ACTIONS(9970), 1,
      anon_sym_POUND,
    ACTIONS(10571), 1,
      anon_sym_AT,
    STATE(6715), 1,
      sym_type_arguments,
    STATE(7996), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9109), 1,
      sym_annotation,
    STATE(5801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [303871] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [303913] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5803), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [303955] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5804), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [303997] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [304039] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5806), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [304081] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10090), 1,
      anon_sym_with,
    STATE(8232), 1,
      aux_sym_compound_type_repeat1,
    STATE(9648), 1,
      sym_template_body,
    STATE(9654), 1,
      sym__refinement,
    STATE(5571), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5807), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8252), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304175] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10585), 1,
      anon_sym_COLON,
    ACTIONS(10588), 1,
      anon_sym_LBRACE,
    STATE(7677), 1,
      sym_template_body,
    STATE(5809), 2,
      sym_comment,
      sym_block_comment,
    STATE(7638), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 7,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 15,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [304225] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5810), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304267] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10163), 1,
      anon_sym_LBRACK,
    ACTIONS(10165), 1,
      anon_sym_AT,
    ACTIONS(10169), 1,
      anon_sym_POUND,
    STATE(6828), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7993), 1,
      sym_type_arguments,
    STATE(8391), 1,
      sym_annotation,
    STATE(5811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304321] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9807), 1,
      anon_sym_DOT,
    ACTIONS(10591), 1,
      anon_sym_EQ_GT,
    STATE(5812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [304367] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304409] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5814), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304451] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5815), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [304493] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9790), 1,
      anon_sym_DOT,
    ACTIONS(10593), 1,
      anon_sym_EQ_GT,
    STATE(5816), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304539] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5817), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304581] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10595), 1,
      anon_sym_LBRACK,
    ACTIONS(10597), 1,
      anon_sym_LPAREN,
    ACTIONS(10599), 1,
      anon_sym_POUND,
    STATE(7043), 1,
      aux_sym_annotation_repeat1,
    STATE(7992), 1,
      sym_type_arguments,
    STATE(8604), 1,
      sym_arguments,
    STATE(5818), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304635] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10601), 1,
      anon_sym_COLON,
    ACTIONS(10603), 1,
      anon_sym_LBRACE,
    ACTIONS(10605), 1,
      anon_sym_with,
    STATE(8631), 1,
      aux_sym_compound_type_repeat1,
    STATE(10372), 1,
      sym_template_body,
    STATE(10410), 1,
      sym__refinement,
    STATE(5819), 2,
      sym_comment,
      sym_block_comment,
    STATE(10229), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304691] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304733] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [304775] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(972), 1,
      anon_sym_LBRACE,
    ACTIONS(8374), 1,
      anon_sym_LPAREN,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9046), 1,
      anon_sym_DOT,
    ACTIONS(9835), 1,
      sym__alpha_identifier,
    ACTIONS(9841), 1,
      sym__backquoted_id,
    ACTIONS(9843), 1,
      sym_operator_identifier,
    ACTIONS(10607), 1,
      anon_sym_EQ,
    STATE(531), 1,
      sym_identifier,
    STATE(3976), 1,
      sym__soft_identifier,
    STATE(5822), 2,
      sym_comment,
      sym_block_comment,
    STATE(6202), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(9837), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [304841] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8910), 1,
      sym_interpolated_string,
    STATE(14822), 1,
      sym__interpolated_string_start,
    STATE(14827), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10609), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5823), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304895] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [304937] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10205), 1,
      anon_sym_COLON,
    ACTIONS(10207), 1,
      anon_sym_LBRACE,
    ACTIONS(10209), 1,
      anon_sym_with,
    STATE(8294), 1,
      aux_sym_compound_type_repeat1,
    STATE(10132), 1,
      sym__refinement,
    STATE(10417), 1,
      sym_template_body,
    STATE(5825), 2,
      sym_comment,
      sym_block_comment,
    STATE(10171), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304993] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10601), 1,
      anon_sym_COLON,
    ACTIONS(10603), 1,
      anon_sym_LBRACE,
    ACTIONS(10605), 1,
      anon_sym_with,
    STATE(5819), 1,
      aux_sym_compound_type_repeat1,
    STATE(10372), 1,
      sym_template_body,
    STATE(10374), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5826), 2,
      sym_comment,
      sym_block_comment,
    STATE(10229), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8412), 3,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [305055] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10611), 1,
      anon_sym_LPAREN,
    STATE(4401), 1,
      sym_arguments,
    STATE(5827), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 24,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [305099] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10614), 1,
      anon_sym_LPAREN,
    STATE(7299), 1,
      sym_arguments,
    STATE(5828), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [305145] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [305187] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [305229] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [305271] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [305313] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1282), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9080), 1,
      anon_sym_LPAREN,
    ACTIONS(9535), 1,
      anon_sym_DOT,
    ACTIONS(10617), 1,
      sym__alpha_identifier,
    ACTIONS(10621), 1,
      anon_sym_EQ,
    ACTIONS(10623), 1,
      sym__backquoted_id,
    ACTIONS(10625), 1,
      sym_operator_identifier,
    STATE(541), 1,
      sym_identifier,
    STATE(4039), 1,
      sym__soft_identifier,
    STATE(5833), 2,
      sym_comment,
      sym_block_comment,
    STATE(7666), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
    ACTIONS(10619), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [305379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5834), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [305421] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [305463] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [305505] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5837), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [305547] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9920), 1,
      anon_sym_LBRACK,
    ACTIONS(9926), 1,
      anon_sym_POUND,
    ACTIONS(10627), 1,
      anon_sym_LPAREN,
    STATE(7134), 1,
      aux_sym_annotation_repeat1,
    STATE(7593), 1,
      sym_type_arguments,
    STATE(8617), 1,
      sym_arguments,
    STATE(5838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [305601] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5839), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [305643] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [305685] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1338), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9318), 1,
      anon_sym_LPAREN,
    ACTIONS(10054), 1,
      anon_sym_DOT,
    ACTIONS(10268), 1,
      sym__alpha_identifier,
    ACTIONS(10274), 1,
      sym__backquoted_id,
    ACTIONS(10276), 1,
      sym_operator_identifier,
    ACTIONS(10629), 1,
      anon_sym_EQ,
    STATE(543), 1,
      sym_identifier,
    STATE(4041), 1,
      sym__soft_identifier,
    STATE(5841), 2,
      sym_comment,
      sym_block_comment,
    STATE(8493), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(10270), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [305751] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10631), 1,
      anon_sym_LBRACE,
    ACTIONS(10633), 1,
      anon_sym_with,
    STATE(8566), 1,
      aux_sym_compound_type_repeat1,
    STATE(9740), 1,
      sym__refinement,
    STATE(9923), 1,
      sym_template_body,
    STATE(5842), 2,
      sym_comment,
      sym_block_comment,
    STATE(9892), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [305805] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10635), 1,
      anon_sym_LPAREN,
    STATE(6826), 1,
      sym_arguments,
    STATE(5843), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [305851] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [305893] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [305937] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9434), 1,
      anon_sym_LPAREN,
    STATE(5854), 1,
      aux_sym_annotation_repeat1,
    STATE(7038), 1,
      sym_arguments,
    STATE(5846), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [305985] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5847), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [306027] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10638), 1,
      anon_sym_DOT,
    STATE(5848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [306071] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5849), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [306113] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [306155] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10468), 1,
      anon_sym_LBRACE,
    ACTIONS(10470), 1,
      anon_sym_with,
    STATE(8630), 1,
      aux_sym_compound_type_repeat1,
    STATE(9755), 1,
      sym_template_body,
    STATE(9767), 1,
      sym__refinement,
    STATE(5851), 2,
      sym_comment,
      sym_block_comment,
    STATE(10017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [306209] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [306251] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(10092), 1,
      sym_interpolated_string,
    STATE(14993), 1,
      sym__interpolated_string_start,
    STATE(14996), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5853), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [306305] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10640), 1,
      anon_sym_LPAREN,
    STATE(7038), 1,
      sym_arguments,
    STATE(5854), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [306351] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5855), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [306393] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10643), 1,
      anon_sym_with,
    STATE(5856), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [306437] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10646), 1,
      anon_sym_DOT,
    STATE(5857), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [306481] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10284), 1,
      anon_sym_COLON,
    ACTIONS(10286), 1,
      anon_sym_LBRACE,
    ACTIONS(10288), 1,
      anon_sym_with,
    STATE(5564), 1,
      aux_sym_compound_type_repeat1,
    STATE(9908), 1,
      sym_template_body,
    STATE(9913), 1,
      sym__refinement,
    STATE(5858), 2,
      sym_comment,
      sym_block_comment,
    STATE(10043), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [306537] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [306579] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [306621] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [306663] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [306705] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9636), 1,
      anon_sym_AT,
    STATE(5714), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7364), 1,
      sym_annotation,
    STATE(5863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [306753] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5864), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [306795] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [306837] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5866), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [306881] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [306923] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [306965] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5869), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [307007] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6430), 1,
      sym_arguments,
    STATE(5870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [307051] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5871), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [307093] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [307135] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10284), 1,
      anon_sym_COLON,
    ACTIONS(10286), 1,
      anon_sym_LBRACE,
    ACTIONS(10288), 1,
      anon_sym_with,
    STATE(5564), 1,
      aux_sym_compound_type_repeat1,
    STATE(9908), 1,
      sym_template_body,
    STATE(9913), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5873), 2,
      sym_comment,
      sym_block_comment,
    STATE(10043), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8412), 3,
      anon_sym_case,
      anon_sym_if,
      anon_sym_EQ,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [307197] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [307239] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9206), 1,
      anon_sym_AT,
    STATE(5910), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7256), 1,
      sym_annotation,
    STATE(5875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [307287] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10648), 1,
      anon_sym_DOT,
    STATE(5876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [307331] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5877), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [307373] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5878), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [307415] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5879), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [307457] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [307499] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5881), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [307541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [307583] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5883), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [307627] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5884), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [307669] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10650), 1,
      anon_sym_LBRACK,
    ACTIONS(10652), 1,
      anon_sym_LPAREN,
    ACTIONS(10654), 1,
      anon_sym_POUND,
    STATE(7742), 1,
      sym_type_arguments,
    STATE(7887), 1,
      aux_sym_annotation_repeat1,
    STATE(9168), 1,
      sym_arguments,
    STATE(5885), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [307723] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [307765] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10601), 1,
      anon_sym_COLON,
    ACTIONS(10603), 1,
      anon_sym_LBRACE,
    ACTIONS(10605), 1,
      anon_sym_with,
    STATE(5819), 1,
      aux_sym_compound_type_repeat1,
    STATE(10372), 1,
      sym_template_body,
    STATE(10374), 1,
      sym__refinement,
    STATE(5887), 2,
      sym_comment,
      sym_block_comment,
    STATE(10229), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [307821] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9495), 1,
      anon_sym_AT,
    STATE(5922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7276), 1,
      sym_annotation,
    STATE(5888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8957), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [307869] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5889), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [307913] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [307955] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10656), 1,
      anon_sym_LBRACK,
    ACTIONS(10658), 1,
      anon_sym_LPAREN,
    ACTIONS(10660), 1,
      anon_sym_POUND,
    STATE(7073), 1,
      aux_sym_annotation_repeat1,
    STATE(7610), 1,
      sym_type_arguments,
    STATE(8226), 1,
      sym_arguments,
    STATE(5891), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [308009] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10631), 1,
      anon_sym_LBRACE,
    ACTIONS(10633), 1,
      anon_sym_with,
    STATE(5842), 1,
      aux_sym_compound_type_repeat1,
    STATE(9736), 1,
      sym__refinement,
    STATE(9923), 1,
      sym_template_body,
    STATE(5892), 2,
      sym_comment,
      sym_block_comment,
    STATE(9892), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [308063] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4200), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(5893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [308109] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5894), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [308151] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [308193] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5896), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [308235] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9216), 1,
      anon_sym_AT,
    STATE(5934), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7294), 1,
      sym_annotation,
    STATE(5897), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [308283] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5898), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [308325] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [308367] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5900), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [308409] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [308451] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5902), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [308493] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [308535] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9651), 1,
      anon_sym_AT,
    STATE(5594), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7329), 1,
      sym_annotation,
    STATE(5904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8957), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [308583] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5905), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [308625] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [308667] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5907), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [308709] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5908), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [308751] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10226), 1,
      anon_sym_COLON,
    ACTIONS(10666), 1,
      anon_sym_EQ_GT,
    ACTIONS(10668), 1,
      anon_sym_QMARK_EQ_GT,
    STATE(7598), 1,
      sym_interpolated_string,
    STATE(15304), 1,
      sym__interpolated_string_start,
    STATE(15305), 1,
      sym__interpolated_multiline_string_start,
    STATE(16373), 1,
      sym__self_type_ascription,
    STATE(5909), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [308811] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10670), 1,
      anon_sym_AT,
    STATE(7256), 1,
      sym_annotation,
    STATE(5910), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [308857] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10631), 1,
      anon_sym_LBRACE,
    ACTIONS(10633), 1,
      anon_sym_with,
    ACTIONS(10673), 1,
      anon_sym_COLON,
    STATE(5842), 1,
      aux_sym_compound_type_repeat1,
    STATE(9736), 1,
      sym__refinement,
    STATE(9923), 1,
      sym_template_body,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5911), 2,
      sym_comment,
      sym_block_comment,
    STATE(9892), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [308919] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5912), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9068), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [308961] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [309003] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5914), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [309045] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [309087] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309131] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [309173] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10676), 1,
      anon_sym_AT,
    STATE(6700), 1,
      sym_annotation,
    STATE(5918), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309219] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [309261] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10076), 1,
      anon_sym_LBRACK,
    ACTIONS(10078), 1,
      anon_sym_AT,
    ACTIONS(10082), 1,
      anon_sym_POUND,
    STATE(6783), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7868), 1,
      sym_type_arguments,
    STATE(8392), 1,
      sym_annotation,
    STATE(5920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309315] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5921), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [309357] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10679), 1,
      anon_sym_AT,
    STATE(7276), 1,
      sym_annotation,
    STATE(5922), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8931), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [309403] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [309445] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9920), 1,
      anon_sym_LBRACK,
    ACTIONS(9922), 1,
      anon_sym_AT,
    ACTIONS(9926), 1,
      anon_sym_POUND,
    STATE(6950), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7593), 1,
      sym_type_arguments,
    STATE(8105), 1,
      sym_annotation,
    STATE(5924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309499] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10552), 1,
      anon_sym_COLON,
    ACTIONS(10554), 1,
      anon_sym_LBRACE,
    ACTIONS(10556), 1,
      anon_sym_with,
    STATE(8310), 1,
      aux_sym_compound_type_repeat1,
    STATE(10349), 1,
      sym_template_body,
    STATE(10362), 1,
      sym__refinement,
    STATE(5925), 2,
      sym_comment,
      sym_block_comment,
    STATE(10157), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309555] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [309597] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10682), 1,
      anon_sym_DOT,
    STATE(5927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [309641] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5928), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [309683] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [309725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9068), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [309767] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309809] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [309851] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [309893] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10684), 1,
      anon_sym_AT,
    STATE(7294), 1,
      sym_annotation,
    STATE(5934), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309939] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10176), 1,
      anon_sym_LBRACK,
    ACTIONS(10180), 1,
      anon_sym_POUND,
    ACTIONS(10687), 1,
      anon_sym_AT,
    STATE(7084), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7089), 1,
      sym_type_arguments,
    STATE(8468), 1,
      sym_annotation,
    STATE(5935), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309993] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [310035] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9576), 1,
      anon_sym_LPAREN,
    STATE(5940), 1,
      aux_sym_annotation_repeat1,
    STATE(7206), 1,
      sym_arguments,
    STATE(5937), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [310083] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5938), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [310127] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [310171] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10689), 1,
      anon_sym_LPAREN,
    STATE(7206), 1,
      sym_arguments,
    STATE(5940), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [310217] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5941), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [310259] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10528), 1,
      anon_sym_COLON,
    ACTIONS(10530), 1,
      anon_sym_LBRACE,
    ACTIONS(10532), 1,
      anon_sym_with,
    STATE(5982), 1,
      aux_sym_compound_type_repeat1,
    STATE(10419), 1,
      sym_template_body,
    STATE(10422), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5942), 2,
      sym_comment,
      sym_block_comment,
    STATE(10358), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8412), 4,
      anon_sym_while,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [310321] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [310363] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [310405] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9972), 1,
      anon_sym_LBRACK,
    ACTIONS(9976), 1,
      anon_sym_POUND,
    ACTIONS(10692), 1,
      anon_sym_AT,
    STATE(7160), 1,
      sym_type_arguments,
    STATE(7939), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9003), 1,
      sym_annotation,
    STATE(5945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [310459] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5946), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9086), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [310501] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9088), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [310543] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9090), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [310585] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10694), 1,
      anon_sym_with,
    STATE(5949), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [310629] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [310671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [310713] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9098), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [310755] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [310797] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [310839] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [310881] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10697), 1,
      anon_sym_DOT,
    STATE(5956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [310925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5957), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [310967] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9586), 1,
      anon_sym_LPAREN,
    STATE(5962), 1,
      aux_sym_annotation_repeat1,
    STATE(7222), 1,
      sym_arguments,
    STATE(5958), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8426), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [311015] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [311057] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5960), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [311099] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [311141] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10699), 1,
      anon_sym_LPAREN,
    STATE(7222), 1,
      sym_arguments,
    STATE(5962), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8430), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [311187] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5963), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [311229] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(936), 1,
      anon_sym_LBRACE,
    ACTIONS(8236), 1,
      anon_sym_LPAREN,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8989), 1,
      anon_sym_DOT,
    ACTIONS(9813), 1,
      sym__alpha_identifier,
    ACTIONS(9819), 1,
      sym__backquoted_id,
    ACTIONS(9821), 1,
      sym_operator_identifier,
    ACTIONS(10702), 1,
      anon_sym_EQ,
    STATE(530), 1,
      sym_identifier,
    STATE(3932), 1,
      sym__soft_identifier,
    STATE(5964), 2,
      sym_comment,
      sym_block_comment,
    STATE(6647), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_case,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9815), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [311295] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5965), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [311337] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5966), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [311379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5967), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [311421] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [311463] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [311505] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5970), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [311547] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10716), 1,
      anon_sym_with,
    STATE(5971), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [311591] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5972), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [311633] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [311675] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [311717] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [311759] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [311801] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9772), 1,
      anon_sym_LBRACK,
    ACTIONS(9776), 1,
      anon_sym_POUND,
    ACTIONS(10719), 1,
      anon_sym_AT,
    STATE(6662), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7020), 1,
      sym_type_arguments,
    STATE(8581), 1,
      sym_annotation,
    STATE(5977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [311855] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5978), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [311897] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5979), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [311939] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10721), 1,
      anon_sym_with,
    STATE(5980), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [311983] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [312025] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10528), 1,
      anon_sym_COLON,
    ACTIONS(10530), 1,
      anon_sym_LBRACE,
    ACTIONS(10532), 1,
      anon_sym_with,
    STATE(8498), 1,
      aux_sym_compound_type_repeat1,
    STATE(10221), 1,
      sym__refinement,
    STATE(10419), 1,
      sym_template_body,
    STATE(5982), 2,
      sym_comment,
      sym_block_comment,
    STATE(10358), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8246), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [312081] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [312123] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [312165] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(5985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [312209] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [312251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [312293] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5988), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [312335] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9680), 1,
      anon_sym_LPAREN,
    STATE(5992), 1,
      aux_sym_annotation_repeat1,
    STATE(7383), 1,
      sym_arguments,
    STATE(5989), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [312383] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10724), 1,
      anon_sym_with,
    STATE(5990), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [312427] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6273), 1,
      sym__end_marker,
    STATE(5991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [312471] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10727), 1,
      anon_sym_LPAREN,
    STATE(7383), 1,
      sym_arguments,
    STATE(5992), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [312517] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5993), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [312559] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5994), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [312600] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8313), 1,
      sym_interpolated_string,
    STATE(15827), 1,
      sym__interpolated_string_start,
    STATE(15829), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10730), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [312653] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9547), 1,
      anon_sym_AT,
    STATE(6013), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7862), 1,
      sym_annotation,
    STATE(5996), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [312700] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [312741] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [312782] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [312823] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6000), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [312864] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(6001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [312911] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6002), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [312952] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10732), 1,
      anon_sym_DOT,
    STATE(6003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [312995] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [313036] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8442), 1,
      sym_interpolated_string,
    STATE(15634), 1,
      sym__interpolated_string_start,
    STATE(15635), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10734), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [313089] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6006), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [313130] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [313173] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6008), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [313214] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1008), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8855), 1,
      anon_sym_LPAREN,
    ACTIONS(9240), 1,
      anon_sym_DOT,
    ACTIONS(10006), 1,
      sym__alpha_identifier,
    ACTIONS(10012), 1,
      sym__backquoted_id,
    ACTIONS(10014), 1,
      sym_operator_identifier,
    ACTIONS(10736), 1,
      anon_sym_EQ,
    STATE(532), 1,
      sym_identifier,
    STATE(4034), 1,
      sym__soft_identifier,
    ACTIONS(9363), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(6009), 2,
      sym_comment,
      sym_block_comment,
    STATE(6919), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9367), 5,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(10008), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [313279] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8946), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [313322] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1572), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9549), 1,
      anon_sym_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOT,
    ACTIONS(10738), 1,
      sym__alpha_identifier,
    ACTIONS(10742), 1,
      anon_sym_EQ,
    ACTIONS(10744), 1,
      sym__backquoted_id,
    ACTIONS(10746), 1,
      sym_operator_identifier,
    STATE(552), 1,
      sym_identifier,
    STATE(4049), 1,
      sym__soft_identifier,
    STATE(6011), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
    STATE(8852), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10740), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [313387] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6012), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [313428] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10748), 1,
      anon_sym_AT,
    STATE(7862), 1,
      sym_annotation,
    STATE(6013), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [313473] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6014), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [313514] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9710), 1,
      anon_sym_LPAREN,
    STATE(6072), 1,
      aux_sym_annotation_repeat1,
    STATE(7900), 1,
      sym_arguments,
    STATE(6015), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [313561] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6016), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [313602] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1698), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9563), 1,
      anon_sym_LPAREN,
    ACTIONS(10540), 1,
      anon_sym_DOT,
    ACTIONS(10751), 1,
      sym__alpha_identifier,
    ACTIONS(10755), 1,
      anon_sym_EQ,
    ACTIONS(10757), 1,
      sym__backquoted_id,
    ACTIONS(10759), 1,
      sym_operator_identifier,
    STATE(558), 1,
      sym_identifier,
    STATE(4050), 1,
      sym__soft_identifier,
    STATE(6017), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
    STATE(8909), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10753), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [313667] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10761), 1,
      anon_sym_DOT,
    STATE(6018), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [313710] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6019), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [313751] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10763), 1,
      anon_sym_DOT,
    STATE(6020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [313794] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6021), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [313835] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [313876] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6023), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [313917] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6024), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [313958] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6025), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [313999] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [314040] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314081] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314122] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314163] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10765), 1,
      sym__backquoted_id,
    STATE(6030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7396), 25,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314204] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314245] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6032), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314286] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10161), 1,
      anon_sym_AT,
    STATE(6326), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7969), 1,
      sym_annotation,
    STATE(6033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314333] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [314374] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [314415] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10767), 1,
      anon_sym_AT,
    STATE(8077), 1,
      sym_annotation,
    STATE(6036), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [314460] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10770), 1,
      anon_sym_COLON,
    ACTIONS(10773), 1,
      anon_sym_LBRACE,
    STATE(8239), 1,
      sym_template_body,
    STATE(6037), 2,
      sym_comment,
      sym_block_comment,
    STATE(8419), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 6,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9222), 15,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [314509] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9425), 1,
      anon_sym_LPAREN,
    STATE(6069), 1,
      aux_sym_annotation_repeat1,
    STATE(7980), 1,
      sym_arguments,
    STATE(6038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314556] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10776), 1,
      anon_sym_AT,
    STATE(8032), 1,
      sym_annotation,
    STATE(6039), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8931), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [314601] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [314642] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314683] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10340), 1,
      anon_sym_with,
    STATE(8769), 1,
      aux_sym_compound_type_repeat1,
    STATE(9753), 1,
      sym__refinement,
    STATE(9761), 1,
      sym_template_body,
    STATE(6042), 2,
      sym_comment,
      sym_block_comment,
    STATE(6450), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314734] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [314775] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6044), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314818] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [314859] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [314900] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9811), 1,
      anon_sym_LPAREN,
    STATE(6100), 1,
      aux_sym_annotation_repeat1,
    STATE(7633), 1,
      sym_arguments,
    STATE(6047), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314947] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314988] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10334), 1,
      anon_sym_DOT,
    ACTIONS(10779), 1,
      anon_sym_EQ_GT,
    STATE(6049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [315033] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [315074] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9068), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [315115] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10154), 1,
      anon_sym_AT,
    STATE(6279), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7467), 1,
      sym_annotation,
    STATE(6052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [315162] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [315203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [315244] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1080), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8847), 1,
      anon_sym_LPAREN,
    ACTIONS(9232), 1,
      anon_sym_DOT,
    ACTIONS(10255), 1,
      sym__alpha_identifier,
    ACTIONS(10261), 1,
      sym__backquoted_id,
    ACTIONS(10263), 1,
      sym_operator_identifier,
    ACTIONS(10781), 1,
      anon_sym_EQ,
    STATE(534), 1,
      sym_identifier,
    STATE(4030), 1,
      sym__soft_identifier,
    STATE(6055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_case,
      anon_sym_match,
      anon_sym_finally,
    STATE(6886), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [315309] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6056), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [315350] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [315391] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [315432] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [315473] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(6060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [315516] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [315557] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4134), 1,
      sym__backquoted_id,
    STATE(6062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4130), 25,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [315598] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [315639] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [315682] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6065), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [315723] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9086), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [315764] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10785), 1,
      anon_sym_LBRACE,
    ACTIONS(10787), 1,
      anon_sym_with,
    STATE(6566), 1,
      aux_sym_compound_type_repeat1,
    STATE(10149), 1,
      sym_template_body,
    STATE(10201), 1,
      sym__refinement,
    STATE(6067), 2,
      sym_comment,
      sym_block_comment,
    STATE(10295), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [315817] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [315858] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10789), 1,
      anon_sym_LPAREN,
    STATE(7980), 1,
      sym_arguments,
    STATE(6069), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [315903] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [315946] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10389), 1,
      anon_sym_DOT,
    ACTIONS(10792), 1,
      anon_sym_EQ_GT,
    STATE(6071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [315991] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10794), 1,
      anon_sym_LPAREN,
    STATE(7900), 1,
      sym_arguments,
    STATE(6072), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316036] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6073), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9088), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [316077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6074), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9090), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [316118] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6075), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316161] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316202] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316243] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6078), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [316284] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [316325] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9098), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [316366] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6081), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [316407] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10797), 1,
      anon_sym_AT,
    STATE(7725), 1,
      sym_annotation,
    STATE(6082), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8931), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [316452] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6083), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316493] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316534] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316575] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(107), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9039), 1,
      anon_sym_LPAREN,
    ACTIONS(9391), 1,
      anon_sym_DOT,
    ACTIONS(9854), 1,
      sym__alpha_identifier,
    ACTIONS(9860), 1,
      sym__backquoted_id,
    ACTIONS(9862), 1,
      sym_operator_identifier,
    ACTIONS(10800), 1,
      anon_sym_EQ,
    STATE(553), 1,
      sym_identifier,
    STATE(4043), 1,
      sym__soft_identifier,
    STATE(6086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(7569), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9367), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [316640] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6087), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [316681] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10802), 1,
      anon_sym_COLON,
    ACTIONS(10804), 1,
      anon_sym_LBRACE,
    ACTIONS(10806), 1,
      anon_sym_with,
    STATE(8938), 1,
      aux_sym_compound_type_repeat1,
    STATE(10467), 1,
      sym_template_body,
    STATE(10553), 1,
      sym__refinement,
    STATE(6088), 2,
      sym_comment,
      sym_block_comment,
    STATE(10520), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316736] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6089), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [316777] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10595), 1,
      anon_sym_LBRACK,
    ACTIONS(10599), 1,
      anon_sym_POUND,
    ACTIONS(10808), 1,
      anon_sym_AT,
    STATE(7878), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7992), 1,
      sym_type_arguments,
    STATE(8731), 1,
      sym_annotation,
    STATE(6090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316830] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6091), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [316871] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6092), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316912] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6093), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [316953] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [316994] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6095), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317035] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8313), 1,
      sym_interpolated_string,
    STATE(15827), 1,
      sym__interpolated_string_start,
    STATE(15829), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10810), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317088] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6097), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317129] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9068), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [317170] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6099), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317211] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10812), 1,
      anon_sym_LPAREN,
    STATE(7633), 1,
      sym_arguments,
    STATE(6100), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317256] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8442), 1,
      sym_interpolated_string,
    STATE(15634), 1,
      sym__interpolated_string_start,
    STATE(15635), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10815), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6101), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317309] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9561), 1,
      anon_sym_AT,
    STATE(6511), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7691), 1,
      sym_annotation,
    STATE(6102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317356] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6103), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317397] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1008), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8855), 1,
      anon_sym_LPAREN,
    ACTIONS(9240), 1,
      anon_sym_DOT,
    ACTIONS(10006), 1,
      sym__alpha_identifier,
    ACTIONS(10012), 1,
      sym__backquoted_id,
    ACTIONS(10014), 1,
      sym_operator_identifier,
    ACTIONS(10817), 1,
      anon_sym_EQ,
    STATE(532), 1,
      sym_identifier,
    STATE(4034), 1,
      sym__soft_identifier,
    ACTIONS(9363), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(6104), 2,
      sym_comment,
      sym_block_comment,
    STATE(6919), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9367), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10008), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [317462] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [317503] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6993), 1,
      sym_arguments,
    STATE(6106), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [317546] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [317587] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8951), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317630] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9852), 1,
      anon_sym_LPAREN,
    STATE(6126), 1,
      aux_sym_annotation_repeat1,
    STATE(7557), 1,
      sym_arguments,
    STATE(6109), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317677] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [317718] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [317759] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10819), 1,
      anon_sym_DOT,
    STATE(6112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [317802] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317843] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6114), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [317884] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317927] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317968] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [318009] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6118), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9086), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [318050] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [318091] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [318132] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10646), 1,
      anon_sym_DOT,
    ACTIONS(10821), 1,
      anon_sym_EQ_GT,
    STATE(6121), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [318177] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10823), 1,
      anon_sym_DOT,
    STATE(6122), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [318220] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9088), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [318261] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6124), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9090), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [318302] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [318343] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10825), 1,
      anon_sym_LPAREN,
    STATE(7557), 1,
      sym_arguments,
    STATE(6126), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [318388] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [318429] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1484), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9341), 1,
      anon_sym_LPAREN,
    ACTIONS(9809), 1,
      anon_sym_DOT,
    ACTIONS(10828), 1,
      sym__alpha_identifier,
    ACTIONS(10832), 1,
      anon_sym_EQ,
    ACTIONS(10834), 1,
      sym__backquoted_id,
    ACTIONS(10836), 1,
      sym_operator_identifier,
    STATE(548), 1,
      sym_identifier,
    STATE(4051), 1,
      sym__soft_identifier,
    STATE(6128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    STATE(8599), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9367), 4,
      anon_sym_match,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10830), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [318494] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6129), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [318535] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6130), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9098), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [318576] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10319), 1,
      anon_sym_AT,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10970), 1,
      sym_interpolated_string,
    STATE(15611), 1,
      sym__interpolated_string_start,
    STATE(15612), 1,
      sym__interpolated_multiline_string_start,
    STATE(6131), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10840), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10838), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [318637] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10842), 1,
      anon_sym_with,
    STATE(6132), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [318680] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1572), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9549), 1,
      anon_sym_LPAREN,
    ACTIONS(10492), 1,
      anon_sym_DOT,
    ACTIONS(10738), 1,
      sym__alpha_identifier,
    ACTIONS(10744), 1,
      sym__backquoted_id,
    ACTIONS(10746), 1,
      sym_operator_identifier,
    ACTIONS(10845), 1,
      anon_sym_EQ,
    STATE(552), 1,
      sym_identifier,
    STATE(4049), 1,
      sym__soft_identifier,
    STATE(6133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
    STATE(8852), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10740), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [318745] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6134), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [318786] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [318827] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [318868] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6137), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [318909] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1642), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10080), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_DOT,
    ACTIONS(10849), 1,
      sym_operator_identifier,
    STATE(1698), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(6138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8807), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    STATE(9371), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [318974] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10851), 1,
      sym__backquoted_id,
    STATE(6139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7340), 25,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319015] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319056] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319097] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [319138] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6143), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [319179] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319220] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319261] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [319302] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9757), 1,
      anon_sym_LPAREN,
    STATE(6177), 1,
      aux_sym_annotation_repeat1,
    STATE(7447), 1,
      sym_arguments,
    STATE(6147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319349] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(477), 1,
      anon_sym_LBRACE,
    ACTIONS(9924), 1,
      anon_sym_LPAREN,
    ACTIONS(10853), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(6148), 2,
      sym_comment,
      sym_block_comment,
    STATE(9378), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319402] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6149), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319443] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6150), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [319484] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319525] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319568] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319609] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7037), 1,
      sym_arguments,
    STATE(6154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [319652] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1642), 1,
      anon_sym_LBRACE,
    ACTIONS(10080), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(6155), 2,
      sym_comment,
      sym_block_comment,
    STATE(9371), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319705] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [319746] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [319787] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319828] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6159), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [319869] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6160), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [319910] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(832), 1,
      anon_sym_LBRACE,
    ACTIONS(10123), 1,
      anon_sym_LPAREN,
    ACTIONS(10855), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(6161), 2,
      sym_comment,
      sym_block_comment,
    STATE(9409), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8831), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [319963] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [320004] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [320045] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320086] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10857), 1,
      anon_sym_LBRACE,
    ACTIONS(10859), 1,
      anon_sym_with,
    STATE(8928), 1,
      aux_sym_compound_type_repeat1,
    STATE(10184), 1,
      sym__refinement,
    STATE(10399), 1,
      sym_template_body,
    STATE(6165), 2,
      sym_comment,
      sym_block_comment,
    STATE(10357), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320139] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10861), 1,
      anon_sym_AT,
    STATE(7751), 1,
      sym_annotation,
    STATE(6166), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320184] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [320225] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [320266] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1642), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(10080), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(6169), 2,
      sym_comment,
      sym_block_comment,
    STATE(9371), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320321] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9068), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [320362] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6171), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [320403] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320444] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9700), 1,
      anon_sym_AT,
    STATE(6580), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7839), 1,
      sym_annotation,
    STATE(6173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320491] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [320532] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6175), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [320573] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6905), 1,
      sym__end_marker,
    STATE(6176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [320616] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10864), 1,
      anon_sym_LPAREN,
    STATE(7447), 1,
      sym_arguments,
    STATE(6177), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320661] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9088), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [320702] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320743] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [320784] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320825] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10867), 1,
      anon_sym_COLON,
    ACTIONS(10869), 1,
      anon_sym_LBRACE,
    ACTIONS(10871), 1,
      anon_sym_with,
    STATE(6572), 1,
      aux_sym_compound_type_repeat1,
    STATE(10506), 1,
      sym_template_body,
    STATE(10507), 1,
      sym__refinement,
    STATE(6182), 2,
      sym_comment,
      sym_block_comment,
    STATE(10602), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320880] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(832), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10123), 1,
      anon_sym_LPAREN,
    ACTIONS(10855), 1,
      anon_sym_DOT,
    ACTIONS(10873), 1,
      sym_operator_identifier,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(6183), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    STATE(9409), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8807), 4,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [320945] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [320986] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [321027] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(107), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9039), 1,
      anon_sym_LPAREN,
    ACTIONS(9391), 1,
      anon_sym_DOT,
    ACTIONS(9854), 1,
      sym__alpha_identifier,
    ACTIONS(9860), 1,
      sym__backquoted_id,
    ACTIONS(9862), 1,
      sym_operator_identifier,
    ACTIONS(10875), 1,
      anon_sym_EQ,
    STATE(553), 1,
      sym_identifier,
    STATE(4043), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_if,
      anon_sym_match,
    STATE(6186), 2,
      sym_comment,
      sym_block_comment,
    STATE(7569), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [321092] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [321133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [321174] = 21,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10970), 1,
      sym_interpolated_string,
    STATE(15611), 1,
      sym__interpolated_string_start,
    STATE(15612), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10877), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(6189), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10879), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [321247] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1698), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9563), 1,
      anon_sym_LPAREN,
    ACTIONS(10540), 1,
      anon_sym_DOT,
    ACTIONS(10751), 1,
      sym__alpha_identifier,
    ACTIONS(10757), 1,
      sym__backquoted_id,
    ACTIONS(10759), 1,
      sym_operator_identifier,
    ACTIONS(10881), 1,
      anon_sym_EQ,
    STATE(558), 1,
      sym_identifier,
    STATE(4050), 1,
      sym__soft_identifier,
    STATE(6190), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_case,
      anon_sym_match,
      anon_sym_finally,
    STATE(8909), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10753), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [321312] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [321353] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [321394] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [321435] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [321476] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10883), 1,
      anon_sym_DOT,
    STATE(6195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [321519] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [321560] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10656), 1,
      anon_sym_LBRACK,
    ACTIONS(10660), 1,
      anon_sym_POUND,
    ACTIONS(10885), 1,
      anon_sym_AT,
    STATE(7610), 1,
      sym_type_arguments,
    STATE(7844), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8774), 1,
      sym_annotation,
    STATE(6197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [321613] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6198), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [321654] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6199), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [321695] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6200), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [321736] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [321777] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [321818] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [321859] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9291), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [321900] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [321941] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10393), 1,
      anon_sym_LBRACK,
    ACTIONS(10397), 1,
      anon_sym_POUND,
    ACTIONS(10887), 1,
      anon_sym_AT,
    STATE(7388), 1,
      sym_type_arguments,
    STATE(7963), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9278), 1,
      sym_annotation,
    STATE(6206), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [321994] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10889), 1,
      anon_sym_LBRACK,
    ACTIONS(10891), 1,
      anon_sym_LPAREN,
    ACTIONS(10893), 1,
      anon_sym_POUND,
    STATE(7480), 1,
      aux_sym_annotation_repeat1,
    STATE(8251), 1,
      sym_type_arguments,
    STATE(8797), 1,
      sym_arguments,
    STATE(6207), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [322047] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [322088] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [322129] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [322170] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6211), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [322211] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [322252] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [322293] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6214), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [322336] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6215), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [322377] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6216), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [322418] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [322459] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6218), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [322500] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6219), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [322541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6220), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [322582] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6221), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [322623] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [322664] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10895), 1,
      anon_sym_COLON,
    ACTIONS(10897), 1,
      anon_sym_LBRACE,
    ACTIONS(10899), 1,
      anon_sym_with,
    STATE(6610), 1,
      aux_sym_compound_type_repeat1,
    STATE(10565), 1,
      sym__refinement,
    STATE(10662), 1,
      sym_template_body,
    STATE(6223), 2,
      sym_comment,
      sym_block_comment,
    STATE(10618), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [322719] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [322760] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6225), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [322801] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6226), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [322842] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6227), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [322883] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [322924] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10901), 1,
      anon_sym_DOT,
    STATE(6229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [322967] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [323008] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10903), 1,
      anon_sym_COLON,
    ACTIONS(10905), 1,
      anon_sym_LBRACE,
    ACTIONS(10907), 1,
      anon_sym_with,
    STATE(8727), 1,
      aux_sym_compound_type_repeat1,
    STATE(10622), 1,
      sym_template_body,
    STATE(10648), 1,
      sym__refinement,
    STATE(6231), 2,
      sym_comment,
      sym_block_comment,
    STATE(10473), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323063] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10909), 1,
      anon_sym_AT,
    STATE(7938), 1,
      sym_annotation,
    STATE(6232), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323108] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6233), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [323149] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10912), 1,
      anon_sym_LPAREN,
    STATE(7703), 1,
      sym_arguments,
    STATE(6234), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323194] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1642), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10080), 1,
      anon_sym_LPAREN,
    ACTIONS(10847), 1,
      anon_sym_DOT,
    ACTIONS(10915), 1,
      sym__alpha_identifier,
    ACTIONS(10919), 1,
      anon_sym_EQ,
    ACTIONS(10921), 1,
      sym__backquoted_id,
    ACTIONS(10923), 1,
      sym_operator_identifier,
    STATE(556), 1,
      sym_identifier,
    STATE(4055), 1,
      sym__soft_identifier,
    STATE(6235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    STATE(9371), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10917), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [323259] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [323300] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6237), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [323341] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6238), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [323382] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6239), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323423] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323464] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [323505] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6242), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [323546] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10319), 1,
      anon_sym_AT,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10970), 1,
      sym_interpolated_string,
    STATE(15611), 1,
      sym__interpolated_string_start,
    STATE(15612), 1,
      sym__interpolated_multiline_string_start,
    STATE(6243), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10927), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10925), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [323607] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10929), 1,
      anon_sym_DOT,
    STATE(6244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323650] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [323691] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6246), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [323734] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [323775] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10867), 1,
      anon_sym_COLON,
    ACTIONS(10869), 1,
      anon_sym_LBRACE,
    ACTIONS(10871), 1,
      anon_sym_with,
    STATE(6572), 1,
      aux_sym_compound_type_repeat1,
    STATE(10506), 1,
      sym_template_body,
    STATE(10507), 1,
      sym__refinement,
    ACTIONS(8412), 2,
      anon_sym_STAR,
      anon_sym_else,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6248), 2,
      sym_comment,
      sym_block_comment,
    STATE(10602), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323836] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(7598), 1,
      sym_interpolated_string,
    STATE(15304), 1,
      sym__interpolated_string_start,
    STATE(15305), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10668), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323889] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6250), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323930] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1044), 1,
      anon_sym_LBRACE,
    ACTIONS(8731), 1,
      anon_sym_LPAREN,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9131), 1,
      anon_sym_DOT,
    ACTIONS(10235), 1,
      sym__alpha_identifier,
    ACTIONS(10241), 1,
      sym__backquoted_id,
    ACTIONS(10243), 1,
      sym_operator_identifier,
    ACTIONS(10931), 1,
      anon_sym_EQ,
    STATE(533), 1,
      sym_identifier,
    STATE(4027), 1,
      sym__soft_identifier,
    STATE(6251), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
    STATE(6706), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10237), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [323995] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6252), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324036] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [324077] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10933), 1,
      anon_sym_with,
    STATE(6254), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [324120] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6255), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [324161] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10903), 1,
      anon_sym_COLON,
    ACTIONS(10905), 1,
      anon_sym_LBRACE,
    ACTIONS(10907), 1,
      anon_sym_with,
    STATE(6231), 1,
      aux_sym_compound_type_repeat1,
    STATE(10454), 1,
      sym__refinement,
    STATE(10622), 1,
      sym_template_body,
    ACTIONS(8412), 2,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6256), 2,
      sym_comment,
      sym_block_comment,
    STATE(10473), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324222] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6257), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324263] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [324304] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324345] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10593), 1,
      anon_sym_EQ_GT,
    STATE(6260), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324388] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6261), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [324431] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6262), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [324472] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10936), 1,
      anon_sym_with,
    STATE(6263), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [324515] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6264), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [324556] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10939), 1,
      anon_sym_COLON,
    ACTIONS(10942), 1,
      anon_sym_LBRACE,
    STATE(8544), 1,
      sym_template_body,
    STATE(6265), 2,
      sym_comment,
      sym_block_comment,
    STATE(8355), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 7,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 14,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [324605] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6266), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324646] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6267), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [324687] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324728] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [324769] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324810] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10945), 1,
      anon_sym_LBRACK,
    ACTIONS(10947), 1,
      anon_sym_LPAREN,
    ACTIONS(10949), 1,
      anon_sym_POUND,
    STATE(8085), 1,
      aux_sym_annotation_repeat1,
    STATE(8465), 1,
      sym_type_arguments,
    STATE(8787), 1,
      sym_arguments,
    STATE(6271), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324863] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9086), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [324904] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6273), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [324945] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10951), 1,
      anon_sym_LPAREN,
    STATE(7998), 1,
      sym_arguments,
    STATE(6274), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324990] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325031] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6276), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9088), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [325072] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [325113] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [325154] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10954), 1,
      anon_sym_AT,
    STATE(7467), 1,
      sym_annotation,
    STATE(6279), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325199] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6280), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325240] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6281), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [325281] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6282), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [325322] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6283), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [325363] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10957), 1,
      anon_sym_with,
    STATE(6284), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [325406] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9090), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [325447] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6286), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [325488] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [325529] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6288), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325570] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10960), 1,
      anon_sym_COLON,
    ACTIONS(10963), 1,
      anon_sym_LBRACE,
    STATE(8522), 1,
      sym_template_body,
    STATE(6289), 2,
      sym_comment,
      sym_block_comment,
    STATE(8220), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 14,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325619] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6290), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325660] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [325701] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [325742] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [325783] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10895), 1,
      anon_sym_COLON,
    ACTIONS(10897), 1,
      anon_sym_LBRACE,
    ACTIONS(10899), 1,
      anon_sym_with,
    STATE(6610), 1,
      aux_sym_compound_type_repeat1,
    STATE(10565), 1,
      sym__refinement,
    STATE(10662), 1,
      sym_template_body,
    ACTIONS(8412), 2,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6294), 2,
      sym_comment,
      sym_block_comment,
    STATE(10618), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325844] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10191), 1,
      anon_sym_LBRACK,
    ACTIONS(10195), 1,
      anon_sym_POUND,
    ACTIONS(10966), 1,
      anon_sym_AT,
    STATE(7549), 1,
      sym_type_arguments,
    STATE(8000), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9314), 1,
      sym_annotation,
    STATE(6295), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325897] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10347), 1,
      anon_sym_EQ_GT,
    STATE(6296), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [325940] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6297), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [325981] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9098), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [326022] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(832), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(10123), 1,
      anon_sym_LPAREN,
    ACTIONS(10855), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(6299), 2,
      sym_comment,
      sym_block_comment,
    STATE(9409), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8835), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [326077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10970), 1,
      sym__backquoted_id,
    STATE(6300), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10968), 25,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326118] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [326159] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [326202] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326243] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6304), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [326284] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6305), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [326325] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [326366] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326407] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [326448] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10972), 1,
      anon_sym_LBRACK,
    ACTIONS(10974), 1,
      anon_sym_AT,
    ACTIONS(10976), 1,
      anon_sym_LPAREN,
    ACTIONS(10978), 1,
      anon_sym_POUND,
    STATE(8593), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9237), 1,
      sym_type_arguments,
    STATE(9646), 1,
      sym_arguments,
    STATE(9691), 1,
      sym_annotation,
    STATE(6309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326505] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6310), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [326546] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6311), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326587] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10980), 1,
      anon_sym_DOT,
    STATE(6312), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326630] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6313), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [326671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6314), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326712] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6315), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326753] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(9512), 1,
      sym_interpolated_string,
    STATE(15002), 1,
      sym__interpolated_string_start,
    STATE(15006), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10231), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326806] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6317), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [326847] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6318), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [326888] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9982), 1,
      anon_sym_AT,
    STATE(6036), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8077), 1,
      sym_annotation,
    STATE(6319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [326935] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6320), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [326976] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327017] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [327058] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6323), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [327099] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10591), 1,
      anon_sym_EQ_GT,
    STATE(6324), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [327142] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10982), 1,
      anon_sym_COLON,
    ACTIONS(10984), 1,
      anon_sym_LBRACE,
    ACTIONS(10986), 1,
      anon_sym_with,
    STATE(9057), 1,
      aux_sym_compound_type_repeat1,
    STATE(10569), 1,
      sym_template_body,
    STATE(10594), 1,
      sym__refinement,
    STATE(6325), 2,
      sym_comment,
      sym_block_comment,
    STATE(10537), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327197] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10988), 1,
      anon_sym_AT,
    STATE(7969), 1,
      sym_annotation,
    STATE(6326), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327242] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10991), 1,
      anon_sym_with,
    STATE(6327), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [327285] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10475), 1,
      anon_sym_LBRACK,
    ACTIONS(10481), 1,
      anon_sym_POUND,
    ACTIONS(10994), 1,
      anon_sym_LPAREN,
    STATE(7400), 1,
      aux_sym_annotation_repeat1,
    STATE(8464), 1,
      sym_type_arguments,
    STATE(9021), 1,
      sym_arguments,
    STATE(6328), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327338] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6329), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [327379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6330), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [327420] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6331), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [327461] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9800), 1,
      anon_sym_LPAREN,
    STATE(6448), 1,
      aux_sym_annotation_repeat1,
    STATE(7908), 1,
      sym_arguments,
    STATE(6332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8426), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [327508] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10996), 1,
      anon_sym_COLON,
    ACTIONS(10998), 1,
      anon_sym_LBRACE,
    ACTIONS(11000), 1,
      anon_sym_with,
    STATE(9044), 1,
      aux_sym_compound_type_repeat1,
    STATE(10510), 1,
      sym__refinement,
    STATE(10657), 1,
      sym_template_body,
    STATE(6333), 2,
      sym_comment,
      sym_block_comment,
    STATE(10460), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327563] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327604] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6335), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327647] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6336), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327688] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11002), 1,
      anon_sym_DOT,
    STATE(6337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327731] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1374), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9208), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_DOT,
    ACTIONS(11004), 1,
      sym__alpha_identifier,
    ACTIONS(11008), 1,
      anon_sym_EQ,
    ACTIONS(11010), 1,
      sym__backquoted_id,
    ACTIONS(11012), 1,
      sym_operator_identifier,
    STATE(544), 1,
      sym_identifier,
    STATE(4058), 1,
      sym__soft_identifier,
    STATE(6338), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
    STATE(8511), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(11006), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [327796] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11014), 1,
      anon_sym_AT,
    STATE(7958), 1,
      sym_annotation,
    STATE(6339), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8931), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [327841] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327882] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327923] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6342), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [327964] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6343), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328005] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6344), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [328046] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6345), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [328087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [328128] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6347), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [328169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [328210] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11017), 1,
      anon_sym_AT,
    STATE(7896), 1,
      sym_annotation,
    STATE(6349), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 23,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [328253] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6350), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [328294] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6351), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328335] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [328376] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11020), 1,
      anon_sym_with,
    STATE(6353), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [328419] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6354), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [328460] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [328501] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6356), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [328542] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10359), 1,
      anon_sym_LBRACK,
    ACTIONS(10365), 1,
      anon_sym_POUND,
    ACTIONS(11023), 1,
      anon_sym_LPAREN,
    STATE(7794), 1,
      aux_sym_annotation_repeat1,
    STATE(8143), 1,
      sym_type_arguments,
    STATE(9106), 1,
      sym_arguments,
    STATE(6357), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328595] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11025), 1,
      sym__backquoted_id,
    STATE(6358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(834), 25,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328636] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328677] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6360), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328718] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11027), 1,
      anon_sym_COLON,
    ACTIONS(11030), 1,
      anon_sym_LBRACE,
    STATE(8173), 1,
      sym_template_body,
    STATE(6361), 2,
      sym_comment,
      sym_block_comment,
    STATE(8139), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 14,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328767] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6362), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328808] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9714), 1,
      anon_sym_AT,
    STATE(6166), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7751), 1,
      sym_annotation,
    STATE(6363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328855] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6364), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [328896] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6365), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328939] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328980] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [329021] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [329062] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11033), 1,
      anon_sym_LBRACE,
    ACTIONS(11035), 1,
      anon_sym_with,
    STATE(6606), 1,
      aux_sym_compound_type_repeat1,
    STATE(10260), 1,
      sym_template_body,
    STATE(10266), 1,
      sym__refinement,
    STATE(6369), 2,
      sym_comment,
      sym_block_comment,
    STATE(10329), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329115] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10982), 1,
      anon_sym_COLON,
    ACTIONS(10984), 1,
      anon_sym_LBRACE,
    ACTIONS(10986), 1,
      anon_sym_with,
    STATE(6325), 1,
      aux_sym_compound_type_repeat1,
    STATE(10569), 1,
      sym_template_body,
    STATE(10571), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6370), 2,
      sym_comment,
      sym_block_comment,
    STATE(10537), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(8412), 3,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_EQ,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329176] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6371), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329217] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329258] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329299] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6374), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [329340] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6375), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [329381] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9513), 1,
      anon_sym_AT,
    STATE(6594), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7448), 1,
      sym_annotation,
    STATE(6376), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8957), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [329428] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6377), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [329469] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329510] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11037), 1,
      anon_sym_with,
    STATE(6379), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [329553] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6380), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [329594] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6381), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329635] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(10156), 1,
      sym_interpolated_string,
    STATE(14791), 1,
      sym__interpolated_string_start,
    STATE(14838), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11040), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6382), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329688] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6383), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329729] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10650), 1,
      anon_sym_LBRACK,
    ACTIONS(10654), 1,
      anon_sym_POUND,
    ACTIONS(11042), 1,
      anon_sym_AT,
    STATE(7742), 1,
      sym_type_arguments,
    STATE(8563), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9456), 1,
      sym_annotation,
    STATE(6384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329782] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [329823] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6386), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329864] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6387), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329905] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6388), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [329946] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6389), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [329987] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330028] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6391), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [330069] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6392), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330110] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6393), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330151] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6394), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330192] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330233] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330274] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330317] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [330358] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330399] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330440] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10110), 1,
      anon_sym_LPAREN,
    STATE(6405), 1,
      aux_sym_annotation_repeat1,
    STATE(7830), 1,
      sym_arguments,
    STATE(6401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330487] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6402), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330528] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [330571] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330612] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11044), 1,
      anon_sym_LPAREN,
    STATE(7830), 1,
      sym_arguments,
    STATE(6405), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330657] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [330698] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6407), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330739] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10996), 1,
      anon_sym_COLON,
    ACTIONS(10998), 1,
      anon_sym_LBRACE,
    ACTIONS(11000), 1,
      anon_sym_with,
    STATE(6333), 1,
      aux_sym_compound_type_repeat1,
    STATE(10657), 1,
      sym_template_body,
    STATE(10659), 1,
      sym__refinement,
    STATE(6408), 2,
      sym_comment,
      sym_block_comment,
    STATE(10460), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330794] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330835] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6410), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [330876] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1410), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10167), 1,
      anon_sym_LPAREN,
    ACTIONS(11047), 1,
      sym__alpha_identifier,
    ACTIONS(11049), 1,
      anon_sym_DOT,
    ACTIONS(11053), 1,
      anon_sym_EQ,
    ACTIONS(11055), 1,
      sym__backquoted_id,
    ACTIONS(11057), 1,
      sym_operator_identifier,
    STATE(545), 1,
      sym_identifier,
    STATE(4059), 1,
      sym__soft_identifier,
    STATE(6411), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    STATE(9614), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11051), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [330941] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [330982] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6413), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331023] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6414), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [331064] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6415), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331105] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6416), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331146] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10355), 1,
      anon_sym_EQ_GT,
    STATE(6417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331189] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6418), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [331230] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [331271] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [331312] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [331353] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6422), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [331394] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11059), 1,
      anon_sym_DOT,
    STATE(6423), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [331437] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6424), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [331478] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11061), 1,
      anon_sym_LBRACK,
    ACTIONS(11063), 1,
      anon_sym_LPAREN,
    ACTIONS(11065), 1,
      anon_sym_POUND,
    STATE(7859), 1,
      aux_sym_annotation_repeat1,
    STATE(8514), 1,
      sym_type_arguments,
    STATE(9154), 1,
      sym_arguments,
    STATE(6425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331531] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6426), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [331572] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6427), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331613] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6428), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331654] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10857), 1,
      anon_sym_LBRACE,
    ACTIONS(10859), 1,
      anon_sym_with,
    STATE(6165), 1,
      aux_sym_compound_type_repeat1,
    STATE(10193), 1,
      sym__refinement,
    STATE(10399), 1,
      sym_template_body,
    STATE(6429), 2,
      sym_comment,
      sym_block_comment,
    STATE(10357), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331707] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6430), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [331748] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11067), 1,
      anon_sym_DOT,
    STATE(6431), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331791] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4185), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(6432), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [331836] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6433), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [331877] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11071), 1,
      sym__backquoted_id,
    STATE(6434), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11069), 25,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331918] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6435), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [331959] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9745), 1,
      anon_sym_LPAREN,
    STATE(6234), 1,
      aux_sym_annotation_repeat1,
    STATE(7703), 1,
      sym_arguments,
    STATE(6436), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332006] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332047] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332090] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6439), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332131] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9774), 1,
      anon_sym_LPAREN,
    STATE(6447), 1,
      aux_sym_annotation_repeat1,
    STATE(7634), 1,
      sym_arguments,
    STATE(6440), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332178] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6441), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [332219] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1410), 1,
      anon_sym_LBRACE,
    ACTIONS(10167), 1,
      anon_sym_LPAREN,
    ACTIONS(11049), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(6442), 2,
      sym_comment,
      sym_block_comment,
    STATE(9614), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332272] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6443), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332313] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6444), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332354] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6445), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [332395] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6446), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332436] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11073), 1,
      anon_sym_LPAREN,
    STATE(7634), 1,
      sym_arguments,
    STATE(6447), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332481] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11076), 1,
      anon_sym_LPAREN,
    STATE(7908), 1,
      sym_arguments,
    STATE(6448), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8430), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [332526] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6449), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332567] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6450), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [332608] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332649] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8156), 1,
      sym__backquoted_id,
    ACTIONS(10123), 1,
      anon_sym_LPAREN,
    ACTIONS(11079), 1,
      anon_sym_LBRACK,
    ACTIONS(11081), 1,
      anon_sym_POUND,
    STATE(8390), 1,
      aux_sym_annotation_repeat1,
    STATE(8704), 1,
      sym_type_arguments,
    STATE(9629), 1,
      sym_arguments,
    STATE(6452), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8154), 19,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332702] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(10156), 1,
      sym_interpolated_string,
    STATE(14791), 1,
      sym__interpolated_string_start,
    STATE(14838), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6453), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332755] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6791), 1,
      sym_arguments,
    STATE(6454), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [332798] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332839] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1410), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10167), 1,
      anon_sym_LPAREN,
    ACTIONS(11049), 1,
      anon_sym_DOT,
    ACTIONS(11083), 1,
      sym_operator_identifier,
    STATE(1747), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(6456), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8807), 3,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    STATE(9614), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [332904] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10996), 1,
      anon_sym_COLON,
    ACTIONS(10998), 1,
      anon_sym_LBRACE,
    ACTIONS(11000), 1,
      anon_sym_with,
    STATE(6333), 1,
      aux_sym_compound_type_repeat1,
    STATE(10657), 1,
      sym_template_body,
    STATE(10659), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6457), 2,
      sym_comment,
      sym_block_comment,
    STATE(10460), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(8412), 3,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_EQ,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332965] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6458), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [333006] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333047] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6460), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [333088] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6461), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333129] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9729), 1,
      anon_sym_LPAREN,
    STATE(6483), 1,
      aux_sym_annotation_repeat1,
    STATE(7929), 1,
      sym_arguments,
    STATE(6462), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8426), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [333176] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6463), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [333217] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7023), 1,
      sym__end_marker,
    STATE(6464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [333260] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11085), 1,
      anon_sym_with,
    STATE(6465), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333303] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6466), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333344] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333385] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333426] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6469), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [333467] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [333508] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6471), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [333549] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6472), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333590] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [333631] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11088), 1,
      anon_sym_DOT,
    STATE(6474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333674] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10857), 1,
      anon_sym_LBRACE,
    ACTIONS(10859), 1,
      anon_sym_with,
    ACTIONS(11090), 1,
      anon_sym_COLON,
    STATE(6165), 1,
      aux_sym_compound_type_repeat1,
    STATE(10193), 1,
      sym__refinement,
    STATE(10399), 1,
      sym_template_body,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6475), 2,
      sym_comment,
      sym_block_comment,
    STATE(10357), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(8412), 3,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333735] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333776] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333817] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333858] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333899] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6480), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333942] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [333983] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334024] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11093), 1,
      anon_sym_LPAREN,
    STATE(7929), 1,
      sym_arguments,
    STATE(6483), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8430), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [334069] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6484), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334110] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [334151] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6486), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334192] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334233] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10648), 1,
      anon_sym_DOT,
    ACTIONS(11096), 1,
      anon_sym_EQ_GT,
    STATE(6488), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334278] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4181), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(6489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [334323] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6490), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [334364] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334407] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334448] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11098), 1,
      anon_sym_with,
    STATE(6493), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [334491] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6494), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334532] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6495), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334573] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6496), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [334614] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6497), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334655] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6498), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [334696] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [334737] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6500), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334778] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6501), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334819] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334860] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [334901] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6504), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [334942] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6505), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [334983] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335024] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6507), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9098), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [335065] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6508), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335106] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6509), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [335147] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10785), 1,
      anon_sym_LBRACE,
    ACTIONS(10787), 1,
      anon_sym_with,
    ACTIONS(11101), 1,
      anon_sym_COLON,
    STATE(6566), 1,
      aux_sym_compound_type_repeat1,
    STATE(10149), 1,
      sym_template_body,
    STATE(10201), 1,
      sym__refinement,
    ACTIONS(8410), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6510), 2,
      sym_comment,
      sym_block_comment,
    STATE(10295), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8412), 4,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335208] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11104), 1,
      anon_sym_AT,
    STATE(7691), 1,
      sym_annotation,
    STATE(6511), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335253] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [335294] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6803), 1,
      sym__end_marker,
    STATE(6513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [335337] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6514), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335378] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1410), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(10167), 1,
      anon_sym_LPAREN,
    ACTIONS(11049), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(6515), 2,
      sym_comment,
      sym_block_comment,
    STATE(9614), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335433] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6516), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335474] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335515] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10097), 1,
      anon_sym_AT,
    STATE(6082), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7725), 1,
      sym_annotation,
    STATE(6518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8957), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [335562] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6519), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335603] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6520), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [335644] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335685] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6522), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335726] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6523), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [335767] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335808] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11107), 1,
      anon_sym_with,
    STATE(6815), 1,
      aux_sym_compound_type_repeat1,
    STATE(9639), 1,
      sym_template_body,
    STATE(9645), 1,
      sym__refinement,
    STATE(9646), 1,
      sym_arguments,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6525), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335861] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10178), 1,
      anon_sym_LPAREN,
    STATE(6535), 1,
      aux_sym_annotation_repeat1,
    STATE(7774), 1,
      sym_arguments,
    STATE(6526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335908] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6527), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [335949] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [335990] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11109), 1,
      anon_sym_with,
    STATE(6529), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336033] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9453), 1,
      anon_sym_AT,
    STATE(6588), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7990), 1,
      sym_annotation,
    STATE(6530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336080] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6531), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [336121] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [336162] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6533), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [336203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6534), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [336244] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11112), 1,
      anon_sym_LPAREN,
    STATE(7774), 1,
      sym_arguments,
    STATE(6535), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336289] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336332] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4214), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(6537), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [336377] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11115), 1,
      anon_sym_DOT,
    STATE(6538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336420] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6539), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [336461] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10802), 1,
      anon_sym_COLON,
    ACTIONS(10804), 1,
      anon_sym_LBRACE,
    ACTIONS(10806), 1,
      anon_sym_with,
    STATE(6088), 1,
      aux_sym_compound_type_repeat1,
    STATE(10467), 1,
      sym_template_body,
    STATE(10468), 1,
      sym__refinement,
    STATE(6540), 2,
      sym_comment,
      sym_block_comment,
    STATE(10520), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336516] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6541), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [336557] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9086), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [336598] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6543), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [336639] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [336680] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6545), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336721] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [336762] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(477), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9924), 1,
      anon_sym_LPAREN,
    ACTIONS(10853), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(6547), 2,
      sym_comment,
      sym_block_comment,
    STATE(9378), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336817] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336858] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [336899] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336940] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [336981] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10018), 1,
      anon_sym_AT,
    STATE(6232), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7938), 1,
      sym_annotation,
    STATE(6552), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [337028] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337069] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [337110] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337151] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6556), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337192] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [337233] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6558), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337274] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10475), 1,
      anon_sym_LBRACK,
    ACTIONS(10477), 1,
      anon_sym_AT,
    ACTIONS(10481), 1,
      anon_sym_POUND,
    STATE(7979), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8464), 1,
      sym_type_arguments,
    STATE(9293), 1,
      sym_annotation,
    STATE(6559), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [337327] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6560), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337368] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6561), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [337409] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6562), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337450] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6563), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337491] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6564), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [337532] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6565), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9291), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337573] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10785), 1,
      anon_sym_LBRACE,
    ACTIONS(10787), 1,
      anon_sym_with,
    STATE(9028), 1,
      aux_sym_compound_type_repeat1,
    STATE(10149), 1,
      sym_template_body,
    STATE(10213), 1,
      sym__refinement,
    STATE(6566), 2,
      sym_comment,
      sym_block_comment,
    STATE(10295), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [337626] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6567), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337667] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [337708] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337749] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10802), 1,
      anon_sym_COLON,
    ACTIONS(10804), 1,
      anon_sym_LBRACE,
    ACTIONS(10806), 1,
      anon_sym_with,
    STATE(6088), 1,
      aux_sym_compound_type_repeat1,
    STATE(10467), 1,
      sym_template_body,
    STATE(10468), 1,
      sym__refinement,
    ACTIONS(8412), 2,
      anon_sym_STAR,
      anon_sym_finally,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6570), 2,
      sym_comment,
      sym_block_comment,
    STATE(10520), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [337810] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [337851] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10867), 1,
      anon_sym_COLON,
    ACTIONS(10869), 1,
      anon_sym_LBRACE,
    ACTIONS(10871), 1,
      anon_sym_with,
    STATE(9218), 1,
      aux_sym_compound_type_repeat1,
    STATE(10506), 1,
      sym_template_body,
    STATE(10519), 1,
      sym__refinement,
    STATE(6572), 2,
      sym_comment,
      sym_block_comment,
    STATE(10602), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [337906] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337947] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [337988] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [338029] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11117), 1,
      anon_sym_DOT,
    STATE(6576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338072] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(8817), 1,
      sym_operator_identifier,
    STATE(1769), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(6577), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8807), 8,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [338129] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [338170] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338211] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11119), 1,
      anon_sym_AT,
    STATE(7839), 1,
      sym_annotation,
    STATE(6580), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338256] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [338297] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9090), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [338338] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11122), 1,
      anon_sym_DOT,
    STATE(6583), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338381] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9964), 1,
      anon_sym_AT,
    STATE(6039), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8032), 1,
      sym_annotation,
    STATE(6584), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8957), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [338428] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6585), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338469] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [338510] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6587), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [338551] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11124), 1,
      anon_sym_AT,
    STATE(7990), 1,
      sym_annotation,
    STATE(6588), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338596] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9739), 1,
      anon_sym_LPAREN,
    STATE(6609), 1,
      aux_sym_annotation_repeat1,
    STATE(8079), 1,
      sym_arguments,
    STATE(6589), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338643] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [338684] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10410), 1,
      anon_sym_with,
    STATE(9238), 1,
      aux_sym_compound_type_repeat1,
    STATE(9992), 1,
      sym_template_body,
    STATE(10001), 1,
      sym__refinement,
    STATE(6282), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8252), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338735] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338776] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9662), 1,
      anon_sym_LPAREN,
    STATE(6598), 1,
      aux_sym_annotation_repeat1,
    STATE(8001), 1,
      sym_arguments,
    STATE(6593), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338823] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11127), 1,
      anon_sym_AT,
    STATE(7448), 1,
      sym_annotation,
    STATE(6594), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8931), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [338868] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [338909] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [338950] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338991] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11130), 1,
      anon_sym_LPAREN,
    STATE(8001), 1,
      sym_arguments,
    STATE(6598), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339036] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339118] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339159] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6602), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [339200] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6603), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339241] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339282] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [339323] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11033), 1,
      anon_sym_LBRACE,
    ACTIONS(11035), 1,
      anon_sym_with,
    STATE(8897), 1,
      aux_sym_compound_type_repeat1,
    STATE(10175), 1,
      sym__refinement,
    STATE(10260), 1,
      sym_template_body,
    STATE(6606), 2,
      sym_comment,
      sym_block_comment,
    STATE(10329), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8246), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339376] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6607), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [339417] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339458] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11133), 1,
      anon_sym_LPAREN,
    STATE(8079), 1,
      sym_arguments,
    STATE(6609), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339503] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10895), 1,
      anon_sym_COLON,
    ACTIONS(10897), 1,
      anon_sym_LBRACE,
    ACTIONS(10899), 1,
      anon_sym_with,
    STATE(9252), 1,
      aux_sym_compound_type_repeat1,
    STATE(10575), 1,
      sym__refinement,
    STATE(10662), 1,
      sym_template_body,
    STATE(6610), 2,
      sym_comment,
      sym_block_comment,
    STATE(10618), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339558] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10982), 1,
      anon_sym_COLON,
    ACTIONS(10984), 1,
      anon_sym_LBRACE,
    ACTIONS(10986), 1,
      anon_sym_with,
    STATE(6325), 1,
      aux_sym_compound_type_repeat1,
    STATE(10569), 1,
      sym_template_body,
    STATE(10571), 1,
      sym__refinement,
    STATE(6611), 2,
      sym_comment,
      sym_block_comment,
    STATE(10537), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339613] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9687), 1,
      anon_sym_LPAREN,
    STATE(6274), 1,
      aux_sym_annotation_repeat1,
    STATE(7998), 1,
      sym_arguments,
    STATE(6612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339660] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6613), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [339701] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6614), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [339744] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6615), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [339785] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6616), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339826] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6617), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [339867] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6618), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339908] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6619), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [339949] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339990] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6621), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [340031] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [340074] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6623), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [340115] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6624), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [340156] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10139), 1,
      anon_sym_AT,
    STATE(6339), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7958), 1,
      sym_annotation,
    STATE(6625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8957), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [340203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [340244] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11136), 1,
      anon_sym_LBRACK,
    ACTIONS(11138), 1,
      anon_sym_LPAREN,
    ACTIONS(11140), 1,
      anon_sym_POUND,
    STATE(8441), 1,
      sym_type_arguments,
    STATE(8647), 1,
      aux_sym_annotation_repeat1,
    STATE(9704), 1,
      sym_arguments,
    STATE(6627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8154), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [340297] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [340338] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [340381] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10359), 1,
      anon_sym_LBRACK,
    ACTIONS(10361), 1,
      anon_sym_AT,
    ACTIONS(10365), 1,
      anon_sym_POUND,
    STATE(7463), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8143), 1,
      sym_type_arguments,
    STATE(8953), 1,
      sym_annotation,
    STATE(6630), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [340434] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [340475] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9068), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [340516] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [340557] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [340598] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [340639] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6636), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [340680] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [340721] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6638), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [340762] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11142), 1,
      anon_sym_LBRACK,
    ACTIONS(11144), 1,
      anon_sym_LPAREN,
    ACTIONS(11146), 1,
      anon_sym_POUND,
    STATE(7920), 1,
      aux_sym_annotation_repeat1,
    STATE(8534), 1,
      sym_type_arguments,
    STATE(9318), 1,
      sym_arguments,
    STATE(6639), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [340815] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [340856] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [340897] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6642), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [340938] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [340979] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6644), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [341020] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [341061] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11148), 1,
      sym__backquoted_id,
    STATE(6646), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7354), 25,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [341102] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [341143] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6648), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [341184] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [341225] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [341266] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [341307] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [341348] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [341389] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [341432] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [341473] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [341514] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10903), 1,
      anon_sym_COLON,
    ACTIONS(10905), 1,
      anon_sym_LBRACE,
    ACTIONS(10907), 1,
      anon_sym_with,
    STATE(6231), 1,
      aux_sym_compound_type_repeat1,
    STATE(10454), 1,
      sym__refinement,
    STATE(10622), 1,
      sym_template_body,
    STATE(6657), 2,
      sym_comment,
      sym_block_comment,
    STATE(10473), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [341569] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [341610] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6659), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [341651] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6660), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9088), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [341691] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6661), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [341731] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10719), 1,
      anon_sym_AT,
    STATE(6729), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8581), 1,
      sym_annotation,
    STATE(6662), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [341777] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6663), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [341817] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11150), 1,
      anon_sym_COLON,
    ACTIONS(11152), 1,
      anon_sym_COMMA,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11160), 1,
      anon_sym_EQ,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    STATE(15520), 1,
      aux_sym_val_declaration_repeat1,
    STATE(6664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [341893] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11152), 1,
      anon_sym_COMMA,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11166), 1,
      anon_sym_COLON,
    ACTIONS(11168), 1,
      anon_sym_EQ,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    STATE(15522), 1,
      aux_sym_val_declaration_repeat1,
    STATE(6665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [341969] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [342009] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11170), 1,
      anon_sym_COLON,
    ACTIONS(11172), 1,
      anon_sym_LBRACE,
    ACTIONS(11174), 1,
      anon_sym_with,
    STATE(6972), 1,
      aux_sym_compound_type_repeat1,
    STATE(10638), 1,
      sym_template_body,
    STATE(10646), 1,
      sym__refinement,
    STATE(6667), 2,
      sym_comment,
      sym_block_comment,
    STATE(10464), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [342063] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6668), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [342103] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10323), 1,
      anon_sym_RPAREN,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15473), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    STATE(6669), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [342179] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11180), 1,
      anon_sym_RBRACK,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(15890), 1,
      sym__variant_type_parameter,
    STATE(6670), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [342249] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11190), 1,
      anon_sym_COMMA,
    ACTIONS(11192), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    STATE(15555), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(6671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [342325] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [342365] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [342405] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(11194), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(15890), 1,
      sym__variant_type_parameter,
    STATE(6674), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [342475] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6675), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [342515] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [342555] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10159), 1,
      anon_sym_AT,
    STATE(6846), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8213), 1,
      sym_annotation,
    STATE(6677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [342601] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6678), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [342641] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [342681] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9345), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6680), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [342723] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6681), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [342763] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(477), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9924), 1,
      anon_sym_LPAREN,
    ACTIONS(10853), 1,
      anon_sym_DOT,
    ACTIONS(11196), 1,
      sym__alpha_identifier,
    ACTIONS(11200), 1,
      anon_sym_EQ,
    ACTIONS(11202), 1,
      sym__backquoted_id,
    ACTIONS(11204), 1,
      sym_operator_identifier,
    STATE(600), 1,
      sym_identifier,
    STATE(4071), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_if,
      anon_sym_match,
    STATE(6682), 2,
      sym_comment,
      sym_block_comment,
    STATE(9378), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11198), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [342827] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [342867] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10526), 1,
      anon_sym_LPAREN,
    STATE(6689), 1,
      aux_sym_annotation_repeat1,
    STATE(8272), 1,
      sym_arguments,
    STATE(6684), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [342913] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [342953] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8910), 1,
      sym_interpolated_string,
    STATE(14822), 1,
      sym__interpolated_string_start,
    STATE(14827), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11206), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6686), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [343005] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1282), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9080), 1,
      anon_sym_LPAREN,
    ACTIONS(9535), 1,
      anon_sym_DOT,
    ACTIONS(10617), 1,
      sym__alpha_identifier,
    ACTIONS(10623), 1,
      sym__backquoted_id,
    ACTIONS(10625), 1,
      sym_operator_identifier,
    ACTIONS(11208), 1,
      anon_sym_EQ,
    STATE(541), 1,
      sym_identifier,
    STATE(4039), 1,
      sym__soft_identifier,
    ACTIONS(9363), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(6687), 2,
      sym_comment,
      sym_block_comment,
    STATE(7666), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9367), 4,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(10619), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [343069] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9349), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [343111] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11210), 1,
      anon_sym_LPAREN,
    STATE(8272), 1,
      sym_arguments,
    STATE(6689), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [343155] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6690), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [343195] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11213), 1,
      anon_sym_type,
    STATE(6691), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [343237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [343277] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6693), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [343319] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11152), 1,
      anon_sym_COMMA,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11215), 1,
      anon_sym_COLON,
    ACTIONS(11217), 1,
      anon_sym_EQ,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15334), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    STATE(6694), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [343395] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11152), 1,
      anon_sym_COMMA,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11219), 1,
      anon_sym_COLON,
    ACTIONS(11221), 1,
      anon_sym_EQ,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15337), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    STATE(6695), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [343471] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [343511] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [343551] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11223), 1,
      anon_sym_with,
    STATE(6698), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [343593] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6699), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [343633] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6700), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [343673] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [343713] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(11226), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(15890), 1,
      sym__variant_type_parameter,
    STATE(6702), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [343783] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6703), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [343823] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [343863] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [343903] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [343943] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [343983] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(11228), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(15890), 1,
      sym__variant_type_parameter,
    STATE(6708), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [344053] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [344093] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [344133] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 1,
      anon_sym_EQ,
    ACTIONS(11170), 1,
      anon_sym_COLON,
    ACTIONS(11172), 1,
      anon_sym_LBRACE,
    ACTIONS(11174), 1,
      anon_sym_with,
    STATE(6972), 1,
      aux_sym_compound_type_repeat1,
    STATE(10638), 1,
      sym_template_body,
    STATE(10646), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6711), 2,
      sym_comment,
      sym_block_comment,
    STATE(10464), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [344193] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [344233] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10972), 1,
      anon_sym_LBRACK,
    ACTIONS(10974), 1,
      anon_sym_AT,
    ACTIONS(10978), 1,
      anon_sym_POUND,
    STATE(8593), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9237), 1,
      sym_type_arguments,
    STATE(9691), 1,
      sym_annotation,
    STATE(6713), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [344285] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11230), 1,
      anon_sym_COLON,
    ACTIONS(11232), 1,
      anon_sym_LBRACE,
    ACTIONS(11234), 1,
      anon_sym_with,
    STATE(9466), 1,
      aux_sym_compound_type_repeat1,
    STATE(10709), 1,
      sym__refinement,
    STATE(10908), 1,
      sym_template_body,
    STATE(6714), 2,
      sym_comment,
      sym_block_comment,
    STATE(10883), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [344339] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9086), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [344379] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11152), 1,
      anon_sym_COMMA,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11236), 1,
      anon_sym_COLON,
    ACTIONS(11238), 1,
      anon_sym_EQ,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    STATE(15520), 1,
      aux_sym_val_declaration_repeat1,
    STATE(6716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [344455] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11152), 1,
      anon_sym_COMMA,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11240), 1,
      anon_sym_COLON,
    ACTIONS(11242), 1,
      anon_sym_EQ,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    STATE(15522), 1,
      aux_sym_val_declaration_repeat1,
    STATE(6717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [344531] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [344571] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(11244), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(15890), 1,
      sym__variant_type_parameter,
    STATE(6719), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [344641] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [344681] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6721), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [344721] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(11246), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(15890), 1,
      sym__variant_type_parameter,
    STATE(6722), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [344791] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [344831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [344871] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [344911] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6726), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9068), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [344951] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11248), 1,
      anon_sym_DOT,
    STATE(6727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [344993] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6728), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9090), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345033] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11250), 1,
      anon_sym_AT,
    STATE(8581), 1,
      sym_annotation,
    STATE(6729), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [345117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [345157] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(11253), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(15890), 1,
      sym__variant_type_parameter,
    STATE(6732), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [345227] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6733), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345267] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11255), 1,
      anon_sym_COLON,
    ACTIONS(11257), 1,
      anon_sym_LBRACE,
    ACTIONS(11259), 1,
      anon_sym_with,
    STATE(6994), 1,
      aux_sym_compound_type_repeat1,
    STATE(10663), 1,
      sym__refinement,
    STATE(10774), 1,
      sym_template_body,
    STATE(6734), 2,
      sym_comment,
      sym_block_comment,
    STATE(10931), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345321] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(11261), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(15890), 1,
      sym__variant_type_parameter,
    STATE(6735), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [345391] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345431] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [345471] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6738), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9090), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [345511] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [345551] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9098), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345591] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345631] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6742), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9068), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [345671] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11263), 1,
      anon_sym_with,
    STATE(6743), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [345713] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(6744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [345759] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9978), 1,
      sym__backquoted_id,
    STATE(4457), 1,
      aux_sym_modifiers_repeat1,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(6745), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
    ACTIONS(11266), 10,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345807] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345847] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6747), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [345889] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11268), 1,
      anon_sym_AT,
    STATE(8391), 1,
      sym_annotation,
    STATE(6748), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345933] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(11255), 1,
      anon_sym_COLON,
    ACTIONS(11257), 1,
      anon_sym_LBRACE,
    ACTIONS(11259), 1,
      anon_sym_with,
    STATE(6994), 1,
      aux_sym_compound_type_repeat1,
    STATE(10663), 1,
      sym__refinement,
    STATE(10774), 1,
      sym_template_body,
    ACTIONS(8412), 2,
      anon_sym_LT_COLON,
      anon_sym_EQ,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6749), 2,
      sym_comment,
      sym_block_comment,
    STATE(10931), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345993] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11061), 1,
      anon_sym_LBRACK,
    ACTIONS(11065), 1,
      anon_sym_POUND,
    ACTIONS(11271), 1,
      anon_sym_AT,
    STATE(8240), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8514), 1,
      sym_type_arguments,
    STATE(9430), 1,
      sym_annotation,
    STATE(6750), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346045] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346085] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10345), 1,
      anon_sym_LPAREN,
    STATE(6754), 1,
      aux_sym_annotation_repeat1,
    STATE(8557), 1,
      sym_arguments,
    STATE(6752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8426), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [346131] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6753), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346171] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11273), 1,
      anon_sym_LPAREN,
    STATE(8557), 1,
      sym_arguments,
    STATE(6754), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8430), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [346215] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11276), 1,
      anon_sym_with,
    STATE(6755), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346257] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11279), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15361), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    STATE(6756), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [346333] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11281), 1,
      anon_sym_AT,
    STATE(8468), 1,
      sym_annotation,
    STATE(6757), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346377] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6758), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [346417] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346457] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [346497] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6761), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [346537] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346577] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6763), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346619] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [346659] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6765), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [346699] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6766), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9086), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [346739] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6767), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [346779] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9932), 1,
      anon_sym_LPAREN,
    STATE(6773), 1,
      aux_sym_annotation_repeat1,
    STATE(8185), 1,
      sym_arguments,
    STATE(6768), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8426), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [346825] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [346865] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(477), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9924), 1,
      anon_sym_LPAREN,
    ACTIONS(10853), 1,
      anon_sym_DOT,
    ACTIONS(11284), 1,
      sym_operator_identifier,
    STATE(1727), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(8807), 2,
      anon_sym_if,
      anon_sym_match,
    STATE(6770), 2,
      sym_comment,
      sym_block_comment,
    STATE(9378), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [346929] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6771), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346969] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9088), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [347009] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11286), 1,
      anon_sym_LPAREN,
    STATE(8185), 1,
      sym_arguments,
    STATE(6773), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8430), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [347053] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9090), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [347093] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [347133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6776), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [347173] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6777), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [347213] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9098), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [347253] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(11289), 1,
      anon_sym_COLON,
    STATE(9410), 1,
      sym_interpolated_string,
    STATE(15502), 1,
      sym__interpolated_string_start,
    STATE(15503), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(11292), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(6779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [347309] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [347349] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [347389] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [347429] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10078), 1,
      anon_sym_AT,
    STATE(6879), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8392), 1,
      sym_annotation,
    STATE(6783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [347475] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [347515] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11295), 1,
      anon_sym_COLON,
    ACTIONS(11298), 1,
      anon_sym_LBRACE,
    STATE(9184), 1,
      sym_template_body,
    STATE(5352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9230), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 13,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [347563] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [347603] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [347643] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6788), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [347683] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [347723] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [347763] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [347803] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [347843] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10369), 1,
      anon_sym_LPAREN,
    STATE(6800), 1,
      aux_sym_annotation_repeat1,
    STATE(8122), 1,
      sym_arguments,
    STATE(6793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [347889] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11096), 1,
      anon_sym_EQ_GT,
    STATE(6794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [347931] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6795), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [347971] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [348011] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348051] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6798), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [348091] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [348131] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11301), 1,
      anon_sym_LPAREN,
    STATE(8122), 1,
      sym_arguments,
    STATE(6800), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [348175] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348215] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348255] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6803), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [348295] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6804), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348335] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10395), 1,
      anon_sym_LPAREN,
    STATE(6837), 1,
      aux_sym_annotation_repeat1,
    STATE(8268), 1,
      sym_arguments,
    STATE(6805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [348381] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7735), 1,
      sym__end_marker,
    STATE(6806), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348423] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6807), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [348465] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348505] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6809), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348545] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1850), 1,
      anon_sym_LBRACE,
    ACTIONS(10479), 1,
      anon_sym_LPAREN,
    ACTIONS(11304), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(6810), 2,
      sym_comment,
      sym_block_comment,
    STATE(9981), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [348597] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [348637] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [348677] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1850), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10479), 1,
      anon_sym_LPAREN,
    ACTIONS(11304), 1,
      anon_sym_DOT,
    ACTIONS(11306), 1,
      sym_operator_identifier,
    STATE(1760), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(8807), 2,
      anon_sym_match,
      anon_sym_finally,
    STATE(6813), 2,
      sym_comment,
      sym_block_comment,
    STATE(9981), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [348741] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6814), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [348783] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11107), 1,
      anon_sym_with,
    STATE(9450), 1,
      sym__refinement,
    STATE(9499), 1,
      aux_sym_compound_type_repeat1,
    STATE(9639), 1,
      sym_template_body,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6815), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8252), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [348833] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1850), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(10479), 1,
      anon_sym_LPAREN,
    ACTIONS(11304), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(6816), 2,
      sym_comment,
      sym_block_comment,
    STATE(9981), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [348887] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6817), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [348927] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6818), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [348969] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349009] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9086), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [349049] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [349089] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10338), 1,
      anon_sym_AT,
    STATE(6942), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8164), 1,
      sym_annotation,
    STATE(6822), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349135] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6823), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349175] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(477), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(9367), 1,
      anon_sym_match,
    ACTIONS(9924), 1,
      anon_sym_LPAREN,
    ACTIONS(10853), 1,
      anon_sym_DOT,
    ACTIONS(11196), 1,
      sym__alpha_identifier,
    ACTIONS(11202), 1,
      sym__backquoted_id,
    ACTIONS(11204), 1,
      sym_operator_identifier,
    STATE(600), 1,
      sym_identifier,
    STATE(4071), 1,
      sym__soft_identifier,
    ACTIONS(8803), 2,
      anon_sym_COLON,
      anon_sym_if,
    STATE(6824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9856), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    STATE(9378), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(11198), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [349241] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349281] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6826), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349321] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6827), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349361] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10165), 1,
      anon_sym_AT,
    STATE(6748), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8391), 1,
      sym_annotation,
    STATE(6828), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349407] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(8817), 1,
      sym_operator_identifier,
    STATE(1769), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(6829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8807), 8,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [349461] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349501] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349543] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349583] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6833), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349623] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6834), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349663] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9968), 1,
      anon_sym_LPAREN,
    STATE(6840), 1,
      aux_sym_annotation_repeat1,
    STATE(8165), 1,
      sym_arguments,
    STATE(6835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8426), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349709] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [349749] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11308), 1,
      anon_sym_LPAREN,
    STATE(8268), 1,
      sym_arguments,
    STATE(6837), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349793] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349833] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11311), 1,
      anon_sym_with,
    STATE(6839), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [349875] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11314), 1,
      anon_sym_LPAREN,
    STATE(8165), 1,
      sym_arguments,
    STATE(6840), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8430), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349919] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [349959] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6842), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349999] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [350039] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350079] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350121] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11317), 1,
      anon_sym_AT,
    STATE(8213), 1,
      sym_annotation,
    STATE(6846), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350165] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1850), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10479), 1,
      anon_sym_LPAREN,
    ACTIONS(11304), 1,
      anon_sym_DOT,
    ACTIONS(11320), 1,
      sym__alpha_identifier,
    ACTIONS(11324), 1,
      anon_sym_EQ,
    ACTIONS(11326), 1,
      sym__backquoted_id,
    ACTIONS(11328), 1,
      sym_operator_identifier,
    STATE(565), 1,
      sym_identifier,
    STATE(4063), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_match,
      anon_sym_finally,
    STATE(6847), 2,
      sym_comment,
      sym_block_comment,
    STATE(9981), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [350229] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 25,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [350267] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10284), 1,
      anon_sym_COLON,
    ACTIONS(10288), 1,
      anon_sym_with,
    STATE(8131), 1,
      aux_sym_compound_type_repeat1,
    STATE(9908), 1,
      sym_template_body,
    STATE(9948), 1,
      sym__refinement,
    STATE(6849), 2,
      sym_comment,
      sym_block_comment,
    STATE(10043), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350319] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10929), 1,
      anon_sym_DOT,
    ACTIONS(11330), 1,
      anon_sym_EQ_GT,
    STATE(6850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350363] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9974), 1,
      anon_sym_LPAREN,
    STATE(6855), 1,
      aux_sym_annotation_repeat1,
    STATE(8308), 1,
      sym_arguments,
    STATE(6851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350409] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [350449] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(6853), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350491] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6854), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [350531] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11332), 1,
      anon_sym_LPAREN,
    STATE(8308), 1,
      sym_arguments,
    STATE(6855), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350575] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6856), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350615] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6857), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350655] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6858), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9088), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [350695] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350735] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350775] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [350815] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350855] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350895] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6864), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350935] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11335), 1,
      anon_sym_with,
    STATE(6865), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9416), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [350977] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4206), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(6866), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351021] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [351061] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [351101] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9198), 1,
      anon_sym_COLON,
    ACTIONS(9202), 1,
      anon_sym_with,
    STATE(7151), 1,
      aux_sym_compound_type_repeat1,
    STATE(8291), 1,
      sym_template_body,
    STATE(8296), 1,
      sym__refinement,
    STATE(6869), 2,
      sym_comment,
      sym_block_comment,
    STATE(8383), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [351153] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [351193] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6871), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [351233] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [351273] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6873), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9068), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [351313] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351353] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [351393] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [351433] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6877), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351473] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6878), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351513] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11338), 1,
      anon_sym_AT,
    STATE(8392), 1,
      sym_annotation,
    STATE(6879), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [351557] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351597] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6881), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351637] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351677] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6883), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [351717] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6884), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351757] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6885), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351797] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351837] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6887), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351877] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351917] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6889), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351957] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9198), 1,
      anon_sym_COLON,
    ACTIONS(9202), 1,
      anon_sym_with,
    ACTIONS(11341), 1,
      anon_sym_LBRACE,
    STATE(7151), 1,
      aux_sym_compound_type_repeat1,
    STATE(8291), 1,
      sym_template_body,
    STATE(8296), 1,
      sym__refinement,
    ACTIONS(8412), 2,
      anon_sym_case,
      anon_sym_EQ,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6890), 2,
      sym_comment,
      sym_block_comment,
    STATE(8383), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [352017] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6891), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [352057] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11158), 1,
      anon_sym_AT,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    STATE(6892), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10840), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10838), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [352117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6894), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352197] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6896), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352277] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11344), 1,
      anon_sym_DOT,
    STATE(6897), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [352319] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6898), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352359] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [352399] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6900), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352439] = 21,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10877), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(10879), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    STATE(6901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [352511] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6902), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352551] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352591] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352631] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6905), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352711] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6907), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352751] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6908), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352791] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11158), 1,
      anon_sym_AT,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    STATE(6909), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10927), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10925), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [352851] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6910), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [352891] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6911), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352931] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9361), 1,
      sym__alpha_identifier,
    ACTIONS(9371), 1,
      sym__backquoted_id,
    ACTIONS(9373), 1,
      sym_operator_identifier,
    STATE(529), 1,
      sym_identifier,
    STATE(3852), 1,
      sym__soft_identifier,
    STATE(6912), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9365), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(9367), 8,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [352985] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353025] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10945), 1,
      anon_sym_LBRACK,
    ACTIONS(10949), 1,
      anon_sym_POUND,
    ACTIONS(11346), 1,
      anon_sym_AT,
    STATE(8306), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8465), 1,
      sym_type_arguments,
    STATE(9364), 1,
      sym_annotation,
    STATE(6914), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353197] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353277] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353317] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6921), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353357] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6922), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353397] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353437] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353477] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [353517] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353557] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353597] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6928), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353637] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10779), 1,
      anon_sym_EQ_GT,
    STATE(6929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353679] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353719] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [353759] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353799] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353839] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6934), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353879] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6935), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353919] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353959] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6937), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353999] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11348), 1,
      anon_sym_DOT,
    STATE(6938), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354041] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354081] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6940), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [354121] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11152), 1,
      anon_sym_COMMA,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11350), 1,
      anon_sym_COLON,
    ACTIONS(11352), 1,
      anon_sym_EQ,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15035), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    STATE(6941), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [354197] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11354), 1,
      anon_sym_AT,
    STATE(8164), 1,
      sym_annotation,
    STATE(6942), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354241] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [354281] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354321] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11357), 1,
      anon_sym_COLON,
    ACTIONS(11360), 1,
      anon_sym_LBRACE,
    STATE(8813), 1,
      sym_template_body,
    STATE(6945), 2,
      sym_comment,
      sym_block_comment,
    STATE(9294), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 6,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9222), 14,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [354369] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6946), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354409] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9068), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [354449] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354489] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6949), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354529] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9922), 1,
      anon_sym_AT,
    STATE(7013), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8105), 1,
      sym_annotation,
    STATE(6950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354575] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [354615] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [354655] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [354695] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354735] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10792), 1,
      anon_sym_EQ_GT,
    STATE(6955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354777] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [354817] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6957), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [354857] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11152), 1,
      anon_sym_COMMA,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11363), 1,
      anon_sym_COLON,
    ACTIONS(11365), 1,
      anon_sym_EQ,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15135), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    STATE(6958), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [354933] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11367), 1,
      anon_sym_DOT,
    STATE(6959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354975] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(11369), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(15890), 1,
      sym__variant_type_parameter,
    STATE(6960), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [355045] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9519), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [355085] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6962), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [355125] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6963), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [355165] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6964), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [355205] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6965), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [355245] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11374), 1,
      anon_sym_LBRACE,
    STATE(8859), 1,
      sym_template_body,
    STATE(6966), 2,
      sym_comment,
      sym_block_comment,
    STATE(9215), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 13,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355293] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6967), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [355333] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [355373] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [355413] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11136), 1,
      anon_sym_LBRACK,
    ACTIONS(11140), 1,
      anon_sym_POUND,
    ACTIONS(11377), 1,
      anon_sym_AT,
    STATE(8441), 1,
      sym_type_arguments,
    STATE(9135), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9936), 1,
      sym_annotation,
    STATE(6970), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355465] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6971), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [355505] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11170), 1,
      anon_sym_COLON,
    ACTIONS(11172), 1,
      anon_sym_LBRACE,
    ACTIONS(11174), 1,
      anon_sym_with,
    STATE(9612), 1,
      aux_sym_compound_type_repeat1,
    STATE(10465), 1,
      sym__refinement,
    STATE(10638), 1,
      sym_template_body,
    STATE(6972), 2,
      sym_comment,
      sym_block_comment,
    STATE(10464), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355559] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [355599] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355639] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [355679] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [355719] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355759] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 1,
      anon_sym_finally,
    ACTIONS(11379), 1,
      anon_sym_COLON,
    ACTIONS(11381), 1,
      anon_sym_LBRACE,
    ACTIONS(11383), 1,
      anon_sym_with,
    STATE(7071), 1,
      aux_sym_compound_type_repeat1,
    STATE(10672), 1,
      sym_template_body,
    STATE(10725), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6978), 2,
      sym_comment,
      sym_block_comment,
    STATE(10806), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355819] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6979), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [355859] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6980), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [355899] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355939] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6982), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355979] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1808), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9515), 1,
      anon_sym_LPAREN,
    ACTIONS(10483), 1,
      anon_sym_DOT,
    ACTIONS(11385), 1,
      sym__alpha_identifier,
    ACTIONS(11389), 1,
      anon_sym_EQ,
    ACTIONS(11391), 1,
      sym__backquoted_id,
    ACTIONS(11393), 1,
      sym_operator_identifier,
    STATE(563), 1,
      sym_identifier,
    STATE(4068), 1,
      sym__soft_identifier,
    STATE(6983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(9367), 3,
      anon_sym_match,
      anon_sym_then,
      anon_sym_finally,
    STATE(8804), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(11387), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [356043] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [356083] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [356123] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [356163] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [356203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6988), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [356243] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6989), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [356283] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6990), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [356323] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [356363] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6992), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [356403] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6993), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [356443] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11255), 1,
      anon_sym_COLON,
    ACTIONS(11257), 1,
      anon_sym_LBRACE,
    ACTIONS(11259), 1,
      anon_sym_with,
    STATE(9702), 1,
      aux_sym_compound_type_repeat1,
    STATE(10774), 1,
      sym_template_body,
    STATE(10870), 1,
      sym__refinement,
    STATE(6994), 2,
      sym_comment,
      sym_block_comment,
    STATE(10931), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [356497] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10219), 1,
      anon_sym_AT,
    STATE(7056), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8682), 1,
      sym_annotation,
    STATE(6995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [356543] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6996), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9291), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [356583] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [356623] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10821), 1,
      anon_sym_EQ_GT,
    STATE(6998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [356665] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [356705] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7000), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [356745] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [356785] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7002), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [356825] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11213), 1,
      anon_sym_type,
    STATE(7003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [356867] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [356907] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [356947] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9260), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7006), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [356989] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [357029] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7008), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [357069] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [357109] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [357149] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11395), 1,
      anon_sym_COLON,
    ACTIONS(11398), 1,
      anon_sym_LBRACE,
    STATE(8917), 1,
      sym_template_body,
    STATE(7011), 2,
      sym_comment,
      sym_block_comment,
    STATE(8768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 13,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [357197] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7012), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [357237] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11401), 1,
      anon_sym_AT,
    STATE(8105), 1,
      sym_annotation,
    STATE(7013), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [357281] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7014), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [357321] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7015), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [357361] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11067), 1,
      anon_sym_DOT,
    ACTIONS(11404), 1,
      anon_sym_EQ_GT,
    STATE(7016), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [357405] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7017), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [357445] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7018), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [357485] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7019), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [357525] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [357565] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7021), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [357605] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4209), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(7022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [357649] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7023), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [357689] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7024), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [357729] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7025), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [357769] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [357809] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [357849] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7665), 1,
      sym_arguments,
    STATE(7028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [357891] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [357931] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [357971] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11406), 1,
      anon_sym_DOT,
    STATE(7031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358013] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7032), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358053] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9111), 1,
      sym_operator_identifier,
    STATE(1710), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(7033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8807), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [358109] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358149] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [358189] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7036), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [358229] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7037), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [358269] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358309] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7039), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9291), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [358349] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358389] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [358429] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7042), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358469] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10597), 1,
      anon_sym_LPAREN,
    STATE(7055), 1,
      aux_sym_annotation_repeat1,
    STATE(8604), 1,
      sym_arguments,
    STATE(7043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358515] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7044), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358555] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [358595] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358635] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7047), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [358675] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358715] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4223), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(7049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [358759] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [358801] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358841] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [358881] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358921] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358961] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11408), 1,
      anon_sym_LPAREN,
    STATE(8604), 1,
      sym_arguments,
    STATE(7055), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359005] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11411), 1,
      anon_sym_AT,
    STATE(8682), 1,
      sym_annotation,
    STATE(7056), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359049] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [359089] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(7058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [359135] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359175] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359215] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359255] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359295] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [359335] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359375] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7065), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359415] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359455] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359495] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11414), 1,
      anon_sym_DOT,
    STATE(7068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359537] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11416), 1,
      anon_sym_DOT,
    STATE(7069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [359579] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 25,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [359617] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11379), 1,
      anon_sym_COLON,
    ACTIONS(11381), 1,
      anon_sym_LBRACE,
    ACTIONS(11383), 1,
      anon_sym_with,
    STATE(9660), 1,
      aux_sym_compound_type_repeat1,
    STATE(10672), 1,
      sym_template_body,
    STATE(10723), 1,
      sym__refinement,
    STATE(7071), 2,
      sym_comment,
      sym_block_comment,
    STATE(10806), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359711] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10658), 1,
      anon_sym_LPAREN,
    STATE(7078), 1,
      aux_sym_annotation_repeat1,
    STATE(8226), 1,
      sym_arguments,
    STATE(7073), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359757] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9269), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7074), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359799] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7075), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [359839] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7609), 1,
      sym__end_marker,
    STATE(7076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [359881] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(7077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359923] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11418), 1,
      anon_sym_LPAREN,
    STATE(8226), 1,
      sym_arguments,
    STATE(7078), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359967] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360007] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360047] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7081), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360127] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7083), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [360167] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10687), 1,
      anon_sym_AT,
    STATE(6757), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8468), 1,
      sym_annotation,
    STATE(7084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360213] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [360253] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10121), 1,
      anon_sym_AT,
    STATE(7310), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8444), 1,
      sym_annotation,
    STATE(7086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8957), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [360299] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11421), 1,
      anon_sym_COLON,
    ACTIONS(11423), 1,
      anon_sym_LBRACE,
    ACTIONS(11425), 1,
      anon_sym_with,
    STATE(9495), 1,
      aux_sym_compound_type_repeat1,
    STATE(10844), 1,
      sym_template_body,
    STATE(10858), 1,
      sym__refinement,
    STATE(7087), 2,
      sym_comment,
      sym_block_comment,
    STATE(10937), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360353] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7088), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360393] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7089), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360433] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [360473] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7091), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360513] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7092), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [360553] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7093), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [360593] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360633] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7095), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360673] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360713] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7097), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [360753] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360793] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7099), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360833] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360873] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7101), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [360913] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360953] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7103), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [360993] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11427), 1,
      anon_sym_COMMA,
    ACTIONS(11429), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(14808), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    STATE(7104), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [361069] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [361109] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7106), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [361149] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [361189] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10336), 1,
      anon_sym_AT,
    STATE(7198), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8212), 1,
      sym_annotation,
    STATE(7108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8957), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [361235] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7109), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361275] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361315] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361357] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361397] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361437] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7114), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361477] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361517] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361557] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10972), 1,
      anon_sym_LBRACK,
    ACTIONS(10978), 1,
      anon_sym_POUND,
    ACTIONS(11431), 1,
      anon_sym_LPAREN,
    STATE(8262), 1,
      aux_sym_annotation_repeat1,
    STATE(9237), 1,
      sym_type_arguments,
    STATE(9351), 1,
      sym_arguments,
    STATE(7117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8154), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361609] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7118), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361649] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361689] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [361729] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7121), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361769] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7122), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [361809] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7124), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361889] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361929] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7126), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361969] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [362009] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362049] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7129), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362089] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7130), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362129] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7131), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [362169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7132), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362209] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362249] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10627), 1,
      anon_sym_LPAREN,
    STATE(7137), 1,
      aux_sym_annotation_repeat1,
    STATE(8617), 1,
      sym_arguments,
    STATE(7134), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362295] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [362335] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362375] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11433), 1,
      anon_sym_LPAREN,
    STATE(8617), 1,
      sym_arguments,
    STATE(7137), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362419] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362459] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [362499] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [362539] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362581] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362621] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7143), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362661] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [362701] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362741] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7776), 1,
      sym_arguments,
    STATE(7146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362783] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362823] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7148), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [362863] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7149), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362903] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7150), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [362943] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9198), 1,
      anon_sym_COLON,
    ACTIONS(9202), 1,
      anon_sym_with,
    STATE(6263), 1,
      aux_sym_compound_type_repeat1,
    STATE(8291), 1,
      sym_template_body,
    STATE(8333), 1,
      sym__refinement,
    STATE(7151), 2,
      sym_comment,
      sym_block_comment,
    STATE(8383), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362995] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363035] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363075] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363115] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7155), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363155] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [363195] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363235] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363275] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7159), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363315] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7160), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363355] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7161), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363395] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10001), 1,
      anon_sym_AT,
    STATE(7207), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8225), 1,
      sym_annotation,
    STATE(7162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363441] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [363481] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [363521] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363561] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7166), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [363601] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363641] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [363681] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7169), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363721] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [363761] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7171), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [363801] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363841] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363881] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363921] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7175), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363961] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364001] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11436), 1,
      anon_sym_COLON,
    ACTIONS(11438), 1,
      anon_sym_DOT,
    ACTIONS(11440), 1,
      anon_sym_STAR,
    ACTIONS(11442), 1,
      anon_sym_EQ_GT,
    ACTIONS(11444), 1,
      anon_sym_if,
    ACTIONS(11446), 1,
      anon_sym_AT,
    ACTIONS(11448), 1,
      anon_sym_PIPE,
    ACTIONS(11450), 1,
      sym_operator_identifier,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11485), 1,
      sym_interpolated_string,
    STATE(15541), 1,
      sym__interpolated_string_start,
    STATE(15546), 1,
      sym__interpolated_multiline_string_start,
    STATE(17622), 1,
      sym_guard,
    STATE(7177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [364077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364117] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10466), 1,
      anon_sym_AT,
    STATE(7251), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8336), 1,
      sym_annotation,
    STATE(7179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364163] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9443), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [364205] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364245] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7182), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364285] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7183), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364325] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11452), 1,
      anon_sym_with,
    STATE(7184), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [364367] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364407] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7186), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364447] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364487] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364527] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7189), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364567] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7190), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364607] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364647] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [364687] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364727] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(7194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364769] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364809] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11455), 1,
      anon_sym_with,
    STATE(7196), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9416), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [364851] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 25,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [364889] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11458), 1,
      anon_sym_AT,
    STATE(8212), 1,
      sym_annotation,
    STATE(7198), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8931), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [364933] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7199), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364973] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7200), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365013] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365053] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365093] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365173] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365213] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7206), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [365253] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11461), 1,
      anon_sym_AT,
    STATE(8225), 1,
      sym_annotation,
    STATE(7207), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365297] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365337] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365377] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365417] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7211), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365457] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365497] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365537] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11464), 1,
      anon_sym_with,
    STATE(7214), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365579] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7215), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [365619] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10284), 1,
      anon_sym_COLON,
    ACTIONS(10288), 1,
      anon_sym_with,
    STATE(6849), 1,
      aux_sym_compound_type_repeat1,
    STATE(9908), 1,
      sym_template_body,
    STATE(9913), 1,
      sym__refinement,
    STATE(7216), 2,
      sym_comment,
      sym_block_comment,
    STATE(10043), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365711] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7218), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [365751] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10569), 1,
      anon_sym_AT,
    STATE(7286), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8439), 1,
      sym_annotation,
    STATE(7219), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365797] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7220), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [365837] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7221), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [365877] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9291), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [365917] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7223), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [365957] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [365997] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7225), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [366037] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7884), 1,
      sym_arguments,
    STATE(7226), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [366079] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7227), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366119] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(7228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366161] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [366201] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366241] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7231), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [366281] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7232), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366321] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7233), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9098), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [366361] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7234), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366401] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366441] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [366481] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7237), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366521] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7238), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366561] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7239), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [366601] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [366641] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366681] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7242), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366721] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7243), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366761] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 1,
      anon_sym_STAR,
    ACTIONS(11230), 1,
      anon_sym_COLON,
    ACTIONS(11232), 1,
      anon_sym_LBRACE,
    ACTIONS(11234), 1,
      anon_sym_with,
    STATE(6714), 1,
      aux_sym_compound_type_repeat1,
    STATE(10908), 1,
      sym_template_body,
    STATE(10929), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7244), 2,
      sym_comment,
      sym_block_comment,
    STATE(10883), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366821] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11142), 1,
      anon_sym_LBRACK,
    ACTIONS(11146), 1,
      anon_sym_POUND,
    ACTIONS(11467), 1,
      anon_sym_AT,
    STATE(8231), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8534), 1,
      sym_type_arguments,
    STATE(9600), 1,
      sym_annotation,
    STATE(7245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366873] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(10284), 1,
      anon_sym_COLON,
    ACTIONS(10288), 1,
      anon_sym_with,
    ACTIONS(11469), 1,
      anon_sym_LBRACE,
    STATE(6849), 1,
      aux_sym_compound_type_repeat1,
    STATE(9908), 1,
      sym_template_body,
    STATE(9913), 1,
      sym__refinement,
    ACTIONS(8412), 2,
      anon_sym_case,
      anon_sym_EQ,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7246), 2,
      sym_comment,
      sym_block_comment,
    STATE(10043), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366933] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366973] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(11472), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(15890), 1,
      sym__variant_type_parameter,
    STATE(7248), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [367043] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10135), 1,
      anon_sym_LPAREN,
    STATE(7253), 1,
      aux_sym_annotation_repeat1,
    STATE(8349), 1,
      sym_arguments,
    STATE(7249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367089] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7250), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367129] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11474), 1,
      anon_sym_AT,
    STATE(8336), 1,
      sym_annotation,
    STATE(7251), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367173] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(7252), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367215] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11477), 1,
      anon_sym_LPAREN,
    STATE(8349), 1,
      sym_arguments,
    STATE(7253), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367259] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7254), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367299] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7255), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367339] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7256), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [367379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7257), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367419] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11480), 1,
      anon_sym_DOT,
    STATE(7258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367461] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367501] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7260), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7261), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367581] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7262), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367621] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7263), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 8,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367667] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7264), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367707] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10547), 1,
      anon_sym_AT,
    STATE(7312), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8512), 1,
      sym_annotation,
    STATE(7265), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367753] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7266), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9086), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [367793] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7267), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367833] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11421), 1,
      anon_sym_COLON,
    ACTIONS(11423), 1,
      anon_sym_LBRACE,
    ACTIONS(11425), 1,
      anon_sym_with,
    STATE(7087), 1,
      aux_sym_compound_type_repeat1,
    STATE(10844), 1,
      sym_template_body,
    STATE(10846), 1,
      sym__refinement,
    STATE(7268), 2,
      sym_comment,
      sym_block_comment,
    STATE(10937), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367887] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4233), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(7269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [367931] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10980), 1,
      anon_sym_DOT,
    ACTIONS(11482), 1,
      anon_sym_EQ_GT,
    STATE(7270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367975] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7271), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368015] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368055] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7273), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368095] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368135] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9327), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368177] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7276), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9519), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [368217] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368257] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10193), 1,
      anon_sym_LPAREN,
    STATE(7311), 1,
      aux_sym_annotation_repeat1,
    STATE(8428), 1,
      sym_arguments,
    STATE(7278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368303] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7279), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368343] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7280), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368383] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7281), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [368423] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2020), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10363), 1,
      anon_sym_LPAREN,
    ACTIONS(11484), 1,
      sym__alpha_identifier,
    ACTIONS(11486), 1,
      anon_sym_DOT,
    ACTIONS(11490), 1,
      anon_sym_EQ,
    ACTIONS(11492), 1,
      sym__backquoted_id,
    ACTIONS(11494), 1,
      sym_operator_identifier,
    STATE(574), 1,
      sym_identifier,
    STATE(4066), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_match,
      anon_sym_else,
    STATE(7282), 2,
      sym_comment,
      sym_block_comment,
    STATE(9958), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11488), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [368487] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7283), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [368527] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7284), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [368567] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9088), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [368607] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11496), 1,
      anon_sym_AT,
    STATE(8439), 1,
      sym_annotation,
    STATE(7286), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368651] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [368691] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7288), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [368731] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4231), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(7289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [368775] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11499), 1,
      anon_sym_with,
    STATE(7290), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9416), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [368817] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [368857] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11152), 1,
      anon_sym_COMMA,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11502), 1,
      anon_sym_COLON,
    ACTIONS(11504), 1,
      anon_sym_EQ,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15334), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    STATE(7292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [368933] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11152), 1,
      anon_sym_COMMA,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11506), 1,
      anon_sym_COLON,
    ACTIONS(11508), 1,
      anon_sym_EQ,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15337), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    STATE(7293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [369009] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7294), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369049] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2020), 1,
      anon_sym_LBRACE,
    ACTIONS(10363), 1,
      anon_sym_LPAREN,
    ACTIONS(11486), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(7295), 2,
      sym_comment,
      sym_block_comment,
    STATE(9958), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369101] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11510), 1,
      anon_sym_DOT,
    STATE(7296), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369143] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 1,
      anon_sym_else,
    ACTIONS(11421), 1,
      anon_sym_COLON,
    ACTIONS(11423), 1,
      anon_sym_LBRACE,
    ACTIONS(11425), 1,
      anon_sym_with,
    STATE(7087), 1,
      aux_sym_compound_type_repeat1,
    STATE(10844), 1,
      sym_template_body,
    STATE(10846), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7297), 2,
      sym_comment,
      sym_block_comment,
    STATE(10937), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369203] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11436), 1,
      anon_sym_COLON,
    ACTIONS(11438), 1,
      anon_sym_DOT,
    ACTIONS(11440), 1,
      anon_sym_STAR,
    ACTIONS(11444), 1,
      anon_sym_if,
    ACTIONS(11446), 1,
      anon_sym_AT,
    ACTIONS(11448), 1,
      anon_sym_PIPE,
    ACTIONS(11450), 1,
      sym_operator_identifier,
    ACTIONS(11512), 1,
      anon_sym_EQ_GT,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11485), 1,
      sym_interpolated_string,
    STATE(15541), 1,
      sym__interpolated_string_start,
    STATE(15546), 1,
      sym__interpolated_multiline_string_start,
    STATE(16350), 1,
      sym_guard,
    STATE(7298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [369279] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7299), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369319] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2020), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10363), 1,
      anon_sym_LPAREN,
    ACTIONS(11486), 1,
      anon_sym_DOT,
    ACTIONS(11514), 1,
      sym_operator_identifier,
    STATE(1752), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(8807), 2,
      anon_sym_match,
      anon_sym_else,
    STATE(7300), 2,
      sym_comment,
      sym_block_comment,
    STATE(9958), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [369383] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11516), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    STATE(15539), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(7301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [369459] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [369499] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369539] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7304), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [369579] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11230), 1,
      anon_sym_COLON,
    ACTIONS(11232), 1,
      anon_sym_LBRACE,
    ACTIONS(11234), 1,
      anon_sym_with,
    STATE(6714), 1,
      aux_sym_compound_type_repeat1,
    STATE(10908), 1,
      sym_template_body,
    STATE(10929), 1,
      sym__refinement,
    STATE(7305), 2,
      sym_comment,
      sym_block_comment,
    STATE(10883), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369633] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [369673] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9090), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [369713] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(11518), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(15890), 1,
      sym__variant_type_parameter,
    STATE(7308), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [369783] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11520), 1,
      anon_sym_COMMA,
    ACTIONS(11522), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15388), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    STATE(7309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [369859] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11524), 1,
      anon_sym_AT,
    STATE(8444), 1,
      sym_annotation,
    STATE(7310), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8931), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [369903] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11527), 1,
      anon_sym_LPAREN,
    STATE(8428), 1,
      sym_arguments,
    STATE(7311), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369947] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11530), 1,
      anon_sym_AT,
    STATE(8512), 1,
      sym_annotation,
    STATE(7312), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369991] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7313), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [370031] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10150), 1,
      anon_sym_LPAREN,
    STATE(7318), 1,
      aux_sym_annotation_repeat1,
    STATE(8527), 1,
      sym_arguments,
    STATE(7314), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7315), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370157] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(11533), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(15890), 1,
      sym__variant_type_parameter,
    STATE(7317), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [370227] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11535), 1,
      anon_sym_LPAREN,
    STATE(8527), 1,
      sym_arguments,
    STATE(7318), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370271] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370311] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7320), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [370351] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370391] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [370431] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7323), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370471] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7324), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [370511] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7325), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370551] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7326), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [370591] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7327), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [370631] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7328), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [370671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7329), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9519), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [370711] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7330), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [370751] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(107), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9039), 1,
      anon_sym_LPAREN,
    ACTIONS(9391), 1,
      anon_sym_DOT,
    ACTIONS(9854), 1,
      sym__alpha_identifier,
    ACTIONS(9860), 1,
      sym__backquoted_id,
    ACTIONS(11538), 1,
      anon_sym_EQ,
    ACTIONS(11540), 1,
      sym_operator_identifier,
    STATE(575), 1,
      sym_identifier,
    STATE(4043), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(7331), 2,
      sym_comment,
      sym_block_comment,
    STATE(7569), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [370815] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370855] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7333), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [370895] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(107), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9039), 1,
      anon_sym_LPAREN,
    ACTIONS(9391), 1,
      anon_sym_DOT,
    ACTIONS(11542), 1,
      sym_operator_identifier,
    STATE(1730), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(8807), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(7334), 2,
      sym_comment,
      sym_block_comment,
    STATE(7569), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [370959] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7402), 1,
      sym__end_marker,
    STATE(7335), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371001] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7336), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [371041] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371081] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11544), 1,
      anon_sym_with,
    STATE(7338), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371123] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7339), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [371163] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371243] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11547), 1,
      anon_sym_LBRACK,
    ACTIONS(11549), 1,
      anon_sym_LPAREN,
    ACTIONS(11551), 1,
      anon_sym_POUND,
    STATE(9216), 1,
      sym_type_arguments,
    STATE(9282), 1,
      aux_sym_annotation_repeat1,
    STATE(10079), 1,
      sym_arguments,
    STATE(7342), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8154), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371295] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2020), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(10363), 1,
      anon_sym_LPAREN,
    ACTIONS(11486), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(7343), 2,
      sym_comment,
      sym_block_comment,
    STATE(9958), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371349] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    ACTIONS(11553), 1,
      anon_sym_EQ_GT,
    STATE(7344), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [371393] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7345), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371433] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9291), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [371473] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7347), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371513] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371553] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9299), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7349), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [371595] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7350), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9098), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [371635] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7351), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371675] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371715] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7353), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371755] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7354), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371795] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371835] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(477), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9924), 1,
      anon_sym_LPAREN,
    ACTIONS(10853), 1,
      anon_sym_DOT,
    ACTIONS(11196), 1,
      sym__alpha_identifier,
    ACTIONS(11202), 1,
      sym__backquoted_id,
    ACTIONS(11555), 1,
      anon_sym_EQ,
    ACTIONS(11557), 1,
      sym_operator_identifier,
    STATE(564), 1,
      sym_identifier,
    STATE(4071), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(7356), 2,
      sym_comment,
      sym_block_comment,
    STATE(9378), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11198), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [371899] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7357), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371939] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(477), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9924), 1,
      anon_sym_LPAREN,
    ACTIONS(10853), 1,
      anon_sym_DOT,
    ACTIONS(11559), 1,
      sym_operator_identifier,
    STATE(1702), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(8807), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(7358), 2,
      sym_comment,
      sym_block_comment,
    STATE(9378), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [372003] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [372043] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7360), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372083] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7361), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372123] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7362), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372163] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [372203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7364), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372243] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7365), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372283] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11379), 1,
      anon_sym_COLON,
    ACTIONS(11381), 1,
      anon_sym_LBRACE,
    ACTIONS(11383), 1,
      anon_sym_with,
    STATE(7071), 1,
      aux_sym_compound_type_repeat1,
    STATE(10672), 1,
      sym_template_body,
    STATE(10725), 1,
      sym__refinement,
    STATE(7366), 2,
      sym_comment,
      sym_block_comment,
    STATE(10806), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372337] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372377] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372417] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7369), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372457] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7370), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [372497] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9109), 1,
      sym_operator_identifier,
    STATE(1667), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(7371), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8807), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [372553] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372593] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372633] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7374), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372673] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11565), 1,
      anon_sym_with,
    STATE(7375), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372715] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7376), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372755] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(8910), 1,
      sym_interpolated_string,
    STATE(14822), 1,
      sym__interpolated_string_start,
    STATE(14827), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11568), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7377), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [372807] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10889), 1,
      anon_sym_LBRACK,
    ACTIONS(10893), 1,
      anon_sym_POUND,
    ACTIONS(11570), 1,
      anon_sym_AT,
    STATE(8251), 1,
      sym_type_arguments,
    STATE(8299), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9669), 1,
      sym_annotation,
    STATE(7378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372859] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7379), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [372899] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7380), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [372939] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1282), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9080), 1,
      anon_sym_LPAREN,
    ACTIONS(9535), 1,
      anon_sym_DOT,
    ACTIONS(10617), 1,
      sym__alpha_identifier,
    ACTIONS(10623), 1,
      sym__backquoted_id,
    ACTIONS(10625), 1,
      sym_operator_identifier,
    ACTIONS(11572), 1,
      anon_sym_EQ,
    STATE(541), 1,
      sym_identifier,
    STATE(4039), 1,
      sym__soft_identifier,
    ACTIONS(9363), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(7381), 2,
      sym_comment,
      sym_block_comment,
    STATE(7666), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9367), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(10619), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [373003] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9310), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7382), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373045] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7383), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [373085] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [373125] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9312), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [373167] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7386), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373207] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(11033), 1,
      anon_sym_LBRACE,
    ACTIONS(11035), 1,
      anon_sym_with,
    ACTIONS(11574), 1,
      anon_sym_COLON,
    STATE(6606), 1,
      aux_sym_compound_type_repeat1,
    STATE(10260), 1,
      sym_template_body,
    STATE(10266), 1,
      sym__refinement,
    ACTIONS(8410), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7387), 2,
      sym_comment,
      sym_block_comment,
    STATE(10329), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8412), 3,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373267] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7388), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373306] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7389), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373345] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8527), 1,
      sym__alpha_identifier,
    ACTIONS(8533), 1,
      anon_sym__,
    ACTIONS(8537), 1,
      anon_sym_LPAREN,
    ACTIONS(8539), 1,
      sym__backquoted_id,
    ACTIONS(8541), 1,
      sym_operator_identifier,
    STATE(4458), 1,
      sym__simple_type,
    STATE(4810), 1,
      sym_identifier,
    STATE(5008), 1,
      sym__soft_identifier,
    STATE(5624), 1,
      sym_annotated_type,
    STATE(5634), 1,
      sym__annotated_type,
    STATE(17280), 1,
      sym_stable_identifier,
    STATE(7390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8535), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4820), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [373406] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7391), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373445] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(7392), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [373490] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11170), 1,
      anon_sym_COLON,
    ACTIONS(11174), 1,
      anon_sym_with,
    STATE(7537), 1,
      aux_sym_compound_type_repeat1,
    STATE(10638), 1,
      sym_template_body,
    STATE(10646), 1,
      sym__refinement,
    STATE(7393), 2,
      sym_comment,
      sym_block_comment,
    STATE(10464), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7394), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373580] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4540), 1,
      sym__alpha_identifier,
    ACTIONS(4546), 1,
      anon_sym__,
    ACTIONS(4558), 1,
      sym__backquoted_id,
    ACTIONS(6892), 1,
      sym_operator_identifier,
    ACTIONS(7822), 1,
      anon_sym_LPAREN,
    STATE(4984), 1,
      sym__simple_type,
    STATE(5050), 1,
      sym_identifier,
    STATE(5155), 1,
      sym__soft_identifier,
    STATE(7631), 1,
      sym_annotated_type,
    STATE(7781), 1,
      sym__annotated_type,
    STATE(16782), 1,
      sym_stable_identifier,
    STATE(7395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5928), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [373641] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8146), 1,
      sym__end_marker,
    STATE(7396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10127), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [373682] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373721] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9068), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [373760] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373799] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10994), 1,
      anon_sym_LPAREN,
    STATE(7431), 1,
      aux_sym_annotation_repeat1,
    STATE(9021), 1,
      sym_arguments,
    STATE(7400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373844] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8697), 1,
      sym__alpha_identifier,
    ACTIONS(8699), 1,
      anon_sym__,
    ACTIONS(8703), 1,
      anon_sym_LPAREN,
    ACTIONS(8705), 1,
      sym__backquoted_id,
    ACTIONS(8707), 1,
      sym_operator_identifier,
    STATE(5220), 1,
      sym__simple_type,
    STATE(7069), 1,
      sym_identifier,
    STATE(7122), 1,
      sym__soft_identifier,
    STATE(8284), 1,
      sym__annotated_type,
    STATE(8328), 1,
      sym_annotated_type,
    STATE(16800), 1,
      sym_stable_identifier,
    STATE(7401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8701), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7218), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [373905] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7402), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373944] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [373983] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [374022] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7405), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374061] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11577), 1,
      anon_sym_LPAREN,
    STATE(8787), 1,
      sym_arguments,
    STATE(7406), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374104] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7407), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374143] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7408), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374182] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6370), 1,
      sym__alpha_identifier,
    ACTIONS(6376), 1,
      anon_sym__,
    ACTIONS(6384), 1,
      sym__backquoted_id,
    ACTIONS(6386), 1,
      sym_operator_identifier,
    ACTIONS(7502), 1,
      anon_sym_LPAREN,
    STATE(5425), 1,
      sym__simple_type,
    STATE(5485), 1,
      sym__soft_identifier,
    STATE(5665), 1,
      sym_identifier,
    STATE(8438), 1,
      sym__annotated_type,
    STATE(8696), 1,
      sym_annotated_type,
    STATE(16818), 1,
      sym_stable_identifier,
    STATE(7409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6380), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6556), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [374243] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7410), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [374282] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7411), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374321] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11580), 1,
      anon_sym_LBRACK,
    ACTIONS(11582), 1,
      anon_sym_AT,
    ACTIONS(11584), 1,
      anon_sym_LPAREN,
    ACTIONS(11586), 1,
      anon_sym_POUND,
    STATE(9695), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9986), 1,
      sym_type_arguments,
    STATE(10164), 1,
      sym_annotation,
    STATE(10855), 1,
      sym_arguments,
    STATE(7412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 3,
      anon_sym_LBRACE,
      anon_sym_DOT,
      sym__backquoted_id,
    ACTIONS(8078), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374376] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8316), 1,
      sym__alpha_identifier,
    ACTIONS(8322), 1,
      anon_sym__,
    ACTIONS(8326), 1,
      anon_sym_LPAREN,
    ACTIONS(8328), 1,
      sym__backquoted_id,
    ACTIONS(8330), 1,
      sym_operator_identifier,
    STATE(10961), 1,
      sym__simple_type,
    STATE(11509), 1,
      sym_identifier,
    STATE(11550), 1,
      sym__soft_identifier,
    STATE(13099), 1,
      sym__annotated_type,
    STATE(13134), 1,
      sym_annotated_type,
    STATE(16853), 1,
      sym_stable_identifier,
    STATE(7413), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8324), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11787), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [374437] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4572), 1,
      sym__alpha_identifier,
    ACTIONS(4578), 1,
      anon_sym__,
    ACTIONS(4590), 1,
      sym__backquoted_id,
    ACTIONS(6896), 1,
      sym_operator_identifier,
    ACTIONS(7432), 1,
      anon_sym_LPAREN,
    STATE(4753), 1,
      sym__simple_type,
    STATE(5024), 1,
      sym_identifier,
    STATE(5025), 1,
      sym__soft_identifier,
    STATE(6780), 1,
      sym_annotated_type,
    STATE(6797), 1,
      sym__annotated_type,
    STATE(17351), 1,
      sym_stable_identifier,
    STATE(7414), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5296), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [374498] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4216), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(7415), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [374541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7416), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374580] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9443), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [374621] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8715), 1,
      sym__alpha_identifier,
    ACTIONS(8717), 1,
      anon_sym__,
    ACTIONS(8721), 1,
      anon_sym_LPAREN,
    ACTIONS(8723), 1,
      sym__backquoted_id,
    ACTIONS(8725), 1,
      sym_operator_identifier,
    STATE(5301), 1,
      sym__simple_type,
    STATE(6897), 1,
      sym_identifier,
    STATE(7174), 1,
      sym__soft_identifier,
    STATE(8307), 1,
      sym__annotated_type,
    STATE(8623), 1,
      sym_annotated_type,
    STATE(16889), 1,
      sym_stable_identifier,
    STATE(7418), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8719), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6899), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [374682] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [374721] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [374760] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11547), 1,
      anon_sym_LBRACK,
    ACTIONS(11551), 1,
      anon_sym_POUND,
    ACTIONS(11588), 1,
      anon_sym_AT,
    STATE(9216), 1,
      sym_type_arguments,
    STATE(9559), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10327), 1,
      sym_annotation,
    STATE(7421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374811] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7422), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374850] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7423), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374889] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4664), 1,
      sym__alpha_identifier,
    ACTIONS(4670), 1,
      anon_sym__,
    ACTIONS(4682), 1,
      sym__backquoted_id,
    ACTIONS(6544), 1,
      sym_operator_identifier,
    ACTIONS(7782), 1,
      anon_sym_LPAREN,
    STATE(5002), 1,
      sym__simple_type,
    STATE(5067), 1,
      sym_identifier,
    STATE(5176), 1,
      sym__soft_identifier,
    STATE(7437), 1,
      sym__annotated_type,
    STATE(7967), 1,
      sym_annotated_type,
    STATE(16905), 1,
      sym_stable_identifier,
    STATE(7424), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4676), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5890), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [374950] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9484), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374991] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7426), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375030] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7427), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [375069] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7428), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9090), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [375108] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7429), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375147] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7430), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [375186] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11590), 1,
      anon_sym_LPAREN,
    STATE(9021), 1,
      sym_arguments,
    STATE(7431), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375229] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(7482), 1,
      anon_sym_LPAREN,
    STATE(5935), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(8814), 1,
      sym__annotated_type,
    STATE(9108), 1,
      sym_annotated_type,
    STATE(16917), 1,
      sym_stable_identifier,
    STATE(7432), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [375290] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7433), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [375329] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7434), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375368] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7435), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375407] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6482), 1,
      sym__alpha_identifier,
    ACTIONS(6484), 1,
      anon_sym__,
    ACTIONS(6492), 1,
      sym__backquoted_id,
    ACTIONS(6494), 1,
      sym_operator_identifier,
    ACTIONS(7992), 1,
      anon_sym_LPAREN,
    STATE(5945), 1,
      sym__simple_type,
    STATE(6020), 1,
      sym_identifier,
    STATE(6416), 1,
      sym__soft_identifier,
    STATE(9454), 1,
      sym__annotated_type,
    STATE(9690), 1,
      sym_annotated_type,
    STATE(16929), 1,
      sym_stable_identifier,
    STATE(7436), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6488), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7126), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [375468] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375507] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375546] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7439), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [375585] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7440), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375624] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6252), 1,
      sym__alpha_identifier,
    ACTIONS(6258), 1,
      anon_sym__,
    ACTIONS(6266), 1,
      sym__backquoted_id,
    ACTIONS(6268), 1,
      sym_operator_identifier,
    ACTIONS(7792), 1,
      anon_sym_LPAREN,
    STATE(5450), 1,
      sym__simple_type,
    STATE(5492), 1,
      sym__soft_identifier,
    STATE(5705), 1,
      sym_identifier,
    STATE(8761), 1,
      sym_annotated_type,
    STATE(9205), 1,
      sym__annotated_type,
    STATE(16941), 1,
      sym_stable_identifier,
    STATE(7441), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6262), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6211), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [375685] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7442), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9086), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [375724] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8280), 1,
      sym__alpha_identifier,
    ACTIONS(8286), 1,
      anon_sym__,
    ACTIONS(8290), 1,
      anon_sym_LPAREN,
    ACTIONS(8292), 1,
      sym__backquoted_id,
    ACTIONS(8294), 1,
      sym_operator_identifier,
    STATE(10835), 1,
      sym__simple_type,
    STATE(11152), 1,
      sym_identifier,
    STATE(11176), 1,
      sym__soft_identifier,
    STATE(12709), 1,
      sym_annotated_type,
    STATE(12866), 1,
      sym__annotated_type,
    STATE(17410), 1,
      sym_stable_identifier,
    STATE(7443), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11603), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [375785] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7444), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [375824] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4698), 1,
      sym__alpha_identifier,
    ACTIONS(4704), 1,
      anon_sym__,
    ACTIONS(4716), 1,
      sym__backquoted_id,
    ACTIONS(6368), 1,
      sym_operator_identifier,
    ACTIONS(7932), 1,
      anon_sym_LPAREN,
    STATE(5453), 1,
      sym__simple_type,
    STATE(5498), 1,
      sym__soft_identifier,
    STATE(5876), 1,
      sym_identifier,
    STATE(8485), 1,
      sym__annotated_type,
    STATE(8602), 1,
      sym_annotated_type,
    STATE(16963), 1,
      sym_stable_identifier,
    STATE(7445), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4710), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6568), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [375885] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7446), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [375924] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7447), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375963] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7448), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9519), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [376002] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8487), 1,
      sym__alpha_identifier,
    ACTIONS(8489), 1,
      anon_sym__,
    ACTIONS(8493), 1,
      anon_sym_LPAREN,
    ACTIONS(8495), 1,
      sym__backquoted_id,
    ACTIONS(8497), 1,
      sym_operator_identifier,
    STATE(5779), 1,
      sym__simple_type,
    STATE(7616), 1,
      sym__soft_identifier,
    STATE(8045), 1,
      sym_identifier,
    STATE(8916), 1,
      sym__annotated_type,
    STATE(9288), 1,
      sym_annotated_type,
    STATE(16768), 1,
      sym_stable_identifier,
    STATE(7449), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8491), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8075), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [376063] = 19,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15637), 1,
      sym__variant_type_parameter,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(7450), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [376130] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11593), 1,
      anon_sym_DOT,
    STATE(7451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376171] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7452), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376210] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7453), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376251] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11595), 1,
      anon_sym_AT,
    STATE(9109), 1,
      sym_annotation,
    STATE(7454), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8931), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376294] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6518), 1,
      sym__alpha_identifier,
    ACTIONS(6524), 1,
      anon_sym__,
    ACTIONS(6532), 1,
      sym__backquoted_id,
    ACTIONS(6534), 1,
      sym_operator_identifier,
    ACTIONS(7742), 1,
      anon_sym_LPAREN,
    STATE(7378), 1,
      sym__simple_type,
    STATE(7649), 1,
      sym_identifier,
    STATE(7843), 1,
      sym__soft_identifier,
    STATE(9842), 1,
      sym_annotated_type,
    STATE(10106), 1,
      sym__annotated_type,
    STATE(16974), 1,
      sym_stable_identifier,
    STATE(7455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6528), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [376355] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7456), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [376394] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7457), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [376433] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7458), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [376472] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376511] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 1,
      anon_sym_EQ,
    ACTIONS(11170), 1,
      anon_sym_COLON,
    ACTIONS(11174), 1,
      anon_sym_with,
    ACTIONS(11598), 1,
      anon_sym_LBRACE,
    STATE(7537), 1,
      aux_sym_compound_type_repeat1,
    STATE(10638), 1,
      sym_template_body,
    STATE(10646), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7460), 2,
      sym_comment,
      sym_block_comment,
    STATE(10464), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376570] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4732), 1,
      sym__alpha_identifier,
    ACTIONS(4738), 1,
      anon_sym__,
    ACTIONS(4750), 1,
      sym__backquoted_id,
    ACTIONS(6648), 1,
      sym_operator_identifier,
    ACTIONS(7852), 1,
      anon_sym_LPAREN,
    STATE(6090), 1,
      sym__simple_type,
    STATE(6727), 1,
      sym_identifier,
    STATE(7205), 1,
      sym__soft_identifier,
    STATE(9350), 1,
      sym__annotated_type,
    STATE(9502), 1,
      sym_annotated_type,
    STATE(16996), 1,
      sym_stable_identifier,
    STATE(7461), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4744), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7933), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [376631] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7462), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376670] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10361), 1,
      anon_sym_AT,
    STATE(7585), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8953), 1,
      sym_annotation,
    STATE(7463), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376715] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(8344), 1,
      anon_sym_LPAREN,
    ACTIONS(8346), 1,
      sym_operator_identifier,
    STATE(11161), 1,
      sym_identifier,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11574), 1,
      sym__simple_type,
    STATE(12987), 1,
      sym_annotated_type,
    STATE(13736), 1,
      sym__annotated_type,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(7464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [376776] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11601), 1,
      anon_sym_DOT,
    STATE(7465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376817] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7466), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [376856] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376895] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4770), 1,
      sym__alpha_identifier,
    ACTIONS(4772), 1,
      anon_sym__,
    ACTIONS(4782), 1,
      sym__backquoted_id,
    ACTIONS(6710), 1,
      sym_operator_identifier,
    ACTIONS(7612), 1,
      anon_sym_LPAREN,
    STATE(4279), 1,
      sym__simple_type,
    STATE(4395), 1,
      sym_identifier,
    STATE(4399), 1,
      sym__soft_identifier,
    STATE(5118), 1,
      sym__annotated_type,
    STATE(5134), 1,
      sym_annotated_type,
    STATE(17007), 1,
      sym_stable_identifier,
    STATE(7468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4778), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4539), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [376956] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11603), 1,
      anon_sym_LBRACE,
    ACTIONS(11605), 1,
      anon_sym_with,
    STATE(7857), 1,
      aux_sym_compound_type_repeat1,
    STATE(10681), 1,
      sym_template_body,
    STATE(10682), 1,
      sym__refinement,
    STATE(7469), 2,
      sym_comment,
      sym_block_comment,
    STATE(10916), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377007] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [377046] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6760), 1,
      sym__alpha_identifier,
    ACTIONS(6762), 1,
      anon_sym__,
    ACTIONS(6770), 1,
      sym__backquoted_id,
    ACTIONS(6772), 1,
      sym_operator_identifier,
    ACTIONS(7702), 1,
      anon_sym_LPAREN,
    STATE(4677), 1,
      sym__simple_type,
    STATE(4900), 1,
      sym_identifier,
    STATE(4925), 1,
      sym__soft_identifier,
    STATE(6925), 1,
      sym__annotated_type,
    STATE(6971), 1,
      sym_annotated_type,
    STATE(17018), 1,
      sym_stable_identifier,
    STATE(7471), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6766), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5278), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [377107] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(7552), 1,
      anon_sym_LPAREN,
    STATE(5283), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(8091), 1,
      sym_annotated_type,
    STATE(8208), 1,
      sym__annotated_type,
    STATE(17593), 1,
      sym_stable_identifier,
    STATE(7472), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [377168] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377207] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [377246] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4794), 1,
      sym__alpha_identifier,
    ACTIONS(4796), 1,
      anon_sym__,
    ACTIONS(4806), 1,
      sym__backquoted_id,
    ACTIONS(6828), 1,
      sym_operator_identifier,
    ACTIONS(7902), 1,
      anon_sym_LPAREN,
    STATE(4477), 1,
      sym__simple_type,
    STATE(4605), 1,
      sym__soft_identifier,
    STATE(4610), 1,
      sym_identifier,
    STATE(6171), 1,
      sym_annotated_type,
    STATE(6575), 1,
      sym__annotated_type,
    STATE(17024), 1,
      sym_stable_identifier,
    STATE(7475), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4802), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4813), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [377307] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377346] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [377385] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377424] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377463] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10891), 1,
      anon_sym_LPAREN,
    STATE(7496), 1,
      aux_sym_annotation_repeat1,
    STATE(8797), 1,
      sym_arguments,
    STATE(7480), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377508] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9133), 1,
      sym_operator_identifier,
    STATE(1676), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(7481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8807), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [377563] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4820), 1,
      sym__alpha_identifier,
    ACTIONS(4826), 1,
      anon_sym__,
    ACTIONS(4838), 1,
      sym__backquoted_id,
    ACTIONS(6888), 1,
      sym_operator_identifier,
    ACTIONS(7882), 1,
      anon_sym_LPAREN,
    STATE(4479), 1,
      sym__simple_type,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(4630), 1,
      sym_identifier,
    STATE(5999), 1,
      sym_annotated_type,
    STATE(6635), 1,
      sym__annotated_type,
    STATE(17030), 1,
      sym_stable_identifier,
    STATE(7482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4832), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4830), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [377624] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7483), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [377663] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7484), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377702] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377741] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(7486), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377782] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6192), 1,
      sym__alpha_identifier,
    ACTIONS(6198), 1,
      anon_sym__,
    ACTIONS(6206), 1,
      sym__backquoted_id,
    ACTIONS(6208), 1,
      sym_operator_identifier,
    ACTIONS(7842), 1,
      anon_sym_LPAREN,
    STATE(5313), 1,
      sym__simple_type,
    STATE(5503), 1,
      sym_identifier,
    STATE(5516), 1,
      sym__soft_identifier,
    STATE(8169), 1,
      sym__annotated_type,
    STATE(8264), 1,
      sym_annotated_type,
    STATE(17035), 1,
      sym_stable_identifier,
    STATE(7487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6202), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6134), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [377843] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7488), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377882] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10377), 1,
      anon_sym_AT,
    STATE(7583), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8995), 1,
      sym_annotation,
    STATE(7489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8957), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [377927] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7490), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377966] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378005] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378050] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7493), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378089] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7494), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378128] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4852), 1,
      sym__alpha_identifier,
    ACTIONS(4858), 1,
      anon_sym__,
    ACTIONS(4870), 1,
      sym__backquoted_id,
    ACTIONS(6298), 1,
      sym_operator_identifier,
    ACTIONS(7962), 1,
      anon_sym_LPAREN,
    STATE(5391), 1,
      sym__simple_type,
    STATE(5519), 1,
      sym__soft_identifier,
    STATE(5597), 1,
      sym_identifier,
    STATE(8364), 1,
      sym__annotated_type,
    STATE(8415), 1,
      sym_annotated_type,
    STATE(17047), 1,
      sym_stable_identifier,
    STATE(7495), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4864), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6267), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [378189] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11607), 1,
      anon_sym_LPAREN,
    STATE(8797), 1,
      sym_arguments,
    STATE(7496), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378232] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7497), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [378271] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13), 1,
      anon_sym_LBRACE,
    ACTIONS(10976), 1,
      anon_sym_LPAREN,
    ACTIONS(11610), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(7498), 2,
      sym_comment,
      sym_block_comment,
    STATE(10332), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8833), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8831), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378322] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8735), 1,
      sym__alpha_identifier,
    ACTIONS(8737), 1,
      anon_sym__,
    ACTIONS(8741), 1,
      anon_sym_LPAREN,
    ACTIONS(8743), 1,
      sym__backquoted_id,
    ACTIONS(8745), 1,
      sym_operator_identifier,
    STATE(4682), 1,
      sym__simple_type,
    STATE(5520), 1,
      sym__soft_identifier,
    STATE(5547), 1,
      sym_identifier,
    STATE(7303), 1,
      sym__annotated_type,
    STATE(7323), 1,
      sym_annotated_type,
    STATE(17053), 1,
      sym_stable_identifier,
    STATE(7499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8739), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5835), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [378383] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7500), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378422] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11612), 1,
      anon_sym_with,
    STATE(7501), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378463] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378502] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7504), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378580] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7505), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378619] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4882), 1,
      sym__alpha_identifier,
    ACTIONS(4888), 1,
      anon_sym__,
    ACTIONS(4900), 1,
      sym__backquoted_id,
    ACTIONS(6364), 1,
      sym_operator_identifier,
    ACTIONS(7972), 1,
      anon_sym_LPAREN,
    STATE(5446), 1,
      sym__simple_type,
    STATE(5522), 1,
      sym__soft_identifier,
    STATE(5657), 1,
      sym_identifier,
    STATE(8639), 1,
      sym__annotated_type,
    STATE(8698), 1,
      sym_annotated_type,
    STATE(17059), 1,
      sym_stable_identifier,
    STATE(7506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4894), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6372), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [378680] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7507), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [378719] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7508), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [378758] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7509), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [378797] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8749), 1,
      sym__alpha_identifier,
    ACTIONS(8751), 1,
      anon_sym__,
    ACTIONS(8755), 1,
      anon_sym_LPAREN,
    ACTIONS(8757), 1,
      sym__backquoted_id,
    ACTIONS(8759), 1,
      sym_operator_identifier,
    STATE(5448), 1,
      sym__simple_type,
    STATE(7068), 1,
      sym_identifier,
    STATE(7238), 1,
      sym__soft_identifier,
    STATE(8315), 1,
      sym_annotated_type,
    STATE(8374), 1,
      sym__annotated_type,
    STATE(17065), 1,
      sym_stable_identifier,
    STATE(7510), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8753), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7119), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [378858] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7511), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [378897] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378936] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378975] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8543), 1,
      sym__alpha_identifier,
    ACTIONS(8545), 1,
      anon_sym__,
    ACTIONS(8549), 1,
      anon_sym_LPAREN,
    ACTIONS(8551), 1,
      sym__backquoted_id,
    ACTIONS(8553), 1,
      sym_operator_identifier,
    STATE(4987), 1,
      sym__simple_type,
    STATE(6060), 1,
      sym_identifier,
    STATE(6081), 1,
      sym__soft_identifier,
    STATE(7937), 1,
      sym__annotated_type,
    STATE(7953), 1,
      sym_annotated_type,
    STATE(17711), 1,
      sym_stable_identifier,
    STATE(7514), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8547), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6107), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [379036] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(7532), 1,
      anon_sym_LPAREN,
    STATE(5022), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(7851), 1,
      sym_annotated_type,
    STATE(7949), 1,
      sym__annotated_type,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(7515), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [379097] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6278), 1,
      sym__alpha_identifier,
    ACTIONS(6284), 1,
      anon_sym__,
    ACTIONS(6292), 1,
      sym__backquoted_id,
    ACTIONS(6294), 1,
      sym_operator_identifier,
    ACTIONS(7912), 1,
      anon_sym_LPAREN,
    STATE(5075), 1,
      sym__simple_type,
    STATE(5525), 1,
      sym__soft_identifier,
    STATE(5572), 1,
      sym_identifier,
    STATE(8188), 1,
      sym__annotated_type,
    STATE(8337), 1,
      sym_annotated_type,
    STATE(17071), 1,
      sym_stable_identifier,
    STATE(7516), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6477), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [379158] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11615), 1,
      anon_sym_LBRACK,
    ACTIONS(11617), 1,
      anon_sym_LPAREN,
    ACTIONS(11619), 1,
      anon_sym_POUND,
    STATE(9438), 1,
      sym_type_arguments,
    STATE(9525), 1,
      aux_sym_annotation_repeat1,
    STATE(10373), 1,
      sym_arguments,
    STATE(7517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    ACTIONS(8154), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [379209] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [379248] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7519), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [379287] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7520), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [379326] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [379365] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8761), 1,
      sym__alpha_identifier,
    ACTIONS(8763), 1,
      anon_sym__,
    ACTIONS(8767), 1,
      anon_sym_LPAREN,
    ACTIONS(8769), 1,
      sym__backquoted_id,
    ACTIONS(8771), 1,
      sym_operator_identifier,
    STATE(5920), 1,
      sym__simple_type,
    STATE(7705), 1,
      sym_identifier,
    STATE(7907), 1,
      sym__soft_identifier,
    STATE(9116), 1,
      sym__annotated_type,
    STATE(9156), 1,
      sym_annotated_type,
    STATE(17083), 1,
      sym_stable_identifier,
    STATE(7522), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8765), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7863), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [379426] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7523), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [379465] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6344), 1,
      sym__alpha_identifier,
    ACTIONS(6350), 1,
      anon_sym__,
    ACTIONS(6358), 1,
      sym__backquoted_id,
    ACTIONS(6360), 1,
      sym_operator_identifier,
    ACTIONS(7542), 1,
      anon_sym_LPAREN,
    STATE(5615), 1,
      sym__simple_type,
    STATE(6141), 1,
      sym__soft_identifier,
    STATE(6576), 1,
      sym_identifier,
    STATE(9197), 1,
      sym__annotated_type,
    STATE(9227), 1,
      sym_annotated_type,
    STATE(17089), 1,
      sym_stable_identifier,
    STATE(7524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6354), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7247), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [379526] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7525), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [379565] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [379604] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11621), 1,
      anon_sym_DOT,
    STATE(7527), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [379645] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6426), 1,
      anon_sym__,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(6436), 1,
      sym_operator_identifier,
    ACTIONS(7922), 1,
      anon_sym_LPAREN,
    STATE(6914), 1,
      sym__simple_type,
    STATE(7465), 1,
      sym_identifier,
    STATE(7913), 1,
      sym__soft_identifier,
    STATE(10013), 1,
      sym__annotated_type,
    STATE(10061), 1,
      sym_annotated_type,
    STATE(17101), 1,
      sym_stable_identifier,
    STATE(7528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8446), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [379706] = 19,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(15890), 1,
      sym__variant_type_parameter,
    STATE(7529), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [379773] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [379814] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(8276), 1,
      anon_sym_LPAREN,
    ACTIONS(8278), 1,
      sym_operator_identifier,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(11545), 1,
      sym_identifier,
    STATE(11681), 1,
      sym__simple_type,
    STATE(13188), 1,
      sym_annotated_type,
    STATE(13766), 1,
      sym__annotated_type,
    STATE(17819), 1,
      sym_stable_identifier,
    STATE(7531), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11824), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [379875] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8773), 1,
      sym__alpha_identifier,
    ACTIONS(8779), 1,
      anon_sym__,
    ACTIONS(8783), 1,
      anon_sym_LPAREN,
    ACTIONS(8785), 1,
      sym__backquoted_id,
    ACTIONS(8787), 1,
      sym_operator_identifier,
    STATE(4393), 1,
      sym__simple_type,
    STATE(4893), 1,
      sym_identifier,
    STATE(4931), 1,
      sym__soft_identifier,
    STATE(5703), 1,
      sym_annotated_type,
    STATE(5724), 1,
      sym__annotated_type,
    STATE(17113), 1,
      sym_stable_identifier,
    STATE(7532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8781), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4979), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [379936] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6506), 1,
      anon_sym__,
    ACTIONS(6514), 1,
      sym__backquoted_id,
    ACTIONS(6516), 1,
      sym_operator_identifier,
    ACTIONS(7722), 1,
      anon_sym_LPAREN,
    STATE(4455), 1,
      sym__simple_type,
    STATE(4474), 1,
      sym__soft_identifier,
    STATE(4498), 1,
      sym_identifier,
    STATE(5768), 1,
      sym_annotated_type,
    STATE(5782), 1,
      sym__annotated_type,
    STATE(17119), 1,
      sym_stable_identifier,
    STATE(7533), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6510), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4591), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [379997] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(11603), 1,
      anon_sym_LBRACE,
    ACTIONS(11605), 1,
      anon_sym_with,
    ACTIONS(11623), 1,
      anon_sym_COLON,
    STATE(7857), 1,
      aux_sym_compound_type_repeat1,
    STATE(10681), 1,
      sym_template_body,
    STATE(10682), 1,
      sym__refinement,
    ACTIONS(8410), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(8412), 2,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7534), 2,
      sym_comment,
      sym_block_comment,
    STATE(10916), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380056] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11626), 1,
      anon_sym_with,
    STATE(7535), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380097] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6546), 1,
      sym__alpha_identifier,
    ACTIONS(6548), 1,
      anon_sym__,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(6558), 1,
      sym_operator_identifier,
    ACTIONS(7732), 1,
      anon_sym_LPAREN,
    STATE(4676), 1,
      sym__simple_type,
    STATE(4934), 1,
      sym_identifier,
    STATE(4937), 1,
      sym__soft_identifier,
    STATE(6975), 1,
      sym_annotated_type,
    STATE(6988), 1,
      sym__annotated_type,
    STATE(17125), 1,
      sym_stable_identifier,
    STATE(7536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5066), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [380158] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11170), 1,
      anon_sym_COLON,
    ACTIONS(11174), 1,
      anon_sym_with,
    STATE(9612), 1,
      aux_sym_compound_type_repeat1,
    STATE(10465), 1,
      sym__refinement,
    STATE(10638), 1,
      sym_template_body,
    STATE(7537), 2,
      sym_comment,
      sym_block_comment,
    STATE(10464), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8246), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380209] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(832), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10123), 1,
      anon_sym_LPAREN,
    ACTIONS(10855), 1,
      anon_sym_DOT,
    ACTIONS(10873), 1,
      sym_operator_identifier,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_match,
      anon_sym_then,
    STATE(7538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    STATE(9409), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [380272] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8789), 1,
      sym__alpha_identifier,
    ACTIONS(8791), 1,
      anon_sym__,
    ACTIONS(8795), 1,
      anon_sym_LPAREN,
    ACTIONS(8797), 1,
      sym__backquoted_id,
    ACTIONS(8799), 1,
      sym_operator_identifier,
    STATE(4603), 1,
      sym__simple_type,
    STATE(5528), 1,
      sym__soft_identifier,
    STATE(5927), 1,
      sym_identifier,
    STATE(7015), 1,
      sym_annotated_type,
    STATE(7052), 1,
      sym__annotated_type,
    STATE(17131), 1,
      sym_stable_identifier,
    STATE(7539), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8793), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5865), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [380333] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6626), 1,
      sym__alpha_identifier,
    ACTIONS(6632), 1,
      anon_sym__,
    ACTIONS(6640), 1,
      sym__backquoted_id,
    ACTIONS(6642), 1,
      sym_operator_identifier,
    ACTIONS(7712), 1,
      anon_sym_LPAREN,
    STATE(4681), 1,
      sym__simple_type,
    STATE(4939), 1,
      sym__soft_identifier,
    STATE(4959), 1,
      sym_identifier,
    STATE(7063), 1,
      sym_annotated_type,
    STATE(7083), 1,
      sym__annotated_type,
    STATE(17137), 1,
      sym_stable_identifier,
    STATE(7540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5078), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [380394] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8555), 1,
      sym__alpha_identifier,
    ACTIONS(8557), 1,
      anon_sym__,
    ACTIONS(8561), 1,
      anon_sym_LPAREN,
    ACTIONS(8563), 1,
      sym__backquoted_id,
    ACTIONS(8565), 1,
      sym_operator_identifier,
    STATE(5924), 1,
      sym__simple_type,
    STATE(7451), 1,
      sym_identifier,
    STATE(7612), 1,
      sym__soft_identifier,
    STATE(8732), 1,
      sym__annotated_type,
    STATE(8792), 1,
      sym_annotated_type,
    STATE(17871), 1,
      sym_stable_identifier,
    STATE(7541), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8559), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7570), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [380455] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11404), 1,
      anon_sym_EQ_GT,
    STATE(7542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380496] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6650), 1,
      sym__alpha_identifier,
    ACTIONS(6656), 1,
      anon_sym__,
    ACTIONS(6664), 1,
      sym__backquoted_id,
    ACTIONS(6666), 1,
      sym_operator_identifier,
    ACTIONS(7672), 1,
      anon_sym_LPAREN,
    STATE(5598), 1,
      sym__simple_type,
    STATE(6112), 1,
      sym_identifier,
    STATE(6233), 1,
      sym__soft_identifier,
    STATE(8943), 1,
      sym_annotated_type,
    STATE(8973), 1,
      sym__annotated_type,
    STATE(17149), 1,
      sym_stable_identifier,
    STATE(7543), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6660), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6764), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [380557] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(7544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380598] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7545), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380637] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4254), 1,
      sym__alpha_identifier,
    ACTIONS(4260), 1,
      anon_sym__,
    ACTIONS(4272), 1,
      sym__backquoted_id,
    ACTIONS(6732), 1,
      sym_operator_identifier,
    ACTIONS(7512), 1,
      anon_sym_LPAREN,
    STATE(4744), 1,
      sym__simple_type,
    STATE(4846), 1,
      sym_identifier,
    STATE(4941), 1,
      sym__soft_identifier,
    STATE(7118), 1,
      sym_annotated_type,
    STATE(7132), 1,
      sym__annotated_type,
    STATE(17161), 1,
      sym_stable_identifier,
    STATE(7546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4266), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5096), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [380698] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [380737] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6668), 1,
      sym__alpha_identifier,
    ACTIONS(6674), 1,
      anon_sym__,
    ACTIONS(6682), 1,
      sym__backquoted_id,
    ACTIONS(6684), 1,
      sym_operator_identifier,
    ACTIONS(7772), 1,
      anon_sym_LPAREN,
    STATE(5712), 1,
      sym__simple_type,
    STATE(6018), 1,
      sym_identifier,
    STATE(6257), 1,
      sym__soft_identifier,
    STATE(9026), 1,
      sym_annotated_type,
    STATE(9039), 1,
      sym__annotated_type,
    STATE(17167), 1,
      sym_stable_identifier,
    STATE(7548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6678), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6819), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [380798] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380837] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4312), 1,
      sym__alpha_identifier,
    ACTIONS(4318), 1,
      anon_sym__,
    ACTIONS(4330), 1,
      sym__backquoted_id,
    ACTIONS(6790), 1,
      sym_operator_identifier,
    ACTIONS(7602), 1,
      anon_sym_LPAREN,
    STATE(5344), 1,
      sym__simple_type,
    STATE(5532), 1,
      sym__soft_identifier,
    STATE(5857), 1,
      sym_identifier,
    STATE(8214), 1,
      sym_annotated_type,
    STATE(8249), 1,
      sym__annotated_type,
    STATE(17179), 1,
      sym_stable_identifier,
    STATE(7550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4324), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6288), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [380898] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380937] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4344), 1,
      sym__alpha_identifier,
    ACTIONS(4350), 1,
      anon_sym__,
    ACTIONS(4362), 1,
      sym__backquoted_id,
    ACTIONS(6816), 1,
      sym_operator_identifier,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    STATE(5792), 1,
      sym__simple_type,
    STATE(6290), 1,
      sym__soft_identifier,
    STATE(6431), 1,
      sym_identifier,
    STATE(9068), 1,
      sym_annotated_type,
    STATE(9086), 1,
      sym__annotated_type,
    STATE(17185), 1,
      sym_stable_identifier,
    STATE(7552), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4356), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6857), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [380998] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [381037] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381076] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4408), 1,
      sym__alpha_identifier,
    ACTIONS(4410), 1,
      anon_sym__,
    ACTIONS(4420), 1,
      sym__backquoted_id,
    ACTIONS(6820), 1,
      sym_operator_identifier,
    ACTIONS(7422), 1,
      anon_sym_LPAREN,
    STATE(4385), 1,
      sym__simple_type,
    STATE(4469), 1,
      sym_identifier,
    STATE(4476), 1,
      sym__soft_identifier,
    STATE(5974), 1,
      sym_annotated_type,
    STATE(5986), 1,
      sym__annotated_type,
    STATE(17191), 1,
      sym_stable_identifier,
    STATE(7555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4416), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4659), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [381137] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7556), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381176] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381215] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6836), 1,
      anon_sym__,
    ACTIONS(6844), 1,
      sym__backquoted_id,
    ACTIONS(6846), 1,
      sym_operator_identifier,
    ACTIONS(7762), 1,
      anon_sym_LPAREN,
    STATE(8371), 1,
      sym__simple_type,
    STATE(8809), 1,
      sym__soft_identifier,
    STATE(8868), 1,
      sym_identifier,
    STATE(10851), 1,
      sym_annotated_type,
    STATE(10948), 1,
      sym__annotated_type,
    STATE(17197), 1,
      sym_stable_identifier,
    STATE(7558), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6840), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9436), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [381276] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7559), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381315] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7560), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381354] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4434), 1,
      sym__alpha_identifier,
    ACTIONS(4440), 1,
      anon_sym__,
    ACTIONS(4452), 1,
      sym__backquoted_id,
    ACTIONS(6862), 1,
      sym_operator_identifier,
    ACTIONS(7442), 1,
      anon_sym_LPAREN,
    STATE(4590), 1,
      sym__simple_type,
    STATE(4870), 1,
      sym_identifier,
    STATE(4948), 1,
      sym__soft_identifier,
    STATE(7281), 1,
      sym_annotated_type,
    STATE(7304), 1,
      sym__annotated_type,
    STATE(17203), 1,
      sym_stable_identifier,
    STATE(7561), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4446), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5122), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [381415] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7562), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381454] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7563), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [381493] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7564), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381532] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8819), 1,
      sym__alpha_identifier,
    ACTIONS(8821), 1,
      anon_sym__,
    ACTIONS(8825), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      sym__backquoted_id,
    ACTIONS(8829), 1,
      sym_operator_identifier,
    STATE(5039), 1,
      sym__simple_type,
    STATE(6229), 1,
      sym_identifier,
    STATE(6351), 1,
      sym__soft_identifier,
    STATE(7985), 1,
      sym_annotated_type,
    STATE(8010), 1,
      sym__annotated_type,
    STATE(17209), 1,
      sym_stable_identifier,
    STATE(7565), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8823), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6140), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [381593] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7566), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [381632] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7567), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381671] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6690), 1,
      sym__alpha_identifier,
    ACTIONS(6696), 1,
      anon_sym__,
    ACTIONS(6704), 1,
      sym__backquoted_id,
    ACTIONS(6706), 1,
      sym_operator_identifier,
    ACTIONS(7412), 1,
      anon_sym_LPAREN,
    STATE(4955), 1,
      sym__simple_type,
    STATE(5112), 1,
      sym_identifier,
    STATE(5191), 1,
      sym__soft_identifier,
    STATE(8039), 1,
      sym_annotated_type,
    STATE(8070), 1,
      sym__annotated_type,
    STATE(17215), 1,
      sym_stable_identifier,
    STATE(7568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5795), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [381732] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [381771] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7570), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381810] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7572), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [381888] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [381927] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6712), 1,
      sym__alpha_identifier,
    ACTIONS(6718), 1,
      anon_sym__,
    ACTIONS(6726), 1,
      sym__backquoted_id,
    ACTIONS(6728), 1,
      sym_operator_identifier,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    STATE(5977), 1,
      sym__simple_type,
    STATE(6378), 1,
      sym__soft_identifier,
    STATE(6583), 1,
      sym_identifier,
    STATE(9268), 1,
      sym_annotated_type,
    STATE(9304), 1,
      sym__annotated_type,
    STATE(17227), 1,
      sym_stable_identifier,
    STATE(7574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6722), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7014), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [381988] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382027] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11629), 1,
      anon_sym_COLON,
    ACTIONS(11632), 1,
      anon_sym_LBRACE,
    STATE(9374), 1,
      sym_template_body,
    STATE(5571), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9230), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 12,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382074] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7577), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382113] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382152] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6740), 1,
      sym__alpha_identifier,
    ACTIONS(6746), 1,
      anon_sym__,
    ACTIONS(6754), 1,
      sym__backquoted_id,
    ACTIONS(6756), 1,
      sym_operator_identifier,
    ACTIONS(7952), 1,
      anon_sym_LPAREN,
    STATE(6197), 1,
      sym__simple_type,
    STATE(6959), 1,
      sym_identifier,
    STATE(7274), 1,
      sym__soft_identifier,
    STATE(9379), 1,
      sym__annotated_type,
    STATE(9511), 1,
      sym_annotated_type,
    STATE(17239), 1,
      sym_stable_identifier,
    STATE(7579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6750), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7605), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [382213] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9111), 1,
      sym_operator_identifier,
    STATE(1710), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(7580), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8807), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [382266] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [382305] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6774), 1,
      sym__alpha_identifier,
    ACTIONS(6776), 1,
      anon_sym__,
    ACTIONS(6784), 1,
      sym__backquoted_id,
    ACTIONS(6786), 1,
      sym_operator_identifier,
    ACTIONS(7662), 1,
      anon_sym_LPAREN,
    STATE(4495), 1,
      sym__simple_type,
    STATE(4574), 1,
      sym_identifier,
    STATE(4626), 1,
      sym__soft_identifier,
    STATE(6388), 1,
      sym_annotated_type,
    STATE(6645), 1,
      sym__annotated_type,
    STATE(17251), 1,
      sym_stable_identifier,
    STATE(7582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6780), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4851), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [382366] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11635), 1,
      anon_sym_AT,
    STATE(8995), 1,
      sym_annotation,
    STATE(7583), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8931), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [382409] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6114), 1,
      sym__alpha_identifier,
    ACTIONS(6120), 1,
      anon_sym__,
    ACTIONS(6128), 1,
      sym__backquoted_id,
    ACTIONS(6130), 1,
      sym_operator_identifier,
    ACTIONS(7652), 1,
      anon_sym_LPAREN,
    STATE(5030), 1,
      sym__simple_type,
    STATE(5135), 1,
      sym_identifier,
    STATE(5193), 1,
      sym__soft_identifier,
    STATE(7769), 1,
      sym_annotated_type,
    STATE(7945), 1,
      sym__annotated_type,
    STATE(17257), 1,
      sym_stable_identifier,
    STATE(7584), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6124), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5886), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [382470] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11638), 1,
      anon_sym_AT,
    STATE(8953), 1,
      sym_annotation,
    STATE(7585), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382513] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382552] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7587), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382591] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4602), 1,
      sym__alpha_identifier,
    ACTIONS(4608), 1,
      anon_sym__,
    ACTIONS(4620), 1,
      sym__backquoted_id,
    ACTIONS(6176), 1,
      sym_operator_identifier,
    ACTIONS(7832), 1,
      anon_sym_LPAREN,
    STATE(5035), 1,
      sym__simple_type,
    STATE(5163), 1,
      sym_identifier,
    STATE(5195), 1,
      sym__soft_identifier,
    STATE(7405), 1,
      sym__annotated_type,
    STATE(8014), 1,
      sym_annotated_type,
    STATE(17269), 1,
      sym_stable_identifier,
    STATE(7588), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5955), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [382652] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7589), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382691] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382732] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [382771] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    ACTIONS(7642), 1,
      anon_sym_LPAREN,
    STATE(5087), 1,
      sym__simple_type,
    STATE(5538), 1,
      sym__soft_identifier,
    STATE(5956), 1,
      sym_identifier,
    STATE(8410), 1,
      sym__annotated_type,
    STATE(8528), 1,
      sym_annotated_type,
    STATE(17275), 1,
      sym_stable_identifier,
    STATE(7592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6616), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [382832] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7593), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382871] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8567), 1,
      sym__alpha_identifier,
    ACTIONS(8569), 1,
      anon_sym__,
    ACTIONS(8573), 1,
      anon_sym_LPAREN,
    ACTIONS(8575), 1,
      sym__backquoted_id,
    ACTIONS(8577), 1,
      sym_operator_identifier,
    STATE(6630), 1,
      sym__simple_type,
    STATE(8201), 1,
      sym__soft_identifier,
    STATE(8332), 1,
      sym_identifier,
    STATE(9347), 1,
      sym__annotated_type,
    STATE(9547), 1,
      sym_annotated_type,
    STATE(16178), 1,
      sym_stable_identifier,
    STATE(7594), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8571), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8702), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [382932] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [382971] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11641), 1,
      anon_sym_COLON,
    ACTIONS(11644), 1,
      anon_sym_LBRACE,
    STATE(9452), 1,
      sym_template_body,
    STATE(7596), 2,
      sym_comment,
      sym_block_comment,
    STATE(8238), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 6,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9222), 13,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [383018] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383057] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [383096] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383135] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(7600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383176] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383215] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7602), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383254] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7603), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [383293] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383332] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383371] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7606), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 7,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383416] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7607), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383455] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383494] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7609), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [383533] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7610), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383572] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7611), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383611] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383650] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7613), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383689] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7614), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383728] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7615), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383767] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7616), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [383806] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7617), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383845] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7618), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [383884] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8807), 1,
      anon_sym_match,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10976), 1,
      anon_sym_LPAREN,
    ACTIONS(11610), 1,
      anon_sym_DOT,
    ACTIONS(11647), 1,
      sym_operator_identifier,
    STATE(1766), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(7619), 2,
      sym_comment,
      sym_block_comment,
    STATE(10332), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [383947] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4210), 1,
      sym__alpha_identifier,
    ACTIONS(4216), 1,
      anon_sym__,
    ACTIONS(4228), 1,
      sym__backquoted_id,
    ACTIONS(6248), 1,
      sym_operator_identifier,
    ACTIONS(7872), 1,
      anon_sym_LPAREN,
    STATE(5546), 1,
      sym__simple_type,
    STATE(6312), 1,
      sym_identifier,
    STATE(6658), 1,
      sym__soft_identifier,
    STATE(8823), 1,
      sym__annotated_type,
    STATE(8878), 1,
      sym_annotated_type,
    STATE(16208), 1,
      sym_stable_identifier,
    STATE(7620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4222), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7079), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [384008] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7621), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [384047] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384086] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7623), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384125] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7624), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384164] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384242] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384281] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [384320] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [384359] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10373), 1,
      anon_sym_AT,
    STATE(7738), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9066), 1,
      sym_annotation,
    STATE(7630), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384404] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [384443] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [384482] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384521] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384560] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384599] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7636), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384638] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [384677] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7638), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [384716] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8524), 1,
      sym__end_marker,
    STATE(7639), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [384757] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384796] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384835] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11649), 1,
      anon_sym_with,
    STATE(7642), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384876] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [384915] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7644), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384954] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [384993] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    ACTIONS(7492), 1,
      anon_sym_LPAREN,
    STATE(6750), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(9928), 1,
      sym__annotated_type,
    STATE(10041), 1,
      sym_annotated_type,
    STATE(16238), 1,
      sym_stable_identifier,
    STATE(7646), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [385054] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385093] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7648), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [385132] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11652), 1,
      anon_sym_DOT,
    STATE(7649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385173] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385212] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [385251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385290] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11654), 1,
      anon_sym_AT,
    STATE(9003), 1,
      sym_annotation,
    STATE(7653), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385333] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [385372] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4196), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(7655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [385415] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [385454] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7657), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385493] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [385532] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7659), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385571] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(9410), 1,
      sym_interpolated_string,
    STATE(15502), 1,
      sym__interpolated_string_start,
    STATE(15503), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11657), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7660), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385622] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7661), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [385661] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7662), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [385700] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7663), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [385739] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [385778] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [385817] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [385856] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [385895] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11659), 1,
      anon_sym_AT,
    STATE(8731), 1,
      sym_annotation,
    STATE(7668), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385938] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7669), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [385977] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8218), 1,
      sym_arguments,
    STATE(7670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [386018] = 19,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15316), 1,
      sym__variant_type_parameter,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(7671), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [386085] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [386124] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386163] = 21,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10970), 1,
      sym_interpolated_string,
    STATE(15611), 1,
      sym__interpolated_string_start,
    STATE(15612), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11662), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(7674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [386234] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7675), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386273] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [386312] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [386351] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7678), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [386390] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386429] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7680), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386468] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7681), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [386507] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7682), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [386546] = 21,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10970), 1,
      sym_interpolated_string,
    STATE(15611), 1,
      sym__interpolated_string_start,
    STATE(15612), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11664), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(7683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [386617] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7684), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386656] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [386695] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym__alpha_identifier,
    ACTIONS(6462), 1,
      anon_sym__,
    ACTIONS(6470), 1,
      sym__backquoted_id,
    ACTIONS(6472), 1,
      sym_operator_identifier,
    ACTIONS(7452), 1,
      anon_sym_LPAREN,
    STATE(5654), 1,
      sym__simple_type,
    STATE(6003), 1,
      sym_identifier,
    STATE(6313), 1,
      sym__soft_identifier,
    STATE(9426), 1,
      sym__annotated_type,
    STATE(9520), 1,
      sym_annotated_type,
    STATE(16863), 1,
      sym_stable_identifier,
    STATE(7686), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6466), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [386756] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6322), 1,
      sym__alpha_identifier,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    ACTIONS(7862), 1,
      anon_sym_LPAREN,
    STATE(6384), 1,
      sym__simple_type,
    STATE(7031), 1,
      sym_identifier,
    STATE(7267), 1,
      sym__soft_identifier,
    STATE(9861), 1,
      sym_annotated_type,
    STATE(10091), 1,
      sym__annotated_type,
    STATE(16266), 1,
      sym_stable_identifier,
    STATE(7687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7736), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [386817] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386856] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7689), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [386895] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7690), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [386934] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7691), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386973] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8515), 1,
      sym_arguments,
    STATE(7692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [387014] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7693), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [387053] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11666), 1,
      anon_sym_with,
    STATE(7694), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387094] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7695), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [387172] = 19,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15505), 1,
      sym__variant_type_parameter,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(7697), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [387239] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [387278] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(7699), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387319] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7700), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [387358] = 21,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10970), 1,
      sym_interpolated_string,
    STATE(15611), 1,
      sym__interpolated_string_start,
    STATE(15612), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10321), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(7701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [387429] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [387468] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7703), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387507] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [387546] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11669), 1,
      anon_sym_DOT,
    STATE(7705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387587] = 21,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10970), 1,
      sym_interpolated_string,
    STATE(15611), 1,
      sym__interpolated_string_start,
    STATE(15612), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11671), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(7706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [387658] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387697] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9835), 1,
      sym__alpha_identifier,
    ACTIONS(9841), 1,
      sym__backquoted_id,
    ACTIONS(9843), 1,
      sym_operator_identifier,
    STATE(531), 1,
      sym_identifier,
    STATE(3976), 1,
      sym__soft_identifier,
    STATE(7708), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9837), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(9367), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [387750] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6388), 1,
      sym__alpha_identifier,
    ACTIONS(6394), 1,
      anon_sym__,
    ACTIONS(6402), 1,
      sym__backquoted_id,
    ACTIONS(6404), 1,
      sym_operator_identifier,
    ACTIONS(7982), 1,
      anon_sym_LPAREN,
    STATE(5646), 1,
      sym__simple_type,
    STATE(6195), 1,
      sym_identifier,
    STATE(6548), 1,
      sym__soft_identifier,
    STATE(9342), 1,
      sym__annotated_type,
    STATE(9396), 1,
      sym_annotated_type,
    STATE(16293), 1,
      sym_stable_identifier,
    STATE(7709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6398), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7147), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [387811] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8885), 1,
      sym__alpha_identifier,
    ACTIONS(8887), 1,
      anon_sym__,
    ACTIONS(8891), 1,
      anon_sym_LPAREN,
    ACTIONS(8893), 1,
      sym__backquoted_id,
    ACTIONS(8895), 1,
      sym_operator_identifier,
    STATE(6713), 1,
      sym__simple_type,
    STATE(8971), 1,
      sym_identifier,
    STATE(8990), 1,
      sym__soft_identifier,
    STATE(9758), 1,
      sym__annotated_type,
    STATE(9795), 1,
      sym_annotated_type,
    STATE(17521), 1,
      sym_stable_identifier,
    STATE(7710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8889), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9102), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [387872] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387911] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [387950] = 19,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15613), 1,
      sym__variant_type_parameter,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(7713), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [388017] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7714), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [388056] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [388095] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [388134] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [388173] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [388212] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(7719), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [388257] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [388296] = 19,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15548), 1,
      sym__variant_type_parameter,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(7721), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [388363] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [388402] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [388441] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [388480] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9519), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [388519] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7726), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [388558] = 19,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8401), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15553), 1,
      sym__variant_type_parameter,
    STATE(15882), 1,
      sym__type_parameter,
    STATE(7727), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16051), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [388625] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7728), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [388664] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [388703] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [388742] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8579), 1,
      sym__alpha_identifier,
    ACTIONS(8585), 1,
      anon_sym__,
    ACTIONS(8589), 1,
      anon_sym_LPAREN,
    ACTIONS(8591), 1,
      sym__backquoted_id,
    ACTIONS(8593), 1,
      sym_operator_identifier,
    STATE(4486), 1,
      sym__simple_type,
    STATE(5231), 1,
      sym__soft_identifier,
    STATE(5372), 1,
      sym_identifier,
    STATE(6174), 1,
      sym__annotated_type,
    STATE(6238), 1,
      sym_annotated_type,
    STATE(16340), 1,
      sym_stable_identifier,
    STATE(7731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8587), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5387), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [388803] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11248), 1,
      anon_sym_DOT,
    ACTIONS(11673), 1,
      anon_sym_EQ_GT,
    STATE(7732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [388846] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7733), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [388885] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(7734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [388926] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7735), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [388965] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389004] = 21,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10970), 1,
      sym_interpolated_string,
    STATE(15611), 1,
      sym__interpolated_string_start,
    STATE(15612), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11675), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(7737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [389075] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11677), 1,
      anon_sym_AT,
    STATE(9066), 1,
      sym_annotation,
    STATE(7738), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389118] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [389157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [389196] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [389235] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7742), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389274] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [389313] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389352] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7745), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389391] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389430] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7747), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [389469] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389508] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7749), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389547] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(7750), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389588] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389627] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389666] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8224), 1,
      sym__end_marker,
    STATE(7753), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389707] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1484), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9341), 1,
      anon_sym_LPAREN,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(9809), 1,
      anon_sym_DOT,
    ACTIONS(10828), 1,
      sym__alpha_identifier,
    ACTIONS(10834), 1,
      sym__backquoted_id,
    ACTIONS(10836), 1,
      sym_operator_identifier,
    ACTIONS(11680), 1,
      anon_sym_EQ,
    STATE(548), 1,
      sym_identifier,
    STATE(4051), 1,
      sym__soft_identifier,
    STATE(7754), 2,
      sym_comment,
      sym_block_comment,
    STATE(8599), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9367), 4,
      anon_sym_while,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10830), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [389770] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4286), 1,
      sym__alpha_identifier,
    ACTIONS(4288), 1,
      anon_sym__,
    ACTIONS(4298), 1,
      sym__backquoted_id,
    ACTIONS(6538), 1,
      sym_operator_identifier,
    ACTIONS(7462), 1,
      anon_sym_LPAREN,
    STATE(4440), 1,
      sym__simple_type,
    STATE(4467), 1,
      sym__soft_identifier,
    STATE(4504), 1,
      sym_identifier,
    STATE(5796), 1,
      sym__annotated_type,
    STATE(5824), 1,
      sym_annotated_type,
    STATE(16363), 1,
      sym_stable_identifier,
    STATE(7755), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4294), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4713), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [389831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7756), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [389870] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7757), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389909] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7758), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389948] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389987] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [390026] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7761), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390065] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390104] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10840), 1,
      sym__backquoted_id,
    ACTIONS(11438), 1,
      anon_sym_DOT,
    ACTIONS(11446), 1,
      anon_sym_AT,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11485), 1,
      sym_interpolated_string,
    STATE(15541), 1,
      sym__interpolated_string_start,
    STATE(15546), 1,
      sym__interpolated_multiline_string_start,
    STATE(7763), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10838), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390163] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390202] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11213), 1,
      anon_sym_type,
    STATE(7765), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [390243] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7766), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [390282] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7767), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390321] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7768), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390360] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [390399] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(10976), 1,
      anon_sym_LPAREN,
    ACTIONS(11610), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(7770), 2,
      sym_comment,
      sym_block_comment,
    STATE(10332), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 10,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390452] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7771), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [390491] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11436), 1,
      anon_sym_COLON,
    ACTIONS(11438), 1,
      anon_sym_DOT,
    ACTIONS(11440), 1,
      anon_sym_STAR,
    ACTIONS(11446), 1,
      anon_sym_AT,
    ACTIONS(11450), 1,
      sym_operator_identifier,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11485), 1,
      sym_interpolated_string,
    STATE(15541), 1,
      sym__interpolated_string_start,
    STATE(15546), 1,
      sym__interpolated_multiline_string_start,
    STATE(7772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10879), 3,
      anon_sym_EQ_GT,
      anon_sym_if,
      anon_sym_PIPE,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [390560] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7773), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [390599] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390638] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390677] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7776), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390716] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    ACTIONS(7572), 1,
      anon_sym_LPAREN,
    STATE(4639), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(7092), 1,
      sym__annotated_type,
    STATE(7127), 1,
      sym_annotated_type,
    STATE(16383), 1,
      sym_stable_identifier,
    STATE(7777), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [390777] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10464), 1,
      anon_sym_AT,
    STATE(7828), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9131), 1,
      sym_annotation,
    STATE(7778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390822] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10927), 1,
      sym__backquoted_id,
    ACTIONS(11438), 1,
      anon_sym_DOT,
    ACTIONS(11446), 1,
      anon_sym_AT,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11485), 1,
      sym_interpolated_string,
    STATE(15541), 1,
      sym__interpolated_string_start,
    STATE(15546), 1,
      sym__interpolated_multiline_string_start,
    STATE(7779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10925), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390881] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390920] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [390959] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(7782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [391000] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [391039] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [391078] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391117] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8151), 1,
      sym_arguments,
    STATE(7786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391158] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391197] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7788), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391236] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391277] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [391316] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391355] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391394] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [391433] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11023), 1,
      anon_sym_LPAREN,
    STATE(7798), 1,
      aux_sym_annotation_repeat1,
    STATE(9106), 1,
      sym_arguments,
    STATE(7794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391478] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7795), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [391517] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9555), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391558] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391597] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11682), 1,
      anon_sym_LPAREN,
    STATE(9106), 1,
      sym_arguments,
    STATE(7798), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391640] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [391679] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6580), 1,
      anon_sym__,
    ACTIONS(6588), 1,
      sym__backquoted_id,
    ACTIONS(6590), 1,
      sym_operator_identifier,
    ACTIONS(7522), 1,
      anon_sym_LPAREN,
    STATE(5708), 1,
      sym__simple_type,
    STATE(6199), 1,
      sym__soft_identifier,
    STATE(6337), 1,
      sym_identifier,
    STATE(9477), 1,
      sym__annotated_type,
    STATE(9519), 1,
      sym_annotated_type,
    STATE(16404), 1,
      sym_stable_identifier,
    STATE(7800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7227), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [391740] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [391779] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [391818] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7803), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [391857] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11685), 1,
      anon_sym_DOT,
    STATE(7804), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391898] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [391937] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7806), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [391976] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7807), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [392015] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392054] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7809), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392093] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6606), 1,
      anon_sym__,
    ACTIONS(6614), 1,
      sym__backquoted_id,
    ACTIONS(6616), 1,
      sym_operator_identifier,
    ACTIONS(7812), 1,
      anon_sym_LPAREN,
    STATE(5326), 1,
      sym__simple_type,
    STATE(5817), 1,
      sym__soft_identifier,
    STATE(5848), 1,
      sym_identifier,
    STATE(9079), 1,
      sym__annotated_type,
    STATE(9098), 1,
      sym_annotated_type,
    STATE(16425), 1,
      sym_stable_identifier,
    STATE(7810), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6610), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6472), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [392154] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [392193] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(7812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392234] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [392273] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1374), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9208), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_DOT,
    ACTIONS(11004), 1,
      sym__alpha_identifier,
    ACTIONS(11010), 1,
      sym__backquoted_id,
    ACTIONS(11012), 1,
      sym_operator_identifier,
    ACTIONS(11687), 1,
      anon_sym_EQ,
    STATE(544), 1,
      sym_identifier,
    STATE(4058), 1,
      sym__soft_identifier,
    ACTIONS(9363), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(7814), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
    STATE(8511), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(11006), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [392336] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7815), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [392375] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7816), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [392414] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7817), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392453] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7818), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392492] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11689), 1,
      anon_sym_with,
    STATE(7819), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [392533] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392572] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [392611] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7822), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [392650] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7823), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392689] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392728] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11692), 1,
      anon_sym_DOT,
    STATE(7825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392769] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7826), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392808] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7827), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392847] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11694), 1,
      anon_sym_AT,
    STATE(9131), 1,
      sym_annotation,
    STATE(7828), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392890] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [392929] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392968] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8503), 1,
      sym__alpha_identifier,
    ACTIONS(8505), 1,
      anon_sym__,
    ACTIONS(8509), 1,
      anon_sym_LPAREN,
    ACTIONS(8511), 1,
      sym__backquoted_id,
    ACTIONS(8513), 1,
      sym_operator_identifier,
    STATE(5811), 1,
      sym__simple_type,
    STATE(7788), 1,
      sym__soft_identifier,
    STATE(7804), 1,
      sym_identifier,
    STATE(8796), 1,
      sym_annotated_type,
    STATE(9132), 1,
      sym__annotated_type,
    STATE(16966), 1,
      sym_stable_identifier,
    STATE(7831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8507), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [393029] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6792), 1,
      sym__alpha_identifier,
    ACTIONS(6794), 1,
      anon_sym__,
    ACTIONS(6802), 1,
      sym__backquoted_id,
    ACTIONS(6804), 1,
      sym_operator_identifier,
    ACTIONS(7892), 1,
      anon_sym_LPAREN,
    STATE(7421), 1,
      sym__simple_type,
    STATE(8149), 1,
      sym__soft_identifier,
    STATE(8152), 1,
      sym_identifier,
    STATE(10491), 1,
      sym__annotated_type,
    STATE(10572), 1,
      sym_annotated_type,
    STATE(16446), 1,
      sym_stable_identifier,
    STATE(7832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6798), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9214), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [393090] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7833), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9733), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [393129] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11697), 1,
      anon_sym_with,
    STATE(7834), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9416), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [393170] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393209] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393248] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7837), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393287] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393326] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7839), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393365] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393404] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [393443] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7842), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [393482] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393521] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10885), 1,
      anon_sym_AT,
    STATE(8054), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8774), 1,
      sym_annotation,
    STATE(7844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393566] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393605] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7846), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [393644] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7847), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393683] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393722] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7849), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393761] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393800] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [393839] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393878] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    ACTIONS(7632), 1,
      anon_sym_LPAREN,
    STATE(6970), 1,
      sym__simple_type,
    STATE(7680), 1,
      sym__soft_identifier,
    STATE(7825), 1,
      sym_identifier,
    STATE(10180), 1,
      sym_annotated_type,
    STATE(10285), 1,
      sym__annotated_type,
    STATE(16467), 1,
      sym_stable_identifier,
    STATE(7853), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8431), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [393939] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7854), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [393978] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7855), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394017] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7856), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394056] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11603), 1,
      anon_sym_LBRACE,
    ACTIONS(11605), 1,
      anon_sym_with,
    STATE(9823), 1,
      aux_sym_compound_type_repeat1,
    STATE(10681), 1,
      sym_template_body,
    STATE(10699), 1,
      sym__refinement,
    STATE(7857), 2,
      sym_comment,
      sym_block_comment,
    STATE(10916), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8246), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394107] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11700), 1,
      anon_sym_with,
    STATE(7858), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394148] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11063), 1,
      anon_sym_LPAREN,
    STATE(7864), 1,
      aux_sym_annotation_repeat1,
    STATE(9154), 1,
      sym_arguments,
    STATE(7859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394193] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [394232] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394271] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394310] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394349] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11703), 1,
      anon_sym_LPAREN,
    STATE(9154), 1,
      sym_arguments,
    STATE(7864), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394392] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394431] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7866), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394470] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9441), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394511] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394550] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8595), 1,
      sym__alpha_identifier,
    ACTIONS(8597), 1,
      anon_sym__,
    ACTIONS(8601), 1,
      anon_sym_LPAREN,
    ACTIONS(8603), 1,
      sym__backquoted_id,
    ACTIONS(8605), 1,
      sym_operator_identifier,
    STATE(4850), 1,
      sym__simple_type,
    STATE(6423), 1,
      sym_identifier,
    STATE(6470), 1,
      sym__soft_identifier,
    STATE(7813), 1,
      sym__annotated_type,
    STATE(7846), 1,
      sym_annotated_type,
    STATE(16488), 1,
      sym_stable_identifier,
    STATE(7869), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8599), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6546), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [394611] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11706), 1,
      anon_sym_COLON,
    ACTIONS(11709), 1,
      anon_sym_LBRACE,
    STATE(9628), 1,
      sym_template_body,
    STATE(5972), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9230), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 12,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394658] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7871), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394697] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394736] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7873), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [394775] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9098), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [394814] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394853] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394892] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7877), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [394931] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10808), 1,
      anon_sym_AT,
    STATE(7668), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8731), 1,
      sym_annotation,
    STATE(7878), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394976] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7879), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [395015] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [395054] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7881), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395093] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11712), 1,
      anon_sym_DOT,
    STATE(7882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395134] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7883), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395173] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7884), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [395212] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4376), 1,
      sym__alpha_identifier,
    ACTIONS(4382), 1,
      anon_sym__,
    ACTIONS(4394), 1,
      sym__backquoted_id,
    ACTIONS(6824), 1,
      sym_operator_identifier,
    ACTIONS(7752), 1,
      anon_sym_LPAREN,
    STATE(4887), 1,
      sym__simple_type,
    STATE(5049), 1,
      sym__soft_identifier,
    STATE(5197), 1,
      sym_identifier,
    STATE(7833), 1,
      sym__annotated_type,
    STATE(7877), 1,
      sym_annotated_type,
    STATE(16509), 1,
      sym_stable_identifier,
    STATE(7885), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5943), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [395273] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395312] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10652), 1,
      anon_sym_LPAREN,
    STATE(7892), 1,
      aux_sym_annotation_repeat1,
    STATE(9168), 1,
      sym_arguments,
    STATE(7887), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395357] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395396] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7889), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395435] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9375), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395476] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11714), 1,
      anon_sym_with,
    STATE(7891), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9416), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [395517] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11717), 1,
      anon_sym_LPAREN,
    STATE(9168), 1,
      sym_arguments,
    STATE(7892), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395560] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395599] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(107), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9039), 1,
      anon_sym_LPAREN,
    ACTIONS(9367), 1,
      anon_sym_match,
    ACTIONS(9391), 1,
      anon_sym_DOT,
    ACTIONS(9854), 1,
      sym__alpha_identifier,
    ACTIONS(9860), 1,
      sym__backquoted_id,
    ACTIONS(9862), 1,
      sym_operator_identifier,
    ACTIONS(11720), 1,
      anon_sym_EQ,
    STATE(553), 1,
      sym_identifier,
    STATE(4043), 1,
      sym__soft_identifier,
    STATE(7894), 2,
      sym_comment,
      sym_block_comment,
    STATE(7569), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [395662] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9234), 1,
      sym_operator_identifier,
    STATE(1777), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(7895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8807), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [395717] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7896), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 24,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [395754] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7897), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395793] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7898), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395832] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395871] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7900), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395910] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395949] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7902), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [395990] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396029] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396068] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7905), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [396107] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396146] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7907), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396185] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7908), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9291), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [396224] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8209), 1,
      sym__end_marker,
    STATE(7909), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396265] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11330), 1,
      anon_sym_EQ_GT,
    STATE(7910), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396306] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7911), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [396345] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7912), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396384] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396423] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8607), 1,
      sym__alpha_identifier,
    ACTIONS(8609), 1,
      anon_sym__,
    ACTIONS(8613), 1,
      anon_sym_LPAREN,
    ACTIONS(8615), 1,
      sym__backquoted_id,
    ACTIONS(8617), 1,
      sym_operator_identifier,
    STATE(5009), 1,
      sym__simple_type,
    STATE(6383), 1,
      sym__soft_identifier,
    STATE(6474), 1,
      sym_identifier,
    STATE(7861), 1,
      sym__annotated_type,
    STATE(7906), 1,
      sym_annotated_type,
    STATE(16530), 1,
      sym_stable_identifier,
    STATE(7914), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8611), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6585), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [396484] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [396523] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4190), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(7916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396566] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11722), 1,
      anon_sym_with,
    STATE(7917), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396607] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(7692), 1,
      anon_sym_LPAREN,
    STATE(5801), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(9329), 1,
      sym__annotated_type,
    STATE(9731), 1,
      sym_annotated_type,
    STATE(17060), 1,
      sym_stable_identifier,
    STATE(7918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [396668] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396707] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11144), 1,
      anon_sym_LPAREN,
    STATE(7941), 1,
      aux_sym_annotation_repeat1,
    STATE(9318), 1,
      sym_arguments,
    STATE(7920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396752] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7921), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [396791] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11725), 1,
      anon_sym_with,
    STATE(7922), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9416), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [396832] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4212), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(7923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [396875] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [396914] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [396953] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396992] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [397031] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7928), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [397070] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9291), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [397109] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 7,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397154] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397193] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397234] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397273] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8398), 1,
      sym_arguments,
    STATE(7934), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397314] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4138), 1,
      sym__alpha_identifier,
    ACTIONS(4144), 1,
      anon_sym__,
    ACTIONS(4156), 1,
      sym__backquoted_id,
    ACTIONS(6858), 1,
      sym_operator_identifier,
    ACTIONS(7942), 1,
      anon_sym_LPAREN,
    STATE(5771), 1,
      sym__simple_type,
    STATE(6041), 1,
      sym__soft_identifier,
    STATE(6244), 1,
      sym_identifier,
    STATE(9172), 1,
      sym__annotated_type,
    STATE(9212), 1,
      sym_annotated_type,
    STATE(16550), 1,
      sym_stable_identifier,
    STATE(7935), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4150), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7341), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [397375] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397414] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7937), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9733), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [397453] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7938), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397492] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10692), 1,
      anon_sym_AT,
    STATE(7653), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9003), 1,
      sym_annotation,
    STATE(7939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397537] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7940), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397576] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11728), 1,
      anon_sym_LPAREN,
    STATE(9318), 1,
      sym_arguments,
    STATE(7941), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397619] = 21,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10970), 1,
      sym_interpolated_string,
    STATE(15611), 1,
      sym__interpolated_string_start,
    STATE(15612), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11731), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(7942), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [397690] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8909), 1,
      sym__alpha_identifier,
    ACTIONS(8911), 1,
      anon_sym__,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8917), 1,
      sym__backquoted_id,
    ACTIONS(8919), 1,
      sym_operator_identifier,
    STATE(5092), 1,
      sym__simple_type,
    STATE(6699), 1,
      sym__soft_identifier,
    STATE(7258), 1,
      sym_identifier,
    STATE(8357), 1,
      sym__annotated_type,
    STATE(8430), 1,
      sym_annotated_type,
    STATE(16570), 1,
      sym_stable_identifier,
    STATE(7943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8913), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7360), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [397751] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11482), 1,
      anon_sym_EQ_GT,
    STATE(7944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397792] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [397831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7946), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [397870] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4468), 1,
      sym__alpha_identifier,
    ACTIONS(4474), 1,
      anon_sym__,
    ACTIONS(4486), 1,
      sym__backquoted_id,
    ACTIONS(6866), 1,
      sym_operator_identifier,
    ACTIONS(7582), 1,
      anon_sym_LPAREN,
    STATE(6206), 1,
      sym__simple_type,
    STATE(6759), 1,
      sym__soft_identifier,
    STATE(6938), 1,
      sym_identifier,
    STATE(9634), 1,
      sym__annotated_type,
    STATE(9655), 1,
      sym_annotated_type,
    STATE(16590), 1,
      sym_stable_identifier,
    STATE(7947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4480), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8071), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [397931] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [397970] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7949), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9733), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [398009] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [398048] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11733), 1,
      anon_sym_COLON,
    ACTIONS(11736), 1,
      anon_sym_LBRACE,
    STATE(9494), 1,
      sym_template_body,
    STATE(7951), 2,
      sym_comment,
      sym_block_comment,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 12,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398095] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398134] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [398173] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398212] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398290] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8625), 1,
      sym__alpha_identifier,
    ACTIONS(8627), 1,
      anon_sym__,
    ACTIONS(8631), 1,
      anon_sym_LPAREN,
    ACTIONS(8633), 1,
      sym__backquoted_id,
    ACTIONS(8635), 1,
      sym_operator_identifier,
    STATE(6559), 1,
      sym__simple_type,
    STATE(8303), 1,
      sym__soft_identifier,
    STATE(8432), 1,
      sym_identifier,
    STATE(9650), 1,
      sym__annotated_type,
    STATE(9665), 1,
      sym_annotated_type,
    STATE(16610), 1,
      sym_stable_identifier,
    STATE(7957), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8629), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8693), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [398351] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7958), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9519), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [398390] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9367), 1,
      anon_sym_match,
    ACTIONS(10976), 1,
      anon_sym_LPAREN,
    ACTIONS(11610), 1,
      anon_sym_DOT,
    ACTIONS(11739), 1,
      sym__alpha_identifier,
    ACTIONS(11743), 1,
      anon_sym_EQ,
    ACTIONS(11745), 1,
      sym__backquoted_id,
    ACTIONS(11747), 1,
      sym_operator_identifier,
    STATE(603), 1,
      sym_identifier,
    STATE(4075), 1,
      sym__soft_identifier,
    STATE(7959), 2,
      sym_comment,
      sym_block_comment,
    STATE(10332), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11741), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [398453] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7960), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [398492] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398531] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8465), 1,
      sym__alpha_identifier,
    ACTIONS(8471), 1,
      anon_sym__,
    ACTIONS(8475), 1,
      anon_sym_LPAREN,
    ACTIONS(8477), 1,
      sym__backquoted_id,
    ACTIONS(8479), 1,
      sym_operator_identifier,
    STATE(4629), 1,
      sym__simple_type,
    STATE(5699), 1,
      sym__soft_identifier,
    STATE(5780), 1,
      sym_identifier,
    STATE(7025), 1,
      sym_annotated_type,
    STATE(7131), 1,
      sym__annotated_type,
    STATE(16486), 1,
      sym_stable_identifier,
    STATE(7962), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8473), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5877), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [398592] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10887), 1,
      anon_sym_AT,
    STATE(8021), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9278), 1,
      sym_annotation,
    STATE(7963), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398637] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7964), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398676] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11749), 1,
      anon_sym_with,
    STATE(7965), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398717] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7966), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [398756] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7967), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398795] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4640), 1,
      sym__alpha_identifier,
    ACTIONS(4642), 1,
      anon_sym__,
    ACTIONS(4652), 1,
      sym__backquoted_id,
    ACTIONS(6688), 1,
      sym_operator_identifier,
    ACTIONS(7472), 1,
      anon_sym_LPAREN,
    STATE(7245), 1,
      sym__simple_type,
    STATE(7872), 1,
      sym__soft_identifier,
    STATE(7995), 1,
      sym_identifier,
    STATE(9803), 1,
      sym_annotated_type,
    STATE(10069), 1,
      sym__annotated_type,
    STATE(17142), 1,
      sym_stable_identifier,
    STATE(7968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4648), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8425), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [398856] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398895] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(7970), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398936] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9242), 1,
      sym_operator_identifier,
    STATE(1784), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(7971), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8807), 7,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [398991] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7972), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [399030] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399069] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399108] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399147] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(7592), 1,
      anon_sym_LPAREN,
    STATE(6295), 1,
      sym__simple_type,
    STATE(6834), 1,
      sym__soft_identifier,
    STATE(7296), 1,
      sym_identifier,
    STATE(9664), 1,
      sym__annotated_type,
    STATE(9681), 1,
      sym_annotated_type,
    STATE(16630), 1,
      sym_stable_identifier,
    STATE(7976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7652), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [399208] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399247] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7978), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399286] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10477), 1,
      anon_sym_AT,
    STATE(8047), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9293), 1,
      sym_annotation,
    STATE(7979), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399331] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7980), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399370] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [399409] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11752), 1,
      anon_sym_with,
    STATE(7982), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9416), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [399450] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4213), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(7983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [399493] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(7984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [399538] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399577] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [399616] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8637), 1,
      sym__alpha_identifier,
    ACTIONS(8643), 1,
      anon_sym__,
    ACTIONS(8647), 1,
      anon_sym_LPAREN,
    ACTIONS(8649), 1,
      sym__backquoted_id,
    ACTIONS(8651), 1,
      sym_operator_identifier,
    STATE(8324), 1,
      sym__simple_type,
    STATE(9867), 1,
      sym__soft_identifier,
    STATE(10066), 1,
      sym_identifier,
    STATE(10595), 1,
      sym__annotated_type,
    STATE(10612), 1,
      sym_annotated_type,
    STATE(16670), 1,
      sym_stable_identifier,
    STATE(7987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8645), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9783), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [399677] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7988), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [399716] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9658), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7989), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399757] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7990), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399796] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [399835] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7992), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399874] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7993), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399913] = 21,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11184), 1,
      sym_interpolated_string,
    STATE(15499), 1,
      sym__interpolated_string_start,
    STATE(15506), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11755), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(7994), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [399984] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11757), 1,
      anon_sym_DOT,
    STATE(7995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400025] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10571), 1,
      anon_sym_AT,
    STATE(7454), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9109), 1,
      sym_annotation,
    STATE(7996), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8957), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400070] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400109] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400148] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4183), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(7999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [400191] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10966), 1,
      anon_sym_AT,
    STATE(8074), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9314), 1,
      sym_annotation,
    STATE(8000), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400236] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400275] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(477), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9367), 1,
      anon_sym_match,
    ACTIONS(9924), 1,
      anon_sym_LPAREN,
    ACTIONS(10853), 1,
      anon_sym_DOT,
    ACTIONS(11196), 1,
      sym__alpha_identifier,
    ACTIONS(11202), 1,
      sym__backquoted_id,
    ACTIONS(11204), 1,
      sym_operator_identifier,
    ACTIONS(11759), 1,
      anon_sym_EQ,
    STATE(600), 1,
      sym_identifier,
    STATE(4071), 1,
      sym__soft_identifier,
    STATE(8002), 2,
      sym_comment,
      sym_block_comment,
    STATE(9378), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11198), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [400338] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400377] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400416] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(8005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400457] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8378), 1,
      sym__alpha_identifier,
    ACTIONS(8384), 1,
      anon_sym__,
    ACTIONS(8388), 1,
      anon_sym_LPAREN,
    ACTIONS(8390), 1,
      sym__backquoted_id,
    ACTIONS(8392), 1,
      sym_operator_identifier,
    STATE(12528), 1,
      sym__simple_type,
    STATE(13074), 1,
      sym_identifier,
    STATE(13178), 1,
      sym__soft_identifier,
    STATE(14020), 1,
      sym__annotated_type,
    STATE(14057), 1,
      sym_annotated_type,
    STATE(17206), 1,
      sym_stable_identifier,
    STATE(8006), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8386), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13352), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [400518] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400557] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8008), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400596] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8653), 1,
      sym__alpha_identifier,
    ACTIONS(8659), 1,
      anon_sym__,
    ACTIONS(8663), 1,
      anon_sym_LPAREN,
    ACTIONS(8665), 1,
      sym__backquoted_id,
    ACTIONS(8667), 1,
      sym_operator_identifier,
    STATE(4289), 1,
      sym__simple_type,
    STATE(4727), 1,
      sym__soft_identifier,
    STATE(4750), 1,
      sym_identifier,
    STATE(5451), 1,
      sym__annotated_type,
    STATE(5455), 1,
      sym_annotated_type,
    STATE(16689), 1,
      sym_stable_identifier,
    STATE(8009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8661), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4741), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [400657] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400696] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4182), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(8011), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [400739] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8012), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [400778] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9673), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8013), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400819] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8014), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400858] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8015), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400897] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9671), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8016), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400938] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(9410), 1,
      sym_interpolated_string,
    STATE(15502), 1,
      sym__interpolated_string_start,
    STATE(15503), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11761), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8017), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [400989] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8018), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401028] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11348), 1,
      anon_sym_DOT,
    ACTIONS(11763), 1,
      anon_sym_EQ_GT,
    STATE(8019), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401071] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9813), 1,
      sym__alpha_identifier,
    ACTIONS(9819), 1,
      sym__backquoted_id,
    ACTIONS(9821), 1,
      sym_operator_identifier,
    STATE(530), 1,
      sym_identifier,
    STATE(3932), 1,
      sym__soft_identifier,
    STATE(8020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9815), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(9367), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [401124] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11765), 1,
      anon_sym_AT,
    STATE(9278), 1,
      sym_annotation,
    STATE(8021), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401167] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4510), 1,
      sym__alpha_identifier,
    ACTIONS(4512), 1,
      anon_sym__,
    ACTIONS(4522), 1,
      sym__backquoted_id,
    ACTIONS(6884), 1,
      sym_operator_identifier,
    ACTIONS(7682), 1,
      anon_sym_LPAREN,
    STATE(4538), 1,
      sym__simple_type,
    STATE(4572), 1,
      sym__soft_identifier,
    STATE(4611), 1,
      sym_identifier,
    STATE(6615), 1,
      sym__annotated_type,
    STATE(6644), 1,
      sym_annotated_type,
    STATE(16708), 1,
      sym_stable_identifier,
    STATE(8022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4518), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4978), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [401228] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11553), 1,
      anon_sym_EQ_GT,
    STATE(8023), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [401269] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8024), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401308] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8025), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401347] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [401386] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9461), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401427] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401466] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401505] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401544] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [401583] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8032), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9519), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [401622] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1484), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9341), 1,
      anon_sym_LPAREN,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(9809), 1,
      anon_sym_DOT,
    ACTIONS(10828), 1,
      sym__alpha_identifier,
    ACTIONS(10834), 1,
      sym__backquoted_id,
    ACTIONS(10836), 1,
      sym_operator_identifier,
    ACTIONS(11768), 1,
      anon_sym_EQ,
    STATE(548), 1,
      sym_identifier,
    STATE(4051), 1,
      sym__soft_identifier,
    STATE(8033), 2,
      sym_comment,
      sym_block_comment,
    STATE(8599), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9367), 4,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(10830), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [401685] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401724] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11770), 1,
      sym__alpha_identifier,
    ACTIONS(11772), 1,
      anon_sym__,
    ACTIONS(11776), 1,
      anon_sym_LPAREN,
    ACTIONS(11778), 1,
      sym__backquoted_id,
    ACTIONS(11780), 1,
      sym_operator_identifier,
    STATE(13118), 1,
      sym__simple_type,
    STATE(13643), 1,
      sym__soft_identifier,
    STATE(13807), 1,
      sym_identifier,
    STATE(14492), 1,
      sym_annotated_type,
    STATE(14620), 1,
      sym__annotated_type,
    STATE(17660), 1,
      sym_stable_identifier,
    STATE(8035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11774), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14006), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [401785] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8036), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [401824] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8037), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401863] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [401902] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8039), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401941] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9618), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [401982] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 4,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402021] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8669), 1,
      sym__alpha_identifier,
    ACTIONS(8675), 1,
      anon_sym__,
    ACTIONS(8679), 1,
      anon_sym_LPAREN,
    ACTIONS(8681), 1,
      sym__backquoted_id,
    ACTIONS(8683), 1,
      sym_operator_identifier,
    STATE(4524), 1,
      sym__simple_type,
    STATE(5137), 1,
      sym__soft_identifier,
    STATE(5462), 1,
      sym_identifier,
    STATE(6205), 1,
      sym_annotated_type,
    STATE(6636), 1,
      sym__annotated_type,
    STATE(16727), 1,
      sym_stable_identifier,
    STATE(8042), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8677), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5243), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [402082] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402121] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1374), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9208), 1,
      anon_sym_LPAREN,
    ACTIONS(9908), 1,
      anon_sym_DOT,
    ACTIONS(11004), 1,
      sym__alpha_identifier,
    ACTIONS(11010), 1,
      sym__backquoted_id,
    ACTIONS(11012), 1,
      sym_operator_identifier,
    ACTIONS(11782), 1,
      anon_sym_EQ,
    STATE(544), 1,
      sym_identifier,
    STATE(4058), 1,
      sym__soft_identifier,
    ACTIONS(9363), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(8044), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_do,
    STATE(8511), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(11006), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [402184] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11784), 1,
      anon_sym_DOT,
    STATE(8045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [402225] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [402264] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11786), 1,
      anon_sym_AT,
    STATE(9293), 1,
      sym_annotation,
    STATE(8047), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402307] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9620), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402348] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402387] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11789), 1,
      anon_sym_with,
    STATE(8050), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402428] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402467] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402506] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [402545] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11792), 1,
      anon_sym_AT,
    STATE(8774), 1,
      sym_annotation,
    STATE(8054), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402588] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9088), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [402627] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9109), 1,
      sym_operator_identifier,
    STATE(1667), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(8056), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8807), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [402680] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11795), 1,
      anon_sym_with,
    STATE(8691), 1,
      aux_sym_compound_type_repeat1,
    STATE(10800), 1,
      sym_template_body,
    STATE(10801), 1,
      sym__refinement,
    STATE(10855), 1,
      sym_arguments,
    STATE(8057), 2,
      sym_comment,
      sym_block_comment,
    STATE(10876), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402731] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402770] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402809] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [402848] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402887] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9638), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [402928] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [402967] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403006] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8065), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403045] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [403084] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6868), 1,
      sym__alpha_identifier,
    ACTIONS(6870), 1,
      anon_sym__,
    ACTIONS(6878), 1,
      sym__backquoted_id,
    ACTIONS(6880), 1,
      sym_operator_identifier,
    ACTIONS(7802), 1,
      anon_sym_LPAREN,
    STATE(4541), 1,
      sym__simple_type,
    STATE(4620), 1,
      sym__soft_identifier,
    STATE(4757), 1,
      sym_identifier,
    STATE(6245), 1,
      sym_annotated_type,
    STATE(6655), 1,
      sym__annotated_type,
    STATE(16746), 1,
      sym_stable_identifier,
    STATE(8067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6874), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4890), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [403145] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 4,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403184] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403225] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403264] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403303] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403342] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8073), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [403381] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11797), 1,
      anon_sym_AT,
    STATE(9314), 1,
      sym_annotation,
    STATE(8074), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403424] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8075), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [403463] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403502] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [403541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8078), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403580] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403619] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403658] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8081), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403697] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [403736] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8083), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403775] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8685), 1,
      sym__alpha_identifier,
    ACTIONS(8687), 1,
      anon_sym__,
    ACTIONS(8691), 1,
      anon_sym_LPAREN,
    ACTIONS(8693), 1,
      sym__backquoted_id,
    ACTIONS(8695), 1,
      sym_operator_identifier,
    STATE(4527), 1,
      sym__simple_type,
    STATE(5145), 1,
      sym__soft_identifier,
    STATE(5245), 1,
      sym_identifier,
    STATE(6220), 1,
      sym_annotated_type,
    STATE(6346), 1,
      sym__annotated_type,
    STATE(16764), 1,
      sym_stable_identifier,
    STATE(8084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5378), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [403836] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10947), 1,
      anon_sym_LPAREN,
    STATE(7406), 1,
      aux_sym_annotation_repeat1,
    STATE(8787), 1,
      sym_arguments,
    STATE(8085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403881] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9646), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403922] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8087), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [403961] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10114), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8088), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [404001] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(8089), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [404041] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [404079] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8091), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [404117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8092), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10496), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [404155] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8093), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [404193] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [404231] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8095), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [404269] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [404307] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8097), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [404347] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [404385] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8099), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [404423] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [404461] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9537), 1,
      sym_operator_identifier,
    STATE(1722), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(8101), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8807), 6,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [404515] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [404553] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8103), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [404591] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8104), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [404629] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [404667] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8106), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [404705] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [404743] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [404781] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8109), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [404819] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [404857] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9105), 1,
      sym_arguments,
    STATE(8111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [404897] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [404935] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [404973] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8114), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405011] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [405049] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [405125] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8118), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405163] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405201] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405241] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8121), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405279] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8122), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405317] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405355] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9891), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8124), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405395] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10452), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [405433] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8126), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405471] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [405509] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405547] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8129), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405585] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8130), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405623] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11800), 1,
      anon_sym_with,
    STATE(8131), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405663] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8132), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405701] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5244), 1,
      sym__end_marker,
    STATE(8133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405741] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8134), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [405779] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405823] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405861] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8137), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [405899] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405937] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405975] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406013] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8218), 1,
      anon_sym_def,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(6349), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(17424), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(8141), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [406073] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406111] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8143), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406149] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [406187] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406225] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9902), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [406263] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11803), 1,
      anon_sym_AT,
    STATE(9364), 1,
      sym_annotation,
    STATE(8147), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406305] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8148), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406343] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8149), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406381] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8150), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406419] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406457] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11806), 1,
      anon_sym_DOT,
    STATE(8152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406497] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [406535] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406573] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8155), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [406611] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [406649] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10432), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [406687] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [406725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8159), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [406763] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8160), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [406801] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4226), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(8161), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406843] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10424), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [406881] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(8163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [406925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406963] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9291), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407001] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8166), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [407039] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [407077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407115] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8169), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [407153] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407191] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8171), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [407229] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [407267] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407305] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407343] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8175), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407381] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [407419] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [407457] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407495] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [407533] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407571] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [407609] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8182), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [407647] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11808), 1,
      anon_sym_with,
    STATE(8183), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407687] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10508), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [407725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9291), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [407763] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8186), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407801] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407839] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407877] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8189), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [407915] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8190), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [407953] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407991] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408029] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [408067] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10851), 1,
      sym__backquoted_id,
    ACTIONS(4132), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    ACTIONS(4136), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7340), 18,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408109] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11148), 1,
      sym__backquoted_id,
    ACTIONS(4132), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    ACTIONS(4136), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7354), 18,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408151] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10765), 1,
      sym__backquoted_id,
    ACTIONS(4132), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    ACTIONS(4136), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7396), 18,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408193] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9889), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [408233] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8198), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408271] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11811), 1,
      anon_sym_LBRACE,
    ACTIONS(11813), 1,
      anon_sym_with,
    STATE(10134), 1,
      aux_sym_compound_type_repeat1,
    STATE(10967), 1,
      sym__refinement,
    STATE(11006), 1,
      sym_template_body,
    STATE(8199), 2,
      sym_comment,
      sym_block_comment,
    STATE(11047), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8246), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408321] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8200), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408359] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408397] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408435] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408473] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [408511] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [408549] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8206), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408587] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4225), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(8207), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [408629] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9733), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [408667] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408705] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [408743] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8211), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408781] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9519), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [408819] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408857] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8214), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408895] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8215), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408933] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4180), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(8216), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408975] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409013] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8218), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10522), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [409051] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11811), 1,
      anon_sym_LBRACE,
    ACTIONS(11813), 1,
      anon_sym_with,
    STATE(8199), 1,
      aux_sym_compound_type_repeat1,
    STATE(11006), 1,
      sym_template_body,
    STATE(11061), 1,
      sym__refinement,
    STATE(8219), 2,
      sym_comment,
      sym_block_comment,
    STATE(11047), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8406), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409101] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8220), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409139] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8221), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409177] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [409215] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8223), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409253] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409291] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8225), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409329] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8226), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409367] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11580), 1,
      anon_sym_LBRACK,
    ACTIONS(11586), 1,
      anon_sym_POUND,
    ACTIONS(11815), 1,
      anon_sym_LPAREN,
    STATE(9432), 1,
      aux_sym_annotation_repeat1,
    STATE(9986), 1,
      sym_type_arguments,
    STATE(10167), 1,
      sym_arguments,
    STATE(8227), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 3,
      anon_sym_LBRACE,
      anon_sym_DOT,
      sym__backquoted_id,
    ACTIONS(8154), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409417] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409455] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [409493] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [409531] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11467), 1,
      anon_sym_AT,
    STATE(8614), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9600), 1,
      sym_annotation,
    STATE(8231), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409575] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11817), 1,
      anon_sym_with,
    STATE(8232), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409615] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8233), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [409653] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8234), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409691] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10512), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [409729] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [409767] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8237), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [409805] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8238), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10031), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [409843] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8239), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10428), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [409881] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11271), 1,
      anon_sym_AT,
    STATE(8283), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9430), 1,
      sym_annotation,
    STATE(8240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [409963] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8242), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410001] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8243), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [410039] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410115] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8246), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [410153] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410191] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8248), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [410229] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410267] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4205), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(8250), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [410309] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8251), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410347] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8252), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [410385] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410423] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8254), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410461] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8255), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410499] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9361), 1,
      sym__alpha_identifier,
    ACTIONS(9369), 1,
      anon_sym_EQ,
    ACTIONS(9371), 1,
      sym__backquoted_id,
    ACTIONS(9373), 1,
      sym_operator_identifier,
    STATE(529), 1,
      sym_identifier,
    STATE(3852), 1,
      sym__soft_identifier,
    STATE(8256), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9367), 5,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9365), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [410553] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8257), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [410591] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10456), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [410629] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410667] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8260), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410705] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8261), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [410743] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11431), 1,
      anon_sym_LPAREN,
    STATE(8367), 1,
      aux_sym_annotation_repeat1,
    STATE(9351), 1,
      sym_arguments,
    STATE(8262), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8426), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410787] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8263), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410825] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8264), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [410863] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11757), 1,
      anon_sym_DOT,
    ACTIONS(11820), 1,
      anon_sym_EQ_GT,
    STATE(8265), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410905] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8266), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410943] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8267), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410981] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411019] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411057] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [411095] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9955), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8271), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411135] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411173] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8273), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411211] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411249] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411287] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8276), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411325] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9133), 1,
      sym_operator_identifier,
    STATE(1676), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(8277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8807), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [411377] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411415] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8279), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [411453] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8280), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [411491] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11822), 1,
      anon_sym_AT,
    STATE(9669), 1,
      sym_annotation,
    STATE(8281), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411533] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1808), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(9515), 1,
      anon_sym_LPAREN,
    ACTIONS(10483), 1,
      anon_sym_DOT,
    ACTIONS(11385), 1,
      sym__alpha_identifier,
    ACTIONS(11391), 1,
      sym__backquoted_id,
    ACTIONS(11393), 1,
      sym_operator_identifier,
    ACTIONS(11825), 1,
      anon_sym_EQ,
    STATE(563), 1,
      sym_identifier,
    STATE(4068), 1,
      sym__soft_identifier,
    STATE(8282), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_while,
      anon_sym_match,
      anon_sym_finally,
    STATE(8804), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(11387), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [411595] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11827), 1,
      anon_sym_AT,
    STATE(9430), 1,
      sym_annotation,
    STATE(8283), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411637] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8284), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9733), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [411675] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411713] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8286), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [411751] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9090), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411789] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11830), 1,
      anon_sym_with,
    STATE(8288), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411829] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411873] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8290), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411911] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [411949] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9315), 1,
      sym_arguments,
    STATE(8292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411989] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [412027] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11833), 1,
      anon_sym_with,
    STATE(8294), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412067] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8295), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412107] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8296), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [412145] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8297), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412183] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [412221] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11570), 1,
      anon_sym_AT,
    STATE(8281), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9669), 1,
      sym_annotation,
    STATE(8299), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412265] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8300), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [412303] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [412341] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [412379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412417] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8304), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412455] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8305), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [412493] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11346), 1,
      anon_sym_AT,
    STATE(8147), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9364), 1,
      sym_annotation,
    STATE(8306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412537] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412575] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412613] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [412651] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11836), 1,
      anon_sym_with,
    STATE(8310), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412691] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8311), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412729] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8312), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [412767] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8313), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10500), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [412805] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8314), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412843] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8315), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412881] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412919] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(8317), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [412963] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9234), 1,
      sym_operator_identifier,
    STATE(1777), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(8318), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8807), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [413015] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10006), 1,
      sym__alpha_identifier,
    ACTIONS(10012), 1,
      sym__backquoted_id,
    ACTIONS(10014), 1,
      sym_operator_identifier,
    STATE(532), 1,
      sym_identifier,
    STATE(4034), 1,
      sym__soft_identifier,
    STATE(8319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(10008), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(9367), 7,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [413067] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8320), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11839), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [413105] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413143] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [413181] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8323), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413219] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11580), 1,
      anon_sym_LBRACK,
    ACTIONS(11582), 1,
      anon_sym_AT,
    ACTIONS(11586), 1,
      anon_sym_POUND,
    STATE(9695), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9986), 1,
      sym_type_arguments,
    STATE(10164), 1,
      sym_annotation,
    STATE(8324), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 4,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413269] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 1,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(8172), 1,
      anon_sym_DQUOTE,
    ACTIONS(8174), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(11843), 1,
      anon_sym_EQ_GT,
    STATE(10674), 1,
      sym_interpolated_string,
    STATE(15211), 1,
      sym__interpolated_string_start,
    STATE(15215), 1,
      sym__interpolated_multiline_string_start,
    STATE(8325), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413321] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8326), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [413359] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8327), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413397] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8328), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [413435] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8329), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [413473] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8330), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413511] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8331), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [413549] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11846), 1,
      anon_sym_DOT,
    STATE(8332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413589] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8333), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [413627] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [413665] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8335), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413703] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8336), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413741] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413779] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10022), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8338), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413819] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8339), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10035), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [413857] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11848), 1,
      anon_sym_with,
    STATE(8340), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9416), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [413897] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413941] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8342), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413979] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4134), 1,
      sym__backquoted_id,
    ACTIONS(4132), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    ACTIONS(4136), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8343), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4130), 18,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414021] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8344), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414059] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8345), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414097] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [414135] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8347), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414173] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9906), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414213] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8349), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414251] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9866), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8350), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414291] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8351), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [414329] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414367] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8353), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [414405] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8354), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [414443] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [414481] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8356), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9068), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414519] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8357), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414557] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [414595] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(8359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414635] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8360), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414673] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8361), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414711] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8362), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414749] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414787] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8364), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9733), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [414825] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8365), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [414863] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414901] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11851), 1,
      anon_sym_LPAREN,
    STATE(9351), 1,
      sym_arguments,
    STATE(8367), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8430), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414943] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [414981] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8369), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415019] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8370), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9098), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415057] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11615), 1,
      anon_sym_LBRACK,
    ACTIONS(11619), 1,
      anon_sym_POUND,
    ACTIONS(11854), 1,
      anon_sym_AT,
    STATE(9438), 1,
      sym_type_arguments,
    STATE(9894), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10550), 1,
      sym_annotation,
    STATE(8371), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415107] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415145] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [415183] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8374), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415221] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8375), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [415259] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11856), 1,
      anon_sym_COLON,
    ACTIONS(11859), 1,
      anon_sym_LBRACE,
    STATE(9995), 1,
      sym_template_body,
    STATE(6282), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8376), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9230), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 11,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415305] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8377), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415343] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [415381] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8379), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415419] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8380), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [415457] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8381), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415495] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 1,
      anon_sym_LT_PERCENT,
    ACTIONS(11811), 1,
      anon_sym_LBRACE,
    ACTIONS(11813), 1,
      anon_sym_with,
    ACTIONS(11862), 1,
      anon_sym_COLON,
    STATE(8199), 1,
      aux_sym_compound_type_repeat1,
    STATE(11006), 1,
      sym_template_body,
    STATE(11061), 1,
      sym__refinement,
    ACTIONS(8410), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8382), 2,
      sym_comment,
      sym_block_comment,
    STATE(11047), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415553] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8383), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [415591] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [415629] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415667] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8386), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415705] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8387), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10412), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [415743] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8388), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415781] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8389), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415819] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8428), 1,
      sym__backquoted_id,
    ACTIONS(10123), 1,
      anon_sym_LPAREN,
    STATE(8479), 1,
      aux_sym_annotation_repeat1,
    STATE(9629), 1,
      sym_arguments,
    STATE(8390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8426), 19,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415863] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8391), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415901] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8392), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415939] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8393), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [415977] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8394), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416015] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [416053] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [416091] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(8397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 8,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416171] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416209] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [416247] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4952), 1,
      anon_sym_LBRACK,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11182), 1,
      anon_sym_PLUS,
    ACTIONS(11184), 1,
      anon_sym_DASH,
    ACTIONS(11186), 1,
      anon_sym_AT,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(11116), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11468), 1,
      sym_annotation,
    STATE(15986), 1,
      sym__type_parameter,
    STATE(8401), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(15958), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [416311] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10235), 1,
      sym__alpha_identifier,
    ACTIONS(10241), 1,
      sym__backquoted_id,
    ACTIONS(10243), 1,
      sym_operator_identifier,
    STATE(533), 1,
      sym_identifier,
    STATE(4027), 1,
      sym__soft_identifier,
    STATE(8402), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9367), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(10237), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [416363] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416401] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [416439] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8405), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [416477] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416515] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8407), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416553] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8408), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416591] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416629] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8410), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416667] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8411), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416705] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416743] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8413), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416781] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8414), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [416819] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8415), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [416857] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8416), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416895] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [416933] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8418), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [416971] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417009] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [417047] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [417085] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8422), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [417123] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9085), 1,
      sym_arguments,
    STATE(8423), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417163] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8424), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10436), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417201] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417239] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8426), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417277] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8427), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417315] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8428), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417353] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8429), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417391] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8430), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417429] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8431), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417467] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11869), 1,
      anon_sym_DOT,
    STATE(8432), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417507] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8433), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417545] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8434), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11871), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [417583] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8435), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10041), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417621] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8436), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417659] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9959), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417697] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9733), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417735] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8439), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417773] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8440), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417811] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8441), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9086), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8442), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417887] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8443), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11875), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [417925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8444), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9519), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417963] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8445), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [418001] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8446), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418039] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8447), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [418077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8448), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [418115] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8449), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418153] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8450), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9088), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418191] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [418229] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8452), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418267] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8453), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9090), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418305] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9247), 1,
      sym__end_marker,
    STATE(8454), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10127), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [418345] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418385] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9051), 1,
      sym_arguments,
    STATE(8456), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418425] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8457), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418463] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8458), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418501] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [418539] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8460), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418577] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8108), 1,
      anon_sym_def,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(6349), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(16279), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(8461), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [418637] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8462), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [418675] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8463), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418713] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418751] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418789] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8466), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418827] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10440), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [418865] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418903] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8469), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9098), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418941] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [418979] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8471), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419017] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8472), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419055] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419093] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10144), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419133] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4192), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(8475), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10662), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [419175] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11879), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [419213] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [419251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9088), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419289] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8432), 1,
      sym__backquoted_id,
    ACTIONS(11883), 1,
      anon_sym_LPAREN,
    STATE(9629), 1,
      sym_arguments,
    STATE(8479), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8430), 19,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419331] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8480), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [419369] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419407] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [419445] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8483), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419483] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10255), 1,
      sym__alpha_identifier,
    ACTIONS(10261), 1,
      sym__backquoted_id,
    ACTIONS(10263), 1,
      sym_operator_identifier,
    STATE(534), 1,
      sym_identifier,
    STATE(4030), 1,
      sym__soft_identifier,
    STATE(8484), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9367), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(10257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [419535] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419573] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8486), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419611] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419649] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8488), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419693] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419731] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8490), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419769] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [419807] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11886), 1,
      anon_sym_COLON,
    ACTIONS(11889), 1,
      anon_sym_LBRACE,
    STATE(10080), 1,
      sym_template_body,
    STATE(6450), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9230), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 11,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419853] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8493), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419891] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11892), 1,
      anon_sym_AT,
    STATE(9456), 1,
      sym_annotation,
    STATE(8494), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419933] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9482), 1,
      sym_operator_identifier,
    STATE(1662), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(8495), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8807), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [419987] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8496), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420025] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8497), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420063] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11895), 1,
      anon_sym_with,
    STATE(8498), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9416), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [420103] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9286), 1,
      sym__end_marker,
    STATE(8499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420143] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8500), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10048), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [420181] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8501), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420219] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [420257] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_EQ,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8410), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420301] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9242), 1,
      sym_operator_identifier,
    STATE(1784), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(8504), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8807), 7,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [420353] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8505), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420391] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [420429] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8507), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [420467] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8508), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420505] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8509), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [420543] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10146), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8510), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420583] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8511), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [420621] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420659] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420697] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8514), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420735] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8515), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [420773] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8516), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [420811] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [420849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [420887] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8519), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [420925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8520), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420963] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 7,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421007] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8522), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421045] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8523), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421083] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [421121] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8525), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421159] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421197] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8527), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421235] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421273] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8529), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [421311] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(8530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421351] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8531), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421389] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(8532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421433] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8533), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421471] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8534), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421509] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8535), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421547] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421585] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8537), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [421623] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [421661] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8539), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10052), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [421699] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421737] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8541), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11898), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [421775] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421813] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8543), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421851] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [421889] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8545), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421927] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421965] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422003] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422041] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422079] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [422155] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8552), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422193] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [422231] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422269] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422307] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8556), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10416), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [422345] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9291), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [422383] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4221), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(8558), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422425] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8559), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422463] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8560), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11902), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [422501] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11906), 1,
      anon_sym_with,
    STATE(8561), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8562), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422579] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11042), 1,
      anon_sym_AT,
    STATE(8494), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9456), 1,
      sym_annotation,
    STATE(8563), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422623] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8564), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422661] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8565), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422699] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11909), 1,
      anon_sym_with,
    STATE(8566), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422739] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8567), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422777] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [422815] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11673), 1,
      anon_sym_EQ_GT,
    STATE(8569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422855] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8570), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [422893] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422931] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10074), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8572), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422971] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [423009] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423047] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423085] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423123] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8577), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423161] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423199] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8580), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423275] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423313] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9068), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423351] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8583), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7220), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [423389] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8584), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423427] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8585), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [423465] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [423503] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8587), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8588), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [423579] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8589), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8412), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [423617] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [423655] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423693] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11912), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [423731] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10974), 1,
      anon_sym_AT,
    STATE(8685), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9691), 1,
      sym_annotation,
    STATE(8593), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8957), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423775] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8594), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423813] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11763), 1,
      anon_sym_EQ_GT,
    STATE(8595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423853] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [423891] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423929] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [423967] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10420), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [424005] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424043] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10406), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [424081] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8602), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424119] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8603), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [424157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424195] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424233] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11916), 1,
      anon_sym_with,
    STATE(8606), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424273] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8607), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [424311] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424349] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8609), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424387] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8610), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424425] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8611), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [424463] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8830), 1,
      sym__end_marker,
    STATE(8612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424503] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8613), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424541] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11919), 1,
      anon_sym_AT,
    STATE(9600), 1,
      sym_annotation,
    STATE(8614), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424583] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8615), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424621] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8616), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [424659] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8617), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424697] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8618), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424735] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8619), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [424773] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424811] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8621), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9895), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [424849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424887] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8623), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8624), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424963] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425001] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425039] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9912), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [425077] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4218), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(8628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10662), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [425119] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11922), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [425157] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11926), 1,
      anon_sym_with,
    STATE(8630), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425197] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11929), 1,
      anon_sym_with,
    STATE(8631), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9916), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [425275] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425313] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [425351] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425389] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8636), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425427] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425465] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8638), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425503] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8639), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425579] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [425617] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8642), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [425655] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425693] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8644), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425731] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [425769] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9361), 1,
      sym__alpha_identifier,
    ACTIONS(9371), 1,
      sym__backquoted_id,
    ACTIONS(9373), 1,
      sym_operator_identifier,
    ACTIONS(9628), 1,
      anon_sym_EQ,
    STATE(529), 1,
      sym_identifier,
    STATE(3852), 1,
      sym__soft_identifier,
    STATE(8646), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9365), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(9367), 7,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [425823] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11138), 1,
      anon_sym_LPAREN,
    STATE(8659), 1,
      aux_sym_annotation_repeat1,
    STATE(9704), 1,
      sym_arguments,
    STATE(8647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8426), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425867] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8648), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425905] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425943] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425981] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [426019] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426057] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1808), 1,
      anon_sym_LBRACE,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(9515), 1,
      anon_sym_LPAREN,
    ACTIONS(10483), 1,
      anon_sym_DOT,
    ACTIONS(11385), 1,
      sym__alpha_identifier,
    ACTIONS(11391), 1,
      sym__backquoted_id,
    ACTIONS(11393), 1,
      sym_operator_identifier,
    ACTIONS(11932), 1,
      anon_sym_EQ,
    STATE(563), 1,
      sym_identifier,
    STATE(4068), 1,
      sym__soft_identifier,
    STATE(8653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
    STATE(8804), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(11387), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [426119] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [426157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426195] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9443), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [426235] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8657), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [426273] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [426311] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11934), 1,
      anon_sym_LPAREN,
    STATE(9704), 1,
      sym_arguments,
    STATE(8659), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8430), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426353] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8660), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [426391] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8661), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426429] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8014), 1,
      anon_sym_AT,
    ACTIONS(8022), 1,
      anon_sym_inline,
    ACTIONS(8024), 1,
      anon_sym_infix,
    ACTIONS(8026), 1,
      anon_sym_open,
    ACTIONS(8028), 1,
      anon_sym_transparent,
    ACTIONS(8150), 1,
      anon_sym_def,
    STATE(5305), 1,
      aux_sym_modifiers_repeat1,
    STATE(6349), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7896), 1,
      sym_annotation,
    STATE(17350), 1,
      sym_modifiers,
    ACTIONS(8020), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(8662), 2,
      sym_comment,
      sym_block_comment,
    STATE(6358), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8018), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [426489] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8663), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [426527] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [426565] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426603] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10402), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [426641] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426679] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8668), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426717] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8669), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11937), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [426755] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10504), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [426793] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426831] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426871] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426909] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426947] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11941), 1,
      anon_sym_with,
    STATE(8675), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426987] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427025] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427063] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8678), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [427101] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9833), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [427141] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8680), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427179] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8681), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [427217] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8682), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427255] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10444), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [427293] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8684), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [427331] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11944), 1,
      anon_sym_AT,
    STATE(9691), 1,
      sym_annotation,
    STATE(8685), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8931), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427373] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8686), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10448), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [427411] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9845), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427451] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427489] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8689), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [427527] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8690), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427567] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11795), 1,
      anon_sym_with,
    STATE(10296), 1,
      aux_sym_compound_type_repeat1,
    STATE(10800), 1,
      sym_template_body,
    STATE(10812), 1,
      sym__refinement,
    STATE(8691), 2,
      sym_comment,
      sym_block_comment,
    STATE(10876), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8246), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427615] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [427653] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8693), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427691] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8694), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [427729] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8695), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427769] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [427807] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427845] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427883] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 1,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(11033), 1,
      anon_sym_LBRACE,
    ACTIONS(11035), 1,
      anon_sym_with,
    ACTIONS(11574), 1,
      anon_sym_COLON,
    STATE(6606), 1,
      aux_sym_compound_type_repeat1,
    STATE(10260), 1,
      sym_template_body,
    STATE(10266), 1,
      sym__refinement,
    STATE(8699), 2,
      sym_comment,
      sym_block_comment,
    STATE(10329), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8412), 4,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_if,
      anon_sym_PIPE,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427939] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9006), 1,
      sym_arguments,
    STATE(8700), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [427979] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9847), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428019] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428057] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8703), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428095] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9086), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428171] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428209] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [428247] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8708), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428285] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428323] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9792), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428363] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428401] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428438] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8713), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428475] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8714), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428512] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6322), 1,
      sym__alpha_identifier,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    ACTIONS(7862), 1,
      anon_sym_LPAREN,
    STATE(5885), 1,
      sym__simple_type,
    STATE(7031), 1,
      sym_identifier,
    STATE(7267), 1,
      sym__soft_identifier,
    STATE(16266), 1,
      sym_stable_identifier,
    STATE(8715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7736), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [428567] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428604] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4199), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(8717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428645] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428682] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6388), 1,
      sym__alpha_identifier,
    ACTIONS(6394), 1,
      anon_sym__,
    ACTIONS(6402), 1,
      sym__backquoted_id,
    ACTIONS(6404), 1,
      sym_operator_identifier,
    ACTIONS(7982), 1,
      anon_sym_LPAREN,
    STATE(5424), 1,
      sym__simple_type,
    STATE(6195), 1,
      sym_identifier,
    STATE(6548), 1,
      sym__soft_identifier,
    STATE(16293), 1,
      sym_stable_identifier,
    STATE(8719), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6398), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7147), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [428737] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9090), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428774] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8721), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428813] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428850] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3298), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(9367), 1,
      anon_sym_match,
    ACTIONS(11584), 1,
      anon_sym_LPAREN,
    ACTIONS(11947), 1,
      sym__alpha_identifier,
    ACTIONS(11949), 1,
      anon_sym_DOT,
    ACTIONS(11953), 1,
      sym__backquoted_id,
    ACTIONS(11955), 1,
      sym_operator_identifier,
    STATE(1391), 1,
      sym_identifier,
    STATE(4164), 1,
      sym__soft_identifier,
    ACTIONS(8803), 2,
      anon_sym_COLON,
      anon_sym_EQ_GT,
    STATE(8723), 2,
      sym_comment,
      sym_block_comment,
    STATE(10787), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(11951), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [428911] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8579), 1,
      sym__alpha_identifier,
    ACTIONS(8585), 1,
      anon_sym__,
    ACTIONS(8589), 1,
      anon_sym_LPAREN,
    ACTIONS(8591), 1,
      sym__backquoted_id,
    ACTIONS(8593), 1,
      sym_operator_identifier,
    STATE(4550), 1,
      sym__simple_type,
    STATE(5231), 1,
      sym__soft_identifier,
    STATE(5372), 1,
      sym_identifier,
    STATE(16340), 1,
      sym_stable_identifier,
    STATE(8724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8587), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5387), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [428966] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429003] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4286), 1,
      sym__alpha_identifier,
    ACTIONS(4288), 1,
      anon_sym__,
    ACTIONS(4298), 1,
      sym__backquoted_id,
    ACTIONS(6538), 1,
      sym_operator_identifier,
    ACTIONS(7462), 1,
      anon_sym_LPAREN,
    STATE(4378), 1,
      sym__simple_type,
    STATE(4467), 1,
      sym__soft_identifier,
    STATE(4504), 1,
      sym_identifier,
    STATE(16363), 1,
      sym_stable_identifier,
    STATE(8726), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4294), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4713), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [429058] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11957), 1,
      anon_sym_with,
    STATE(8727), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429097] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8728), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429134] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429171] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym__,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(6572), 1,
      sym_operator_identifier,
    ACTIONS(7572), 1,
      anon_sym_LPAREN,
    STATE(4554), 1,
      sym__simple_type,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(16383), 1,
      sym_stable_identifier,
    STATE(8730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5406), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [429226] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429263] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429300] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8733), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429337] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10712), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [429374] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6580), 1,
      anon_sym__,
    ACTIONS(6588), 1,
      sym__backquoted_id,
    ACTIONS(6590), 1,
      sym_operator_identifier,
    ACTIONS(7522), 1,
      anon_sym_LPAREN,
    STATE(5444), 1,
      sym__simple_type,
    STATE(6199), 1,
      sym__soft_identifier,
    STATE(6337), 1,
      sym_identifier,
    STATE(16404), 1,
      sym_stable_identifier,
    STATE(8735), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7227), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [429429] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [429466] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [429503] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8738), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8953), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429540] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [429577] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [429614] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6606), 1,
      anon_sym__,
    ACTIONS(6614), 1,
      sym__backquoted_id,
    ACTIONS(6616), 1,
      sym_operator_identifier,
    ACTIONS(7812), 1,
      anon_sym_LPAREN,
    STATE(5027), 1,
      sym__simple_type,
    STATE(5817), 1,
      sym__soft_identifier,
    STATE(5848), 1,
      sym_identifier,
    STATE(16425), 1,
      sym_stable_identifier,
    STATE(8741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6610), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6472), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [429669] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8742), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9092), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429706] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429743] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [429780] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8745), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [429817] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [429854] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9361), 1,
      sym__alpha_identifier,
    ACTIONS(9371), 1,
      sym__backquoted_id,
    ACTIONS(9373), 1,
      sym_operator_identifier,
    ACTIONS(9993), 1,
      anon_sym_EQ,
    STATE(529), 1,
      sym_identifier,
    STATE(3852), 1,
      sym__soft_identifier,
    STATE(8747), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 5,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9365), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [429907] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6792), 1,
      sym__alpha_identifier,
    ACTIONS(6794), 1,
      anon_sym__,
    ACTIONS(6802), 1,
      sym__backquoted_id,
    ACTIONS(6804), 1,
      sym_operator_identifier,
    ACTIONS(7892), 1,
      anon_sym_LPAREN,
    STATE(7342), 1,
      sym__simple_type,
    STATE(8149), 1,
      sym__soft_identifier,
    STATE(8152), 1,
      sym_identifier,
    STATE(16446), 1,
      sym_stable_identifier,
    STATE(8748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6798), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9214), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [429962] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(8749), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430003] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8750), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430040] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [430077] = 19,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10323), 1,
      anon_sym_RPAREN,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15473), 1,
      aux_sym_case_class_pattern_repeat1,
    ACTIONS(10321), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(8752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [430142] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8753), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [430179] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8754), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430216] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    ACTIONS(7632), 1,
      anon_sym_LPAREN,
    STATE(6627), 1,
      sym__simple_type,
    STATE(7680), 1,
      sym__soft_identifier,
    STATE(7825), 1,
      sym_identifier,
    STATE(16467), 1,
      sym_stable_identifier,
    STATE(8755), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8431), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [430271] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8756), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [430308] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8757), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430345] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8595), 1,
      sym__alpha_identifier,
    ACTIONS(8597), 1,
      anon_sym__,
    ACTIONS(8601), 1,
      anon_sym_LPAREN,
    ACTIONS(8603), 1,
      sym__backquoted_id,
    ACTIONS(8605), 1,
      sym_operator_identifier,
    STATE(5044), 1,
      sym__simple_type,
    STATE(6423), 1,
      sym_identifier,
    STATE(6470), 1,
      sym__soft_identifier,
    STATE(16488), 1,
      sym_stable_identifier,
    STATE(8758), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8599), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6546), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [430400] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4204), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(8759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430441] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430478] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8761), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430515] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430552] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8763), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430589] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430626] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8765), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430669] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8766), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430706] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11960), 1,
      sym__alpha_identifier,
    ACTIONS(11962), 1,
      anon_sym__,
    ACTIONS(11966), 1,
      anon_sym_LPAREN,
    ACTIONS(11968), 1,
      sym__backquoted_id,
    ACTIONS(11970), 1,
      sym_operator_identifier,
    STATE(11718), 1,
      sym__simple_type,
    STATE(12387), 1,
      sym__soft_identifier,
    STATE(12557), 1,
      sym_identifier,
    STATE(17041), 1,
      sym_stable_identifier,
    STATE(8767), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11964), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(12857), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [430761] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8768), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430798] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11972), 1,
      anon_sym_with,
    STATE(8769), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430837] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [430874] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4376), 1,
      sym__alpha_identifier,
    ACTIONS(4382), 1,
      anon_sym__,
    ACTIONS(4394), 1,
      sym__backquoted_id,
    ACTIONS(6824), 1,
      sym_operator_identifier,
    ACTIONS(7752), 1,
      anon_sym_LPAREN,
    STATE(4617), 1,
      sym__simple_type,
    STATE(5049), 1,
      sym__soft_identifier,
    STATE(5197), 1,
      sym_identifier,
    STATE(16509), 1,
      sym_stable_identifier,
    STATE(8771), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5943), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [430929] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [430966] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8773), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [431003] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431040] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9624), 1,
      anon_sym_LBRACE,
    ACTIONS(9626), 1,
      anon_sym_with,
    STATE(9122), 1,
      aux_sym_compound_type_repeat1,
    STATE(9198), 1,
      sym_template_body,
    STATE(9203), 1,
      sym__refinement,
    STATE(8775), 2,
      sym_comment,
      sym_block_comment,
    STATE(9246), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8408), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8406), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431089] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8776), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431126] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8777), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [431163] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8607), 1,
      sym__alpha_identifier,
    ACTIONS(8609), 1,
      anon_sym__,
    ACTIONS(8613), 1,
      anon_sym_LPAREN,
    ACTIONS(8615), 1,
      sym__backquoted_id,
    ACTIONS(8617), 1,
      sym_operator_identifier,
    STATE(4963), 1,
      sym__simple_type,
    STATE(6383), 1,
      sym__soft_identifier,
    STATE(6474), 1,
      sym_identifier,
    STATE(16530), 1,
      sym_stable_identifier,
    STATE(8778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8611), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6585), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [431218] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431255] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6832), 1,
      anon_sym_COLON,
    ACTIONS(6834), 1,
      anon_sym_LBRACE,
    ACTIONS(11975), 1,
      anon_sym_with,
    STATE(10446), 1,
      aux_sym_compound_type_repeat1,
    STATE(11691), 1,
      sym_template_body,
    STATE(11693), 1,
      sym__refinement,
    ACTIONS(8252), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(8780), 2,
      sym_comment,
      sym_block_comment,
    STATE(11704), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8246), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431306] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10211), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431345] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431382] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10490), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431421] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431458] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431495] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [431532] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431569] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8788), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [431606] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10402), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [431643] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11977), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      anon_sym__,
    ACTIONS(11983), 1,
      anon_sym_LPAREN,
    ACTIONS(11985), 1,
      sym__backquoted_id,
    ACTIONS(11987), 1,
      sym_operator_identifier,
    STATE(11479), 1,
      sym__simple_type,
    STATE(12198), 1,
      sym_identifier,
    STATE(12392), 1,
      sym__soft_identifier,
    STATE(17077), 1,
      sym_stable_identifier,
    STATE(8790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11981), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(12793), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [431698] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [431735] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431772] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431809] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431846] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8795), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10406), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [431883] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431920] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431957] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4138), 1,
      sym__alpha_identifier,
    ACTIONS(4144), 1,
      anon_sym__,
    ACTIONS(4156), 1,
      sym__backquoted_id,
    ACTIONS(6858), 1,
      sym_operator_identifier,
    ACTIONS(7942), 1,
      anon_sym_LPAREN,
    STATE(5120), 1,
      sym__simple_type,
    STATE(6041), 1,
      sym__soft_identifier,
    STATE(6244), 1,
      sym_identifier,
    STATE(16550), 1,
      sym_stable_identifier,
    STATE(8798), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4150), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7341), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [432012] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10412), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [432049] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432086] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [432123] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10416), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [432160] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8803), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 6,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432197] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8804), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10420), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [432234] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10424), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [432271] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8806), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9959), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [432308] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8807), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [432345] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8909), 1,
      sym__alpha_identifier,
    ACTIONS(8911), 1,
      anon_sym__,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8917), 1,
      sym__backquoted_id,
    ACTIONS(8919), 1,
      sym_operator_identifier,
    STATE(5199), 1,
      sym__simple_type,
    STATE(6699), 1,
      sym__soft_identifier,
    STATE(7258), 1,
      sym_identifier,
    STATE(16570), 1,
      sym_stable_identifier,
    STATE(8808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8913), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7360), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [432400] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8809), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 6,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432437] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8810), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432474] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432511] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [432548] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10428), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [432585] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8814), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432622] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8815), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432659] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8816), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10432), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [432696] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8817), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10436), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [432733] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8818), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10440), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [432770] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11989), 1,
      sym__alpha_identifier,
    ACTIONS(11991), 1,
      anon_sym__,
    ACTIONS(11995), 1,
      anon_sym_LPAREN,
    ACTIONS(11997), 1,
      sym__backquoted_id,
    ACTIONS(11999), 1,
      sym_operator_identifier,
    STATE(10360), 1,
      sym__simple_type,
    STATE(10814), 1,
      sym_identifier,
    STATE(10934), 1,
      sym__soft_identifier,
    STATE(17095), 1,
      sym_stable_identifier,
    STATE(8819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11993), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10983), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [432825] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [432862] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [432899] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8822), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [432936] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8823), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432973] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433010] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10444), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [433047] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8826), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10448), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [433084] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8827), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [433121] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4468), 1,
      sym__alpha_identifier,
    ACTIONS(4474), 1,
      anon_sym__,
    ACTIONS(4486), 1,
      sym__backquoted_id,
    ACTIONS(6866), 1,
      sym_operator_identifier,
    ACTIONS(7582), 1,
      anon_sym_LPAREN,
    STATE(5666), 1,
      sym__simple_type,
    STATE(6759), 1,
      sym__soft_identifier,
    STATE(6938), 1,
      sym_identifier,
    STATE(16590), 1,
      sym_stable_identifier,
    STATE(8828), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4480), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8071), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [433176] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [433213] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433250] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10452), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [433287] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10456), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [433324] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8833), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [433361] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8834), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [433398] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433435] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8625), 1,
      sym__alpha_identifier,
    ACTIONS(8627), 1,
      anon_sym__,
    ACTIONS(8631), 1,
      anon_sym_LPAREN,
    ACTIONS(8633), 1,
      sym__backquoted_id,
    ACTIONS(8635), 1,
      sym_operator_identifier,
    STATE(6328), 1,
      sym__simple_type,
    STATE(8303), 1,
      sym__soft_identifier,
    STATE(8432), 1,
      sym_identifier,
    STATE(16610), 1,
      sym_stable_identifier,
    STATE(8836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8629), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8693), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [433490] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12003), 1,
      anon_sym__,
    ACTIONS(12007), 1,
      anon_sym_LPAREN,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(12011), 1,
      sym_operator_identifier,
    STATE(10829), 1,
      sym__simple_type,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11285), 1,
      sym_identifier,
    STATE(16150), 1,
      sym_stable_identifier,
    STATE(8837), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11619), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [433545] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433582] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8839), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [433619] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433656] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10006), 1,
      sym__alpha_identifier,
    ACTIONS(10010), 1,
      anon_sym_EQ,
    ACTIONS(10012), 1,
      sym__backquoted_id,
    ACTIONS(10014), 1,
      sym_operator_identifier,
    STATE(532), 1,
      sym_identifier,
    STATE(4034), 1,
      sym__soft_identifier,
    STATE(8841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9367), 5,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10008), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [433709] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8842), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433746] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12013), 1,
      sym__alpha_identifier,
    ACTIONS(12015), 1,
      anon_sym__,
    ACTIONS(12019), 1,
      anon_sym_LPAREN,
    ACTIONS(12021), 1,
      sym__backquoted_id,
    ACTIONS(12023), 1,
      sym_operator_identifier,
    STATE(10762), 1,
      sym__simple_type,
    STATE(11162), 1,
      sym_identifier,
    STATE(11287), 1,
      sym__soft_identifier,
    STATE(17107), 1,
      sym_stable_identifier,
    STATE(8843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12017), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11678), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [433801] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433838] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433875] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8846), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [433912] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(7592), 1,
      anon_sym_LPAREN,
    STATE(5475), 1,
      sym__simple_type,
    STATE(6834), 1,
      sym__soft_identifier,
    STATE(7296), 1,
      sym_identifier,
    STATE(16630), 1,
      sym_stable_identifier,
    STATE(8847), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7652), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [433967] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9482), 1,
      sym_operator_identifier,
    STATE(1662), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(8848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8807), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [434018] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8849), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434055] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434092] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [434129] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434166] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8853), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8854), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434240] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8637), 1,
      sym__alpha_identifier,
    ACTIONS(8643), 1,
      anon_sym__,
    ACTIONS(8647), 1,
      anon_sym_LPAREN,
    ACTIONS(8649), 1,
      sym__backquoted_id,
    ACTIONS(8651), 1,
      sym_operator_identifier,
    STATE(8227), 1,
      sym__simple_type,
    STATE(9867), 1,
      sym__soft_identifier,
    STATE(10066), 1,
      sym_identifier,
    STATE(16670), 1,
      sym_stable_identifier,
    STATE(8855), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8645), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9783), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [434295] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(9624), 1,
      anon_sym_LBRACE,
    ACTIONS(9626), 1,
      anon_sym_with,
    ACTIONS(12025), 1,
      anon_sym_COLON,
    STATE(9122), 1,
      aux_sym_compound_type_repeat1,
    STATE(9198), 1,
      sym_template_body,
    STATE(9203), 1,
      sym__refinement,
    ACTIONS(8410), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8856), 2,
      sym_comment,
      sym_block_comment,
    STATE(9246), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434350] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8857), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [434387] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8858), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [434424] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434461] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8653), 1,
      sym__alpha_identifier,
    ACTIONS(8659), 1,
      anon_sym__,
    ACTIONS(8663), 1,
      anon_sym_LPAREN,
    ACTIONS(8665), 1,
      sym__backquoted_id,
    ACTIONS(8667), 1,
      sym_operator_identifier,
    STATE(4286), 1,
      sym__simple_type,
    STATE(4727), 1,
      sym__soft_identifier,
    STATE(4750), 1,
      sym_identifier,
    STATE(16689), 1,
      sym_stable_identifier,
    STATE(8860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8661), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4741), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [434516] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434553] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [434590] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [434627] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(8864), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8835), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [434670] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434707] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8866), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434744] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434783] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12028), 1,
      anon_sym_DOT,
    STATE(8868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434822] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4510), 1,
      sym__alpha_identifier,
    ACTIONS(4512), 1,
      anon_sym__,
    ACTIONS(4522), 1,
      sym__backquoted_id,
    ACTIONS(6884), 1,
      sym_operator_identifier,
    ACTIONS(7682), 1,
      anon_sym_LPAREN,
    STATE(4412), 1,
      sym__simple_type,
    STATE(4572), 1,
      sym__soft_identifier,
    STATE(4611), 1,
      sym_identifier,
    STATE(16708), 1,
      sym_stable_identifier,
    STATE(8869), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4518), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4978), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [434877] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434914] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8871), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434951] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434988] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8669), 1,
      sym__alpha_identifier,
    ACTIONS(8675), 1,
      anon_sym__,
    ACTIONS(8679), 1,
      anon_sym_LPAREN,
    ACTIONS(8681), 1,
      sym__backquoted_id,
    ACTIONS(8683), 1,
      sym_operator_identifier,
    STATE(4492), 1,
      sym__simple_type,
    STATE(5137), 1,
      sym__soft_identifier,
    STATE(5462), 1,
      sym_identifier,
    STATE(16727), 1,
      sym_stable_identifier,
    STATE(8873), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8677), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5243), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [435043] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435080] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9098), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435154] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6868), 1,
      sym__alpha_identifier,
    ACTIONS(6870), 1,
      anon_sym__,
    ACTIONS(6878), 1,
      sym__backquoted_id,
    ACTIONS(6880), 1,
      sym_operator_identifier,
    ACTIONS(7802), 1,
      anon_sym_LPAREN,
    STATE(4416), 1,
      sym__simple_type,
    STATE(4620), 1,
      sym__soft_identifier,
    STATE(4757), 1,
      sym_identifier,
    STATE(16746), 1,
      sym_stable_identifier,
    STATE(8877), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6874), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4890), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [435209] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8878), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435246] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8685), 1,
      sym__alpha_identifier,
    ACTIONS(8687), 1,
      anon_sym__,
    ACTIONS(8691), 1,
      anon_sym_LPAREN,
    ACTIONS(8693), 1,
      sym__backquoted_id,
    ACTIONS(8695), 1,
      sym_operator_identifier,
    STATE(4494), 1,
      sym__simple_type,
    STATE(5145), 1,
      sym__soft_identifier,
    STATE(5245), 1,
      sym_identifier,
    STATE(16764), 1,
      sym_stable_identifier,
    STATE(8879), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5378), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [435301] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12030), 1,
      sym__alpha_identifier,
    ACTIONS(12032), 1,
      anon_sym__,
    ACTIONS(12036), 1,
      anon_sym_LPAREN,
    ACTIONS(12038), 1,
      sym__backquoted_id,
    ACTIONS(12040), 1,
      sym_operator_identifier,
    STATE(11034), 1,
      sym__simple_type,
    STATE(11591), 1,
      sym__soft_identifier,
    STATE(11659), 1,
      sym_identifier,
    STATE(17143), 1,
      sym_stable_identifier,
    STATE(8880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12034), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(12080), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [435356] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4540), 1,
      sym__alpha_identifier,
    ACTIONS(4546), 1,
      anon_sym__,
    ACTIONS(4558), 1,
      sym__backquoted_id,
    ACTIONS(6892), 1,
      sym_operator_identifier,
    ACTIONS(7822), 1,
      anon_sym_LPAREN,
    STATE(4647), 1,
      sym__simple_type,
    STATE(5050), 1,
      sym_identifier,
    STATE(5155), 1,
      sym__soft_identifier,
    STATE(16782), 1,
      sym_stable_identifier,
    STATE(8881), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5928), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [435411] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8697), 1,
      sym__alpha_identifier,
    ACTIONS(8699), 1,
      anon_sym__,
    ACTIONS(8703), 1,
      anon_sym_LPAREN,
    ACTIONS(8705), 1,
      sym__backquoted_id,
    ACTIONS(8707), 1,
      sym_operator_identifier,
    STATE(5188), 1,
      sym__simple_type,
    STATE(7069), 1,
      sym_identifier,
    STATE(7122), 1,
      sym__soft_identifier,
    STATE(16800), 1,
      sym_stable_identifier,
    STATE(8882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8701), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7218), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [435466] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8883), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7220), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [435503] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12042), 1,
      sym__alpha_identifier,
    ACTIONS(12044), 1,
      anon_sym__,
    ACTIONS(12048), 1,
      anon_sym_LPAREN,
    ACTIONS(12050), 1,
      sym__backquoted_id,
    ACTIONS(12052), 1,
      sym_operator_identifier,
    STATE(11944), 1,
      sym__simple_type,
    STATE(12703), 1,
      sym_identifier,
    STATE(12741), 1,
      sym__soft_identifier,
    STATE(17155), 1,
      sym_stable_identifier,
    STATE(8884), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12046), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13204), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [435558] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9384), 1,
      sym__end_marker,
    STATE(8885), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435597] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6370), 1,
      sym__alpha_identifier,
    ACTIONS(6376), 1,
      anon_sym__,
    ACTIONS(6384), 1,
      sym__backquoted_id,
    ACTIONS(6386), 1,
      sym_operator_identifier,
    ACTIONS(7502), 1,
      anon_sym_LPAREN,
    STATE(4970), 1,
      sym__simple_type,
    STATE(5485), 1,
      sym__soft_identifier,
    STATE(5665), 1,
      sym_identifier,
    STATE(16818), 1,
      sym_stable_identifier,
    STATE(8886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6380), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6556), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [435652] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10226), 1,
      anon_sym_COLON,
    ACTIONS(10229), 1,
      anon_sym_EQ_GT,
    ACTIONS(10231), 1,
      anon_sym_QMARK_EQ_GT,
    STATE(17044), 1,
      sym__self_type_ascription,
    STATE(8887), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435697] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435740] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8316), 1,
      sym__alpha_identifier,
    ACTIONS(8322), 1,
      anon_sym__,
    ACTIONS(8326), 1,
      anon_sym_LPAREN,
    ACTIONS(8328), 1,
      sym__backquoted_id,
    ACTIONS(8330), 1,
      sym_operator_identifier,
    STATE(10979), 1,
      sym__simple_type,
    STATE(11509), 1,
      sym_identifier,
    STATE(11550), 1,
      sym__soft_identifier,
    STATE(16853), 1,
      sym_stable_identifier,
    STATE(8889), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8324), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11787), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [435795] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(832), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(10123), 1,
      anon_sym_LPAREN,
    ACTIONS(10855), 1,
      anon_sym_DOT,
    ACTIONS(10873), 1,
      sym_operator_identifier,
    ACTIONS(12054), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_match,
      anon_sym_do,
    STATE(8890), 2,
      sym_comment,
      sym_block_comment,
    STATE(9409), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [435856] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8891), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [435893] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8892), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [435930] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8715), 1,
      sym__alpha_identifier,
    ACTIONS(8717), 1,
      anon_sym__,
    ACTIONS(8721), 1,
      anon_sym_LPAREN,
    ACTIONS(8723), 1,
      sym__backquoted_id,
    ACTIONS(8725), 1,
      sym_operator_identifier,
    STATE(5215), 1,
      sym__simple_type,
    STATE(6897), 1,
      sym_identifier,
    STATE(7174), 1,
      sym__soft_identifier,
    STATE(16889), 1,
      sym_stable_identifier,
    STATE(8893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8719), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6899), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [435985] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8894), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436022] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436059] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12056), 1,
      sym__alpha_identifier,
    ACTIONS(12058), 1,
      anon_sym__,
    ACTIONS(12062), 1,
      anon_sym_LPAREN,
    ACTIONS(12064), 1,
      sym__backquoted_id,
    ACTIONS(12066), 1,
      sym_operator_identifier,
    STATE(11988), 1,
      sym__simple_type,
    STATE(12744), 1,
      sym__soft_identifier,
    STATE(12778), 1,
      sym_identifier,
    STATE(17173), 1,
      sym_stable_identifier,
    STATE(8896), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13270), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [436114] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12068), 1,
      anon_sym_with,
    STATE(8897), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9416), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436153] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8898), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436190] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9813), 1,
      sym__alpha_identifier,
    ACTIONS(9817), 1,
      anon_sym_EQ,
    ACTIONS(9819), 1,
      sym__backquoted_id,
    ACTIONS(9821), 1,
      sym_operator_identifier,
    STATE(530), 1,
      sym_identifier,
    STATE(3932), 1,
      sym__soft_identifier,
    STATE(8899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 6,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9815), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [436243] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4664), 1,
      sym__alpha_identifier,
    ACTIONS(4670), 1,
      anon_sym__,
    ACTIONS(4682), 1,
      sym__backquoted_id,
    ACTIONS(6544), 1,
      sym_operator_identifier,
    ACTIONS(7782), 1,
      anon_sym_LPAREN,
    STATE(4706), 1,
      sym__simple_type,
    STATE(5067), 1,
      sym_identifier,
    STATE(5176), 1,
      sym__soft_identifier,
    STATE(16905), 1,
      sym_stable_identifier,
    STATE(8900), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4676), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5890), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [436298] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [436335] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8902), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436372] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10233), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436411] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6180), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(6190), 1,
      sym_operator_identifier,
    ACTIONS(7482), 1,
      anon_sym_LPAREN,
    STATE(5464), 1,
      sym__simple_type,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(6538), 1,
      sym_identifier,
    STATE(16917), 1,
      sym_stable_identifier,
    STATE(8904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7081), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [436466] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8905), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436503] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10496), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [436540] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6482), 1,
      sym__alpha_identifier,
    ACTIONS(6484), 1,
      anon_sym__,
    ACTIONS(6492), 1,
      sym__backquoted_id,
    ACTIONS(6494), 1,
      sym_operator_identifier,
    ACTIONS(7992), 1,
      anon_sym_LPAREN,
    STATE(5299), 1,
      sym__simple_type,
    STATE(6020), 1,
      sym_identifier,
    STATE(6416), 1,
      sym__soft_identifier,
    STATE(16929), 1,
      sym_stable_identifier,
    STATE(8907), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6488), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7126), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [436595] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8908), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436632] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8909), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436669] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8910), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10500), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [436706] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8911), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436743] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6252), 1,
      sym__alpha_identifier,
    ACTIONS(6258), 1,
      anon_sym__,
    ACTIONS(6266), 1,
      sym__backquoted_id,
    ACTIONS(6268), 1,
      sym_operator_identifier,
    ACTIONS(7792), 1,
      anon_sym_LPAREN,
    STATE(4831), 1,
      sym__simple_type,
    STATE(5492), 1,
      sym__soft_identifier,
    STATE(5705), 1,
      sym_identifier,
    STATE(16941), 1,
      sym_stable_identifier,
    STATE(8912), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6262), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6211), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [436798] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436835] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4698), 1,
      sym__alpha_identifier,
    ACTIONS(4704), 1,
      anon_sym__,
    ACTIONS(4716), 1,
      sym__backquoted_id,
    ACTIONS(6368), 1,
      sym_operator_identifier,
    ACTIONS(7932), 1,
      anon_sym_LPAREN,
    STATE(4876), 1,
      sym__simple_type,
    STATE(5498), 1,
      sym__soft_identifier,
    STATE(5876), 1,
      sym_identifier,
    STATE(16963), 1,
      sym_stable_identifier,
    STATE(8914), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4710), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6568), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [436890] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6518), 1,
      sym__alpha_identifier,
    ACTIONS(6524), 1,
      anon_sym__,
    ACTIONS(6532), 1,
      sym__backquoted_id,
    ACTIONS(6534), 1,
      sym_operator_identifier,
    ACTIONS(7742), 1,
      anon_sym_LPAREN,
    STATE(6207), 1,
      sym__simple_type,
    STATE(7649), 1,
      sym_identifier,
    STATE(7843), 1,
      sym__soft_identifier,
    STATE(16974), 1,
      sym_stable_identifier,
    STATE(8915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6528), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [436945] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9733), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [436982] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437019] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437056] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437093] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4732), 1,
      sym__alpha_identifier,
    ACTIONS(4738), 1,
      anon_sym__,
    ACTIONS(4750), 1,
      sym__backquoted_id,
    ACTIONS(6648), 1,
      sym_operator_identifier,
    ACTIONS(7852), 1,
      anon_sym_LPAREN,
    STATE(5818), 1,
      sym__simple_type,
    STATE(6727), 1,
      sym_identifier,
    STATE(7205), 1,
      sym__soft_identifier,
    STATE(16996), 1,
      sym_stable_identifier,
    STATE(8920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4744), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7933), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [437148] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8921), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437185] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8922), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437222] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437259] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4770), 1,
      sym__alpha_identifier,
    ACTIONS(4772), 1,
      anon_sym__,
    ACTIONS(4782), 1,
      sym__backquoted_id,
    ACTIONS(6710), 1,
      sym_operator_identifier,
    ACTIONS(7612), 1,
      anon_sym_LPAREN,
    STATE(4264), 1,
      sym__simple_type,
    STATE(4395), 1,
      sym_identifier,
    STATE(4399), 1,
      sym__soft_identifier,
    STATE(17007), 1,
      sym_stable_identifier,
    STATE(8924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4778), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4539), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [437314] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10504), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [437351] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437388] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6760), 1,
      sym__alpha_identifier,
    ACTIONS(6762), 1,
      anon_sym__,
    ACTIONS(6770), 1,
      sym__backquoted_id,
    ACTIONS(6772), 1,
      sym_operator_identifier,
    ACTIONS(7702), 1,
      anon_sym_LPAREN,
    STATE(4500), 1,
      sym__simple_type,
    STATE(4900), 1,
      sym_identifier,
    STATE(4925), 1,
      sym__soft_identifier,
    STATE(17018), 1,
      sym_stable_identifier,
    STATE(8927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6766), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5278), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [437443] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12071), 1,
      anon_sym_with,
    STATE(8928), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437482] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437519] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4794), 1,
      sym__alpha_identifier,
    ACTIONS(4796), 1,
      anon_sym__,
    ACTIONS(4806), 1,
      sym__backquoted_id,
    ACTIONS(6828), 1,
      sym_operator_identifier,
    ACTIONS(7902), 1,
      anon_sym_LPAREN,
    STATE(4388), 1,
      sym__simple_type,
    STATE(4605), 1,
      sym__soft_identifier,
    STATE(4610), 1,
      sym_identifier,
    STATE(17024), 1,
      sym_stable_identifier,
    STATE(8930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4802), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4813), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [437574] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437611] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437648] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437685] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8934), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10508), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [437722] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8935), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437759] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4820), 1,
      sym__alpha_identifier,
    ACTIONS(4826), 1,
      anon_sym__,
    ACTIONS(4838), 1,
      sym__backquoted_id,
    ACTIONS(6888), 1,
      sym_operator_identifier,
    ACTIONS(7882), 1,
      anon_sym_LPAREN,
    STATE(4390), 1,
      sym__simple_type,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(4630), 1,
      sym_identifier,
    STATE(17030), 1,
      sym_stable_identifier,
    STATE(8936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4832), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4830), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [437814] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8937), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10512), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [437851] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12074), 1,
      anon_sym_with,
    STATE(8938), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437890] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6192), 1,
      sym__alpha_identifier,
    ACTIONS(6198), 1,
      anon_sym__,
    ACTIONS(6206), 1,
      sym__backquoted_id,
    ACTIONS(6208), 1,
      sym_operator_identifier,
    ACTIONS(7842), 1,
      anon_sym_LPAREN,
    STATE(4953), 1,
      sym__simple_type,
    STATE(5503), 1,
      sym_identifier,
    STATE(5516), 1,
      sym__soft_identifier,
    STATE(17035), 1,
      sym_stable_identifier,
    STATE(8939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6202), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6134), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [437945] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9823), 1,
      sym__alpha_identifier,
    ACTIONS(9827), 1,
      anon_sym_EQ,
    ACTIONS(9829), 1,
      sym__backquoted_id,
    ACTIONS(9831), 1,
      sym_operator_identifier,
    STATE(535), 1,
      sym_identifier,
    STATE(4031), 1,
      sym__soft_identifier,
    STATE(8940), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 5,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9825), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [437998] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8941), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438035] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4852), 1,
      sym__alpha_identifier,
    ACTIONS(4858), 1,
      anon_sym__,
    ACTIONS(4870), 1,
      sym__backquoted_id,
    ACTIONS(6298), 1,
      sym_operator_identifier,
    ACTIONS(7962), 1,
      anon_sym_LPAREN,
    STATE(4960), 1,
      sym__simple_type,
    STATE(5519), 1,
      sym__soft_identifier,
    STATE(5597), 1,
      sym_identifier,
    STATE(17047), 1,
      sym_stable_identifier,
    STATE(8942), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4864), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6267), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [438090] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [438127] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438164] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438201] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9835), 1,
      sym__alpha_identifier,
    ACTIONS(9839), 1,
      anon_sym_EQ,
    ACTIONS(9841), 1,
      sym__backquoted_id,
    ACTIONS(9843), 1,
      sym_operator_identifier,
    STATE(531), 1,
      sym_identifier,
    STATE(3976), 1,
      sym__soft_identifier,
    STATE(8946), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 6,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9837), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [438254] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8735), 1,
      sym__alpha_identifier,
    ACTIONS(8737), 1,
      anon_sym__,
    ACTIONS(8741), 1,
      anon_sym_LPAREN,
    ACTIONS(8743), 1,
      sym__backquoted_id,
    ACTIONS(8745), 1,
      sym_operator_identifier,
    STATE(4666), 1,
      sym__simple_type,
    STATE(5520), 1,
      sym__soft_identifier,
    STATE(5547), 1,
      sym_identifier,
    STATE(17053), 1,
      sym_stable_identifier,
    STATE(8947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8739), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5835), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [438309] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438346] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8949), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438383] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12077), 1,
      sym__alpha_identifier,
    ACTIONS(12079), 1,
      anon_sym__,
    ACTIONS(12083), 1,
      anon_sym_LPAREN,
    ACTIONS(12085), 1,
      sym__backquoted_id,
    ACTIONS(12087), 1,
      sym_operator_identifier,
    STATE(11169), 1,
      sym__simple_type,
    STATE(11793), 1,
      sym__soft_identifier,
    STATE(12139), 1,
      sym_identifier,
    STATE(17221), 1,
      sym_stable_identifier,
    STATE(8950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12081), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(12230), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [438438] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438475] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438512] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438549] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4882), 1,
      sym__alpha_identifier,
    ACTIONS(4888), 1,
      anon_sym__,
    ACTIONS(4900), 1,
      sym__backquoted_id,
    ACTIONS(6364), 1,
      sym_operator_identifier,
    ACTIONS(7972), 1,
      anon_sym_LPAREN,
    STATE(4973), 1,
      sym__simple_type,
    STATE(5522), 1,
      sym__soft_identifier,
    STATE(5657), 1,
      sym_identifier,
    STATE(17059), 1,
      sym_stable_identifier,
    STATE(8954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4894), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6372), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [438604] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9823), 1,
      sym__alpha_identifier,
    ACTIONS(9829), 1,
      sym__backquoted_id,
    ACTIONS(9831), 1,
      sym_operator_identifier,
    STATE(535), 1,
      sym_identifier,
    STATE(4031), 1,
      sym__soft_identifier,
    STATE(8955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9825), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [438655] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9823), 1,
      sym__alpha_identifier,
    ACTIONS(9829), 1,
      sym__backquoted_id,
    ACTIONS(9831), 1,
      sym_operator_identifier,
    ACTIONS(10020), 1,
      anon_sym_EQ,
    STATE(535), 1,
      sym_identifier,
    STATE(4031), 1,
      sym__soft_identifier,
    STATE(8956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 5,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9825), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [438708] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8957), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [438745] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8749), 1,
      sym__alpha_identifier,
    ACTIONS(8751), 1,
      anon_sym__,
    ACTIONS(8755), 1,
      anon_sym_LPAREN,
    ACTIONS(8757), 1,
      sym__backquoted_id,
    ACTIONS(8759), 1,
      sym_operator_identifier,
    STATE(5054), 1,
      sym__simple_type,
    STATE(7068), 1,
      sym_identifier,
    STATE(7238), 1,
      sym__soft_identifier,
    STATE(17065), 1,
      sym_stable_identifier,
    STATE(8958), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8753), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7119), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [438800] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10290), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [438839] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12089), 1,
      sym__alpha_identifier,
    ACTIONS(12091), 1,
      anon_sym__,
    ACTIONS(12095), 1,
      anon_sym_LPAREN,
    ACTIONS(12097), 1,
      sym__backquoted_id,
    ACTIONS(12099), 1,
      sym_operator_identifier,
    STATE(12030), 1,
      sym__simple_type,
    STATE(12691), 1,
      sym_identifier,
    STATE(12752), 1,
      sym__soft_identifier,
    STATE(17233), 1,
      sym_stable_identifier,
    STATE(8960), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12093), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13093), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [438894] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438931] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12101), 1,
      sym__alpha_identifier,
    ACTIONS(12103), 1,
      anon_sym__,
    ACTIONS(12107), 1,
      anon_sym_LPAREN,
    ACTIONS(12109), 1,
      sym__backquoted_id,
    ACTIONS(12111), 1,
      sym_operator_identifier,
    STATE(10440), 1,
      sym__simple_type,
    STATE(10770), 1,
      sym_identifier,
    STATE(10865), 1,
      sym__soft_identifier,
    STATE(17477), 1,
      sym_stable_identifier,
    STATE(8962), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12105), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11079), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [438986] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6278), 1,
      sym__alpha_identifier,
    ACTIONS(6284), 1,
      anon_sym__,
    ACTIONS(6292), 1,
      sym__backquoted_id,
    ACTIONS(6294), 1,
      sym_operator_identifier,
    ACTIONS(7912), 1,
      anon_sym_LPAREN,
    STATE(5001), 1,
      sym__simple_type,
    STATE(5525), 1,
      sym__soft_identifier,
    STATE(5572), 1,
      sym_identifier,
    STATE(17071), 1,
      sym_stable_identifier,
    STATE(8963), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6477), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [439041] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8761), 1,
      sym__alpha_identifier,
    ACTIONS(8763), 1,
      anon_sym__,
    ACTIONS(8767), 1,
      anon_sym_LPAREN,
    ACTIONS(8769), 1,
      sym__backquoted_id,
    ACTIONS(8771), 1,
      sym_operator_identifier,
    STATE(5749), 1,
      sym__simple_type,
    STATE(7705), 1,
      sym_identifier,
    STATE(7907), 1,
      sym__soft_identifier,
    STATE(17083), 1,
      sym_stable_identifier,
    STATE(8964), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8765), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7863), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [439096] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8965), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439133] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12113), 1,
      sym__alpha_identifier,
    ACTIONS(12115), 1,
      anon_sym__,
    ACTIONS(12119), 1,
      anon_sym_LPAREN,
    ACTIONS(12121), 1,
      sym__backquoted_id,
    ACTIONS(12123), 1,
      sym_operator_identifier,
    STATE(10539), 1,
      sym__simple_type,
    STATE(11035), 1,
      sym__soft_identifier,
    STATE(11075), 1,
      sym_identifier,
    STATE(17245), 1,
      sym_stable_identifier,
    STATE(8966), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12117), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11229), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [439188] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8967), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439225] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6344), 1,
      sym__alpha_identifier,
    ACTIONS(6350), 1,
      anon_sym__,
    ACTIONS(6358), 1,
      sym__backquoted_id,
    ACTIONS(6360), 1,
      sym_operator_identifier,
    ACTIONS(7542), 1,
      anon_sym_LPAREN,
    STATE(5079), 1,
      sym__simple_type,
    STATE(6141), 1,
      sym__soft_identifier,
    STATE(6576), 1,
      sym_identifier,
    STATE(17089), 1,
      sym_stable_identifier,
    STATE(8968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6354), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7247), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [439280] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439317] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6426), 1,
      anon_sym__,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(6436), 1,
      sym_operator_identifier,
    ACTIONS(7922), 1,
      anon_sym_LPAREN,
    STATE(6271), 1,
      sym__simple_type,
    STATE(7465), 1,
      sym_identifier,
    STATE(7913), 1,
      sym__soft_identifier,
    STATE(17101), 1,
      sym_stable_identifier,
    STATE(8970), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8446), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [439372] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12125), 1,
      anon_sym_DOT,
    STATE(8971), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439411] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8773), 1,
      sym__alpha_identifier,
    ACTIONS(8779), 1,
      anon_sym__,
    ACTIONS(8783), 1,
      anon_sym_LPAREN,
    ACTIONS(8785), 1,
      sym__backquoted_id,
    ACTIONS(8787), 1,
      sym_operator_identifier,
    STATE(4396), 1,
      sym__simple_type,
    STATE(4893), 1,
      sym_identifier,
    STATE(4931), 1,
      sym__soft_identifier,
    STATE(17113), 1,
      sym_stable_identifier,
    STATE(8972), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8781), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4979), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [439466] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9733), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [439503] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6506), 1,
      anon_sym__,
    ACTIONS(6514), 1,
      sym__backquoted_id,
    ACTIONS(6516), 1,
      sym_operator_identifier,
    ACTIONS(7722), 1,
      anon_sym_LPAREN,
    STATE(4292), 1,
      sym__simple_type,
    STATE(4474), 1,
      sym__soft_identifier,
    STATE(4498), 1,
      sym_identifier,
    STATE(17119), 1,
      sym_stable_identifier,
    STATE(8974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6510), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4591), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [439558] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6546), 1,
      sym__alpha_identifier,
    ACTIONS(6548), 1,
      anon_sym__,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(6558), 1,
      sym_operator_identifier,
    ACTIONS(7732), 1,
      anon_sym_LPAREN,
    STATE(4510), 1,
      sym__simple_type,
    STATE(4934), 1,
      sym_identifier,
    STATE(4937), 1,
      sym__soft_identifier,
    STATE(17125), 1,
      sym_stable_identifier,
    STATE(8975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5066), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [439613] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439650] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8789), 1,
      sym__alpha_identifier,
    ACTIONS(8791), 1,
      anon_sym__,
    ACTIONS(8795), 1,
      anon_sym_LPAREN,
    ACTIONS(8797), 1,
      sym__backquoted_id,
    ACTIONS(8799), 1,
      sym_operator_identifier,
    STATE(4640), 1,
      sym__simple_type,
    STATE(5528), 1,
      sym__soft_identifier,
    STATE(5927), 1,
      sym_identifier,
    STATE(17131), 1,
      sym_stable_identifier,
    STATE(8977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8793), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5865), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [439705] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8978), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [439742] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12127), 1,
      sym__alpha_identifier,
    ACTIONS(12129), 1,
      anon_sym__,
    ACTIONS(12133), 1,
      anon_sym_LPAREN,
    ACTIONS(12135), 1,
      sym__backquoted_id,
    ACTIONS(12137), 1,
      sym_operator_identifier,
    STATE(11200), 1,
      sym__simple_type,
    STATE(11798), 1,
      sym__soft_identifier,
    STATE(11799), 1,
      sym_identifier,
    STATE(17263), 1,
      sym_stable_identifier,
    STATE(8979), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12131), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(12304), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [439797] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6626), 1,
      sym__alpha_identifier,
    ACTIONS(6632), 1,
      anon_sym__,
    ACTIONS(6640), 1,
      sym__backquoted_id,
    ACTIONS(6642), 1,
      sym_operator_identifier,
    ACTIONS(7712), 1,
      anon_sym_LPAREN,
    STATE(4514), 1,
      sym__simple_type,
    STATE(4939), 1,
      sym__soft_identifier,
    STATE(4959), 1,
      sym_identifier,
    STATE(17137), 1,
      sym_stable_identifier,
    STATE(8980), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5078), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [439852] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439889] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8982), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439926] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439963] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6650), 1,
      sym__alpha_identifier,
    ACTIONS(6656), 1,
      anon_sym__,
    ACTIONS(6664), 1,
      sym__backquoted_id,
    ACTIONS(6666), 1,
      sym_operator_identifier,
    ACTIONS(7672), 1,
      anon_sym_LPAREN,
    STATE(5115), 1,
      sym__simple_type,
    STATE(6112), 1,
      sym_identifier,
    STATE(6233), 1,
      sym__soft_identifier,
    STATE(17149), 1,
      sym_stable_identifier,
    STATE(8984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6660), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6764), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [440018] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [440055] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4254), 1,
      sym__alpha_identifier,
    ACTIONS(4260), 1,
      anon_sym__,
    ACTIONS(4272), 1,
      sym__backquoted_id,
    ACTIONS(6732), 1,
      sym_operator_identifier,
    ACTIONS(7512), 1,
      anon_sym_LPAREN,
    STATE(4517), 1,
      sym__simple_type,
    STATE(4846), 1,
      sym_identifier,
    STATE(4941), 1,
      sym__soft_identifier,
    STATE(17161), 1,
      sym_stable_identifier,
    STATE(8986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4266), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5096), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [440110] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6668), 1,
      sym__alpha_identifier,
    ACTIONS(6674), 1,
      anon_sym__,
    ACTIONS(6682), 1,
      sym__backquoted_id,
    ACTIONS(6684), 1,
      sym_operator_identifier,
    ACTIONS(7772), 1,
      anon_sym_LPAREN,
    STATE(5119), 1,
      sym__simple_type,
    STATE(6018), 1,
      sym_identifier,
    STATE(6257), 1,
      sym__soft_identifier,
    STATE(17167), 1,
      sym_stable_identifier,
    STATE(8987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6678), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6819), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [440165] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4312), 1,
      sym__alpha_identifier,
    ACTIONS(4318), 1,
      anon_sym__,
    ACTIONS(4330), 1,
      sym__backquoted_id,
    ACTIONS(6790), 1,
      sym_operator_identifier,
    ACTIONS(7602), 1,
      anon_sym_LPAREN,
    STATE(4817), 1,
      sym__simple_type,
    STATE(5532), 1,
      sym__soft_identifier,
    STATE(5857), 1,
      sym_identifier,
    STATE(17179), 1,
      sym_stable_identifier,
    STATE(8988), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4324), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6288), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [440220] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4344), 1,
      sym__alpha_identifier,
    ACTIONS(4350), 1,
      anon_sym__,
    ACTIONS(4362), 1,
      sym__backquoted_id,
    ACTIONS(6816), 1,
      sym_operator_identifier,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    STATE(5131), 1,
      sym__simple_type,
    STATE(6290), 1,
      sym__soft_identifier,
    STATE(6431), 1,
      sym_identifier,
    STATE(17185), 1,
      sym_stable_identifier,
    STATE(8989), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4356), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6857), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [440275] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8990), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440312] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4408), 1,
      sym__alpha_identifier,
    ACTIONS(4410), 1,
      anon_sym__,
    ACTIONS(4420), 1,
      sym__backquoted_id,
    ACTIONS(6820), 1,
      sym_operator_identifier,
    ACTIONS(7422), 1,
      anon_sym_LPAREN,
    STATE(4293), 1,
      sym__simple_type,
    STATE(4469), 1,
      sym_identifier,
    STATE(4476), 1,
      sym__soft_identifier,
    STATE(17191), 1,
      sym_stable_identifier,
    STATE(8991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4416), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4659), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [440367] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6836), 1,
      anon_sym__,
    ACTIONS(6844), 1,
      sym__backquoted_id,
    ACTIONS(6846), 1,
      sym_operator_identifier,
    ACTIONS(7762), 1,
      anon_sym_LPAREN,
    STATE(7517), 1,
      sym__simple_type,
    STATE(8809), 1,
      sym__soft_identifier,
    STATE(8868), 1,
      sym_identifier,
    STATE(17197), 1,
      sym_stable_identifier,
    STATE(8992), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6840), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9436), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [440422] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8993), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [440459] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4434), 1,
      sym__alpha_identifier,
    ACTIONS(4440), 1,
      anon_sym__,
    ACTIONS(4452), 1,
      sym__backquoted_id,
    ACTIONS(6862), 1,
      sym_operator_identifier,
    ACTIONS(7442), 1,
      anon_sym_LPAREN,
    STATE(4468), 1,
      sym__simple_type,
    STATE(4870), 1,
      sym_identifier,
    STATE(4948), 1,
      sym__soft_identifier,
    STATE(17203), 1,
      sym_stable_identifier,
    STATE(8994), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4446), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5122), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [440514] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9519), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [440551] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8819), 1,
      sym__alpha_identifier,
    ACTIONS(8821), 1,
      anon_sym__,
    ACTIONS(8825), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      sym__backquoted_id,
    ACTIONS(8829), 1,
      sym_operator_identifier,
    STATE(4840), 1,
      sym__simple_type,
    STATE(6229), 1,
      sym_identifier,
    STATE(6351), 1,
      sym__soft_identifier,
    STATE(17209), 1,
      sym_stable_identifier,
    STATE(8996), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8823), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6140), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [440606] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9537), 1,
      sym_operator_identifier,
    STATE(1722), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(8997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8807), 6,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [440657] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(9367), 1,
      anon_sym_match,
    ACTIONS(9854), 1,
      sym__alpha_identifier,
    ACTIONS(9860), 1,
      sym__backquoted_id,
    ACTIONS(9862), 1,
      sym_operator_identifier,
    STATE(553), 1,
      sym_identifier,
    STATE(4043), 1,
      sym__soft_identifier,
    STATE(8998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8803), 4,
      anon_sym_COLON,
      anon_sym_if,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9856), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [440712] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10297), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440751] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12139), 1,
      sym__alpha_identifier,
    ACTIONS(12141), 1,
      anon_sym__,
    ACTIONS(12145), 1,
      anon_sym_LPAREN,
    ACTIONS(12147), 1,
      sym__backquoted_id,
    ACTIONS(12149), 1,
      sym_operator_identifier,
    STATE(11511), 1,
      sym__simple_type,
    STATE(12320), 1,
      sym_identifier,
    STATE(12413), 1,
      sym__soft_identifier,
    STATE(17281), 1,
      sym_stable_identifier,
    STATE(9000), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12143), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13020), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [440806] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440843] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6690), 1,
      sym__alpha_identifier,
    ACTIONS(6696), 1,
      anon_sym__,
    ACTIONS(6704), 1,
      sym__backquoted_id,
    ACTIONS(6706), 1,
      sym_operator_identifier,
    ACTIONS(7412), 1,
      anon_sym_LPAREN,
    STATE(4619), 1,
      sym__simple_type,
    STATE(5112), 1,
      sym_identifier,
    STATE(5191), 1,
      sym__soft_identifier,
    STATE(17215), 1,
      sym_stable_identifier,
    STATE(9002), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5795), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [440898] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440935] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6712), 1,
      sym__alpha_identifier,
    ACTIONS(6718), 1,
      anon_sym__,
    ACTIONS(6726), 1,
      sym__backquoted_id,
    ACTIONS(6728), 1,
      sym_operator_identifier,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    STATE(5144), 1,
      sym__simple_type,
    STATE(6378), 1,
      sym__soft_identifier,
    STATE(6583), 1,
      sym_identifier,
    STATE(17227), 1,
      sym_stable_identifier,
    STATE(9004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6722), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7014), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [440990] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(832), 1,
      anon_sym_LBRACE,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(10123), 1,
      anon_sym_LPAREN,
    ACTIONS(10855), 1,
      anon_sym_DOT,
    ACTIONS(10873), 1,
      sym_operator_identifier,
    ACTIONS(12151), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_while,
      anon_sym_match,
    STATE(9005), 2,
      sym_comment,
      sym_block_comment,
    STATE(9409), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [441051] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9006), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10522), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [441088] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6740), 1,
      sym__alpha_identifier,
    ACTIONS(6746), 1,
      anon_sym__,
    ACTIONS(6754), 1,
      sym__backquoted_id,
    ACTIONS(6756), 1,
      sym_operator_identifier,
    ACTIONS(7952), 1,
      anon_sym_LPAREN,
    STATE(5891), 1,
      sym__simple_type,
    STATE(6959), 1,
      sym_identifier,
    STATE(7274), 1,
      sym__soft_identifier,
    STATE(17239), 1,
      sym_stable_identifier,
    STATE(9007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6750), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7605), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [441143] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8933), 1,
      sym__backquoted_id,
    ACTIONS(12153), 1,
      anon_sym_AT,
    STATE(9885), 1,
      sym_annotation,
    STATE(9008), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8931), 18,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441184] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6774), 1,
      sym__alpha_identifier,
    ACTIONS(6776), 1,
      anon_sym__,
    ACTIONS(6784), 1,
      sym__backquoted_id,
    ACTIONS(6786), 1,
      sym_operator_identifier,
    ACTIONS(7662), 1,
      anon_sym_LPAREN,
    STATE(4397), 1,
      sym__simple_type,
    STATE(4574), 1,
      sym_identifier,
    STATE(4626), 1,
      sym__soft_identifier,
    STATE(17251), 1,
      sym_stable_identifier,
    STATE(9009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6780), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4851), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [441239] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441276] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9011), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [441313] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9012), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [441350] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6114), 1,
      sym__alpha_identifier,
    ACTIONS(6120), 1,
      anon_sym__,
    ACTIONS(6128), 1,
      sym__backquoted_id,
    ACTIONS(6130), 1,
      sym_operator_identifier,
    ACTIONS(7652), 1,
      anon_sym_LPAREN,
    STATE(4698), 1,
      sym__simple_type,
    STATE(5135), 1,
      sym_identifier,
    STATE(5193), 1,
      sym__soft_identifier,
    STATE(17257), 1,
      sym_stable_identifier,
    STATE(9013), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6124), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5886), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [441405] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9813), 1,
      sym__alpha_identifier,
    ACTIONS(9819), 1,
      sym__backquoted_id,
    ACTIONS(9821), 1,
      sym_operator_identifier,
    ACTIONS(9864), 1,
      anon_sym_EQ,
    STATE(530), 1,
      sym_identifier,
    STATE(3932), 1,
      sym__soft_identifier,
    STATE(9014), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9363), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9815), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [441458] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4602), 1,
      sym__alpha_identifier,
    ACTIONS(4608), 1,
      anon_sym__,
    ACTIONS(4620), 1,
      sym__backquoted_id,
    ACTIONS(6176), 1,
      sym_operator_identifier,
    ACTIONS(7832), 1,
      anon_sym_LPAREN,
    STATE(4739), 1,
      sym__simple_type,
    STATE(5163), 1,
      sym_identifier,
    STATE(5195), 1,
      sym__soft_identifier,
    STATE(17269), 1,
      sym_stable_identifier,
    STATE(9015), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5955), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [441513] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10299), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9016), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441552] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    ACTIONS(7642), 1,
      anon_sym_LPAREN,
    STATE(4892), 1,
      sym__simple_type,
    STATE(5538), 1,
      sym__soft_identifier,
    STATE(5956), 1,
      sym_identifier,
    STATE(17275), 1,
      sym_stable_identifier,
    STATE(9017), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6616), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [441607] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9018), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [441644] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9019), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [441681] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9835), 1,
      sym__alpha_identifier,
    ACTIONS(9841), 1,
      sym__backquoted_id,
    ACTIONS(9843), 1,
      sym_operator_identifier,
    ACTIONS(9868), 1,
      anon_sym_EQ,
    STATE(531), 1,
      sym_identifier,
    STATE(3976), 1,
      sym__soft_identifier,
    STATE(9020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(9363), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9837), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [441734] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9021), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441771] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10305), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441810] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12156), 1,
      sym__alpha_identifier,
    ACTIONS(12158), 1,
      anon_sym__,
    ACTIONS(12162), 1,
      anon_sym_LPAREN,
    ACTIONS(12164), 1,
      sym__backquoted_id,
    ACTIONS(12166), 1,
      sym_operator_identifier,
    STATE(6452), 1,
      sym__simple_type,
    STATE(7882), 1,
      sym_identifier,
    STATE(8068), 1,
      sym__soft_identifier,
    STATE(17535), 1,
      sym_stable_identifier,
    STATE(9023), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12160), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8635), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [441865] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10056), 1,
      sym_operator_identifier,
    STATE(1695), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9024), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8807), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [441918] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9025), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441955] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441992] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442029] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12168), 1,
      anon_sym_with,
    STATE(9028), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9416), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [442068] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [442105] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [442142] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [442179] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9032), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [442216] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [442253] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442290] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442327] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9036), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [442364] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9037), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442401] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442438] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9039), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442475] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [442512] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4189), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10662), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [442553] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7318), 1,
      anon_sym__,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(8344), 1,
      anon_sym_LPAREN,
    ACTIONS(8346), 1,
      sym_operator_identifier,
    STATE(10885), 1,
      sym__simple_type,
    STATE(11161), 1,
      sym_identifier,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(16658), 1,
      sym_stable_identifier,
    STATE(9042), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11465), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [442608] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10609), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442647] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12171), 1,
      anon_sym_with,
    STATE(9044), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442686] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442723] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442760] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9047), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442797] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6832), 1,
      anon_sym_COLON,
    ACTIONS(6834), 1,
      anon_sym_LBRACE,
    ACTIONS(11975), 1,
      anon_sym_with,
    STATE(8780), 1,
      aux_sym_compound_type_repeat1,
    STATE(11691), 1,
      sym_template_body,
    STATE(11692), 1,
      sym__refinement,
    ACTIONS(8408), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(9048), 2,
      sym_comment,
      sym_block_comment,
    STATE(11704), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8406), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442848] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442885] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8885), 1,
      sym__alpha_identifier,
    ACTIONS(8887), 1,
      anon_sym__,
    ACTIONS(8891), 1,
      anon_sym_LPAREN,
    ACTIONS(8893), 1,
      sym__backquoted_id,
    ACTIONS(8895), 1,
      sym_operator_identifier,
    STATE(7117), 1,
      sym__simple_type,
    STATE(8971), 1,
      sym_identifier,
    STATE(8990), 1,
      sym__soft_identifier,
    STATE(17521), 1,
      sym_stable_identifier,
    STATE(9050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8889), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9102), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [442940] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442977] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443014] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443051] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443088] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12174), 1,
      anon_sym_COLON,
    ACTIONS(12177), 1,
      anon_sym_LBRACE,
    STATE(10437), 1,
      sym_template_body,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9230), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9222), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9056), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443170] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12180), 1,
      anon_sym_with,
    STATE(9057), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443209] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443246] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443283] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443320] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443357] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12185), 1,
      anon_sym__,
    ACTIONS(12187), 1,
      anon_sym_LPAREN,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(12191), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(11100), 1,
      sym__simple_type,
    STATE(11587), 1,
      sym_identifier,
    STATE(16317), 1,
      sym_stable_identifier,
    STATE(9062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11979), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [443412] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [443449] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [443486] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9065), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [443523] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443560] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10617), 1,
      sym__alpha_identifier,
    ACTIONS(10623), 1,
      sym__backquoted_id,
    ACTIONS(10625), 1,
      sym_operator_identifier,
    STATE(541), 1,
      sym_identifier,
    STATE(4039), 1,
      sym__soft_identifier,
    STATE(9067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9367), 6,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(10619), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [443611] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443648] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(9069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443687] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9068), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443724] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443761] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [443798] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9073), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443835] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9074), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443872] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8465), 1,
      sym__alpha_identifier,
    ACTIONS(8471), 1,
      anon_sym__,
    ACTIONS(8475), 1,
      anon_sym_LPAREN,
    ACTIONS(8477), 1,
      sym__backquoted_id,
    ACTIONS(8479), 1,
      sym_operator_identifier,
    STATE(4657), 1,
      sym__simple_type,
    STATE(5699), 1,
      sym__soft_identifier,
    STATE(5780), 1,
      sym_identifier,
    STATE(16486), 1,
      sym_stable_identifier,
    STATE(9075), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8473), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5877), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [443927] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443964] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [444001] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(9078), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444040] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444077] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9918), 1,
      sym_operator_identifier,
    STATE(1712), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8807), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [444130] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9081), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444167] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444204] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9083), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444241] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444278] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444315] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444352] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9087), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444389] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4950), 1,
      anon_sym__,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(5116), 1,
      sym_operator_identifier,
    ACTIONS(7532), 1,
      anon_sym_LPAREN,
    STATE(4568), 1,
      sym__simple_type,
    STATE(5196), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(16640), 1,
      sym_stable_identifier,
    STATE(9088), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5973), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [444444] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9089), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444481] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444518] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9091), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [444561] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9092), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444598] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9878), 1,
      sym_operator_identifier,
    STATE(1703), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9093), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8807), 6,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [444651] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [444688] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9095), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [444725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [444762] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8487), 1,
      sym__alpha_identifier,
    ACTIONS(8489), 1,
      anon_sym__,
    ACTIONS(8493), 1,
      anon_sym_LPAREN,
    ACTIONS(8495), 1,
      sym__backquoted_id,
    ACTIONS(8497), 1,
      sym_operator_identifier,
    STATE(5618), 1,
      sym__simple_type,
    STATE(7616), 1,
      sym__soft_identifier,
    STATE(8045), 1,
      sym_identifier,
    STATE(16768), 1,
      sym_stable_identifier,
    STATE(9097), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8491), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8075), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [444817] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444854] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9099), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444891] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9646), 1,
      sym_arguments,
    STATE(9100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444930] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9101), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [444967] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445004] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9103), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445041] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9104), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445078] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445115] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9106), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445152] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym__alpha_identifier,
    ACTIONS(6462), 1,
      anon_sym__,
    ACTIONS(6470), 1,
      sym__backquoted_id,
    ACTIONS(6472), 1,
      sym_operator_identifier,
    ACTIONS(7452), 1,
      anon_sym_LPAREN,
    STATE(5259), 1,
      sym__simple_type,
    STATE(6003), 1,
      sym_identifier,
    STATE(6313), 1,
      sym__soft_identifier,
    STATE(16863), 1,
      sym_stable_identifier,
    STATE(9107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6466), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6703), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [445207] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445244] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9109), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9519), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445281] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4222), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445322] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445359] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445398] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445435] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9114), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445472] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9557), 1,
      sym_arguments,
    STATE(9115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445511] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445548] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [445585] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9118), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445622] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [445659] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [445696] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9121), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [445733] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9624), 1,
      anon_sym_LBRACE,
    ACTIONS(9626), 1,
      anon_sym_with,
    STATE(7290), 1,
      aux_sym_compound_type_repeat1,
    STATE(9198), 1,
      sym_template_body,
    STATE(9243), 1,
      sym__refinement,
    STATE(9122), 2,
      sym_comment,
      sym_block_comment,
    STATE(9246), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8246), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445782] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    ACTIONS(12193), 1,
      anon_sym_COLON,
    ACTIONS(12196), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(9123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445825] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9124), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [445862] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8503), 1,
      sym__alpha_identifier,
    ACTIONS(8505), 1,
      anon_sym__,
    ACTIONS(8509), 1,
      anon_sym_LPAREN,
    ACTIONS(8511), 1,
      sym__backquoted_id,
    ACTIONS(8513), 1,
      sym_operator_identifier,
    STATE(5644), 1,
      sym__simple_type,
    STATE(7788), 1,
      sym__soft_identifier,
    STATE(7804), 1,
      sym_identifier,
    STATE(16966), 1,
      sym_stable_identifier,
    STATE(9125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8507), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [445917] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9936), 1,
      sym_operator_identifier,
    STATE(1745), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9126), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8807), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [445970] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [446007] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4236), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446048] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9129), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [446085] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9130), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446122] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9131), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446159] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9132), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446196] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446233] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12199), 1,
      sym__alpha_identifier,
    ACTIONS(12201), 1,
      anon_sym__,
    ACTIONS(12205), 1,
      anon_sym_LPAREN,
    ACTIONS(12207), 1,
      sym__backquoted_id,
    ACTIONS(12209), 1,
      sym_operator_identifier,
    STATE(10522), 1,
      sym__simple_type,
    STATE(10957), 1,
      sym__soft_identifier,
    STATE(11113), 1,
      sym_identifier,
    STATE(16650), 1,
      sym_stable_identifier,
    STATE(9134), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12203), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11202), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [446288] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11377), 1,
      anon_sym_AT,
    STATE(9191), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9936), 1,
      sym_annotation,
    STATE(9135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8957), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446331] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446368] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9137), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446411] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446448] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446485] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446522] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446559] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446596] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9666), 1,
      sym__end_marker,
    STATE(9143), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10127), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [446635] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [446672] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9947), 1,
      sym_operator_identifier,
    STATE(1789), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8807), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8805), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [446725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [446762] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [446799] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6138), 1,
      anon_sym__,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(6148), 1,
      sym_operator_identifier,
    ACTIONS(7692), 1,
      anon_sym_LPAREN,
    STATE(5298), 1,
      sym__simple_type,
    STATE(6122), 1,
      sym_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(17060), 1,
      sym_stable_identifier,
    STATE(9148), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6681), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [446854] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9149), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446891] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9150), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446928] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446965] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447002] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9621), 1,
      sym_arguments,
    STATE(9153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [447041] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447078] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4640), 1,
      sym__alpha_identifier,
    ACTIONS(4642), 1,
      anon_sym__,
    ACTIONS(4652), 1,
      sym__backquoted_id,
    ACTIONS(6688), 1,
      sym_operator_identifier,
    ACTIONS(7472), 1,
      anon_sym_LPAREN,
    STATE(6639), 1,
      sym__simple_type,
    STATE(7872), 1,
      sym__soft_identifier,
    STATE(7995), 1,
      sym_identifier,
    STATE(17142), 1,
      sym_stable_identifier,
    STATE(9155), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4648), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8425), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [447133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447170] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4134), 1,
      sym__backquoted_id,
    STATE(9157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(4130), 8,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
    ACTIONS(4132), 8,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
  [447211] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447248] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9159), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447285] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9160), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447322] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9161), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447359] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447396] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447433] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8378), 1,
      sym__alpha_identifier,
    ACTIONS(8384), 1,
      anon_sym__,
    ACTIONS(8388), 1,
      anon_sym_LPAREN,
    ACTIONS(8390), 1,
      sym__backquoted_id,
    ACTIONS(8392), 1,
      sym_operator_identifier,
    STATE(12326), 1,
      sym__simple_type,
    STATE(13074), 1,
      sym_identifier,
    STATE(13178), 1,
      sym__soft_identifier,
    STATE(17206), 1,
      sym_stable_identifier,
    STATE(9164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8386), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13352), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [447488] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8422), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447525] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9166), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447562] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447599] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447636] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9169), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447673] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447710] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9171), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9068), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447747] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447784] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447821] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447858] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9175), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447895] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [447932] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(9177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 7,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447973] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [448010] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [448047] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8527), 1,
      sym__alpha_identifier,
    ACTIONS(8533), 1,
      anon_sym__,
    ACTIONS(8537), 1,
      anon_sym_LPAREN,
    ACTIONS(8539), 1,
      sym__backquoted_id,
    ACTIONS(8541), 1,
      sym_operator_identifier,
    STATE(4449), 1,
      sym__simple_type,
    STATE(4810), 1,
      sym_identifier,
    STATE(5008), 1,
      sym__soft_identifier,
    STATE(17280), 1,
      sym_stable_identifier,
    STATE(9180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8535), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4820), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [448102] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448139] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4194), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9182), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10662), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [448180] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9183), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10573), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [448217] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448254] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10577), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [448291] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9186), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10581), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [448328] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10226), 1,
      anon_sym_COLON,
    ACTIONS(10666), 1,
      anon_sym_EQ_GT,
    ACTIONS(10668), 1,
      anon_sym_QMARK_EQ_GT,
    STATE(16373), 1,
      sym__self_type_ascription,
    STATE(9187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448373] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448410] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9189), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448447] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9190), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448484] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12211), 1,
      anon_sym_AT,
    STATE(9936), 1,
      sym_annotation,
    STATE(9191), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8931), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448525] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448562] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448599] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448636] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6832), 1,
      anon_sym_COLON,
    ACTIONS(6834), 1,
      anon_sym_LBRACE,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8410), 1,
      sym__outdent,
    ACTIONS(8412), 1,
      anon_sym_case,
    ACTIONS(11975), 1,
      anon_sym_with,
    STATE(8780), 1,
      aux_sym_compound_type_repeat1,
    STATE(11691), 1,
      sym_template_body,
    STATE(11692), 1,
      sym__refinement,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9195), 2,
      sym_comment,
      sym_block_comment,
    STATE(11704), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448693] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [448730] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448767] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9198), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [448804] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4572), 1,
      sym__alpha_identifier,
    ACTIONS(4578), 1,
      anon_sym__,
    ACTIONS(4590), 1,
      sym__backquoted_id,
    ACTIONS(6896), 1,
      sym_operator_identifier,
    ACTIONS(7432), 1,
      anon_sym_LPAREN,
    STATE(4513), 1,
      sym__simple_type,
    STATE(5024), 1,
      sym_identifier,
    STATE(5025), 1,
      sym__soft_identifier,
    STATE(17351), 1,
      sym_stable_identifier,
    STATE(9199), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5296), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [448859] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9200), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448896] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448933] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448970] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [449007] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [449044] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449081] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10226), 1,
      anon_sym_COLON,
    ACTIONS(10231), 1,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(10375), 1,
      anon_sym_EQ_GT,
    STATE(16353), 1,
      sym__self_type_ascription,
    STATE(9206), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449126] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9207), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449163] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449200] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    ACTIONS(12214), 1,
      anon_sym_COLON,
    STATE(9209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449241] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [449278] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9211), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449321] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449358] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8280), 1,
      sym__alpha_identifier,
    ACTIONS(8286), 1,
      anon_sym__,
    ACTIONS(8290), 1,
      anon_sym_LPAREN,
    ACTIONS(8292), 1,
      sym__backquoted_id,
    ACTIONS(8294), 1,
      sym_operator_identifier,
    STATE(10759), 1,
      sym__simple_type,
    STATE(11152), 1,
      sym_identifier,
    STATE(11176), 1,
      sym__soft_identifier,
    STATE(17410), 1,
      sym_stable_identifier,
    STATE(9213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11603), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [449413] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9214), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449450] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9215), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449487] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9216), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9086), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449524] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9088), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449561] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12216), 1,
      anon_sym_with,
    STATE(9218), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449600] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9219), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9090), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449637] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9220), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449676] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9221), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449713] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4176), 1,
      anon_sym__,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(4976), 1,
      sym_operator_identifier,
    ACTIONS(7552), 1,
      anon_sym_LPAREN,
    STATE(4886), 1,
      sym__simple_type,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym_identifier,
    STATE(17593), 1,
      sym_stable_identifier,
    STATE(9222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6058), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [449768] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9223), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449805] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12219), 1,
      anon_sym_LPAREN,
    ACTIONS(12221), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(4268), 1,
      sym_identifier,
    STATE(4575), 1,
      sym__simple_type,
    STATE(16304), 1,
      sym_stable_identifier,
    STATE(9224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4353), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [449860] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9225), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [449897] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9226), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449934] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9227), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449971] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9098), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450008] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450045] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450082] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9231), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450119] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9232), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450156] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9233), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [450193] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9234), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450230] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450273] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11770), 1,
      sym__alpha_identifier,
    ACTIONS(11772), 1,
      anon_sym__,
    ACTIONS(11776), 1,
      anon_sym_LPAREN,
    ACTIONS(11778), 1,
      sym__backquoted_id,
    ACTIONS(11780), 1,
      sym_operator_identifier,
    STATE(13195), 1,
      sym__simple_type,
    STATE(13643), 1,
      sym__soft_identifier,
    STATE(13807), 1,
      sym_identifier,
    STATE(17660), 1,
      sym_stable_identifier,
    STATE(9236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11774), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14006), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [450328] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9237), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9086), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450365] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12223), 1,
      anon_sym_with,
    STATE(9238), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450404] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9239), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [450441] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450484] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5738), 1,
      sym__end_marker,
    STATE(9241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450523] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9242), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9895), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [450560] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9243), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [450597] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [450634] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8543), 1,
      sym__alpha_identifier,
    ACTIONS(8545), 1,
      anon_sym__,
    ACTIONS(8549), 1,
      anon_sym_LPAREN,
    ACTIONS(8551), 1,
      sym__backquoted_id,
    ACTIONS(8553), 1,
      sym_operator_identifier,
    STATE(4897), 1,
      sym__simple_type,
    STATE(6060), 1,
      sym_identifier,
    STATE(6081), 1,
      sym__soft_identifier,
    STATE(17711), 1,
      sym_stable_identifier,
    STATE(9245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8547), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6107), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [450689] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9246), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [450726] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9902), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [450763] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9248), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [450800] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450837] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9250), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [450874] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9251), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450911] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12226), 1,
      anon_sym_with,
    STATE(9252), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450950] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12229), 1,
      sym__alpha_identifier,
    ACTIONS(12231), 1,
      anon_sym__,
    ACTIONS(12235), 1,
      anon_sym_LPAREN,
    ACTIONS(12237), 1,
      sym__backquoted_id,
    ACTIONS(12239), 1,
      sym_operator_identifier,
    STATE(11554), 1,
      sym__simple_type,
    STATE(12227), 1,
      sym_identifier,
    STATE(12341), 1,
      sym__soft_identifier,
    STATE(16835), 1,
      sym_stable_identifier,
    STATE(9253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12233), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(12718), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [451005] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4227), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9254), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [451046] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9255), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [451083] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9256), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [451120] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9257), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [451157] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3298), 1,
      anon_sym_LBRACE,
    ACTIONS(11584), 1,
      anon_sym_LPAREN,
    ACTIONS(11949), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(8833), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(9258), 2,
      sym_comment,
      sym_block_comment,
    STATE(10787), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8831), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [451206] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9912), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [451243] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9260), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9916), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [451280] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9261), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10704), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [451317] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(8276), 1,
      anon_sym_LPAREN,
    ACTIONS(8278), 1,
      sym_operator_identifier,
    STATE(11115), 1,
      sym__simple_type,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(11545), 1,
      sym_identifier,
    STATE(17819), 1,
      sym_stable_identifier,
    STATE(9262), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11824), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [451372] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9263), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [451409] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4240), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9264), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10662), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [451450] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9265), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9092), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [451487] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12241), 1,
      sym__alpha_identifier,
    ACTIONS(12243), 1,
      anon_sym__,
    ACTIONS(12247), 1,
      anon_sym_LPAREN,
    ACTIONS(12249), 1,
      sym__backquoted_id,
    ACTIONS(12251), 1,
      sym_operator_identifier,
    STATE(11118), 1,
      sym__simple_type,
    STATE(11224), 1,
      sym__soft_identifier,
    STATE(11520), 1,
      sym_identifier,
    STATE(16871), 1,
      sym_stable_identifier,
    STATE(9266), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12245), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11826), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [451542] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9267), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10708), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [451579] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [451616] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [451653] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [451690] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9271), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [451727] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [451764] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3298), 1,
      anon_sym_LBRACE,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(11584), 1,
      anon_sym_LPAREN,
    ACTIONS(11949), 1,
      anon_sym_DOT,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(8837), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(9273), 2,
      sym_comment,
      sym_block_comment,
    STATE(10787), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8835), 11,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [451815] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4241), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [451856] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(8412), 5,
      anon_sym_COLON,
      anon_sym_while,
      anon_sym_EQ,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [451899] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8555), 1,
      sym__alpha_identifier,
    ACTIONS(8557), 1,
      anon_sym__,
    ACTIONS(8561), 1,
      anon_sym_LPAREN,
    ACTIONS(8563), 1,
      sym__backquoted_id,
    ACTIONS(8565), 1,
      sym_operator_identifier,
    STATE(5838), 1,
      sym__simple_type,
    STATE(7451), 1,
      sym_identifier,
    STATE(7612), 1,
      sym__soft_identifier,
    STATE(17871), 1,
      sym_stable_identifier,
    STATE(9276), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8559), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7570), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [451954] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [451991] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452028] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9279), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452065] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9280), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [452102] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9281), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [452139] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11549), 1,
      anon_sym_LPAREN,
    STATE(9289), 1,
      aux_sym_annotation_repeat1,
    STATE(10079), 1,
      sym_arguments,
    STATE(9282), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8426), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452182] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12253), 1,
      sym__alpha_identifier,
    ACTIONS(12255), 1,
      anon_sym__,
    ACTIONS(12259), 1,
      anon_sym_LPAREN,
    ACTIONS(12261), 1,
      sym__backquoted_id,
    ACTIONS(12263), 1,
      sym_operator_identifier,
    STATE(11063), 1,
      sym__soft_identifier,
    STATE(12561), 1,
      sym__simple_type,
    STATE(13049), 1,
      sym_identifier,
    STATE(16952), 1,
      sym_stable_identifier,
    STATE(9283), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13348), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [452237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9284), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [452274] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4224), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452315] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9286), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452352] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452395] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9288), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [452432] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12265), 1,
      anon_sym_LPAREN,
    STATE(10079), 1,
      sym_arguments,
    STATE(9289), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8430), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452473] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4234), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9290), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452514] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9538), 1,
      sym_arguments,
    STATE(9291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452553] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8567), 1,
      sym__alpha_identifier,
    ACTIONS(8569), 1,
      anon_sym__,
    ACTIONS(8573), 1,
      anon_sym_LPAREN,
    ACTIONS(8575), 1,
      sym__backquoted_id,
    ACTIONS(8577), 1,
      sym_operator_identifier,
    STATE(6357), 1,
      sym__simple_type,
    STATE(8201), 1,
      sym__soft_identifier,
    STATE(8332), 1,
      sym_identifier,
    STATE(16178), 1,
      sym_stable_identifier,
    STATE(9292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8571), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8702), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [452608] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452645] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9294), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10031), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [452682] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11820), 1,
      anon_sym_EQ_GT,
    STATE(9295), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452721] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9296), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10035), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [452758] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9297), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452795] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452832] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12268), 1,
      sym__alpha_identifier,
    ACTIONS(12270), 1,
      anon_sym__,
    ACTIONS(12274), 1,
      anon_sym_LPAREN,
    ACTIONS(12276), 1,
      sym__backquoted_id,
    ACTIONS(12278), 1,
      sym_operator_identifier,
    STATE(10751), 1,
      sym__simple_type,
    STATE(11269), 1,
      sym__soft_identifier,
    STATE(11296), 1,
      sym_identifier,
    STATE(16985), 1,
      sym_stable_identifier,
    STATE(9299), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12272), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11698), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [452887] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9300), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10041), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [452924] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452961] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452998] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5751), 1,
      sym__end_marker,
    STATE(9303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453037] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9304), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453074] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12219), 1,
      anon_sym_LPAREN,
    ACTIONS(12221), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(4268), 1,
      sym_identifier,
    STATE(12316), 1,
      sym__simple_type,
    STATE(16304), 1,
      sym_stable_identifier,
    STATE(9305), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4353), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [453129] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [453166] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10048), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [453203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8994), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453240] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453277] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9310), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10052), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [453314] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4210), 1,
      sym__alpha_identifier,
    ACTIONS(4216), 1,
      anon_sym__,
    ACTIONS(4228), 1,
      sym__backquoted_id,
    ACTIONS(6248), 1,
      sym_operator_identifier,
    ACTIONS(7872), 1,
      anon_sym_LPAREN,
    STATE(5402), 1,
      sym__simple_type,
    STATE(6312), 1,
      sym_identifier,
    STATE(6658), 1,
      sym__soft_identifier,
    STATE(16208), 1,
      sym_stable_identifier,
    STATE(9311), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4222), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7079), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [453369] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9312), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453406] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9313), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [453443] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9314), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453480] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9315), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453517] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453554] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(9317), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 7,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453595] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9318), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453632] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      anon_sym__,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(6226), 1,
      sym_operator_identifier,
    ACTIONS(7492), 1,
      anon_sym_LPAREN,
    STATE(6425), 1,
      sym__simple_type,
    STATE(7527), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(16238), 1,
      sym_stable_identifier,
    STATE(9319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8458), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [453687] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9320), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9088), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453724] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453761] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453798] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9323), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453835] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9324), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8953), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453872] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9325), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453915] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(830), 1,
      sym__alpha_identifier,
    ACTIONS(860), 1,
      sym__backquoted_id,
    ACTIONS(12282), 1,
      sym_operator_identifier,
    STATE(5706), 1,
      sym__soft_identifier,
    STATE(9370), 1,
      sym_identifier,
    STATE(9326), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(840), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12280), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [453961] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9327), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453997] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9328), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454033] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9329), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9733), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454069] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10730), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9330), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [454107] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9331), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [454143] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9762), 1,
      sym_arguments,
    STATE(9332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454181] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(10877), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(9333), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10879), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [454239] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454275] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10235), 1,
      sym__alpha_identifier,
    ACTIONS(10239), 1,
      anon_sym_EQ,
    ACTIONS(10241), 1,
      sym__backquoted_id,
    ACTIONS(10243), 1,
      sym_operator_identifier,
    STATE(533), 1,
      sym_identifier,
    STATE(4027), 1,
      sym__soft_identifier,
    STATE(9335), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 5,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(10237), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [454327] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10734), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9336), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [454365] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454407] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10245), 1,
      sym__alpha_identifier,
    ACTIONS(10249), 1,
      anon_sym_EQ,
    ACTIONS(10251), 1,
      sym__backquoted_id,
    ACTIONS(10253), 1,
      sym_operator_identifier,
    STATE(538), 1,
      sym_identifier,
    STATE(4045), 1,
      sym__soft_identifier,
    STATE(9338), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10247), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [454459] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9339), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454495] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10828), 1,
      sym__alpha_identifier,
    ACTIONS(10834), 1,
      sym__backquoted_id,
    ACTIONS(10836), 1,
      sym_operator_identifier,
    STATE(548), 1,
      sym_identifier,
    STATE(4051), 1,
      sym__soft_identifier,
    STATE(9340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(9367), 6,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(10830), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [454545] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454581] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9342), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454617] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10255), 1,
      sym__alpha_identifier,
    ACTIONS(10259), 1,
      anon_sym_EQ,
    ACTIONS(10261), 1,
      sym__backquoted_id,
    ACTIONS(10263), 1,
      sym_operator_identifier,
    STATE(534), 1,
      sym_identifier,
    STATE(4030), 1,
      sym__soft_identifier,
    STATE(9343), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 5,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(10257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [454669] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6564), 1,
      sym__end_marker,
    STATE(9344), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454707] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9345), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454743] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454779] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9347), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454815] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454851] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9349), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454887] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9350), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454923] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9351), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9291), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454959] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11040), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454997] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9353), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10402), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [455033] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9354), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455069] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [455105] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9356), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455141] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9357), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455177] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455213] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10268), 1,
      sym__alpha_identifier,
    ACTIONS(10272), 1,
      anon_sym_EQ,
    ACTIONS(10274), 1,
      sym__backquoted_id,
    ACTIONS(10276), 1,
      sym_operator_identifier,
    STATE(543), 1,
      sym_identifier,
    STATE(4041), 1,
      sym__soft_identifier,
    STATE(9359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(10270), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [455265] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9360), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8406), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [455301] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9361), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455337] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9362), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [455373] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455409] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9364), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455445] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9365), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455481] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4207), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10662), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [455521] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455557] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455593] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9369), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9912), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [455629] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9370), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9916), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [455665] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9371), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455701] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4195), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455741] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10406), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [455777] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9374), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455813] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9375), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9376), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455885] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9377), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455921] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455957] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9379), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455993] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9380), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456029] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9381), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456065] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9382), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456101] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9383), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456143] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9902), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456179] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456215] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9386), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [456251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9387), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456287] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9388), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12286), 6,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(12284), 15,
      anon_sym__,
      anon_sym_given,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
  [456323] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9389), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [456359] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [456395] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9391), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10412), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [456431] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9392), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10496), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [456467] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9393), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456503] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1480), 1,
      sym__alpha_identifier,
    ACTIONS(1502), 1,
      sym__backquoted_id,
    ACTIONS(12290), 1,
      sym_operator_identifier,
    STATE(5752), 1,
      sym__soft_identifier,
    STATE(8632), 1,
      sym_identifier,
    STATE(9394), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1490), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12288), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [456549] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [456585] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456621] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456657] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9959), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456693] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(9367), 1,
      anon_sym_match,
    ACTIONS(9854), 1,
      sym__alpha_identifier,
    ACTIONS(9860), 1,
      sym__backquoted_id,
    ACTIONS(9862), 1,
      sym_operator_identifier,
    STATE(553), 1,
      sym_identifier,
    STATE(4043), 1,
      sym__soft_identifier,
    STATE(9399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8803), 4,
      anon_sym_COLON,
      anon_sym_if,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9856), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [456745] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10416), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [456781] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [456817] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9402), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456853] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10319), 1,
      anon_sym_AT,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10927), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10925), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [456899] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [456935] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1334), 1,
      sym__alpha_identifier,
    ACTIONS(1356), 1,
      sym__backquoted_id,
    ACTIONS(12294), 1,
      sym_operator_identifier,
    STATE(5530), 1,
      sym__soft_identifier,
    STATE(8709), 1,
      sym_identifier,
    STATE(9405), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1344), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12292), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [456981] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(9406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457021] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9407), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457057] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9408), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 6,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_LT_DASH,
  [457093] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10420), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [457129] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9410), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10500), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [457165] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10494), 1,
      sym_operator_identifier,
    STATE(1743), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9411), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8807), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [457217] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8901), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457253] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9413), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457289] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9414), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [457325] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10810), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9415), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457363] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9416), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457399] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9068), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457435] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10235), 1,
      sym__alpha_identifier,
    ACTIONS(10241), 1,
      sym__backquoted_id,
    ACTIONS(10243), 1,
      sym_operator_identifier,
    ACTIONS(10301), 1,
      anon_sym_EQ,
    STATE(533), 1,
      sym_identifier,
    STATE(4027), 1,
      sym__soft_identifier,
    STATE(9418), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
    ACTIONS(9363), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(10237), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [457487] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10424), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [457523] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10815), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457561] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8905), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457597] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10255), 1,
      sym__alpha_identifier,
    ACTIONS(10261), 1,
      sym__backquoted_id,
    ACTIONS(10263), 1,
      sym_operator_identifier,
    ACTIONS(10303), 1,
      anon_sym_EQ,
    STATE(534), 1,
      sym_identifier,
    STATE(4030), 1,
      sym__soft_identifier,
    STATE(9422), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
    ACTIONS(9363), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(10257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [457649] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9423), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [457685] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9424), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9959), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [457721] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8621), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457757] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9426), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9733), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [457793] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9427), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [457829] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9428), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [457865] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9429), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [457901] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9430), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457937] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9431), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457979] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11815), 1,
      anon_sym_LPAREN,
    STATE(9522), 1,
      aux_sym_annotation_repeat1,
    STATE(10167), 1,
      sym_arguments,
    STATE(9432), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 4,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8426), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458021] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10056), 1,
      sym_operator_identifier,
    STATE(1695), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9433), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8807), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [458071] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9434), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458107] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(9435), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458147] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9436), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458183] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458219] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9086), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458255] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9439), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458291] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9440), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458327] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9441), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458363] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2016), 1,
      sym__alpha_identifier,
    ACTIONS(2038), 1,
      sym__backquoted_id,
    ACTIONS(12298), 1,
      sym_operator_identifier,
    STATE(4685), 1,
      sym__soft_identifier,
    STATE(6561), 1,
      sym_identifier,
    STATE(9442), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2026), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12296), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [458409] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9443), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [458445] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9444), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9088), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458481] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9445), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9090), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458517] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9446), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458553] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9447), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [458589] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9448), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [458625] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9449), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458661] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9450), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458697] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9098), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458733] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9452), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10428), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [458769] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9453), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8835), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [458811] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9454), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458847] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458883] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9456), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458919] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10668), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9457), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458957] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9458), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 15,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [458993] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9835), 1,
      sym__alpha_identifier,
    ACTIONS(9841), 1,
      sym__backquoted_id,
    ACTIONS(9843), 1,
      sym_operator_identifier,
    ACTIONS(10607), 1,
      anon_sym_EQ,
    STATE(531), 1,
      sym_identifier,
    STATE(3976), 1,
      sym__soft_identifier,
    STATE(9459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(9837), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [459045] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9460), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7220), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459081] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9461), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9462), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [459153] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9463), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 6,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_LT_DASH,
  [459189] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459225] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10432), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [459261] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12300), 1,
      anon_sym_with,
    STATE(9466), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459299] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459335] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459377] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9469), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459413] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [459449] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9471), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459485] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9472), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [459521] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4220), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459561] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459597] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9475), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459633] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1370), 1,
      sym__alpha_identifier,
    ACTIONS(1392), 1,
      sym__backquoted_id,
    ACTIONS(12305), 1,
      sym_operator_identifier,
    STATE(5569), 1,
      sym__soft_identifier,
    STATE(8482), 1,
      sym_identifier,
    STATE(9476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1380), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12303), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [459679] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459715] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10436), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [459751] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10440), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [459787] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4184), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9480), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10662), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [459827] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459863] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459899] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(8052), 1,
      sym_operator_identifier,
    STATE(4512), 1,
      sym__soft_identifier,
    STATE(7120), 1,
      sym_identifier,
    STATE(9483), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8048), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [459945] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9484), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10712), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [459981] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460017] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9486), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10504), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [460053] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460089] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9488), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460125] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9854), 1,
      sym__alpha_identifier,
    ACTIONS(9860), 1,
      sym__backquoted_id,
    ACTIONS(9862), 1,
      sym_operator_identifier,
    STATE(553), 1,
      sym_identifier,
    STATE(4043), 1,
      sym__soft_identifier,
    STATE(9489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9363), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [460175] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9490), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460211] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460247] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460283] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9493), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9092), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460319] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9494), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460355] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12307), 1,
      anon_sym_with,
    STATE(9495), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460393] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10617), 1,
      sym__alpha_identifier,
    ACTIONS(10621), 1,
      anon_sym_EQ,
    ACTIONS(10623), 1,
      sym__backquoted_id,
    ACTIONS(10625), 1,
      sym_operator_identifier,
    STATE(541), 1,
      sym_identifier,
    STATE(4039), 1,
      sym__soft_identifier,
    STATE(9496), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
    ACTIONS(10619), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [460445] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9497), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 6,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4132), 15,
      anon_sym__,
      anon_sym_given,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
  [460481] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9878), 1,
      sym_operator_identifier,
    STATE(1703), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9498), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8807), 6,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [460531] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12310), 1,
      anon_sym_with,
    STATE(9499), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460569] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9500), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7220), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [460605] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1190), 1,
      sym__alpha_identifier,
    ACTIONS(1212), 1,
      sym__backquoted_id,
    ACTIONS(12315), 1,
      sym_operator_identifier,
    STATE(5821), 1,
      sym__soft_identifier,
    STATE(8542), 1,
      sym_identifier,
    STATE(9501), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1200), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12313), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [460651] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460687] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460723] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4238), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9504), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460763] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9505), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [460799] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9918), 1,
      sym_operator_identifier,
    STATE(1712), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8807), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [460849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9507), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460885] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9508), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460921] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9509), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 21,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [460955] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9510), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460991] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9511), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461027] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461063] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4237), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461103] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1226), 1,
      sym__alpha_identifier,
    ACTIONS(1248), 1,
      sym__backquoted_id,
    ACTIONS(12319), 1,
      sym_operator_identifier,
    STATE(4411), 1,
      sym__soft_identifier,
    STATE(5249), 1,
      sym_identifier,
    STATE(9514), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1236), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12317), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [461149] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9515), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11561), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [461185] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9516), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 6,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6936), 15,
      anon_sym__,
      anon_sym_given,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
  [461221] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10268), 1,
      sym__alpha_identifier,
    ACTIONS(10274), 1,
      sym__backquoted_id,
    ACTIONS(10276), 1,
      sym_operator_identifier,
    STATE(543), 1,
      sym_identifier,
    STATE(4041), 1,
      sym__soft_identifier,
    STATE(9517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(10270), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [461271] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10268), 1,
      sym__alpha_identifier,
    ACTIONS(10274), 1,
      sym__backquoted_id,
    ACTIONS(10276), 1,
      sym_operator_identifier,
    ACTIONS(10629), 1,
      anon_sym_EQ,
    STATE(543), 1,
      sym_identifier,
    STATE(4041), 1,
      sym__soft_identifier,
    STATE(9518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(10270), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [461323] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9519), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461359] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9520), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [461395] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4230), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461435] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12321), 1,
      anon_sym_LPAREN,
    STATE(10167), 1,
      sym_arguments,
    STATE(9522), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 4,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8430), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461475] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9523), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461517] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [461553] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11617), 1,
      anon_sym_LPAREN,
    STATE(9527), 1,
      aux_sym_annotation_repeat1,
    STATE(10373), 1,
      sym_arguments,
    STATE(9525), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    ACTIONS(8426), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461595] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461631] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12324), 1,
      anon_sym_LPAREN,
    STATE(10373), 1,
      sym_arguments,
    ACTIONS(8432), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(9527), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8430), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461707] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9529), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10444), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [461743] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461779] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9531), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10448), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [461815] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10508), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [461851] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9533), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461889] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9534), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9535), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461961] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461997] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4242), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9537), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462037] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462073] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9539), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462109] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462145] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1846), 1,
      sym__alpha_identifier,
    ACTIONS(1868), 1,
      sym__backquoted_id,
    ACTIONS(12329), 1,
      sym_operator_identifier,
    STATE(4597), 1,
      sym__soft_identifier,
    STATE(6356), 1,
      sym_identifier,
    STATE(9541), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1856), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12327), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [462191] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 15,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [462227] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9543), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462263] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10512), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [462299] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9545), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9912), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462335] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9916), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462371] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462407] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(11004), 1,
      sym__alpha_identifier,
    ACTIONS(11010), 1,
      sym__backquoted_id,
    ACTIONS(11012), 1,
      sym_operator_identifier,
    STATE(544), 1,
      sym_identifier,
    STATE(4058), 1,
      sym__soft_identifier,
    STATE(9548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9367), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(11006), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [462457] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4211), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10662), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462497] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462533] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462569] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9552), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10452), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [462605] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462641] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9860), 1,
      sym_arguments,
    STATE(9554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462679] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462715] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9556), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [462751] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462787] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9558), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [462823] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11588), 1,
      anon_sym_AT,
    STATE(9606), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10327), 1,
      sym_annotation,
    STATE(9559), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8957), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462865] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9560), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [462901] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9561), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10456), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [462937] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12331), 1,
      anon_sym_COLON,
    ACTIONS(12334), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(9562), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462977] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9936), 1,
      sym_operator_identifier,
    STATE(1745), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9563), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8807), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [463027] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4134), 1,
      sym__backquoted_id,
    STATE(9564), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(4132), 7,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(4130), 8,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463067] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6318), 1,
      sym__end_marker,
    STATE(9565), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463105] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9566), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [463141] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9567), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [463177] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463213] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [463249] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4201), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9570), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463289] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463325] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9572), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463361] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [463397] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463433] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463469] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10704), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [463505] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9577), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10708), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [463541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463577] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463613] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9947), 1,
      sym_operator_identifier,
    STATE(1789), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9580), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8807), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8805), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [463663] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463699] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463735] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9583), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10712), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [463771] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9584), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463807] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1004), 1,
      sym__alpha_identifier,
    ACTIONS(1026), 1,
      sym__backquoted_id,
    ACTIONS(12339), 1,
      sym_operator_identifier,
    STATE(4922), 1,
      sym__soft_identifier,
    STATE(6812), 1,
      sym_identifier,
    STATE(9585), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1014), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12337), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [463853] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463889] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9587), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9588), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [463961] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9589), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463997] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464039] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8412), 6,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464081] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9593), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [464153] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9594), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464189] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464225] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1804), 1,
      sym__alpha_identifier,
    ACTIONS(1826), 1,
      sym__backquoted_id,
    ACTIONS(12343), 1,
      sym_operator_identifier,
    STATE(6619), 1,
      sym__soft_identifier,
    STATE(9260), 1,
      sym_identifier,
    STATE(9596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1814), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12341), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [464271] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9443), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464309] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [464345] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464381] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464417] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10245), 1,
      sym__alpha_identifier,
    ACTIONS(10251), 1,
      sym__backquoted_id,
    ACTIONS(10253), 1,
      sym_operator_identifier,
    STATE(538), 1,
      sym_identifier,
    STATE(4045), 1,
      sym__soft_identifier,
    STATE(9601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10247), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [464467] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10245), 1,
      sym__alpha_identifier,
    ACTIONS(10251), 1,
      sym__backquoted_id,
    ACTIONS(10253), 1,
      sym_operator_identifier,
    ACTIONS(10357), 1,
      anon_sym_EQ,
    STATE(538), 1,
      sym_identifier,
    STATE(4045), 1,
      sym__soft_identifier,
    STATE(9602), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_case,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10247), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [464519] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9603), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464555] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464597] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464633] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12345), 1,
      anon_sym_AT,
    STATE(10327), 1,
      sym_annotation,
    STATE(9606), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8931), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464673] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10371), 1,
      sym_operator_identifier,
    STATE(1754), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9607), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8807), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [464725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464761] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9609), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464797] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1568), 1,
      sym__alpha_identifier,
    ACTIONS(1590), 1,
      sym__backquoted_id,
    ACTIONS(12350), 1,
      sym_operator_identifier,
    STATE(6091), 1,
      sym__soft_identifier,
    STATE(9302), 1,
      sym_identifier,
    STATE(9610), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1578), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12348), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [464843] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9611), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464879] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12352), 1,
      anon_sym_with,
    STATE(9612), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464917] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9613), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12357), 6,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(12355), 15,
      anon_sym__,
      anon_sym_given,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
  [464953] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9614), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464989] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9615), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465025] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9616), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465067] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(473), 1,
      sym__alpha_identifier,
    ACTIONS(537), 1,
      sym__backquoted_id,
    ACTIONS(8036), 1,
      sym_operator_identifier,
    STATE(5776), 1,
      sym__soft_identifier,
    STATE(9546), 1,
      sym_identifier,
    STATE(9617), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(659), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8034), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [465113] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9618), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8953), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465149] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9619), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [465185] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [465221] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9621), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10522), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [465257] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465293] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9623), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12361), 6,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(12359), 15,
      anon_sym__,
      anon_sym_given,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
  [465329] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9624), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465365] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12365), 6,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(12363), 15,
      anon_sym__,
      anon_sym_given,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
  [465401] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465437] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465473] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465509] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8481), 2,
      anon_sym_LPAREN,
      sym__backquoted_id,
    STATE(9629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9291), 19,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465545] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10379), 1,
      sym__alpha_identifier,
    ACTIONS(10383), 1,
      anon_sym_EQ,
    ACTIONS(10385), 1,
      sym__backquoted_id,
    ACTIONS(10387), 1,
      sym_operator_identifier,
    STATE(539), 1,
      sym_identifier,
    STATE(4048), 1,
      sym__soft_identifier,
    STATE(9630), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10381), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [465597] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9895), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [465633] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465669] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465705] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465741] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465777] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9636), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [465813] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9638), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [465885] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9639), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465921] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465957] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465993] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9642), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [466029] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(9643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_EQ,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8410), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466069] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9644), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466105] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466141] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9646), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466177] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466213] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9648), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466249] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466285] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466321] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [466357] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [466393] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10542), 1,
      sym_operator_identifier,
    STATE(1683), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8807), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [466445] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466481] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466517] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1406), 1,
      sym__alpha_identifier,
    ACTIONS(1428), 1,
      sym__backquoted_id,
    ACTIONS(12369), 1,
      sym_operator_identifier,
    STATE(4473), 1,
      sym__soft_identifier,
    STATE(5881), 1,
      sym_identifier,
    STATE(9656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1416), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12367), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [466563] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9657), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466599] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12373), 6,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(12371), 15,
      anon_sym__,
      anon_sym_given,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
  [466635] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9659), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466671] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12375), 1,
      anon_sym_with,
    STATE(9660), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466709] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(9661), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466749] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1112), 1,
      sym__alpha_identifier,
    ACTIONS(1134), 1,
      sym__backquoted_id,
    ACTIONS(12380), 1,
      sym_operator_identifier,
    STATE(5173), 1,
      sym__soft_identifier,
    STATE(8051), 1,
      sym_identifier,
    STATE(9662), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1122), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12378), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [466795] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9663), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [466831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466867] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466903] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9902), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [466939] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466975] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9805), 1,
      anon_sym_DOT,
    ACTIONS(12214), 1,
      anon_sym_COLON,
    STATE(9668), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467015] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9669), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467051] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1694), 1,
      sym__alpha_identifier,
    ACTIONS(1716), 1,
      sym__backquoted_id,
    ACTIONS(12384), 1,
      sym_operator_identifier,
    STATE(6117), 1,
      sym__soft_identifier,
    STATE(8794), 1,
      sym_identifier,
    STATE(9670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1704), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12382), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [467097] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467133] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(9672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 7,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467173] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10573), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [467209] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [467245] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9675), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467281] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467317] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467353] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9678), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10577), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [467389] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467425] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9680), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [467461] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9681), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467497] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9682), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467533] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10581), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [467569] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9684), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467605] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467641] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1638), 1,
      sym__alpha_identifier,
    ACTIONS(1660), 1,
      sym__backquoted_id,
    ACTIONS(12388), 1,
      sym_operator_identifier,
    STATE(4471), 1,
      sym__soft_identifier,
    STATE(5744), 1,
      sym_identifier,
    STATE(9686), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1648), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12386), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [467687] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467723] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467759] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9689), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467795] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9690), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9691), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9519), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467867] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467903] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9693), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467939] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9694), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467975] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11582), 1,
      anon_sym_AT,
    STATE(9720), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10164), 1,
      sym_annotation,
    STATE(9695), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8957), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468017] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9813), 1,
      sym__alpha_identifier,
    ACTIONS(9819), 1,
      sym__backquoted_id,
    ACTIONS(9821), 1,
      sym_operator_identifier,
    ACTIONS(10702), 1,
      anon_sym_EQ,
    STATE(530), 1,
      sym_identifier,
    STATE(3932), 1,
      sym__soft_identifier,
    STATE(9696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_case,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9815), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [468069] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468105] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468141] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9699), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468177] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9700), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [468213] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468249] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12390), 1,
      anon_sym_with,
    STATE(9702), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9416), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468287] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9703), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12395), 6,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(12393), 15,
      anon_sym__,
      anon_sym_given,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
  [468323] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9291), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468359] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468395] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468431] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(9707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468471] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10485), 1,
      sym_operator_identifier,
    STATE(1793), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9708), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8807), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [468523] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4193), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468563] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468599] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10231), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468637] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [468673] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9713), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [468709] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9714), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [468745] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468781] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10031), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [468817] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468853] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10035), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [468889] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10319), 1,
      anon_sym_AT,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9719), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10840), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10838), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [468935] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12397), 1,
      anon_sym_AT,
    STATE(10164), 1,
      sym_annotation,
    STATE(9720), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8931), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468975] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9721), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10041), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [469011] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [469047] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1278), 1,
      sym__alpha_identifier,
    ACTIONS(1300), 1,
      sym__backquoted_id,
    ACTIONS(12402), 1,
      sym_operator_identifier,
    STATE(5185), 1,
      sym__soft_identifier,
    STATE(7573), 1,
      sym_identifier,
    STATE(9723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12400), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [469093] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [469129] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [469165] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9726), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10048), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [469201] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9895), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9728), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10704), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [469273] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10708), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [469309] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10052), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [469345] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469381] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469416] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9733), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469451] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469486] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    ACTIONS(11763), 1,
      anon_sym_EQ_GT,
    STATE(9735), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469525] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469560] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10255), 1,
      sym__alpha_identifier,
    ACTIONS(10261), 1,
      sym__backquoted_id,
    ACTIONS(10263), 1,
      sym_operator_identifier,
    ACTIONS(10781), 1,
      anon_sym_EQ,
    STATE(534), 1,
      sym_identifier,
    STATE(4030), 1,
      sym__soft_identifier,
    STATE(9737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_case,
      anon_sym_match,
      anon_sym_finally,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [469611] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9738), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469646] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11190), 1,
      anon_sym_COMMA,
    ACTIONS(11192), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15555), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(9739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [469707] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469742] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    ACTIONS(12404), 1,
      anon_sym_EQ_GT,
    STATE(9741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469781] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9742), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469816] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469851] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469886] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10006), 1,
      sym__alpha_identifier,
    ACTIONS(10012), 1,
      sym__backquoted_id,
    ACTIONS(10014), 1,
      sym_operator_identifier,
    ACTIONS(10736), 1,
      anon_sym_EQ,
    STATE(532), 1,
      sym_identifier,
    STATE(4034), 1,
      sym__soft_identifier,
    ACTIONS(9363), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(9745), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 5,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(10008), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [469937] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469972] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9747), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [470007] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [470042] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10873), 1,
      sym_operator_identifier,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9749), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8807), 4,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [470093] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9386), 1,
      anon_sym_EQ_GT,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    STATE(9750), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470132] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10235), 1,
      sym__alpha_identifier,
    ACTIONS(10241), 1,
      sym__backquoted_id,
    ACTIONS(10243), 1,
      sym_operator_identifier,
    ACTIONS(10931), 1,
      anon_sym_EQ,
    STATE(533), 1,
      sym_identifier,
    STATE(4027), 1,
      sym__soft_identifier,
    STATE(9751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10237), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [470183] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10849), 1,
      sym_operator_identifier,
    STATE(1698), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8807), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [470234] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9753), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470269] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9754), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8412), 5,
      anon_sym_while,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470310] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9755), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470345] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10347), 1,
      anon_sym_EQ_GT,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    STATE(9756), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470384] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9757), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470419] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9758), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470454] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [470489] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470524] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9761), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470559] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470594] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11363), 1,
      anon_sym_COLON,
    ACTIONS(11365), 1,
      anon_sym_EQ,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15124), 1,
      aux_sym_val_declaration_repeat1,
    STATE(9763), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [470655] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470690] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9765), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470725] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10355), 1,
      anon_sym_EQ_GT,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    STATE(9766), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470764] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9767), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470799] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9768), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470834] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10751), 1,
      sym__alpha_identifier,
    ACTIONS(10757), 1,
      sym__backquoted_id,
    ACTIONS(10759), 1,
      sym_operator_identifier,
    STATE(558), 1,
      sym_identifier,
    STATE(4050), 1,
      sym__soft_identifier,
    STATE(9769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
    ACTIONS(10753), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [470883] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10751), 1,
      sym__alpha_identifier,
    ACTIONS(10757), 1,
      sym__backquoted_id,
    ACTIONS(10759), 1,
      sym_operator_identifier,
    ACTIONS(10881), 1,
      anon_sym_EQ,
    STATE(558), 1,
      sym_identifier,
    STATE(4050), 1,
      sym__soft_identifier,
    STATE(9770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_case,
      anon_sym_match,
      anon_sym_finally,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10753), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [470934] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9771), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470969] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10738), 1,
      sym__alpha_identifier,
    ACTIONS(10742), 1,
      anon_sym_EQ,
    ACTIONS(10744), 1,
      sym__backquoted_id,
    ACTIONS(10746), 1,
      sym_operator_identifier,
    STATE(552), 1,
      sym_identifier,
    STATE(4049), 1,
      sym__soft_identifier,
    STATE(9772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10740), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [471020] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9773), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [471055] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471090] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471125] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    ACTIONS(11096), 1,
      anon_sym_EQ_GT,
    STATE(9776), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471164] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9777), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471199] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471234] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    ACTIONS(11673), 1,
      anon_sym_EQ_GT,
    STATE(9779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471273] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471308] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [471343] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471378] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471413] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471448] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471483] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(9786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471522] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8996), 1,
      anon_sym_EQ_GT,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    STATE(9787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471561] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9788), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [471596] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10738), 1,
      sym__alpha_identifier,
    ACTIONS(10744), 1,
      sym__backquoted_id,
    ACTIONS(10746), 1,
      sym_operator_identifier,
    STATE(552), 1,
      sym_identifier,
    STATE(4049), 1,
      sym__soft_identifier,
    STATE(9789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
    ACTIONS(10740), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [471645] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471680] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471721] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9449), 1,
      anon_sym_EQ_GT,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    STATE(9792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471760] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [471795] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9854), 1,
      sym__alpha_identifier,
    ACTIONS(9860), 1,
      sym__backquoted_id,
    ACTIONS(9862), 1,
      sym_operator_identifier,
    ACTIONS(10800), 1,
      anon_sym_EQ,
    STATE(553), 1,
      sym_identifier,
    STATE(4043), 1,
      sym__soft_identifier,
    STATE(9794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [471846] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9795), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471881] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9459), 1,
      anon_sym_EQ_GT,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    STATE(9796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471920] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471955] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9798), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471990] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11350), 1,
      anon_sym_COLON,
    ACTIONS(11352), 1,
      anon_sym_EQ,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(14988), 1,
      aux_sym_val_declaration_repeat1,
    STATE(9799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [472051] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472086] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4243), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472125] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [472160] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9803), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472195] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10751), 1,
      sym__alpha_identifier,
    ACTIONS(10755), 1,
      anon_sym_EQ,
    ACTIONS(10757), 1,
      sym__backquoted_id,
    ACTIONS(10759), 1,
      sym_operator_identifier,
    STATE(558), 1,
      sym_identifier,
    STATE(4050), 1,
      sym__soft_identifier,
    STATE(9804), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10753), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [472246] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    ACTIONS(10779), 1,
      anon_sym_EQ_GT,
    STATE(9805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472285] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9806), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472320] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9807), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [472355] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11568), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [472392] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    ACTIONS(10792), 1,
      anon_sym_EQ_GT,
    STATE(9809), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472431] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9810), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472466] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472501] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11158), 1,
      anon_sym_AT,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10927), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10925), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472546] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9980), 1,
      anon_sym_EQ_GT,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    STATE(9813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472585] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9814), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [472620] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9815), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472655] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9816), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472690] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9817), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 3,
      anon_sym_case,
      anon_sym_if,
      anon_sym_EQ,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472731] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9818), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472766] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10016), 1,
      anon_sym_EQ_GT,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    STATE(9819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472805] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472840] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10494), 1,
      sym_operator_identifier,
    STATE(1743), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8807), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [472889] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9822), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472924] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12408), 1,
      anon_sym_with,
    STATE(9823), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9416), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472961] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    ACTIONS(10821), 1,
      anon_sym_EQ_GT,
    STATE(9824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473000] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473035] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11436), 1,
      anon_sym_COLON,
    ACTIONS(11438), 1,
      anon_sym_DOT,
    ACTIONS(11440), 1,
      anon_sym_STAR,
    ACTIONS(11442), 1,
      anon_sym_EQ_GT,
    ACTIONS(11444), 1,
      anon_sym_if,
    ACTIONS(11446), 1,
      anon_sym_AT,
    ACTIONS(11448), 1,
      anon_sym_PIPE,
    ACTIONS(11450), 1,
      sym_operator_identifier,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(17622), 1,
      sym_guard,
    STATE(9826), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [473096] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9827), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473131] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(10877), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(10879), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    STATE(9828), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [473188] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473223] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473258] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473293] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(11004), 1,
      sym__alpha_identifier,
    ACTIONS(11008), 1,
      anon_sym_EQ,
    ACTIONS(11010), 1,
      sym__backquoted_id,
    ACTIONS(11012), 1,
      sym_operator_identifier,
    STATE(544), 1,
      sym_identifier,
    STATE(4058), 1,
      sym__soft_identifier,
    STATE(9832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
    ACTIONS(9363), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(11006), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [473344] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9833), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473379] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    ACTIONS(11404), 1,
      anon_sym_EQ_GT,
    STATE(9834), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473418] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473453] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 6,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [473488] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9837), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473523] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473558] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9839), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473593] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9262), 1,
      anon_sym_EQ_GT,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    STATE(9840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473632] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11502), 1,
      anon_sym_COLON,
    ACTIONS(11504), 1,
      anon_sym_EQ,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15333), 1,
      aux_sym_val_declaration_repeat1,
    STATE(9841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [473693] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9842), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473728] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [473763] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473798] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10037), 1,
      anon_sym_EQ_GT,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    STATE(9845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473837] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9846), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 15,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [473872] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11506), 1,
      anon_sym_COLON,
    ACTIONS(11508), 1,
      anon_sym_EQ,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15335), 1,
      aux_sym_val_declaration_repeat1,
    STATE(9847), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [473933] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473968] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9849), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [474003] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [474038] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474073] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474108] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9853), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474143] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    ACTIONS(10593), 1,
      anon_sym_EQ_GT,
    STATE(9854), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474182] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9855), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474217] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9856), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474252] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9857), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474287] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9858), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474322] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8412), 5,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_EQ,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474363] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10522), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474398] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474433] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 15,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [474468] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10006), 1,
      sym__alpha_identifier,
    ACTIONS(10012), 1,
      sym__backquoted_id,
    ACTIONS(10014), 1,
      sym_operator_identifier,
    ACTIONS(10817), 1,
      anon_sym_EQ,
    STATE(532), 1,
      sym_identifier,
    STATE(4034), 1,
      sym__soft_identifier,
    ACTIONS(9363), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(9863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10008), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [474519] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9864), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [474554] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474595] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9866), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [474630] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474665] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 15,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [474700] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9869), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [474735] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [474770] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9871), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 20,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [474803] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10738), 1,
      sym__alpha_identifier,
    ACTIONS(10744), 1,
      sym__backquoted_id,
    ACTIONS(10746), 1,
      sym_operator_identifier,
    ACTIONS(10845), 1,
      anon_sym_EQ,
    STATE(552), 1,
      sym_identifier,
    STATE(4049), 1,
      sym__soft_identifier,
    STATE(9872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10740), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [474854] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11206), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9873), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474891] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474926] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [474961] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474996] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11436), 1,
      anon_sym_COLON,
    ACTIONS(11438), 1,
      anon_sym_DOT,
    ACTIONS(11440), 1,
      anon_sym_STAR,
    ACTIONS(11444), 1,
      anon_sym_if,
    ACTIONS(11446), 1,
      anon_sym_AT,
    ACTIONS(11448), 1,
      anon_sym_PIPE,
    ACTIONS(11450), 1,
      sym_operator_identifier,
    ACTIONS(11512), 1,
      anon_sym_EQ_GT,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(16350), 1,
      sym_guard,
    STATE(9877), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [475057] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 1,
      anon_sym_EQ_GT,
    ACTIONS(8414), 1,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(9622), 1,
      anon_sym_COLON,
    ACTIONS(9624), 1,
      anon_sym_LBRACE,
    ACTIONS(9626), 1,
      anon_sym_with,
    STATE(4996), 1,
      aux_sym_compound_type_repeat1,
    STATE(9198), 1,
      sym_template_body,
    STATE(9203), 1,
      sym__refinement,
    STATE(9246), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9878), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475110] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10915), 1,
      sym__alpha_identifier,
    ACTIONS(10919), 1,
      anon_sym_EQ,
    ACTIONS(10921), 1,
      sym__backquoted_id,
    ACTIONS(10923), 1,
      sym_operator_identifier,
    STATE(556), 1,
      sym_identifier,
    STATE(4055), 1,
      sym__soft_identifier,
    STATE(9879), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10917), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [475161] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(11047), 1,
      sym__alpha_identifier,
    ACTIONS(11053), 1,
      anon_sym_EQ,
    ACTIONS(11055), 1,
      sym__backquoted_id,
    ACTIONS(11057), 1,
      sym_operator_identifier,
    STATE(545), 1,
      sym_identifier,
    STATE(4059), 1,
      sym__soft_identifier,
    STATE(9880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11051), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [475212] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9881), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [475247] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475282] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9883), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475317] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9884), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475352] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9521), 1,
      sym__backquoted_id,
    STATE(9885), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 19,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475387] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475422] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9887), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475457] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475492] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9889), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_STAR,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475533] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [475568] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9891), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475603] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9892), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475638] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [475673] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11854), 1,
      anon_sym_AT,
    STATE(10016), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10550), 1,
      sym_annotation,
    STATE(9894), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    ACTIONS(8957), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475714] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11289), 1,
      anon_sym_COLON,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(11292), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(9895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475755] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9896), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475790] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9897), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [475825] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9898), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [475860] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 6,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [475895] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9900), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475930] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475965] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11215), 1,
      anon_sym_COLON,
    ACTIONS(11217), 1,
      anon_sym_EQ,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15333), 1,
      aux_sym_val_declaration_repeat1,
    STATE(9902), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [476026] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4228), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476065] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11219), 1,
      anon_sym_COLON,
    ACTIONS(11221), 1,
      anon_sym_EQ,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15335), 1,
      aux_sym_val_declaration_repeat1,
    STATE(9904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [476126] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9905), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476161] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476196] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12411), 1,
      anon_sym_COLON,
    ACTIONS(8170), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(12414), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(9907), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9908), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476272] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9909), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476307] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9910), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476342] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9911), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476377] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(9912), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476416] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476451] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9914), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [476486] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476521] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10371), 1,
      sym_operator_identifier,
    STATE(1754), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8807), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [476570] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [476605] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476640] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476675] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(11083), 1,
      sym_operator_identifier,
    STATE(1747), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8807), 3,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [476726] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9921), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476761] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9922), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476796] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476866] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476901] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476936] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476971] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9928), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477006] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [477041] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477076] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11516), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15539), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(9931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [477137] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477172] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [477207] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9934), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477242] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9935), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9088), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477277] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9519), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477312] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9937), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477347] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9938), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477382] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4197), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477421] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9940), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [477456] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9941), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [477491] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9942), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477526] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477561] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477596] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477631] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9946), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477666] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477701] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477736] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9949), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477771] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477806] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477847] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [477882] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477917] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11150), 1,
      anon_sym_COLON,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11160), 1,
      anon_sym_EQ,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15519), 1,
      aux_sym_val_declaration_repeat1,
    STATE(9954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [477978] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478013] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478048] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9957), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478083] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9958), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478118] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [478153] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9960), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [478188] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478223] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11158), 1,
      anon_sym_AT,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9962), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10840), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10838), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478268] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11520), 1,
      anon_sym_COMMA,
    ACTIONS(11522), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15388), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(9963), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [478329] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10379), 1,
      sym__alpha_identifier,
    ACTIONS(10385), 1,
      sym__backquoted_id,
    ACTIONS(10387), 1,
      sym_operator_identifier,
    STATE(539), 1,
      sym_identifier,
    STATE(4048), 1,
      sym__soft_identifier,
    STATE(9964), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9367), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10381), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [478378] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9965), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478413] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9966), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [478448] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9967), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478483] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10323), 1,
      anon_sym_RPAREN,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15473), 1,
      aux_sym_case_class_pattern_repeat1,
    ACTIONS(10321), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(9968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [478542] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(9969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478581] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9970), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478616] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9971), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478651] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(11385), 1,
      sym__alpha_identifier,
    ACTIONS(11391), 1,
      sym__backquoted_id,
    ACTIONS(11393), 1,
      sym_operator_identifier,
    STATE(563), 1,
      sym_identifier,
    STATE(4068), 1,
      sym__soft_identifier,
    STATE(9972), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(9367), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(11387), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [478700] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [478735] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478770] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(9975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478811] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478846] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11427), 1,
      anon_sym_COMMA,
    ACTIONS(11429), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(14808), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(9977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [478907] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9978), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478942] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9979), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478983] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9980), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479018] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479053] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9982), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 4,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8953), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479088] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10424), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479123] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4208), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479162] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4187), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(9985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479201] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9086), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479236] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [479271] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9988), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 15,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [479306] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9854), 1,
      sym__alpha_identifier,
    ACTIONS(9860), 1,
      sym__backquoted_id,
    ACTIONS(9862), 1,
      sym_operator_identifier,
    ACTIONS(10875), 1,
      anon_sym_EQ,
    STATE(553), 1,
      sym_identifier,
    STATE(4043), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_if,
      anon_sym_match,
    STATE(9989), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [479357] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11166), 1,
      anon_sym_COLON,
    ACTIONS(11168), 1,
      anon_sym_EQ,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15521), 1,
      aux_sym_val_declaration_repeat1,
    STATE(9990), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [479418] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(9991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479457] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9992), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479492] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9993), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479527] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    ACTIONS(11482), 1,
      anon_sym_EQ_GT,
    STATE(9994), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479566] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479601] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9996), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [479636] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9068), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479706] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479741] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10000), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479776] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479811] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10002), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479846] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479881] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479916] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479951] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10006), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 4,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9092), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479986] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480021] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10008), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480056] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480091] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [480126] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10542), 1,
      sym_operator_identifier,
    STATE(1683), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(10011), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8807), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [480175] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10012), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [480210] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10013), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480245] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10014), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480280] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4191), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10015), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480319] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12417), 1,
      anon_sym_AT,
    STATE(10550), 1,
      sym_annotation,
    ACTIONS(8933), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(10016), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8931), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480358] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10017), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480393] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10018), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [480428] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11279), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15361), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10019), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [480489] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11236), 1,
      anon_sym_COLON,
    ACTIONS(11238), 1,
      anon_sym_EQ,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15519), 1,
      aux_sym_val_declaration_repeat1,
    STATE(10020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [480550] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10021), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480585] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480620] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10023), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480655] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11240), 1,
      anon_sym_COLON,
    ACTIONS(11242), 1,
      anon_sym_EQ,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15521), 1,
      aux_sym_val_declaration_repeat1,
    STATE(10024), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [480716] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10025), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480751] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480786] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480821] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [480856] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480891] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [480926] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [480961] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10032), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480996] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481031] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [481066] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481101] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10036), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481136] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10037), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481171] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481206] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10039), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481245] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [481280] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481315] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10042), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481350] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481385] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12420), 1,
      anon_sym_COLON,
    ACTIONS(12423), 1,
      anon_sym_LBRACE,
    STATE(10811), 1,
      sym_template_body,
    STATE(10044), 2,
      sym_comment,
      sym_block_comment,
    STATE(10876), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(9230), 4,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9222), 11,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481428] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [481463] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9098), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481498] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(10047), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481535] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [481570] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [481605] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481640] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481675] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481710] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9283), 1,
      anon_sym_EQ_GT,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    STATE(10053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481749] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [481784] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [481819] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10056), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481860] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 15,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [481895] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6911), 1,
      sym__end_marker,
    STATE(10058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10127), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481932] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [481967] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482002] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482037] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482072] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482107] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482142] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4239), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10065), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482181] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12426), 1,
      anon_sym_DOT,
    STATE(10066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482218] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [482253] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482288] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482323] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [482358] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [482393] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9090), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482428] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10073), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8412), 5,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482469] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10323), 1,
      anon_sym_RPAREN,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15473), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10074), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [482530] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(10075), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482571] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482606] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482641] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10078), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [482676] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9291), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482711] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482746] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10081), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [482781] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482816] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10083), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [482851] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482886] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [482921] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482956] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10087), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482991] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    ACTIONS(10591), 1,
      anon_sym_EQ_GT,
    STATE(10088), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483030] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10089), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [483065] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483100] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10091), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483135] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10092), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483170] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10093), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483211] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10323), 1,
      anon_sym_RPAREN,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15473), 1,
      aux_sym_case_class_pattern_repeat1,
    ACTIONS(10321), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [483270] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10485), 1,
      sym_operator_identifier,
    STATE(1793), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(10095), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8807), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [483319] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483354] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10828), 1,
      sym__alpha_identifier,
    ACTIONS(10832), 1,
      anon_sym_EQ,
    ACTIONS(10834), 1,
      sym__backquoted_id,
    ACTIONS(10836), 1,
      sym_operator_identifier,
    STATE(548), 1,
      sym_identifier,
    STATE(4051), 1,
      sym__soft_identifier,
    STATE(10097), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(9367), 4,
      anon_sym_match,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10830), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [483405] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(10098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8835), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [483446] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10099), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483481] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483516] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    ACTIONS(11820), 1,
      anon_sym_EQ_GT,
    STATE(10101), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483555] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [483590] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10103), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483625] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10104), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483660] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(8412), 5,
      anon_sym_COLON,
      anon_sym_while,
      anon_sym_EQ,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483699] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10106), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9733), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483734] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [483769] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483810] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10109), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483845] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4198), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483884] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483960] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    ACTIONS(11330), 1,
      anon_sym_EQ_GT,
    STATE(10113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8422), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483999] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10114), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484034] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484069] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 6,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484108] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484143] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10118), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484178] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484213] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484248] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10121), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484283] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10122), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [484318] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484353] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10124), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484388] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484423] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12430), 1,
      anon_sym_LPAREN,
    STATE(10673), 1,
      sym__using_parameters_clause,
    STATE(10941), 1,
      sym_parameters,
    STATE(10126), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_extension_definition_repeat1,
    ACTIONS(12428), 16,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [484462] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4204), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12435), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(10688), 1,
      sym_colon_argument,
    STATE(9478), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10127), 2,
      sym_comment,
      sym_block_comment,
    STATE(16390), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [484514] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484548] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10129), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10927), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10925), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [484588] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12437), 1,
      anon_sym_implicit,
    ACTIONS(12439), 1,
      anon_sym_using,
    ACTIONS(12441), 1,
      anon_sym_RPAREN,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15508), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10130), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [484648] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4198), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12445), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(10616), 1,
      sym_colon_argument,
    STATE(8817), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10131), 2,
      sym_comment,
      sym_block_comment,
    STATE(17692), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [484700] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10132), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484734] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484768] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12447), 1,
      anon_sym_with,
    STATE(10134), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9416), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484804] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12404), 1,
      anon_sym_EQ_GT,
    STATE(10135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484840] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10355), 1,
      anon_sym_EQ_GT,
    STATE(10136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484876] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9386), 1,
      anon_sym_EQ_GT,
    STATE(10137), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484912] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11865), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [484946] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484980] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8406), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [485014] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10573), 15,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [485048] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10512), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485082] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11675), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10143), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [485138] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10577), 15,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [485172] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10581), 15,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [485206] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9459), 1,
      anon_sym_EQ_GT,
    STATE(10146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485242] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11820), 1,
      anon_sym_EQ_GT,
    STATE(10147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485278] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10148), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10508), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485312] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10149), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [485346] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10593), 1,
      anon_sym_EQ_GT,
    STATE(10150), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485382] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485416] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485450] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11664), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [485506] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485540] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4244), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12450), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(10487), 1,
      sym_colon_argument,
    STATE(9189), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10155), 2,
      sym_comment,
      sym_block_comment,
    STATE(17320), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [485592] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10500), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485626] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485660] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10840), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10838), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [485700] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8410), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10159), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 5,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485740] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4208), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12452), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(10471), 1,
      sym_colon_argument,
    STATE(8865), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10160), 2,
      sym_comment,
      sym_block_comment,
    STATE(17745), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [485792] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4496), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12454), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(11109), 1,
      sym_colon_argument,
    STATE(10120), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10161), 2,
      sym_comment,
      sym_block_comment,
    STATE(17038), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [485844] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485878] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 4,
      anon_sym_DOT,
      anon_sym_LPAREN,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(4132), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [485912] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9519), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485946] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485980] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10166), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486014] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9291), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486048] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4132), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486082] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10169), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486116] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486150] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10171), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486184] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10323), 1,
      anon_sym_RPAREN,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15473), 1,
      aux_sym_case_class_pattern_repeat1,
    ACTIONS(10321), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [486240] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486280] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(11385), 1,
      sym__alpha_identifier,
    ACTIONS(11389), 1,
      anon_sym_EQ,
    ACTIONS(11391), 1,
      sym__backquoted_id,
    ACTIONS(11393), 1,
      sym_operator_identifier,
    STATE(563), 1,
      sym_identifier,
    STATE(4068), 1,
      sym__soft_identifier,
    STATE(10174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(9367), 3,
      anon_sym_match,
      anon_sym_then,
      anon_sym_finally,
    ACTIONS(11387), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [486330] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10175), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486364] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486398] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486432] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486466] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(11306), 1,
      sym_operator_identifier,
    STATE(1760), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(8807), 2,
      anon_sym_match,
      anon_sym_finally,
    STATE(10179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [486516] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8078), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486550] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10573), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [486584] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10182), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10041), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [486618] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4202), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10183), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10662), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486656] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486690] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [486724] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10186), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10577), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [486758] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486792] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486826] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4282), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12456), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(10099), 1,
      sym_colon_argument,
    STATE(7504), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10189), 2,
      sym_comment,
      sym_block_comment,
    STATE(17853), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [486878] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10190), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10581), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [486912] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4188), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486950] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12460), 1,
      anon_sym_LBRACK,
    ACTIONS(12462), 1,
      anon_sym_AT,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12468), 1,
      sym__automatic_semicolon,
    STATE(10837), 1,
      sym_type_parameters,
    STATE(11213), 1,
      sym_annotation,
    STATE(12210), 1,
      sym_access_modifier,
    STATE(12212), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    ACTIONS(12464), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(10192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12458), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [487002] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487036] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487070] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10779), 1,
      anon_sym_EQ_GT,
    STATE(10195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487106] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487140] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [487174] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10198), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10048), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [487208] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10199), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10448), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487242] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4568), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12471), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(10185), 1,
      sym_colon_argument,
    STATE(8588), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10200), 2,
      sym_comment,
      sym_block_comment,
    STATE(17186), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [487294] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [487328] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 3,
      anon_sym_STAR,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487368] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487402] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [487436] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487470] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11657), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10206), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487506] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10207), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487540] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4760), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12473), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(11007), 1,
      sym_colon_argument,
    STATE(9999), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10208), 2,
      sym_comment,
      sym_block_comment,
    STATE(17386), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [487592] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487626] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11482), 1,
      anon_sym_EQ_GT,
    STATE(10210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487662] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10211), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 4,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487696] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2511), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487730] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10712), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [487764] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(10214), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487804] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10215), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487838] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10216), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487872] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10617), 1,
      sym__alpha_identifier,
    ACTIONS(10623), 1,
      sym__backquoted_id,
    ACTIONS(10625), 1,
      sym_operator_identifier,
    ACTIONS(11208), 1,
      anon_sym_EQ,
    STATE(541), 1,
      sym_identifier,
    STATE(4039), 1,
      sym__soft_identifier,
    ACTIONS(9363), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(10217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 4,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(10619), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [487922] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4340), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12475), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(10578), 1,
      sym_colon_argument,
    STATE(8922), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10218), 2,
      sym_comment,
      sym_block_comment,
    STATE(16165), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [487974] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10792), 1,
      anon_sym_EQ_GT,
    STATE(10219), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488010] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10220), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10052), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [488044] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10221), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10712), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [488078] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10840), 1,
      sym__backquoted_id,
    ACTIONS(11438), 1,
      anon_sym_DOT,
    ACTIONS(11446), 1,
      anon_sym_AT,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10838), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488122] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10223), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488156] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4217), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488194] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10225), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 3,
      anon_sym_STAR,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488234] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10226), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10840), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10838), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [488274] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10227), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 4,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488308] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488342] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488376] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10915), 1,
      sym__alpha_identifier,
    ACTIONS(10921), 1,
      sym__backquoted_id,
    ACTIONS(10923), 1,
      sym_operator_identifier,
    STATE(556), 1,
      sym_identifier,
    STATE(4055), 1,
      sym__soft_identifier,
    STATE(10230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10917), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [488424] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10231), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488458] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(11047), 1,
      sym__alpha_identifier,
    ACTIONS(11055), 1,
      sym__backquoted_id,
    ACTIONS(11057), 1,
      sym_operator_identifier,
    STATE(545), 1,
      sym_identifier,
    STATE(4059), 1,
      sym__soft_identifier,
    STATE(10232), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11051), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [488506] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11096), 1,
      anon_sym_EQ_GT,
    STATE(10233), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488542] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10234), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8412), 6,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488580] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488614] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 4,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488648] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10237), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488682] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10238), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488716] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10239), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488750] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488784] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488818] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10242), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [488852] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4372), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12477), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(10731), 1,
      sym_colon_argument,
    STATE(9376), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10243), 2,
      sym_comment,
      sym_block_comment,
    STATE(16195), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [488904] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10432), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488938] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(10321), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [488994] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10246), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 3,
      anon_sym_case,
      anon_sym_if,
      anon_sym_finally,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489034] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10873), 1,
      sym_operator_identifier,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(10247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8807), 4,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [489082] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10248), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489116] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4766), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12479), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(12149), 1,
      sym_colon_argument,
    STATE(10249), 2,
      sym_comment,
      sym_block_comment,
    STATE(10822), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(17453), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [489168] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10250), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489202] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10251), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489236] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10252), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489270] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(10877), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(10253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10879), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [489322] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10254), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10416), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489356] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10016), 1,
      anon_sym_EQ_GT,
    STATE(10255), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489392] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10256), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10402), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489426] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10257), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489460] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 4,
      anon_sym_DOT,
      anon_sym_LPAREN,
      sym__backquoted_id,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(6936), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [489494] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489528] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10260), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10704), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489562] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11436), 1,
      anon_sym_COLON,
    ACTIONS(11438), 1,
      anon_sym_DOT,
    ACTIONS(11440), 1,
      anon_sym_STAR,
    ACTIONS(11446), 1,
      anon_sym_AT,
    ACTIONS(11450), 1,
      sym_operator_identifier,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10261), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10879), 3,
      anon_sym_EQ_GT,
      anon_sym_if,
      anon_sym_PIPE,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [489616] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10262), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [489650] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10263), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489684] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10264), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489718] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10265), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489756] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10266), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10708), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489790] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4508), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12481), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(11141), 1,
      sym_colon_argument,
    STATE(10267), 2,
      sym_comment,
      sym_block_comment,
    STATE(10378), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16804), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [489842] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489876] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489910] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11673), 1,
      anon_sym_EQ_GT,
    STATE(10270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489946] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10271), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489980] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490014] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(9367), 1,
      anon_sym_match,
    ACTIONS(11196), 1,
      sym__alpha_identifier,
    ACTIONS(11202), 1,
      sym__backquoted_id,
    ACTIONS(11204), 1,
      sym_operator_identifier,
    STATE(600), 1,
      sym_identifier,
    STATE(4071), 1,
      sym__soft_identifier,
    ACTIONS(8803), 2,
      anon_sym_COLON,
      anon_sym_if,
    STATE(10273), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9856), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(11198), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [490066] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4186), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490104] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9980), 1,
      anon_sym_EQ_GT,
    STATE(10275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490140] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4430), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12483), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9018), 1,
      sym_colon_argument,
    STATE(6212), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10276), 2,
      sym_comment,
      sym_block_comment,
    STATE(16225), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [490192] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490226] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8412), 4,
      anon_sym_while,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490266] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10279), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(6936), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490300] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10280), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [490334] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(10877), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(10281), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10879), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [490386] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11671), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10282), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [490442] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4203), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10283), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490480] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4308), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12485), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9313), 1,
      sym_colon_argument,
    STATE(6617), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10284), 2,
      sym_comment,
      sym_block_comment,
    STATE(16719), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [490532] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9733), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490566] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10347), 1,
      anon_sym_EQ_GT,
    STATE(10286), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490602] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490640] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10288), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 3,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490680] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11561), 15,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [490714] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10290), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10406), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490748] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11755), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(10291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [490804] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10821), 1,
      anon_sym_EQ_GT,
    STATE(10292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490840] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490874] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4252), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12487), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(8420), 1,
      sym_colon_argument,
    STATE(5692), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10294), 2,
      sym_comment,
      sym_block_comment,
    STATE(17513), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [490926] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10295), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [490960] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12489), 1,
      anon_sym_with,
    STATE(10296), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9416), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490996] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10297), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491030] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    ACTIONS(12492), 1,
      anon_sym_implicit,
    ACTIONS(12494), 1,
      anon_sym_using,
    ACTIONS(12496), 1,
      anon_sym_RPAREN,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15317), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [491090] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10299), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491124] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10300), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [491158] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491192] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(11284), 1,
      sym_operator_identifier,
    STATE(1727), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(8807), 2,
      anon_sym_if,
      anon_sym_match,
    STATE(10302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [491242] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12498), 1,
      anon_sym_RBRACE,
    ACTIONS(12502), 1,
      anon_sym_given,
    ACTIONS(12504), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(14713), 1,
      sym_identifier,
    ACTIONS(12500), 2,
      anon_sym_STAR,
      anon_sym__,
    STATE(10303), 2,
      sym_comment,
      sym_block_comment,
    STATE(16114), 4,
      sym_namespace_wildcard,
      sym__namespace_given_by_type,
      sym_arrow_renamed_identifier,
      sym_as_renamed_identifier,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [491292] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4462), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12506), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9987), 1,
      sym_colon_argument,
    STATE(7681), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10304), 2,
      sym_comment,
      sym_block_comment,
    STATE(16255), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [491344] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10305), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491382] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10412), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491416] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(10617), 1,
      sym__alpha_identifier,
    ACTIONS(10623), 1,
      sym__backquoted_id,
    ACTIONS(10625), 1,
      sym_operator_identifier,
    ACTIONS(11572), 1,
      anon_sym_EQ,
    STATE(541), 1,
      sym_identifier,
    STATE(4039), 1,
      sym__soft_identifier,
    ACTIONS(9363), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(10307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(10619), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [491466] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [491500] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491534] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10310), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [491568] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10311), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [491602] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10312), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [491636] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10313), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491670] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10849), 1,
      sym_operator_identifier,
    STATE(1698), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(10314), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8807), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [491718] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9283), 1,
      anon_sym_EQ_GT,
    STATE(10315), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491754] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491788] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4692), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12508), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(10241), 1,
      sym_colon_argument,
    STATE(8345), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10317), 2,
      sym_comment,
      sym_block_comment,
    STATE(17255), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [491840] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4166), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12510), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(10683), 1,
      sym_colon_argument,
    STATE(9528), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10318), 2,
      sym_comment,
      sym_block_comment,
    STATE(16921), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [491892] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8406), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491926] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10320), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [491960] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8996), 1,
      anon_sym_EQ_GT,
    STATE(10321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491996] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [492030] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4630), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12512), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(10432), 1,
      sym_colon_argument,
    STATE(8535), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10323), 2,
      sym_comment,
      sym_block_comment,
    STATE(16282), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [492082] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10927), 1,
      sym__backquoted_id,
    ACTIONS(11438), 1,
      anon_sym_DOT,
    ACTIONS(11446), 1,
      anon_sym_AT,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10324), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10925), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492126] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10325), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [492160] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10326), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492194] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10327), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9519), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492228] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10328), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492262] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10329), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10031), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492296] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10330), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492330] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12502), 1,
      anon_sym_given,
    ACTIONS(12504), 1,
      sym_operator_identifier,
    ACTIONS(12514), 1,
      anon_sym_RBRACE,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(14713), 1,
      sym_identifier,
    ACTIONS(12500), 2,
      anon_sym_STAR,
      anon_sym__,
    STATE(10331), 2,
      sym_comment,
      sym_block_comment,
    STATE(16114), 4,
      sym_namespace_wildcard,
      sym__namespace_given_by_type,
      sym_arrow_renamed_identifier,
      sym_as_renamed_identifier,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [492380] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10420), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492414] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10333), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10035), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492448] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11404), 1,
      anon_sym_EQ_GT,
    STATE(10334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492484] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10335), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10573), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492518] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4532), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12516), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9472), 1,
      sym_colon_argument,
    STATE(6723), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10336), 2,
      sym_comment,
      sym_block_comment,
    STATE(17109), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [492570] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10577), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492604] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10338), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10581), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492638] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10339), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10041), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492672] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10048), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492706] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492740] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(11083), 1,
      sym_operator_identifier,
    STATE(1747), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(10342), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8807), 3,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [492788] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10343), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8983), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492822] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10344), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492856] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10345), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10052), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492890] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10444), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492924] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4730), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12518), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9505), 1,
      sym_colon_argument,
    STATE(6895), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10347), 2,
      sym_comment,
      sym_block_comment,
    STATE(17573), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [492976] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493010] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10349), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493044] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10350), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493078] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(11559), 1,
      sym_operator_identifier,
    STATE(1702), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(8807), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(10351), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [493128] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493162] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(4956), 1,
      anon_sym_implicit,
    ACTIONS(4962), 1,
      anon_sym_using,
    ACTIONS(4964), 1,
      anon_sym_RPAREN,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(14801), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10353), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [493222] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10354), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493256] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [493290] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10356), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 3,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493330] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10357), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493364] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10031), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [493398] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493432] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9455), 1,
      anon_sym_LPAREN,
    ACTIONS(12520), 1,
      anon_sym_LBRACK,
    ACTIONS(12522), 1,
      anon_sym_POUND,
    STATE(10694), 1,
      aux_sym_annotation_repeat1,
    STATE(11107), 1,
      sym_type_arguments,
    STATE(11228), 1,
      sym_arguments,
    STATE(10360), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [493476] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10361), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493510] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10362), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493544] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493578] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9854), 1,
      sym__alpha_identifier,
    ACTIONS(9860), 1,
      sym__backquoted_id,
    ACTIONS(11538), 1,
      anon_sym_EQ,
    ACTIONS(11540), 1,
      sym_operator_identifier,
    STATE(575), 1,
      sym_identifier,
    STATE(4043), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(10364), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [493628] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10365), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493662] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493696] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(11514), 1,
      sym_operator_identifier,
    STATE(1752), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(8807), 2,
      anon_sym_match,
      anon_sym_else,
    STATE(10367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [493746] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 3,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493786] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10369), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493824] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10370), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493858] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10591), 1,
      anon_sym_EQ_GT,
    STATE(10371), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493894] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493928] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 4,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9291), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493962] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10374), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493996] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10375), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494030] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10376), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494064] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9262), 1,
      anon_sym_EQ_GT,
    STATE(10377), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494100] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10436), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494134] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10379), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494168] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10380), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494202] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10381), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494236] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10382), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10440), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494270] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10383), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10452), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494304] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(11542), 1,
      sym_operator_identifier,
    STATE(1730), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(8807), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(10384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [494354] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494388] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(11320), 1,
      sym__alpha_identifier,
    ACTIONS(11324), 1,
      anon_sym_EQ,
    ACTIONS(11326), 1,
      sym__backquoted_id,
    ACTIONS(11328), 1,
      sym_operator_identifier,
    STATE(565), 1,
      sym_identifier,
    STATE(4063), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_match,
      anon_sym_finally,
    STATE(10386), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [494438] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10387), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10496), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494472] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10388), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494506] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10389), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11561), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494540] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8981), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494574] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4238), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12524), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(10739), 1,
      sym_colon_argument,
    STATE(9637), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10391), 2,
      sym_comment,
      sym_block_comment,
    STATE(16555), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [494626] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10392), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494660] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10393), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494694] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10394), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494732] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11763), 1,
      anon_sym_EQ_GT,
    STATE(10395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494768] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494802] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494836] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494870] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494904] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494938] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494972] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10402), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10504), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495006] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4404), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12526), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(10138), 1,
      sym_colon_argument,
    STATE(8424), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10403), 2,
      sym_comment,
      sym_block_comment,
    STATE(16824), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [495058] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11662), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [495114] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9449), 1,
      anon_sym_EQ_GT,
    STATE(10405), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495150] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11761), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [495186] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4848), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12528), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9355), 1,
      sym_colon_argument,
    STATE(6927), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10407), 2,
      sym_comment,
      sym_block_comment,
    STATE(17633), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [495238] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12502), 1,
      anon_sym_given,
    ACTIONS(12504), 1,
      sym_operator_identifier,
    ACTIONS(12530), 1,
      anon_sym_RBRACE,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(14713), 1,
      sym_identifier,
    ACTIONS(12500), 2,
      anon_sym_STAR,
      anon_sym__,
    STATE(10408), 2,
      sym_comment,
      sym_block_comment,
    STATE(16114), 4,
      sym_namespace_wildcard,
      sym__namespace_given_by_type,
      sym_arrow_renamed_identifier,
      sym_as_renamed_identifier,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [495288] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495322] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10410), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495356] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10411), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495390] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495424] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12502), 1,
      anon_sym_given,
    ACTIONS(12504), 1,
      sym_operator_identifier,
    ACTIONS(12532), 1,
      anon_sym_RBRACE,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(14713), 1,
      sym_identifier,
    ACTIONS(12500), 2,
      anon_sym_STAR,
      anon_sym__,
    STATE(10413), 2,
      sym_comment,
      sym_block_comment,
    STATE(16114), 4,
      sym_namespace_wildcard,
      sym__namespace_given_by_type,
      sym_arrow_renamed_identifier,
      sym_as_renamed_identifier,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [495474] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(11196), 1,
      sym__alpha_identifier,
    ACTIONS(11200), 1,
      anon_sym_EQ,
    ACTIONS(11202), 1,
      sym__backquoted_id,
    ACTIONS(11204), 1,
      sym_operator_identifier,
    STATE(600), 1,
      sym_identifier,
    STATE(4071), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_if,
      anon_sym_match,
    STATE(10414), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11198), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [495524] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11731), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10415), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [495580] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10873), 1,
      sym_operator_identifier,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(10416), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(9367), 4,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [495628] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495662] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10418), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495696] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10704), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [495730] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495764] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495798] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10422), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10708), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [495832] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10423), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10035), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [495866] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(10424), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495906] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11330), 1,
      anon_sym_EQ_GT,
    STATE(10425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495942] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10426), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495976] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4229), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10427), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496014] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10428), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8985), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496048] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10429), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496082] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(11484), 1,
      sym__alpha_identifier,
    ACTIONS(11490), 1,
      anon_sym_EQ,
    ACTIONS(11492), 1,
      sym__backquoted_id,
    ACTIONS(11494), 1,
      sym_operator_identifier,
    STATE(574), 1,
      sym_identifier,
    STATE(4066), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_match,
      anon_sym_else,
    STATE(10430), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11488), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [496132] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10037), 1,
      anon_sym_EQ_GT,
    STATE(10431), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496168] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10432), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496202] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(11196), 1,
      sym__alpha_identifier,
    ACTIONS(11202), 1,
      sym__backquoted_id,
    ACTIONS(11555), 1,
      anon_sym_EQ,
    ACTIONS(11557), 1,
      sym_operator_identifier,
    STATE(564), 1,
      sym_identifier,
    STATE(4071), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(10433), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11198), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [496252] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4248), 1,
      sym__indent,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12433), 1,
      anon_sym_LPAREN,
    ACTIONS(12534), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(10018), 1,
      sym_colon_argument,
    STATE(7841), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10434), 2,
      sym_comment,
      sym_block_comment,
    STATE(17726), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [496304] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10435), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11561), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [496338] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10436), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10927), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10925), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [496378] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10428), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496412] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4235), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10662), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496450] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10439), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10456), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496484] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8156), 1,
      sym__backquoted_id,
    ACTIONS(12536), 1,
      anon_sym_LBRACK,
    ACTIONS(12538), 1,
      anon_sym_LPAREN,
    ACTIONS(12540), 1,
      anon_sym_POUND,
    STATE(10732), 1,
      aux_sym_annotation_repeat1,
    STATE(11071), 1,
      sym_type_arguments,
    STATE(11323), 1,
      sym_arguments,
    STATE(10440), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8154), 12,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496530] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10441), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496564] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10442), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496598] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10443), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496632] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10444), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496669] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10445), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496702] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12542), 1,
      anon_sym_with,
    ACTIONS(9418), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(10446), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9416), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496737] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10447), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496770] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10448), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 13,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496803] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 2,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10449), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496842] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 2,
      anon_sym_STAR,
      anon_sym_else,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10450), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496881] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496914] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10452), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10927), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10925), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496953] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10453), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496986] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10454), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497019] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 1,
      anon_sym_EQ,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497058] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12502), 1,
      anon_sym_given,
    ACTIONS(12545), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(14243), 1,
      sym_identifier,
    ACTIONS(12500), 2,
      anon_sym_STAR,
      anon_sym__,
    STATE(10456), 2,
      sym_comment,
      sym_block_comment,
    STATE(15378), 4,
      sym_namespace_wildcard,
      sym__namespace_given_by_type,
      sym_arrow_renamed_identifier,
      sym_as_renamed_identifier,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [497105] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10457), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10840), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10838), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497144] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10458), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [497177] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10927), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10925), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [497214] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10460), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497247] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(11514), 1,
      sym_operator_identifier,
    STATE(1752), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(8807), 2,
      anon_sym_match,
      anon_sym_else,
    STATE(10461), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [497294] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10462), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497327] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(12547), 1,
      anon_sym_LBRACE,
    ACTIONS(12551), 1,
      sym_operator_identifier,
    STATE(4512), 1,
      sym__soft_identifier,
    STATE(13687), 1,
      sym_identifier,
    STATE(10463), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12549), 3,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_given,
    STATE(14131), 3,
      sym_namespace_wildcard,
      sym_namespace_selectors,
      sym_as_renamed_identifier,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [497374] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497407] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497440] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10466), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497473] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497506] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497539] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10469), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497572] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11516), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15539), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [497627] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10471), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497660] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11516), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15539), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10472), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [497715] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497748] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(11484), 1,
      sym__alpha_identifier,
    ACTIONS(11492), 1,
      sym__backquoted_id,
    ACTIONS(11494), 1,
      sym_operator_identifier,
    STATE(574), 1,
      sym_identifier,
    STATE(4066), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_match,
      anon_sym_else,
    STATE(10474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11488), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [497795] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10475), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 13,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497828] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497861] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497894] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497927] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4232), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10662), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497964] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10480), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497997] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 2,
      anon_sym_STAR,
      anon_sym_finally,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498036] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(473), 1,
      sym__alpha_identifier,
    ACTIONS(537), 1,
      sym__backquoted_id,
    ACTIONS(12553), 1,
      anon_sym_LBRACE,
    ACTIONS(12557), 1,
      sym_operator_identifier,
    STATE(5776), 1,
      sym__soft_identifier,
    STATE(13979), 1,
      sym_identifier,
    STATE(10482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12555), 3,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_given,
    STATE(14308), 3,
      sym_namespace_wildcard,
      sym_namespace_selectors,
      sym_as_renamed_identifier,
    ACTIONS(659), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [498083] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 2,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10483), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498122] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10484), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498155] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 13,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498188] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8170), 1,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(11843), 1,
      anon_sym_EQ_GT,
    STATE(10486), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498225] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498258] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10488), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498291] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498324] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10490), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498357] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9733), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498390] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(12547), 1,
      anon_sym_LBRACE,
    ACTIONS(12551), 1,
      sym_operator_identifier,
    STATE(4512), 1,
      sym__soft_identifier,
    STATE(13687), 1,
      sym_identifier,
    STATE(10492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12549), 3,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_given,
    STATE(14137), 3,
      sym_namespace_wildcard,
      sym_namespace_selectors,
      sym_as_renamed_identifier,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [498437] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10493), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 13,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498470] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10494), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10840), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10838), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498509] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10495), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498542] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10496), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498575] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11427), 1,
      anon_sym_COMMA,
    ACTIONS(11429), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(14808), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10497), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [498630] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10498), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498663] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498696] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10500), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [498729] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10501), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498762] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498795] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 13,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498828] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10504), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 12,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498861] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10505), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [498894] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498927] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10507), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498960] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10508), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 13,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498993] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11427), 1,
      anon_sym_COMMA,
    ACTIONS(11429), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(14808), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10509), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [499048] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10510), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499081] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10511), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499114] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499147] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [499180] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10514), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499213] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10515), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 13,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499246] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(11196), 1,
      sym__alpha_identifier,
    ACTIONS(11202), 1,
      sym__backquoted_id,
    ACTIONS(11557), 1,
      sym_operator_identifier,
    STATE(564), 1,
      sym_identifier,
    STATE(4071), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(10516), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11198), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [499293] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499326] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499359] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10519), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499392] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10520), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499425] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 13,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499458] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10167), 1,
      anon_sym_LPAREN,
    ACTIONS(12559), 1,
      anon_sym_LBRACK,
    ACTIONS(12561), 1,
      anon_sym_POUND,
    STATE(10987), 1,
      aux_sym_annotation_repeat1,
    STATE(11204), 1,
      sym_type_arguments,
    STATE(11480), 1,
      sym_arguments,
    STATE(10522), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [499501] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11520), 1,
      anon_sym_COMMA,
    ACTIONS(11522), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15388), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10523), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [499556] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11520), 1,
      anon_sym_COMMA,
    ACTIONS(11522), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15388), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [499611] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(11306), 1,
      sym_operator_identifier,
    STATE(1760), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(8807), 2,
      anon_sym_match,
      anon_sym_finally,
    STATE(10525), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [499658] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10323), 1,
      anon_sym_RPAREN,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15473), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [499713] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10527), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499746] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499779] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8807), 1,
      anon_sym_match,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(11647), 1,
      sym_operator_identifier,
    STATE(1766), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(10529), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [499828] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499861] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(10877), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(10879), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    STATE(10531), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [499912] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10323), 1,
      anon_sym_RPAREN,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15473), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [499967] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10533), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500004] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10534), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500037] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(11284), 1,
      sym_operator_identifier,
    STATE(1727), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(8807), 2,
      anon_sym_if,
      anon_sym_match,
    STATE(10535), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [500084] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(10828), 1,
      sym__alpha_identifier,
    ACTIONS(10834), 1,
      sym__backquoted_id,
    ACTIONS(10836), 1,
      sym_operator_identifier,
    ACTIONS(11680), 1,
      anon_sym_EQ,
    STATE(548), 1,
      sym_identifier,
    STATE(4051), 1,
      sym__soft_identifier,
    STATE(10536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 4,
      anon_sym_while,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10830), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [500133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10537), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500166] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500199] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10080), 1,
      anon_sym_LPAREN,
    ACTIONS(12563), 1,
      anon_sym_LBRACK,
    ACTIONS(12565), 1,
      anon_sym_POUND,
    STATE(11028), 1,
      aux_sym_annotation_repeat1,
    STATE(11231), 1,
      sym_type_arguments,
    STATE(11700), 1,
      sym_arguments,
    STATE(10539), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [500242] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 3,
      anon_sym_case,
      anon_sym_if,
      anon_sym_EQ,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500279] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10541), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500312] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12567), 1,
      anon_sym_LBRACK,
    ACTIONS(12569), 1,
      anon_sym_AT,
    ACTIONS(12573), 1,
      anon_sym_LPAREN,
    ACTIONS(12575), 1,
      sym__automatic_semicolon,
    STATE(11011), 1,
      sym_type_parameters,
    STATE(11650), 1,
      sym_annotation,
    STATE(12945), 1,
      sym_access_modifier,
    STATE(12947), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13452), 1,
      sym_class_parameters,
    ACTIONS(12571), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(10542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12458), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [500363] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10543), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500400] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12502), 1,
      anon_sym_given,
    ACTIONS(12578), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(14387), 1,
      sym_identifier,
    ACTIONS(12500), 2,
      anon_sym_STAR,
      anon_sym__,
    STATE(10544), 2,
      sym_comment,
      sym_block_comment,
    STATE(15155), 4,
      sym_namespace_wildcard,
      sym__namespace_given_by_type,
      sym_arrow_renamed_identifier,
      sym_as_renamed_identifier,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [500447] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10545), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500480] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500513] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500546] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500579] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500612] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    ACTIONS(9519), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500645] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500678] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10552), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500711] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500744] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500777] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(11004), 1,
      sym__alpha_identifier,
    ACTIONS(11010), 1,
      sym__backquoted_id,
    ACTIONS(11012), 1,
      sym_operator_identifier,
    ACTIONS(11687), 1,
      anon_sym_EQ,
    STATE(544), 1,
      sym_identifier,
    STATE(4058), 1,
      sym__soft_identifier,
    ACTIONS(9363), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(10555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
    ACTIONS(11006), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [500826] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10556), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500859] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9367), 1,
      anon_sym_match,
    ACTIONS(11196), 1,
      sym__alpha_identifier,
    ACTIONS(11202), 1,
      sym__backquoted_id,
    ACTIONS(11204), 1,
      sym_operator_identifier,
    ACTIONS(11759), 1,
      anon_sym_EQ,
    STATE(600), 1,
      sym_identifier,
    STATE(4071), 1,
      sym__soft_identifier,
    STATE(10557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11198), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [500908] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10558), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500941] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10559), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500974] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10560), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501007] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10561), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [501040] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12580), 1,
      anon_sym_LBRACK,
    ACTIONS(12582), 1,
      anon_sym_AT,
    ACTIONS(12584), 1,
      anon_sym_LPAREN,
    ACTIONS(12586), 1,
      anon_sym_POUND,
    STATE(11476), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11630), 1,
      sym_type_arguments,
    STATE(12303), 1,
      sym_annotation,
    STATE(12840), 1,
      sym_arguments,
    STATE(10562), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [501087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10563), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501120] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12580), 1,
      anon_sym_LBRACK,
    ACTIONS(12582), 1,
      anon_sym_AT,
    ACTIONS(12586), 1,
      anon_sym_POUND,
    ACTIONS(12588), 1,
      anon_sym_LPAREN,
    STATE(11476), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11630), 1,
      sym_type_arguments,
    STATE(12303), 1,
      sym_annotation,
    STATE(13043), 1,
      sym_arguments,
    STATE(10564), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [501167] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10565), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501200] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11436), 1,
      anon_sym_COLON,
    ACTIONS(11438), 1,
      anon_sym_DOT,
    ACTIONS(11440), 1,
      anon_sym_STAR,
    ACTIONS(11442), 1,
      anon_sym_EQ_GT,
    ACTIONS(11444), 1,
      anon_sym_if,
    ACTIONS(11448), 1,
      anon_sym_PIPE,
    ACTIONS(11450), 1,
      sym_operator_identifier,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(17622), 1,
      sym_guard,
    STATE(10566), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [501255] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10567), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501288] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501321] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501354] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10570), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501387] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501420] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10572), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501453] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501486] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501519] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501552] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501585] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(10877), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(10879), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    STATE(10577), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [501636] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501669] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11190), 1,
      anon_sym_COMMA,
    ACTIONS(11192), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15555), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [501724] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10580), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501757] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11279), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15361), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [501812] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(9367), 1,
      anon_sym_match,
    ACTIONS(11196), 1,
      sym__alpha_identifier,
    ACTIONS(11202), 1,
      sym__backquoted_id,
    ACTIONS(11204), 1,
      sym_operator_identifier,
    STATE(600), 1,
      sym_identifier,
    STATE(4071), 1,
      sym__soft_identifier,
    ACTIONS(8803), 2,
      anon_sym_COLON,
      anon_sym_if,
    STATE(10582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9856), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(11198), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [501861] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11190), 1,
      anon_sym_COMMA,
    ACTIONS(11192), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15555), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10583), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [501916] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10584), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(8412), 3,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_EQ,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501955] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10585), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501988] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(10873), 1,
      sym_operator_identifier,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_match,
      anon_sym_then,
    STATE(10586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [502037] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10587), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502070] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10588), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502103] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10589), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502136] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 13,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502169] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8410), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 4,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502208] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(10877), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(10592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10879), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [502257] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(11004), 1,
      sym__alpha_identifier,
    ACTIONS(11010), 1,
      sym__backquoted_id,
    ACTIONS(11012), 1,
      sym_operator_identifier,
    ACTIONS(11782), 1,
      anon_sym_EQ,
    STATE(544), 1,
      sym_identifier,
    STATE(4058), 1,
      sym__soft_identifier,
    ACTIONS(9363), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(10593), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_do,
    ACTIONS(11006), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [502306] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10594), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502339] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9733), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502372] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 13,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502405] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 1,
      anon_sym_QMARK_EQ_GT,
    STATE(10597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9445), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9443), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502440] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(10828), 1,
      sym__alpha_identifier,
    ACTIONS(10834), 1,
      sym__backquoted_id,
    ACTIONS(10836), 1,
      sym_operator_identifier,
    ACTIONS(11768), 1,
      anon_sym_EQ,
    STATE(548), 1,
      sym_identifier,
    STATE(4051), 1,
      sym__soft_identifier,
    STATE(10598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 4,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(10830), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [502489] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(10599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8837), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8835), 10,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502528] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11279), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15361), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [502583] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 13,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502616] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10602), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502649] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11436), 1,
      anon_sym_COLON,
    ACTIONS(11440), 1,
      anon_sym_STAR,
    ACTIONS(11442), 1,
      anon_sym_EQ_GT,
    ACTIONS(11444), 1,
      anon_sym_if,
    ACTIONS(11446), 1,
      anon_sym_AT,
    ACTIONS(11448), 1,
      anon_sym_PIPE,
    ACTIONS(11450), 1,
      sym_operator_identifier,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(17622), 1,
      sym_guard,
    STATE(10603), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [502704] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(8412), 3,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_EQ,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502743] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502780] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10606), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [502813] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10607), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502846] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10927), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10925), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502885] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10609), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 13,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502918] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10610), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502951] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12502), 1,
      anon_sym_given,
    ACTIONS(12504), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(14713), 1,
      sym_identifier,
    ACTIONS(12500), 2,
      anon_sym_STAR,
      anon_sym__,
    STATE(10611), 2,
      sym_comment,
      sym_block_comment,
    STATE(16114), 4,
      sym_namespace_wildcard,
      sym__namespace_given_by_type,
      sym_arrow_renamed_identifier,
      sym_as_renamed_identifier,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [502998] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8078), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503031] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10613), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503068] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9367), 1,
      anon_sym_match,
    ACTIONS(11739), 1,
      sym__alpha_identifier,
    ACTIONS(11743), 1,
      anon_sym_EQ,
    ACTIONS(11745), 1,
      sym__backquoted_id,
    ACTIONS(11747), 1,
      sym_operator_identifier,
    STATE(603), 1,
      sym_identifier,
    STATE(4075), 1,
      sym__soft_identifier,
    STATE(10614), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11741), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [503117] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10615), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8412), 5,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503154] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10616), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11865), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [503187] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9367), 1,
      anon_sym_match,
    ACTIONS(9854), 1,
      sym__alpha_identifier,
    ACTIONS(9860), 1,
      sym__backquoted_id,
    ACTIONS(9862), 1,
      sym_operator_identifier,
    ACTIONS(11720), 1,
      anon_sym_EQ,
    STATE(553), 1,
      sym_identifier,
    STATE(4043), 1,
      sym__soft_identifier,
    STATE(10617), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [503236] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10618), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503269] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9854), 1,
      sym__alpha_identifier,
    ACTIONS(9860), 1,
      sym__backquoted_id,
    ACTIONS(11540), 1,
      sym_operator_identifier,
    STATE(575), 1,
      sym_identifier,
    STATE(4043), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(10619), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [503316] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10805), 1,
      sym__end_marker,
    STATE(10620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10127), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503351] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(11542), 1,
      sym_operator_identifier,
    STATE(1730), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(8807), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(10621), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [503398] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503431] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(11559), 1,
      sym_operator_identifier,
    STATE(1702), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(8807), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(10623), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [503478] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10855), 1,
      sym_arguments,
    STATE(10624), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503513] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [503546] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503579] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [503612] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503645] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [503678] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(11196), 1,
      sym__alpha_identifier,
    ACTIONS(11202), 1,
      sym__backquoted_id,
    ACTIONS(11204), 1,
      sym_operator_identifier,
    STATE(600), 1,
      sym_identifier,
    STATE(4071), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_if,
      anon_sym_match,
    STATE(10630), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11198), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [503725] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(11320), 1,
      sym__alpha_identifier,
    ACTIONS(11326), 1,
      sym__backquoted_id,
    ACTIONS(11328), 1,
      sym_operator_identifier,
    STATE(565), 1,
      sym_identifier,
    STATE(4063), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_match,
      anon_sym_finally,
    STATE(10631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [503772] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11436), 1,
      anon_sym_COLON,
    ACTIONS(11438), 1,
      anon_sym_DOT,
    ACTIONS(11440), 1,
      anon_sym_STAR,
    ACTIONS(11444), 1,
      anon_sym_if,
    ACTIONS(11448), 1,
      anon_sym_PIPE,
    ACTIONS(11450), 1,
      sym_operator_identifier,
    ACTIONS(11512), 1,
      anon_sym_EQ_GT,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(16350), 1,
      sym_guard,
    STATE(10632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [503827] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 13,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503860] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503893] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503926] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(473), 1,
      sym__alpha_identifier,
    ACTIONS(537), 1,
      sym__backquoted_id,
    ACTIONS(12553), 1,
      anon_sym_LBRACE,
    ACTIONS(12557), 1,
      sym_operator_identifier,
    STATE(5776), 1,
      sym__soft_identifier,
    STATE(13979), 1,
      sym_identifier,
    STATE(10636), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12555), 3,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_given,
    STATE(14178), 3,
      sym_namespace_wildcard,
      sym_namespace_selectors,
      sym_as_renamed_identifier,
    ACTIONS(659), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [503973] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504006] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10638), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504039] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10639), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504072] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504105] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504138] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10642), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 13,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [504171] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8412), 5,
      anon_sym_while,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504208] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10644), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 13,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504241] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504274] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10646), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504307] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504340] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10648), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504373] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504406] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504439] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(8412), 5,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504476] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_STAR,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504513] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8412), 5,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_EQ,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504550] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504583] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504620] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10840), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10838), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [504657] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10657), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504690] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11436), 1,
      anon_sym_COLON,
    ACTIONS(11440), 1,
      anon_sym_STAR,
    ACTIONS(11444), 1,
      anon_sym_if,
    ACTIONS(11446), 1,
      anon_sym_AT,
    ACTIONS(11448), 1,
      anon_sym_PIPE,
    ACTIONS(11450), 1,
      sym_operator_identifier,
    ACTIONS(11512), 1,
      anon_sym_EQ_GT,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(16350), 1,
      sym_guard,
    STATE(10658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [504745] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10659), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504778] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12590), 1,
      anon_sym_COLON,
    ACTIONS(12593), 1,
      anon_sym_DOT,
    ACTIONS(12595), 1,
      anon_sym_LBRACK,
    ACTIONS(12598), 1,
      anon_sym_LPAREN,
    ACTIONS(12601), 1,
      sym__automatic_semicolon,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14075), 1,
      sym_type_parameters,
    STATE(14118), 1,
      aux_sym__function_constructor_repeat1,
    STATE(10660), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 9,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_SEMI,
      anon_sym_POUND,
  [504827] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    STATE(10661), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8008), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12604), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [504862] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10662), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504895] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10663), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504927] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11561), 13,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [504959] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11671), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [505009] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8807), 1,
      anon_sym_match,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(11647), 1,
      sym_operator_identifier,
    STATE(1766), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    STATE(10666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8805), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [505055] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(10877), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(10879), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    STATE(10667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [505103] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10668), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12606), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [505133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10669), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7222), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(7220), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505165] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505197] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11898), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505229] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505261] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12608), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [505291] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10500), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505323] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10675), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505355] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505387] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11436), 1,
      anon_sym_COLON,
    ACTIONS(11440), 1,
      anon_sym_STAR,
    ACTIONS(11446), 1,
      anon_sym_AT,
    ACTIONS(11450), 1,
      sym_operator_identifier,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10879), 3,
      anon_sym_EQ_GT,
      anon_sym_if,
      anon_sym_PIPE,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [505435] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10678), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12610), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [505465] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505497] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10680), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10512), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505529] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10681), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10704), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505561] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10682), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10708), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505593] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505625] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10684), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10927), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10925), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505661] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11875), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505693] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10686), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9910), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9912), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505757] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11865), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [505789] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12612), 1,
      anon_sym_with,
    STATE(11078), 1,
      aux_sym_compound_type_repeat1,
    STATE(13043), 1,
      sym_arguments,
    STATE(13255), 1,
      sym_template_body,
    STATE(13256), 1,
      sym__refinement,
    STATE(10689), 2,
      sym_comment,
      sym_block_comment,
    STATE(13295), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [505831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10690), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9914), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9916), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505863] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10691), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11922), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505895] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10840), 1,
      sym__backquoted_id,
    ACTIONS(11438), 1,
      anon_sym_DOT,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10838), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505933] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10693), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11902), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505965] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9455), 1,
      anon_sym_LPAREN,
    STATE(10853), 1,
      aux_sym_annotation_repeat1,
    STATE(11228), 1,
      sym_arguments,
    STATE(10694), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [506001] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10695), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506033] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    ACTIONS(12614), 1,
      anon_sym_RPAREN,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15957), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [506087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506119] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11898), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506151] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10699), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10712), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506183] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10700), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506215] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506247] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506279] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(5054), 1,
      anon_sym_RPAREN,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15957), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10703), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [506333] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506365] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506397] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 12,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506429] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    ACTIONS(12616), 1,
      anon_sym_RPAREN,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15957), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [506483] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10708), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10840), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10838), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506519] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506551] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506583] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506615] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    ACTIONS(12618), 1,
      anon_sym_RPAREN,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15531), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [506669] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10713), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 12,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506701] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10714), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11937), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506733] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506765] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4215), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10664), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10662), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506801] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 12,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506833] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 12,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506865] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 1,
      anon_sym_finally,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10719), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506903] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 3,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506939] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    ACTIONS(12620), 1,
      anon_sym_RPAREN,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15957), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10721), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [506993] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(11385), 1,
      sym__alpha_identifier,
    ACTIONS(11391), 1,
      sym__backquoted_id,
    ACTIONS(11393), 1,
      sym_operator_identifier,
    ACTIONS(11932), 1,
      anon_sym_EQ,
    STATE(563), 1,
      sym_identifier,
    STATE(4068), 1,
      sym__soft_identifier,
    STATE(10722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(11387), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [507041] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507073] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507105] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507137] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10726), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 12,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8406), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507201] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10728), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507233] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12622), 1,
      anon_sym_LBRACK,
    ACTIONS(12624), 1,
      anon_sym_AT,
    ACTIONS(12626), 1,
      anon_sym_POUND,
    STATE(11585), 1,
      sym_type_arguments,
    STATE(11588), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12435), 1,
      sym_annotation,
    STATE(16693), 1,
      sym_arguments,
    STATE(10729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_SEMI,
  [507279] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12628), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [507309] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507341] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12538), 1,
      anon_sym_LPAREN,
    STATE(10777), 1,
      aux_sym_annotation_repeat1,
    STATE(11323), 1,
      sym_arguments,
    ACTIONS(8428), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(10732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8426), 12,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10733), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507411] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 1,
      anon_sym_STAR,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507449] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11436), 1,
      anon_sym_COLON,
    ACTIONS(11440), 1,
      anon_sym_STAR,
    ACTIONS(11442), 1,
      anon_sym_EQ_GT,
    ACTIONS(11444), 1,
      anon_sym_if,
    ACTIONS(11448), 1,
      anon_sym_PIPE,
    ACTIONS(11450), 1,
      sym_operator_identifier,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(17622), 1,
      sym_guard,
    STATE(10735), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [507501] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 3,
      anon_sym_STAR,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507537] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10927), 1,
      sym__backquoted_id,
    ACTIONS(11438), 1,
      anon_sym_DOT,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10925), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507575] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10738), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 3,
      anon_sym_STAR,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507611] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507643] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507675] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12630), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [507705] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11427), 1,
      anon_sym_COMMA,
    ACTIONS(11429), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(14808), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10742), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [507757] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12634), 1,
      anon_sym_case,
    ACTIONS(12636), 1,
      anon_sym_EQ,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    STATE(10743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12638), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507795] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    ACTIONS(12642), 1,
      anon_sym_case,
    ACTIONS(12644), 1,
      anon_sym_EQ,
    STATE(10744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12646), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507833] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10927), 1,
      sym__backquoted_id,
    ACTIONS(11446), 1,
      anon_sym_AT,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10745), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10925), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507871] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507903] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 1,
      anon_sym_else,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10747), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507941] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2516), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2511), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507973] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10749), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 12,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508005] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(11385), 1,
      sym__alpha_identifier,
    ACTIONS(11391), 1,
      sym__backquoted_id,
    ACTIONS(11393), 1,
      sym_operator_identifier,
    ACTIONS(11825), 1,
      anon_sym_EQ,
    STATE(563), 1,
      sym_identifier,
    STATE(4068), 1,
      sym__soft_identifier,
    STATE(10750), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9367), 3,
      anon_sym_while,
      anon_sym_match,
      anon_sym_finally,
    ACTIONS(11387), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [508053] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10363), 1,
      anon_sym_LPAREN,
    ACTIONS(12648), 1,
      anon_sym_LBRACK,
    ACTIONS(12650), 1,
      anon_sym_POUND,
    STATE(11149), 1,
      aux_sym_annotation_repeat1,
    STATE(11513), 1,
      sym_type_arguments,
    STATE(12041), 1,
      sym_arguments,
    STATE(10751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [508095] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11190), 1,
      anon_sym_COMMA,
    ACTIONS(11192), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15555), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [508147] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11675), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10753), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [508197] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11731), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10754), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [508247] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10755), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 3,
      anon_sym_case,
      anon_sym_if,
      anon_sym_finally,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508283] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(10756), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [508315] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10757), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508347] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10758), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508379] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12580), 1,
      anon_sym_LBRACK,
    ACTIONS(12584), 1,
      anon_sym_LPAREN,
    ACTIONS(12586), 1,
      anon_sym_POUND,
    STATE(11475), 1,
      aux_sym_annotation_repeat1,
    STATE(11630), 1,
      sym_type_arguments,
    STATE(12434), 1,
      sym_arguments,
    STATE(10759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [508421] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10402), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508453] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10761), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508485] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10479), 1,
      anon_sym_LPAREN,
    ACTIONS(12652), 1,
      anon_sym_LBRACK,
    ACTIONS(12654), 1,
      anon_sym_POUND,
    STATE(11256), 1,
      aux_sym_annotation_repeat1,
    STATE(11682), 1,
      sym_type_arguments,
    STATE(12060), 1,
      sym_arguments,
    STATE(10762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [508527] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11074), 1,
      aux_sym_compound_type_repeat1,
    STATE(12840), 1,
      sym_arguments,
    STATE(13017), 1,
      sym__refinement,
    STATE(13019), 1,
      sym_template_body,
    STATE(10763), 2,
      sym_comment,
      sym_block_comment,
    STATE(12646), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [508567] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10840), 1,
      sym__backquoted_id,
    ACTIONS(11446), 1,
      anon_sym_AT,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10838), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508605] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10765), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 12,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508637] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10766), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508669] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10767), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 3,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508705] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    STATE(10768), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8008), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12604), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508739] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    ACTIONS(12656), 1,
      anon_sym_RPAREN,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15957), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [508793] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12658), 1,
      anon_sym_DOT,
    STATE(10770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508827] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10771), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10408), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10406), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508859] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11879), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508891] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10773), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 3,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508927] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508959] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508991] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10776), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12660), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [509021] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12662), 1,
      anon_sym_LPAREN,
    STATE(11323), 1,
      sym_arguments,
    ACTIONS(8432), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(10777), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8430), 12,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509057] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509089] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9893), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9895), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509121] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11664), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [509171] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10414), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10412), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509203] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    ACTIONS(12665), 1,
      anon_sym_RPAREN,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15957), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [509257] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11279), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15361), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [509309] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509341] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509373] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10418), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10416), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509405] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10422), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10420), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509437] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10788), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509469] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10426), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10424), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509501] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11755), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(10790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [509551] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9959), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509583] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 12,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509615] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10573), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509647] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(10321), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [509697] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10795), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 12,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509729] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    ACTIONS(12667), 1,
      anon_sym_RPAREN,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15957), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [509783] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 12,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509815] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10798), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509847] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10504), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509879] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10704), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509911] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10708), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509943] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(10321), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [509993] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10803), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510025] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(5066), 1,
      anon_sym_RPAREN,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15957), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10804), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [510079] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9900), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9902), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510111] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10806), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510143] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10807), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 17,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [510173] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [510205] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10809), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12669), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [510235] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    ACTIONS(12671), 1,
      anon_sym_RPAREN,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15957), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10810), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [510289] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10430), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10428), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510321] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10712), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510353] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12673), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [510383] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12675), 1,
      anon_sym_DOT,
    STATE(10814), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [510415] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10815), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8412), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510447] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11755), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(10816), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [510497] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10817), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10434), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10432), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510529] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10818), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10573), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [510561] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510593] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10577), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510625] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(8412), 4,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510661] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10822), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10438), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10436), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510693] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10823), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10581), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10442), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10440), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510757] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 12,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510789] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(10826), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8412), 4,
      anon_sym_while,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510825] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10827), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510857] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10828), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510889] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12677), 1,
      anon_sym_LBRACK,
    ACTIONS(12679), 1,
      anon_sym_LPAREN,
    ACTIONS(12681), 1,
      anon_sym_POUND,
    STATE(11512), 1,
      aux_sym_annotation_repeat1,
    STATE(11632), 1,
      sym_type_arguments,
    STATE(12267), 1,
      sym_arguments,
    STATE(10829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [510931] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(5008), 1,
      anon_sym_RPAREN,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15957), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [510985] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511017] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 12,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511049] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10833), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 4,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511081] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10834), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511113] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12580), 1,
      anon_sym_LBRACK,
    ACTIONS(12582), 1,
      anon_sym_AT,
    ACTIONS(12586), 1,
      anon_sym_POUND,
    STATE(11476), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11630), 1,
      sym_type_arguments,
    STATE(12303), 1,
      sym_annotation,
    STATE(10835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [511155] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8410), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 3,
      anon_sym_COLON,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511193] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12462), 1,
      anon_sym_AT,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12685), 1,
      sym__automatic_semicolon,
    STATE(11238), 1,
      sym_annotation,
    STATE(12294), 1,
      sym_access_modifier,
    STATE(12295), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    ACTIONS(12464), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(10837), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12683), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [511239] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 12,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511271] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10839), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 17,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [511301] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10446), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10444), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511333] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10450), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10448), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511365] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11664), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10842), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [511415] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12688), 1,
      anon_sym_LBRACK,
    ACTIONS(12690), 1,
      anon_sym_AT,
    ACTIONS(12692), 1,
      anon_sym_LPAREN,
    ACTIONS(12694), 1,
      anon_sym_POUND,
    STATE(11794), 1,
      sym_type_arguments,
    STATE(11833), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13003), 1,
      sym_annotation,
    STATE(13470), 1,
      sym_arguments,
    STATE(10843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [511461] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511493] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11675), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [511543] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10846), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511575] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10847), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10577), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [511607] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    ACTIONS(12696), 1,
      anon_sym_RPAREN,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15957), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [511661] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10849), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11871), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511693] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    ACTIONS(8078), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511757] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11912), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511789] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12698), 1,
      anon_sym_LPAREN,
    STATE(11228), 1,
      sym_arguments,
    STATE(10853), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [511823] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10854), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10454), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10452), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511855] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10855), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10522), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511887] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11731), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10856), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [511937] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10857), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10581), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [511969] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10858), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512001] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512033] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(10860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512067] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 2,
      anon_sym_LT_COLON,
      anon_sym_EQ,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512105] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10458), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10456), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512137] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [512169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10864), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512201] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 4,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512233] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10866), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512265] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512297] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11922), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512329] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10869), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512361] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10712), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512393] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10323), 1,
      anon_sym_RPAREN,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15473), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10871), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [512445] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512477] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10873), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512509] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(4132), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(10875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [512573] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10031), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512605] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10877), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512637] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10878), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(6936), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512669] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10879), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10035), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512701] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11436), 1,
      anon_sym_COLON,
    ACTIONS(11440), 1,
      anon_sym_STAR,
    ACTIONS(11444), 1,
      anon_sym_if,
    ACTIONS(11448), 1,
      anon_sym_PIPE,
    ACTIONS(11450), 1,
      sym_operator_identifier,
    ACTIONS(11512), 1,
      anon_sym_EQ_GT,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(16350), 1,
      sym_guard,
    STATE(10880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [512753] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10881), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512785] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10041), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512817] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10883), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10884), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10048), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512881] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12622), 1,
      anon_sym_LBRACK,
    ACTIONS(12626), 1,
      anon_sym_POUND,
    ACTIONS(12701), 1,
      anon_sym_LPAREN,
    STATE(11585), 1,
      sym_type_arguments,
    STATE(11676), 1,
      aux_sym_annotation_repeat1,
    STATE(12369), 1,
      sym_arguments,
    STATE(10885), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_SEMI,
  [512923] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12703), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [512953] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10887), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10052), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512985] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(5030), 1,
      anon_sym_RPAREN,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15957), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [513039] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(5010), 1,
      anon_sym_RPAREN,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15957), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10889), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [513093] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12590), 1,
      anon_sym_COLON,
    ACTIONS(12595), 1,
      anon_sym_LBRACK,
    ACTIONS(12598), 1,
      anon_sym_LPAREN,
    ACTIONS(12601), 1,
      sym__automatic_semicolon,
    ACTIONS(12705), 1,
      anon_sym_DOT,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14075), 1,
      sym_type_parameters,
    STATE(14118), 1,
      aux_sym__function_constructor_repeat1,
    STATE(10890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_SEMI,
      anon_sym_POUND,
  [513141] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    ACTIONS(12707), 1,
      anon_sym_RPAREN,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15143), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10891), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [513195] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12634), 1,
      anon_sym_case,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    ACTIONS(12709), 1,
      anon_sym_EQ,
    STATE(10892), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12638), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513233] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    ACTIONS(12642), 1,
      anon_sym_case,
    ACTIONS(12711), 1,
      anon_sym_EQ,
    STATE(10893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12646), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513271] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10894), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11839), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513303] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12688), 1,
      anon_sym_LBRACK,
    ACTIONS(12690), 1,
      anon_sym_AT,
    ACTIONS(12694), 1,
      anon_sym_POUND,
    ACTIONS(12713), 1,
      anon_sym_LPAREN,
    STATE(11794), 1,
      sym_type_arguments,
    STATE(11833), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13003), 1,
      sym_annotation,
    STATE(13115), 1,
      sym_arguments,
    STATE(10895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [513349] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11662), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10896), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [513399] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10897), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513431] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10898), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 12,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513463] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513495] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10900), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513527] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12715), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [513557] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11520), 1,
      anon_sym_COMMA,
    ACTIONS(11522), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15388), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10902), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [513609] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8410), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(10903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 5,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513645] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10319), 1,
      anon_sym_AT,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11662), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [513695] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10905), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513727] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11871), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513759] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10907), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513791] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10908), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10704), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513823] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10909), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513855] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10910), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10508), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513887] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10911), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10496), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513919] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10912), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513951] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11879), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513983] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10914), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514015] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(11561), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514047] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10031), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514079] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10035), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514111] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514143] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514175] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12717), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [514205] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10921), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12719), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [514235] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10922), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 12,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514267] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11436), 1,
      anon_sym_COLON,
    ACTIONS(11438), 1,
      anon_sym_DOT,
    ACTIONS(11440), 1,
      anon_sym_STAR,
    ACTIONS(11450), 1,
      sym_operator_identifier,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10879), 3,
      anon_sym_EQ_GT,
      anon_sym_if,
      anon_sym_PIPE,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [514315] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514347] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10041), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514411] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    ACTIONS(12721), 1,
      anon_sym_RPAREN,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15957), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [514465] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10313), 1,
      anon_sym_DOT,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11671), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10928), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [514515] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10708), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514547] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10048), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514579] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514611] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(9367), 1,
      anon_sym_match,
    ACTIONS(11739), 1,
      sym__alpha_identifier,
    ACTIONS(11745), 1,
      sym__backquoted_id,
    ACTIONS(11747), 1,
      sym_operator_identifier,
    STATE(603), 1,
      sym_identifier,
    STATE(4075), 1,
      sym__soft_identifier,
    STATE(10932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11741), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [514657] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10052), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514689] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10934), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 17,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [514719] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(5042), 1,
      anon_sym_RPAREN,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15957), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10935), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [514773] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514805] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10937), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514837] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10938), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11839), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514869] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11875), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514901] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10940), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11902), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514933] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10941), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12723), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [514963] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    ACTIONS(12725), 1,
      anon_sym_RPAREN,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15352), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(10942), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [515017] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11912), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515049] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11937), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515081] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    ACTIONS(11516), 1,
      anon_sym_RPAREN,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15539), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [515133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10946), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8406), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515165] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8412), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515197] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    ACTIONS(9733), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515229] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10949), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12727), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [515259] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10035), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515290] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11160), 1,
      anon_sym_EQ,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(12729), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [515339] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [515368] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 12,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515399] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11221), 1,
      anon_sym_EQ,
    ACTIONS(12731), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [515448] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12733), 1,
      anon_sym_end,
    STATE(5244), 1,
      sym__end_marker,
    STATE(10955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [515481] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [515510] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10957), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [515539] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11221), 1,
      anon_sym_EQ,
    ACTIONS(12731), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10958), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [515588] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 11,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515619] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11242), 1,
      anon_sym_EQ,
    ACTIONS(12735), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10960), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [515668] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12688), 1,
      anon_sym_LBRACK,
    ACTIONS(12690), 1,
      anon_sym_AT,
    ACTIONS(12694), 1,
      anon_sym_POUND,
    STATE(11794), 1,
      sym_type_arguments,
    STATE(11833), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13003), 1,
      sym_annotation,
    STATE(10961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [515709] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10962), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10573), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515740] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11352), 1,
      anon_sym_EQ,
    ACTIONS(12737), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10963), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [515789] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12739), 1,
      anon_sym_with,
    STATE(11173), 1,
      aux_sym_compound_type_repeat1,
    STATE(13416), 1,
      sym__refinement,
    STATE(13470), 1,
      sym_arguments,
    STATE(13626), 1,
      sym_template_body,
    STATE(10964), 2,
      sym_comment,
      sym_block_comment,
    STATE(13512), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [515830] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10965), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10031), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [515861] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10966), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515892] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10967), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10712), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515923] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 2,
      anon_sym_STAR,
      anon_sym_else,
    STATE(10968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515958] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11508), 1,
      anon_sym_EQ,
    ACTIONS(12741), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [516007] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10970), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10500), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [516038] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10971), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12745), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12743), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [516069] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10972), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10048), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516100] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10840), 1,
      sym__backquoted_id,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10838), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516135] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(11561), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516166] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11436), 1,
      anon_sym_COLON,
    ACTIONS(11440), 1,
      anon_sym_STAR,
    ACTIONS(11450), 1,
      sym_operator_identifier,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10879), 3,
      anon_sym_EQ_GT,
      anon_sym_if,
      anon_sym_PIPE,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [516211] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8412), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516242] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [516271] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10978), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10581), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516302] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12688), 1,
      anon_sym_LBRACK,
    ACTIONS(12694), 1,
      anon_sym_POUND,
    ACTIONS(12713), 1,
      anon_sym_LPAREN,
    STATE(11794), 1,
      sym_type_arguments,
    STATE(12084), 1,
      aux_sym_annotation_repeat1,
    STATE(12735), 1,
      sym_arguments,
    STATE(10979), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [516343] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    ACTIONS(12747), 1,
      anon_sym_EQ,
    STATE(10980), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12638), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516378] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10052), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [516409] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10982), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [516438] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [516467] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(9367), 1,
      anon_sym_match,
    ACTIONS(11947), 1,
      sym__alpha_identifier,
    ACTIONS(11953), 1,
      sym__backquoted_id,
    ACTIONS(11955), 1,
      sym_operator_identifier,
    STATE(1391), 1,
      sym_identifier,
    STATE(4164), 1,
      sym__soft_identifier,
    ACTIONS(8803), 2,
      anon_sym_COLON,
      anon_sym_EQ_GT,
    STATE(10984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11951), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [516514] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10927), 1,
      sym__backquoted_id,
    STATE(4142), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(10985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10925), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516549] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11561), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516580] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10167), 1,
      anon_sym_LPAREN,
    STATE(10989), 1,
      aux_sym_annotation_repeat1,
    STATE(11480), 1,
      sym_arguments,
    STATE(10987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [516615] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8410), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(10988), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 4,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516650] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12749), 1,
      anon_sym_LPAREN,
    STATE(11480), 1,
      sym_arguments,
    STATE(10989), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [516683] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10990), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11922), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516714] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4219), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(10664), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(10991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10662), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516749] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10992), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 11,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516780] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10993), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10512), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [516811] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10994), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10052), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516842] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11176), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11755), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(10995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [516889] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10996), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 11,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516920] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10041), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [516951] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    ACTIONS(12752), 1,
      anon_sym_EQ,
    STATE(10998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12646), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516986] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8953), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517017] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11000), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8981), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517048] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(11001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [517079] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11002), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10035), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [517110] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10504), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [517141] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11238), 1,
      anon_sym_EQ,
    ACTIONS(12754), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [517190] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 12,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517221] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11006), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10704), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517252] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517283] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11008), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10577), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517314] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10581), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517345] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [517374] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12569), 1,
      anon_sym_AT,
    ACTIONS(12573), 1,
      anon_sym_LPAREN,
    ACTIONS(12756), 1,
      sym__automatic_semicolon,
    STATE(11672), 1,
      sym_annotation,
    STATE(12973), 1,
      sym_access_modifier,
    STATE(12975), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13452), 1,
      sym_class_parameters,
    ACTIONS(12571), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(11011), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12683), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [517419] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11012), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [517448] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11160), 1,
      anon_sym_EQ,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(12729), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11013), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [517497] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11508), 1,
      anon_sym_EQ,
    ACTIONS(12741), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11014), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [517546] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11015), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10577), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517577] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11016), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10496), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [517608] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11017), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [517637] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12759), 1,
      anon_sym_LPAREN,
    STATE(11700), 1,
      sym_arguments,
    STATE(11018), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [517670] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11019), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10035), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517701] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12764), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12762), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [517732] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11021), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9092), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517763] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(11022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [517794] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11023), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [517823] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11168), 1,
      anon_sym_EQ,
    ACTIONS(12766), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11024), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [517872] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11025), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [517901] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [517930] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(10321), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(11027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [517977] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10080), 1,
      anon_sym_LPAREN,
    STATE(11018), 1,
      aux_sym_annotation_repeat1,
    STATE(11700), 1,
      sym_arguments,
    STATE(11028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [518012] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 2,
      anon_sym_else,
      anon_sym_finally,
    STATE(11029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518047] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9088), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518078] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 12,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518109] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(11032), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(8412), 3,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_EQ,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518144] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [518173] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8855), 1,
      anon_sym_LPAREN,
    ACTIONS(12768), 1,
      anon_sym_LBRACK,
    ACTIONS(12770), 1,
      anon_sym_POUND,
    STATE(11633), 1,
      aux_sym_annotation_repeat1,
    STATE(12085), 1,
      sym_type_arguments,
    STATE(12525), 1,
      sym_arguments,
    STATE(11034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 10,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [518214] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [518243] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11036), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12774), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12772), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [518274] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12776), 1,
      anon_sym_LBRACK,
    ACTIONS(12778), 1,
      anon_sym_AT,
    ACTIONS(12780), 1,
      anon_sym_POUND,
    STATE(11877), 1,
      sym_type_arguments,
    STATE(12049), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12713), 1,
      sym_annotation,
    STATE(16693), 1,
      sym_arguments,
    STATE(11037), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_SEMI,
  [518319] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12640), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12632), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [518350] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11039), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11839), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518381] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11875), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518412] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11902), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518443] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11042), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12784), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12782), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [518474] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11255), 1,
      aux_sym_compound_type_repeat1,
    STATE(13115), 1,
      sym_arguments,
    STATE(13190), 1,
      sym_template_body,
    STATE(13192), 1,
      sym__refinement,
    STATE(11043), 2,
      sym_comment,
      sym_block_comment,
    STATE(13197), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [518513] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11044), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 11,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518544] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9068), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518575] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8410), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(8412), 2,
      anon_sym_COLON,
      anon_sym_LT_PERCENT,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(11046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518612] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11047), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10031), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518643] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12443), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9885), 1,
      sym_annotation,
    STATE(11157), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12969), 1,
      sym_inline_modifier,
    STATE(15957), 1,
      sym_parameter,
    STATE(17375), 1,
      sym_identifier,
    STATE(11048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [518694] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8985), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8994), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518756] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12788), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12786), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [518787] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [518816] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10041), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518847] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    ACTIONS(12790), 1,
      anon_sym_EQ,
    STATE(11054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12638), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518882] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11675), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(11055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [518929] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11662), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(11056), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [518976] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11898), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519007] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8422), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519038] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 12,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519069] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10048), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519100] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10708), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519131] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [519160] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 16,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [519189] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519220] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11065), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11912), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11937), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519282] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11871), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519313] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 11,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519344] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 2,
      anon_sym_catch,
      anon_sym_finally,
    STATE(11069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10052), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519410] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9086), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519441] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11504), 1,
      anon_sym_EQ,
    ACTIONS(12792), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [519490] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    ACTIONS(12794), 1,
      anon_sym_EQ,
    STATE(11073), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12638), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519525] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12300), 1,
      aux_sym_compound_type_repeat1,
    STATE(12867), 1,
      sym__refinement,
    STATE(13019), 1,
      sym_template_body,
    STATE(11074), 2,
      sym_comment,
      sym_block_comment,
    STATE(12646), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [519562] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12796), 1,
      anon_sym_DOT,
    STATE(11075), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [519593] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 12,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519624] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_LPAREN,
    ACTIONS(8008), 2,
      anon_sym_DOT,
      sym__backquoted_id,
    STATE(11077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12604), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519657] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12612), 1,
      anon_sym_with,
    STATE(12300), 1,
      aux_sym_compound_type_repeat1,
    STATE(13255), 1,
      sym_template_body,
    STATE(13265), 1,
      sym__refinement,
    STATE(11078), 2,
      sym_comment,
      sym_block_comment,
    STATE(13295), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [519696] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519727] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 11,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519758] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11352), 1,
      anon_sym_EQ,
    ACTIONS(12737), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11081), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [519807] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11168), 1,
      anon_sym_EQ,
    ACTIONS(12766), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [519856] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 1,
      anon_sym_EQ,
    STATE(11083), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519891] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    ACTIONS(12798), 1,
      anon_sym_EQ,
    STATE(11084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12646), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519926] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 11,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519957] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 2,
      anon_sym_STAR,
      anon_sym_finally,
    STATE(11086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519992] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(10873), 1,
      sym_operator_identifier,
    ACTIONS(12151), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_while,
      anon_sym_match,
    STATE(11087), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [520039] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11088), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12802), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12800), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [520070] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11089), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10048), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [520101] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 11,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520132] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11091), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 11,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520163] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11092), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11879), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520194] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      sym__alpha_identifier,
    ACTIONS(8803), 1,
      anon_sym_COLON,
    ACTIONS(8815), 1,
      sym__backquoted_id,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(10873), 1,
      sym_operator_identifier,
    ACTIONS(12054), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(9367), 2,
      anon_sym_match,
      anon_sym_do,
    STATE(11093), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8811), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [520241] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [520270] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11095), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12806), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12804), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [520301] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8813), 1,
      anon_sym_EQ,
    STATE(611), 1,
      sym_identifier,
    STATE(4076), 1,
      sym__soft_identifier,
    ACTIONS(8837), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(11096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8835), 11,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520338] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11097), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [520367] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 11,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520398] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11099), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10573), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520429] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10976), 1,
      anon_sym_LPAREN,
    ACTIONS(12808), 1,
      anon_sym_LBRACK,
    ACTIONS(12810), 1,
      anon_sym_POUND,
    STATE(11494), 1,
      aux_sym_annotation_repeat1,
    STATE(12062), 1,
      sym_type_arguments,
    STATE(12204), 1,
      sym_arguments,
    STATE(11100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [520470] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11101), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8983), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520501] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11671), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(11102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [520548] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11103), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9090), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520579] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11104), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10031), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520610] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(11105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(8412), 3,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_EQ,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520645] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11217), 1,
      anon_sym_EQ,
    ACTIONS(12812), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11106), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [520694] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [520723] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 12,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520754] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11109), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520785] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 12,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520816] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 16,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [520845] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [520874] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12814), 1,
      anon_sym_DOT,
    STATE(11113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [520905] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11114), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10041), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520936] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12776), 1,
      anon_sym_LBRACK,
    ACTIONS(12780), 1,
      anon_sym_POUND,
    ACTIONS(12816), 1,
      anon_sym_LPAREN,
    STATE(11790), 1,
      aux_sym_annotation_repeat1,
    STATE(11877), 1,
      sym_type_arguments,
    STATE(12747), 1,
      sym_arguments,
    STATE(11115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_SEMI,
  [520977] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12818), 1,
      anon_sym_AT,
    STATE(11468), 1,
      sym_annotation,
    ACTIONS(8933), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(11116), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8931), 11,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521012] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    ACTIONS(12821), 1,
      anon_sym_EQ,
    STATE(11117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12646), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521047] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12823), 1,
      anon_sym_LBRACK,
    ACTIONS(12825), 1,
      anon_sym_LPAREN,
    ACTIONS(12827), 1,
      anon_sym_POUND,
    STATE(11837), 1,
      sym_type_arguments,
    STATE(11860), 1,
      aux_sym_annotation_repeat1,
    STATE(12835), 1,
      sym_arguments,
    STATE(11118), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [521088] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8414), 1,
      anon_sym_QMARK_EQ_GT,
    STATE(11119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 5,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_if,
      anon_sym_PIPE,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521123] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8408), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8406), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521154] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11504), 1,
      anon_sym_EQ,
    ACTIONS(12792), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11121), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [521203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11122), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12831), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12829), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [521234] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11238), 1,
      anon_sym_EQ,
    ACTIONS(12754), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [521283] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11731), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(11124), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [521330] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 12,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521361] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11242), 1,
      anon_sym_EQ,
    ACTIONS(12735), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11126), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [521410] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11365), 1,
      anon_sym_EQ,
    ACTIONS(12833), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [521459] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10508), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [521490] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11154), 1,
      anon_sym_DOT,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11365), 1,
      anon_sym_EQ,
    ACTIONS(12833), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11129), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [521539] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10315), 1,
      anon_sym_STAR,
    ACTIONS(10325), 1,
      anon_sym_PIPE,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(10329), 1,
      sym_operator_identifier,
    STATE(4147), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    ACTIONS(11664), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(11130), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [521586] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11131), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [521615] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11158), 1,
      anon_sym_AT,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11217), 1,
      anon_sym_EQ,
    ACTIONS(12812), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11132), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [521664] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9098), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521695] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12835), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11134), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [521739] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [521767] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11242), 1,
      anon_sym_EQ,
    ACTIONS(12735), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [521813] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11137), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [521841] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12640), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12632), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521871] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [521899] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12837), 1,
      anon_sym_RPAREN,
    ACTIONS(12839), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15323), 1,
      sym_binding,
    STATE(15582), 1,
      sym_identifier,
    STATE(15588), 1,
      sym_wildcard,
    STATE(11140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [521945] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11867), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11865), 10,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521975] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [522003] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12460), 1,
      anon_sym_LBRACK,
    ACTIONS(12462), 1,
      anon_sym_AT,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12841), 1,
      sym__automatic_semicolon,
    STATE(12112), 1,
      sym_type_parameters,
    STATE(12722), 1,
      sym_annotation,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(13726), 1,
      sym_access_modifier,
    STATE(13727), 1,
      aux_sym__class_constructor_repeat1,
    ACTIONS(12464), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(11143), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12458), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [522051] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [522079] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [522107] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [522135] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [522163] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11148), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [522191] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10363), 1,
      anon_sym_LPAREN,
    STATE(11150), 1,
      aux_sym_annotation_repeat1,
    STATE(12041), 1,
      sym_arguments,
    STATE(11149), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [522225] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12843), 1,
      anon_sym_LPAREN,
    STATE(12041), 1,
      sym_arguments,
    STATE(11150), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [522257] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10573), 12,
      anon_sym_COLON,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522287] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12846), 1,
      anon_sym_DOT,
    STATE(11152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [522317] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10577), 12,
      anon_sym_COLON,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522347] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10581), 12,
      anon_sym_COLON,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522377] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(11155), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [522407] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12848), 1,
      sym__alpha_identifier,
    ACTIONS(12850), 1,
      anon_sym_object,
    ACTIONS(12852), 1,
      anon_sym_class,
    ACTIONS(12856), 1,
      sym__backquoted_id,
    ACTIONS(12858), 1,
      sym_operator_identifier,
    STATE(12301), 1,
      sym_identifier,
    STATE(13994), 1,
      sym__soft_identifier,
    STATE(14209), 1,
      sym_simple_enum_case,
    STATE(15297), 1,
      sym_full_enum_case,
    STATE(11156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12854), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [522453] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4936), 1,
      anon_sym_AT,
    ACTIONS(8062), 1,
      anon_sym_inline,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12860), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(9008), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9885), 1,
      sym_annotation,
    STATE(12734), 1,
      sym_inline_modifier,
    STATE(17384), 1,
      sym_identifier,
    STATE(11157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [522501] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11898), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522531] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 1,
      anon_sym_else,
    STATE(11159), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522565] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12862), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11160), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [522609] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12593), 1,
      anon_sym_DOT,
    STATE(11161), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [522639] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12864), 1,
      anon_sym_DOT,
    STATE(11162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [522669] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(11163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [522699] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 10,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522729] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 1,
      anon_sym_STAR,
    STATE(11165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522763] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(12868), 1,
      anon_sym_COLON,
    ACTIONS(12870), 1,
      anon_sym_extends,
    ACTIONS(12872), 1,
      anon_sym_derives,
    STATE(11915), 1,
      sym_extends_clause,
    STATE(12905), 1,
      sym_derives_clause,
    STATE(14311), 1,
      sym__definition_body,
    STATE(14313), 1,
      sym_template_body,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11166), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12866), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [522809] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [522837] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9363), 1,
      anon_sym_LBRACK,
    ACTIONS(9367), 1,
      anon_sym_match,
    ACTIONS(11947), 1,
      sym__alpha_identifier,
    ACTIONS(11953), 1,
      sym__backquoted_id,
    ACTIONS(11955), 1,
      sym_operator_identifier,
    STATE(1391), 1,
      sym_identifier,
    STATE(4164), 1,
      sym__soft_identifier,
    ACTIONS(8803), 2,
      anon_sym_COLON,
      anon_sym_EQ_GT,
    STATE(11168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11951), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [522881] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9064), 1,
      anon_sym_LPAREN,
    ACTIONS(12874), 1,
      anon_sym_LBRACK,
    ACTIONS(12876), 1,
      anon_sym_POUND,
    STATE(11977), 1,
      aux_sym_annotation_repeat1,
    STATE(12233), 1,
      sym_type_arguments,
    STATE(12652), 1,
      sym_arguments,
    STATE(11169), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [522921] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12878), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11170), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [522965] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11563), 1,
      sym__backquoted_id,
    STATE(11171), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11561), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522995] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    STATE(11172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 5,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_if,
      anon_sym_PIPE,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523027] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12739), 1,
      anon_sym_with,
    STATE(12887), 1,
      aux_sym_compound_type_repeat1,
    STATE(13484), 1,
      sym__refinement,
    STATE(13626), 1,
      sym_template_body,
    STATE(11173), 2,
      sym_comment,
      sym_block_comment,
    STATE(13512), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [523065] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [523093] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11175), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523123] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [523151] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(11177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [523181] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8901), 12,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523211] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8905), 12,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523241] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [523269] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8621), 12,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523299] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11182), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [523327] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11183), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10498), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10496), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523357] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10502), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10500), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523387] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [523415] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12839), 1,
      sym_operator_identifier,
    ACTIONS(12880), 1,
      anon_sym_RPAREN,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15582), 1,
      sym_identifier,
    STATE(15588), 1,
      sym_wildcard,
    STATE(16107), 1,
      sym_binding,
    STATE(11186), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [523461] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [523489] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11352), 1,
      anon_sym_EQ,
    ACTIONS(12737), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [523535] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11189), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(11561), 12,
      anon_sym_COLON,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523565] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8410), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(11190), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 3,
      anon_sym_COLON,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523599] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [523627] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10506), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10504), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523657] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [523685] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(11194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [523715] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11365), 1,
      anon_sym_EQ,
    ACTIONS(12833), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [523761] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 1,
      anon_sym_finally,
    STATE(11196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523795] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10510), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10508), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523825] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11198), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10514), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10512), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523855] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11199), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [523883] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9080), 1,
      anon_sym_LPAREN,
    ACTIONS(12882), 1,
      anon_sym_LBRACK,
    ACTIONS(12884), 1,
      anon_sym_POUND,
    STATE(12005), 1,
      aux_sym_annotation_repeat1,
    STATE(12306), 1,
      sym_type_arguments,
    STATE(13002), 1,
      sym_arguments,
    STATE(11200), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [523923] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [523951] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [523979] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10575), 1,
      sym__backquoted_id,
    STATE(11203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10573), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524009] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524037] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10579), 1,
      sym__backquoted_id,
    STATE(11205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10577), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524067] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10583), 1,
      sym__backquoted_id,
    STATE(11206), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10581), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524097] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11207), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524125] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524153] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524181] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524209] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(12868), 1,
      anon_sym_COLON,
    ACTIONS(12870), 1,
      anon_sym_extends,
    ACTIONS(12872), 1,
      anon_sym_derives,
    ACTIONS(12888), 1,
      sym__automatic_semicolon,
    STATE(11809), 1,
      sym_extends_clause,
    STATE(12831), 1,
      sym_derives_clause,
    STATE(14188), 1,
      sym__definition_body,
    STATE(14313), 1,
      sym_template_body,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11211), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12886), 4,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [524257] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524285] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12893), 1,
      sym__automatic_semicolon,
    STATE(12296), 1,
      sym_access_modifier,
    STATE(12297), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    ACTIONS(12464), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(11213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12891), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [524325] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11214), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 15,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [524353] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11215), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524381] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11216), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [524409] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524437] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11218), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524465] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11219), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524493] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11220), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 11,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524523] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11221), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524551] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 11,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524581] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11223), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 11,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524611] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 15,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [524639] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11225), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12806), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12804), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524669] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11226), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12788), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12786), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524699] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11227), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524727] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524755] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524783] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524811] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11231), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524839] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11232), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524867] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11233), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524895] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11234), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524923] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524951] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7182), 1,
      anon_sym_object,
    ACTIONS(7188), 1,
      anon_sym_class,
    ACTIONS(12848), 1,
      sym__alpha_identifier,
    ACTIONS(12856), 1,
      sym__backquoted_id,
    ACTIONS(12858), 1,
      sym_operator_identifier,
    STATE(12301), 1,
      sym_identifier,
    STATE(13994), 1,
      sym__soft_identifier,
    STATE(14255), 1,
      sym_simple_enum_case,
    STATE(15419), 1,
      sym_full_enum_case,
    STATE(11236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12854), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [524997] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11237), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10031), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525027] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12898), 1,
      sym__automatic_semicolon,
    STATE(12359), 1,
      sym_access_modifier,
    STATE(12361), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    ACTIONS(12464), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(11238), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12896), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [525067] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11239), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10035), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525097] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10041), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525127] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7202), 1,
      anon_sym_object,
    ACTIONS(7204), 1,
      anon_sym_class,
    ACTIONS(12901), 1,
      sym__alpha_identifier,
    ACTIONS(12905), 1,
      sym__backquoted_id,
    ACTIONS(12907), 1,
      sym_operator_identifier,
    STATE(12363), 1,
      sym_identifier,
    STATE(13840), 1,
      sym__soft_identifier,
    STATE(14171), 1,
      sym_simple_enum_case,
    STATE(15167), 1,
      sym_full_enum_case,
    STATE(11241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12903), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [525173] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11242), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10048), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11243), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10052), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525233] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [525261] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12909), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11245), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [525305] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12911), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11246), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [525349] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(12917), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11247), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12915), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [525397] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(12921), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11248), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12919), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [525445] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(12925), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11249), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12923), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [525493] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(12929), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11250), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12927), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [525541] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(12933), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11251), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12931), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [525589] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(12937), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11252), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12935), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [525637] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12939), 1,
      anon_sym_end,
    STATE(5738), 1,
      sym__end_marker,
    STATE(11253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [525669] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11254), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12774), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12772), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525699] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12887), 1,
      aux_sym_compound_type_repeat1,
    STATE(13190), 1,
      sym_template_body,
    STATE(13316), 1,
      sym__refinement,
    STATE(11255), 2,
      sym_comment,
      sym_block_comment,
    STATE(13197), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [525735] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10479), 1,
      anon_sym_LPAREN,
    STATE(11260), 1,
      aux_sym_annotation_repeat1,
    STATE(12060), 1,
      sym_arguments,
    STATE(11256), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [525769] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12941), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11257), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [525813] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12943), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11258), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [525857] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12784), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12782), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525887] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12945), 1,
      anon_sym_LPAREN,
    STATE(12060), 1,
      sym_arguments,
    STATE(11260), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [525919] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12948), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11261), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [525963] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12950), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11262), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [526007] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12954), 1,
      anon_sym_STAR,
    STATE(11263), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [526037] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11264), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8412), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526067] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11238), 1,
      anon_sym_EQ,
    ACTIONS(12754), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11265), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [526113] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11266), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11922), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526143] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11267), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [526171] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11871), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526201] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [526229] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11879), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526259] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12901), 1,
      sym__alpha_identifier,
    ACTIONS(12905), 1,
      sym__backquoted_id,
    ACTIONS(12907), 1,
      sym_operator_identifier,
    ACTIONS(12956), 1,
      anon_sym_object,
    ACTIONS(12958), 1,
      anon_sym_class,
    STATE(12363), 1,
      sym_identifier,
    STATE(13840), 1,
      sym__soft_identifier,
    STATE(14234), 1,
      sym_simple_enum_case,
    STATE(15362), 1,
      sym_full_enum_case,
    STATE(11271), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12903), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [526305] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [526333] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11273), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [526361] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [526389] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7410), 1,
      sym__backquoted_id,
    STATE(11275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8994), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526419] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11276), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [526447] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11839), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526477] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11875), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526507] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11279), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11902), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526537] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11280), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11912), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526567] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11281), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11937), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526597] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9856), 1,
      anon_sym_COLON,
    STATE(11282), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [526627] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11283), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [526655] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11284), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [526683] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12960), 1,
      anon_sym_DOT,
    STATE(11285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [526713] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11286), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [526741] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [526769] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11288), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12802), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12800), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526799] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12831), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12829), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526829] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(11290), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [526859] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 11,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526889] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 2,
      anon_sym_LT_COLON,
      anon_sym_EQ,
    STATE(11292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526923] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12622), 1,
      anon_sym_LBRACK,
    ACTIONS(12624), 1,
      anon_sym_AT,
    ACTIONS(12626), 1,
      anon_sym_POUND,
    ACTIONS(12701), 1,
      anon_sym_LPAREN,
    STATE(11585), 1,
      sym_type_arguments,
    STATE(11588), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12435), 1,
      sym_annotation,
    STATE(14039), 1,
      sym_arguments,
    STATE(11293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_SEMI,
  [526967] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11504), 1,
      anon_sym_EQ,
    ACTIONS(12792), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11294), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [527013] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11508), 1,
      anon_sym_EQ,
    ACTIONS(12741), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11295), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [527059] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12962), 1,
      anon_sym_DOT,
    STATE(11296), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [527089] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11297), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12764), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12762), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527119] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [527147] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11299), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [527175] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11300), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12745), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12743), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527205] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12776), 1,
      anon_sym_LBRACK,
    ACTIONS(12778), 1,
      anon_sym_AT,
    ACTIONS(12780), 1,
      anon_sym_POUND,
    ACTIONS(12816), 1,
      anon_sym_LPAREN,
    STATE(11877), 1,
      sym_type_arguments,
    STATE(12049), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12713), 1,
      sym_annotation,
    STATE(14054), 1,
      sym_arguments,
    STATE(11301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_SEMI,
  [527249] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [527277] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [527305] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11304), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [527333] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(12964), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11305), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12915), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [527381] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10976), 1,
      anon_sym_LPAREN,
    ACTIONS(12622), 1,
      anon_sym_LBRACK,
    ACTIONS(12624), 1,
      anon_sym_AT,
    ACTIONS(12626), 1,
      anon_sym_POUND,
    STATE(9646), 1,
      sym_arguments,
    STATE(11585), 1,
      sym_type_arguments,
    STATE(11588), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12435), 1,
      sym_annotation,
    STATE(11306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_SEMI,
  [527425] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [527453] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11160), 1,
      anon_sym_EQ,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(12729), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [527499] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11168), 1,
      anon_sym_EQ,
    ACTIONS(12766), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [527545] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(12966), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11310), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12919), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [527593] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11311), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [527621] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(12968), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11312), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12923), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [527669] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(12970), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11313), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12927), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [527717] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12972), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11314), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [527761] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(12974), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11315), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12935), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [527809] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10573), 10,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527839] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11317), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10577), 10,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527869] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11318), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10581), 10,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527899] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9924), 1,
      anon_sym_LPAREN,
    ACTIONS(12776), 1,
      anon_sym_LBRACK,
    ACTIONS(12778), 1,
      anon_sym_AT,
    ACTIONS(12780), 1,
      anon_sym_POUND,
    STATE(9085), 1,
      sym_arguments,
    STATE(11877), 1,
      sym_type_arguments,
    STATE(12049), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12713), 1,
      sym_annotation,
    STATE(11319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_SEMI,
  [527943] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12839), 1,
      sym_operator_identifier,
    ACTIONS(12976), 1,
      anon_sym_RPAREN,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15582), 1,
      sym_identifier,
    STATE(15588), 1,
      sym_wildcard,
    STATE(16107), 1,
      sym_binding,
    STATE(11320), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [527989] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11561), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [528019] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12978), 1,
      anon_sym_end,
    STATE(5751), 1,
      sym__end_marker,
    STATE(11322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [528051] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11323), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9291), 12,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [528081] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11217), 1,
      anon_sym_EQ,
    ACTIONS(12812), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11324), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528127] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(11156), 1,
      anon_sym_STAR,
    ACTIONS(11162), 1,
      anon_sym_PIPE,
    ACTIONS(11164), 1,
      sym_operator_identifier,
    ACTIONS(11221), 1,
      anon_sym_EQ,
    ACTIONS(12731), 1,
      anon_sym_COLON,
    STATE(4174), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(11325), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528173] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11326), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [528201] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12980), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11327), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528245] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12982), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11328), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528289] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12984), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11329), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528333] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12986), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11330), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528377] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12988), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11331), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528421] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12990), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11332), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528465] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12992), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11333), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528509] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12994), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11334), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528553] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12996), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11335), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528597] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(12998), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11336), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528641] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13000), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11337), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528685] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13002), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11338), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528729] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13004), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11339), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528773] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13006), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11340), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528817] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13008), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11341), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528861] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13010), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11342), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528905] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13012), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11343), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528949] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13014), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11344), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528993] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13016), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11345), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529037] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13018), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11346), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529081] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11347), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [529109] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13020), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11348), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529153] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13022), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11349), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529197] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13024), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11350), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529241] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13026), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11351), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529285] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13028), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11352), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529329] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13030), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11353), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529373] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13032), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11354), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529417] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13034), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11355), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529461] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13036), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11356), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529505] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13038), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11357), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529549] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [529577] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13040), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11359), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529621] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13042), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11360), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529665] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13044), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11361), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529709] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13046), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11362), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529753] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13048), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11363), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529797] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13050), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11364), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529841] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13052), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11365), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529885] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13054), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11366), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529929] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [529957] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13056), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11368), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530001] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13058), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11369), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530045] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13060), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11370), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530089] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13062), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11371), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530133] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13064), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11372), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530177] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13066), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11373), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530221] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13068), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11374), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530265] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13070), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11375), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530309] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13072), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11376), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530353] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13074), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11377), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530397] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13076), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11378), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530441] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13078), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11379), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530485] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13080), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11380), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530529] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13082), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11381), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530573] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13084), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11382), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530617] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13086), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11383), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530661] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13088), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11384), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530705] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13090), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11385), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530749] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13092), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11386), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530793] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13094), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11387), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530837] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13096), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11388), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530881] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13098), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11389), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530925] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13100), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11390), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530969] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13102), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11391), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531013] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13104), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11392), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531057] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13106), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11393), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531101] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13108), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11394), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531145] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13110), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11395), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531189] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13112), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11396), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531233] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13114), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11397), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531277] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13116), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11398), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531321] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13118), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11399), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531365] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13120), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11400), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531409] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13122), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11401), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531453] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13124), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11402), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531497] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13126), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11403), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531541] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13128), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11404), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531585] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13130), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11405), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531629] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13132), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11406), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531673] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13134), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11407), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531717] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13136), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11408), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531761] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13138), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11409), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531805] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13140), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11410), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531849] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13142), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11411), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531893] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13144), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11412), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531937] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13146), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11413), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531981] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13148), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11414), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532025] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13150), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11415), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532069] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13152), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11416), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532113] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13154), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11417), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532157] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13156), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11418), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532201] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13158), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11419), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532245] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13160), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11420), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532289] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13162), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11421), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532333] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13164), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11422), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532377] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13166), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11423), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532421] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13168), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11424), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532465] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13170), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11425), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532509] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13172), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11426), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532553] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13174), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11427), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532597] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13176), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11428), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532641] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13178), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11429), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532685] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13180), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11430), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532729] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13182), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11431), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532773] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13184), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11432), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532817] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13186), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11433), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532861] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13188), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11434), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532905] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13190), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11435), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532949] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13192), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11436), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532993] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13194), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11437), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533037] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13196), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11438), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533081] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13198), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11439), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533125] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13200), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11440), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533169] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13202), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11441), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533213] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13204), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11442), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533257] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13206), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11443), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533301] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13208), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11444), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533345] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13210), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11445), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533389] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13212), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11446), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533433] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13214), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11447), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533477] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13216), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11448), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533521] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13218), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11449), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533565] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13220), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11450), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533609] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13222), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11451), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533653] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13224), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11452), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533697] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13226), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11453), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533741] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13228), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11454), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533785] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13230), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11455), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533829] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13232), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11456), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533873] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    ACTIONS(13234), 1,
      anon_sym_RBRACK,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11457), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533917] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13236), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11458), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12931), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [533965] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [533992] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15824), 1,
      sym__type_parameter,
    STATE(11460), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [534033] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11461), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10575), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10573), 11,
      anon_sym_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [534062] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13240), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11462), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12915), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [534109] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11463), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10579), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10577), 11,
      anon_sym_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [534138] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(11464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [534167] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [534194] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11466), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [534221] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [534248] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9521), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(11468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 12,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [534277] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(13242), 1,
      anon_sym_COLON,
    ACTIONS(13244), 1,
      anon_sym_extends,
    ACTIONS(13246), 1,
      anon_sym_derives,
    STATE(12218), 1,
      sym_extends_clause,
    STATE(13126), 1,
      sym_derives_clause,
    STATE(14716), 1,
      sym__definition_body,
    STATE(14724), 1,
      sym_template_body,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11469), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12866), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [534322] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [534349] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12253), 1,
      sym__alpha_identifier,
    ACTIONS(12261), 1,
      sym__backquoted_id,
    ACTIONS(13248), 1,
      sym_operator_identifier,
    STATE(11063), 1,
      sym__soft_identifier,
    STATE(13818), 1,
      sym_identifier,
    STATE(16394), 1,
      sym_stable_identifier,
    STATE(11471), 2,
      sym_comment,
      sym_block_comment,
    STATE(13950), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(12257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [534390] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13250), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11472), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12915), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [534437] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13252), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11473), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12923), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [534484] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(13242), 1,
      anon_sym_COLON,
    ACTIONS(13244), 1,
      anon_sym_extends,
    ACTIONS(13246), 1,
      anon_sym_derives,
    ACTIONS(13254), 1,
      sym__automatic_semicolon,
    STATE(12251), 1,
      sym_extends_clause,
    STATE(13078), 1,
      sym_derives_clause,
    STATE(14671), 1,
      sym__definition_body,
    STATE(14724), 1,
      sym_template_body,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12886), 3,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [534531] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12584), 1,
      anon_sym_LPAREN,
    STATE(11483), 1,
      aux_sym_annotation_repeat1,
    STATE(12434), 1,
      sym_arguments,
    STATE(11475), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [534564] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12582), 1,
      anon_sym_AT,
    STATE(11668), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12303), 1,
      sym_annotation,
    STATE(11476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [534597] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [534624] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [534651] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9218), 1,
      anon_sym_LPAREN,
    ACTIONS(13257), 1,
      anon_sym_LBRACK,
    ACTIONS(13259), 1,
      anon_sym_POUND,
    STATE(12188), 1,
      aux_sym_annotation_repeat1,
    STATE(12814), 1,
      sym_type_arguments,
    STATE(13282), 1,
      sym_arguments,
    STATE(11479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [534690] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11480), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [534717] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [534744] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10498), 1,
      sym__backquoted_id,
    STATE(11482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10496), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [534773] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13261), 1,
      anon_sym_LPAREN,
    STATE(12434), 1,
      sym_arguments,
    STATE(11483), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [534804] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11484), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [534831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10502), 1,
      sym__backquoted_id,
    STATE(11485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10500), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [534860] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11486), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [534887] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [534914] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11488), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [534941] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [534968] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11490), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [534995] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [535022] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [535049] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11493), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [535076] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10976), 1,
      anon_sym_LPAREN,
    STATE(11498), 1,
      aux_sym_annotation_repeat1,
    STATE(12204), 1,
      sym_arguments,
    STATE(11494), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [535109] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11495), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10583), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10581), 11,
      anon_sym_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [535138] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10506), 1,
      sym__backquoted_id,
    STATE(11496), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10504), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [535167] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11497), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [535194] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13264), 1,
      anon_sym_LPAREN,
    STATE(12204), 1,
      sym_arguments,
    STATE(11498), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [535225] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10510), 1,
      sym__backquoted_id,
    STATE(11499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10508), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [535254] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10514), 1,
      sym__backquoted_id,
    STATE(11500), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10512), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [535283] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11501), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [535310] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12802), 1,
      sym__backquoted_id,
    STATE(11502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12800), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [535339] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12831), 1,
      sym__backquoted_id,
    STATE(11503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12829), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [535368] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13267), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11504), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12919), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [535415] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11505), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [535442] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [535469] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11507), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [535496] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11508), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [535523] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13269), 1,
      anon_sym_DOT,
    STATE(11509), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [535552] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11510), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [535579] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9318), 1,
      anon_sym_LPAREN,
    ACTIONS(13273), 1,
      anon_sym_LBRACK,
    ACTIONS(13275), 1,
      anon_sym_POUND,
    STATE(12269), 1,
      aux_sym_annotation_repeat1,
    STATE(12641), 1,
      sym_type_arguments,
    STATE(13238), 1,
      sym_arguments,
    STATE(11511), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [535618] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12679), 1,
      anon_sym_LPAREN,
    STATE(11549), 1,
      aux_sym_annotation_repeat1,
    STATE(12267), 1,
      sym_arguments,
    STATE(11512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [535651] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [535678] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13277), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11514), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12923), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [535725] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11515), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [535752] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12764), 1,
      sym__backquoted_id,
    STATE(11516), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12762), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [535781] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12774), 1,
      sym__backquoted_id,
    STATE(11517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12772), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [535810] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 14,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [535837] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11519), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 14,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [535864] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13279), 1,
      anon_sym_DOT,
    STATE(11520), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [535893] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [535920] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11522), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [535947] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11523), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [535974] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [536001] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11525), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536028] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10029), 1,
      sym__backquoted_id,
    STATE(11526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10031), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [536057] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10033), 1,
      sym__backquoted_id,
    STATE(11527), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10035), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [536086] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [536113] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10039), 1,
      sym__backquoted_id,
    STATE(11529), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10041), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [536142] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10046), 1,
      sym__backquoted_id,
    STATE(11530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10048), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [536171] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10050), 1,
      sym__backquoted_id,
    STATE(11531), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10052), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [536200] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11563), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11561), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [536229] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11533), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536256] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11534), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536283] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12745), 1,
      sym__backquoted_id,
    STATE(11535), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12743), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [536312] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536339] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11537), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536366] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536393] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10575), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11539), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10573), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [536422] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10579), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10577), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [536451] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10583), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11541), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10581), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [536480] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536507] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(13281), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(14729), 1,
      sym_identifier,
    STATE(16571), 1,
      sym_stable_identifier,
    STATE(11543), 2,
      sym_comment,
      sym_block_comment,
    STATE(15312), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [536548] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    STATE(11544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12632), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [536577] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12705), 1,
      anon_sym_DOT,
    STATE(11545), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [536606] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8406), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [536635] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 14,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [536662] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [536689] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13283), 1,
      anon_sym_LPAREN,
    STATE(12267), 1,
      sym_arguments,
    STATE(11549), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [536720] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 14,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [536747] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536774] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11552), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13288), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536801] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13290), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536828] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9341), 1,
      anon_sym_LPAREN,
    ACTIONS(13292), 1,
      anon_sym_LBRACK,
    ACTIONS(13294), 1,
      anon_sym_POUND,
    STATE(12351), 1,
      aux_sym_annotation_repeat1,
    STATE(12726), 1,
      sym_type_arguments,
    STATE(13120), 1,
      sym_arguments,
    STATE(11554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [536867] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536894] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13296), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11556), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12927), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [536941] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13298), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536968] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13300), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11558), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12919), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [537015] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11559), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13302), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537042] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11560), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13304), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537069] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11561), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13306), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537096] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11562), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537123] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11563), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13310), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537150] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11564), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13312), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537177] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13316), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(11565), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13314), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537206] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11566), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13319), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537233] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11567), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13321), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537260] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13323), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537287] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13325), 1,
      anon_sym_end,
    STATE(6318), 1,
      sym__end_marker,
    STATE(11569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537318] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13327), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11570), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12931), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [537365] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8410), 1,
      sym__outdent,
    ACTIONS(8412), 1,
      anon_sym_case,
    ACTIONS(8414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(11571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [537400] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11572), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13329), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537427] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13331), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537454] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12622), 1,
      anon_sym_LBRACK,
    ACTIONS(12624), 1,
      anon_sym_AT,
    ACTIONS(12626), 1,
      anon_sym_POUND,
    STATE(11585), 1,
      sym_type_arguments,
    STATE(11588), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12435), 1,
      sym_annotation,
    STATE(11574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [537493] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13333), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537520] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11900), 1,
      sym__backquoted_id,
    STATE(11576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11898), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [537549] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13335), 1,
      anon_sym_AT,
    STATE(12435), 1,
      sym_annotation,
    STATE(11577), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [537580] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13340), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(11578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13338), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537609] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(12868), 1,
      anon_sym_COLON,
    ACTIONS(13343), 1,
      anon_sym_with,
    STATE(9639), 1,
      sym_template_body,
    STATE(9645), 1,
      sym__refinement,
    STATE(9646), 1,
      sym_arguments,
    STATE(12055), 1,
      aux_sym_compound_type_repeat1,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [537652] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11580), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [537679] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [537706] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13347), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(11582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13345), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537735] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8358), 1,
      anon_sym_LBRACE,
    ACTIONS(13350), 1,
      anon_sym_COLON,
    STATE(11788), 1,
      aux_sym_compound_type_repeat1,
    STATE(14052), 1,
      sym__refinement,
    STATE(14054), 1,
      sym_arguments,
    STATE(14106), 1,
      sym_template_body,
    STATE(11583), 2,
      sym_comment,
      sym_block_comment,
    STATE(14051), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [537776] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(13352), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(13350), 1,
      sym_identifier,
    STATE(17813), 1,
      sym_stable_identifier,
    STATE(11584), 2,
      sym_comment,
      sym_block_comment,
    STATE(13750), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [537817] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11585), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [537844] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [537871] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13354), 1,
      anon_sym_DOT,
    STATE(11587), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [537900] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12624), 1,
      anon_sym_AT,
    STATE(11577), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12435), 1,
      sym_annotation,
    STATE(11588), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [537933] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11589), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [537960] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 14,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [537987] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 14,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [538014] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8410), 1,
      sym__backquoted_id,
    STATE(11592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8412), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [538043] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11593), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [538070] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11924), 1,
      sym__backquoted_id,
    STATE(11594), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11922), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [538099] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13356), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11595), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12915), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [538146] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13358), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11596), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12935), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [538193] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [538220] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11873), 1,
      sym__backquoted_id,
    STATE(11598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11871), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [538249] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [538276] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11881), 1,
      sym__backquoted_id,
    STATE(11600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11879), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [538305] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [538332] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(13352), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(13350), 1,
      sym_identifier,
    STATE(17813), 1,
      sym_stable_identifier,
    STATE(11602), 2,
      sym_comment,
      sym_block_comment,
    STATE(13381), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538373] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11603), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [538400] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13360), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11604), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12919), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [538447] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [538474] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11841), 1,
      sym__backquoted_id,
    STATE(11606), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11839), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [538503] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11877), 1,
      sym__backquoted_id,
    STATE(11607), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11875), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [538532] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11904), 1,
      sym__backquoted_id,
    STATE(11608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11902), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [538561] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11914), 1,
      sym__backquoted_id,
    STATE(11609), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11912), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [538590] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11939), 1,
      sym__backquoted_id,
    STATE(11610), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11937), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [538619] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13362), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11611), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12923), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [538666] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13364), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11612), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12927), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [538713] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13366), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11613), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12931), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [538760] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(13281), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(14729), 1,
      sym_identifier,
    STATE(16571), 1,
      sym_stable_identifier,
    STATE(11614), 2,
      sym_comment,
      sym_block_comment,
    STATE(14423), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538801] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8342), 1,
      anon_sym_LBRACE,
    ACTIONS(13368), 1,
      anon_sym_COLON,
    STATE(11934), 1,
      aux_sym_compound_type_repeat1,
    STATE(14039), 1,
      sym_arguments,
    STATE(14081), 1,
      sym_template_body,
    STATE(14082), 1,
      sym__refinement,
    STATE(11615), 2,
      sym_comment,
      sym_block_comment,
    STATE(14130), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [538842] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13370), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11616), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12935), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [538889] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11617), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [538916] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(11618), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [538945] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11619), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [538972] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13372), 1,
      anon_sym_end,
    STATE(6564), 1,
      sym__end_marker,
    STATE(11620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [539003] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13374), 1,
      anon_sym_LBRACK,
    ACTIONS(13376), 1,
      anon_sym_match,
    STATE(5685), 1,
      sym_type_arguments,
    STATE(11621), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [539036] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13374), 1,
      anon_sym_LBRACK,
    STATE(5685), 1,
      sym_type_arguments,
    STATE(11622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 12,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [539067] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13374), 1,
      anon_sym_LBRACK,
    STATE(5685), 1,
      sym_type_arguments,
    STATE(11623), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 12,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [539098] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13374), 1,
      anon_sym_LBRACK,
    ACTIONS(13376), 1,
      anon_sym_match,
    STATE(5685), 1,
      sym_type_arguments,
    STATE(11624), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [539131] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13374), 1,
      anon_sym_LBRACK,
    STATE(5685), 1,
      sym_type_arguments,
    STATE(11625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 12,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [539162] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13374), 1,
      anon_sym_LBRACK,
    STATE(5685), 1,
      sym_type_arguments,
    STATE(11626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 12,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [539193] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13374), 1,
      anon_sym_LBRACK,
    STATE(5685), 1,
      sym_type_arguments,
    STATE(11627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13388), 12,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [539224] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(12839), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15582), 1,
      sym_identifier,
    STATE(15588), 1,
      sym_wildcard,
    STATE(16107), 1,
      sym_binding,
    STATE(11628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539267] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(11629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [539296] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11630), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [539323] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [539350] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [539377] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8855), 1,
      anon_sym_LPAREN,
    STATE(11636), 1,
      aux_sym_annotation_repeat1,
    STATE(12525), 1,
      sym_arguments,
    STATE(11633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [539410] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9856), 1,
      anon_sym_COLON,
    STATE(11634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [539439] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(13242), 1,
      anon_sym_COLON,
    ACTIONS(13390), 1,
      anon_sym_with,
    STATE(8728), 1,
      sym_template_body,
    STATE(8729), 1,
      sym__refinement,
    STATE(9085), 1,
      sym_arguments,
    STATE(12083), 1,
      aux_sym_compound_type_repeat1,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [539482] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13392), 1,
      anon_sym_LPAREN,
    STATE(12525), 1,
      sym_arguments,
    STATE(11636), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [539513] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [539540] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    ACTIONS(13399), 1,
      sym__automatic_semicolon,
    STATE(12541), 1,
      sym_type_parameters,
    STATE(12560), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(11638), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13395), 7,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [539581] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12253), 1,
      sym__alpha_identifier,
    ACTIONS(12261), 1,
      sym__backquoted_id,
    ACTIONS(13248), 1,
      sym_operator_identifier,
    STATE(11063), 1,
      sym__soft_identifier,
    STATE(13818), 1,
      sym_identifier,
    STATE(16394), 1,
      sym_stable_identifier,
    STATE(11639), 2,
      sym_comment,
      sym_block_comment,
    STATE(13821), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(12257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539622] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [539649] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [539676] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11642), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [539703] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [539730] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11644), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [539757] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(11645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [539786] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11646), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [539813] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [539840] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11648), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [539867] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [539894] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12573), 1,
      anon_sym_LPAREN,
    ACTIONS(13401), 1,
      sym__automatic_semicolon,
    STATE(12977), 1,
      sym_access_modifier,
    STATE(12980), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13452), 1,
      sym_class_parameters,
    ACTIONS(12571), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(11650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12891), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [539933] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [539960] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [539987] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13404), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11653), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12935), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [540034] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [540061] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [540088] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12806), 1,
      sym__backquoted_id,
    STATE(11656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12804), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [540117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12788), 1,
      sym__backquoted_id,
    STATE(11657), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12786), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [540146] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [540173] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13406), 1,
      anon_sym_DOT,
    STATE(11659), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [540202] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15051), 1,
      sym__type_parameter,
    STATE(11660), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540243] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15952), 1,
      sym__type_parameter,
    STATE(11661), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540284] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15956), 1,
      sym__type_parameter,
    STATE(11662), 2,
      sym_comment,
      sym_block_comment,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540325] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    ACTIONS(13412), 1,
      anon_sym_LBRACK,
    ACTIONS(13414), 1,
      anon_sym_LT_COLON,
    ACTIONS(13416), 1,
      anon_sym_GT_COLON,
    ACTIONS(13418), 1,
      anon_sym_LT_PERCENT,
    STATE(12343), 1,
      sym_type_parameters,
    STATE(13042), 1,
      sym_lower_bound,
    STATE(13703), 1,
      sym_upper_bound,
    STATE(13705), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14396), 1,
      aux_sym__type_parameter_repeat2,
    STATE(14680), 1,
      sym_view_bound,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(13410), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(11663), 2,
      sym_comment,
      sym_block_comment,
  [540376] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [540403] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13420), 1,
      anon_sym_STAR,
    STATE(11665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [540432] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15001), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540473] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15052), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540514] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13422), 1,
      anon_sym_AT,
    STATE(12303), 1,
      sym_annotation,
    STATE(11668), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [540545] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15078), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11669), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540586] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [540613] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [540640] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12573), 1,
      anon_sym_LPAREN,
    ACTIONS(13425), 1,
      sym__automatic_semicolon,
    STATE(12974), 1,
      sym_access_modifier,
    STATE(12979), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13452), 1,
      sym_class_parameters,
    ACTIONS(12571), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(11672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12896), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [540679] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13428), 1,
      anon_sym_STAR,
    STATE(11673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [540708] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13434), 1,
      sym__indent,
    STATE(11674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13432), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13430), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [540739] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11675), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [540766] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12701), 1,
      anon_sym_LPAREN,
    STATE(11694), 1,
      aux_sym_annotation_repeat1,
    STATE(12369), 1,
      sym_arguments,
    STATE(11676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_SEMI,
  [540799] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [540826] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11678), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [540853] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [540880] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11680), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [540907] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12776), 1,
      anon_sym_LBRACK,
    ACTIONS(12778), 1,
      anon_sym_AT,
    ACTIONS(12780), 1,
      anon_sym_POUND,
    STATE(11877), 1,
      sym_type_arguments,
    STATE(12049), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12713), 1,
      sym_annotation,
    STATE(11681), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [540946] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11682), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [540973] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [541000] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11684), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [541027] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [541054] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11686), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [541081] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [541108] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [541135] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11689), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [541162] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11690), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [541189] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10706), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11691), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10704), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [541218] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10710), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10708), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [541247] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10714), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11693), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10712), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [541276] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13436), 1,
      anon_sym_LPAREN,
    STATE(12369), 1,
      sym_arguments,
    STATE(11694), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_SEMI,
  [541307] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11695), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [541334] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11563), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(11561), 11,
      anon_sym_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [541363] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8410), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(8412), 2,
      anon_sym_COLON,
      anon_sym_LT_PERCENT,
    STATE(11697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [541396] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [541423] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12784), 1,
      sym__backquoted_id,
    STATE(11699), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12782), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [541452] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11700), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [541479] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [541506] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [541533] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11703), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [541560] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10029), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10031), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [541589] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16054), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [541630] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10033), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10035), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [541659] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [541686] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10039), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11708), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10041), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [541715] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10046), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10048), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [541744] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10050), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10052), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [541773] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [541800] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(13441), 1,
      sym_operator_identifier,
    STATE(4192), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(15910), 1,
      sym__arrow_then_type,
    ACTIONS(13439), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(11712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [541841] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13443), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11713), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12927), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [541888] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9856), 1,
      anon_sym_COLON,
    STATE(11714), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [541917] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [541944] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [541971] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [541998] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9208), 1,
      anon_sym_LPAREN,
    ACTIONS(13445), 1,
      anon_sym_LBRACK,
    ACTIONS(13447), 1,
      anon_sym_POUND,
    STATE(12584), 1,
      aux_sym_annotation_repeat1,
    STATE(12864), 1,
      sym_type_arguments,
    STATE(13208), 1,
      sym_arguments,
    STATE(11718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [542037] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    ACTIONS(13449), 1,
      anon_sym_EQ,
    STATE(13520), 1,
      aux_sym_compound_type_repeat1,
    STATE(15878), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    STATE(16693), 1,
      sym_arguments,
    STATE(11719), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(12931), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [542084] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15630), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542125] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15639), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11721), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542166] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15644), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542207] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15649), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542248] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15652), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542289] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15654), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542330] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15656), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11726), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542371] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15660), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542412] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15662), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11728), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542453] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15664), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542494] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15667), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542535] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15671), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542576] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15673), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542617] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15679), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11733), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542658] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15681), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542699] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15685), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11735), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542740] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15690), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542781] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15692), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542822] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15694), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11738), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542863] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15698), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542904] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15700), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542945] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15702), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542986] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15706), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11742), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543027] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15709), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543068] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15712), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543109] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15715), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11745), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543150] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15720), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543191] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15722), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11747), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543232] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15725), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543273] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15728), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11749), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543314] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15730), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11750), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543355] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15734), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543396] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15738), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543437] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15740), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11753), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543478] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15743), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11754), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543519] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15746), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11755), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543560] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15748), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11756), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543601] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15752), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11757), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543642] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15754), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11758), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543683] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15756), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543724] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15759), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543765] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15761), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11761), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543806] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15763), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543847] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15766), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11763), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543888] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15769), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543929] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15772), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11765), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543970] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15774), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11766), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544011] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15778), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11767), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544052] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15781), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11768), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544093] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15784), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544134] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15786), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544175] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15790), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11771), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544216] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15793), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544257] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15796), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11773), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544298] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15799), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544339] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15802), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544380] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15804), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11776), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544421] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15806), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11777), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544462] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15809), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544503] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15811), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544544] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15813), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544585] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15816), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544626] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15819), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544667] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(11178), 1,
      anon_sym__,
    ACTIONS(11188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15822), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544708] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [544735] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [544761] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4312), 1,
      sym__alpha_identifier,
    ACTIONS(4330), 1,
      sym__backquoted_id,
    ACTIONS(13451), 1,
      anon_sym_type,
    ACTIONS(13453), 1,
      sym_operator_identifier,
    STATE(5532), 1,
      sym__soft_identifier,
    STATE(5671), 1,
      sym_identifier,
    STATE(6217), 1,
      sym__type_identifier,
    STATE(11786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4324), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544801] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [544827] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8358), 1,
      anon_sym_LBRACE,
    ACTIONS(13350), 1,
      anon_sym_COLON,
    STATE(13450), 1,
      aux_sym_compound_type_repeat1,
    STATE(14106), 1,
      sym_template_body,
    STATE(14127), 1,
      sym__refinement,
    STATE(11788), 2,
      sym_comment,
      sym_block_comment,
    STATE(14051), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [544865] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(13455), 1,
      anon_sym_type,
    ACTIONS(13457), 1,
      sym_operator_identifier,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(11618), 1,
      sym_identifier,
    STATE(12129), 1,
      sym__type_identifier,
    STATE(11789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544905] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12816), 1,
      anon_sym_LPAREN,
    STATE(11807), 1,
      aux_sym_annotation_repeat1,
    STATE(12747), 1,
      sym_arguments,
    STATE(11790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_SEMI,
  [544937] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [544963] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13461), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13459), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [544991] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [545017] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [545043] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11795), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13465), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13463), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [545071] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [545097] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 13,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [545123] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11798), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 13,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [545149] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13467), 1,
      anon_sym_DOT,
    STATE(11799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [545177] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13471), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13469), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [545205] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [545231] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12241), 1,
      sym__alpha_identifier,
    ACTIONS(12249), 1,
      sym__backquoted_id,
    ACTIONS(13473), 1,
      sym_operator_identifier,
    STATE(10542), 1,
      sym_identifier,
    STATE(11224), 1,
      sym__soft_identifier,
    STATE(11474), 1,
      sym__class_constructor,
    STATE(14487), 1,
      sym__class_definition,
    STATE(11802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12245), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [545271] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12241), 1,
      sym__alpha_identifier,
    ACTIONS(12249), 1,
      sym__backquoted_id,
    ACTIONS(13473), 1,
      sym_operator_identifier,
    STATE(10542), 1,
      sym_identifier,
    STATE(11224), 1,
      sym__soft_identifier,
    STATE(11474), 1,
      sym__class_constructor,
    STATE(14496), 1,
      sym__class_definition,
    STATE(11803), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12245), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [545311] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11804), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [545337] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12253), 1,
      sym__alpha_identifier,
    ACTIONS(12261), 1,
      sym__backquoted_id,
    ACTIONS(13475), 1,
      sym_operator_identifier,
    STATE(11063), 1,
      sym__soft_identifier,
    STATE(12555), 1,
      sym_identifier,
    STATE(12676), 1,
      sym__type_identifier,
    STATE(14336), 1,
      sym__type_constructor,
    STATE(11805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [545377] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11806), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [545403] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13477), 1,
      anon_sym_LPAREN,
    STATE(12747), 1,
      sym_arguments,
    STATE(11807), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_SEMI,
  [545433] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [545459] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(12868), 1,
      anon_sym_COLON,
    ACTIONS(12872), 1,
      anon_sym_derives,
    ACTIONS(13482), 1,
      sym__automatic_semicolon,
    STATE(12838), 1,
      sym_derives_clause,
    STATE(14265), 1,
      sym__definition_body,
    STATE(14313), 1,
      sym_template_body,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11809), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13480), 4,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [545501] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11810), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [545527] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [545553] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4344), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      sym__backquoted_id,
    ACTIONS(13485), 1,
      anon_sym_type,
    ACTIONS(13487), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym_identifier,
    STATE(6290), 1,
      sym__soft_identifier,
    STATE(6838), 1,
      sym__type_identifier,
    STATE(11812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4356), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [545593] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13489), 1,
      anon_sym_STAR,
    STATE(11813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [545621] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11814), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [545647] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11815), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13493), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13491), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [545675] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11816), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [545701] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11817), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12717), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [545727] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11818), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [545753] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [545779] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4408), 1,
      sym__alpha_identifier,
    ACTIONS(4420), 1,
      sym__backquoted_id,
    ACTIONS(13495), 1,
      anon_sym_type,
    ACTIONS(13497), 1,
      sym_operator_identifier,
    STATE(4476), 1,
      sym__soft_identifier,
    STATE(4548), 1,
      sym_identifier,
    STATE(4655), 1,
      sym__type_identifier,
    STATE(11820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4416), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [545819] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13302), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [545845] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(13499), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(10977), 1,
      sym_identifier,
    STATE(12773), 1,
      sym__type_identifier,
    STATE(14224), 1,
      sym__type_constructor,
    STATE(11822), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [545885] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6844), 1,
      sym__backquoted_id,
    ACTIONS(13501), 1,
      anon_sym_type,
    ACTIONS(13503), 1,
      sym_operator_identifier,
    STATE(8809), 1,
      sym__soft_identifier,
    STATE(9078), 1,
      sym_identifier,
    STATE(9417), 1,
      sym__type_identifier,
    STATE(11823), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6840), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [545925] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [545951] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [545977] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11826), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [546003] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11827), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13304), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [546029] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8885), 1,
      sym__alpha_identifier,
    ACTIONS(8893), 1,
      sym__backquoted_id,
    ACTIONS(13505), 1,
      anon_sym_type,
    ACTIONS(13507), 1,
      sym_operator_identifier,
    STATE(8990), 1,
      sym__soft_identifier,
    STATE(9069), 1,
      sym_identifier,
    STATE(9070), 1,
      sym__type_identifier,
    STATE(11828), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8889), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [546069] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4434), 1,
      sym__alpha_identifier,
    ACTIONS(4452), 1,
      sym__backquoted_id,
    ACTIONS(13509), 1,
      anon_sym_type,
    ACTIONS(13511), 1,
      sym_operator_identifier,
    STATE(4833), 1,
      sym_identifier,
    STATE(4948), 1,
      sym__soft_identifier,
    STATE(5117), 1,
      sym__type_identifier,
    STATE(11829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4446), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [546109] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [546135] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4640), 1,
      sym__alpha_identifier,
    ACTIONS(4652), 1,
      sym__backquoted_id,
    ACTIONS(13513), 1,
      anon_sym_type,
    ACTIONS(13515), 1,
      sym_operator_identifier,
    STATE(7734), 1,
      sym_identifier,
    STATE(7872), 1,
      sym__soft_identifier,
    STATE(8626), 1,
      sym__type_identifier,
    STATE(11831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4648), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [546175] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8819), 1,
      sym__alpha_identifier,
    ACTIONS(8827), 1,
      sym__backquoted_id,
    ACTIONS(13517), 1,
      anon_sym_type,
    ACTIONS(13519), 1,
      sym_operator_identifier,
    STATE(6335), 1,
      sym_identifier,
    STATE(6351), 1,
      sym__soft_identifier,
    STATE(6608), 1,
      sym__type_identifier,
    STATE(11832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8823), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [546215] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12690), 1,
      anon_sym_AT,
    STATE(12048), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13003), 1,
      sym_annotation,
    STATE(11833), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [546247] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12268), 1,
      sym__alpha_identifier,
    ACTIONS(12276), 1,
      sym__backquoted_id,
    ACTIONS(13521), 1,
      anon_sym_type,
    ACTIONS(13523), 1,
      sym_operator_identifier,
    STATE(11155), 1,
      sym_identifier,
    STATE(11269), 1,
      sym__soft_identifier,
    STATE(11671), 1,
      sym__type_identifier,
    STATE(11834), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12272), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [546287] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6690), 1,
      sym__alpha_identifier,
    ACTIONS(6704), 1,
      sym__backquoted_id,
    ACTIONS(13525), 1,
      anon_sym_type,
    ACTIONS(13527), 1,
      sym_operator_identifier,
    STATE(5140), 1,
      sym_identifier,
    STATE(5191), 1,
      sym__soft_identifier,
    STATE(5725), 1,
      sym__type_identifier,
    STATE(11835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [546327] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12241), 1,
      sym__alpha_identifier,
    ACTIONS(12249), 1,
      sym__backquoted_id,
    ACTIONS(13529), 1,
      anon_sym_type,
    ACTIONS(13531), 1,
      sym_operator_identifier,
    STATE(11224), 1,
      sym__soft_identifier,
    STATE(11645), 1,
      sym_identifier,
    STATE(11804), 1,
      sym__type_identifier,
    STATE(11836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12245), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [546367] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11837), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [546393] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(11838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [546421] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(13499), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(10977), 1,
      sym_identifier,
    STATE(12773), 1,
      sym__type_identifier,
    STATE(14238), 1,
      sym__type_constructor,
    STATE(11839), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [546461] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(13499), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(10977), 1,
      sym_identifier,
    STATE(13105), 1,
      sym__type_identifier,
    STATE(14544), 1,
      sym__type_constructor,
    STATE(11840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [546501] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [546527] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11842), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [546553] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    ACTIONS(12794), 1,
      anon_sym_EQ,
    STATE(11843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [546583] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    ACTIONS(12752), 1,
      anon_sym_EQ,
    STATE(11844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [546613] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12077), 1,
      sym__alpha_identifier,
    ACTIONS(12085), 1,
      sym__backquoted_id,
    ACTIONS(13533), 1,
      anon_sym_type,
    ACTIONS(13535), 1,
      sym_operator_identifier,
    STATE(11793), 1,
      sym__soft_identifier,
    STATE(11838), 1,
      sym_identifier,
    STATE(12215), 1,
      sym__type_identifier,
    STATE(11845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12081), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [546653] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6712), 1,
      sym__alpha_identifier,
    ACTIONS(6726), 1,
      sym__backquoted_id,
    ACTIONS(13537), 1,
      anon_sym_type,
    ACTIONS(13539), 1,
      sym_operator_identifier,
    STATE(6378), 1,
      sym__soft_identifier,
    STATE(6397), 1,
      sym_identifier,
    STATE(6987), 1,
      sym__type_identifier,
    STATE(11846), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6722), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [546693] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(13499), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(10977), 1,
      sym_identifier,
    STATE(12773), 1,
      sym__type_identifier,
    STATE(14249), 1,
      sym__type_constructor,
    STATE(11847), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [546733] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [546759] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12089), 1,
      sym__alpha_identifier,
    ACTIONS(12097), 1,
      sym__backquoted_id,
    ACTIONS(13541), 1,
      anon_sym_type,
    ACTIONS(13543), 1,
      sym_operator_identifier,
    STATE(12752), 1,
      sym__soft_identifier,
    STATE(12861), 1,
      sym_identifier,
    STATE(13039), 1,
      sym__type_identifier,
    STATE(11849), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12093), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [546799] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13331), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [546825] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [546851] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13333), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [546877] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6740), 1,
      sym__alpha_identifier,
    ACTIONS(6754), 1,
      sym__backquoted_id,
    ACTIONS(13545), 1,
      anon_sym_type,
    ACTIONS(13547), 1,
      sym_operator_identifier,
    STATE(7077), 1,
      sym_identifier,
    STATE(7274), 1,
      sym__soft_identifier,
    STATE(7564), 1,
      sym__type_identifier,
    STATE(11853), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6750), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [546917] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11854), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [546943] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11855), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [546969] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11856), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [546995] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13549), 1,
      anon_sym_LBRACK,
    ACTIONS(13551), 1,
      anon_sym_match,
    STATE(6641), 1,
      sym_type_arguments,
    STATE(11857), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547027] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11858), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13555), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13553), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [547055] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(473), 1,
      sym__alpha_identifier,
    ACTIONS(487), 1,
      anon_sym__,
    ACTIONS(537), 1,
      sym__backquoted_id,
    ACTIONS(13557), 1,
      sym_operator_identifier,
    STATE(5776), 1,
      sym__soft_identifier,
    STATE(11859), 2,
      sym_comment,
      sym_block_comment,
    STATE(14321), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(659), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [547093] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12825), 1,
      anon_sym_LPAREN,
    STATE(11870), 1,
      aux_sym_annotation_repeat1,
    STATE(12835), 1,
      sym_arguments,
    STATE(11860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [547125] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13549), 1,
      anon_sym_LBRACK,
    STATE(6641), 1,
      sym_type_arguments,
    STATE(11861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547155] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13549), 1,
      anon_sym_LBRACK,
    STATE(6641), 1,
      sym_type_arguments,
    STATE(11862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547185] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13549), 1,
      anon_sym_LBRACK,
    ACTIONS(13551), 1,
      anon_sym_match,
    STATE(6641), 1,
      sym_type_arguments,
    STATE(11863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547217] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11864), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [547243] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13549), 1,
      anon_sym_LBRACK,
    STATE(6641), 1,
      sym_type_arguments,
    STATE(11865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547273] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4572), 1,
      sym__alpha_identifier,
    ACTIONS(4590), 1,
      sym__backquoted_id,
    ACTIONS(13559), 1,
      anon_sym_type,
    ACTIONS(13561), 1,
      sym_operator_identifier,
    STATE(4875), 1,
      sym_identifier,
    STATE(5025), 1,
      sym__soft_identifier,
    STATE(5308), 1,
      sym__type_identifier,
    STATE(11866), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [547313] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13549), 1,
      anon_sym_LBRACK,
    STATE(6641), 1,
      sym_type_arguments,
    STATE(11867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547343] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [547369] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13549), 1,
      anon_sym_LBRACK,
    STATE(6641), 1,
      sym_type_arguments,
    STATE(11869), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13388), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547399] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13563), 1,
      anon_sym_LPAREN,
    STATE(12835), 1,
      sym_arguments,
    STATE(11870), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [547429] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12241), 1,
      sym__alpha_identifier,
    ACTIONS(12249), 1,
      sym__backquoted_id,
    ACTIONS(13473), 1,
      sym_operator_identifier,
    STATE(10542), 1,
      sym_identifier,
    STATE(11224), 1,
      sym__soft_identifier,
    STATE(11474), 1,
      sym__class_constructor,
    STATE(14697), 1,
      sym__class_definition,
    STATE(11871), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12245), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [547469] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [547495] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13566), 1,
      anon_sym_LBRACK,
    ACTIONS(13568), 1,
      anon_sym_AT,
    ACTIONS(13570), 1,
      anon_sym_LPAREN,
    ACTIONS(13572), 1,
      anon_sym_POUND,
    STATE(13407), 1,
      sym_type_arguments,
    STATE(13507), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13894), 1,
      sym_annotation,
    STATE(14384), 1,
      sym_arguments,
    STATE(11873), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
  [547537] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13574), 1,
      anon_sym_LBRACK,
    STATE(6201), 1,
      sym_type_arguments,
    STATE(11874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13388), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547567] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [547593] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8555), 1,
      sym__alpha_identifier,
    ACTIONS(8563), 1,
      sym__backquoted_id,
    ACTIONS(13576), 1,
      anon_sym_type,
    ACTIONS(13578), 1,
      sym_operator_identifier,
    STATE(7545), 1,
      sym__type_identifier,
    STATE(7612), 1,
      sym__soft_identifier,
    STATE(7750), 1,
      sym_identifier,
    STATE(11876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8559), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [547633] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11877), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [547659] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11878), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [547685] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(13499), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(10977), 1,
      sym_identifier,
    STATE(13105), 1,
      sym__type_identifier,
    STATE(14471), 1,
      sym__type_constructor,
    STATE(11879), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [547725] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12113), 1,
      sym__alpha_identifier,
    ACTIONS(12121), 1,
      sym__backquoted_id,
    ACTIONS(13580), 1,
      anon_sym_type,
    ACTIONS(13582), 1,
      sym_operator_identifier,
    STATE(11001), 1,
      sym_identifier,
    STATE(11035), 1,
      sym__soft_identifier,
    STATE(11227), 1,
      sym__type_identifier,
    STATE(11880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12117), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [547765] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12229), 1,
      sym__alpha_identifier,
    ACTIONS(12237), 1,
      sym__backquoted_id,
    ACTIONS(13584), 1,
      anon_sym_type,
    ACTIONS(13586), 1,
      sym_operator_identifier,
    STATE(12341), 1,
      sym__soft_identifier,
    STATE(12479), 1,
      sym_identifier,
    STATE(12672), 1,
      sym__type_identifier,
    STATE(11881), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12233), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [547805] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [547831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13316), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(11883), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13314), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547859] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6774), 1,
      sym__alpha_identifier,
    ACTIONS(6784), 1,
      sym__backquoted_id,
    ACTIONS(13588), 1,
      anon_sym_type,
    ACTIONS(13590), 1,
      sym_operator_identifier,
    STATE(4626), 1,
      sym__soft_identifier,
    STATE(4702), 1,
      sym_identifier,
    STATE(4847), 1,
      sym__type_identifier,
    STATE(11884), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6780), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [547899] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11885), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [547925] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12253), 1,
      sym__alpha_identifier,
    ACTIONS(12261), 1,
      sym__backquoted_id,
    ACTIONS(13475), 1,
      sym_operator_identifier,
    STATE(11063), 1,
      sym__soft_identifier,
    STATE(12555), 1,
      sym_identifier,
    STATE(12676), 1,
      sym__type_identifier,
    STATE(14409), 1,
      sym__type_constructor,
    STATE(11886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [547965] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4732), 1,
      sym__alpha_identifier,
    ACTIONS(4750), 1,
      sym__backquoted_id,
    ACTIONS(13592), 1,
      anon_sym_type,
    ACTIONS(13594), 1,
      sym_operator_identifier,
    STATE(6853), 1,
      sym_identifier,
    STATE(7205), 1,
      sym__soft_identifier,
    STATE(7422), 1,
      sym__type_identifier,
    STATE(11887), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4744), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [548005] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(13596), 1,
      sym_operator_identifier,
    STATE(10192), 1,
      sym_identifier,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11211), 1,
      sym__class_constructor,
    STATE(14303), 1,
      sym__class_definition,
    STATE(11888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [548045] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8567), 1,
      sym__alpha_identifier,
    ACTIONS(8575), 1,
      sym__backquoted_id,
    ACTIONS(13598), 1,
      anon_sym_type,
    ACTIONS(13600), 1,
      sym_operator_identifier,
    STATE(8089), 1,
      sym_identifier,
    STATE(8201), 1,
      sym__soft_identifier,
    STATE(8615), 1,
      sym__type_identifier,
    STATE(11889), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8571), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [548085] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [548111] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13574), 1,
      anon_sym_LBRACK,
    ACTIONS(13602), 1,
      anon_sym_match,
    STATE(6201), 1,
      sym_type_arguments,
    STATE(11891), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548143] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13574), 1,
      anon_sym_LBRACK,
    STATE(6201), 1,
      sym_type_arguments,
    STATE(11892), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548173] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13574), 1,
      anon_sym_LBRACK,
    STATE(6201), 1,
      sym_type_arguments,
    STATE(11893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548203] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13574), 1,
      anon_sym_LBRACK,
    ACTIONS(13602), 1,
      anon_sym_match,
    STATE(6201), 1,
      sym_type_arguments,
    STATE(11894), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548235] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13574), 1,
      anon_sym_LBRACK,
    STATE(6201), 1,
      sym_type_arguments,
    STATE(11895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548265] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13574), 1,
      anon_sym_LBRACK,
    STATE(6201), 1,
      sym_type_arguments,
    STATE(11896), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548295] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11897), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [548321] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11898), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [548347] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [548373] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11900), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [548399] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13340), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(11901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13338), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548427] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6114), 1,
      sym__alpha_identifier,
    ACTIONS(6128), 1,
      sym__backquoted_id,
    ACTIONS(13604), 1,
      anon_sym_type,
    ACTIONS(13606), 1,
      sym_operator_identifier,
    STATE(5158), 1,
      sym_identifier,
    STATE(5193), 1,
      sym__soft_identifier,
    STATE(5862), 1,
      sym__type_identifier,
    STATE(11902), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6124), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [548467] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(13608), 1,
      anon_sym_object,
    ACTIONS(13610), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(13681), 1,
      sym_package_identifier,
    STATE(13968), 1,
      sym_identifier,
    STATE(11903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [548507] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [548533] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11905), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548559] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548585] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11907), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548611] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(11908), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [548639] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11909), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [548665] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12127), 1,
      sym__alpha_identifier,
    ACTIONS(12135), 1,
      sym__backquoted_id,
    ACTIONS(13612), 1,
      anon_sym_type,
    ACTIONS(13614), 1,
      sym_operator_identifier,
    STATE(11798), 1,
      sym__soft_identifier,
    STATE(12047), 1,
      sym_identifier,
    STATE(12290), 1,
      sym__type_identifier,
    STATE(11910), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12131), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [548705] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8715), 1,
      sym__alpha_identifier,
    ACTIONS(8723), 1,
      sym__backquoted_id,
    ACTIONS(13616), 1,
      anon_sym_type,
    ACTIONS(13618), 1,
      sym_operator_identifier,
    STATE(6856), 1,
      sym__type_identifier,
    STATE(7174), 1,
      sym__soft_identifier,
    STATE(7252), 1,
      sym_identifier,
    STATE(11911), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8719), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [548745] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4210), 1,
      sym__alpha_identifier,
    ACTIONS(4228), 1,
      sym__backquoted_id,
    ACTIONS(13620), 1,
      anon_sym_type,
    ACTIONS(13622), 1,
      sym_operator_identifier,
    STATE(6365), 1,
      sym_identifier,
    STATE(6658), 1,
      sym__soft_identifier,
    STATE(7061), 1,
      sym__type_identifier,
    STATE(11912), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4222), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [548785] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4602), 1,
      sym__alpha_identifier,
    ACTIONS(4620), 1,
      sym__backquoted_id,
    ACTIONS(13624), 1,
      anon_sym_type,
    ACTIONS(13626), 1,
      sym_operator_identifier,
    STATE(5167), 1,
      sym_identifier,
    STATE(5195), 1,
      sym__soft_identifier,
    STATE(5899), 1,
      sym__type_identifier,
    STATE(11913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [548825] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11914), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [548851] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(12868), 1,
      anon_sym_COLON,
    ACTIONS(12872), 1,
      anon_sym_derives,
    STATE(13008), 1,
      sym_derives_clause,
    STATE(14313), 1,
      sym_template_body,
    STATE(14328), 1,
      sym__definition_body,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13628), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [548891] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548917] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(13630), 1,
      anon_sym_type,
    ACTIONS(13632), 1,
      sym_operator_identifier,
    STATE(5484), 1,
      sym_identifier,
    STATE(5538), 1,
      sym__soft_identifier,
    STATE(6550), 1,
      sym__type_identifier,
    STATE(11917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [548957] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(13634), 1,
      anon_sym_type,
    ACTIONS(13636), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(4245), 1,
      sym_identifier,
    STATE(4249), 1,
      sym__type_identifier,
    STATE(11918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [548997] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [549023] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [549049] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4770), 1,
      sym__alpha_identifier,
    ACTIONS(4782), 1,
      sym__backquoted_id,
    ACTIONS(13638), 1,
      anon_sym_type,
    ACTIONS(13640), 1,
      sym_operator_identifier,
    STATE(4384), 1,
      sym_identifier,
    STATE(4399), 1,
      sym__soft_identifier,
    STATE(4533), 1,
      sym__type_identifier,
    STATE(11921), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4778), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [549089] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12139), 1,
      sym__alpha_identifier,
    ACTIONS(12147), 1,
      sym__backquoted_id,
    ACTIONS(13642), 1,
      anon_sym_type,
    ACTIONS(13644), 1,
      sym_operator_identifier,
    STATE(12339), 1,
      sym_identifier,
    STATE(12413), 1,
      sym__soft_identifier,
    STATE(12984), 1,
      sym__type_identifier,
    STATE(11922), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12143), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [549129] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(13596), 1,
      sym_operator_identifier,
    STATE(10192), 1,
      sym_identifier,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11211), 1,
      sym__class_constructor,
    STATE(14296), 1,
      sym__class_definition,
    STATE(11923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [549169] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8487), 1,
      sym__alpha_identifier,
    ACTIONS(8495), 1,
      sym__backquoted_id,
    ACTIONS(13646), 1,
      anon_sym_type,
    ACTIONS(13648), 1,
      sym_operator_identifier,
    STATE(7398), 1,
      sym__type_identifier,
    STATE(7616), 1,
      sym__soft_identifier,
    STATE(7782), 1,
      sym_identifier,
    STATE(11924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8491), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [549209] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    ACTIONS(12747), 1,
      anon_sym_EQ,
    STATE(11925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [549239] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    ACTIONS(12798), 1,
      anon_sym_EQ,
    STATE(11926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [549269] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12241), 1,
      sym__alpha_identifier,
    ACTIONS(12249), 1,
      sym__backquoted_id,
    ACTIONS(13473), 1,
      sym_operator_identifier,
    STATE(10542), 1,
      sym_identifier,
    STATE(11224), 1,
      sym__soft_identifier,
    STATE(11474), 1,
      sym__class_constructor,
    STATE(14505), 1,
      sym__class_definition,
    STATE(11927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12245), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [549309] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13650), 1,
      anon_sym_end,
    STATE(6803), 1,
      sym__end_marker,
    STATE(11928), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [549339] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549365] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549391] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13654), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13652), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [549419] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(13656), 1,
      anon_sym_type,
    ACTIONS(13658), 1,
      sym_operator_identifier,
    STATE(7812), 1,
      sym_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(8330), 1,
      sym__type_identifier,
    STATE(11932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [549459] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549485] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8342), 1,
      anon_sym_LBRACE,
    ACTIONS(13368), 1,
      anon_sym_COLON,
    STATE(13593), 1,
      aux_sym_compound_type_repeat1,
    STATE(14081), 1,
      sym_template_body,
    STATE(14090), 1,
      sym__refinement,
    STATE(11934), 2,
      sym_comment,
      sym_block_comment,
    STATE(14130), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [549523] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11935), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549549] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [549575] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11937), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549601] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6322), 1,
      sym__alpha_identifier,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(13660), 1,
      anon_sym_type,
    ACTIONS(13662), 1,
      sym_operator_identifier,
    STATE(7194), 1,
      sym_identifier,
    STATE(7267), 1,
      sym__soft_identifier,
    STATE(7726), 1,
      sym__type_identifier,
    STATE(11938), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [549641] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [549667] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11940), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549693] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9856), 1,
      anon_sym_COLON,
    STATE(11941), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549721] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11942), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549747] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6388), 1,
      sym__alpha_identifier,
    ACTIONS(6402), 1,
      sym__backquoted_id,
    ACTIONS(13664), 1,
      anon_sym_type,
    ACTIONS(13666), 1,
      sym_operator_identifier,
    STATE(6438), 1,
      sym_identifier,
    STATE(6548), 1,
      sym__soft_identifier,
    STATE(7136), 1,
      sym__type_identifier,
    STATE(11943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6398), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [549787] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9515), 1,
      anon_sym_LPAREN,
    ACTIONS(13668), 1,
      anon_sym_LBRACK,
    ACTIONS(13670), 1,
      anon_sym_POUND,
    STATE(12953), 1,
      aux_sym_annotation_repeat1,
    STATE(13210), 1,
      sym_type_arguments,
    STATE(13355), 1,
      sym_arguments,
    STATE(11944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [549825] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12636), 1,
      anon_sym_EQ,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    STATE(11945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [549855] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4664), 1,
      sym__alpha_identifier,
    ACTIONS(4682), 1,
      sym__backquoted_id,
    ACTIONS(13672), 1,
      anon_sym_type,
    ACTIONS(13674), 1,
      sym_operator_identifier,
    STATE(5176), 1,
      sym__soft_identifier,
    STATE(5201), 1,
      sym_identifier,
    STATE(5855), 1,
      sym__type_identifier,
    STATE(11946), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4676), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [549895] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(13676), 1,
      anon_sym_type,
    ACTIONS(13678), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(10875), 1,
      sym_identifier,
    STATE(11094), 1,
      sym__type_identifier,
    STATE(11947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [549935] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [549961] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11949), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549987] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [550013] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [550039] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13682), 1,
      anon_sym_COMMA,
    ACTIONS(13684), 1,
      anon_sym_with,
    STATE(12705), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(12707), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(11952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13680), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [550073] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13288), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [550099] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    ACTIONS(12790), 1,
      anon_sym_EQ,
    STATE(11954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [550129] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8465), 1,
      sym__alpha_identifier,
    ACTIONS(8477), 1,
      sym__backquoted_id,
    ACTIONS(13686), 1,
      anon_sym_type,
    ACTIONS(13688), 1,
      sym_operator_identifier,
    STATE(5699), 1,
      sym__soft_identifier,
    STATE(5793), 1,
      sym_identifier,
    STATE(5929), 1,
      sym__type_identifier,
    STATE(11955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8473), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550169] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13290), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [550195] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11957), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13319), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [550221] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11958), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [550247] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6370), 1,
      sym__alpha_identifier,
    ACTIONS(6384), 1,
      sym__backquoted_id,
    ACTIONS(13690), 1,
      anon_sym_type,
    ACTIONS(13692), 1,
      sym_operator_identifier,
    STATE(5485), 1,
      sym__soft_identifier,
    STATE(5667), 1,
      sym_identifier,
    STATE(6632), 1,
      sym__type_identifier,
    STATE(11959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6380), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550287] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8579), 1,
      sym__alpha_identifier,
    ACTIONS(8591), 1,
      sym__backquoted_id,
    ACTIONS(13694), 1,
      anon_sym_type,
    ACTIONS(13696), 1,
      sym_operator_identifier,
    STATE(5231), 1,
      sym__soft_identifier,
    STATE(5382), 1,
      sym__type_identifier,
    STATE(5422), 1,
      sym_identifier,
    STATE(11960), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8587), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550327] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    ACTIONS(12821), 1,
      anon_sym_EQ,
    STATE(11961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [550357] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11962), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [550383] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6760), 1,
      sym__alpha_identifier,
    ACTIONS(6770), 1,
      sym__backquoted_id,
    ACTIONS(13698), 1,
      anon_sym_type,
    ACTIONS(13700), 1,
      sym_operator_identifier,
    STATE(4880), 1,
      sym_identifier,
    STATE(4925), 1,
      sym__soft_identifier,
    STATE(5235), 1,
      sym__type_identifier,
    STATE(11963), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6766), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550423] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(13702), 1,
      anon_sym_type,
    ACTIONS(13704), 1,
      sym_operator_identifier,
    STATE(6007), 1,
      sym_identifier,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(7040), 1,
      sym__type_identifier,
    STATE(11964), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550463] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13706), 1,
      anon_sym_LBRACK,
    ACTIONS(13708), 1,
      anon_sym_LPAREN,
    ACTIONS(13710), 1,
      sym__automatic_semicolon,
    STATE(12803), 1,
      sym_type_parameters,
    STATE(12806), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13652), 1,
      sym_parameters,
    STATE(13782), 1,
      sym__using_parameters_clause,
    STATE(11965), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13395), 6,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [550503] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11966), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [550529] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11967), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [550555] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4286), 1,
      sym__alpha_identifier,
    ACTIONS(4298), 1,
      sym__backquoted_id,
    ACTIONS(13712), 1,
      anon_sym_type,
    ACTIONS(13714), 1,
      sym_operator_identifier,
    STATE(4467), 1,
      sym__soft_identifier,
    STATE(4549), 1,
      sym_identifier,
    STATE(4705), 1,
      sym__type_identifier,
    STATE(11968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4294), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550595] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    ACTIONS(12709), 1,
      anon_sym_EQ,
    STATE(11969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [550625] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    ACTIONS(12711), 1,
      anon_sym_EQ,
    STATE(11970), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [550655] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4794), 1,
      sym__alpha_identifier,
    ACTIONS(4806), 1,
      sym__backquoted_id,
    ACTIONS(13716), 1,
      anon_sym_type,
    ACTIONS(13718), 1,
      sym_operator_identifier,
    STATE(4605), 1,
      sym__soft_identifier,
    STATE(4738), 1,
      sym_identifier,
    STATE(4773), 1,
      sym__type_identifier,
    STATE(11971), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4802), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550695] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11972), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [550721] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym__alpha_identifier,
    ACTIONS(6470), 1,
      sym__backquoted_id,
    ACTIONS(13720), 1,
      anon_sym_type,
    ACTIONS(13722), 1,
      sym_operator_identifier,
    STATE(6302), 1,
      sym_identifier,
    STATE(6313), 1,
      sym__soft_identifier,
    STATE(6873), 1,
      sym__type_identifier,
    STATE(11973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6466), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550761] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(13499), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(10977), 1,
      sym_identifier,
    STATE(12773), 1,
      sym__type_identifier,
    STATE(14207), 1,
      sym__type_constructor,
    STATE(11974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550801] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(13724), 1,
      anon_sym_type,
    ACTIONS(13726), 1,
      sym_operator_identifier,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(5005), 1,
      sym_identifier,
    STATE(5394), 1,
      sym__type_identifier,
    STATE(11975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550841] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(830), 1,
      sym__alpha_identifier,
    ACTIONS(836), 1,
      anon_sym__,
    ACTIONS(860), 1,
      sym__backquoted_id,
    ACTIONS(13728), 1,
      sym_operator_identifier,
    STATE(5706), 1,
      sym__soft_identifier,
    STATE(11976), 2,
      sym_comment,
      sym_block_comment,
    STATE(16118), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(840), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550879] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9064), 1,
      anon_sym_LPAREN,
    STATE(11982), 1,
      aux_sym_annotation_repeat1,
    STATE(12652), 1,
      sym_arguments,
    STATE(11977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [550911] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11978), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [550937] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11979), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [550963] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11980), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [550989] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6588), 1,
      sym__backquoted_id,
    ACTIONS(13730), 1,
      anon_sym_type,
    ACTIONS(13732), 1,
      sym_operator_identifier,
    STATE(6199), 1,
      sym__soft_identifier,
    STATE(6536), 1,
      sym_identifier,
    STATE(7195), 1,
      sym__type_identifier,
    STATE(11981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [551029] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13734), 1,
      anon_sym_LPAREN,
    STATE(12652), 1,
      sym_arguments,
    STATE(11982), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [551059] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [551085] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [551111] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13288), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551137] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13290), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551163] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [551189] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9549), 1,
      anon_sym_LPAREN,
    ACTIONS(13737), 1,
      anon_sym_LBRACK,
    ACTIONS(13739), 1,
      anon_sym_POUND,
    STATE(12828), 1,
      aux_sym_annotation_repeat1,
    STATE(13274), 1,
      sym_type_arguments,
    STATE(13446), 1,
      sym_arguments,
    STATE(11988), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [551227] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11989), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551253] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6614), 1,
      sym__backquoted_id,
    ACTIONS(13741), 1,
      anon_sym_type,
    ACTIONS(13743), 1,
      sym_operator_identifier,
    STATE(5817), 1,
      sym__soft_identifier,
    STATE(5938), 1,
      sym_identifier,
    STATE(6439), 1,
      sym__type_identifier,
    STATE(11990), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6610), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [551293] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [551319] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12640), 1,
      sym__backquoted_id,
    ACTIONS(12644), 1,
      anon_sym_EQ,
    STATE(11992), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12632), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [551349] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13745), 1,
      anon_sym_LPAREN,
    STATE(12735), 1,
      sym_arguments,
    STATE(11993), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [551379] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11994), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [551405] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [551431] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11996), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13298), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551457] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6792), 1,
      sym__alpha_identifier,
    ACTIONS(6802), 1,
      sym__backquoted_id,
    ACTIONS(13748), 1,
      anon_sym_type,
    ACTIONS(13750), 1,
      sym_operator_identifier,
    STATE(8149), 1,
      sym__soft_identifier,
    STATE(8530), 1,
      sym_identifier,
    STATE(9171), 1,
      sym__type_identifier,
    STATE(11997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6798), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [551497] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551523] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13306), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551549] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13752), 1,
      anon_sym_STAR,
    STATE(12000), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [551577] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(9006), 1,
      sym_operator_identifier,
    STATE(14559), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    ACTIONS(9004), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(12001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8056), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [551615] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12002), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13310), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551641] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13312), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551667] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13316), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13314), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551695] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9080), 1,
      anon_sym_LPAREN,
    STATE(12023), 1,
      aux_sym_annotation_repeat1,
    STATE(13002), 1,
      sym_arguments,
    STATE(12005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [551727] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12006), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13319), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551753] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [551779] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12008), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [551805] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13321), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551831] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [551857] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(13754), 1,
      anon_sym_type,
    ACTIONS(13756), 1,
      sym_operator_identifier,
    STATE(7680), 1,
      sym__soft_identifier,
    STATE(8005), 1,
      sym_identifier,
    STATE(8356), 1,
      sym__type_identifier,
    STATE(12011), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [551897] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12012), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13323), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551923] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12013), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [551949] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12014), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [551975] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12015), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [552001] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4820), 1,
      sym__alpha_identifier,
    ACTIONS(4838), 1,
      sym__backquoted_id,
    ACTIONS(13758), 1,
      anon_sym_type,
    ACTIONS(13760), 1,
      sym_operator_identifier,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(4623), 1,
      sym_identifier,
    STATE(4801), 1,
      sym__type_identifier,
    STATE(12016), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4832), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552041] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6482), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      sym__backquoted_id,
    ACTIONS(13762), 1,
      anon_sym_type,
    ACTIONS(13764), 1,
      sym_operator_identifier,
    STATE(6064), 1,
      sym_identifier,
    STATE(6416), 1,
      sym__soft_identifier,
    STATE(7096), 1,
      sym__type_identifier,
    STATE(12017), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6488), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552081] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6192), 1,
      sym__alpha_identifier,
    ACTIONS(6206), 1,
      sym__backquoted_id,
    ACTIONS(13766), 1,
      anon_sym_type,
    ACTIONS(13768), 1,
      sym_operator_identifier,
    STATE(5516), 1,
      sym__soft_identifier,
    STATE(5845), 1,
      sym_identifier,
    STATE(6624), 1,
      sym__type_identifier,
    STATE(12018), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6202), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552121] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12019), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13329), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [552147] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [552173] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8595), 1,
      sym__alpha_identifier,
    ACTIONS(8603), 1,
      sym__backquoted_id,
    ACTIONS(13770), 1,
      anon_sym_type,
    ACTIONS(13772), 1,
      sym_operator_identifier,
    STATE(6470), 1,
      sym__soft_identifier,
    STATE(6512), 1,
      sym__type_identifier,
    STATE(6614), 1,
      sym_identifier,
    STATE(12021), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8599), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552213] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13347), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13345), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [552241] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13774), 1,
      anon_sym_LPAREN,
    STATE(13002), 1,
      sym_arguments,
    STATE(12023), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [552271] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12253), 1,
      sym__alpha_identifier,
    ACTIONS(12261), 1,
      sym__backquoted_id,
    ACTIONS(13475), 1,
      sym_operator_identifier,
    STATE(11063), 1,
      sym__soft_identifier,
    STATE(12555), 1,
      sym_identifier,
    STATE(12676), 1,
      sym__type_identifier,
    STATE(14242), 1,
      sym__type_constructor,
    STATE(12024), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552311] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8280), 1,
      sym__alpha_identifier,
    ACTIONS(8292), 1,
      sym__backquoted_id,
    ACTIONS(13777), 1,
      anon_sym_type,
    ACTIONS(13779), 1,
      sym_operator_identifier,
    STATE(11176), 1,
      sym__soft_identifier,
    STATE(11194), 1,
      sym_identifier,
    STATE(11644), 1,
      sym__type_identifier,
    STATE(12025), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552351] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [552377] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11960), 1,
      sym__alpha_identifier,
    ACTIONS(11968), 1,
      sym__backquoted_id,
    ACTIONS(13781), 1,
      anon_sym_type,
    ACTIONS(13783), 1,
      sym_operator_identifier,
    STATE(12193), 1,
      sym_identifier,
    STATE(12387), 1,
      sym__soft_identifier,
    STATE(12702), 1,
      sym__type_identifier,
    STATE(12027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11964), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552417] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13331), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [552443] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13333), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [552469] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9563), 1,
      anon_sym_LPAREN,
    ACTIONS(13785), 1,
      anon_sym_LBRACK,
    ACTIONS(13787), 1,
      anon_sym_POUND,
    STATE(12758), 1,
      aux_sym_annotation_repeat1,
    STATE(13112), 1,
      sym_type_arguments,
    STATE(13575), 1,
      sym_arguments,
    STATE(12030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [552507] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13340), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13338), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [552535] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4376), 1,
      sym__alpha_identifier,
    ACTIONS(4394), 1,
      sym__backquoted_id,
    ACTIONS(13789), 1,
      anon_sym_type,
    ACTIONS(13791), 1,
      sym_operator_identifier,
    STATE(5049), 1,
      sym__soft_identifier,
    STATE(5458), 1,
      sym_identifier,
    STATE(5930), 1,
      sym__type_identifier,
    STATE(12032), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552575] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [552601] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(13499), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(10977), 1,
      sym_identifier,
    STATE(13105), 1,
      sym__type_identifier,
    STATE(14454), 1,
      sym__type_constructor,
    STATE(12034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552641] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13347), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13345), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [552669] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(13596), 1,
      sym_operator_identifier,
    STATE(10192), 1,
      sym_identifier,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11211), 1,
      sym__class_constructor,
    STATE(14226), 1,
      sym__class_definition,
    STATE(12036), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552709] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12037), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [552735] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13795), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13793), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [552763] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8607), 1,
      sym__alpha_identifier,
    ACTIONS(8615), 1,
      sym__backquoted_id,
    ACTIONS(13797), 1,
      anon_sym_type,
    ACTIONS(13799), 1,
      sym_operator_identifier,
    STATE(6383), 1,
      sym__soft_identifier,
    STATE(6557), 1,
      sym__type_identifier,
    STATE(6654), 1,
      sym_identifier,
    STATE(12039), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8611), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552803] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13801), 1,
      anon_sym_end,
    STATE(6911), 1,
      sym__end_marker,
    STATE(12040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [552833] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [552859] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6252), 1,
      sym__alpha_identifier,
    ACTIONS(6266), 1,
      sym__backquoted_id,
    ACTIONS(13803), 1,
      anon_sym_type,
    ACTIONS(13805), 1,
      sym_operator_identifier,
    STATE(5492), 1,
      sym__soft_identifier,
    STATE(5587), 1,
      sym_identifier,
    STATE(6158), 1,
      sym__type_identifier,
    STATE(12042), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6262), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552899] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4138), 1,
      sym__alpha_identifier,
    ACTIONS(4156), 1,
      sym__backquoted_id,
    ACTIONS(13807), 1,
      anon_sym_type,
    ACTIONS(13809), 1,
      sym_operator_identifier,
    STATE(6041), 1,
      sym__soft_identifier,
    STATE(6152), 1,
      sym_identifier,
    STATE(7316), 1,
      sym__type_identifier,
    STATE(12043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4150), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552939] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(13811), 1,
      anon_sym_type,
    ACTIONS(13813), 1,
      sym_operator_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(6491), 1,
      sym_identifier,
    STATE(6726), 1,
      sym__type_identifier,
    STATE(12044), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552979] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8909), 1,
      sym__alpha_identifier,
    ACTIONS(8917), 1,
      sym__backquoted_id,
    ACTIONS(13815), 1,
      anon_sym_type,
    ACTIONS(13817), 1,
      sym_operator_identifier,
    STATE(6699), 1,
      sym__soft_identifier,
    STATE(6814), 1,
      sym_identifier,
    STATE(7332), 1,
      sym__type_identifier,
    STATE(12045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8913), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553019] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4468), 1,
      sym__alpha_identifier,
    ACTIONS(4486), 1,
      sym__backquoted_id,
    ACTIONS(13819), 1,
      anon_sym_type,
    ACTIONS(13821), 1,
      sym_operator_identifier,
    STATE(6759), 1,
      sym__soft_identifier,
    STATE(6845), 1,
      sym_identifier,
    STATE(8029), 1,
      sym__type_identifier,
    STATE(12046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4480), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553059] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(12047), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [553087] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13823), 1,
      anon_sym_AT,
    STATE(13003), 1,
      sym_annotation,
    STATE(12048), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [553117] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12778), 1,
      anon_sym_AT,
    STATE(12115), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12713), 1,
      sym_annotation,
    STATE(12049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [553149] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8625), 1,
      sym__alpha_identifier,
    ACTIONS(8633), 1,
      sym__backquoted_id,
    ACTIONS(13826), 1,
      anon_sym_type,
    ACTIONS(13828), 1,
      sym_operator_identifier,
    STATE(8303), 1,
      sym__soft_identifier,
    STATE(8359), 1,
      sym_identifier,
    STATE(8652), 1,
      sym__type_identifier,
    STATE(12050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8629), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553189] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [553215] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13321), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [553241] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(13830), 1,
      anon_sym_type,
    ACTIONS(13832), 1,
      sym_operator_identifier,
    STATE(6831), 1,
      sym_identifier,
    STATE(6834), 1,
      sym__soft_identifier,
    STATE(8081), 1,
      sym__type_identifier,
    STATE(12053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553281] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(13596), 1,
      sym_operator_identifier,
    STATE(10192), 1,
      sym_identifier,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11211), 1,
      sym__class_constructor,
    STATE(14343), 1,
      sym__class_definition,
    STATE(12054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553321] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(12868), 1,
      anon_sym_COLON,
    ACTIONS(13343), 1,
      anon_sym_with,
    STATE(9450), 1,
      sym__refinement,
    STATE(9639), 1,
      sym_template_body,
    STATE(13593), 1,
      aux_sym_compound_type_repeat1,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [553361] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12056), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13836), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13834), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [553389] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12199), 1,
      sym__alpha_identifier,
    ACTIONS(12207), 1,
      sym__backquoted_id,
    ACTIONS(13838), 1,
      anon_sym_type,
    ACTIONS(13840), 1,
      sym_operator_identifier,
    STATE(10957), 1,
      sym__soft_identifier,
    STATE(11022), 1,
      sym_identifier,
    STATE(11191), 1,
      sym__type_identifier,
    STATE(12057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12203), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553429] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [553455] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [553481] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [553507] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [553533] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [553559] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4852), 1,
      sym__alpha_identifier,
    ACTIONS(4870), 1,
      sym__backquoted_id,
    ACTIONS(13842), 1,
      anon_sym_type,
    ACTIONS(13844), 1,
      sym_operator_identifier,
    STATE(5519), 1,
      sym__soft_identifier,
    STATE(5889), 1,
      sym_identifier,
    STATE(6170), 1,
      sym__type_identifier,
    STATE(12063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4864), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553599] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8637), 1,
      sym__alpha_identifier,
    ACTIONS(8649), 1,
      sym__backquoted_id,
    ACTIONS(13846), 1,
      anon_sym_type,
    ACTIONS(13848), 1,
      sym_operator_identifier,
    STATE(9867), 1,
      sym__soft_identifier,
    STATE(9998), 1,
      sym__type_identifier,
    STATE(10047), 1,
      sym_identifier,
    STATE(12064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8645), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553639] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12065), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [553665] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9856), 1,
      anon_sym_COLON,
    STATE(12066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [553693] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [553719] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(13850), 1,
      anon_sym_type,
    ACTIONS(13852), 1,
      sym_operator_identifier,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11290), 1,
      sym_identifier,
    STATE(11593), 1,
      sym__type_identifier,
    STATE(12068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553759] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(25), 1,
      anon_sym__,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(13854), 1,
      sym_operator_identifier,
    STATE(4512), 1,
      sym__soft_identifier,
    STATE(12069), 2,
      sym_comment,
      sym_block_comment,
    STATE(14043), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553797] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8653), 1,
      sym__alpha_identifier,
    ACTIONS(8665), 1,
      sym__backquoted_id,
    ACTIONS(13856), 1,
      anon_sym_type,
    ACTIONS(13858), 1,
      sym_operator_identifier,
    STATE(4573), 1,
      sym__type_identifier,
    STATE(4711), 1,
      sym_identifier,
    STATE(4727), 1,
      sym__soft_identifier,
    STATE(12070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8661), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553837] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13302), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [553863] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13304), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [553889] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13566), 1,
      anon_sym_LBRACK,
    ACTIONS(13568), 1,
      anon_sym_AT,
    ACTIONS(13572), 1,
      anon_sym_POUND,
    ACTIONS(13860), 1,
      anon_sym_LPAREN,
    STATE(13407), 1,
      sym_type_arguments,
    STATE(13507), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13894), 1,
      sym_annotation,
    STATE(14156), 1,
      sym_arguments,
    STATE(12073), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
  [553931] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(13862), 1,
      anon_sym_type,
    ACTIONS(13864), 1,
      sym_operator_identifier,
    STATE(5204), 1,
      sym_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(5912), 1,
      sym__type_identifier,
    STATE(12074), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553971] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12101), 1,
      sym__alpha_identifier,
    ACTIONS(12109), 1,
      sym__backquoted_id,
    ACTIONS(13866), 1,
      anon_sym_type,
    ACTIONS(13868), 1,
      sym_operator_identifier,
    STATE(10860), 1,
      sym_identifier,
    STATE(10865), 1,
      sym__soft_identifier,
    STATE(11045), 1,
      sym__type_identifier,
    STATE(12075), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12105), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554011] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4510), 1,
      sym__alpha_identifier,
    ACTIONS(4522), 1,
      sym__backquoted_id,
    ACTIONS(13870), 1,
      anon_sym_type,
    ACTIONS(13872), 1,
      sym_operator_identifier,
    STATE(4572), 1,
      sym__soft_identifier,
    STATE(4720), 1,
      sym_identifier,
    STATE(4952), 1,
      sym__type_identifier,
    STATE(12076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4518), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554051] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12241), 1,
      sym__alpha_identifier,
    ACTIONS(12249), 1,
      sym__backquoted_id,
    ACTIONS(13473), 1,
      sym_operator_identifier,
    STATE(10542), 1,
      sym_identifier,
    STATE(11224), 1,
      sym__soft_identifier,
    STATE(11474), 1,
      sym__class_constructor,
    STATE(14629), 1,
      sym__class_definition,
    STATE(12077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12245), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554091] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12078), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [554117] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8735), 1,
      sym__alpha_identifier,
    ACTIONS(8743), 1,
      sym__backquoted_id,
    ACTIONS(13874), 1,
      anon_sym_type,
    ACTIONS(13876), 1,
      sym_operator_identifier,
    STATE(5520), 1,
      sym__soft_identifier,
    STATE(5813), 1,
      sym__type_identifier,
    STATE(5916), 1,
      sym_identifier,
    STATE(12079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8739), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554157] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [554183] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12081), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [554209] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8669), 1,
      sym__alpha_identifier,
    ACTIONS(8681), 1,
      sym__backquoted_id,
    ACTIONS(13878), 1,
      anon_sym_type,
    ACTIONS(13880), 1,
      sym_operator_identifier,
    STATE(5137), 1,
      sym__soft_identifier,
    STATE(5146), 1,
      sym__type_identifier,
    STATE(5456), 1,
      sym_identifier,
    STATE(12082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8677), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554249] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(13242), 1,
      anon_sym_COLON,
    ACTIONS(13390), 1,
      anon_sym_with,
    STATE(8728), 1,
      sym_template_body,
    STATE(8733), 1,
      sym__refinement,
    STATE(13450), 1,
      aux_sym_compound_type_repeat1,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12083), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8252), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [554289] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12713), 1,
      anon_sym_LPAREN,
    STATE(11993), 1,
      aux_sym_annotation_repeat1,
    STATE(12735), 1,
      sym_arguments,
    STATE(12084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [554321] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [554347] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13306), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [554373] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12087), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [554399] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12088), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [554425] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4882), 1,
      sym__alpha_identifier,
    ACTIONS(4900), 1,
      sym__backquoted_id,
    ACTIONS(13882), 1,
      anon_sym_type,
    ACTIONS(13884), 1,
      sym_operator_identifier,
    STATE(5522), 1,
      sym__soft_identifier,
    STATE(5939), 1,
      sym_identifier,
    STATE(6280), 1,
      sym__type_identifier,
    STATE(12089), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4894), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554465] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [554491] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6868), 1,
      sym__alpha_identifier,
    ACTIONS(6878), 1,
      sym__backquoted_id,
    ACTIONS(13886), 1,
      anon_sym_type,
    ACTIONS(13888), 1,
      sym_operator_identifier,
    STATE(4620), 1,
      sym__soft_identifier,
    STATE(4731), 1,
      sym_identifier,
    STATE(4766), 1,
      sym__type_identifier,
    STATE(12091), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6874), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554531] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12092), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [554557] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12093), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13310), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [554583] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [554609] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12095), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [554635] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8749), 1,
      sym__alpha_identifier,
    ACTIONS(8757), 1,
      sym__backquoted_id,
    ACTIONS(13890), 1,
      anon_sym_type,
    ACTIONS(13892), 1,
      sym_operator_identifier,
    STATE(7082), 1,
      sym__type_identifier,
    STATE(7228), 1,
      sym_identifier,
    STATE(7238), 1,
      sym__soft_identifier,
    STATE(12096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8753), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554675] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8685), 1,
      sym__alpha_identifier,
    ACTIONS(8693), 1,
      sym__backquoted_id,
    ACTIONS(13894), 1,
      anon_sym_type,
    ACTIONS(13896), 1,
      sym_operator_identifier,
    STATE(5086), 1,
      sym_identifier,
    STATE(5145), 1,
      sym__soft_identifier,
    STATE(5277), 1,
      sym__type_identifier,
    STATE(12097), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554715] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [554741] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8503), 1,
      sym__alpha_identifier,
    ACTIONS(8511), 1,
      sym__backquoted_id,
    ACTIONS(13898), 1,
      anon_sym_type,
    ACTIONS(13900), 1,
      sym_operator_identifier,
    STATE(7486), 1,
      sym_identifier,
    STATE(7788), 1,
      sym__soft_identifier,
    STATE(8025), 1,
      sym__type_identifier,
    STATE(12099), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8507), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554781] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [554807] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12241), 1,
      sym__alpha_identifier,
    ACTIONS(12249), 1,
      sym__backquoted_id,
    ACTIONS(13473), 1,
      sym_operator_identifier,
    STATE(10542), 1,
      sym_identifier,
    STATE(11224), 1,
      sym__soft_identifier,
    STATE(11474), 1,
      sym__class_constructor,
    STATE(14714), 1,
      sym__class_definition,
    STATE(12101), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12245), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554847] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13312), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [554873] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4540), 1,
      sym__alpha_identifier,
    ACTIONS(4558), 1,
      sym__backquoted_id,
    ACTIONS(13902), 1,
      anon_sym_type,
    ACTIONS(13904), 1,
      sym_operator_identifier,
    STATE(5101), 1,
      sym_identifier,
    STATE(5155), 1,
      sym__soft_identifier,
    STATE(5718), 1,
      sym__type_identifier,
    STATE(12103), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554913] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(13596), 1,
      sym_operator_identifier,
    STATE(10192), 1,
      sym_identifier,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11211), 1,
      sym__class_constructor,
    STATE(14395), 1,
      sym__class_definition,
    STATE(12104), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554953] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6278), 1,
      sym__alpha_identifier,
    ACTIONS(6292), 1,
      sym__backquoted_id,
    ACTIONS(13906), 1,
      anon_sym_type,
    ACTIONS(13908), 1,
      sym_operator_identifier,
    STATE(5525), 1,
      sym__soft_identifier,
    STATE(5985), 1,
      sym_identifier,
    STATE(6400), 1,
      sym__type_identifier,
    STATE(12105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554993] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12253), 1,
      sym__alpha_identifier,
    ACTIONS(12261), 1,
      sym__backquoted_id,
    ACTIONS(13910), 1,
      anon_sym_type,
    ACTIONS(13912), 1,
      sym_operator_identifier,
    STATE(11063), 1,
      sym__soft_identifier,
    STATE(11908), 1,
      sym_identifier,
    STATE(12396), 1,
      sym__type_identifier,
    STATE(12106), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555033] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8697), 1,
      sym__alpha_identifier,
    ACTIONS(8705), 1,
      sym__backquoted_id,
    ACTIONS(13914), 1,
      anon_sym_type,
    ACTIONS(13916), 1,
      sym_operator_identifier,
    STATE(6818), 1,
      sym_identifier,
    STATE(6947), 1,
      sym__type_identifier,
    STATE(7122), 1,
      sym__soft_identifier,
    STATE(12107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8701), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555073] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13323), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [555099] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12109), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [555125] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11977), 1,
      sym__alpha_identifier,
    ACTIONS(11985), 1,
      sym__backquoted_id,
    ACTIONS(13918), 1,
      anon_sym_type,
    ACTIONS(13920), 1,
      sym_operator_identifier,
    STATE(12335), 1,
      sym_identifier,
    STATE(12392), 1,
      sym__soft_identifier,
    STATE(12997), 1,
      sym__type_identifier,
    STATE(12110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11981), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555165] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12156), 1,
      sym__alpha_identifier,
    ACTIONS(12164), 1,
      sym__backquoted_id,
    ACTIONS(13922), 1,
      anon_sym_type,
    ACTIONS(13924), 1,
      sym_operator_identifier,
    STATE(7544), 1,
      sym_identifier,
    STATE(8068), 1,
      sym__soft_identifier,
    STATE(8582), 1,
      sym__type_identifier,
    STATE(12111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12160), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555205] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12462), 1,
      anon_sym_AT,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12841), 1,
      sym__automatic_semicolon,
    STATE(12765), 1,
      sym_annotation,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(13667), 1,
      sym_access_modifier,
    STATE(13668), 1,
      aux_sym__class_constructor_repeat1,
    ACTIONS(12464), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(12112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12683), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [555247] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8761), 1,
      sym__alpha_identifier,
    ACTIONS(8769), 1,
      sym__backquoted_id,
    ACTIONS(13926), 1,
      anon_sym_type,
    ACTIONS(13928), 1,
      sym_operator_identifier,
    STATE(7820), 1,
      sym__type_identifier,
    STATE(7907), 1,
      sym__soft_identifier,
    STATE(7970), 1,
      sym_identifier,
    STATE(12113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8765), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555287] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12114), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13932), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13930), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [555315] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13934), 1,
      anon_sym_AT,
    STATE(12713), 1,
      sym_annotation,
    STATE(12115), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [555345] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6344), 1,
      sym__alpha_identifier,
    ACTIONS(6358), 1,
      sym__backquoted_id,
    ACTIONS(13937), 1,
      anon_sym_type,
    ACTIONS(13939), 1,
      sym_operator_identifier,
    STATE(6075), 1,
      sym_identifier,
    STATE(6141), 1,
      sym__soft_identifier,
    STATE(7210), 1,
      sym__type_identifier,
    STATE(12116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6354), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555385] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11989), 1,
      sym__alpha_identifier,
    ACTIONS(11997), 1,
      sym__backquoted_id,
    ACTIONS(13941), 1,
      anon_sym_type,
    ACTIONS(13943), 1,
      sym_operator_identifier,
    STATE(10756), 1,
      sym_identifier,
    STATE(10934), 1,
      sym__soft_identifier,
    STATE(10982), 1,
      sym__type_identifier,
    STATE(12117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11993), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555425] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8316), 1,
      sym__alpha_identifier,
    ACTIONS(8328), 1,
      sym__backquoted_id,
    ACTIONS(13945), 1,
      anon_sym_type,
    ACTIONS(13947), 1,
      sym_operator_identifier,
    STATE(11550), 1,
      sym__soft_identifier,
    STATE(11629), 1,
      sym_identifier,
    STATE(12133), 1,
      sym__type_identifier,
    STATE(12118), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8324), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555465] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13298), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [555491] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(13949), 1,
      anon_sym_type,
    ACTIONS(13951), 1,
      sym_operator_identifier,
    STATE(7699), 1,
      sym_identifier,
    STATE(7913), 1,
      sym__soft_identifier,
    STATE(8377), 1,
      sym__type_identifier,
    STATE(12120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555531] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12013), 1,
      sym__alpha_identifier,
    ACTIONS(12021), 1,
      sym__backquoted_id,
    ACTIONS(13953), 1,
      anon_sym_type,
    ACTIONS(13955), 1,
      sym_operator_identifier,
    STATE(11177), 1,
      sym_identifier,
    STATE(11287), 1,
      sym__soft_identifier,
    STATE(11670), 1,
      sym__type_identifier,
    STATE(12121), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12017), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555571] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4698), 1,
      sym__alpha_identifier,
    ACTIONS(4716), 1,
      sym__backquoted_id,
    ACTIONS(13957), 1,
      anon_sym_type,
    ACTIONS(13959), 1,
      sym_operator_identifier,
    STATE(5498), 1,
      sym__soft_identifier,
    STATE(5602), 1,
      sym_identifier,
    STATE(6409), 1,
      sym__type_identifier,
    STATE(12122), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4710), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555611] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8773), 1,
      sym__alpha_identifier,
    ACTIONS(8785), 1,
      sym__backquoted_id,
    ACTIONS(13961), 1,
      anon_sym_type,
    ACTIONS(13963), 1,
      sym_operator_identifier,
    STATE(4931), 1,
      sym__soft_identifier,
    STATE(4975), 1,
      sym__type_identifier,
    STATE(5034), 1,
      sym_identifier,
    STATE(12123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8781), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555651] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(13499), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(10977), 1,
      sym_identifier,
    STATE(13105), 1,
      sym__type_identifier,
    STATE(14494), 1,
      sym__type_constructor,
    STATE(12124), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555691] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13329), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [555717] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6514), 1,
      sym__backquoted_id,
    ACTIONS(13965), 1,
      anon_sym_type,
    ACTIONS(13967), 1,
      sym_operator_identifier,
    STATE(4474), 1,
      sym__soft_identifier,
    STATE(4499), 1,
      sym_identifier,
    STATE(4588), 1,
      sym__type_identifier,
    STATE(12126), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6510), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555757] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12241), 1,
      sym__alpha_identifier,
    ACTIONS(12249), 1,
      sym__backquoted_id,
    ACTIONS(13473), 1,
      sym_operator_identifier,
    STATE(10542), 1,
      sym_identifier,
    STATE(11224), 1,
      sym__soft_identifier,
    STATE(11474), 1,
      sym__class_constructor,
    STATE(14455), 1,
      sym__class_definition,
    STATE(12127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12245), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555797] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(13596), 1,
      sym_operator_identifier,
    STATE(10192), 1,
      sym_identifier,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11211), 1,
      sym__class_constructor,
    STATE(14358), 1,
      sym__class_definition,
    STATE(12128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555837] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12129), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [555863] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6546), 1,
      sym__alpha_identifier,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(13969), 1,
      anon_sym_type,
    ACTIONS(13971), 1,
      sym_operator_identifier,
    STATE(4937), 1,
      sym__soft_identifier,
    STATE(5040), 1,
      sym_identifier,
    STATE(5060), 1,
      sym__type_identifier,
    STATE(12130), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555903] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12253), 1,
      sym__alpha_identifier,
    ACTIONS(12261), 1,
      sym__backquoted_id,
    ACTIONS(13475), 1,
      sym_operator_identifier,
    STATE(11063), 1,
      sym__soft_identifier,
    STATE(12555), 1,
      sym_identifier,
    STATE(12676), 1,
      sym__type_identifier,
    STATE(14210), 1,
      sym__type_constructor,
    STATE(12131), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555943] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12132), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [555969] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [555995] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(13973), 1,
      anon_sym_type,
    ACTIONS(13975), 1,
      sym_operator_identifier,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(5783), 1,
      sym_identifier,
    STATE(6051), 1,
      sym__type_identifier,
    STATE(12134), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556035] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12703), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [556061] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8789), 1,
      sym__alpha_identifier,
    ACTIONS(8797), 1,
      sym__backquoted_id,
    ACTIONS(13977), 1,
      anon_sym_type,
    ACTIONS(13979), 1,
      sym_operator_identifier,
    STATE(5528), 1,
      sym__soft_identifier,
    STATE(5536), 1,
      sym_identifier,
    STATE(5668), 1,
      sym__type_identifier,
    STATE(12136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8793), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556101] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(13981), 1,
      anon_sym_type,
    ACTIONS(13983), 1,
      sym_operator_identifier,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11163), 1,
      sym_identifier,
    STATE(11641), 1,
      sym__type_identifier,
    STATE(12137), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556141] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6626), 1,
      sym__alpha_identifier,
    ACTIONS(6640), 1,
      sym__backquoted_id,
    ACTIONS(13985), 1,
      anon_sym_type,
    ACTIONS(13987), 1,
      sym_operator_identifier,
    STATE(4771), 1,
      sym_identifier,
    STATE(4939), 1,
      sym__soft_identifier,
    STATE(5071), 1,
      sym__type_identifier,
    STATE(12138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556181] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13989), 1,
      anon_sym_DOT,
    STATE(12139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [556209] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12030), 1,
      sym__alpha_identifier,
    ACTIONS(12038), 1,
      sym__backquoted_id,
    ACTIONS(13991), 1,
      anon_sym_type,
    ACTIONS(13993), 1,
      sym_operator_identifier,
    STATE(11464), 1,
      sym_identifier,
    STATE(11591), 1,
      sym__soft_identifier,
    STATE(12058), 1,
      sym__type_identifier,
    STATE(12140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12034), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556249] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6650), 1,
      sym__alpha_identifier,
    ACTIONS(6664), 1,
      sym__backquoted_id,
    ACTIONS(13995), 1,
      anon_sym_type,
    ACTIONS(13997), 1,
      sym_operator_identifier,
    STATE(6214), 1,
      sym_identifier,
    STATE(6233), 1,
      sym__soft_identifier,
    STATE(6742), 1,
      sym__type_identifier,
    STATE(12141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6660), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556289] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [556315] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(14001), 1,
      sym_operator_identifier,
    STATE(14596), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    ACTIONS(13999), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(12143), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8056), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556353] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6518), 1,
      sym__alpha_identifier,
    ACTIONS(6532), 1,
      sym__backquoted_id,
    ACTIONS(14003), 1,
      anon_sym_type,
    ACTIONS(14005), 1,
      sym_operator_identifier,
    STATE(7600), 1,
      sym_identifier,
    STATE(7843), 1,
      sym__soft_identifier,
    STATE(8497), 1,
      sym__type_identifier,
    STATE(12144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6528), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556393] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12042), 1,
      sym__alpha_identifier,
    ACTIONS(12050), 1,
      sym__backquoted_id,
    ACTIONS(14007), 1,
      anon_sym_type,
    ACTIONS(14009), 1,
      sym_operator_identifier,
    STATE(12741), 1,
      sym__soft_identifier,
    STATE(13004), 1,
      sym_identifier,
    STATE(13182), 1,
      sym__type_identifier,
    STATE(12145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12046), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556433] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8378), 1,
      sym__alpha_identifier,
    ACTIONS(8390), 1,
      sym__backquoted_id,
    ACTIONS(14011), 1,
      anon_sym_type,
    ACTIONS(14013), 1,
      sym_operator_identifier,
    STATE(13141), 1,
      sym_identifier,
    STATE(13178), 1,
      sym__soft_identifier,
    STATE(13559), 1,
      sym__type_identifier,
    STATE(12146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8386), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556473] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11770), 1,
      sym__alpha_identifier,
    ACTIONS(11778), 1,
      sym__backquoted_id,
    ACTIONS(14015), 1,
      anon_sym_type,
    ACTIONS(14017), 1,
      sym_operator_identifier,
    STATE(13643), 1,
      sym__soft_identifier,
    STATE(13713), 1,
      sym_identifier,
    STATE(13890), 1,
      sym__type_identifier,
    STATE(12147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11774), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556513] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4254), 1,
      sym__alpha_identifier,
    ACTIONS(4272), 1,
      sym__backquoted_id,
    ACTIONS(14019), 1,
      anon_sym_type,
    ACTIONS(14021), 1,
      sym_operator_identifier,
    STATE(4793), 1,
      sym_identifier,
    STATE(4941), 1,
      sym__soft_identifier,
    STATE(5089), 1,
      sym__type_identifier,
    STATE(12148), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4266), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556553] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11867), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(12149), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11865), 11,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [556581] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12150), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14025), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(14023), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [556609] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14029), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(14027), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [556637] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14033), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(14031), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [556665] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14037), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(14035), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [556693] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(830), 1,
      sym__alpha_identifier,
    ACTIONS(836), 1,
      anon_sym__,
    ACTIONS(860), 1,
      sym__backquoted_id,
    ACTIONS(14039), 1,
      sym_operator_identifier,
    STATE(5706), 1,
      sym__soft_identifier,
    STATE(12154), 2,
      sym_comment,
      sym_block_comment,
    STATE(16049), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(840), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556731] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(13596), 1,
      sym_operator_identifier,
    STATE(10192), 1,
      sym_identifier,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11211), 1,
      sym__class_constructor,
    STATE(14397), 1,
      sym__class_definition,
    STATE(12155), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556771] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [556797] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [556823] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6668), 1,
      sym__alpha_identifier,
    ACTIONS(6682), 1,
      sym__backquoted_id,
    ACTIONS(14041), 1,
      anon_sym_type,
    ACTIONS(14043), 1,
      sym_operator_identifier,
    STATE(6257), 1,
      sym__soft_identifier,
    STATE(6480), 1,
      sym_identifier,
    STATE(6787), 1,
      sym__type_identifier,
    STATE(12158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6678), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556863] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8543), 1,
      sym__alpha_identifier,
    ACTIONS(8551), 1,
      sym__backquoted_id,
    ACTIONS(14045), 1,
      anon_sym_type,
    ACTIONS(14047), 1,
      sym_operator_identifier,
    STATE(6081), 1,
      sym__soft_identifier,
    STATE(6098), 1,
      sym__type_identifier,
    STATE(6261), 1,
      sym_identifier,
    STATE(12159), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8547), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556903] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12160), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [556929] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12161), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [556955] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [556981] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12715), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [557007] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [557033] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14051), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(14049), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [557061] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12166), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [557087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14055), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(14053), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [557115] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8527), 1,
      sym__alpha_identifier,
    ACTIONS(8539), 1,
      sym__backquoted_id,
    ACTIONS(14057), 1,
      anon_sym_type,
    ACTIONS(14059), 1,
      sym_operator_identifier,
    STATE(4828), 1,
      sym__type_identifier,
    STATE(4866), 1,
      sym_identifier,
    STATE(5008), 1,
      sym__soft_identifier,
    STATE(12168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8535), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557155] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12056), 1,
      sym__alpha_identifier,
    ACTIONS(12064), 1,
      sym__backquoted_id,
    ACTIONS(14061), 1,
      anon_sym_type,
    ACTIONS(14063), 1,
      sym_operator_identifier,
    STATE(12744), 1,
      sym__soft_identifier,
    STATE(12916), 1,
      sym_identifier,
    STATE(13243), 1,
      sym__type_identifier,
    STATE(12169), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557195] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [557221] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12171), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12606), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [557247] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [557273] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [557299] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14067), 1,
      anon_sym_catch,
    ACTIONS(14069), 1,
      anon_sym_finally,
    STATE(11551), 1,
      sym_finally_clause,
    STATE(12666), 1,
      sym_catch_clause,
    STATE(12174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
  [557332] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12175), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [557357] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [557382] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [557407] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4770), 1,
      sym__alpha_identifier,
    ACTIONS(4782), 1,
      sym__backquoted_id,
    ACTIONS(14071), 1,
      sym_operator_identifier,
    STATE(4399), 1,
      sym__soft_identifier,
    STATE(4542), 1,
      sym_identifier,
    STATE(4545), 1,
      sym__type_identifier,
    STATE(12178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4778), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557444] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [557469] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [557494] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6760), 1,
      sym__alpha_identifier,
    ACTIONS(6770), 1,
      sym__backquoted_id,
    ACTIONS(14073), 1,
      sym_operator_identifier,
    STATE(4925), 1,
      sym__soft_identifier,
    STATE(5281), 1,
      sym_identifier,
    STATE(5287), 1,
      sym__type_identifier,
    STATE(12181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6766), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557531] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14077), 1,
      anon_sym_LPAREN,
    ACTIONS(14080), 1,
      sym__automatic_semicolon,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(12182), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__function_constructor_repeat1,
    ACTIONS(14075), 7,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [557564] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14083), 1,
      sym__alpha_identifier,
    ACTIONS(14085), 1,
      anon_sym_LBRACE,
    ACTIONS(14087), 1,
      anon_sym_LBRACK,
    ACTIONS(14091), 1,
      sym__backquoted_id,
    STATE(7488), 1,
      sym_identifier,
    STATE(7888), 1,
      sym__soft_identifier,
    STATE(12183), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14089), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557601] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14093), 1,
      sym__alpha_identifier,
    ACTIONS(14095), 1,
      anon_sym_LBRACE,
    ACTIONS(14097), 1,
      anon_sym_LBRACK,
    ACTIONS(14101), 1,
      sym__backquoted_id,
    STATE(6991), 1,
      sym_identifier,
    STATE(7085), 1,
      sym__soft_identifier,
    STATE(12184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14099), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557638] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4794), 1,
      sym__alpha_identifier,
    ACTIONS(4806), 1,
      sym__backquoted_id,
    ACTIONS(14103), 1,
      sym_operator_identifier,
    STATE(4605), 1,
      sym__soft_identifier,
    STATE(4814), 1,
      sym_identifier,
    STATE(4819), 1,
      sym__type_identifier,
    STATE(12185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4802), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557675] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7372), 1,
      sym__backquoted_id,
    ACTIONS(14105), 1,
      sym_operator_identifier,
    STATE(11518), 1,
      sym__soft_identifier,
    STATE(11920), 1,
      sym__type_identifier,
    STATE(12109), 1,
      sym_identifier,
    STATE(12186), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7368), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557712] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4820), 1,
      sym__alpha_identifier,
    ACTIONS(4838), 1,
      sym__backquoted_id,
    ACTIONS(14107), 1,
      sym_operator_identifier,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(4835), 1,
      sym_identifier,
    STATE(4863), 1,
      sym__type_identifier,
    STATE(12187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4832), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557749] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9218), 1,
      anon_sym_LPAREN,
    STATE(12194), 1,
      aux_sym_annotation_repeat1,
    STATE(13282), 1,
      sym_arguments,
    STATE(12188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [557780] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym__alpha_identifier,
    ACTIONS(6470), 1,
      sym__backquoted_id,
    ACTIONS(14109), 1,
      sym_operator_identifier,
    STATE(6313), 1,
      sym__soft_identifier,
    STATE(6697), 1,
      sym_identifier,
    STATE(6738), 1,
      sym__type_identifier,
    STATE(12189), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6466), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557817] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6192), 1,
      sym__alpha_identifier,
    ACTIONS(6206), 1,
      sym__backquoted_id,
    ACTIONS(14111), 1,
      sym_operator_identifier,
    STATE(5516), 1,
      sym__soft_identifier,
    STATE(6137), 1,
      sym_identifier,
    STATE(6184), 1,
      sym__type_identifier,
    STATE(12190), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6202), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557854] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(14113), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(11638), 1,
      sym_identifier,
    STATE(14070), 1,
      sym__function_constructor,
    STATE(12191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557891] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11960), 1,
      sym__alpha_identifier,
    ACTIONS(11968), 1,
      sym__backquoted_id,
    ACTIONS(14115), 1,
      sym_operator_identifier,
    STATE(12387), 1,
      sym__soft_identifier,
    STATE(12860), 1,
      sym_identifier,
    STATE(12899), 1,
      sym__type_identifier,
    STATE(12192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11964), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557928] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(12193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [557955] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14117), 1,
      anon_sym_LPAREN,
    STATE(13282), 1,
      sym_arguments,
    STATE(12194), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [557984] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(14120), 1,
      sym_operator_identifier,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11166), 1,
      sym_identifier,
    STATE(14302), 1,
      sym__object_definition,
    STATE(12195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558021] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4852), 1,
      sym__alpha_identifier,
    ACTIONS(4870), 1,
      sym__backquoted_id,
    ACTIONS(14122), 1,
      sym_operator_identifier,
    STATE(5519), 1,
      sym__soft_identifier,
    STATE(6269), 1,
      sym_identifier,
    STATE(6285), 1,
      sym__type_identifier,
    STATE(12196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4864), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558058] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4640), 1,
      sym__alpha_identifier,
    ACTIONS(4652), 1,
      sym__backquoted_id,
    ACTIONS(14124), 1,
      sym_operator_identifier,
    STATE(7872), 1,
      sym__soft_identifier,
    STATE(8546), 1,
      sym_identifier,
    STATE(8643), 1,
      sym__type_identifier,
    STATE(12197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4648), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558095] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14126), 1,
      anon_sym_DOT,
    STATE(12198), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [558122] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14128), 1,
      sym__alpha_identifier,
    ACTIONS(14130), 1,
      anon_sym_LBRACE,
    ACTIONS(14132), 1,
      anon_sym_LBRACK,
    ACTIONS(14136), 1,
      sym__backquoted_id,
    STATE(8766), 1,
      sym__soft_identifier,
    STATE(8905), 1,
      sym_identifier,
    STATE(12199), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14134), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558159] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14138), 1,
      sym__alpha_identifier,
    ACTIONS(14140), 1,
      anon_sym_LBRACE,
    ACTIONS(14142), 1,
      anon_sym_LBRACK,
    ACTIONS(14146), 1,
      sym__backquoted_id,
    STATE(8906), 1,
      sym_identifier,
    STATE(9270), 1,
      sym__soft_identifier,
    STATE(12200), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14144), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558196] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8735), 1,
      sym__alpha_identifier,
    ACTIONS(8743), 1,
      sym__backquoted_id,
    ACTIONS(14148), 1,
      sym_operator_identifier,
    STATE(5520), 1,
      sym__soft_identifier,
    STATE(5837), 1,
      sym_identifier,
    STATE(5847), 1,
      sym__type_identifier,
    STATE(12201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8739), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558233] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12253), 1,
      sym__alpha_identifier,
    ACTIONS(12261), 1,
      sym__backquoted_id,
    ACTIONS(14150), 1,
      sym_operator_identifier,
    STATE(11063), 1,
      sym__soft_identifier,
    STATE(11965), 1,
      sym_identifier,
    STATE(13928), 1,
      sym__function_constructor,
    STATE(12202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558270] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4882), 1,
      sym__alpha_identifier,
    ACTIONS(4900), 1,
      sym__backquoted_id,
    ACTIONS(14152), 1,
      sym_operator_identifier,
    STATE(5522), 1,
      sym__soft_identifier,
    STATE(6390), 1,
      sym_identifier,
    STATE(6402), 1,
      sym__type_identifier,
    STATE(12203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4894), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558307] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [558332] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14154), 1,
      anon_sym_STAR,
    STATE(12205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [558359] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(13441), 1,
      sym_operator_identifier,
    ACTIONS(14156), 1,
      anon_sym_match,
    STATE(4192), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12206), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558396] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8749), 1,
      sym__alpha_identifier,
    ACTIONS(8757), 1,
      sym__backquoted_id,
    ACTIONS(14158), 1,
      sym_operator_identifier,
    STATE(7121), 1,
      sym_identifier,
    STATE(7133), 1,
      sym__type_identifier,
    STATE(7238), 1,
      sym__soft_identifier,
    STATE(12207), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8753), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558433] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8555), 1,
      sym__alpha_identifier,
    ACTIONS(8563), 1,
      sym__backquoted_id,
    ACTIONS(14160), 1,
      sym_operator_identifier,
    STATE(7602), 1,
      sym__type_identifier,
    STATE(7612), 1,
      sym__soft_identifier,
    STATE(7659), 1,
      sym_identifier,
    STATE(12208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8559), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558470] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6278), 1,
      sym__alpha_identifier,
    ACTIONS(6292), 1,
      sym__backquoted_id,
    ACTIONS(14162), 1,
      sym_operator_identifier,
    STATE(5525), 1,
      sym__soft_identifier,
    STATE(6495), 1,
      sym_identifier,
    STATE(6514), 1,
      sym__type_identifier,
    STATE(12209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558507] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12893), 1,
      sym__automatic_semicolon,
    STATE(12297), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(12210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12891), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [558540] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11977), 1,
      sym__alpha_identifier,
    ACTIONS(11985), 1,
      sym__backquoted_id,
    ACTIONS(14164), 1,
      sym_operator_identifier,
    STATE(12392), 1,
      sym__soft_identifier,
    STATE(12795), 1,
      sym_identifier,
    STATE(12833), 1,
      sym__type_identifier,
    STATE(12211), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11981), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558577] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(14168), 1,
      sym__automatic_semicolon,
    STATE(12274), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(12212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14166), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [558610] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8761), 1,
      sym__alpha_identifier,
    ACTIONS(8769), 1,
      sym__backquoted_id,
    ACTIONS(14171), 1,
      sym_operator_identifier,
    STATE(7865), 1,
      sym_identifier,
    STATE(7881), 1,
      sym__type_identifier,
    STATE(7907), 1,
      sym__soft_identifier,
    STATE(12213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8765), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558647] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6344), 1,
      sym__alpha_identifier,
    ACTIONS(6358), 1,
      sym__backquoted_id,
    ACTIONS(14173), 1,
      sym_operator_identifier,
    STATE(6141), 1,
      sym__soft_identifier,
    STATE(7250), 1,
      sym_identifier,
    STATE(7257), 1,
      sym__type_identifier,
    STATE(12214), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6354), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558684] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12215), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [558709] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11989), 1,
      sym__alpha_identifier,
    ACTIONS(11997), 1,
      sym__backquoted_id,
    ACTIONS(14175), 1,
      sym_operator_identifier,
    STATE(10934), 1,
      sym__soft_identifier,
    STATE(11023), 1,
      sym_identifier,
    STATE(11033), 1,
      sym__type_identifier,
    STATE(12216), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11993), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558746] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(14177), 1,
      sym_operator_identifier,
    STATE(7913), 1,
      sym__soft_identifier,
    STATE(8452), 1,
      sym_identifier,
    STATE(8513), 1,
      sym__type_identifier,
    STATE(12217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558783] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(13242), 1,
      anon_sym_COLON,
    ACTIONS(13246), 1,
      anon_sym_derives,
    STATE(13230), 1,
      sym_derives_clause,
    STATE(14503), 1,
      sym__definition_body,
    STATE(14724), 1,
      sym_template_body,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12218), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13628), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [558822] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12013), 1,
      sym__alpha_identifier,
    ACTIONS(12021), 1,
      sym__backquoted_id,
    ACTIONS(14179), 1,
      sym_operator_identifier,
    STATE(11287), 1,
      sym__soft_identifier,
    STATE(11679), 1,
      sym_identifier,
    STATE(11685), 1,
      sym__type_identifier,
    STATE(12219), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12017), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558859] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(473), 1,
      sym__alpha_identifier,
    ACTIONS(537), 1,
      sym__backquoted_id,
    ACTIONS(14181), 1,
      sym_operator_identifier,
    STATE(5776), 1,
      sym__soft_identifier,
    STATE(13835), 1,
      sym_identifier,
    STATE(14309), 1,
      sym__namespace_expression,
    STATE(12220), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(659), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558896] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8773), 1,
      sym__alpha_identifier,
    ACTIONS(8785), 1,
      sym__backquoted_id,
    ACTIONS(14183), 1,
      sym_operator_identifier,
    STATE(4931), 1,
      sym__soft_identifier,
    STATE(4980), 1,
      sym_identifier,
    STATE(4985), 1,
      sym__type_identifier,
    STATE(12221), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8781), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558933] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6514), 1,
      sym__backquoted_id,
    ACTIONS(14185), 1,
      sym_operator_identifier,
    STATE(4474), 1,
      sym__soft_identifier,
    STATE(4593), 1,
      sym_identifier,
    STATE(4598), 1,
      sym__type_identifier,
    STATE(12222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6510), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558970] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14187), 1,
      sym__alpha_identifier,
    ACTIONS(14189), 1,
      anon_sym_LBRACE,
    ACTIONS(14191), 1,
      anon_sym_LBRACK,
    ACTIONS(14195), 1,
      sym__backquoted_id,
    STATE(10279), 1,
      sym__soft_identifier,
    STATE(10306), 1,
      sym_identifier,
    STATE(12223), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14193), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559007] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14197), 1,
      sym__alpha_identifier,
    ACTIONS(14199), 1,
      anon_sym_LBRACE,
    ACTIONS(14201), 1,
      anon_sym_LBRACK,
    ACTIONS(14205), 1,
      sym__backquoted_id,
    STATE(9349), 1,
      sym__soft_identifier,
    STATE(9367), 1,
      sym_identifier,
    STATE(12224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14203), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559044] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6546), 1,
      sym__alpha_identifier,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(14207), 1,
      sym_operator_identifier,
    STATE(4937), 1,
      sym__soft_identifier,
    STATE(5068), 1,
      sym_identifier,
    STATE(5072), 1,
      sym__type_identifier,
    STATE(12225), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559081] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14209), 1,
      sym__alpha_identifier,
    ACTIONS(14211), 1,
      anon_sym_LBRACE,
    ACTIONS(14213), 1,
      anon_sym_LBRACK,
    ACTIONS(14217), 1,
      sym__backquoted_id,
    STATE(8722), 1,
      sym__soft_identifier,
    STATE(8965), 1,
      sym_identifier,
    STATE(12226), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14215), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559118] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14219), 1,
      anon_sym_DOT,
    STATE(12227), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [559145] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(14113), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(11638), 1,
      sym_identifier,
    STATE(14040), 1,
      sym__function_constructor,
    STATE(12228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559182] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8789), 1,
      sym__alpha_identifier,
    ACTIONS(8797), 1,
      sym__backquoted_id,
    ACTIONS(14221), 1,
      sym_operator_identifier,
    STATE(5468), 1,
      sym__type_identifier,
    STATE(5528), 1,
      sym__soft_identifier,
    STATE(5884), 1,
      sym_identifier,
    STATE(12229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8793), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559219] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [559244] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4944), 1,
      sym__alpha_identifier,
    ACTIONS(4966), 1,
      sym__backquoted_id,
    ACTIONS(14223), 1,
      sym_operator_identifier,
    STATE(5329), 1,
      sym__soft_identifier,
    STATE(5502), 1,
      sym__type_identifier,
    STATE(5554), 1,
      sym_identifier,
    STATE(12231), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559281] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12232), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [559306] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12233), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [559331] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6626), 1,
      sym__alpha_identifier,
    ACTIONS(6640), 1,
      sym__backquoted_id,
    ACTIONS(14225), 1,
      sym_operator_identifier,
    STATE(4939), 1,
      sym__soft_identifier,
    STATE(5080), 1,
      sym_identifier,
    STATE(5083), 1,
      sym__type_identifier,
    STATE(12234), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559368] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [559393] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8567), 1,
      sym__alpha_identifier,
    ACTIONS(8575), 1,
      sym__backquoted_id,
    ACTIONS(14227), 1,
      sym_operator_identifier,
    STATE(8180), 1,
      sym__type_identifier,
    STATE(8201), 1,
      sym__soft_identifier,
    STATE(8481), 1,
      sym_identifier,
    STATE(12236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8571), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559430] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12237), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [559455] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12030), 1,
      sym__alpha_identifier,
    ACTIONS(12038), 1,
      sym__backquoted_id,
    ACTIONS(14229), 1,
      sym_operator_identifier,
    STATE(11591), 1,
      sym__soft_identifier,
    STATE(12081), 1,
      sym_identifier,
    STATE(12090), 1,
      sym__type_identifier,
    STATE(12238), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12034), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559492] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12239), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [559517] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6650), 1,
      sym__alpha_identifier,
    ACTIONS(6664), 1,
      sym__backquoted_id,
    ACTIONS(14231), 1,
      sym_operator_identifier,
    STATE(6233), 1,
      sym__soft_identifier,
    STATE(6765), 1,
      sym_identifier,
    STATE(6774), 1,
      sym__type_identifier,
    STATE(12240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6660), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559554] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [559579] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12042), 1,
      sym__alpha_identifier,
    ACTIONS(12050), 1,
      sym__backquoted_id,
    ACTIONS(14233), 1,
      sym_operator_identifier,
    STATE(12741), 1,
      sym__soft_identifier,
    STATE(13205), 1,
      sym_identifier,
    STATE(13218), 1,
      sym__type_identifier,
    STATE(12242), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12046), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559616] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(14120), 1,
      sym_operator_identifier,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11166), 1,
      sym_identifier,
    STATE(15486), 1,
      sym__object_definition,
    STATE(12243), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559653] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8487), 1,
      sym__alpha_identifier,
    ACTIONS(8495), 1,
      sym__backquoted_id,
    ACTIONS(14235), 1,
      sym_operator_identifier,
    STATE(7428), 1,
      sym__type_identifier,
    STATE(7616), 1,
      sym__soft_identifier,
    STATE(7966), 1,
      sym_identifier,
    STATE(12244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8491), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559690] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4254), 1,
      sym__alpha_identifier,
    ACTIONS(4272), 1,
      sym__backquoted_id,
    ACTIONS(14237), 1,
      sym_operator_identifier,
    STATE(4941), 1,
      sym__soft_identifier,
    STATE(5097), 1,
      sym_identifier,
    STATE(5100), 1,
      sym__type_identifier,
    STATE(12245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4266), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559727] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(14239), 1,
      sym_operator_identifier,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11466), 1,
      sym_identifier,
    STATE(11643), 1,
      sym__type_identifier,
    STATE(12246), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559764] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14241), 1,
      sym__alpha_identifier,
    ACTIONS(14243), 1,
      anon_sym_LBRACE,
    ACTIONS(14245), 1,
      anon_sym_LBRACK,
    ACTIONS(14249), 1,
      sym__backquoted_id,
    STATE(6150), 1,
      sym__soft_identifier,
    STATE(6200), 1,
      sym_identifier,
    STATE(12247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14247), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559801] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14083), 1,
      sym__alpha_identifier,
    ACTIONS(14091), 1,
      sym__backquoted_id,
    ACTIONS(14251), 1,
      anon_sym_LBRACE,
    ACTIONS(14253), 1,
      anon_sym_LBRACK,
    STATE(7625), 1,
      sym_identifier,
    STATE(7888), 1,
      sym__soft_identifier,
    STATE(12248), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14089), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559838] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6668), 1,
      sym__alpha_identifier,
    ACTIONS(6682), 1,
      sym__backquoted_id,
    ACTIONS(14255), 1,
      sym_operator_identifier,
    STATE(6257), 1,
      sym__soft_identifier,
    STATE(6823), 1,
      sym_identifier,
    STATE(6830), 1,
      sym__type_identifier,
    STATE(12249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6678), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559875] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12056), 1,
      sym__alpha_identifier,
    ACTIONS(12064), 1,
      sym__backquoted_id,
    ACTIONS(14257), 1,
      sym_operator_identifier,
    STATE(12744), 1,
      sym__soft_identifier,
    STATE(13273), 1,
      sym_identifier,
    STATE(13280), 1,
      sym__type_identifier,
    STATE(12250), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559912] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(13242), 1,
      anon_sym_COLON,
    ACTIONS(13246), 1,
      anon_sym_derives,
    ACTIONS(14259), 1,
      sym__automatic_semicolon,
    STATE(13320), 1,
      sym_derives_clause,
    STATE(14563), 1,
      sym__definition_body,
    STATE(14724), 1,
      sym_template_body,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12251), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13480), 3,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [559953] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14262), 1,
      sym__alpha_identifier,
    ACTIONS(14264), 1,
      anon_sym_LBRACE,
    ACTIONS(14266), 1,
      anon_sym_LBRACK,
    ACTIONS(14270), 1,
      sym__backquoted_id,
    STATE(8297), 1,
      sym_identifier,
    STATE(8610), 1,
      sym__soft_identifier,
    STATE(12252), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14268), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559990] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4210), 1,
      sym__alpha_identifier,
    ACTIONS(4228), 1,
      sym__backquoted_id,
    ACTIONS(14272), 1,
      sym_operator_identifier,
    STATE(6658), 1,
      sym__soft_identifier,
    STATE(7094), 1,
      sym__type_identifier,
    STATE(7129), 1,
      sym_identifier,
    STATE(12253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4222), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560027] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4312), 1,
      sym__alpha_identifier,
    ACTIONS(4330), 1,
      sym__backquoted_id,
    ACTIONS(14274), 1,
      sym_operator_identifier,
    STATE(5532), 1,
      sym__soft_identifier,
    STATE(6334), 1,
      sym_identifier,
    STATE(6394), 1,
      sym__type_identifier,
    STATE(12254), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4324), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560064] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4344), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      sym__backquoted_id,
    ACTIONS(14276), 1,
      sym_operator_identifier,
    STATE(6290), 1,
      sym__soft_identifier,
    STATE(6859), 1,
      sym_identifier,
    STATE(6864), 1,
      sym__type_identifier,
    STATE(12255), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4356), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560101] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14278), 1,
      sym__alpha_identifier,
    ACTIONS(14280), 1,
      anon_sym_LBRACE,
    ACTIONS(14282), 1,
      anon_sym_LBRACK,
    ACTIONS(14286), 1,
      sym__backquoted_id,
    STATE(9851), 1,
      sym_identifier,
    STATE(9910), 1,
      sym__soft_identifier,
    STATE(12256), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14284), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560138] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12253), 1,
      sym__alpha_identifier,
    ACTIONS(12261), 1,
      sym__backquoted_id,
    ACTIONS(13912), 1,
      sym_operator_identifier,
    STATE(11063), 1,
      sym__soft_identifier,
    STATE(11908), 1,
      sym_identifier,
    STATE(12396), 1,
      sym__type_identifier,
    STATE(12257), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560175] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4408), 1,
      sym__alpha_identifier,
    ACTIONS(4420), 1,
      sym__backquoted_id,
    ACTIONS(14288), 1,
      sym_operator_identifier,
    STATE(4476), 1,
      sym__soft_identifier,
    STATE(4662), 1,
      sym_identifier,
    STATE(4704), 1,
      sym__type_identifier,
    STATE(12258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4416), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560212] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [560237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12840), 1,
      sym_arguments,
    STATE(12260), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [560264] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6844), 1,
      sym__backquoted_id,
    ACTIONS(14290), 1,
      sym_operator_identifier,
    STATE(8809), 1,
      sym__soft_identifier,
    STATE(9437), 1,
      sym_identifier,
    STATE(9445), 1,
      sym__type_identifier,
    STATE(12261), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6840), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560301] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4434), 1,
      sym__alpha_identifier,
    ACTIONS(4452), 1,
      sym__backquoted_id,
    ACTIONS(14292), 1,
      sym_operator_identifier,
    STATE(4948), 1,
      sym__soft_identifier,
    STATE(5123), 1,
      sym_identifier,
    STATE(5127), 1,
      sym__type_identifier,
    STATE(12262), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4446), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560338] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14294), 1,
      sym__alpha_identifier,
    ACTIONS(14296), 1,
      anon_sym_LBRACE,
    ACTIONS(14298), 1,
      anon_sym_LBRACK,
    ACTIONS(14302), 1,
      sym__backquoted_id,
    STATE(7661), 1,
      sym_identifier,
    STATE(7925), 1,
      sym__soft_identifier,
    STATE(12263), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14300), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560375] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8819), 1,
      sym__alpha_identifier,
    ACTIONS(8827), 1,
      sym__backquoted_id,
    ACTIONS(14304), 1,
      sym_operator_identifier,
    STATE(6144), 1,
      sym_identifier,
    STATE(6153), 1,
      sym__type_identifier,
    STATE(6351), 1,
      sym__soft_identifier,
    STATE(12264), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8823), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560412] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14128), 1,
      sym__alpha_identifier,
    ACTIONS(14136), 1,
      sym__backquoted_id,
    ACTIONS(14306), 1,
      anon_sym_LBRACE,
    ACTIONS(14308), 1,
      anon_sym_LBRACK,
    STATE(8766), 1,
      sym__soft_identifier,
    STATE(9025), 1,
      sym_identifier,
    STATE(12265), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14134), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560449] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6690), 1,
      sym__alpha_identifier,
    ACTIONS(6704), 1,
      sym__backquoted_id,
    ACTIONS(14310), 1,
      sym_operator_identifier,
    STATE(5191), 1,
      sym__soft_identifier,
    STATE(5798), 1,
      sym_identifier,
    STATE(5808), 1,
      sym__type_identifier,
    STATE(12266), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560486] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12267), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [560511] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6210), 1,
      sym__alpha_identifier,
    ACTIONS(6224), 1,
      sym__backquoted_id,
    ACTIONS(14312), 1,
      sym_operator_identifier,
    STATE(7856), 1,
      sym__soft_identifier,
    STATE(8548), 1,
      sym__type_identifier,
    STATE(8677), 1,
      sym_identifier,
    STATE(12268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6220), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560548] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9318), 1,
      anon_sym_LPAREN,
    STATE(12271), 1,
      aux_sym_annotation_repeat1,
    STATE(13238), 1,
      sym_arguments,
    STATE(12269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [560579] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12077), 1,
      sym__alpha_identifier,
    ACTIONS(12085), 1,
      sym__backquoted_id,
    ACTIONS(14314), 1,
      sym_operator_identifier,
    STATE(11793), 1,
      sym__soft_identifier,
    STATE(12232), 1,
      sym_identifier,
    STATE(12237), 1,
      sym__type_identifier,
    STATE(12270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12081), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560616] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14316), 1,
      anon_sym_LPAREN,
    STATE(13238), 1,
      sym_arguments,
    STATE(12271), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [560645] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6712), 1,
      sym__alpha_identifier,
    ACTIONS(6726), 1,
      sym__backquoted_id,
    ACTIONS(14319), 1,
      sym_operator_identifier,
    STATE(6378), 1,
      sym__soft_identifier,
    STATE(7017), 1,
      sym_identifier,
    STATE(7029), 1,
      sym__type_identifier,
    STATE(12272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6722), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560682] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12089), 1,
      sym__alpha_identifier,
    ACTIONS(12097), 1,
      sym__backquoted_id,
    ACTIONS(14321), 1,
      sym_operator_identifier,
    STATE(12752), 1,
      sym__soft_identifier,
    STATE(13111), 1,
      sym_identifier,
    STATE(13143), 1,
      sym__type_identifier,
    STATE(12273), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12093), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560719] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14325), 1,
      anon_sym_LPAREN,
    ACTIONS(14328), 1,
      sym__automatic_semicolon,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(12274), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__class_constructor_repeat1,
    ACTIONS(14323), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [560750] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6740), 1,
      sym__alpha_identifier,
    ACTIONS(6754), 1,
      sym__backquoted_id,
    ACTIONS(14331), 1,
      sym_operator_identifier,
    STATE(7274), 1,
      sym__soft_identifier,
    STATE(7608), 1,
      sym_identifier,
    STATE(7613), 1,
      sym__type_identifier,
    STATE(12275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6750), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560787] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12113), 1,
      sym__alpha_identifier,
    ACTIONS(12121), 1,
      sym__backquoted_id,
    ACTIONS(14333), 1,
      sym_operator_identifier,
    STATE(11035), 1,
      sym__soft_identifier,
    STATE(11230), 1,
      sym_identifier,
    STATE(11233), 1,
      sym__type_identifier,
    STATE(12276), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12117), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560824] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12241), 1,
      sym__alpha_identifier,
    ACTIONS(12249), 1,
      sym__backquoted_id,
    ACTIONS(14335), 1,
      sym_operator_identifier,
    STATE(11224), 1,
      sym__soft_identifier,
    STATE(11469), 1,
      sym_identifier,
    STATE(14692), 1,
      sym__object_definition,
    STATE(12277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12245), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560861] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14337), 1,
      sym__alpha_identifier,
    ACTIONS(14339), 1,
      anon_sym_LBRACE,
    ACTIONS(14341), 1,
      anon_sym_LBRACK,
    ACTIONS(14345), 1,
      sym__backquoted_id,
    STATE(8411), 1,
      sym__soft_identifier,
    STATE(8486), 1,
      sym_identifier,
    STATE(12278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14343), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560898] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14197), 1,
      sym__alpha_identifier,
    ACTIONS(14205), 1,
      sym__backquoted_id,
    ACTIONS(14347), 1,
      anon_sym_LBRACE,
    ACTIONS(14349), 1,
      anon_sym_LBRACK,
    STATE(9349), 1,
      sym__soft_identifier,
    STATE(9464), 1,
      sym_identifier,
    STATE(12279), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14203), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560935] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6774), 1,
      sym__alpha_identifier,
    ACTIONS(6784), 1,
      sym__backquoted_id,
    ACTIONS(14351), 1,
      sym_operator_identifier,
    STATE(4626), 1,
      sym__soft_identifier,
    STATE(4852), 1,
      sym_identifier,
    STATE(4858), 1,
      sym__type_identifier,
    STATE(12280), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6780), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560972] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8378), 1,
      sym__alpha_identifier,
    ACTIONS(8390), 1,
      sym__backquoted_id,
    ACTIONS(14353), 1,
      sym_operator_identifier,
    STATE(13178), 1,
      sym__soft_identifier,
    STATE(13546), 1,
      sym__type_identifier,
    STATE(13589), 1,
      sym_identifier,
    STATE(12281), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8386), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561009] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6322), 1,
      sym__alpha_identifier,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(14355), 1,
      sym_operator_identifier,
    STATE(7267), 1,
      sym__soft_identifier,
    STATE(7752), 1,
      sym__type_identifier,
    STATE(7791), 1,
      sym_identifier,
    STATE(12282), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561046] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6114), 1,
      sym__alpha_identifier,
    ACTIONS(6128), 1,
      sym__backquoted_id,
    ACTIONS(14357), 1,
      sym_operator_identifier,
    STATE(5193), 1,
      sym__soft_identifier,
    STATE(5894), 1,
      sym_identifier,
    STATE(5900), 1,
      sym__type_identifier,
    STATE(12283), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6124), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561083] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12127), 1,
      sym__alpha_identifier,
    ACTIONS(12135), 1,
      sym__backquoted_id,
    ACTIONS(14359), 1,
      sym_operator_identifier,
    STATE(11798), 1,
      sym__soft_identifier,
    STATE(12305), 1,
      sym_identifier,
    STATE(12308), 1,
      sym__type_identifier,
    STATE(12284), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12131), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561120] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [561145] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4602), 1,
      sym__alpha_identifier,
    ACTIONS(4620), 1,
      sym__backquoted_id,
    ACTIONS(14361), 1,
      sym_operator_identifier,
    STATE(5195), 1,
      sym__soft_identifier,
    STATE(5960), 1,
      sym_identifier,
    STATE(5979), 1,
      sym__type_identifier,
    STATE(12286), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561182] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(13678), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(10875), 1,
      sym_identifier,
    STATE(11094), 1,
      sym__type_identifier,
    STATE(12287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561219] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(14363), 1,
      sym_operator_identifier,
    STATE(5538), 1,
      sym__soft_identifier,
    STATE(6032), 1,
      sym_identifier,
    STATE(6395), 1,
      sym__type_identifier,
    STATE(12288), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561256] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12139), 1,
      sym__alpha_identifier,
    ACTIONS(12147), 1,
      sym__backquoted_id,
    ACTIONS(14365), 1,
      sym_operator_identifier,
    STATE(12413), 1,
      sym__soft_identifier,
    STATE(12645), 1,
      sym__type_identifier,
    STATE(13023), 1,
      sym_identifier,
    STATE(12289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12143), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561293] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12290), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [561318] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14241), 1,
      sym__alpha_identifier,
    ACTIONS(14249), 1,
      sym__backquoted_id,
    ACTIONS(14367), 1,
      anon_sym_LBRACE,
    ACTIONS(14369), 1,
      anon_sym_LBRACK,
    STATE(6150), 1,
      sym__soft_identifier,
    STATE(6322), 1,
      sym_identifier,
    STATE(12291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14247), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561355] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6388), 1,
      sym__alpha_identifier,
    ACTIONS(6402), 1,
      sym__backquoted_id,
    ACTIONS(14371), 1,
      sym_operator_identifier,
    STATE(6548), 1,
      sym__soft_identifier,
    STATE(7155), 1,
      sym__type_identifier,
    STATE(7176), 1,
      sym_identifier,
    STATE(12292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6398), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561392] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12253), 1,
      sym__alpha_identifier,
    ACTIONS(12261), 1,
      sym__backquoted_id,
    ACTIONS(14150), 1,
      sym_operator_identifier,
    STATE(11063), 1,
      sym__soft_identifier,
    STATE(11965), 1,
      sym_identifier,
    STATE(13855), 1,
      sym__function_constructor,
    STATE(12293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561429] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12898), 1,
      sym__automatic_semicolon,
    STATE(12361), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(12294), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12896), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [561462] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(14375), 1,
      sym__automatic_semicolon,
    STATE(12274), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(12295), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14373), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [561495] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(14380), 1,
      sym__automatic_semicolon,
    STATE(12362), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(12296), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14378), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [561528] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(14385), 1,
      sym__automatic_semicolon,
    STATE(12274), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(12297), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14383), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [561561] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(14388), 1,
      sym_operator_identifier,
    STATE(4249), 1,
      sym__type_identifier,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(10661), 1,
      sym_identifier,
    STATE(12298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561598] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14294), 1,
      sym__alpha_identifier,
    ACTIONS(14302), 1,
      sym__backquoted_id,
    ACTIONS(14390), 1,
      anon_sym_LBRACE,
    ACTIONS(14392), 1,
      anon_sym_LBRACK,
    STATE(7771), 1,
      sym_identifier,
    STATE(7925), 1,
      sym__soft_identifier,
    STATE(12299), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14300), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561635] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14394), 1,
      anon_sym_with,
    STATE(12300), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [561662] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(14399), 1,
      anon_sym_extends,
    ACTIONS(14401), 1,
      anon_sym_LPAREN,
    STATE(13737), 1,
      aux_sym__full_enum_def_repeat1,
    STATE(14199), 1,
      sym_class_parameters,
    STATE(14424), 1,
      sym_extends_clause,
    STATE(14712), 1,
      sym_type_parameters,
    STATE(15261), 1,
      sym__full_enum_def,
    STATE(12301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14397), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [561703] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8579), 1,
      sym__alpha_identifier,
    ACTIONS(8591), 1,
      sym__backquoted_id,
    ACTIONS(14403), 1,
      sym_operator_identifier,
    STATE(5231), 1,
      sym__soft_identifier,
    STATE(5395), 1,
      sym__type_identifier,
    STATE(5403), 1,
      sym_identifier,
    STATE(12302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8587), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561740] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [561765] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12304), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [561790] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12305), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [561815] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [561840] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [561865] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [561890] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [561915] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12310), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [561940] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(14405), 1,
      sym_operator_identifier,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11143), 1,
      sym_identifier,
    STATE(13877), 1,
      sym__class_constructor,
    STATE(12311), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561977] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(14113), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(11638), 1,
      sym_identifier,
    STATE(13879), 1,
      sym__function_constructor,
    STATE(12312), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562014] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14337), 1,
      sym__alpha_identifier,
    ACTIONS(14345), 1,
      sym__backquoted_id,
    ACTIONS(14407), 1,
      anon_sym_LBRACE,
    ACTIONS(14409), 1,
      anon_sym_LBRACK,
    STATE(8116), 1,
      sym_identifier,
    STATE(8411), 1,
      sym__soft_identifier,
    STATE(12313), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14343), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562051] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14411), 1,
      anon_sym_catch,
    ACTIONS(14413), 1,
      anon_sym_finally,
    STATE(11980), 1,
      sym_finally_clause,
    STATE(13072), 1,
      sym_catch_clause,
    STATE(12314), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [562084] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4286), 1,
      sym__alpha_identifier,
    ACTIONS(4298), 1,
      sym__backquoted_id,
    ACTIONS(14415), 1,
      sym_operator_identifier,
    STATE(4467), 1,
      sym__soft_identifier,
    STATE(4718), 1,
      sym__type_identifier,
    STATE(4725), 1,
      sym_identifier,
    STATE(12315), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4294), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562121] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9137), 1,
      anon_sym_LBRACK,
    ACTIONS(9141), 1,
      anon_sym_POUND,
    ACTIONS(10123), 1,
      anon_sym_LPAREN,
    STATE(4355), 1,
      sym_type_arguments,
    STATE(4401), 1,
      sym_arguments,
    STATE(13259), 1,
      aux_sym_annotation_repeat1,
    STATE(12316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [562158] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(14113), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(11638), 1,
      sym_identifier,
    STATE(13884), 1,
      sym__function_constructor,
    STATE(12317), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562195] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(14405), 1,
      sym_operator_identifier,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11143), 1,
      sym_identifier,
    STATE(13886), 1,
      sym__class_constructor,
    STATE(12318), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562232] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14156), 1,
      anon_sym_match,
    ACTIONS(14417), 1,
      sym_operator_identifier,
    STATE(4184), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562269] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14419), 1,
      anon_sym_DOT,
    STATE(12320), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [562296] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(14405), 1,
      sym_operator_identifier,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11143), 1,
      sym_identifier,
    STATE(13878), 1,
      sym__class_constructor,
    STATE(12321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562333] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14421), 1,
      sym__alpha_identifier,
    ACTIONS(14423), 1,
      anon_sym_LBRACE,
    ACTIONS(14425), 1,
      anon_sym_LBRACK,
    ACTIONS(14429), 1,
      sym__backquoted_id,
    STATE(8754), 1,
      sym__soft_identifier,
    STATE(9166), 1,
      sym_identifier,
    STATE(12322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14427), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562370] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12848), 1,
      sym__alpha_identifier,
    ACTIONS(12856), 1,
      sym__backquoted_id,
    ACTIONS(14431), 1,
      sym_operator_identifier,
    STATE(13994), 1,
      sym__soft_identifier,
    STATE(14151), 1,
      sym_identifier,
    STATE(14702), 1,
      sym_simple_enum_case,
    STATE(12323), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12854), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562407] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14433), 1,
      anon_sym_with,
    STATE(12849), 1,
      aux_sym_compound_type_repeat1,
    STATE(14231), 1,
      sym_template_body,
    STATE(14232), 1,
      sym__refinement,
    STATE(14384), 1,
      sym_arguments,
    STATE(12324), 2,
      sym_comment,
      sym_block_comment,
    STATE(14185), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [562444] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(14113), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(11638), 1,
      sym_identifier,
    STATE(13891), 1,
      sym__function_constructor,
    STATE(12325), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562481] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13566), 1,
      anon_sym_LBRACK,
    ACTIONS(13572), 1,
      anon_sym_POUND,
    ACTIONS(13860), 1,
      anon_sym_LPAREN,
    STATE(13338), 1,
      aux_sym_annotation_repeat1,
    STATE(13407), 1,
      sym_type_arguments,
    STATE(13893), 1,
      sym_arguments,
    STATE(12326), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
  [562518] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14435), 1,
      sym__alpha_identifier,
    ACTIONS(14437), 1,
      anon_sym_LBRACE,
    ACTIONS(14439), 1,
      anon_sym_LBRACK,
    ACTIONS(14443), 1,
      sym__backquoted_id,
    STATE(6767), 1,
      sym__soft_identifier,
    STATE(6788), 1,
      sym_identifier,
    STATE(12327), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14441), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562555] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6570), 1,
      sym__backquoted_id,
    ACTIONS(14445), 1,
      sym_operator_identifier,
    STATE(4874), 1,
      sym__soft_identifier,
    STATE(5413), 1,
      sym__type_identifier,
    STATE(5420), 1,
      sym_identifier,
    STATE(12328), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6566), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562592] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12748), 1,
      aux_sym_compound_type_repeat1,
    STATE(14116), 1,
      sym_template_body,
    STATE(14122), 1,
      sym__refinement,
    STATE(14156), 1,
      sym_arguments,
    STATE(12329), 2,
      sym_comment,
      sym_block_comment,
    STATE(14037), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8114), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [562627] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 1,
      anon_sym_EQ_GT,
    ACTIONS(8414), 1,
      anon_sym_QMARK_EQ_GT,
    STATE(12330), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [562658] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14187), 1,
      sym__alpha_identifier,
    ACTIONS(14195), 1,
      sym__backquoted_id,
    ACTIONS(14447), 1,
      anon_sym_LBRACE,
    ACTIONS(14449), 1,
      anon_sym_LBRACK,
    STATE(10279), 1,
      sym__soft_identifier,
    STATE(10387), 1,
      sym_identifier,
    STATE(12331), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14193), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562695] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6588), 1,
      sym__backquoted_id,
    ACTIONS(14451), 1,
      sym_operator_identifier,
    STATE(6199), 1,
      sym__soft_identifier,
    STATE(7234), 1,
      sym__type_identifier,
    STATE(7243), 1,
      sym_identifier,
    STATE(12332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562732] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12333), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [562757] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14453), 1,
      anon_sym_match,
    ACTIONS(14455), 1,
      sym_operator_identifier,
    STATE(4211), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562794] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(12335), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [562821] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8527), 1,
      sym__alpha_identifier,
    ACTIONS(8539), 1,
      sym__backquoted_id,
    ACTIONS(14457), 1,
      sym_operator_identifier,
    STATE(4829), 1,
      sym__type_identifier,
    STATE(4853), 1,
      sym_identifier,
    STATE(5008), 1,
      sym__soft_identifier,
    STATE(12336), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8535), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562858] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 12,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [562883] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6614), 1,
      sym__backquoted_id,
    ACTIONS(14459), 1,
      sym_operator_identifier,
    STATE(5817), 1,
      sym__soft_identifier,
    STATE(6484), 1,
      sym__type_identifier,
    STATE(6501), 1,
      sym_identifier,
    STATE(12338), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6610), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562920] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(12339), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [562947] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14461), 1,
      anon_sym_match,
    ACTIONS(14463), 1,
      sym_operator_identifier,
    STATE(4186), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562984] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 12,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [563009] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14455), 1,
      sym_operator_identifier,
    ACTIONS(14465), 1,
      anon_sym_match,
    STATE(4211), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12342), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563046] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    ACTIONS(13414), 1,
      anon_sym_LT_COLON,
    ACTIONS(13416), 1,
      anon_sym_GT_COLON,
    ACTIONS(13418), 1,
      anon_sym_LT_PERCENT,
    STATE(13081), 1,
      sym_lower_bound,
    STATE(13644), 1,
      sym_upper_bound,
    STATE(13646), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14169), 1,
      aux_sym__type_parameter_repeat2,
    STATE(14680), 1,
      sym_view_bound,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(14467), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(12343), 2,
      sym_comment,
      sym_block_comment,
  [563091] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14469), 1,
      anon_sym_catch,
    ACTIONS(14471), 1,
      anon_sym_finally,
    STATE(11980), 1,
      sym_finally_clause,
    STATE(13294), 1,
      sym_catch_clause,
    STATE(12344), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
  [563124] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12345), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [563149] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14461), 1,
      anon_sym_match,
    ACTIONS(14473), 1,
      sym_operator_identifier,
    STATE(4182), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563186] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6792), 1,
      sym__alpha_identifier,
    ACTIONS(6802), 1,
      sym__backquoted_id,
    ACTIONS(14475), 1,
      sym_operator_identifier,
    STATE(8149), 1,
      sym__soft_identifier,
    STATE(9219), 1,
      sym__type_identifier,
    STATE(9234), 1,
      sym_identifier,
    STATE(12347), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6798), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563223] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14477), 1,
      anon_sym_match,
    ACTIONS(14479), 1,
      sym_operator_identifier,
    STATE(4194), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563260] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14481), 1,
      sym__alpha_identifier,
    ACTIONS(14483), 1,
      anon_sym_LBRACE,
    ACTIONS(14485), 1,
      anon_sym_LBRACK,
    ACTIONS(14489), 1,
      sym__backquoted_id,
    STATE(9974), 1,
      sym_identifier,
    STATE(10042), 1,
      sym__soft_identifier,
    STATE(12349), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14487), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563297] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14491), 1,
      anon_sym_match,
    ACTIONS(14493), 1,
      sym_operator_identifier,
    STATE(4230), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12350), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563334] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9341), 1,
      anon_sym_LPAREN,
    STATE(12360), 1,
      aux_sym_annotation_repeat1,
    STATE(13120), 1,
      sym_arguments,
    STATE(12351), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [563365] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14495), 1,
      sym__alpha_identifier,
    ACTIONS(14497), 1,
      anon_sym_LBRACE,
    ACTIONS(14499), 1,
      anon_sym_LBRACK,
    ACTIONS(14503), 1,
      sym__backquoted_id,
    STATE(8205), 1,
      sym__soft_identifier,
    STATE(8404), 1,
      sym_identifier,
    STATE(12352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14501), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563402] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12241), 1,
      sym__alpha_identifier,
    ACTIONS(12249), 1,
      sym__backquoted_id,
    ACTIONS(14335), 1,
      sym_operator_identifier,
    STATE(11224), 1,
      sym__soft_identifier,
    STATE(11469), 1,
      sym_identifier,
    STATE(14443), 1,
      sym__object_definition,
    STATE(12353), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12245), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563439] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(14505), 1,
      sym_operator_identifier,
    STATE(7680), 1,
      sym__soft_identifier,
    STATE(8453), 1,
      sym__type_identifier,
    STATE(8483), 1,
      sym_identifier,
    STATE(12354), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563476] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(14507), 1,
      sym_operator_identifier,
    STATE(4512), 1,
      sym__soft_identifier,
    STATE(13725), 1,
      sym_identifier,
    STATE(13896), 1,
      sym__namespace_expression,
    STATE(12355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563513] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8410), 1,
      sym__outdent,
    ACTIONS(8412), 1,
      anon_sym_case,
    STATE(12356), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [563544] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14461), 1,
      anon_sym_match,
    ACTIONS(14509), 1,
      sym_operator_identifier,
    STATE(4203), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12357), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563581] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14278), 1,
      sym__alpha_identifier,
    ACTIONS(14286), 1,
      sym__backquoted_id,
    ACTIONS(14511), 1,
      anon_sym_LBRACE,
    ACTIONS(14513), 1,
      anon_sym_LBRACK,
    STATE(9910), 1,
      sym__soft_identifier,
    STATE(9937), 1,
      sym_identifier,
    STATE(12358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14284), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563618] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(14517), 1,
      sym__automatic_semicolon,
    STATE(12431), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(12359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14515), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [563651] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14520), 1,
      anon_sym_LPAREN,
    STATE(13120), 1,
      sym_arguments,
    STATE(12360), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [563680] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(14525), 1,
      sym__automatic_semicolon,
    STATE(12274), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(12361), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14523), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [563713] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(14530), 1,
      sym__automatic_semicolon,
    STATE(12274), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(12362), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14528), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [563746] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(14533), 1,
      anon_sym_extends,
    ACTIONS(14535), 1,
      anon_sym_LPAREN,
    STATE(13742), 1,
      aux_sym__full_enum_def_repeat1,
    STATE(14220), 1,
      sym_class_parameters,
    STATE(14520), 1,
      sym_extends_clause,
    STATE(14634), 1,
      sym_type_parameters,
    STATE(15308), 1,
      sym__full_enum_def,
    STATE(12363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14397), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [563787] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12364), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [563812] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12365), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [563837] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [563862] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4572), 1,
      sym__alpha_identifier,
    ACTIONS(4590), 1,
      sym__backquoted_id,
    ACTIONS(14537), 1,
      sym_operator_identifier,
    STATE(5025), 1,
      sym__soft_identifier,
    STATE(5309), 1,
      sym__type_identifier,
    STATE(5321), 1,
      sym_identifier,
    STATE(12367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4584), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563899] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14461), 1,
      anon_sym_match,
    ACTIONS(14539), 1,
      sym_operator_identifier,
    STATE(4229), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563936] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12369), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [563961] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14541), 1,
      sym__alpha_identifier,
    ACTIONS(14543), 1,
      anon_sym_LBRACE,
    ACTIONS(14545), 1,
      anon_sym_LBRACK,
    ACTIONS(14549), 1,
      sym__backquoted_id,
    STATE(6504), 1,
      sym_identifier,
    STATE(6544), 1,
      sym__soft_identifier,
    STATE(12370), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14547), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563998] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12371), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [564023] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [564048] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14461), 1,
      anon_sym_match,
    ACTIONS(14551), 1,
      sym_operator_identifier,
    STATE(4188), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564085] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9856), 1,
      anon_sym_COLON,
    STATE(12374), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [564112] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8503), 1,
      sym__alpha_identifier,
    ACTIONS(8511), 1,
      sym__backquoted_id,
    ACTIONS(14553), 1,
      sym_operator_identifier,
    STATE(7788), 1,
      sym__soft_identifier,
    STATE(7954), 1,
      sym_identifier,
    STATE(8028), 1,
      sym__type_identifier,
    STATE(12375), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8507), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564149] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8595), 1,
      sym__alpha_identifier,
    ACTIONS(8603), 1,
      sym__backquoted_id,
    ACTIONS(14555), 1,
      sym_operator_identifier,
    STATE(6470), 1,
      sym__soft_identifier,
    STATE(6558), 1,
      sym__type_identifier,
    STATE(6569), 1,
      sym_identifier,
    STATE(12376), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8599), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564186] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12377), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [564211] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [564236] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14557), 1,
      anon_sym_match,
    ACTIONS(14559), 1,
      sym_operator_identifier,
    STATE(4242), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12379), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564273] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12380), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [564298] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(14120), 1,
      sym_operator_identifier,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11166), 1,
      sym_identifier,
    STATE(14393), 1,
      sym__object_definition,
    STATE(12381), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564335] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12382), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [564360] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12383), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [564385] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [564410] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 12,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [564435] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(13441), 1,
      sym_operator_identifier,
    ACTIONS(14477), 1,
      anon_sym_match,
    STATE(4192), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12386), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564472] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12387), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 12,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [564497] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12388), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [564522] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14491), 1,
      anon_sym_match,
    ACTIONS(14561), 1,
      sym_operator_identifier,
    STATE(4185), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12389), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564559] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [564584] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14563), 1,
      sym__alpha_identifier,
    ACTIONS(14565), 1,
      anon_sym_LBRACE,
    ACTIONS(14567), 1,
      anon_sym_LBRACK,
    ACTIONS(14571), 1,
      sym__backquoted_id,
    STATE(10781), 1,
      sym_identifier,
    STATE(10878), 1,
      sym__soft_identifier,
    STATE(12391), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14569), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564621] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12392), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [564646] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14262), 1,
      sym__alpha_identifier,
    ACTIONS(14270), 1,
      sym__backquoted_id,
    ACTIONS(14573), 1,
      anon_sym_LBRACE,
    ACTIONS(14575), 1,
      anon_sym_LBRACK,
    STATE(8140), 1,
      sym_identifier,
    STATE(8610), 1,
      sym__soft_identifier,
    STATE(12393), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14268), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564683] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12394), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [564708] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14577), 1,
      anon_sym_LBRACK,
    ACTIONS(14579), 1,
      anon_sym_match,
    STATE(6918), 1,
      sym_type_arguments,
    STATE(12395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [564739] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [564764] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4376), 1,
      sym__alpha_identifier,
    ACTIONS(4394), 1,
      sym__backquoted_id,
    ACTIONS(14581), 1,
      sym_operator_identifier,
    STATE(5049), 1,
      sym__soft_identifier,
    STATE(5948), 1,
      sym__type_identifier,
    STATE(5957), 1,
      sym_identifier,
    STATE(12397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564801] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14461), 1,
      anon_sym_match,
    ACTIONS(14583), 1,
      sym_operator_identifier,
    STATE(4196), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564838] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [564863] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [564888] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14469), 1,
      anon_sym_catch,
    ACTIONS(14585), 1,
      anon_sym_finally,
    STATE(12577), 1,
      sym_finally_clause,
    STATE(13253), 1,
      sym_catch_clause,
    STATE(12401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
  [564921] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14461), 1,
      anon_sym_match,
    ACTIONS(14587), 1,
      sym_operator_identifier,
    STATE(4191), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12402), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564958] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [564983] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8280), 1,
      sym__alpha_identifier,
    ACTIONS(8292), 1,
      sym__backquoted_id,
    ACTIONS(14589), 1,
      sym_operator_identifier,
    STATE(11176), 1,
      sym__soft_identifier,
    STATE(11646), 1,
      sym__type_identifier,
    STATE(11695), 1,
      sym_identifier,
    STATE(12404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8288), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565020] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14461), 1,
      anon_sym_match,
    ACTIONS(14591), 1,
      sym_operator_identifier,
    STATE(4208), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12405), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565057] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8607), 1,
      sym__alpha_identifier,
    ACTIONS(8615), 1,
      sym__backquoted_id,
    ACTIONS(14593), 1,
      sym_operator_identifier,
    STATE(6383), 1,
      sym__soft_identifier,
    STATE(6597), 1,
      sym__type_identifier,
    STATE(6604), 1,
      sym_identifier,
    STATE(12406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8611), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565094] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12407), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12715), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [565119] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14411), 1,
      anon_sym_catch,
    ACTIONS(14595), 1,
      anon_sym_finally,
    STATE(12577), 1,
      sym_finally_clause,
    STATE(13071), 1,
      sym_catch_clause,
    STATE(12408), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [565152] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14597), 1,
      anon_sym_match,
    ACTIONS(14599), 1,
      sym_operator_identifier,
    STATE(4224), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565189] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12410), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [565214] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14601), 1,
      sym__alpha_identifier,
    ACTIONS(14603), 1,
      anon_sym_LBRACE,
    ACTIONS(14605), 1,
      anon_sym_LBRACK,
    ACTIONS(14609), 1,
      sym__backquoted_id,
    STATE(8182), 1,
      sym__soft_identifier,
    STATE(8387), 1,
      sym_identifier,
    STATE(12411), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14607), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565251] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [565276] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12413), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [565301] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12241), 1,
      sym__alpha_identifier,
    ACTIONS(12249), 1,
      sym__backquoted_id,
    ACTIONS(14335), 1,
      sym_operator_identifier,
    STATE(11224), 1,
      sym__soft_identifier,
    STATE(11469), 1,
      sym_identifier,
    STATE(14718), 1,
      sym__object_definition,
    STATE(12414), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12245), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565338] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(473), 1,
      sym__alpha_identifier,
    ACTIONS(537), 1,
      sym__backquoted_id,
    ACTIONS(14181), 1,
      sym_operator_identifier,
    STATE(5776), 1,
      sym__soft_identifier,
    STATE(13835), 1,
      sym_identifier,
    STATE(14014), 1,
      sym__namespace_expression,
    STATE(12415), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(659), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565375] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(473), 1,
      sym__alpha_identifier,
    ACTIONS(537), 1,
      sym__backquoted_id,
    ACTIONS(14181), 1,
      sym_operator_identifier,
    STATE(5776), 1,
      sym__soft_identifier,
    STATE(13835), 1,
      sym_identifier,
    STATE(14065), 1,
      sym__namespace_expression,
    STATE(12416), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(659), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565412] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(13441), 1,
      sym_operator_identifier,
    ACTIONS(14611), 1,
      anon_sym_match,
    STATE(4192), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565449] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12418), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13288), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [565474] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13290), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [565499] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12253), 1,
      sym__alpha_identifier,
    ACTIONS(12261), 1,
      sym__backquoted_id,
    ACTIONS(14150), 1,
      sym_operator_identifier,
    STATE(11063), 1,
      sym__soft_identifier,
    STATE(11965), 1,
      sym_identifier,
    STATE(13853), 1,
      sym__function_constructor,
    STATE(12420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565536] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14613), 1,
      sym__alpha_identifier,
    ACTIONS(14615), 1,
      anon_sym_LBRACE,
    ACTIONS(14617), 1,
      anon_sym_LBRACK,
    ACTIONS(14621), 1,
      sym__backquoted_id,
    STATE(7497), 1,
      sym_identifier,
    STATE(8026), 1,
      sym__soft_identifier,
    STATE(12421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14619), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565573] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14613), 1,
      sym__alpha_identifier,
    ACTIONS(14621), 1,
      sym__backquoted_id,
    ACTIONS(14623), 1,
      anon_sym_LBRACE,
    ACTIONS(14625), 1,
      anon_sym_LBRACK,
    STATE(7523), 1,
      sym_identifier,
    STATE(8026), 1,
      sym__soft_identifier,
    STATE(12422), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14619), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565610] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14627), 1,
      anon_sym_end,
    STATE(7402), 1,
      sym__end_marker,
    STATE(12423), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [565639] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14477), 1,
      anon_sym_match,
    ACTIONS(14629), 1,
      sym_operator_identifier,
    STATE(4215), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12424), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565676] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(14631), 1,
      anon_sym_LBRACE,
    ACTIONS(14633), 1,
      anon_sym_LBRACK,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(11183), 1,
      sym_identifier,
    STATE(12425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565713] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4138), 1,
      sym__alpha_identifier,
    ACTIONS(4156), 1,
      sym__backquoted_id,
    ACTIONS(14635), 1,
      sym_operator_identifier,
    STATE(6041), 1,
      sym__soft_identifier,
    STATE(7351), 1,
      sym__type_identifier,
    STATE(7361), 1,
      sym_identifier,
    STATE(12426), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4150), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565750] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12427), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [565775] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14477), 1,
      anon_sym_match,
    ACTIONS(14637), 1,
      sym_operator_identifier,
    STATE(4232), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12428), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565812] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14477), 1,
      anon_sym_match,
    ACTIONS(14639), 1,
      sym_operator_identifier,
    STATE(4202), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12429), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565849] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14641), 1,
      sym__alpha_identifier,
    ACTIONS(14643), 1,
      anon_sym_LBRACE,
    ACTIONS(14645), 1,
      anon_sym_LBRACK,
    ACTIONS(14649), 1,
      sym__backquoted_id,
    STATE(5684), 1,
      sym_identifier,
    STATE(5790), 1,
      sym__soft_identifier,
    STATE(12430), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14647), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565886] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(14653), 1,
      sym__automatic_semicolon,
    STATE(12274), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(12431), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14651), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [565919] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14421), 1,
      sym__alpha_identifier,
    ACTIONS(14429), 1,
      sym__backquoted_id,
    ACTIONS(14656), 1,
      anon_sym_LBRACE,
    ACTIONS(14658), 1,
      anon_sym_LBRACK,
    STATE(8754), 1,
      sym__soft_identifier,
    STATE(9309), 1,
      sym_identifier,
    STATE(12432), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14427), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565956] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8909), 1,
      sym__alpha_identifier,
    ACTIONS(8917), 1,
      sym__backquoted_id,
    ACTIONS(14660), 1,
      sym_operator_identifier,
    STATE(6699), 1,
      sym__soft_identifier,
    STATE(7367), 1,
      sym__type_identifier,
    STATE(7376), 1,
      sym_identifier,
    STATE(12433), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8913), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565993] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12434), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [566018] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12435), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [566043] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8885), 1,
      sym__alpha_identifier,
    ACTIONS(8893), 1,
      sym__backquoted_id,
    ACTIONS(14662), 1,
      sym_operator_identifier,
    STATE(8720), 1,
      sym__type_identifier,
    STATE(8990), 1,
      sym__soft_identifier,
    STATE(9165), 1,
      sym_identifier,
    STATE(12436), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8889), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566080] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14664), 1,
      anon_sym_match,
    ACTIONS(14666), 1,
      sym_operator_identifier,
    STATE(4238), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566117] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7224), 1,
      sym__alpha_identifier,
    ACTIONS(7236), 1,
      sym__backquoted_id,
    ACTIONS(14668), 1,
      sym_operator_identifier,
    STATE(4249), 1,
      sym__type_identifier,
    STATE(9899), 1,
      sym__soft_identifier,
    STATE(10768), 1,
      sym_identifier,
    STATE(12438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7230), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566154] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4468), 1,
      sym__alpha_identifier,
    ACTIONS(4486), 1,
      sym__backquoted_id,
    ACTIONS(14670), 1,
      sym_operator_identifier,
    STATE(6759), 1,
      sym__soft_identifier,
    STATE(7875), 1,
      sym_identifier,
    STATE(8083), 1,
      sym__type_identifier,
    STATE(12439), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4480), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566191] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12440), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12703), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [566216] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14672), 1,
      anon_sym_match,
    ACTIONS(14674), 1,
      sym_operator_identifier,
    STATE(4197), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12441), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566253] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12442), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13298), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [566278] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12443), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [566303] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12444), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12606), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [566328] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14491), 1,
      anon_sym_match,
    ACTIONS(14676), 1,
      sym_operator_identifier,
    STATE(4198), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12445), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566365] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12446), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13306), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [566390] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12447), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [566415] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14672), 1,
      anon_sym_match,
    ACTIONS(14678), 1,
      sym_operator_identifier,
    STATE(4209), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12448), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566452] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12449), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13310), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [566477] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14491), 1,
      anon_sym_match,
    ACTIONS(14680), 1,
      sym_operator_identifier,
    STATE(4223), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12450), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566514] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14435), 1,
      sym__alpha_identifier,
    ACTIONS(14443), 1,
      sym__backquoted_id,
    ACTIONS(14682), 1,
      anon_sym_LBRACE,
    ACTIONS(14684), 1,
      anon_sym_LBRACK,
    STATE(6701), 1,
      sym_identifier,
    STATE(6767), 1,
      sym__soft_identifier,
    STATE(12451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14441), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566551] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14686), 1,
      anon_sym_match,
    ACTIONS(14688), 1,
      sym_operator_identifier,
    STATE(4225), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12452), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566588] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12453), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13312), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [566613] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13316), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12454), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13314), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [566640] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8625), 1,
      sym__alpha_identifier,
    ACTIONS(8633), 1,
      sym__backquoted_id,
    ACTIONS(14690), 1,
      sym_operator_identifier,
    STATE(8095), 1,
      sym__type_identifier,
    STATE(8303), 1,
      sym__soft_identifier,
    STATE(8597), 1,
      sym_identifier,
    STATE(12455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8629), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566677] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12456), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13319), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [566702] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14692), 1,
      anon_sym_match,
    ACTIONS(14694), 1,
      sym_operator_identifier,
    STATE(4189), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12457), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566739] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14601), 1,
      sym__alpha_identifier,
    ACTIONS(14609), 1,
      sym__backquoted_id,
    ACTIONS(14696), 1,
      anon_sym_LBRACE,
    ACTIONS(14698), 1,
      anon_sym_LBRACK,
    STATE(8092), 1,
      sym_identifier,
    STATE(8182), 1,
      sym__soft_identifier,
    STATE(12458), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14607), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566776] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13321), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [566801] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14700), 1,
      anon_sym_match,
    ACTIONS(14702), 1,
      sym_operator_identifier,
    STATE(4221), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12460), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566838] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12461), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13323), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [566863] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14664), 1,
      anon_sym_match,
    ACTIONS(14704), 1,
      sym_operator_identifier,
    STATE(4237), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12462), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566900] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14664), 1,
      anon_sym_match,
    ACTIONS(14706), 1,
      sym_operator_identifier,
    STATE(4243), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12463), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566937] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [566962] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13329), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [566987] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14664), 1,
      anon_sym_match,
    ACTIONS(14708), 1,
      sym_operator_identifier,
    STATE(4187), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12466), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567024] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12101), 1,
      sym__alpha_identifier,
    ACTIONS(12109), 1,
      sym__backquoted_id,
    ACTIONS(14710), 1,
      sym_operator_identifier,
    STATE(10865), 1,
      sym__soft_identifier,
    STATE(11058), 1,
      sym_identifier,
    STATE(11103), 1,
      sym__type_identifier,
    STATE(12467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12105), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567061] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12901), 1,
      sym__alpha_identifier,
    ACTIONS(12905), 1,
      sym__backquoted_id,
    ACTIONS(14712), 1,
      sym_operator_identifier,
    STATE(13840), 1,
      sym__soft_identifier,
    STATE(14114), 1,
      sym_identifier,
    STATE(14420), 1,
      sym_simple_enum_case,
    STATE(12468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12903), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567098] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14714), 1,
      anon_sym_match,
    ACTIONS(14716), 1,
      sym_operator_identifier,
    STATE(4222), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12469), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567135] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(14718), 1,
      sym_operator_identifier,
    STATE(6834), 1,
      sym__soft_identifier,
    STATE(7636), 1,
      sym_identifier,
    STATE(7871), 1,
      sym__type_identifier,
    STATE(12470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567172] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14720), 1,
      anon_sym_LBRACK,
    STATE(6885), 1,
      sym_type_arguments,
    STATE(12471), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13388), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [567201] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12472), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13331), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [567226] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14722), 1,
      anon_sym_match,
    ACTIONS(14724), 1,
      sym_operator_identifier,
    STATE(4236), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567263] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13333), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [567288] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14577), 1,
      anon_sym_LBRACK,
    STATE(6918), 1,
      sym_type_arguments,
    STATE(12475), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13388), 10,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [567317] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13340), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13338), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [567344] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13347), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13345), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [567371] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14672), 1,
      anon_sym_match,
    ACTIONS(14726), 1,
      sym_operator_identifier,
    STATE(4217), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567408] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(12479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [567435] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14728), 1,
      anon_sym_match,
    ACTIONS(14730), 1,
      sym_operator_identifier,
    STATE(4228), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12480), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567472] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14722), 1,
      anon_sym_match,
    ACTIONS(14732), 1,
      sym_operator_identifier,
    STATE(4200), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567509] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12717), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [567534] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14672), 1,
      anon_sym_match,
    ACTIONS(14734), 1,
      sym_operator_identifier,
    STATE(4212), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12483), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567571] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12199), 1,
      sym__alpha_identifier,
    ACTIONS(12207), 1,
      sym__backquoted_id,
    ACTIONS(14736), 1,
      sym_operator_identifier,
    STATE(10957), 1,
      sym__soft_identifier,
    STATE(11208), 1,
      sym__type_identifier,
    STATE(11212), 1,
      sym_identifier,
    STATE(12484), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12203), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567608] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14728), 1,
      anon_sym_match,
    ACTIONS(14738), 1,
      sym_operator_identifier,
    STATE(4233), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567645] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14740), 1,
      anon_sym_LBRACK,
    ACTIONS(14742), 1,
      anon_sym_match,
    STATE(6704), 1,
      sym_type_arguments,
    STATE(12486), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 9,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [567676] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11563), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(12487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11561), 10,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [567703] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14744), 1,
      anon_sym_match,
    ACTIONS(14746), 1,
      sym_operator_identifier,
    STATE(4231), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12488), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567740] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14686), 1,
      anon_sym_match,
    ACTIONS(14748), 1,
      sym_operator_identifier,
    STATE(4227), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567777] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14740), 1,
      anon_sym_LBRACK,
    STATE(6704), 1,
      sym_type_arguments,
    STATE(12490), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [567806] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14740), 1,
      anon_sym_LBRACK,
    STATE(6704), 1,
      sym_type_arguments,
    STATE(12491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [567835] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14740), 1,
      anon_sym_LBRACK,
    ACTIONS(14742), 1,
      anon_sym_match,
    STATE(6704), 1,
      sym_type_arguments,
    STATE(12492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 9,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [567866] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14740), 1,
      anon_sym_LBRACK,
    STATE(6704), 1,
      sym_type_arguments,
    STATE(12493), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [567895] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14740), 1,
      anon_sym_LBRACK,
    STATE(6704), 1,
      sym_type_arguments,
    STATE(12494), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [567924] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14750), 1,
      anon_sym_match,
    ACTIONS(14752), 1,
      sym_operator_identifier,
    STATE(4240), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12495), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567961] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8637), 1,
      sym__alpha_identifier,
    ACTIONS(8649), 1,
      sym__backquoted_id,
    ACTIONS(14754), 1,
      sym_operator_identifier,
    STATE(9867), 1,
      sym__soft_identifier,
    STATE(9946), 1,
      sym_identifier,
    STATE(10072), 1,
      sym__type_identifier,
    STATE(12496), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8645), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567998] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14756), 1,
      anon_sym_match,
    ACTIONS(14758), 1,
      sym_operator_identifier,
    STATE(4241), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12497), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568035] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14720), 1,
      anon_sym_LBRACK,
    ACTIONS(14760), 1,
      anon_sym_match,
    STATE(6885), 1,
      sym_type_arguments,
    STATE(12498), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 9,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [568066] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [568091] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14700), 1,
      anon_sym_match,
    ACTIONS(14762), 1,
      sym_operator_identifier,
    STATE(4234), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12500), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568128] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14720), 1,
      anon_sym_LBRACK,
    STATE(6885), 1,
      sym_type_arguments,
    STATE(12501), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [568157] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14720), 1,
      anon_sym_LBRACK,
    STATE(6885), 1,
      sym_type_arguments,
    STATE(12502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [568186] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14720), 1,
      anon_sym_LBRACK,
    ACTIONS(14760), 1,
      anon_sym_match,
    STATE(6885), 1,
      sym_type_arguments,
    STATE(12503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 9,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [568217] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14720), 1,
      anon_sym_LBRACK,
    STATE(6885), 1,
      sym_type_arguments,
    STATE(12504), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [568246] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14720), 1,
      anon_sym_LBRACK,
    STATE(6885), 1,
      sym_type_arguments,
    STATE(12505), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [568275] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14722), 1,
      anon_sym_match,
    ACTIONS(14764), 1,
      sym_operator_identifier,
    STATE(4193), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568312] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14577), 1,
      anon_sym_LBRACK,
    STATE(6918), 1,
      sym_type_arguments,
    STATE(12507), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 10,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [568341] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14577), 1,
      anon_sym_LBRACK,
    STATE(6918), 1,
      sym_type_arguments,
    STATE(12508), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 10,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [568370] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12509), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [568395] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14728), 1,
      anon_sym_match,
    ACTIONS(14766), 1,
      sym_operator_identifier,
    STATE(4235), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12510), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568432] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14768), 1,
      sym__alpha_identifier,
    ACTIONS(14770), 1,
      anon_sym_LBRACE,
    ACTIONS(14772), 1,
      anon_sym_LBRACK,
    ACTIONS(14776), 1,
      sym__backquoted_id,
    STATE(6884), 1,
      sym_identifier,
    STATE(7047), 1,
      sym__soft_identifier,
    STATE(12511), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14774), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568469] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14481), 1,
      sym__alpha_identifier,
    ACTIONS(14489), 1,
      sym__backquoted_id,
    ACTIONS(14778), 1,
      anon_sym_LBRACE,
    ACTIONS(14780), 1,
      anon_sym_LBRACK,
    STATE(9844), 1,
      sym_identifier,
    STATE(10042), 1,
      sym__soft_identifier,
    STATE(12512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14487), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568506] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8653), 1,
      sym__alpha_identifier,
    ACTIONS(8665), 1,
      sym__backquoted_id,
    ACTIONS(14782), 1,
      sym_operator_identifier,
    STATE(4660), 1,
      sym__type_identifier,
    STATE(4675), 1,
      sym_identifier,
    STATE(4727), 1,
      sym__soft_identifier,
    STATE(12513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8661), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568543] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14722), 1,
      anon_sym_match,
    ACTIONS(14784), 1,
      sym_operator_identifier,
    STATE(4214), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12514), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568580] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12515), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [568605] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14728), 1,
      anon_sym_match,
    ACTIONS(14786), 1,
      sym_operator_identifier,
    STATE(4216), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12516), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568642] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9856), 1,
      anon_sym_COLON,
    STATE(12517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [568669] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(14113), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(11638), 1,
      sym_identifier,
    STATE(14135), 1,
      sym__function_constructor,
    STATE(12518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568706] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14744), 1,
      anon_sym_match,
    ACTIONS(14788), 1,
      sym_operator_identifier,
    STATE(4213), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12519), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568743] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(14120), 1,
      sym_operator_identifier,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11166), 1,
      sym_identifier,
    STATE(14181), 1,
      sym__object_definition,
    STATE(12520), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568780] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(14507), 1,
      sym_operator_identifier,
    STATE(4512), 1,
      sym__soft_identifier,
    STATE(13725), 1,
      sym_identifier,
    STATE(13865), 1,
      sym__namespace_expression,
    STATE(12521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568817] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14750), 1,
      anon_sym_match,
    ACTIONS(14790), 1,
      sym_operator_identifier,
    STATE(4207), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12522), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568854] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14577), 1,
      anon_sym_LBRACK,
    ACTIONS(14579), 1,
      anon_sym_match,
    STATE(6918), 1,
      sym_type_arguments,
    STATE(12523), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [568885] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14792), 1,
      anon_sym_match,
    ACTIONS(14794), 1,
      sym_operator_identifier,
    STATE(4190), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568922] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12525), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [568947] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12156), 1,
      sym__alpha_identifier,
    ACTIONS(12164), 1,
      sym__backquoted_id,
    ACTIONS(14796), 1,
      sym_operator_identifier,
    STATE(8068), 1,
      sym__soft_identifier,
    STATE(8287), 1,
      sym__type_identifier,
    STATE(8449), 1,
      sym_identifier,
    STATE(12526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12160), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568984] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4510), 1,
      sym__alpha_identifier,
    ACTIONS(4522), 1,
      sym__backquoted_id,
    ACTIONS(14798), 1,
      sym_operator_identifier,
    STATE(4572), 1,
      sym__soft_identifier,
    STATE(4767), 1,
      sym__type_identifier,
    STATE(4790), 1,
      sym_identifier,
    STATE(12527), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4518), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569021] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13566), 1,
      anon_sym_LBRACK,
    ACTIONS(13568), 1,
      anon_sym_AT,
    ACTIONS(13572), 1,
      anon_sym_POUND,
    STATE(13407), 1,
      sym_type_arguments,
    STATE(13507), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13894), 1,
      sym_annotation,
    STATE(12528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [569058] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14756), 1,
      anon_sym_match,
    ACTIONS(14800), 1,
      sym_operator_identifier,
    STATE(4220), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12529), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569095] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14802), 1,
      sym__alpha_identifier,
    ACTIONS(14804), 1,
      anon_sym_LBRACE,
    ACTIONS(14806), 1,
      anon_sym_LBRACK,
    ACTIONS(14810), 1,
      sym__backquoted_id,
    STATE(9391), 1,
      sym_identifier,
    STATE(9428), 1,
      sym__soft_identifier,
    STATE(12530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14808), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569132] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14802), 1,
      sym__alpha_identifier,
    ACTIONS(14810), 1,
      sym__backquoted_id,
    ACTIONS(14812), 1,
      anon_sym_LBRACE,
    ACTIONS(14814), 1,
      anon_sym_LBRACK,
    STATE(9392), 1,
      sym_identifier,
    STATE(9428), 1,
      sym__soft_identifier,
    STATE(12531), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14808), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569169] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14577), 1,
      anon_sym_LBRACK,
    STATE(6918), 1,
      sym_type_arguments,
    STATE(12532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 10,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [569198] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14816), 1,
      anon_sym_match,
    ACTIONS(14818), 1,
      sym_operator_identifier,
    STATE(4199), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12533), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569235] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12534), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [569260] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14820), 1,
      anon_sym_match,
    ACTIONS(14822), 1,
      sym_operator_identifier,
    STATE(4201), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12535), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569297] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14824), 1,
      anon_sym_STAR,
    STATE(12536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [569324] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14820), 1,
      anon_sym_match,
    ACTIONS(14826), 1,
      sym_operator_identifier,
    STATE(4181), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12537), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569361] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14828), 1,
      anon_sym_match,
    ACTIONS(14830), 1,
      sym_operator_identifier,
    STATE(4219), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569398] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14832), 1,
      anon_sym_match,
    ACTIONS(14834), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12539), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569435] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14792), 1,
      anon_sym_match,
    ACTIONS(14836), 1,
      sym_operator_identifier,
    STATE(4180), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569472] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    ACTIONS(14840), 1,
      sym__automatic_semicolon,
    STATE(12559), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(12541), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14838), 7,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [569507] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14816), 1,
      anon_sym_match,
    ACTIONS(14842), 1,
      sym_operator_identifier,
    STATE(4195), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569544] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(14844), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(4369), 1,
      sym__type_identifier,
    STATE(4381), 1,
      sym_identifier,
    STATE(12543), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569581] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14820), 1,
      anon_sym_match,
    ACTIONS(14846), 1,
      sym_operator_identifier,
    STATE(4239), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569618] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(14848), 1,
      sym_operator_identifier,
    STATE(4249), 1,
      sym__type_identifier,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(11077), 1,
      sym_identifier,
    STATE(12545), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569655] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14820), 1,
      anon_sym_match,
    ACTIONS(14850), 1,
      sym_operator_identifier,
    STATE(4206), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569692] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(14507), 1,
      sym_operator_identifier,
    STATE(4512), 1,
      sym__soft_identifier,
    STATE(13725), 1,
      sym_identifier,
    STATE(14140), 1,
      sym__namespace_expression,
    STATE(12547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569729] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14832), 1,
      anon_sym_match,
    ACTIONS(14852), 1,
      sym_operator_identifier,
    STATE(4205), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569766] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14854), 1,
      anon_sym_match,
    ACTIONS(14856), 1,
      sym_operator_identifier,
    STATE(4226), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569803] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14854), 1,
      anon_sym_match,
    ACTIONS(14858), 1,
      sym_operator_identifier,
    STATE(4204), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569840] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13302), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [569865] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12552), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13304), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [569890] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [569915] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8669), 1,
      sym__alpha_identifier,
    ACTIONS(8681), 1,
      sym__backquoted_id,
    ACTIONS(14860), 1,
      sym_operator_identifier,
    STATE(5137), 1,
      sym__soft_identifier,
    STATE(5282), 1,
      sym__type_identifier,
    STATE(5300), 1,
      sym_identifier,
    STATE(12554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8677), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569952] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [569977] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14577), 1,
      anon_sym_LBRACK,
    STATE(6918), 1,
      sym_type_arguments,
    STATE(12556), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 10,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [570006] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14862), 1,
      anon_sym_DOT,
    STATE(12557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [570033] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12558), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [570058] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    ACTIONS(14866), 1,
      sym__automatic_semicolon,
    STATE(12182), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(12559), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14864), 7,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [570093] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    ACTIONS(14870), 1,
      sym__automatic_semicolon,
    STATE(12182), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(12560), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14868), 7,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [570128] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9924), 1,
      anon_sym_LPAREN,
    ACTIONS(14872), 1,
      anon_sym_LBRACK,
    ACTIONS(14874), 1,
      anon_sym_POUND,
    STATE(13174), 1,
      aux_sym_annotation_repeat1,
    STATE(13353), 1,
      sym_type_arguments,
    STATE(13802), 1,
      sym_arguments,
    STATE(12561), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [570165] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6868), 1,
      sym__alpha_identifier,
    ACTIONS(6878), 1,
      sym__backquoted_id,
    ACTIONS(14876), 1,
      sym_operator_identifier,
    STATE(4620), 1,
      sym__soft_identifier,
    STATE(4926), 1,
      sym__type_identifier,
    STATE(4944), 1,
      sym_identifier,
    STATE(12562), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6874), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570202] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(13499), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(10977), 1,
      sym_identifier,
    STATE(12142), 1,
      sym__type_identifier,
    STATE(12563), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570239] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14878), 1,
      sym__alpha_identifier,
    ACTIONS(14880), 1,
      anon_sym_LBRACE,
    ACTIONS(14882), 1,
      anon_sym_LBRACK,
    ACTIONS(14886), 1,
      sym__backquoted_id,
    STATE(9551), 1,
      sym__soft_identifier,
    STATE(9609), 1,
      sym_identifier,
    STATE(12564), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14884), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570276] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6898), 1,
      sym__alpha_identifier,
    ACTIONS(6916), 1,
      sym__backquoted_id,
    ACTIONS(14888), 1,
      anon_sym_LBRACE,
    ACTIONS(14890), 1,
      anon_sym_LBRACK,
    STATE(9463), 1,
      sym__soft_identifier,
    STATE(11016), 1,
      sym_identifier,
    STATE(12565), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6908), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570313] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14892), 1,
      sym__alpha_identifier,
    ACTIONS(14894), 1,
      anon_sym_LBRACE,
    ACTIONS(14896), 1,
      anon_sym_LBRACK,
    ACTIONS(14900), 1,
      sym__backquoted_id,
    STATE(9328), 1,
      sym__soft_identifier,
    STATE(9334), 1,
      sym_identifier,
    STATE(12566), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14898), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570350] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14093), 1,
      sym__alpha_identifier,
    ACTIONS(14101), 1,
      sym__backquoted_id,
    ACTIONS(14902), 1,
      anon_sym_LBRACE,
    ACTIONS(14904), 1,
      anon_sym_LBRACK,
    STATE(6917), 1,
      sym_identifier,
    STATE(7085), 1,
      sym__soft_identifier,
    STATE(12567), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14099), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570387] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8685), 1,
      sym__alpha_identifier,
    ACTIONS(8693), 1,
      sym__backquoted_id,
    ACTIONS(14906), 1,
      sym_operator_identifier,
    STATE(5145), 1,
      sym__soft_identifier,
    STATE(5408), 1,
      sym__type_identifier,
    STATE(5441), 1,
      sym_identifier,
    STATE(12568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570424] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8465), 1,
      sym__alpha_identifier,
    ACTIONS(8477), 1,
      sym__backquoted_id,
    ACTIONS(14908), 1,
      sym_operator_identifier,
    STATE(5570), 1,
      sym_identifier,
    STATE(5699), 1,
      sym__soft_identifier,
    STATE(5932), 1,
      sym__type_identifier,
    STATE(12569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8473), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570461] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(13636), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(4245), 1,
      sym_identifier,
    STATE(4249), 1,
      sym__type_identifier,
    STATE(12570), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570498] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14563), 1,
      sym__alpha_identifier,
    ACTIONS(14571), 1,
      sym__backquoted_id,
    ACTIONS(14910), 1,
      anon_sym_LBRACE,
    ACTIONS(14912), 1,
      anon_sym_LBRACK,
    STATE(10878), 1,
      sym__soft_identifier,
    STATE(10911), 1,
      sym_identifier,
    STATE(12571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14569), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570535] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6132), 1,
      sym__alpha_identifier,
    ACTIONS(6146), 1,
      sym__backquoted_id,
    ACTIONS(14914), 1,
      sym_operator_identifier,
    STATE(6415), 1,
      sym__soft_identifier,
    STATE(6728), 1,
      sym__type_identifier,
    STATE(6762), 1,
      sym_identifier,
    STATE(12572), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6142), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570572] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4540), 1,
      sym__alpha_identifier,
    ACTIONS(4558), 1,
      sym__backquoted_id,
    ACTIONS(14916), 1,
      sym_operator_identifier,
    STATE(5155), 1,
      sym__soft_identifier,
    STATE(5486), 1,
      sym__type_identifier,
    STATE(5488), 1,
      sym_identifier,
    STATE(12573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570609] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7180), 1,
      sym__alpha_identifier,
    ACTIONS(7196), 1,
      sym__backquoted_id,
    ACTIONS(14918), 1,
      anon_sym_LBRACE,
    ACTIONS(14920), 1,
      anon_sym_LBRACK,
    STATE(10258), 1,
      sym__soft_identifier,
    STATE(11482), 1,
      sym_identifier,
    STATE(12574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570646] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4170), 1,
      sym__alpha_identifier,
    ACTIONS(4188), 1,
      sym__backquoted_id,
    ACTIONS(14922), 1,
      sym_operator_identifier,
    STATE(5675), 1,
      sym__soft_identifier,
    STATE(6074), 1,
      sym__type_identifier,
    STATE(6114), 1,
      sym_identifier,
    STATE(12575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4182), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570683] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(14405), 1,
      sym_operator_identifier,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11143), 1,
      sym_identifier,
    STATE(13882), 1,
      sym__class_constructor,
    STATE(12576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570720] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12577), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [570745] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8697), 1,
      sym__alpha_identifier,
    ACTIONS(8705), 1,
      sym__backquoted_id,
    ACTIONS(14924), 1,
      sym_operator_identifier,
    STATE(6661), 1,
      sym_identifier,
    STATE(7122), 1,
      sym__soft_identifier,
    STATE(7307), 1,
      sym__type_identifier,
    STATE(12578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8701), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570782] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [570807] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12580), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13288), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [570832] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13290), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [570857] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6370), 1,
      sym__alpha_identifier,
    ACTIONS(6384), 1,
      sym__backquoted_id,
    ACTIONS(14926), 1,
      sym_operator_identifier,
    STATE(5485), 1,
      sym__soft_identifier,
    STATE(6582), 1,
      sym__type_identifier,
    STATE(6653), 1,
      sym_identifier,
    STATE(12582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6380), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570894] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12583), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [570919] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9208), 1,
      anon_sym_LPAREN,
    STATE(12588), 1,
      aux_sym_annotation_repeat1,
    STATE(13208), 1,
      sym_arguments,
    STATE(12584), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [570950] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14928), 1,
      anon_sym_COMMA,
    ACTIONS(14930), 1,
      anon_sym_with,
    STATE(13250), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(13281), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(12585), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13680), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [570983] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12229), 1,
      sym__alpha_identifier,
    ACTIONS(12237), 1,
      sym__backquoted_id,
    ACTIONS(14932), 1,
      sym_operator_identifier,
    STATE(12341), 1,
      sym__soft_identifier,
    STATE(12732), 1,
      sym__type_identifier,
    STATE(12746), 1,
      sym_identifier,
    STATE(12586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12233), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571020] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12587), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [571045] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14934), 1,
      anon_sym_LPAREN,
    STATE(13208), 1,
      sym_arguments,
    STATE(12588), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [571074] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8316), 1,
      sym__alpha_identifier,
    ACTIONS(8328), 1,
      sym__backquoted_id,
    ACTIONS(14937), 1,
      sym_operator_identifier,
    STATE(11550), 1,
      sym__soft_identifier,
    STATE(11806), 1,
      sym__type_identifier,
    STATE(11830), 1,
      sym_identifier,
    STATE(12589), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8324), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571111] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14138), 1,
      sym__alpha_identifier,
    ACTIONS(14146), 1,
      sym__backquoted_id,
    ACTIONS(14939), 1,
      anon_sym_LBRACE,
    ACTIONS(14941), 1,
      anon_sym_LBRACK,
    STATE(8799), 1,
      sym_identifier,
    STATE(9270), 1,
      sym__soft_identifier,
    STATE(12590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14144), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571148] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14943), 1,
      anon_sym_LBRACK,
    STATE(13054), 1,
      sym_access_qualifier,
    STATE(12591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10103), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [571177] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14641), 1,
      sym__alpha_identifier,
    ACTIONS(14649), 1,
      sym__backquoted_id,
    ACTIONS(14945), 1,
      anon_sym_LBRACE,
    ACTIONS(14947), 1,
      anon_sym_LBRACK,
    STATE(5729), 1,
      sym_identifier,
    STATE(5790), 1,
      sym__soft_identifier,
    STATE(12592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14647), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571214] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12241), 1,
      sym__alpha_identifier,
    ACTIONS(12249), 1,
      sym__backquoted_id,
    ACTIONS(14949), 1,
      sym_operator_identifier,
    STATE(11224), 1,
      sym__soft_identifier,
    STATE(11842), 1,
      sym__type_identifier,
    STATE(11855), 1,
      sym_identifier,
    STATE(12593), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12245), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571251] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12594), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13298), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [571276] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [571301] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [571326] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8715), 1,
      sym__alpha_identifier,
    ACTIONS(8723), 1,
      sym__backquoted_id,
    ACTIONS(14951), 1,
      sym_operator_identifier,
    STATE(6930), 1,
      sym__type_identifier,
    STATE(6984), 1,
      sym_identifier,
    STATE(7174), 1,
      sym__soft_identifier,
    STATE(12597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8719), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571363] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10575), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(12598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10573), 10,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [571390] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13306), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [571415] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [571440] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10579), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(12601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10577), 10,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [571467] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10583), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(12602), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10581), 10,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [571494] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12603), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13310), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [571519] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11770), 1,
      sym__alpha_identifier,
    ACTIONS(11778), 1,
      sym__backquoted_id,
    ACTIONS(14953), 1,
      sym_operator_identifier,
    STATE(13643), 1,
      sym__soft_identifier,
    STATE(13849), 1,
      sym__type_identifier,
    STATE(13905), 1,
      sym_identifier,
    STATE(12604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11774), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571556] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14541), 1,
      sym__alpha_identifier,
    ACTIONS(14549), 1,
      sym__backquoted_id,
    ACTIONS(14955), 1,
      anon_sym_LBRACE,
    ACTIONS(14957), 1,
      anon_sym_LBRACK,
    STATE(6544), 1,
      sym__soft_identifier,
    STATE(6640), 1,
      sym_identifier,
    STATE(12605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14547), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571593] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12606), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13312), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [571618] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14878), 1,
      sym__alpha_identifier,
    ACTIONS(14886), 1,
      sym__backquoted_id,
    ACTIONS(14959), 1,
      anon_sym_LBRACE,
    ACTIONS(14961), 1,
      anon_sym_LBRACK,
    STATE(9551), 1,
      sym__soft_identifier,
    STATE(9710), 1,
      sym_identifier,
    STATE(12607), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14884), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571655] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4664), 1,
      sym__alpha_identifier,
    ACTIONS(4682), 1,
      sym__backquoted_id,
    ACTIONS(14963), 1,
      sym_operator_identifier,
    STATE(5176), 1,
      sym__soft_identifier,
    STATE(5491), 1,
      sym_identifier,
    STATE(5954), 1,
      sym__type_identifier,
    STATE(12608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4676), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571692] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13316), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12609), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13314), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [571719] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12610), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13319), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [571744] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12611), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [571769] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13321), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [571794] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12613), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13323), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [571819] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6178), 1,
      sym__alpha_identifier,
    ACTIONS(6188), 1,
      sym__backquoted_id,
    ACTIONS(14965), 1,
      sym_operator_identifier,
    STATE(6240), 1,
      sym__soft_identifier,
    STATE(7099), 1,
      sym__type_identifier,
    STATE(7128), 1,
      sym_identifier,
    STATE(12614), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6184), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571856] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7312), 1,
      sym__alpha_identifier,
    ACTIONS(7326), 1,
      sym__backquoted_id,
    ACTIONS(14967), 1,
      sym_operator_identifier,
    STATE(11167), 1,
      sym__soft_identifier,
    STATE(11481), 1,
      sym_identifier,
    STATE(11617), 1,
      sym__type_identifier,
    STATE(12615), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571893] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6482), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      sym__backquoted_id,
    ACTIONS(14969), 1,
      sym_operator_identifier,
    STATE(6416), 1,
      sym__soft_identifier,
    STATE(7188), 1,
      sym__type_identifier,
    STATE(7217), 1,
      sym_identifier,
    STATE(12616), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6488), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571930] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12617), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13329), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [571955] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6252), 1,
      sym__alpha_identifier,
    ACTIONS(6266), 1,
      sym__backquoted_id,
    ACTIONS(14971), 1,
      sym_operator_identifier,
    STATE(5492), 1,
      sym__soft_identifier,
    STATE(6446), 1,
      sym__type_identifier,
    STATE(6497), 1,
      sym_identifier,
    STATE(12618), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6262), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571992] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14973), 1,
      anon_sym_end,
    STATE(7609), 1,
      sym__end_marker,
    STATE(12619), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [572021] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [572046] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14975), 1,
      anon_sym_catch,
    ACTIONS(14977), 1,
      anon_sym_finally,
    STATE(11551), 1,
      sym_finally_clause,
    STATE(12829), 1,
      sym_catch_clause,
    STATE(12621), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [572079] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12253), 1,
      sym__alpha_identifier,
    ACTIONS(12261), 1,
      sym__backquoted_id,
    ACTIONS(13475), 1,
      sym_operator_identifier,
    STATE(11063), 1,
      sym__soft_identifier,
    STATE(12555), 1,
      sym_identifier,
    STATE(13362), 1,
      sym__type_identifier,
    STATE(12622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12257), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572116] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12623), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13331), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [572141] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12624), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13333), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [572166] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12241), 1,
      sym__alpha_identifier,
    ACTIONS(12249), 1,
      sym__backquoted_id,
    ACTIONS(14335), 1,
      sym_operator_identifier,
    STATE(11224), 1,
      sym__soft_identifier,
    STATE(11469), 1,
      sym_identifier,
    STATE(14694), 1,
      sym__object_definition,
    STATE(12625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12245), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13340), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13338), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [572230] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14209), 1,
      sym__alpha_identifier,
    ACTIONS(14217), 1,
      sym__backquoted_id,
    ACTIONS(14979), 1,
      anon_sym_LBRACE,
    ACTIONS(14981), 1,
      anon_sym_LBRACK,
    STATE(8722), 1,
      sym__soft_identifier,
    STATE(8849), 1,
      sym_identifier,
    STATE(12627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14215), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572267] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14768), 1,
      sym__alpha_identifier,
    ACTIONS(14776), 1,
      sym__backquoted_id,
    ACTIONS(14983), 1,
      anon_sym_LBRACE,
    ACTIONS(14985), 1,
      anon_sym_LBRACK,
    STATE(6968), 1,
      sym_identifier,
    STATE(7047), 1,
      sym__soft_identifier,
    STATE(12628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14774), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572304] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4698), 1,
      sym__alpha_identifier,
    ACTIONS(4716), 1,
      sym__backquoted_id,
    ACTIONS(14987), 1,
      sym_operator_identifier,
    STATE(5498), 1,
      sym__soft_identifier,
    STATE(6012), 1,
      sym__type_identifier,
    STATE(6600), 1,
      sym_identifier,
    STATE(12629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4710), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572341] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12630), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [572366] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13347), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13345), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [572393] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6518), 1,
      sym__alpha_identifier,
    ACTIONS(6532), 1,
      sym__backquoted_id,
    ACTIONS(14989), 1,
      sym_operator_identifier,
    STATE(7843), 1,
      sym__soft_identifier,
    STATE(8202), 1,
      sym_identifier,
    STATE(8304), 1,
      sym__type_identifier,
    STATE(12632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6528), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572430] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8543), 1,
      sym__alpha_identifier,
    ACTIONS(8551), 1,
      sym__backquoted_id,
    ACTIONS(14991), 1,
      sym_operator_identifier,
    STATE(6081), 1,
      sym__soft_identifier,
    STATE(6124), 1,
      sym__type_identifier,
    STATE(6159), 1,
      sym_identifier,
    STATE(12633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8547), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572467] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      sym__alpha_identifier,
    ACTIONS(12009), 1,
      sym__backquoted_id,
    ACTIONS(14120), 1,
      sym_operator_identifier,
    STATE(11062), 1,
      sym__soft_identifier,
    STATE(11166), 1,
      sym_identifier,
    STATE(14377), 1,
      sym__object_definition,
    STATE(12634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12005), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572504] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12268), 1,
      sym__alpha_identifier,
    ACTIONS(12276), 1,
      sym__backquoted_id,
    ACTIONS(14993), 1,
      sym_operator_identifier,
    STATE(11269), 1,
      sym__soft_identifier,
    STATE(11581), 1,
      sym__type_identifier,
    STATE(11716), 1,
      sym_identifier,
    STATE(12635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12272), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572541] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14495), 1,
      sym__alpha_identifier,
    ACTIONS(14503), 1,
      sym__backquoted_id,
    ACTIONS(14995), 1,
      anon_sym_LBRACE,
    ACTIONS(14997), 1,
      anon_sym_LBRACK,
    STATE(8205), 1,
      sym__soft_identifier,
    STATE(8506), 1,
      sym_identifier,
    STATE(12636), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14501), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572578] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14892), 1,
      sym__alpha_identifier,
    ACTIONS(14900), 1,
      sym__backquoted_id,
    ACTIONS(14999), 1,
      anon_sym_LBRACE,
    ACTIONS(15001), 1,
      anon_sym_LBRACK,
    STATE(9328), 1,
      sym__soft_identifier,
    STATE(9508), 1,
      sym_identifier,
    STATE(12637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14898), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572615] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4732), 1,
      sym__alpha_identifier,
    ACTIONS(4750), 1,
      sym__backquoted_id,
    ACTIONS(15003), 1,
      sym_operator_identifier,
    STATE(7205), 1,
      sym__soft_identifier,
    STATE(7407), 1,
      sym__type_identifier,
    STATE(7936), 1,
      sym_identifier,
    STATE(12638), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4744), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572652] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 1,
      sym__alpha_identifier,
    ACTIONS(10327), 1,
      sym__backquoted_id,
    ACTIONS(14692), 1,
      anon_sym_match,
    ACTIONS(15005), 1,
      sym_operator_identifier,
    STATE(4218), 1,
      sym_identifier,
    STATE(9516), 1,
      sym__soft_identifier,
    STATE(12639), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10317), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572689] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15007), 1,
      anon_sym_LBRACK,
    STATE(7490), 1,
      sym_type_arguments,
    STATE(12640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13388), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [572717] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [572741] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12573), 1,
      anon_sym_LPAREN,
    ACTIONS(15009), 1,
      sym__automatic_semicolon,
    STATE(12896), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13452), 1,
      sym_class_parameters,
    STATE(12642), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14651), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [572773] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [572797] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12644), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [572821] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [572845] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12646), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [572869] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15012), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15895), 1,
      sym_identifier,
    STATE(12647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572903] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12648), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [572927] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [572951] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [572975] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(830), 1,
      sym__alpha_identifier,
    ACTIONS(860), 1,
      sym__backquoted_id,
    ACTIONS(15014), 1,
      sym_operator_identifier,
    STATE(5706), 1,
      sym__soft_identifier,
    STATE(16998), 1,
      sym_identifier,
    STATE(12651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(840), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573009] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [573033] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15016), 1,
      anon_sym_catch,
    ACTIONS(15018), 1,
      anon_sym_finally,
    STATE(12745), 1,
      sym_finally_clause,
    STATE(13630), 1,
      sym_catch_clause,
    STATE(12653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [573065] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(14001), 1,
      sym_operator_identifier,
    STATE(14596), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(12654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8056), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573099] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [573123] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(10092), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16069), 1,
      sym_identifier,
    STATE(12656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573157] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12657), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [573181] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [573205] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12659), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [573229] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15020), 1,
      anon_sym_LBRACK,
    STATE(7663), 1,
      sym_type_arguments,
    STATE(12660), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13388), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [573257] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15022), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16033), 1,
      sym_identifier,
    STATE(12661), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573291] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13708), 1,
      anon_sym_LPAREN,
    ACTIONS(15024), 1,
      sym__automatic_semicolon,
    STATE(12717), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13652), 1,
      sym_parameters,
    STATE(13782), 1,
      sym__using_parameters_clause,
    STATE(12662), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14864), 6,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [573325] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15026), 1,
      anon_sym_end,
    STATE(8146), 1,
      sym__end_marker,
    STATE(12663), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [573353] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14083), 1,
      sym__alpha_identifier,
    ACTIONS(14091), 1,
      sym__backquoted_id,
    ACTIONS(15028), 1,
      sym_operator_identifier,
    STATE(7502), 1,
      sym_identifier,
    STATE(7888), 1,
      sym__soft_identifier,
    STATE(12664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14089), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573387] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14128), 1,
      sym__alpha_identifier,
    ACTIONS(14136), 1,
      sym__backquoted_id,
    ACTIONS(15030), 1,
      sym_operator_identifier,
    STATE(8766), 1,
      sym__soft_identifier,
    STATE(8919), 1,
      sym_identifier,
    STATE(12665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14134), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573421] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14069), 1,
      anon_sym_finally,
    STATE(11562), 1,
      sym_finally_clause,
    STATE(12666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 9,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
  [573449] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15032), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15987), 1,
      sym_identifier,
    STATE(12667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573483] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15034), 1,
      anon_sym_end,
    STATE(8209), 1,
      sym__end_marker,
    STATE(12668), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [573511] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15036), 1,
      anon_sym_catch,
    ACTIONS(15038), 1,
      anon_sym_finally,
    STATE(11980), 1,
      sym_finally_clause,
    STATE(13347), 1,
      sym_catch_clause,
    STATE(12669), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [573543] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [573567] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [573591] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [573615] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12715), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [573639] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [573663] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(10064), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15868), 1,
      sym_identifier,
    STATE(12675), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573697] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13706), 1,
      anon_sym_LBRACK,
    ACTIONS(15042), 1,
      anon_sym_LT_COLON,
    ACTIONS(15044), 1,
      anon_sym_GT_COLON,
    STATE(13374), 1,
      sym_type_parameters,
    STATE(13982), 1,
      sym_lower_bound,
    STATE(14230), 1,
      sym_upper_bound,
    STATE(12676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15040), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [573733] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15046), 1,
      anon_sym_end,
    STATE(8224), 1,
      sym__end_marker,
    STATE(12677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [573761] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15048), 1,
      anon_sym_catch,
    ACTIONS(15050), 1,
      anon_sym_finally,
    STATE(13048), 1,
      sym_finally_clause,
    STATE(13435), 1,
      sym_catch_clause,
    STATE(12678), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
  [573793] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15052), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16052), 1,
      sym_identifier,
    STATE(12679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573827] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12680), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [573851] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12681), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12717), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [573875] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12682), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [573899] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15054), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15900), 1,
      sym_identifier,
    STATE(12683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573933] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12684), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [573957] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15056), 1,
      anon_sym_catch,
    ACTIONS(15058), 1,
      anon_sym_finally,
    STATE(12410), 1,
      sym_finally_clause,
    STATE(13325), 1,
      sym_catch_clause,
    STATE(12685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [573989] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12686), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [574013] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [574037] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14481), 1,
      sym__alpha_identifier,
    ACTIONS(14489), 1,
      sym__backquoted_id,
    ACTIONS(15060), 1,
      sym_operator_identifier,
    STATE(9997), 1,
      sym_identifier,
    STATE(10042), 1,
      sym__soft_identifier,
    STATE(12688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14487), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574071] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15062), 1,
      anon_sym_LPAREN,
    STATE(13446), 1,
      sym_arguments,
    STATE(12689), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [574099] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12690), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [574123] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15065), 1,
      anon_sym_DOT,
    STATE(12691), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [574149] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15067), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15850), 1,
      sym_identifier,
    STATE(12692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574183] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12693), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [574207] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12694), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [574231] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12695), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [574255] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [574279] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [574303] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(9006), 1,
      sym_operator_identifier,
    STATE(14559), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(12698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8056), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574337] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14278), 1,
      sym__alpha_identifier,
    ACTIONS(14286), 1,
      sym__backquoted_id,
    ACTIONS(15069), 1,
      sym_operator_identifier,
    STATE(9910), 1,
      sym__soft_identifier,
    STATE(10100), 1,
      sym_identifier,
    STATE(12699), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14284), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574371] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15071), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15893), 1,
      sym_identifier,
    STATE(12700), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574405] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15073), 1,
      anon_sym_catch,
    ACTIONS(15075), 1,
      anon_sym_finally,
    STATE(11949), 1,
      sym_finally_clause,
    STATE(13067), 1,
      sym_catch_clause,
    STATE(12701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [574437] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [574461] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15077), 1,
      anon_sym_DOT,
    STATE(12703), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [574487] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [574511] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13682), 1,
      anon_sym_COMMA,
    STATE(12815), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(12705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15079), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [574539] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15081), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16146), 1,
      sym_identifier,
    STATE(12706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574573] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13684), 1,
      anon_sym_with,
    STATE(12816), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(12707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15079), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [574601] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15083), 1,
      anon_sym_catch,
    ACTIONS(15085), 1,
      anon_sym_finally,
    STATE(13159), 1,
      sym_finally_clause,
    STATE(13234), 1,
      sym_catch_clause,
    STATE(12708), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [574633] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [574657] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13321), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [574681] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [574705] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14601), 1,
      sym__alpha_identifier,
    ACTIONS(14609), 1,
      sym__backquoted_id,
    ACTIONS(15087), 1,
      sym_operator_identifier,
    STATE(8157), 1,
      sym_identifier,
    STATE(8182), 1,
      sym__soft_identifier,
    STATE(12712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14607), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574739] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12713), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [574763] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14241), 1,
      sym__alpha_identifier,
    ACTIONS(14249), 1,
      sym__backquoted_id,
    ACTIONS(15089), 1,
      sym_operator_identifier,
    STATE(6150), 1,
      sym__soft_identifier,
    STATE(6209), 1,
      sym_identifier,
    STATE(12714), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14247), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574797] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15091), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15918), 1,
      sym_identifier,
    STATE(12715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574831] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14495), 1,
      sym__alpha_identifier,
    ACTIONS(14503), 1,
      sym__backquoted_id,
    ACTIONS(15093), 1,
      sym_operator_identifier,
    STATE(8205), 1,
      sym__soft_identifier,
    STATE(8568), 1,
      sym_identifier,
    STATE(12716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14501), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574865] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15095), 1,
      anon_sym_LPAREN,
    ACTIONS(15098), 1,
      sym__automatic_semicolon,
    STATE(13652), 1,
      sym_parameters,
    STATE(13782), 1,
      sym__using_parameters_clause,
    STATE(12717), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__function_constructor_repeat1,
    ACTIONS(14075), 6,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [574897] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [574921] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12719), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [574945] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [574969] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12721), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [574993] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12841), 1,
      sym__automatic_semicolon,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(13669), 1,
      sym_access_modifier,
    STATE(13670), 1,
      aux_sym__class_constructor_repeat1,
    ACTIONS(12464), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(12722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12891), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [575029] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [575053] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15101), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15926), 1,
      sym_identifier,
    STATE(12724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13115), 1,
      sym_arguments,
    STATE(12725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [575113] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12726), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [575137] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15105), 1,
      anon_sym_LBRACK,
    ACTIONS(15107), 1,
      anon_sym_if,
    ACTIONS(15109), 1,
      anon_sym_match,
    STATE(7547), 1,
      sym_type_arguments,
    STATE(14068), 1,
      sym_guard,
    STATE(12727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15103), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [575171] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12728), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [575195] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [575219] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(10066), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16001), 1,
      sym_identifier,
    STATE(12730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575253] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [575277] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [575301] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12733), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [575325] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15111), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16991), 1,
      sym_identifier,
    STATE(12734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575359] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12735), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [575383] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [575407] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14563), 1,
      sym__alpha_identifier,
    ACTIONS(14571), 1,
      sym__backquoted_id,
    ACTIONS(15113), 1,
      sym_operator_identifier,
    STATE(10817), 1,
      sym_identifier,
    STATE(10878), 1,
      sym__soft_identifier,
    STATE(12737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14569), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575441] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15115), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15896), 1,
      sym_identifier,
    STATE(12738), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575475] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [575499] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [575523] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [575547] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12742), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [575571] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15117), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16115), 1,
      sym_identifier,
    STATE(12743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575605] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [575629] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12745), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [575653] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [575677] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12747), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [575701] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13881), 1,
      aux_sym_compound_type_repeat1,
    STATE(14024), 1,
      sym__refinement,
    STATE(14116), 1,
      sym_template_body,
    STATE(12748), 2,
      sym_comment,
      sym_block_comment,
    STATE(14037), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [575733] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12749), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [575757] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15119), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16113), 1,
      sym_identifier,
    STATE(12750), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575791] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [575815] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [575839] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12753), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13290), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [575863] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12754), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [575887] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15121), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15985), 1,
      sym_identifier,
    STATE(12755), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575921] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15123), 1,
      anon_sym_catch,
    ACTIONS(15125), 1,
      anon_sym_finally,
    STATE(11949), 1,
      sym_finally_clause,
    STATE(13217), 1,
      sym_catch_clause,
    STATE(12756), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [575953] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12757), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [575977] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9563), 1,
      anon_sym_LPAREN,
    STATE(12766), 1,
      aux_sym_annotation_repeat1,
    STATE(13575), 1,
      sym_arguments,
    STATE(12758), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [576007] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13043), 1,
      sym_arguments,
    STATE(12759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [576033] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15127), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16030), 1,
      sym_identifier,
    STATE(12760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576067] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12761), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [576091] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14187), 1,
      sym__alpha_identifier,
    ACTIONS(14195), 1,
      sym__backquoted_id,
    ACTIONS(15129), 1,
      sym_operator_identifier,
    STATE(10244), 1,
      sym_identifier,
    STATE(10279), 1,
      sym__soft_identifier,
    STATE(12762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14193), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576125] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14262), 1,
      sym__alpha_identifier,
    ACTIONS(14270), 1,
      sym__backquoted_id,
    ACTIONS(15131), 1,
      sym_operator_identifier,
    STATE(8278), 1,
      sym_identifier,
    STATE(8610), 1,
      sym__soft_identifier,
    STATE(12763), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14268), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576159] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8092), 1,
      anon_sym_case,
    ACTIONS(8094), 1,
      anon_sym_object,
    ACTIONS(8096), 1,
      anon_sym_given,
    ACTIONS(8098), 1,
      anon_sym_class,
    ACTIONS(8100), 1,
      anon_sym_trait,
    ACTIONS(8102), 1,
      anon_sym_val,
    ACTIONS(8104), 1,
      anon_sym_var,
    ACTIONS(8106), 1,
      anon_sym_type,
    ACTIONS(8108), 1,
      anon_sym_def,
    ACTIONS(8110), 1,
      anon_sym_opaque,
    STATE(16203), 1,
      sym_opaque_modifier,
    STATE(12764), 2,
      sym_comment,
      sym_block_comment,
  [576203] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12841), 1,
      sym__automatic_semicolon,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(13743), 1,
      sym_access_modifier,
    STATE(13748), 1,
      aux_sym__class_constructor_repeat1,
    ACTIONS(12464), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(12765), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12896), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [576239] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15133), 1,
      anon_sym_LPAREN,
    STATE(13575), 1,
      sym_arguments,
    STATE(12766), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [576267] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(10068), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15853), 1,
      sym_identifier,
    STATE(12767), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576301] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15136), 1,
      anon_sym_catch,
    ACTIONS(15138), 1,
      anon_sym_finally,
    STATE(13430), 1,
      sym_finally_clause,
    STATE(13553), 1,
      sym_catch_clause,
    STATE(12768), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [576333] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13331), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [576357] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    STATE(13330), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(12770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15140), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [576387] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15142), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15972), 1,
      sym_identifier,
    STATE(12771), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576421] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15007), 1,
      anon_sym_LBRACK,
    ACTIONS(15144), 1,
      anon_sym_match,
    STATE(7490), 1,
      sym_type_arguments,
    STATE(12772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [576451] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(15146), 1,
      anon_sym_LT_COLON,
    ACTIONS(15148), 1,
      anon_sym_GT_COLON,
    STATE(13568), 1,
      sym_type_parameters,
    STATE(13918), 1,
      sym_lower_bound,
    STATE(14161), 1,
      sym_upper_bound,
    STATE(12773), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15040), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [576487] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15105), 1,
      anon_sym_LBRACK,
    STATE(7547), 1,
      sym_type_arguments,
    STATE(12774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 9,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [576515] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15150), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15916), 1,
      sym_identifier,
    STATE(12775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576549] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15105), 1,
      anon_sym_LBRACK,
    STATE(7547), 1,
      sym_type_arguments,
    STATE(12776), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 9,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [576577] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12777), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13333), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [576601] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15152), 1,
      anon_sym_DOT,
    STATE(12778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [576627] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14613), 1,
      sym__alpha_identifier,
    ACTIONS(14621), 1,
      sym__backquoted_id,
    ACTIONS(15154), 1,
      sym_operator_identifier,
    STATE(7801), 1,
      sym_identifier,
    STATE(8026), 1,
      sym__soft_identifier,
    STATE(12779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14619), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576661] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15156), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15886), 1,
      sym_identifier,
    STATE(12780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576695] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8110), 1,
      anon_sym_opaque,
    ACTIONS(15158), 1,
      anon_sym_case,
    ACTIONS(15160), 1,
      anon_sym_object,
    ACTIONS(15162), 1,
      anon_sym_given,
    ACTIONS(15164), 1,
      anon_sym_class,
    ACTIONS(15166), 1,
      anon_sym_trait,
    ACTIONS(15168), 1,
      anon_sym_val,
    ACTIONS(15170), 1,
      anon_sym_var,
    ACTIONS(15172), 1,
      anon_sym_type,
    ACTIONS(15174), 1,
      anon_sym_def,
    STATE(16343), 1,
      sym_opaque_modifier,
    STATE(12781), 2,
      sym_comment,
      sym_block_comment,
  [576739] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14294), 1,
      sym__alpha_identifier,
    ACTIONS(14302), 1,
      sym__backquoted_id,
    ACTIONS(15176), 1,
      sym_operator_identifier,
    STATE(7678), 1,
      sym_identifier,
    STATE(7925), 1,
      sym__soft_identifier,
    STATE(12782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14300), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576773] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(473), 1,
      sym__alpha_identifier,
    ACTIONS(537), 1,
      sym__backquoted_id,
    ACTIONS(15178), 1,
      sym_operator_identifier,
    STATE(5776), 1,
      sym__soft_identifier,
    STATE(14097), 1,
      sym_identifier,
    STATE(12783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(659), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576807] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15180), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15909), 1,
      sym_identifier,
    STATE(12784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576841] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15020), 1,
      anon_sym_LBRACK,
    ACTIONS(15182), 1,
      anon_sym_match,
    STATE(7663), 1,
      sym_type_arguments,
    STATE(12785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [576871] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15105), 1,
      anon_sym_LBRACK,
    ACTIONS(15109), 1,
      anon_sym_match,
    STATE(7547), 1,
      sym_type_arguments,
    STATE(12786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [576901] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14641), 1,
      sym__alpha_identifier,
    ACTIONS(14649), 1,
      sym__backquoted_id,
    ACTIONS(15184), 1,
      sym_operator_identifier,
    STATE(5691), 1,
      sym_identifier,
    STATE(5790), 1,
      sym__soft_identifier,
    STATE(12787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14647), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576935] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15186), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15931), 1,
      sym_identifier,
    STATE(12788), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576969] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [576993] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15020), 1,
      anon_sym_LBRACK,
    STATE(7663), 1,
      sym_type_arguments,
    STATE(12790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [577021] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15020), 1,
      anon_sym_LBRACK,
    STATE(7663), 1,
      sym_type_arguments,
    STATE(12791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [577049] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15188), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15943), 1,
      sym_identifier,
    STATE(12792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577083] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [577107] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [577131] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12795), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [577155] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13302), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [577179] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13304), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [577203] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15190), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16043), 1,
      sym_identifier,
    STATE(12798), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13340), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13338), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [577263] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [577287] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15105), 1,
      anon_sym_LBRACK,
    STATE(7547), 1,
      sym_type_arguments,
    STATE(12801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 9,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [577315] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15192), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16014), 1,
      sym_identifier,
    STATE(12802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577349] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13708), 1,
      anon_sym_LPAREN,
    ACTIONS(15194), 1,
      sym__automatic_semicolon,
    STATE(12662), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13652), 1,
      sym_parameters,
    STATE(13782), 1,
      sym__using_parameters_clause,
    STATE(12803), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14838), 6,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [577383] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15196), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15937), 1,
      sym_identifier,
    STATE(12804), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577417] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [577441] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13708), 1,
      anon_sym_LPAREN,
    ACTIONS(15198), 1,
      sym__automatic_semicolon,
    STATE(12717), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13652), 1,
      sym_parameters,
    STATE(13782), 1,
      sym__using_parameters_clause,
    STATE(12806), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14868), 6,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [577475] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15200), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16024), 1,
      sym_identifier,
    STATE(12807), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577509] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [577533] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12809), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [577557] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15202), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16101), 1,
      sym_identifier,
    STATE(12810), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577591] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [577615] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [577639] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15204), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15872), 1,
      sym_identifier,
    STATE(12813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577673] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12814), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [577697] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15208), 1,
      anon_sym_COMMA,
    STATE(12815), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat1,
    ACTIONS(15206), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [577723] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15213), 1,
      anon_sym_with,
    STATE(12816), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat2,
    ACTIONS(15211), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [577749] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15216), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15902), 1,
      sym_identifier,
    STATE(12817), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577783] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15020), 1,
      anon_sym_LBRACK,
    ACTIONS(15182), 1,
      anon_sym_match,
    STATE(7663), 1,
      sym_type_arguments,
    STATE(12818), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [577813] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13329), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [577837] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(10072), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16108), 1,
      sym_identifier,
    STATE(12820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577871] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15105), 1,
      anon_sym_LBRACK,
    STATE(7547), 1,
      sym_type_arguments,
    STATE(12821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 9,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [577899] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8102), 1,
      anon_sym_val,
    ACTIONS(8104), 1,
      anon_sym_var,
    ACTIONS(8110), 1,
      anon_sym_opaque,
    ACTIONS(8138), 1,
      anon_sym_case,
    ACTIONS(8140), 1,
      anon_sym_object,
    ACTIONS(8144), 1,
      anon_sym_class,
    ACTIONS(8146), 1,
      anon_sym_trait,
    ACTIONS(8214), 1,
      anon_sym_given,
    ACTIONS(8216), 1,
      anon_sym_type,
    ACTIONS(8218), 1,
      anon_sym_def,
    STATE(16557), 1,
      sym_opaque_modifier,
    STATE(12822), 2,
      sym_comment,
      sym_block_comment,
  [577943] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15218), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15940), 1,
      sym_identifier,
    STATE(12823), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577977] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(15220), 1,
      sym_operator_identifier,
    STATE(4512), 1,
      sym__soft_identifier,
    STATE(13571), 1,
      sym_identifier,
    STATE(12824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578011] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [578035] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15222), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15983), 1,
      sym_identifier,
    STATE(12826), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578069] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14337), 1,
      sym__alpha_identifier,
    ACTIONS(14345), 1,
      sym__backquoted_id,
    ACTIONS(15224), 1,
      sym_operator_identifier,
    STATE(8411), 1,
      sym__soft_identifier,
    STATE(8526), 1,
      sym_identifier,
    STATE(12827), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14343), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578103] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9549), 1,
      anon_sym_LPAREN,
    STATE(12689), 1,
      aux_sym_annotation_repeat1,
    STATE(13446), 1,
      sym_arguments,
    STATE(12828), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [578133] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14977), 1,
      anon_sym_finally,
    STATE(11562), 1,
      sym_finally_clause,
    STATE(12829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_do,
      anon_sym_yield,
  [578161] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15226), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16042), 1,
      sym_identifier,
    STATE(12830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578195] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(12868), 1,
      anon_sym_COLON,
    ACTIONS(15230), 1,
      sym__automatic_semicolon,
    STATE(14272), 1,
      sym__definition_body,
    STATE(14313), 1,
      sym_template_body,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15228), 4,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [578231] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15233), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16094), 1,
      sym_identifier,
    STATE(12832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578265] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12833), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [578289] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15235), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15860), 1,
      sym_identifier,
    STATE(12834), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578323] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [578347] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15020), 1,
      anon_sym_LBRACK,
    STATE(7663), 1,
      sym_type_arguments,
    STATE(12836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [578375] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12837), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13323), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [578399] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(12868), 1,
      anon_sym_COLON,
    ACTIONS(15239), 1,
      sym__automatic_semicolon,
    STATE(14182), 1,
      sym__definition_body,
    STATE(14313), 1,
      sym_template_body,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15237), 4,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [578435] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15242), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15919), 1,
      sym_identifier,
    STATE(12839), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578469] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [578493] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [578517] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15244), 1,
      anon_sym_STAR,
    STATE(12842), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [578543] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15007), 1,
      anon_sym_LBRACK,
    STATE(7490), 1,
      sym_type_arguments,
    STATE(12843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [578571] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15246), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15968), 1,
      sym_identifier,
    STATE(12844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578605] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [578629] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12846), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [578653] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15248), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16023), 1,
      sym_identifier,
    STATE(12847), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578687] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15036), 1,
      anon_sym_catch,
    ACTIONS(15250), 1,
      anon_sym_finally,
    STATE(12577), 1,
      sym_finally_clause,
    STATE(13591), 1,
      sym_catch_clause,
    STATE(12848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [578719] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14433), 1,
      anon_sym_with,
    STATE(13881), 1,
      aux_sym_compound_type_repeat1,
    STATE(14231), 1,
      sym_template_body,
    STATE(14252), 1,
      sym__refinement,
    STATE(12849), 2,
      sym_comment,
      sym_block_comment,
    STATE(14185), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8252), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [578753] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15105), 1,
      anon_sym_LBRACK,
    ACTIONS(15109), 1,
      anon_sym_match,
    STATE(7547), 1,
      sym_type_arguments,
    STATE(12850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [578783] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15252), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16075), 1,
      sym_identifier,
    STATE(12851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578817] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15007), 1,
      anon_sym_LBRACK,
    STATE(7490), 1,
      sym_type_arguments,
    STATE(12852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [578845] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15254), 1,
      anon_sym_catch,
    ACTIONS(15256), 1,
      anon_sym_finally,
    STATE(13152), 1,
      sym_catch_clause,
    STATE(13159), 1,
      sym_finally_clause,
    STATE(12853), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [578877] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15258), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16121), 1,
      sym_identifier,
    STATE(12854), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578911] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12855), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [578935] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12856), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [578959] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12857), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [578983] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15260), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16142), 1,
      sym_identifier,
    STATE(12858), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579017] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15262), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16056), 1,
      sym_identifier,
    STATE(12859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579051] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [579075] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(12861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [579101] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [579125] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15264), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16035), 1,
      sym_identifier,
    STATE(12863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579159] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12864), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [579183] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15266), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16045), 1,
      sym_identifier,
    STATE(12865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579217] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12866), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [579241] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [579265] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13298), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [579289] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15268), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16064), 1,
      sym_identifier,
    STATE(12869), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579323] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [579347] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15270), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15973), 1,
      sym_identifier,
    STATE(12871), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579381] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [579405] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12873), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [579429] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    STATE(13330), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(12874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15272), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [579459] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(830), 1,
      sym__alpha_identifier,
    ACTIONS(860), 1,
      sym__backquoted_id,
    ACTIONS(15274), 1,
      sym_operator_identifier,
    STATE(5706), 1,
      sym__soft_identifier,
    STATE(17473), 1,
      sym_identifier,
    STATE(12875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(840), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579493] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14768), 1,
      sym__alpha_identifier,
    ACTIONS(14776), 1,
      sym__backquoted_id,
    ACTIONS(15276), 1,
      sym_operator_identifier,
    STATE(6894), 1,
      sym_identifier,
    STATE(7047), 1,
      sym__soft_identifier,
    STATE(12876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14774), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579527] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15278), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15997), 1,
      sym_identifier,
    STATE(12877), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579561] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12878), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12703), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [579585] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15280), 1,
      anon_sym_LBRACK,
    STATE(13597), 1,
      sym_access_qualifier,
    STATE(12879), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10103), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [579613] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15282), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16110), 1,
      sym_identifier,
    STATE(12880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579647] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12881), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [579671] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15020), 1,
      anon_sym_LBRACK,
    STATE(7663), 1,
      sym_type_arguments,
    STATE(12882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [579699] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15284), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(16136), 1,
      sym_identifier,
    STATE(12883), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579733] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12884), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [579757] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15105), 1,
      anon_sym_LBRACK,
    ACTIONS(15107), 1,
      anon_sym_if,
    ACTIONS(15109), 1,
      anon_sym_match,
    STATE(7547), 1,
      sym_type_arguments,
    STATE(14104), 1,
      sym_guard,
    STATE(12885), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15286), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [579791] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [579815] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15288), 1,
      anon_sym_with,
    STATE(12887), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [579841] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15056), 1,
      anon_sym_catch,
    ACTIONS(15291), 1,
      anon_sym_finally,
    STATE(12745), 1,
      sym_finally_clause,
    STATE(13344), 1,
      sym_catch_clause,
    STATE(12888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [579873] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14541), 1,
      sym__alpha_identifier,
    ACTIONS(14549), 1,
      sym__backquoted_id,
    ACTIONS(15293), 1,
      sym_operator_identifier,
    STATE(6533), 1,
      sym_identifier,
    STATE(6544), 1,
      sym__soft_identifier,
    STATE(12889), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14547), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579907] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [579931] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15295), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15920), 1,
      sym_identifier,
    STATE(12891), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579965] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12892), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13288), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [579989] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13290), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [580013] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12894), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [580037] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15297), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15992), 1,
      sym_identifier,
    STATE(12895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580071] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15299), 1,
      anon_sym_LPAREN,
    ACTIONS(15302), 1,
      sym__automatic_semicolon,
    STATE(13452), 1,
      sym_class_parameters,
    STATE(12896), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__class_constructor_repeat1,
    ACTIONS(14323), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [580101] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12897), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12606), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [580125] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12898), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [580149] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [580173] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15305), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15974), 1,
      sym_identifier,
    STATE(12900), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580207] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12183), 1,
      sym__alpha_identifier,
    ACTIONS(12189), 1,
      sym__backquoted_id,
    ACTIONS(15220), 1,
      sym_operator_identifier,
    STATE(9871), 1,
      sym__soft_identifier,
    STATE(13571), 1,
      sym_identifier,
    STATE(12901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8050), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580241] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12902), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [580265] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15307), 1,
      anon_sym_end,
    STATE(8524), 1,
      sym__end_marker,
    STATE(12903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [580293] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14802), 1,
      sym__alpha_identifier,
    ACTIONS(14810), 1,
      sym__backquoted_id,
    ACTIONS(15309), 1,
      sym_operator_identifier,
    STATE(9428), 1,
      sym__soft_identifier,
    STATE(9465), 1,
      sym_identifier,
    STATE(12904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14808), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580327] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(12868), 1,
      anon_sym_COLON,
    STATE(14313), 1,
      sym_template_body,
    STATE(14334), 1,
      sym__definition_body,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12905), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15311), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [580361] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [580385] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12907), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [580409] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12908), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [580433] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12909), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [580457] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12910), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [580481] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15007), 1,
      anon_sym_LBRACK,
    ACTIONS(15144), 1,
      anon_sym_match,
    STATE(7490), 1,
      sym_type_arguments,
    STATE(12911), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [580511] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12912), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [580535] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [580559] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12914), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [580583] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [580607] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(12916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [580633] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13319), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [580657] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13298), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [580681] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [580705] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13306), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [580729] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12921), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [580753] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12922), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [580777] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13310), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [580801] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [580825] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13312), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [580849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13316), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13314), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [580875] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13319), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [580899] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12928), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13306), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [580923] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13321), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [580947] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [580971] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13323), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [580995] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [581019] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [581043] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15313), 1,
      anon_sym_catch,
    ACTIONS(15315), 1,
      anon_sym_finally,
    STATE(13343), 1,
      sym_catch_clause,
    STATE(13712), 1,
      sym_finally_clause,
    STATE(12934), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [581075] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12935), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13329), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [581099] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [581123] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12937), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [581147] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    STATE(13330), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(12938), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15317), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [581177] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13331), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [581201] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12940), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13333), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [581225] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    STATE(13330), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(12941), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15319), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [581255] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13340), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12942), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13338), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [581281] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [581305] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14435), 1,
      sym__alpha_identifier,
    ACTIONS(14443), 1,
      sym__backquoted_id,
    ACTIONS(15321), 1,
      sym_operator_identifier,
    STATE(6720), 1,
      sym_identifier,
    STATE(6767), 1,
      sym__soft_identifier,
    STATE(12944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14441), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581339] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12573), 1,
      anon_sym_LPAREN,
    ACTIONS(13401), 1,
      sym__automatic_semicolon,
    STATE(12980), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13452), 1,
      sym_class_parameters,
    STATE(12945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12891), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [581371] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13347), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12946), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13345), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [581397] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12573), 1,
      anon_sym_LPAREN,
    ACTIONS(15323), 1,
      sym__automatic_semicolon,
    STATE(12896), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13452), 1,
      sym_class_parameters,
    STATE(12947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14166), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [581429] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13310), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [581453] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12949), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [581477] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [581501] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15136), 1,
      anon_sym_catch,
    ACTIONS(15326), 1,
      anon_sym_finally,
    STATE(13608), 1,
      sym_catch_clause,
    STATE(13712), 1,
      sym_finally_clause,
    STATE(12951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [581533] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13347), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13345), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [581559] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9515), 1,
      anon_sym_LPAREN,
    STATE(12955), 1,
      aux_sym_annotation_repeat1,
    STATE(13355), 1,
      sym_arguments,
    STATE(12953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [581589] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [581613] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15328), 1,
      anon_sym_LPAREN,
    STATE(13355), 1,
      sym_arguments,
    STATE(12955), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [581641] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9856), 1,
      anon_sym_COLON,
    STATE(12956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [581667] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15007), 1,
      anon_sym_LBRACK,
    STATE(7490), 1,
      sym_type_arguments,
    STATE(12957), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [581695] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12958), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13312), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [581719] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13316), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13314), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [581745] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14878), 1,
      sym__alpha_identifier,
    ACTIONS(14886), 1,
      sym__backquoted_id,
    ACTIONS(15331), 1,
      sym_operator_identifier,
    STATE(9551), 1,
      sym__soft_identifier,
    STATE(9633), 1,
      sym_identifier,
    STATE(12960), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14884), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581779] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [581803] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12962), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [581827] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14093), 1,
      sym__alpha_identifier,
    ACTIONS(14101), 1,
      sym__backquoted_id,
    ACTIONS(15333), 1,
      sym_operator_identifier,
    STATE(6926), 1,
      sym_identifier,
    STATE(7085), 1,
      sym__soft_identifier,
    STATE(12963), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14099), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581861] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15335), 1,
      anon_sym_STAR,
    STATE(12964), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [581887] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8092), 1,
      anon_sym_case,
    ACTIONS(8094), 1,
      anon_sym_object,
    ACTIONS(8098), 1,
      anon_sym_class,
    ACTIONS(8100), 1,
      anon_sym_trait,
    ACTIONS(8102), 1,
      anon_sym_val,
    ACTIONS(8104), 1,
      anon_sym_var,
    ACTIONS(8106), 1,
      anon_sym_type,
    ACTIONS(8108), 1,
      anon_sym_def,
    ACTIONS(8110), 1,
      anon_sym_opaque,
    ACTIONS(8152), 1,
      anon_sym_given,
    STATE(16203), 1,
      sym_opaque_modifier,
    STATE(12965), 2,
      sym_comment,
      sym_block_comment,
  [581931] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8110), 1,
      anon_sym_opaque,
    ACTIONS(15158), 1,
      anon_sym_case,
    ACTIONS(15160), 1,
      anon_sym_object,
    ACTIONS(15164), 1,
      anon_sym_class,
    ACTIONS(15166), 1,
      anon_sym_trait,
    ACTIONS(15168), 1,
      anon_sym_val,
    ACTIONS(15170), 1,
      anon_sym_var,
    ACTIONS(15172), 1,
      anon_sym_type,
    ACTIONS(15174), 1,
      anon_sym_def,
    ACTIONS(15337), 1,
      anon_sym_given,
    STATE(16343), 1,
      sym_opaque_modifier,
    STATE(12966), 2,
      sym_comment,
      sym_block_comment,
  [581975] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8102), 1,
      anon_sym_val,
    ACTIONS(8104), 1,
      anon_sym_var,
    ACTIONS(8110), 1,
      anon_sym_opaque,
    ACTIONS(8138), 1,
      anon_sym_case,
    ACTIONS(8140), 1,
      anon_sym_object,
    ACTIONS(8142), 1,
      anon_sym_given,
    ACTIONS(8144), 1,
      anon_sym_class,
    ACTIONS(8146), 1,
      anon_sym_trait,
    ACTIONS(8148), 1,
      anon_sym_type,
    ACTIONS(8150), 1,
      anon_sym_def,
    STATE(17620), 1,
      sym_opaque_modifier,
    STATE(12967), 2,
      sym_comment,
      sym_block_comment,
  [582019] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8110), 1,
      anon_sym_opaque,
    ACTIONS(15168), 1,
      anon_sym_val,
    ACTIONS(15170), 1,
      anon_sym_var,
    ACTIONS(15339), 1,
      anon_sym_case,
    ACTIONS(15341), 1,
      anon_sym_object,
    ACTIONS(15343), 1,
      anon_sym_given,
    ACTIONS(15345), 1,
      anon_sym_class,
    ACTIONS(15347), 1,
      anon_sym_trait,
    ACTIONS(15349), 1,
      anon_sym_type,
    ACTIONS(15351), 1,
      anon_sym_def,
    STATE(17739), 1,
      sym_opaque_modifier,
    STATE(12968), 2,
      sym_comment,
      sym_block_comment,
  [582063] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(12860), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(17384), 1,
      sym_identifier,
    STATE(12969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582097] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12970), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [582121] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12971), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [582145] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12972), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [582169] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12573), 1,
      anon_sym_LPAREN,
    ACTIONS(13425), 1,
      sym__automatic_semicolon,
    STATE(12979), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13452), 1,
      sym_class_parameters,
    STATE(12973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12896), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [582201] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12573), 1,
      anon_sym_LPAREN,
    ACTIONS(15353), 1,
      sym__automatic_semicolon,
    STATE(12642), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13452), 1,
      sym_class_parameters,
    STATE(12974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14515), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [582233] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12573), 1,
      anon_sym_LPAREN,
    ACTIONS(15356), 1,
      sym__automatic_semicolon,
    STATE(12896), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13452), 1,
      sym_class_parameters,
    STATE(12975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14373), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [582265] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8102), 1,
      anon_sym_val,
    ACTIONS(8104), 1,
      anon_sym_var,
    ACTIONS(8110), 1,
      anon_sym_opaque,
    ACTIONS(8138), 1,
      anon_sym_case,
    ACTIONS(8140), 1,
      anon_sym_object,
    ACTIONS(8144), 1,
      anon_sym_class,
    ACTIONS(8146), 1,
      anon_sym_trait,
    ACTIONS(8148), 1,
      anon_sym_type,
    ACTIONS(8150), 1,
      anon_sym_def,
    ACTIONS(8166), 1,
      anon_sym_given,
    STATE(17620), 1,
      sym_opaque_modifier,
    STATE(12976), 2,
      sym_comment,
      sym_block_comment,
  [582309] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12573), 1,
      anon_sym_LPAREN,
    ACTIONS(15359), 1,
      sym__automatic_semicolon,
    STATE(12982), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13452), 1,
      sym_class_parameters,
    STATE(12977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14378), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [582341] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(15362), 1,
      sym_operator_identifier,
    STATE(14696), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(12978), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8056), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582375] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12573), 1,
      anon_sym_LPAREN,
    ACTIONS(15364), 1,
      sym__automatic_semicolon,
    STATE(12896), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13452), 1,
      sym_class_parameters,
    STATE(12979), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14523), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [582407] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12573), 1,
      anon_sym_LPAREN,
    ACTIONS(15367), 1,
      sym__automatic_semicolon,
    STATE(12896), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13452), 1,
      sym_class_parameters,
    STATE(12980), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14383), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [582439] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15370), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15855), 1,
      sym_identifier,
    STATE(12981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582473] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12573), 1,
      anon_sym_LPAREN,
    ACTIONS(15372), 1,
      sym__automatic_semicolon,
    STATE(12896), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13452), 1,
      sym_class_parameters,
    STATE(12982), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14528), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [582505] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [582529] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [582553] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [582577] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13288), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [582601] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [582625] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15375), 1,
      anon_sym_catch,
    ACTIONS(15377), 1,
      anon_sym_finally,
    STATE(11551), 1,
      sym_finally_clause,
    STATE(13298), 1,
      sym_catch_clause,
    STATE(12988), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [582657] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12989), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [582681] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15379), 1,
      anon_sym_catch,
    ACTIONS(15381), 1,
      anon_sym_finally,
    STATE(12886), 1,
      sym_finally_clause,
    STATE(13119), 1,
      sym_catch_clause,
    STATE(12990), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
  [582713] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(830), 1,
      sym__alpha_identifier,
    ACTIONS(860), 1,
      sym__backquoted_id,
    ACTIONS(15383), 1,
      sym_operator_identifier,
    STATE(5706), 1,
      sym__soft_identifier,
    STATE(16283), 1,
      sym_identifier,
    STATE(12991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(840), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582747] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12992), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [582771] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15313), 1,
      anon_sym_catch,
    ACTIONS(15385), 1,
      anon_sym_finally,
    STATE(13368), 1,
      sym_catch_clause,
    STATE(13430), 1,
      sym_finally_clause,
    STATE(12993), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [582803] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12994), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [582827] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14138), 1,
      sym__alpha_identifier,
    ACTIONS(14146), 1,
      sym__backquoted_id,
    ACTIONS(15387), 1,
      sym_operator_identifier,
    STATE(8816), 1,
      sym_identifier,
    STATE(9270), 1,
      sym__soft_identifier,
    STATE(12995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14144), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582861] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8110), 1,
      anon_sym_opaque,
    ACTIONS(15168), 1,
      anon_sym_val,
    ACTIONS(15170), 1,
      anon_sym_var,
    ACTIONS(15339), 1,
      anon_sym_case,
    ACTIONS(15341), 1,
      anon_sym_object,
    ACTIONS(15345), 1,
      anon_sym_class,
    ACTIONS(15347), 1,
      anon_sym_trait,
    ACTIONS(15349), 1,
      anon_sym_type,
    ACTIONS(15351), 1,
      anon_sym_def,
    ACTIONS(15389), 1,
      anon_sym_given,
    STATE(17739), 1,
      sym_opaque_modifier,
    STATE(12996), 2,
      sym_comment,
      sym_block_comment,
  [582905] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [582929] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10058), 1,
      sym__alpha_identifier,
    ACTIONS(10062), 1,
      sym__backquoted_id,
    ACTIONS(15391), 1,
      sym_operator_identifier,
    STATE(4056), 1,
      sym__soft_identifier,
    STATE(15857), 1,
      sym_identifier,
    STATE(12998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10060), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582963] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [582987] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13000), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [583011] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    ACTIONS(15391), 1,
      sym_operator_identifier,
    STATE(14626), 1,
      sym_identifier,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(13001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8056), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583045] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13002), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [583069] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [583093] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(13004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [583119] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9856), 1,
      anon_sym_COLON,
    STATE(13005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [583145] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13006), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [583169] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15048), 1,
      anon_sym_catch,
    ACTIONS(15393), 1,
      anon_sym_finally,
    STATE(13400), 1,
      sym_catch_clause,
    STATE(13413), 1,
      sym_finally_clause,
    STATE(13007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
  [583201] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(12868), 1,
      anon_sym_COLON,
    STATE(14313), 1,
      sym_template_body,
    STATE(14361), 1,
      sym__definition_body,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13008), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15395), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [583235] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14197), 1,
      sym__alpha_identifier,
    ACTIONS(14205), 1,
      sym__backquoted_id,
    ACTIONS(15397), 1,
      sym_operator_identifier,
    STATE(9349), 1,
      sym__soft_identifier,
    STATE(9375), 1,
      sym_identifier,
    STATE(13009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14203), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583269] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15016), 1,
      anon_sym_catch,
    ACTIONS(15399), 1,
      anon_sym_finally,
    STATE(12410), 1,
      sym_finally_clause,
    STATE(13351), 1,
      sym_catch_clause,
    STATE(13010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [583301] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11563), 1,
      sym__backquoted_id,
    STATE(13011), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11561), 10,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [583327] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15007), 1,
      anon_sym_LBRACK,
    STATE(7490), 1,
      sym_type_arguments,
    STATE(13012), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [583355] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14209), 1,
      sym__alpha_identifier,
    ACTIONS(14217), 1,
      sym__backquoted_id,
    ACTIONS(15401), 1,
      sym_operator_identifier,
    STATE(8722), 1,
      sym__soft_identifier,
    STATE(8861), 1,
      sym_identifier,
    STATE(13013), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14215), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583389] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8110), 1,
      anon_sym_opaque,
    ACTIONS(15168), 1,
      anon_sym_val,
    ACTIONS(15170), 1,
      anon_sym_var,
    ACTIONS(15339), 1,
      anon_sym_case,
    ACTIONS(15341), 1,
      anon_sym_object,
    ACTIONS(15345), 1,
      anon_sym_class,
    ACTIONS(15347), 1,
      anon_sym_trait,
    ACTIONS(15403), 1,
      anon_sym_given,
    ACTIONS(15405), 1,
      anon_sym_type,
    ACTIONS(15407), 1,
      anon_sym_def,
    STATE(17595), 1,
      sym_opaque_modifier,
    STATE(13014), 2,
      sym_comment,
      sym_block_comment,
  [583433] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8408), 1,
      sym__backquoted_id,
    ACTIONS(8412), 1,
      anon_sym_EQ_GT,
    STATE(13015), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8406), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [583461] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14892), 1,
      sym__alpha_identifier,
    ACTIONS(14900), 1,
      sym__backquoted_id,
    ACTIONS(15409), 1,
      sym_operator_identifier,
    STATE(9328), 1,
      sym__soft_identifier,
    STATE(9503), 1,
      sym_identifier,
    STATE(13016), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14898), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583495] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13017), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [583519] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14421), 1,
      sym__alpha_identifier,
    ACTIONS(14429), 1,
      sym__backquoted_id,
    ACTIONS(15411), 1,
      sym_operator_identifier,
    STATE(8754), 1,
      sym__soft_identifier,
    STATE(9188), 1,
      sym_identifier,
    STATE(13018), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14427), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583553] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13019), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [583577] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [583601] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13021), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [583625] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [583649] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13023), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [583673] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13024), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [583697] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13025), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [583720] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15413), 1,
      anon_sym_LBRACK,
    STATE(8372), 1,
      sym_type_arguments,
    STATE(13026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [583747] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15413), 1,
      anon_sym_LBRACK,
    STATE(8372), 1,
      sym_type_arguments,
    STATE(13027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [583774] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15415), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [583797] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15417), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [583820] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15419), 1,
      anon_sym_with,
    STATE(13030), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat2,
    ACTIONS(15211), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [583845] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15422), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [583868] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13032), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [583891] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [583914] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10970), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [583937] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15424), 1,
      anon_sym_LBRACK,
    STATE(8507), 1,
      sym_type_arguments,
    STATE(13035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [583964] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13036), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [583987] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13037), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [584010] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15426), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [584033] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13039), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [584056] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [584079] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [584102] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    ACTIONS(13414), 1,
      anon_sym_LT_COLON,
    ACTIONS(13418), 1,
      anon_sym_LT_PERCENT,
    STATE(13647), 1,
      aux_sym__type_parameter_repeat1,
    STATE(13649), 1,
      sym_upper_bound,
    STATE(14174), 1,
      aux_sym__type_parameter_repeat2,
    STATE(14680), 1,
      sym_view_bound,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(15429), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(13042), 2,
      sym_comment,
      sym_block_comment,
  [584141] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [584164] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9856), 1,
      anon_sym_COLON,
    STATE(13044), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [584189] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [584212] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [584235] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13047), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [584258] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [584281] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15431), 1,
      anon_sym_DOT,
    STATE(13049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [584306] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [584329] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [584352] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [584375] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [584398] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11071), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [584421] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13288), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [584444] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13056), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [584467] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13290), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [584490] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15433), 1,
      anon_sym_COMMA,
    STATE(13058), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat1,
    ACTIONS(15206), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [584515] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [584538] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15424), 1,
      anon_sym_LBRACK,
    ACTIONS(15436), 1,
      anon_sym_match,
    STATE(8507), 1,
      sym_type_arguments,
    STATE(13060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [584567] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15438), 1,
      anon_sym_LBRACK,
    STATE(8556), 1,
      sym_type_arguments,
    STATE(13061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13388), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [584594] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [584617] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15440), 1,
      anon_sym_catch,
    ACTIONS(15442), 1,
      anon_sym_finally,
    STATE(13394), 1,
      sym_catch_clause,
    STATE(13536), 1,
      sym_finally_clause,
    STATE(13063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [584648] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15444), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [584671] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13065), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [584694] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15446), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [584717] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15075), 1,
      anon_sym_finally,
    STATE(12087), 1,
      sym_finally_clause,
    STATE(13067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_do,
      anon_sym_yield,
  [584744] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15448), 1,
      anon_sym_end,
    STATE(8830), 1,
      sym__end_marker,
    STATE(13068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [584771] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [584794] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [584817] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14595), 1,
      anon_sym_finally,
    STATE(12600), 1,
      sym_finally_clause,
    STATE(13071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [584844] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14413), 1,
      anon_sym_finally,
    STATE(11785), 1,
      sym_finally_clause,
    STATE(13072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [584871] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13073), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [584894] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15450), 1,
      anon_sym_DOT,
    STATE(13074), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [584919] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9856), 1,
      anon_sym_COLON,
    STATE(13075), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [584944] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15413), 1,
      anon_sym_LBRACK,
    ACTIONS(15452), 1,
      anon_sym_match,
    STATE(8372), 1,
      sym_type_arguments,
    STATE(13076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [584973] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [584996] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(13242), 1,
      anon_sym_COLON,
    ACTIONS(15454), 1,
      sym__automatic_semicolon,
    STATE(14568), 1,
      sym__definition_body,
    STATE(14724), 1,
      sym_template_body,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13078), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15228), 3,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [585031] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9856), 1,
      anon_sym_COLON,
    STATE(13079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [585056] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13298), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [585079] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    ACTIONS(13414), 1,
      anon_sym_LT_COLON,
    ACTIONS(13418), 1,
      anon_sym_LT_PERCENT,
    STATE(13753), 1,
      aux_sym__type_parameter_repeat1,
    STATE(13756), 1,
      sym_upper_bound,
    STATE(14257), 1,
      aux_sym__type_parameter_repeat2,
    STATE(14680), 1,
      sym_view_bound,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(15457), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(13081), 2,
      sym_comment,
      sym_block_comment,
  [585118] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13302), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [585141] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13083), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [585164] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [585187] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13306), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [585210] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [585233] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13087), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [585256] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13088), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [585279] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13089), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13310), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [585302] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15438), 1,
      anon_sym_LBRACK,
    STATE(8556), 1,
      sym_type_arguments,
    STATE(13090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [585329] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13091), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13312), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [585352] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13316), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13092), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13314), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [585377] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13093), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [585400] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [585423] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13095), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13304), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [585446] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [585469] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13097), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13319), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [585492] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15413), 1,
      anon_sym_LBRACK,
    STATE(8372), 1,
      sym_type_arguments,
    STATE(13098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [585519] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13099), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [585542] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13321), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [585565] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13101), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13323), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [585588] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15459), 1,
      anon_sym_catch,
    ACTIONS(15461), 1,
      anon_sym_finally,
    STATE(12577), 1,
      sym_finally_clause,
    STATE(13734), 1,
      sym_catch_clause,
    STATE(13102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [585619] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13708), 1,
      anon_sym_LPAREN,
    STATE(13662), 1,
      sym_parameters,
    STATE(13782), 1,
      sym__using_parameters_clause,
    STATE(13103), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15140), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [585648] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13104), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [585671] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7320), 1,
      anon_sym_LBRACK,
    ACTIONS(15463), 1,
      anon_sym_LT_COLON,
    ACTIONS(15465), 1,
      anon_sym_GT_COLON,
    STATE(13831), 1,
      sym_type_parameters,
    STATE(14161), 1,
      sym_upper_bound,
    STATE(14162), 1,
      sym_lower_bound,
    STATE(13105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15040), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_EQ,
      anon_sym_SEMI,
  [585706] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15467), 1,
      anon_sym_catch,
    ACTIONS(15469), 1,
      anon_sym_finally,
    STATE(13441), 1,
      sym_catch_clause,
    STATE(13536), 1,
      sym_finally_clause,
    STATE(13106), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [585737] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15471), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [585760] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15474), 1,
      anon_sym_STAR,
    STATE(13108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [585785] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15476), 1,
      anon_sym_STAR,
    STATE(13109), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [585810] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13329), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [585833] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [585856] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [585879] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [585902] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15424), 1,
      anon_sym_LBRACK,
    STATE(8507), 1,
      sym_type_arguments,
    STATE(13114), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [585929] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [585952] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [585975] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [585998] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15478), 1,
      anon_sym_LBRACK,
    ACTIONS(15480), 1,
      anon_sym_AT,
    ACTIONS(15482), 1,
      anon_sym_POUND,
    STATE(13843), 1,
      sym_type_arguments,
    STATE(13956), 1,
      aux_sym_enum_definition_repeat1,
    STATE(14184), 1,
      sym_annotation,
    STATE(13118), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_LPAREN,
  [586033] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15381), 1,
      anon_sym_finally,
    STATE(12922), 1,
      sym_finally_clause,
    STATE(13119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
  [586060] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [586083] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15484), 1,
      anon_sym_catch,
    ACTIONS(15486), 1,
      anon_sym_finally,
    STATE(12745), 1,
      sym_finally_clause,
    STATE(13711), 1,
      sym_catch_clause,
    STATE(13121), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [586114] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13122), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [586137] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 10,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [586160] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13124), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [586183] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [586206] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(13242), 1,
      anon_sym_COLON,
    STATE(14504), 1,
      sym__definition_body,
    STATE(14724), 1,
      sym_template_body,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13126), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15311), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [586239] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13331), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [586262] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15488), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [586285] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13129), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13333), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [586308] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13130), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [586331] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13340), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13131), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13338), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [586356] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15490), 1,
      anon_sym_end,
    STATE(9247), 1,
      sym__end_marker,
    STATE(13132), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [586383] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [586406] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13134), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [586429] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13347), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13345), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [586454] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [586477] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13137), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [586500] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [586523] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13302), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [586546] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15438), 1,
      anon_sym_LBRACK,
    ACTIONS(15494), 1,
      anon_sym_match,
    STATE(8556), 1,
      sym_type_arguments,
    STATE(13140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [586575] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(13141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [586600] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [586623] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13143), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [586646] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [586669] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [586692] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [586715] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12588), 1,
      anon_sym_LPAREN,
    STATE(13719), 1,
      sym_arguments,
    STATE(13147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15496), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_SEMI,
  [586742] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13148), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [586765] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13149), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [586788] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13150), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [586811] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15424), 1,
      anon_sym_LBRACK,
    ACTIONS(15436), 1,
      anon_sym_match,
    STATE(8507), 1,
      sym_type_arguments,
    STATE(13151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [586840] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15256), 1,
      anon_sym_finally,
    STATE(13242), 1,
      sym_finally_clause,
    STATE(13152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
  [586867] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [586890] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [586913] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13155), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [586936] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [586959] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [586982] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [587005] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13159), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [587028] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15498), 1,
      anon_sym_LBRACK,
    STATE(8490), 1,
      sym_type_arguments,
    STATE(13160), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13388), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [587055] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13161), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13304), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [587078] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [587101] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15500), 1,
      anon_sym_catch,
    ACTIONS(15502), 1,
      anon_sym_finally,
    STATE(13783), 1,
      sym_catch_clause,
    STATE(13915), 1,
      sym_finally_clause,
    STATE(13163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [587132] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15506), 1,
      anon_sym_SEMI,
    ACTIONS(15509), 1,
      anon_sym_else,
    STATE(13164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [587159] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15516), 1,
      anon_sym_SEMI,
    ACTIONS(15519), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 6,
      sym__automatic_semicolon,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [587188] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15521), 1,
      anon_sym_catch,
    ACTIONS(15523), 1,
      anon_sym_finally,
    STATE(11551), 1,
      sym_finally_clause,
    STATE(13625), 1,
      sym_catch_clause,
    STATE(13166), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [587219] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [587242] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [587265] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13169), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [587288] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15438), 1,
      anon_sym_LBRACK,
    STATE(8556), 1,
      sym_type_arguments,
    STATE(13170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [587315] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15525), 1,
      anon_sym_SEMI,
    ACTIONS(15528), 1,
      anon_sym_else,
    STATE(13171), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [587342] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15531), 1,
      anon_sym_SEMI,
    ACTIONS(15534), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 6,
      sym__automatic_semicolon,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [587371] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13288), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [587394] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9924), 1,
      anon_sym_LPAREN,
    STATE(13177), 1,
      aux_sym_annotation_repeat1,
    STATE(13802), 1,
      sym_arguments,
    STATE(13174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [587423] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13175), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13290), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [587446] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15438), 1,
      anon_sym_LBRACK,
    STATE(8556), 1,
      sym_type_arguments,
    STATE(13176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [587473] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15537), 1,
      anon_sym_LPAREN,
    STATE(13802), 1,
      sym_arguments,
    STATE(13177), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [587500] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 10,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [587523] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [587546] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [587569] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15540), 1,
      anon_sym_catch,
    ACTIONS(15542), 1,
      anon_sym_finally,
    STATE(11949), 1,
      sym_finally_clause,
    STATE(13621), 1,
      sym_catch_clause,
    STATE(13181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [587600] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13182), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [587623] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13183), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15544), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [587646] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15547), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [587669] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [587692] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13186), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [587715] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15498), 1,
      anon_sym_LBRACK,
    ACTIONS(15549), 1,
      anon_sym_match,
    STATE(8490), 1,
      sym_type_arguments,
    STATE(13187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [587744] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [587767] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13189), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [587790] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13190), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [587813] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [587836] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [587859] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15498), 1,
      anon_sym_LBRACK,
    STATE(8490), 1,
      sym_type_arguments,
    STATE(13193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [587886] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15498), 1,
      anon_sym_LBRACK,
    STATE(8490), 1,
      sym_type_arguments,
    STATE(13194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [587913] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15478), 1,
      anon_sym_LBRACK,
    ACTIONS(15482), 1,
      anon_sym_POUND,
    ACTIONS(15551), 1,
      anon_sym_LPAREN,
    STATE(13843), 1,
      sym_type_arguments,
    STATE(13929), 1,
      aux_sym_annotation_repeat1,
    STATE(14251), 1,
      sym_arguments,
    STATE(13195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8156), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_with,
  [587948] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13470), 1,
      sym_arguments,
    STATE(13196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [587973] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [587996] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13198), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15553), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [588019] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13199), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [588042] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13200), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [588065] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [588088] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15498), 1,
      anon_sym_LBRACK,
    ACTIONS(15549), 1,
      anon_sym_match,
    STATE(8490), 1,
      sym_type_arguments,
    STATE(13202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [588117] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15556), 1,
      anon_sym_catch,
    ACTIONS(15558), 1,
      anon_sym_finally,
    STATE(13678), 1,
      sym_finally_clause,
    STATE(13693), 1,
      sym_catch_clause,
    STATE(13203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [588148] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [588171] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [588194] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13206), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15560), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [588217] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13207), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [588240] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [588263] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [588286] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [588309] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13211), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14323), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [588332] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [588355] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [588378] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8074), 1,
      sym__backquoted_id,
    STATE(14725), 1,
      sym__soft_identifier,
    STATE(15604), 1,
      sym_identifier,
    STATE(13214), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8056), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [588409] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13215), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [588432] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15498), 1,
      anon_sym_LBRACK,
    STATE(8490), 1,
      sym_type_arguments,
    STATE(13216), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [588459] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15125), 1,
      anon_sym_finally,
    STATE(12087), 1,
      sym_finally_clause,
    STATE(13217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
  [588486] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13218), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [588509] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13219), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13298), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [588532] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13220), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [588555] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15562), 1,
      anon_sym_STAR,
    STATE(13221), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [588580] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [588603] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13223), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [588626] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12715), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [588649] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15484), 1,
      anon_sym_catch,
    ACTIONS(15564), 1,
      anon_sym_finally,
    STATE(12410), 1,
      sym_finally_clause,
    STATE(13707), 1,
      sym_catch_clause,
    STATE(13225), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [588680] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13226), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [588703] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13227), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [588726] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [588749] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15556), 1,
      anon_sym_catch,
    ACTIONS(15566), 1,
      anon_sym_finally,
    STATE(13683), 1,
      sym_catch_clause,
    STATE(13915), 1,
      sym_finally_clause,
    STATE(13229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [588780] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(13242), 1,
      anon_sym_COLON,
    STATE(14431), 1,
      sym__definition_body,
    STATE(14724), 1,
      sym_template_body,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15395), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [588813] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15568), 1,
      anon_sym_SEMI,
    ACTIONS(15571), 1,
      anon_sym_else,
    STATE(13231), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_catch,
      anon_sym_finally,
  [588840] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13232), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13306), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [588863] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15573), 1,
      anon_sym_SEMI,
    ACTIONS(15576), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13233), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_catch,
      anon_sym_finally,
  [588892] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15085), 1,
      anon_sym_finally,
    STATE(13242), 1,
      sym_finally_clause,
    STATE(13234), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
  [588919] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [588942] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13708), 1,
      anon_sym_LPAREN,
    STATE(13662), 1,
      sym_parameters,
    STATE(13782), 1,
      sym__using_parameters_clause,
    STATE(13236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15317), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [588971] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15578), 1,
      anon_sym_end,
    STATE(9286), 1,
      sym__end_marker,
    STATE(13237), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [588998] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13238), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [589021] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15580), 1,
      anon_sym_STAR,
    STATE(13239), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [589046] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [589069] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [589092] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13242), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [589115] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13243), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [589138] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [589161] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15582), 1,
      anon_sym_SEMI,
    ACTIONS(15585), 1,
      anon_sym_else,
    STATE(13245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_catch,
      anon_sym_finally,
  [589188] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13246), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [589211] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15588), 1,
      anon_sym_SEMI,
    ACTIONS(15591), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_catch,
      anon_sym_finally,
  [589240] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15413), 1,
      anon_sym_LBRACK,
    STATE(8372), 1,
      sym_type_arguments,
    STATE(13248), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [589267] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13310), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [589290] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14928), 1,
      anon_sym_COMMA,
    STATE(13058), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(13250), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15079), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [589317] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13251), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [589340] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13347), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13252), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13345), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [589365] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14585), 1,
      anon_sym_finally,
    STATE(12600), 1,
      sym_finally_clause,
    STATE(13253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
  [589392] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15413), 1,
      anon_sym_LBRACK,
    STATE(8372), 1,
      sym_type_arguments,
    STATE(13254), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13388), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [589419] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13255), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [589442] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13256), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [589465] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13257), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13312), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [589488] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15500), 1,
      anon_sym_catch,
    ACTIONS(15594), 1,
      anon_sym_finally,
    STATE(13678), 1,
      sym_finally_clause,
    STATE(13730), 1,
      sym_catch_clause,
    STATE(13258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [589519] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10123), 1,
      anon_sym_LPAREN,
    STATE(4401), 1,
      sym_arguments,
    STATE(13286), 1,
      aux_sym_annotation_repeat1,
    STATE(13259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [589548] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15498), 1,
      anon_sym_LBRACK,
    STATE(8490), 1,
      sym_type_arguments,
    STATE(13260), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [589575] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13708), 1,
      anon_sym_LPAREN,
    STATE(13662), 1,
      sym_parameters,
    STATE(13782), 1,
      sym__using_parameters_clause,
    STATE(13261), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15319), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [589604] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13262), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [589627] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15413), 1,
      anon_sym_LBRACK,
    ACTIONS(15452), 1,
      anon_sym_match,
    STATE(8372), 1,
      sym_type_arguments,
    STATE(13263), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [589656] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13316), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13264), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13314), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [589681] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13265), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [589704] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13266), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [589727] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13267), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13319), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [589750] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12703), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [589773] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12606), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [589796] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [589819] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13271), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [589842] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13321), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [589865] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13273), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [589888] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [589911] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15459), 1,
      anon_sym_catch,
    ACTIONS(15596), 1,
      anon_sym_finally,
    STATE(11980), 1,
      sym_finally_clause,
    STATE(13747), 1,
      sym_catch_clause,
    STATE(13275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [589942] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13276), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13323), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [589965] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [589988] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [590011] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15438), 1,
      anon_sym_LBRACK,
    ACTIONS(15494), 1,
      anon_sym_match,
    STATE(8556), 1,
      sym_type_arguments,
    STATE(13279), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [590040] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13280), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [590063] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14930), 1,
      anon_sym_with,
    STATE(13030), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(13281), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15079), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [590090] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13282), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [590113] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13283), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [590136] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13284), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [590159] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [590182] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11883), 1,
      anon_sym_LPAREN,
    STATE(4401), 1,
      sym_arguments,
    STATE(13286), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [590209] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [590232] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13288), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12717), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [590255] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [590278] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15424), 1,
      anon_sym_LBRACK,
    STATE(8507), 1,
      sym_type_arguments,
    STATE(13290), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [590305] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15424), 1,
      anon_sym_LBRACK,
    STATE(8507), 1,
      sym_type_arguments,
    STATE(13291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [590332] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13329), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [590355] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [590378] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14471), 1,
      anon_sym_finally,
    STATE(11785), 1,
      sym_finally_clause,
    STATE(13294), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
  [590405] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13295), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [590428] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13296), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [590451] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13297), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [590474] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15377), 1,
      anon_sym_finally,
    STATE(11562), 1,
      sym_finally_clause,
    STATE(13298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
  [590501] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13299), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [590524] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13300), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [590547] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [590570] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [590593] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13708), 1,
      anon_sym_LPAREN,
    STATE(13662), 1,
      sym_parameters,
    STATE(13782), 1,
      sym__using_parameters_clause,
    STATE(13303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15272), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [590622] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13304), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15598), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [590645] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13305), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [590668] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [590691] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [590714] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15438), 1,
      anon_sym_LBRACK,
    STATE(8556), 1,
      sym_type_arguments,
    STATE(13308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [590741] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [590764] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9363), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13310), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9856), 8,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [590789] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13311), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [590812] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13312), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13331), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [590835] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13313), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13333), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [590858] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13314), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [590881] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13315), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [590904] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [590927] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9856), 1,
      anon_sym_COLON,
    STATE(13317), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [590952] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13318), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [590975] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13340), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13338), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [591000] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(13242), 1,
      anon_sym_COLON,
    ACTIONS(15601), 1,
      sym__automatic_semicolon,
    STATE(14545), 1,
      sym__definition_body,
    STATE(14724), 1,
      sym_template_body,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13320), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15237), 3,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [591035] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [591057] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [591079] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13323), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [591101] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15604), 1,
      anon_sym_LPAREN,
    STATE(13893), 1,
      sym_arguments,
    STATE(13324), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
  [591127] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15058), 1,
      anon_sym_finally,
    STATE(12447), 1,
      sym_finally_clause,
    STATE(13325), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [591153] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13326), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13306), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [591175] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15484), 1,
      anon_sym_catch,
    ACTIONS(15607), 1,
      anon_sym_finally,
    STATE(12745), 1,
      sym_finally_clause,
    STATE(13902), 1,
      sym_catch_clause,
    STATE(13327), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [591205] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13347), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13328), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13345), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [591229] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13376), 1,
      anon_sym_match,
    ACTIONS(15609), 1,
      anon_sym_LBRACK,
    STATE(9167), 1,
      sym_type_arguments,
    STATE(13329), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [591257] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13330), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14075), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [591279] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13331), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13288), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [591301] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15611), 1,
      anon_sym_catch,
    ACTIONS(15613), 1,
      anon_sym_finally,
    STATE(13413), 1,
      sym_finally_clause,
    STATE(13926), 1,
      sym_catch_clause,
    STATE(13332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 5,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [591331] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13333), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13290), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [591353] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [591375] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15609), 1,
      anon_sym_LBRACK,
    STATE(9167), 1,
      sym_type_arguments,
    STATE(13335), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [591401] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15615), 1,
      anon_sym_LBRACK,
    STATE(8908), 1,
      sym_type_arguments,
    STATE(13336), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [591427] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13340), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13338), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [591451] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13860), 1,
      anon_sym_LPAREN,
    STATE(13324), 1,
      aux_sym_annotation_repeat1,
    STATE(13893), 1,
      sym_arguments,
    STATE(13338), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
  [591479] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13339), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [591501] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15617), 1,
      anon_sym_STAR,
    STATE(13340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [591525] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15619), 1,
      anon_sym_SEMI,
    ACTIONS(15622), 1,
      anon_sym_else,
    STATE(13341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [591551] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15624), 1,
      anon_sym_SEMI,
    ACTIONS(15627), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13342), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 5,
      sym__automatic_semicolon,
      anon_sym_if,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [591579] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15315), 1,
      anon_sym_finally,
    STATE(13760), 1,
      sym_finally_clause,
    STATE(13343), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [591605] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15291), 1,
      anon_sym_finally,
    STATE(12932), 1,
      sym_finally_clause,
    STATE(13344), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [591631] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15629), 1,
      anon_sym_SEMI,
    ACTIONS(15632), 1,
      anon_sym_else,
    STATE(13345), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [591657] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15635), 1,
      anon_sym_SEMI,
    ACTIONS(15638), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 5,
      sym__automatic_semicolon,
      anon_sym_if,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [591685] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15038), 1,
      anon_sym_finally,
    STATE(11785), 1,
      sym_finally_clause,
    STATE(13347), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [591711] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [591733] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15641), 1,
      anon_sym_STAR,
    STATE(13349), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [591757] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15643), 1,
      anon_sym_DOT,
    STATE(13350), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [591781] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15399), 1,
      anon_sym_finally,
    STATE(12447), 1,
      sym_finally_clause,
    STATE(13351), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [591807] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [591829] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13353), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [591851] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13354), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15426), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [591873] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [591895] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15609), 1,
      anon_sym_LBRACK,
    STATE(9167), 1,
      sym_type_arguments,
    STATE(13356), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [591921] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13347), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13357), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13345), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [591945] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [591967] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15645), 1,
      anon_sym_LBRACK,
    ACTIONS(15647), 1,
      anon_sym_match,
    STATE(8850), 1,
      sym_type_arguments,
    STATE(13359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
  [591995] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15649), 1,
      anon_sym_SEMI,
    ACTIONS(15652), 1,
      anon_sym_else,
    STATE(13360), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [592021] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15655), 1,
      anon_sym_SEMI,
    ACTIONS(15658), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13361), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
  [592049] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13362), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [592071] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [592093] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13364), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13310), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [592115] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13365), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15553), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [592137] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15615), 1,
      anon_sym_LBRACK,
    ACTIONS(15661), 1,
      anon_sym_match,
    STATE(8908), 1,
      sym_type_arguments,
    STATE(13366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_finally,
  [592165] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13288), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [592187] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15385), 1,
      anon_sym_finally,
    STATE(13487), 1,
      sym_finally_clause,
    STATE(13368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [592213] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13369), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [592235] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9856), 1,
      anon_sym_COLON,
    STATE(13370), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [592259] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15107), 1,
      anon_sym_if,
    STATE(13541), 1,
      aux_sym_enumerator_repeat1,
    STATE(13935), 1,
      sym_guard,
    STATE(13371), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15663), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [592287] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [592309] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [592331] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15042), 1,
      anon_sym_LT_COLON,
    ACTIONS(15044), 1,
      anon_sym_GT_COLON,
    STATE(13947), 1,
      sym_lower_bound,
    STATE(14367), 1,
      sym_upper_bound,
    STATE(13374), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15665), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [592361] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13375), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13323), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [592383] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15667), 1,
      anon_sym_catch,
    ACTIONS(15669), 1,
      anon_sym_finally,
    STATE(12745), 1,
      sym_finally_clause,
    STATE(13939), 1,
      sym_catch_clause,
    STATE(13376), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [592413] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15671), 1,
      anon_sym_LBRACK,
    STATE(8802), 1,
      sym_type_arguments,
    STATE(13377), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [592439] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15471), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [592461] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15671), 1,
      anon_sym_LBRACK,
    STATE(8802), 1,
      sym_type_arguments,
    STATE(13379), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [592487] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13380), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [592509] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15675), 1,
      anon_sym_COMMA,
    STATE(13627), 1,
      aux_sym_derives_clause_repeat1,
    STATE(13381), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15673), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [592535] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13382), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [592557] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15677), 1,
      anon_sym_SEMI,
    ACTIONS(15679), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13383), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
  [592585] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13312), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [592607] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [592629] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15681), 1,
      anon_sym_SEMI,
    ACTIONS(15684), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13386), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_catch,
      anon_sym_finally,
  [592657] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13387), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [592679] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13388), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12610), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [592701] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13389), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [592723] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15686), 1,
      anon_sym_SEMI,
    ACTIONS(15689), 1,
      anon_sym_else,
    STATE(13390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [592749] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13391), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [592771] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13392), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14323), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [592793] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13393), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15488), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [592815] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15442), 1,
      anon_sym_finally,
    STATE(13339), 1,
      sym_finally_clause,
    STATE(13394), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
  [592841] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15691), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [592863] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12608), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [592885] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [592907] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13316), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13314), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [592931] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [592953] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15393), 1,
      anon_sym_finally,
    STATE(13380), 1,
      sym_finally_clause,
    STATE(13400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
  [592979] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15645), 1,
      anon_sym_LBRACK,
    STATE(8850), 1,
      sym_type_arguments,
    STATE(13401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [593005] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13402), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13319), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [593027] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15444), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [593049] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [593071] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13316), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13405), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13314), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [593095] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [593117] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13407), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [593139] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13408), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [593161] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15615), 1,
      anon_sym_LBRACK,
    ACTIONS(15661), 1,
      anon_sym_match,
    STATE(8908), 1,
      sym_type_arguments,
    STATE(13409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_finally,
  [593189] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13410), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [593211] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13411), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [593233] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [593255] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13413), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [593277] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13414), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13321), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [593299] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13415), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [593321] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13416), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [593343] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [593365] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15645), 1,
      anon_sym_LBRACK,
    STATE(8850), 1,
      sym_type_arguments,
    STATE(13418), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [593391] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15615), 1,
      anon_sym_LBRACK,
    STATE(8908), 1,
      sym_type_arguments,
    STATE(13419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13388), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [593417] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15645), 1,
      anon_sym_LBRACK,
    STATE(8850), 1,
      sym_type_arguments,
    STATE(13420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [593443] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15671), 1,
      anon_sym_LBRACK,
    ACTIONS(15693), 1,
      anon_sym_match,
    STATE(8802), 1,
      sym_type_arguments,
    STATE(13421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [593471] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9856), 1,
      anon_sym_COLON,
    STATE(13422), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [593495] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15695), 1,
      anon_sym_SEMI,
    ACTIONS(15698), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13423), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_catch,
      anon_sym_finally,
  [593523] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13424), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [593545] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15422), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [593567] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13426), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [593589] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13427), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [593611] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13428), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13323), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [593633] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13429), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10970), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [593655] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13430), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [593677] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13431), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [593699] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13432), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [593721] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13433), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [593743] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13434), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [593765] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15050), 1,
      anon_sym_finally,
    STATE(13086), 1,
      sym_finally_clause,
    STATE(13435), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
  [593791] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13436), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [593813] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13290), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [593835] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [593857] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15700), 1,
      anon_sym_SEMI,
    ACTIONS(15703), 1,
      anon_sym_else,
    STATE(13439), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
  [593883] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13440), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [593905] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15469), 1,
      anon_sym_finally,
    STATE(13339), 1,
      sym_finally_clause,
    STATE(13441), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
  [593931] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13442), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [593953] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13443), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13288), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [593975] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13444), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13331), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [593997] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13445), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13290), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [594019] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13446), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
  [594041] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9856), 1,
      anon_sym_COLON,
    STATE(13447), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [594065] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12692), 1,
      anon_sym_LPAREN,
    STATE(13941), 1,
      sym_arguments,
    STATE(13448), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15496), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_SEMI,
  [594091] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15706), 1,
      anon_sym_catch,
    ACTIONS(15708), 1,
      anon_sym_finally,
    STATE(13903), 1,
      sym_finally_clause,
    STATE(13978), 1,
      sym_catch_clause,
    STATE(13449), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
  [594121] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15710), 1,
      anon_sym_with,
    STATE(13450), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [594145] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13331), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [594167] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13452), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15446), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [594189] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13453), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12719), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [594211] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13454), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13304), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [594233] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [594255] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13456), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [594277] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13457), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13298), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [594299] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13458), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [594321] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [594343] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15671), 1,
      anon_sym_LBRACK,
    STATE(8802), 1,
      sym_type_arguments,
    STATE(13460), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [594369] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15671), 1,
      anon_sym_LBRACK,
    STATE(8802), 1,
      sym_type_arguments,
    STATE(13461), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [594395] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13462), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15560), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [594417] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15713), 1,
      anon_sym_catch,
    ACTIONS(15715), 1,
      anon_sym_finally,
    STATE(13579), 1,
      sym_finally_clause,
    STATE(13673), 1,
      sym_catch_clause,
    STATE(13463), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
  [594447] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [594469] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [594491] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13466), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [594513] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12660), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [594535] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15615), 1,
      anon_sym_LBRACK,
    STATE(8908), 1,
      sym_type_arguments,
    STATE(13468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [594561] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13340), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13469), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13338), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [594585] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [594607] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15717), 1,
      anon_sym_SEMI,
    ACTIONS(15720), 1,
      anon_sym_else,
    STATE(13471), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [594633] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13472), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [594655] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11924), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [594677] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15722), 1,
      anon_sym_SEMI,
    ACTIONS(15725), 1,
      anon_sym_else,
    STATE(13474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [594703] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13475), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [594725] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15728), 1,
      anon_sym_end,
    STATE(9666), 1,
      sym__end_marker,
    STATE(13476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [594751] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13310), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [594773] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15706), 1,
      anon_sym_catch,
    ACTIONS(15730), 1,
      anon_sym_finally,
    STATE(13813), 1,
      sym_finally_clause,
    STATE(13900), 1,
      sym_catch_clause,
    STATE(13478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
  [594803] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15732), 1,
      anon_sym_catch,
    ACTIONS(15734), 1,
      anon_sym_finally,
    STATE(13048), 1,
      sym_finally_clause,
    STATE(13969), 1,
      sym_catch_clause,
    STATE(13479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 5,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [594833] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15738), 1,
      anon_sym_COMMA,
    STATE(13480), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_derives_clause_repeat1,
    ACTIONS(15736), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [594857] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13298), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [594879] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15741), 1,
      anon_sym_catch,
    ACTIONS(15743), 1,
      anon_sym_finally,
    STATE(11949), 1,
      sym_finally_clause,
    STATE(13765), 1,
      sym_catch_clause,
    STATE(13482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [594909] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13483), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [594931] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13484), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [594953] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15732), 1,
      anon_sym_catch,
    ACTIONS(15745), 1,
      anon_sym_finally,
    STATE(13413), 1,
      sym_finally_clause,
    STATE(13862), 1,
      sym_catch_clause,
    STATE(13485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 5,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [594983] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13486), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13306), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [595005] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [595027] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13488), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15598), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [595049] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [595071] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13490), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13310), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [595093] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11881), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [595115] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12669), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [595137] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13493), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13329), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [595159] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13494), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12628), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [595181] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13495), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13312), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [595203] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15671), 1,
      anon_sym_LBRACK,
    STATE(8802), 1,
      sym_type_arguments,
    STATE(13496), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13388), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [595229] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13316), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13497), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13314), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [595253] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15671), 1,
      anon_sym_LBRACK,
    ACTIONS(15693), 1,
      anon_sym_match,
    STATE(8802), 1,
      sym_type_arguments,
    STATE(13498), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [595281] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [595303] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13500), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13319), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [595325] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13501), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [595347] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15747), 1,
      anon_sym_SEMI,
    ACTIONS(15750), 1,
      anon_sym_else,
    STATE(13502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_finally,
  [595373] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15609), 1,
      anon_sym_LBRACK,
    STATE(9167), 1,
      sym_type_arguments,
    STATE(13503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [595399] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13504), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13321), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [595421] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15752), 1,
      anon_sym_SEMI,
    ACTIONS(15755), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13505), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_finally,
  [595449] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15757), 1,
      anon_sym_SEMI,
    ACTIONS(15760), 1,
      anon_sym_else,
    STATE(13506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_finally,
  [595475] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13568), 1,
      anon_sym_AT,
    STATE(13556), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13894), 1,
      sym_annotation,
    STATE(13507), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [595503] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15763), 1,
      anon_sym_SEMI,
    ACTIONS(15766), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13508), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_finally,
  [595531] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13509), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13323), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [595553] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15615), 1,
      anon_sym_LBRACK,
    STATE(8908), 1,
      sym_type_arguments,
    STATE(13510), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [595579] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13511), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [595601] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [595623] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13319), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [595645] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13514), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13331), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [595667] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13515), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [595689] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15609), 1,
      anon_sym_LBRACK,
    STATE(9167), 1,
      sym_type_arguments,
    STATE(13516), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13388), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [595715] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13333), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [595737] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [595759] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13519), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13310), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [595781] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_LBRACE,
    ACTIONS(12913), 1,
      anon_sym_COLON,
    STATE(14250), 1,
      aux_sym_compound_type_repeat1,
    STATE(16063), 1,
      sym__refinement,
    STATE(16139), 1,
      sym_template_body,
    ACTIONS(8252), 2,
      anon_sym_with,
      anon_sym_LPAREN,
    STATE(13520), 2,
      sym_comment,
      sym_block_comment,
    STATE(16017), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [595815] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13312), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [595837] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15769), 1,
      anon_sym_STAR,
    STATE(13522), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [595861] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13523), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13298), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [595883] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13298), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [595905] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13525), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [595927] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [595949] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13527), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [595971] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [595993] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15771), 1,
      anon_sym_SEMI,
    ACTIONS(15774), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13529), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_catch,
      anon_sym_finally,
  [596021] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [596043] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13531), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13329), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [596065] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13340), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13338), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [596089] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13533), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13312), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [596111] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13534), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13329), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [596133] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13535), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [596155] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [596177] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15609), 1,
      anon_sym_LBRACK,
    STATE(9167), 1,
      sym_type_arguments,
    STATE(13537), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [596203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13347), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13345), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [596227] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13316), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13539), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13314), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [596251] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13331), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [596273] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15779), 1,
      anon_sym_if,
    STATE(13935), 1,
      sym_guard,
    STATE(13541), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enumerator_repeat1,
    ACTIONS(15777), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [596299] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15782), 1,
      anon_sym_SEMI,
    ACTIONS(15784), 1,
      anon_sym_else,
    STATE(13542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
  [596325] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13543), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13333), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [596347] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11873), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [596369] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13340), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13545), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13338), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [596393] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [596415] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11841), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [596437] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [596459] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13347), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13345), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [596483] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [596505] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [596527] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13552), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [596549] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15138), 1,
      anon_sym_finally,
    STATE(13487), 1,
      sym_finally_clause,
    STATE(13553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [596575] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11877), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [596597] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13321), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [596619] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15786), 1,
      anon_sym_AT,
    STATE(13894), 1,
      sym_annotation,
    STATE(13556), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [596645] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [596667] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15789), 1,
      anon_sym_end,
    STATE(9384), 1,
      sym__end_marker,
    STATE(13558), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10129), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [596693] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13559), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [596715] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13560), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11904), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [596737] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13561), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [596759] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13562), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12630), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [596781] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13563), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13333), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [596803] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13564), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13302), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [596825] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13565), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13304), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [596847] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9856), 2,
      anon_sym_COLON,
      anon_sym_EQ_GT,
    STATE(13566), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [596871] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13567), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [596893] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15146), 1,
      anon_sym_LT_COLON,
    ACTIONS(15148), 1,
      anon_sym_GT_COLON,
    STATE(13842), 1,
      sym_lower_bound,
    STATE(14063), 1,
      sym_upper_bound,
    STATE(13568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15665), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [596923] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13329), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [596945] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13570), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [596967] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15791), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
  [596989] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13572), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [597011] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15500), 1,
      anon_sym_catch,
    ACTIONS(15793), 1,
      anon_sym_finally,
    STATE(13845), 1,
      sym_catch_clause,
    STATE(13915), 1,
      sym_finally_clause,
    STATE(13573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [597041] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15795), 1,
      anon_sym_SEMI,
    ACTIONS(15798), 1,
      anon_sym_else,
    STATE(13574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [597067] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
  [597089] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15615), 1,
      anon_sym_LBRACK,
    STATE(8908), 1,
      sym_type_arguments,
    STATE(13576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [597115] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15800), 1,
      anon_sym_SEMI,
    ACTIONS(15803), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13577), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
  [597143] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15645), 1,
      anon_sym_LBRACK,
    STATE(8850), 1,
      sym_type_arguments,
    STATE(13578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [597169] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [597191] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13580), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [597213] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [597235] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12727), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [597257] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13583), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13319), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [597279] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13584), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11914), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [597301] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15667), 1,
      anon_sym_catch,
    ACTIONS(15806), 1,
      anon_sym_finally,
    STATE(12410), 1,
      sym_finally_clause,
    STATE(13873), 1,
      sym_catch_clause,
    STATE(13585), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [597331] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15808), 1,
      anon_sym_SEMI,
    ACTIONS(15811), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
  [597359] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13587), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [597381] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13588), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11939), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [597403] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13589), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [597425] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15415), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [597447] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15250), 1,
      anon_sym_finally,
    STATE(12600), 1,
      sym_finally_clause,
    STATE(13591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [597473] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13323), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [597495] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15813), 1,
      anon_sym_with,
    STATE(13593), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 7,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [597519] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13594), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8410), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [597541] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12673), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [597563] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [597585] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11071), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [597607] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13376), 1,
      anon_sym_match,
    ACTIONS(15609), 1,
      anon_sym_LBRACK,
    STATE(9167), 1,
      sym_type_arguments,
    STATE(13598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [597635] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15816), 1,
      anon_sym_catch,
    ACTIONS(15818), 1,
      anon_sym_finally,
    STATE(12886), 1,
      sym_finally_clause,
    STATE(13656), 1,
      sym_catch_clause,
    STATE(13599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 5,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [597665] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [597687] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13333), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [597709] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13602), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [597731] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13603), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13288), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [597753] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15820), 1,
      anon_sym_catch,
    ACTIONS(15822), 1,
      anon_sym_finally,
    STATE(12886), 1,
      sym_finally_clause,
    STATE(13632), 1,
      sym_catch_clause,
    STATE(13604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 5,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [597783] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15611), 1,
      anon_sym_catch,
    ACTIONS(15824), 1,
      anon_sym_finally,
    STATE(13048), 1,
      sym_finally_clause,
    STATE(13907), 1,
      sym_catch_clause,
    STATE(13605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 5,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [597813] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15826), 1,
      anon_sym_SEMI,
    ACTIONS(15829), 1,
      anon_sym_else,
    STATE(13606), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [597839] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15645), 1,
      anon_sym_LBRACK,
    ACTIONS(15647), 1,
      anon_sym_match,
    STATE(8850), 1,
      sym_type_arguments,
    STATE(13607), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
  [597867] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15326), 1,
      anon_sym_finally,
    STATE(13760), 1,
      sym_finally_clause,
    STATE(13608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [597893] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13609), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [597915] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13610), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15417), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [597937] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15832), 1,
      anon_sym_SEMI,
    ACTIONS(15835), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13611), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_catch,
      anon_sym_finally,
  [597965] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13302), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [597987] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13613), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13290), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [598009] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13614), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [598031] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13615), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [598053] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13616), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598075] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13617), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [598097] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13618), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13306), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [598119] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13619), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13304), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [598141] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13306), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [598163] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15542), 1,
      anon_sym_finally,
    STATE(12087), 1,
      sym_finally_clause,
    STATE(13621), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
  [598189] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15544), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [598211] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13623), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [598233] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13624), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15547), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [598255] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15523), 1,
      anon_sym_finally,
    STATE(11562), 1,
      sym_finally_clause,
    STATE(13625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
  [598281] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [598303] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15675), 1,
      anon_sym_COMMA,
    STATE(13480), 1,
      aux_sym_derives_clause_repeat1,
    STATE(13627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15838), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [598329] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13321), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [598351] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13302), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [598373] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15018), 1,
      anon_sym_finally,
    STATE(12932), 1,
      sym_finally_clause,
    STATE(13630), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [598399] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [598421] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15822), 1,
      anon_sym_finally,
    STATE(12922), 1,
      sym_finally_clause,
    STATE(13632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 6,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_do,
  [598446] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13347), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13345), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598469] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13310), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598490] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12719), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [598511] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13636), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13312), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598532] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 8,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [598553] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15840), 1,
      anon_sym_SEMI,
    ACTIONS(15843), 1,
      anon_sym_else,
    STATE(13638), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_finally,
  [598578] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15846), 1,
      anon_sym_SEMI,
    ACTIONS(15848), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13639), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
  [598605] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15850), 1,
      anon_sym_SEMI,
    ACTIONS(15853), 1,
      anon_sym_else,
    STATE(13640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
  [598630] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13316), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13314), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598653] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15855), 1,
      anon_sym_COMMA,
    ACTIONS(15857), 1,
      anon_sym_with,
    STATE(13954), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(14100), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(13642), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13680), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [598682] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 8,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [598703] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    ACTIONS(13418), 1,
      anon_sym_LT_PERCENT,
    STATE(13753), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14257), 1,
      aux_sym__type_parameter_repeat2,
    STATE(14680), 1,
      sym_view_bound,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(15457), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(13644), 2,
      sym_comment,
      sym_block_comment,
  [598736] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13319), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598757] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    ACTIONS(13418), 1,
      anon_sym_LT_PERCENT,
    STATE(14045), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14257), 1,
      aux_sym__type_parameter_repeat2,
    STATE(14680), 1,
      sym_view_bound,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(15457), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(13646), 2,
      sym_comment,
      sym_block_comment,
  [598790] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    ACTIONS(13418), 1,
      anon_sym_LT_PERCENT,
    STATE(14045), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14266), 1,
      aux_sym__type_parameter_repeat2,
    STATE(14680), 1,
      sym_view_bound,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(15859), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(13647), 2,
      sym_comment,
      sym_block_comment,
  [598823] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15861), 1,
      anon_sym_SEMI,
    ACTIONS(15864), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13648), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_finally,
  [598850] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    ACTIONS(13418), 1,
      anon_sym_LT_PERCENT,
    STATE(13758), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14266), 1,
      aux_sym__type_parameter_repeat2,
    STATE(14680), 1,
      sym_view_bound,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(15859), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(13649), 2,
      sym_comment,
      sym_block_comment,
  [598883] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [598904] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15867), 1,
      anon_sym_LBRACK,
    STATE(9368), 1,
      sym_type_arguments,
    STATE(13651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13388), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [598929] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15691), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [598950] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13551), 1,
      anon_sym_match,
    ACTIONS(15869), 1,
      anon_sym_LBRACK,
    STATE(9611), 1,
      sym_type_arguments,
    STATE(13653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [598977] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(13654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [599002] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(13655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [599027] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15818), 1,
      anon_sym_finally,
    STATE(12922), 1,
      sym_finally_clause,
    STATE(13656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 6,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
  [599052] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15873), 1,
      anon_sym_LBRACK,
    ACTIONS(15875), 1,
      anon_sym_match,
    STATE(9356), 1,
      sym_type_arguments,
    STATE(13657), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
  [599079] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15877), 1,
      anon_sym_COMMA,
    ACTIONS(15879), 1,
      anon_sym_with,
    STATE(13987), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(14136), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(13658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13680), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [599108] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13659), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13321), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [599129] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15881), 1,
      anon_sym_SEMI,
    ACTIONS(15884), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13660), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_catch,
      anon_sym_finally,
  [599156] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13661), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13323), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [599177] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13662), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14075), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [599198] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15857), 1,
      anon_sym_with,
    STATE(13954), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(14058), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(13663), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13680), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [599225] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(13664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 5,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [599252] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [599273] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [599294] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12841), 1,
      sym__automatic_semicolon,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(13748), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12896), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [599323] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12841), 1,
      sym__automatic_semicolon,
    STATE(12274), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(13668), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14373), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [599352] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12841), 1,
      sym__automatic_semicolon,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(13749), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13669), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14378), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [599381] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12841), 1,
      sym__automatic_semicolon,
    STATE(12274), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(13670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14383), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [599410] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(13671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [599435] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(13672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 5,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [599462] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15715), 1,
      anon_sym_finally,
    STATE(13456), 1,
      sym_finally_clause,
    STATE(13673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 6,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
  [599487] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15888), 1,
      anon_sym_COMMA,
    ACTIONS(15890), 1,
      anon_sym_with,
    STATE(14155), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(14157), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(13674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13680), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_derives,
      anon_sym_LPAREN,
  [599516] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    STATE(13675), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [599539] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15894), 1,
      anon_sym_COMMA,
    STATE(13788), 1,
      aux_sym_derives_clause_repeat1,
    STATE(13676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15838), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [599564] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15896), 1,
      anon_sym_SEMI,
    ACTIONS(15899), 1,
      anon_sym_else,
    STATE(13677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_finally,
  [599589] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13678), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [599610] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13288), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [599631] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13680), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13290), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [599652] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(12868), 1,
      anon_sym_COLON,
    STATE(15498), 1,
      sym_template_body,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13681), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15901), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [599681] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15903), 1,
      anon_sym_DOT,
    STATE(13682), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_package_identifier_repeat1,
    ACTIONS(15791), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [599704] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15566), 1,
      anon_sym_finally,
    STATE(13965), 1,
      sym_finally_clause,
    STATE(13683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [599729] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15906), 1,
      anon_sym_COLON,
    STATE(13684), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15908), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [599752] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [599773] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13686), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12727), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [599794] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15910), 1,
      anon_sym_as,
    STATE(13687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15791), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
  [599817] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13298), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [599838] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13689), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [599859] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13690), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13306), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [599880] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13691), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [599901] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15873), 1,
      anon_sym_LBRACK,
    ACTIONS(15875), 1,
      anon_sym_match,
    ACTIONS(15912), 1,
      anon_sym_if,
    STATE(9356), 1,
      sym_type_arguments,
    STATE(15236), 1,
      sym_guard,
    STATE(13692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15286), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [599932] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15558), 1,
      anon_sym_finally,
    STATE(13691), 1,
      sym_finally_clause,
    STATE(13693), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [599957] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13694), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13310), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [599978] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13695), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13302), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [599999] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13304), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [600020] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13312), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [600041] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15914), 1,
      anon_sym_SEMI,
    ACTIONS(15917), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_finally,
  [600068] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13316), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13699), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13314), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_finally,
  [600091] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15919), 1,
      anon_sym_SEMI,
    ACTIONS(15922), 1,
      anon_sym_else,
    STATE(13700), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [600116] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13319), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [600137] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13321), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [600158] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    ACTIONS(13418), 1,
      anon_sym_LT_PERCENT,
    STATE(13647), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14174), 1,
      aux_sym__type_parameter_repeat2,
    STATE(14680), 1,
      sym_view_bound,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(15429), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(13703), 2,
      sym_comment,
      sym_block_comment,
  [600191] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13323), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [600212] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    ACTIONS(13418), 1,
      anon_sym_LT_PERCENT,
    STATE(14045), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14174), 1,
      aux_sym__type_parameter_repeat2,
    STATE(14680), 1,
      sym_view_bound,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(15429), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(13705), 2,
      sym_comment,
      sym_block_comment,
  [600245] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12610), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [600266] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15564), 1,
      anon_sym_finally,
    STATE(12447), 1,
      sym_finally_clause,
    STATE(13707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [600291] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13708), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13321), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [600312] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13323), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [600333] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15925), 1,
      anon_sym_SEMI,
    ACTIONS(15928), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_catch,
      anon_sym_finally,
  [600360] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15486), 1,
      anon_sym_finally,
    STATE(12932), 1,
      sym_finally_clause,
    STATE(13711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [600385] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [600406] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8008), 1,
      anon_sym_DOT,
    STATE(13713), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [600429] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13714), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13329), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [600450] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13288), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [600471] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13290), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [600492] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13331), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [600513] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13333), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [600534] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13719), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15931), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_SEMI,
  [600555] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13340), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13338), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_finally,
  [600578] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13347), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13721), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13345), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_finally,
  [600601] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [600622] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15869), 1,
      anon_sym_LBRACK,
    STATE(9611), 1,
      sym_type_arguments,
    STATE(13723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [600647] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13329), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [600668] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15935), 1,
      anon_sym_DOT,
    STATE(13785), 1,
      aux_sym_package_identifier_repeat1,
    STATE(13725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15933), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [600693] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12841), 1,
      sym__automatic_semicolon,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(13670), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13726), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12891), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [600722] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12841), 1,
      sym__automatic_semicolon,
    STATE(12274), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(13727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14166), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [600751] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(13728), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [600776] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15873), 1,
      anon_sym_LBRACK,
    ACTIONS(15875), 1,
      anon_sym_match,
    ACTIONS(15912), 1,
      anon_sym_if,
    STATE(9356), 1,
      sym_type_arguments,
    STATE(15398), 1,
      sym_guard,
    STATE(13729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15103), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [600807] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15594), 1,
      anon_sym_finally,
    STATE(13691), 1,
      sym_finally_clause,
    STATE(13730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [600832] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13298), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [600853] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9856), 1,
      anon_sym_COLON,
    STATE(13732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [600876] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12841), 1,
      sym__automatic_semicolon,
    STATE(12274), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(13733), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14651), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [600905] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15461), 1,
      anon_sym_finally,
    STATE(12600), 1,
      sym_finally_clause,
    STATE(13734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [600930] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13602), 1,
      anon_sym_match,
    ACTIONS(15867), 1,
      anon_sym_LBRACK,
    STATE(9368), 1,
      sym_type_arguments,
    STATE(13735), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [600957] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 8,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [600978] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14401), 1,
      anon_sym_LPAREN,
    ACTIONS(15939), 1,
      anon_sym_extends,
    ACTIONS(15941), 1,
      sym__automatic_semicolon,
    STATE(14005), 1,
      aux_sym__full_enum_def_repeat1,
    STATE(14199), 1,
      sym_class_parameters,
    STATE(15777), 1,
      sym_extends_clause,
    ACTIONS(15937), 2,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(13737), 2,
      sym_comment,
      sym_block_comment,
  [601011] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15105), 1,
      anon_sym_LBRACK,
    ACTIONS(15109), 1,
      anon_sym_match,
    STATE(7547), 1,
      sym_type_arguments,
    STATE(14218), 1,
      aux_sym__block_repeat1,
    ACTIONS(15944), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(15946), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(13738), 2,
      sym_comment,
      sym_block_comment,
  [601042] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15867), 1,
      anon_sym_LBRACK,
    STATE(9368), 1,
      sym_type_arguments,
    STATE(13739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [601067] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15867), 1,
      anon_sym_LBRACK,
    STATE(9368), 1,
      sym_type_arguments,
    STATE(13740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [601092] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15948), 1,
      anon_sym_SEMI,
    ACTIONS(15951), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
  [601119] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14535), 1,
      anon_sym_LPAREN,
    ACTIONS(15953), 1,
      anon_sym_extends,
    ACTIONS(15955), 1,
      sym__automatic_semicolon,
    STATE(13906), 1,
      aux_sym__full_enum_def_repeat1,
    STATE(14220), 1,
      sym_class_parameters,
    STATE(15425), 1,
      sym_extends_clause,
    ACTIONS(15937), 2,
      sym__outdent,
      anon_sym_SEMI,
    STATE(13742), 2,
      sym_comment,
      sym_block_comment,
  [601152] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12841), 1,
      sym__automatic_semicolon,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(13733), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14515), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [601181] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    ACTIONS(13418), 1,
      anon_sym_LT_PERCENT,
    STATE(14045), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14191), 1,
      aux_sym__type_parameter_repeat2,
    STATE(14680), 1,
      sym_view_bound,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(15958), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(13744), 2,
      sym_comment,
      sym_block_comment,
  [601214] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15873), 1,
      anon_sym_LBRACK,
    STATE(9356), 1,
      sym_type_arguments,
    STATE(13745), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [601239] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13602), 1,
      anon_sym_match,
    ACTIONS(15867), 1,
      anon_sym_LBRACK,
    STATE(9368), 1,
      sym_type_arguments,
    STATE(13746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [601266] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15596), 1,
      anon_sym_finally,
    STATE(11785), 1,
      sym_finally_clause,
    STATE(13747), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [601291] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12841), 1,
      sym__automatic_semicolon,
    STATE(12274), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(13748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14523), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [601320] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      anon_sym_LPAREN,
    ACTIONS(12841), 1,
      sym__automatic_semicolon,
    STATE(12274), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13066), 1,
      sym_class_parameters,
    STATE(13749), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14528), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [601349] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13750), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15960), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [601370] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [601391] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15867), 1,
      anon_sym_LBRACK,
    STATE(9368), 1,
      sym_type_arguments,
    STATE(13752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [601416] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    ACTIONS(13418), 1,
      anon_sym_LT_PERCENT,
    STATE(14045), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14415), 1,
      aux_sym__type_parameter_repeat2,
    STATE(14680), 1,
      sym_view_bound,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(15962), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(13753), 2,
      sym_comment,
      sym_block_comment,
  [601449] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15873), 1,
      anon_sym_LBRACK,
    ACTIONS(15875), 1,
      anon_sym_match,
    STATE(9356), 1,
      sym_type_arguments,
    STATE(14259), 1,
      aux_sym__block_repeat1,
    ACTIONS(15944), 2,
      sym__outdent,
      anon_sym_case,
    ACTIONS(15964), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(13754), 2,
      sym_comment,
      sym_block_comment,
  [601480] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13755), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13298), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [601501] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    ACTIONS(13418), 1,
      anon_sym_LT_PERCENT,
    STATE(13744), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14415), 1,
      aux_sym__type_parameter_repeat2,
    STATE(14680), 1,
      sym_view_bound,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(15962), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(13756), 2,
      sym_comment,
      sym_block_comment,
  [601534] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13757), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [601555] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    ACTIONS(13418), 1,
      anon_sym_LT_PERCENT,
    STATE(14045), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14411), 1,
      aux_sym__type_parameter_repeat2,
    STATE(14680), 1,
      sym_view_bound,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(15966), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(13758), 2,
      sym_comment,
      sym_block_comment,
  [601588] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13306), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [601609] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [601630] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14535), 1,
      anon_sym_LPAREN,
    ACTIONS(15953), 1,
      anon_sym_extends,
    ACTIONS(15970), 1,
      sym__automatic_semicolon,
    STATE(13906), 1,
      aux_sym__full_enum_def_repeat1,
    STATE(14220), 1,
      sym_class_parameters,
    STATE(15450), 1,
      sym_extends_clause,
    ACTIONS(15968), 2,
      sym__outdent,
      anon_sym_SEMI,
    STATE(13761), 2,
      sym_comment,
      sym_block_comment,
  [601663] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13310), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [601684] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15873), 1,
      anon_sym_LBRACK,
    ACTIONS(15875), 1,
      anon_sym_match,
    STATE(9356), 1,
      sym_type_arguments,
    STATE(13763), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
  [601711] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [601732] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15743), 1,
      anon_sym_finally,
    STATE(12087), 1,
      sym_finally_clause,
    STATE(13765), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
  [601757] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13766), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [601778] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15973), 1,
      anon_sym_SEMI,
    ACTIONS(15976), 1,
      anon_sym_else,
    STATE(13767), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_finally,
  [601803] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15978), 1,
      anon_sym_SEMI,
    ACTIONS(15981), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13768), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_finally,
  [601830] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13312), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [601851] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15983), 1,
      anon_sym_SEMI,
    ACTIONS(15986), 1,
      anon_sym_else,
    STATE(13770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
  [601876] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15988), 1,
      anon_sym_SEMI,
    ACTIONS(15991), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13771), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_if,
      anon_sym_finally,
  [601903] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15993), 1,
      anon_sym_SEMI,
    ACTIONS(15996), 1,
      anon_sym_else,
    STATE(13772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_finally,
  [601928] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15999), 1,
      anon_sym_SEMI,
    ACTIONS(16002), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13773), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_finally,
  [601955] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15873), 1,
      anon_sym_LBRACK,
    STATE(9356), 1,
      sym_type_arguments,
    STATE(13774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [601980] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16005), 1,
      anon_sym_SEMI,
    ACTIONS(16008), 1,
      anon_sym_else,
    STATE(13775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
  [602005] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16011), 1,
      anon_sym_SEMI,
    ACTIONS(16014), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13776), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_if,
      anon_sym_finally,
  [602032] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13316), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13777), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13314), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
  [602055] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15867), 1,
      anon_sym_LBRACK,
    STATE(9368), 1,
      sym_type_arguments,
    STATE(13778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [602080] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16017), 1,
      anon_sym_STAR,
    STATE(13779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [602103] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15879), 1,
      anon_sym_with,
    STATE(13987), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(14115), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(13780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13680), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [602130] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13319), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [602151] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12608), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [602172] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15502), 1,
      anon_sym_finally,
    STATE(13965), 1,
      sym_finally_clause,
    STATE(13783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [602197] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13321), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [602218] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16021), 1,
      anon_sym_DOT,
    STATE(13682), 1,
      aux_sym_package_identifier_repeat1,
    STATE(13785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16019), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [602243] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13323), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [602264] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13331), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [602285] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16023), 1,
      anon_sym_COMMA,
    STATE(13788), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_derives_clause_repeat1,
    ACTIONS(15736), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [602308] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13333), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [602329] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12628), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [602350] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15869), 1,
      anon_sym_LBRACK,
    STATE(9611), 1,
      sym_type_arguments,
    STATE(13791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [602375] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15869), 1,
      anon_sym_LBRACK,
    STATE(9611), 1,
      sym_type_arguments,
    STATE(13792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [602400] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13329), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [602421] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12630), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [602442] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13795), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13306), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [602463] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13302), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [602484] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13304), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [602505] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13798), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12660), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [602526] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16026), 1,
      anon_sym_SEMI,
    ACTIONS(16029), 1,
      anon_sym_else,
    STATE(13799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_do,
      anon_sym_yield,
  [602551] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16032), 1,
      anon_sym_SEMI,
    ACTIONS(16035), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 4,
      sym__automatic_semicolon,
      anon_sym_if,
      anon_sym_do,
      anon_sym_yield,
  [602578] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [602599] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [602620] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16038), 1,
      anon_sym_SEMI,
    ACTIONS(16041), 1,
      anon_sym_else,
    STATE(13803), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [602645] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13551), 1,
      anon_sym_match,
    ACTIONS(15869), 1,
      anon_sym_LBRACK,
    STATE(9611), 1,
      sym_type_arguments,
    STATE(13804), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [602672] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [602693] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13806), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [602714] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16043), 1,
      anon_sym_DOT,
    STATE(13807), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [602737] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16045), 1,
      anon_sym_SEMI,
    ACTIONS(16048), 1,
      anon_sym_else,
    STATE(13808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_do,
      anon_sym_yield,
  [602762] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15869), 1,
      anon_sym_LBRACK,
    STATE(9611), 1,
      sym_type_arguments,
    STATE(13809), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [602787] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16050), 1,
      anon_sym_SEMI,
    ACTIONS(16053), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13810), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 4,
      sym__automatic_semicolon,
      anon_sym_if,
      anon_sym_do,
      anon_sym_yield,
  [602814] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16055), 1,
      anon_sym_SEMI,
    ACTIONS(16057), 1,
      anon_sym_else,
    STATE(13811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 6,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
  [602839] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13340), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13338), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [602862] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [602883] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15873), 1,
      anon_sym_LBRACK,
    STATE(9356), 1,
      sym_type_arguments,
    STATE(13814), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [602908] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16059), 1,
      anon_sym_SEMI,
    ACTIONS(16062), 1,
      anon_sym_else,
    STATE(13815), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 6,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
  [602933] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13816), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13288), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [602954] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13817), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13290), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [602975] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16065), 1,
      anon_sym_DOT,
    STATE(13818), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [602998] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15869), 1,
      anon_sym_LBRACK,
    STATE(9611), 1,
      sym_type_arguments,
    STATE(13819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13388), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [603023] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13331), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [603044] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15894), 1,
      anon_sym_COMMA,
    STATE(13676), 1,
      aux_sym_derives_clause_repeat1,
    STATE(13821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15673), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [603069] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16067), 1,
      anon_sym_SEMI,
    ACTIONS(16070), 1,
      anon_sym_else,
    STATE(13822), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
  [603094] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13823), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13333), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [603115] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16073), 1,
      anon_sym_SEMI,
    ACTIONS(16076), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
  [603142] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13340), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13338), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
  [603165] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13826), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [603186] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14401), 1,
      anon_sym_LPAREN,
    ACTIONS(15939), 1,
      anon_sym_extends,
    ACTIONS(16079), 1,
      sym__automatic_semicolon,
    STATE(14005), 1,
      aux_sym__full_enum_def_repeat1,
    STATE(14199), 1,
      sym_class_parameters,
    STATE(15181), 1,
      sym_extends_clause,
    ACTIONS(15968), 2,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(13827), 2,
      sym_comment,
      sym_block_comment,
  [603219] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13347), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13828), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13345), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
  [603242] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16082), 1,
      anon_sym_SEMI,
    ACTIONS(16085), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
  [603269] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12669), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [603290] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15463), 1,
      anon_sym_LT_COLON,
    ACTIONS(15465), 1,
      anon_sym_GT_COLON,
    STATE(14063), 1,
      sym_upper_bound,
    STATE(14064), 1,
      sym_lower_bound,
    STATE(13831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15665), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_EQ,
      anon_sym_SEMI,
  [603319] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12673), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [603340] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15873), 1,
      anon_sym_LBRACK,
    STATE(9356), 1,
      sym_type_arguments,
    STATE(13833), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [603365] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16088), 1,
      anon_sym_catch,
    ACTIONS(16090), 1,
      anon_sym_finally,
    STATE(13579), 1,
      sym_finally_clause,
    STATE(14123), 1,
      sym_catch_clause,
    STATE(13834), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 3,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
  [603393] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16092), 1,
      anon_sym_DOT,
    STATE(13872), 1,
      aux_sym_package_identifier_repeat1,
    STATE(13835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15933), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [603417] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [603437] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13837), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13306), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [603457] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [603477] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16094), 1,
      anon_sym_with,
    STATE(13839), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat2,
    ACTIONS(15211), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [603499] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [603519] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16097), 1,
      anon_sym_SEMI,
    ACTIONS(16100), 1,
      anon_sym_else,
    STATE(13841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
  [603543] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15146), 1,
      anon_sym_LT_COLON,
    STATE(14013), 1,
      sym_upper_bound,
    STATE(13842), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16103), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [603567] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8362), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [603587] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13310), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [603607] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15793), 1,
      anon_sym_finally,
    STATE(13965), 1,
      sym_finally_clause,
    STATE(13845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [603631] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13846), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8270), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [603651] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13847), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13312), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [603671] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8366), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [603691] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13849), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8368), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [603711] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16105), 1,
      anon_sym_SEMI,
    ACTIONS(16107), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_then,
  [603737] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13316), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13314), 5,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [603759] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13319), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [603779] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16109), 1,
      anon_sym_COLON,
    STATE(13853), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16111), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [603801] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13854), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8394), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [603821] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16113), 1,
      anon_sym_COLON,
    STATE(13855), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16115), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [603843] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16117), 1,
      anon_sym_LBRACK,
    STATE(9943), 1,
      sym_type_arguments,
    STATE(13856), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [603867] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13857), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8220), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [603887] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16119), 1,
      anon_sym_SEMI,
    ACTIONS(16122), 1,
      anon_sym_else,
    STATE(13858), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
  [603911] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16117), 1,
      anon_sym_LBRACK,
    STATE(9943), 1,
      sym_type_arguments,
    STATE(13859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [603935] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [603955] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [603975] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15745), 1,
      anon_sym_finally,
    STATE(13380), 1,
      sym_finally_clause,
    STATE(13862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 5,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [603999] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16125), 1,
      anon_sym_catch,
    ACTIONS(16127), 1,
      anon_sym_finally,
    STATE(13813), 1,
      sym_finally_clause,
    STATE(14270), 1,
      sym_catch_clause,
    STATE(13863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 3,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_do,
  [604027] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16117), 1,
      anon_sym_LBRACK,
    STATE(9943), 1,
      sym_type_arguments,
    STATE(13864), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [604051] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16131), 1,
      anon_sym_COMMA,
    STATE(13949), 1,
      aux_sym_import_declaration_repeat1,
    STATE(13865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16129), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [604075] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16133), 1,
      anon_sym_catch,
    ACTIONS(16135), 1,
      anon_sym_finally,
    STATE(13579), 1,
      sym_finally_clause,
    STATE(14029), 1,
      sym_catch_clause,
    STATE(13866), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 3,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_do,
  [604103] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13329), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [604123] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16137), 1,
      anon_sym_LBRACK,
    STATE(9978), 1,
      sym_type_arguments,
    STATE(13868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [604147] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16137), 1,
      anon_sym_LBRACK,
    STATE(9978), 1,
      sym_type_arguments,
    STATE(13869), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [604171] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16139), 1,
      anon_sym_SEMI,
    ACTIONS(16142), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_then,
  [604197] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13871), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [604217] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16145), 1,
      anon_sym_DOT,
    STATE(14000), 1,
      aux_sym_package_identifier_repeat1,
    STATE(13872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16019), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [604241] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15806), 1,
      anon_sym_finally,
    STATE(12447), 1,
      sym_finally_clause,
    STATE(13873), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [604265] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16147), 1,
      anon_sym_SEMI,
    ACTIONS(16150), 1,
      anon_sym_else,
    STATE(13874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_finally,
  [604289] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14760), 1,
      anon_sym_match,
    ACTIONS(16137), 1,
      anon_sym_LBRACK,
    STATE(9978), 1,
      sym_type_arguments,
    STATE(13875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_finally,
  [604315] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16137), 1,
      anon_sym_LBRACK,
    STATE(9978), 1,
      sym_type_arguments,
    STATE(13876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [604339] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16152), 1,
      anon_sym_COLON,
    ACTIONS(16154), 1,
      anon_sym_LBRACE,
    ACTIONS(16156), 1,
      anon_sym_extends,
    ACTIONS(16158), 1,
      anon_sym_derives,
    STATE(14217), 1,
      sym_extends_clause,
    STATE(14664), 1,
      sym_enum_body,
    STATE(15311), 1,
      sym_derives_clause,
    STATE(13877), 2,
      sym_comment,
      sym_block_comment,
  [604371] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16156), 1,
      anon_sym_extends,
    ACTIONS(16158), 1,
      anon_sym_derives,
    ACTIONS(16160), 1,
      anon_sym_COLON,
    ACTIONS(16162), 1,
      anon_sym_LBRACE,
    STATE(14268), 1,
      sym_enum_body,
    STATE(14290), 1,
      sym_extends_clause,
    STATE(15326), 1,
      sym_derives_clause,
    STATE(13878), 2,
      sym_comment,
      sym_block_comment,
  [604403] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16164), 1,
      anon_sym_COLON,
    STATE(13879), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16111), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [604425] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8364), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [604445] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16166), 1,
      anon_sym_with,
    STATE(13881), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(9418), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [604467] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16156), 1,
      anon_sym_extends,
    ACTIONS(16158), 1,
      anon_sym_derives,
    ACTIONS(16160), 1,
      anon_sym_COLON,
    ACTIONS(16162), 1,
      anon_sym_LBRACE,
    STATE(14277), 1,
      sym_enum_body,
    STATE(14282), 1,
      sym_extends_clause,
    STATE(15469), 1,
      sym_derives_clause,
    STATE(13882), 2,
      sym_comment,
      sym_block_comment,
  [604499] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13883), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [604519] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16169), 1,
      anon_sym_COLON,
    STATE(13884), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16171), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [604541] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16173), 1,
      anon_sym_SEMI,
    ACTIONS(16176), 1,
      anon_sym_else,
    STATE(13885), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_finally,
  [604565] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16152), 1,
      anon_sym_COLON,
    ACTIONS(16154), 1,
      anon_sym_LBRACE,
    ACTIONS(16156), 1,
      anon_sym_extends,
    ACTIONS(16158), 1,
      anon_sym_derives,
    STATE(14240), 1,
      sym_extends_clause,
    STATE(14590), 1,
      sym_enum_body,
    STATE(15369), 1,
      sym_derives_clause,
    STATE(13886), 2,
      sym_comment,
      sym_block_comment,
  [604597] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16179), 1,
      anon_sym_SEMI,
    ACTIONS(16182), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13887), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_finally,
  [604623] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7410), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [604643] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14054), 1,
      sym_arguments,
    STATE(13889), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [604665] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8040), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [604685] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16184), 1,
      anon_sym_COLON,
    STATE(13891), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16115), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [604707] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16186), 1,
      anon_sym_SEMI,
    ACTIONS(16188), 1,
      anon_sym_else,
    STATE(13892), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
  [604731] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [604751] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13894), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [604771] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16137), 1,
      anon_sym_LBRACK,
    STATE(9978), 1,
      sym_type_arguments,
    STATE(13895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [604795] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16131), 1,
      anon_sym_COMMA,
    STATE(13951), 1,
      aux_sym_import_declaration_repeat1,
    STATE(13896), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16190), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [604819] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13897), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13331), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [604839] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13898), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13333), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [604859] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16125), 1,
      anon_sym_catch,
    ACTIONS(16192), 1,
      anon_sym_finally,
    STATE(13903), 1,
      sym_finally_clause,
    STATE(14410), 1,
      sym_catch_clause,
    STATE(13899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 3,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_do,
  [604887] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15730), 1,
      anon_sym_finally,
    STATE(13806), 1,
      sym_finally_clause,
    STATE(13900), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
  [604911] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13340), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13338), 5,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [604933] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15607), 1,
      anon_sym_finally,
    STATE(12932), 1,
      sym_finally_clause,
    STATE(13902), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [604957] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [604977] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9363), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9856), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_if,
      anon_sym_SEMI,
  [604999] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13905), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [605019] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16196), 1,
      anon_sym_LPAREN,
    ACTIONS(16199), 1,
      sym__automatic_semicolon,
    STATE(14220), 1,
      sym_class_parameters,
    ACTIONS(16194), 3,
      sym__outdent,
      anon_sym_extends,
      anon_sym_SEMI,
    STATE(13906), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__full_enum_def_repeat1,
  [605045] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15824), 1,
      anon_sym_finally,
    STATE(13086), 1,
      sym_finally_clause,
    STATE(13907), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 5,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [605069] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16202), 1,
      anon_sym_SEMI,
    ACTIONS(16204), 1,
      anon_sym_else,
    STATE(13908), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 5,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [605093] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16206), 1,
      anon_sym_SEMI,
    ACTIONS(16208), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13909), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 3,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [605119] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16210), 1,
      anon_sym_SEMI,
    ACTIONS(16213), 1,
      anon_sym_else,
    STATE(13910), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
  [605143] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16215), 1,
      anon_sym_SEMI,
    ACTIONS(16218), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13911), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
  [605169] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16220), 1,
      anon_sym_SEMI,
    ACTIONS(16223), 1,
      anon_sym_else,
    STATE(13912), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
  [605193] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16226), 1,
      anon_sym_SEMI,
    ACTIONS(16229), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
  [605219] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14156), 1,
      sym_arguments,
    STATE(13914), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [605241] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [605261] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16232), 1,
      anon_sym_SEMI,
    ACTIONS(16235), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_finally,
  [605287] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8256), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [605307] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15146), 1,
      anon_sym_LT_COLON,
    STATE(14066), 1,
      sym_upper_bound,
    STATE(13918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16238), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [605331] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8272), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [605351] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16240), 1,
      anon_sym_SEMI,
    ACTIONS(16243), 1,
      anon_sym_else,
    STATE(13920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 5,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [605375] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16246), 1,
      anon_sym_SEMI,
    ACTIONS(16249), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13921), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 3,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [605401] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16252), 1,
      anon_sym_SEMI,
    ACTIONS(16255), 1,
      anon_sym_else,
    STATE(13922), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
  [605425] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16258), 1,
      anon_sym_SEMI,
    ACTIONS(16261), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_if,
  [605451] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13288), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [605471] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13288), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [605491] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15613), 1,
      anon_sym_finally,
    STATE(13380), 1,
      sym_finally_clause,
    STATE(13926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 5,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [605515] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13290), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [605535] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16264), 1,
      anon_sym_COLON,
    STATE(13928), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16171), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [605557] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15551), 1,
      anon_sym_LPAREN,
    STATE(13948), 1,
      aux_sym_annotation_repeat1,
    STATE(14251), 1,
      sym_arguments,
    STATE(13929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8428), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_with,
  [605583] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13290), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [605603] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16266), 1,
      anon_sym_SEMI,
    ACTIONS(16269), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
  [605629] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [605649] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14039), 1,
      sym_arguments,
    STATE(13933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [605671] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15105), 1,
      anon_sym_LBRACK,
    ACTIONS(15109), 1,
      anon_sym_match,
    ACTIONS(16272), 1,
      anon_sym_RBRACE,
    STATE(7547), 1,
      sym_type_arguments,
    STATE(14426), 1,
      aux_sym__enum_block_repeat1,
    ACTIONS(16274), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(13934), 2,
      sym_comment,
      sym_block_comment,
  [605701] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13935), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16276), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [605721] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14742), 1,
      anon_sym_match,
    ACTIONS(16117), 1,
      anon_sym_LBRACK,
    STATE(9943), 1,
      sym_type_arguments,
    STATE(13936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_else,
  [605747] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16278), 1,
      anon_sym_LBRACE,
    ACTIONS(16282), 1,
      anon_sym_EQ,
    STATE(14236), 1,
      sym_block,
    STATE(13937), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16280), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [605773] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16284), 1,
      anon_sym_AT,
    STATE(14184), 1,
      sym_annotation,
    STATE(13938), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8933), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_LPAREN,
  [605797] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15669), 1,
      anon_sym_finally,
    STATE(12932), 1,
      sym_finally_clause,
    STATE(13939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [605821] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16289), 1,
      anon_sym_DOT,
    STATE(13992), 1,
      aux_sym_package_identifier_repeat1,
    STATE(13940), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16287), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [605845] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13941), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15931), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_SEMI,
  [605865] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16291), 1,
      anon_sym_catch,
    ACTIONS(16293), 1,
      anon_sym_finally,
    STATE(13813), 1,
      sym_finally_clause,
    STATE(14229), 1,
      sym_catch_clause,
    STATE(13942), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 3,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
  [605893] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [605913] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14742), 1,
      anon_sym_match,
    ACTIONS(16117), 1,
      anon_sym_LBRACK,
    STATE(9943), 1,
      sym_type_arguments,
    STATE(13944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_else,
  [605939] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12952), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [605959] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16295), 1,
      anon_sym_SEMI,
    ACTIONS(16298), 1,
      anon_sym_else,
    STATE(13946), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
  [605983] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15042), 1,
      anon_sym_LT_COLON,
    STATE(14187), 1,
      sym_upper_bound,
    STATE(13947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16103), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [606007] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16300), 1,
      anon_sym_LPAREN,
    STATE(14251), 1,
      sym_arguments,
    STATE(13948), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8432), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_with,
  [606031] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16131), 1,
      anon_sym_COMMA,
    STATE(14002), 1,
      aux_sym_import_declaration_repeat1,
    STATE(13949), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16303), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [606055] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15960), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [606075] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16131), 1,
      anon_sym_COMMA,
    STATE(14002), 1,
      aux_sym_import_declaration_repeat1,
    STATE(13951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16305), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [606099] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15873), 1,
      anon_sym_LBRACK,
    ACTIONS(15875), 1,
      anon_sym_match,
    ACTIONS(16272), 1,
      sym__outdent,
    STATE(9356), 1,
      sym_type_arguments,
    STATE(14516), 1,
      aux_sym__enum_block_repeat1,
    ACTIONS(16307), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(13952), 2,
      sym_comment,
      sym_block_comment,
  [606129] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16309), 1,
      anon_sym_SEMI,
    ACTIONS(16312), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
  [606155] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15857), 1,
      anon_sym_with,
    STATE(13839), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(13954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15079), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [606179] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16314), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_EQ,
      anon_sym_SEMI,
  [606199] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15480), 1,
      anon_sym_AT,
    STATE(13938), 1,
      aux_sym_enum_definition_repeat1,
    STATE(14184), 1,
      sym_annotation,
    STATE(13956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8959), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_LPAREN,
  [606225] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16291), 1,
      anon_sym_catch,
    ACTIONS(16316), 1,
      anon_sym_finally,
    STATE(13903), 1,
      sym_finally_clause,
    STATE(14214), 1,
      sym_catch_clause,
    STATE(13957), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14065), 3,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
  [606253] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13958), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13298), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [606273] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16318), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [606293] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13960), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [606313] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16320), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [606333] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13962), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13306), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [606353] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16322), 1,
      anon_sym_SEMI,
    ACTIONS(16324), 1,
      anon_sym_else,
    STATE(13963), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 5,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [606377] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16326), 1,
      anon_sym_SEMI,
    ACTIONS(16328), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13964), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 3,
      anon_sym_while,
      anon_sym_catch,
      anon_sym_finally,
  [606403] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13965), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [606423] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16330), 1,
      anon_sym_SEMI,
    ACTIONS(16333), 1,
      anon_sym_else,
    STATE(13966), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
  [606447] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16335), 1,
      anon_sym_SEMI,
    ACTIONS(16338), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13967), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_if,
  [606473] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16289), 1,
      anon_sym_DOT,
    STATE(13940), 1,
      aux_sym_package_identifier_repeat1,
    STATE(13968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16340), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [606497] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15734), 1,
      anon_sym_finally,
    STATE(13086), 1,
      sym_finally_clause,
    STATE(13969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 5,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [606521] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15105), 1,
      anon_sym_LBRACK,
    ACTIONS(15109), 1,
      anon_sym_match,
    ACTIONS(15944), 1,
      anon_sym_RBRACE,
    STATE(7547), 1,
      sym_type_arguments,
    STATE(14483), 1,
      aux_sym__block_repeat1,
    ACTIONS(16342), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(13970), 2,
      sym_comment,
      sym_block_comment,
  [606551] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15873), 1,
      anon_sym_LBRACK,
    ACTIONS(15875), 1,
      anon_sym_match,
    STATE(9356), 1,
      sym_type_arguments,
    STATE(13971), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16344), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [606577] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16346), 1,
      anon_sym_SEMI,
    ACTIONS(16349), 1,
      anon_sym_else,
    STATE(13972), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 5,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [606601] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16352), 1,
      anon_sym_SEMI,
    ACTIONS(16355), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15514), 3,
      anon_sym_while,
      anon_sym_catch,
      anon_sym_finally,
  [606627] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [606647] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13310), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [606667] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16137), 1,
      anon_sym_LBRACK,
    STATE(9978), 1,
      sym_type_arguments,
    STATE(13976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13388), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [606691] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13312), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [606711] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15708), 1,
      anon_sym_finally,
    STATE(13838), 1,
      sym_finally_clause,
    STATE(13978), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
  [606735] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16358), 1,
      anon_sym_as,
    STATE(13979), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15791), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
  [606757] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13316), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13980), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13314), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
  [606779] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13319), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [606799] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15042), 1,
      anon_sym_LT_COLON,
    STATE(14373), 1,
      sym_upper_bound,
    STATE(13982), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16238), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [606823] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13321), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [606843] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13323), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [606863] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15105), 1,
      anon_sym_LBRACK,
    ACTIONS(15109), 1,
      anon_sym_match,
    STATE(7547), 1,
      sym_type_arguments,
    STATE(13985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16344), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [606889] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [606909] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15879), 1,
      anon_sym_with,
    STATE(13996), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(13987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15079), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [606933] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13988), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [606953] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13989), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16360), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [606973] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13990), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9363), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [606993] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13329), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [607013] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16362), 1,
      anon_sym_DOT,
    STATE(13992), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_package_identifier_repeat1,
    ACTIONS(15791), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [607035] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16365), 1,
      anon_sym_LBRACE,
    ACTIONS(16367), 1,
      anon_sym_EQ,
    STATE(14597), 1,
      sym_block,
    STATE(13993), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16280), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [607061] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13994), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [607081] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16117), 1,
      anon_sym_LBRACK,
    STATE(9943), 1,
      sym_type_arguments,
    STATE(13995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [607105] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16369), 1,
      anon_sym_with,
    STATE(13996), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat2,
    ACTIONS(15211), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [607127] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13298), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [607147] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13331), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [607167] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13333), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [607187] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16372), 1,
      anon_sym_DOT,
    STATE(14000), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_package_identifier_repeat1,
    ACTIONS(15791), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [607209] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13340), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13338), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
  [607231] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16377), 1,
      anon_sym_COMMA,
    STATE(14002), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_import_declaration_repeat1,
    ACTIONS(16375), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [607253] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13347), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13345), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
  [607275] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15873), 1,
      anon_sym_LBRACK,
    ACTIONS(15875), 1,
      anon_sym_match,
    ACTIONS(15944), 1,
      sym__outdent,
    STATE(9356), 1,
      sym_type_arguments,
    STATE(14683), 1,
      aux_sym__block_repeat1,
    ACTIONS(16380), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14004), 2,
      sym_comment,
      sym_block_comment,
  [607305] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16382), 1,
      anon_sym_LPAREN,
    ACTIONS(16385), 1,
      sym__automatic_semicolon,
    STATE(14199), 1,
      sym_class_parameters,
    ACTIONS(16194), 3,
      anon_sym_RBRACE,
      anon_sym_extends,
      anon_sym_SEMI,
    STATE(14005), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__full_enum_def_repeat1,
  [607331] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14006), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8360), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [607351] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14760), 1,
      anon_sym_match,
    ACTIONS(16137), 1,
      anon_sym_LBRACK,
    STATE(9978), 1,
      sym_type_arguments,
    STATE(14007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_finally,
  [607377] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13347), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14008), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13345), 5,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [607399] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16388), 1,
      anon_sym_SEMI,
    ACTIONS(16390), 1,
      anon_sym_else,
    STATE(14009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 4,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_finally,
  [607422] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16314), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_EQ,
      anon_sym_SEMI,
  [607441] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15109), 1,
      anon_sym_match,
    ACTIONS(16392), 1,
      anon_sym_LBRACK,
    STATE(10254), 1,
      sym_type_arguments,
    STATE(14011), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [607466] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15912), 1,
      anon_sym_if,
    STATE(14079), 1,
      aux_sym_enumerator_repeat1,
    STATE(14518), 1,
      sym_guard,
    STATE(14012), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15663), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [607491] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14013), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16394), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [607510] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16396), 1,
      anon_sym_COMMA,
    STATE(14142), 1,
      aux_sym_import_declaration_repeat1,
    STATE(14014), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16129), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [607533] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16400), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15327), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14015), 2,
      sym_comment,
      sym_block_comment,
  [607562] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15109), 1,
      anon_sym_match,
    ACTIONS(16392), 1,
      anon_sym_LBRACK,
    STATE(10254), 1,
      sym_type_arguments,
    STATE(14016), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16402), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [607587] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14017), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [607606] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16404), 1,
      anon_sym_SEMI,
    ACTIONS(16407), 1,
      anon_sym_else,
    STATE(14018), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 4,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
  [607629] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16410), 1,
      anon_sym_SEMI,
    ACTIONS(16413), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    ACTIONS(15514), 2,
      anon_sym_finally,
      anon_sym_do,
    STATE(14019), 2,
      sym_comment,
      sym_block_comment,
  [607654] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [607673] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16416), 1,
      anon_sym_COMMA,
    STATE(14021), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat1,
    ACTIONS(15206), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_derives,
      anon_sym_LPAREN,
  [607694] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16419), 1,
      anon_sym_SEMI,
    ACTIONS(16422), 1,
      anon_sym_else,
    STATE(14022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
  [607717] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16425), 1,
      anon_sym_with,
    STATE(14023), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat2,
    ACTIONS(15211), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_derives,
      anon_sym_LPAREN,
  [607738] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14024), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [607757] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16392), 1,
      anon_sym_LBRACK,
    STATE(10254), 1,
      sym_type_arguments,
    STATE(14025), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13384), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
  [607780] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [607799] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16428), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15684), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14027), 2,
      sym_comment,
      sym_block_comment,
  [607828] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16430), 1,
      anon_sym_SEMI,
    ACTIONS(16433), 1,
      anon_sym_else,
    STATE(14028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_match,
  [607851] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16135), 1,
      anon_sym_finally,
    STATE(13456), 1,
      sym_finally_clause,
    STATE(14029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 4,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_do,
  [607874] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16435), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [607893] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [607912] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14032), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [607931] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [607950] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16437), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14992), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14034), 2,
      sym_comment,
      sym_block_comment,
  [607979] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16439), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15516), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14035), 2,
      sym_comment,
      sym_block_comment,
  [608008] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16441), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15445), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14036), 2,
      sym_comment,
      sym_block_comment,
  [608037] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14037), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [608056] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9924), 1,
      anon_sym_LPAREN,
    STATE(14641), 1,
      sym_arguments,
    STATE(14038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15496), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [608079] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14039), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [608098] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16443), 1,
      anon_sym_COLON,
    STATE(14040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16115), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_SEMI,
  [608119] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15873), 1,
      anon_sym_LBRACK,
    ACTIONS(15875), 1,
      anon_sym_match,
    STATE(9356), 1,
      sym_type_arguments,
    STATE(14041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16445), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [608144] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16447), 1,
      anon_sym_COMMA,
    STATE(14042), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat1,
    ACTIONS(15206), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [608165] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16450), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [608184] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14044), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [608203] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16454), 1,
      anon_sym_LT_PERCENT,
    STATE(14680), 1,
      sym_view_bound,
    ACTIONS(16452), 3,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14045), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__type_parameter_repeat1,
  [608226] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16392), 1,
      anon_sym_LBRACK,
    STATE(10254), 1,
      sym_type_arguments,
    STATE(14046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13386), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
  [608249] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14047), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16318), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [608268] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [608287] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16457), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14732), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14049), 2,
      sym_comment,
      sym_block_comment,
  [608316] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16459), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [608335] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [608354] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [608373] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16461), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14763), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14053), 2,
      sym_comment,
      sym_block_comment,
  [608402] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [608421] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16463), 1,
      anon_sym_SEMI,
    ACTIONS(16466), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    ACTIONS(15514), 2,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
    STATE(14055), 2,
      sym_comment,
      sym_block_comment,
  [608446] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16468), 1,
      anon_sym_LBRACE,
    ACTIONS(16472), 1,
      sym__interpolation_identifier,
    ACTIONS(16470), 2,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
    STATE(14056), 2,
      sym_comment,
      sym_block_comment,
    STATE(16081), 2,
      sym_block,
      sym__aliased_interpolation_identifier,
  [608471] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [608490] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14042), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(14058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15079), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [608511] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16474), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [608530] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [608549] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12703), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_LT_PERCENT,
  [608568] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16476), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15142), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14062), 2,
      sym_comment,
      sym_block_comment,
  [608597] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16103), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [608616] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15463), 1,
      anon_sym_LT_COLON,
    STATE(14013), 1,
      sym_upper_bound,
    STATE(14064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16103), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_EQ,
      anon_sym_SEMI,
  [608639] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16396), 1,
      anon_sym_COMMA,
    STATE(14144), 1,
      aux_sym_import_declaration_repeat1,
    STATE(14065), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16190), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [608662] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16478), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [608681] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10976), 1,
      anon_sym_LPAREN,
    STATE(14458), 1,
      sym_arguments,
    STATE(14067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15496), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [608704] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16480), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [608723] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16482), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15619), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14069), 2,
      sym_comment,
      sym_block_comment,
  [608752] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16484), 1,
      anon_sym_COLON,
    STATE(14070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16171), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_SEMI,
  [608773] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16486), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15516), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14071), 2,
      sym_comment,
      sym_block_comment,
  [608802] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12606), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_LT_PERCENT,
  [608821] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16488), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15470), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14073), 2,
      sym_comment,
      sym_block_comment,
  [608850] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16490), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15100), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14074), 2,
      sym_comment,
      sym_block_comment,
  [608879] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    ACTIONS(16492), 1,
      anon_sym_COLON,
    ACTIONS(16494), 1,
      sym__automatic_semicolon,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14126), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14075), 2,
      sym_comment,
      sym_block_comment,
  [608908] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16496), 1,
      anon_sym_SEMI,
    ACTIONS(16499), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    ACTIONS(15514), 2,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
    STATE(14076), 2,
      sym_comment,
      sym_block_comment,
  [608933] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [608952] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14078), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [608971] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16501), 1,
      anon_sym_if,
    STATE(14518), 1,
      sym_guard,
    ACTIONS(15777), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    STATE(14079), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enumerator_repeat1,
  [608994] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16504), 1,
      anon_sym_LBRACE,
    ACTIONS(16508), 1,
      sym__interpolation_identifier,
    ACTIONS(16506), 2,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
    STATE(14080), 2,
      sym_comment,
      sym_block_comment,
    STATE(16080), 2,
      sym_block,
      sym__aliased_interpolation_identifier,
  [609019] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14081), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609038] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609057] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16510), 1,
      anon_sym_SEMI,
    ACTIONS(16513), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    ACTIONS(15514), 2,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
    STATE(14083), 2,
      sym_comment,
      sym_block_comment,
  [609082] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609101] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12715), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_LT_PERCENT,
  [609120] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16516), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15366), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14086), 2,
      sym_comment,
      sym_block_comment,
  [609149] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14384), 1,
      sym_arguments,
    STATE(14087), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [609170] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16518), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15246), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14088), 2,
      sym_comment,
      sym_block_comment,
  [609199] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16520), 1,
      anon_sym_COMMA,
    ACTIONS(16522), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14881), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14089), 2,
      sym_comment,
      sym_block_comment,
  [609228] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609247] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16524), 1,
      anon_sym_SEMI,
    ACTIONS(16527), 1,
      anon_sym_else,
    STATE(14091), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
  [609270] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14092), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609289] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16529), 1,
      anon_sym_SEMI,
    ACTIONS(16531), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    ACTIONS(15514), 2,
      anon_sym_finally,
      anon_sym_do,
    STATE(14093), 2,
      sym_comment,
      sym_block_comment,
  [609314] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16533), 1,
      anon_sym_SEMI,
    ACTIONS(16536), 1,
      anon_sym_else,
    STATE(14094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 4,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_finally,
  [609337] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16539), 1,
      anon_sym_SEMI,
    ACTIONS(16542), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    ACTIONS(15514), 2,
      anon_sym_while,
      anon_sym_finally,
    STATE(14095), 2,
      sym_comment,
      sym_block_comment,
  [609362] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15417), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609381] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14097), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15791), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
  [609400] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16545), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14844), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14098), 2,
      sym_comment,
      sym_block_comment,
  [609429] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14099), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16360), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [609448] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15855), 1,
      anon_sym_COMMA,
    STATE(14042), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(14100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15079), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609471] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16547), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15169), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14101), 2,
      sym_comment,
      sym_block_comment,
  [609500] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [609519] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16549), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14738), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14103), 2,
      sym_comment,
      sym_block_comment,
  [609548] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14104), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15103), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [609567] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16551), 1,
      anon_sym_SEMI,
    ACTIONS(16554), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    ACTIONS(15514), 2,
      sym__automatic_semicolon,
      sym__outdent,
    STATE(14105), 2,
      sym_comment,
      sym_block_comment,
  [609592] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14106), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609611] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15109), 1,
      anon_sym_match,
    ACTIONS(16392), 1,
      anon_sym_LBRACK,
    STATE(10254), 1,
      sym_type_arguments,
    STATE(14107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13382), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [609636] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16556), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15516), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14108), 2,
      sym_comment,
      sym_block_comment,
  [609665] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16558), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15038), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14109), 2,
      sym_comment,
      sym_block_comment,
  [609694] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609713] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16560), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15306), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14111), 2,
      sym_comment,
      sym_block_comment,
  [609742] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12717), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_LT_PERCENT,
  [609761] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16562), 1,
      anon_sym_COMMA,
    STATE(14113), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_import_declaration_repeat1,
    ACTIONS(16375), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [609782] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14533), 1,
      anon_sym_extends,
    STATE(14520), 1,
      sym_extends_clause,
    STATE(14114), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14397), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [609805] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14134), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(14115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15079), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609826] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [609845] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16565), 1,
      anon_sym_SEMI,
    ACTIONS(16568), 1,
      anon_sym_else,
    STATE(14117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_match,
  [609868] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    ACTIONS(16570), 1,
      anon_sym_COLON,
    ACTIONS(16572), 1,
      sym__automatic_semicolon,
    STATE(12182), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14118), 2,
      sym_comment,
      sym_block_comment,
  [609897] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    ACTIONS(16574), 1,
      anon_sym_COLON,
    ACTIONS(16576), 1,
      sym__automatic_semicolon,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14138), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14119), 2,
      sym_comment,
      sym_block_comment,
  [609926] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16578), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [609945] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16365), 1,
      anon_sym_LBRACE,
    ACTIONS(16580), 1,
      anon_sym_EQ,
    STATE(14597), 1,
      sym_block,
    STATE(14121), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16280), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [609970] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14122), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [609989] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16090), 1,
      anon_sym_finally,
    STATE(13456), 1,
      sym_finally_clause,
    STATE(14123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 4,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_catch,
  [610012] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14124), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16320), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [610031] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16582), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15686), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14125), 2,
      sym_comment,
      sym_block_comment,
  [610060] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    ACTIONS(16584), 1,
      anon_sym_COLON,
    ACTIONS(16586), 1,
      sym__automatic_semicolon,
    STATE(12182), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14126), 2,
      sym_comment,
      sym_block_comment,
  [610089] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [610108] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(5114), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [610127] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    ACTIONS(16588), 1,
      anon_sym_COLON,
    ACTIONS(16590), 1,
      sym__automatic_semicolon,
    STATE(12182), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14129), 2,
      sym_comment,
      sym_block_comment,
  [610156] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14130), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [610175] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14131), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16592), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [610194] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16594), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15659), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14132), 2,
      sym_comment,
      sym_block_comment,
  [610223] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15417), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [610242] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16596), 1,
      anon_sym_COMMA,
    STATE(14134), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat1,
    ACTIONS(15206), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [610263] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16599), 1,
      anon_sym_COLON,
    STATE(14135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16111), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_SEMI,
  [610284] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15877), 1,
      anon_sym_COMMA,
    STATE(14134), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(14136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15079), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [610307] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14137), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16601), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [610326] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    ACTIONS(16603), 1,
      anon_sym_COLON,
    ACTIONS(16605), 1,
      sym__automatic_semicolon,
    STATE(12182), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13395), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14138), 2,
      sym_comment,
      sym_block_comment,
  [610355] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [610374] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16607), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [610393] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [610412] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16396), 1,
      anon_sym_COMMA,
    STATE(14113), 1,
      aux_sym_import_declaration_repeat1,
    STATE(14142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16303), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [610435] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16609), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14922), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14143), 2,
      sym_comment,
      sym_block_comment,
  [610464] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16396), 1,
      anon_sym_COMMA,
    STATE(14113), 1,
      aux_sym_import_declaration_repeat1,
    STATE(14144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16305), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [610487] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16611), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15040), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14145), 2,
      sym_comment,
      sym_block_comment,
  [610516] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15105), 1,
      anon_sym_LBRACK,
    ACTIONS(15109), 1,
      anon_sym_match,
    STATE(7547), 1,
      sym_type_arguments,
    STATE(14146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16445), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [610541] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16392), 1,
      anon_sym_LBRACK,
    STATE(10254), 1,
      sym_type_arguments,
    STATE(14147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13378), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
  [610564] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16278), 1,
      anon_sym_LBRACE,
    ACTIONS(16613), 1,
      anon_sym_EQ,
    STATE(14236), 1,
      sym_block,
    STATE(14148), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16280), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [610589] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16615), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15207), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14149), 2,
      sym_comment,
      sym_block_comment,
  [610618] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16617), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15056), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14150), 2,
      sym_comment,
      sym_block_comment,
  [610647] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14399), 1,
      anon_sym_extends,
    STATE(14424), 1,
      sym_extends_clause,
    STATE(14151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14397), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [610670] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16392), 1,
      anon_sym_LBRACK,
    STATE(10254), 1,
      sym_type_arguments,
    STATE(14152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13380), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
  [610693] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16278), 1,
      anon_sym_LBRACE,
    ACTIONS(16619), 1,
      anon_sym_EQ,
    STATE(14236), 1,
      sym_block,
    STATE(14153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16280), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [610718] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16621), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [610737] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15888), 1,
      anon_sym_COMMA,
    STATE(14021), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(14155), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15079), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_derives,
      anon_sym_LPAREN,
  [610760] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [610779] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15890), 1,
      anon_sym_with,
    STATE(14023), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(14157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15079), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_derives,
      anon_sym_LPAREN,
  [610802] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [610821] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16398), 1,
      anon_sym_COMMA,
    ACTIONS(16623), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15826), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14159), 2,
      sym_comment,
      sym_block_comment,
  [610850] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14160), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [610869] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14161), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16238), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [610888] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15463), 1,
      anon_sym_LT_COLON,
    STATE(14066), 1,
      sym_upper_bound,
    STATE(14162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16238), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_EQ,
      anon_sym_SEMI,
  [610911] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16625), 1,
      anon_sym_SEMI,
    ACTIONS(16627), 1,
      anon_sym_else,
    STATE(14163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 4,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
  [610934] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16629), 1,
      anon_sym_SEMI,
    ACTIONS(16631), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    ACTIONS(15514), 2,
      anon_sym_while,
      anon_sym_finally,
    STATE(14164), 2,
      sym_comment,
      sym_block_comment,
  [610959] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15444), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [610977] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16633), 1,
      anon_sym_COMMA,
    ACTIONS(16635), 1,
      anon_sym_RPAREN,
    STATE(15094), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14166), 2,
      sym_comment,
      sym_block_comment,
  [611003] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16637), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [611021] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16639), 1,
      anon_sym_COMMA,
    ACTIONS(16641), 1,
      anon_sym_RPAREN,
    STATE(14836), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14168), 2,
      sym_comment,
      sym_block_comment,
  [611047] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    STATE(14190), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(15457), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14169), 2,
      sym_comment,
      sym_block_comment,
  [611071] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15444), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [611089] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16643), 1,
      anon_sym_COMMA,
    STATE(14222), 1,
      aux_sym_enum_case_definitions_repeat1,
    STATE(14171), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16645), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [611111] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16647), 1,
      anon_sym_COMMA,
    ACTIONS(16649), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15170), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14172), 2,
      sym_comment,
      sym_block_comment,
  [611137] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15547), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [611155] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    STATE(14190), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(15859), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14174), 2,
      sym_comment,
      sym_block_comment,
  [611179] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16651), 1,
      anon_sym_COMMA,
    ACTIONS(16653), 1,
      anon_sym_RPAREN,
    STATE(15120), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14175), 2,
      sym_comment,
      sym_block_comment,
  [611205] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10046), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [611223] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16655), 1,
      anon_sym_COMMA,
    ACTIONS(16657), 1,
      anon_sym_RPAREN,
    STATE(14789), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14177), 2,
      sym_comment,
      sym_block_comment,
  [611249] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16601), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [611267] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15560), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [611285] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16659), 1,
      anon_sym_COMMA,
    ACTIONS(16661), 1,
      anon_sym_RPAREN,
    STATE(14856), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14180), 2,
      sym_comment,
      sym_block_comment,
  [611311] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16663), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [611329] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14182), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16665), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [611347] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16667), 1,
      anon_sym_COMMA,
    ACTIONS(16669), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15719), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14183), 2,
      sym_comment,
      sym_block_comment,
  [611373] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
  [611391] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10029), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [611409] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16671), 1,
      anon_sym_COMMA,
    ACTIONS(16673), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15156), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14186), 2,
      sym_comment,
      sym_block_comment,
  [611435] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16394), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [611453] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16675), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [611471] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    ACTIONS(16677), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14189), 2,
      sym_comment,
      sym_block_comment,
  [611495] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16679), 1,
      anon_sym_COLON,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(16682), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14190), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__type_parameter_repeat2,
  [611517] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    STATE(14190), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(16684), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14191), 2,
      sym_comment,
      sym_block_comment,
  [611541] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16686), 1,
      anon_sym_COMMA,
    ACTIONS(16688), 1,
      anon_sym_RPAREN,
    STATE(14872), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14192), 2,
      sym_comment,
      sym_block_comment,
  [611567] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10050), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [611585] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16690), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [611603] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16692), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [611621] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15422), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [611639] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    ACTIONS(16694), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14197), 2,
      sym_comment,
      sym_block_comment,
  [611663] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16696), 1,
      anon_sym_COMMA,
    ACTIONS(16698), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15183), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14198), 2,
      sym_comment,
      sym_block_comment,
  [611689] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14199), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16700), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [611707] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16702), 1,
      anon_sym_COMMA,
    ACTIONS(16704), 1,
      anon_sym_RPAREN,
    STATE(14877), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14200), 2,
      sym_comment,
      sym_block_comment,
  [611733] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16706), 1,
      anon_sym_COMMA,
    ACTIONS(16708), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15814), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14201), 2,
      sym_comment,
      sym_block_comment,
  [611759] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16712), 1,
      anon_sym_COMMA,
    STATE(14404), 1,
      aux_sym_enum_case_definitions_repeat1,
    STATE(14202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16710), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [611781] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16714), 1,
      anon_sym_COLON,
    STATE(14203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15908), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_if,
      anon_sym_SEMI,
  [611801] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16716), 1,
      anon_sym_COMMA,
    ACTIONS(16718), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15441), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14204), 2,
      sym_comment,
      sym_block_comment,
  [611827] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16720), 1,
      anon_sym_COMMA,
    ACTIONS(16722), 1,
      anon_sym_RPAREN,
    STATE(14766), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14205), 2,
      sym_comment,
      sym_block_comment,
  [611853] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14218), 1,
      aux_sym__block_repeat1,
    ACTIONS(15944), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(15946), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14206), 2,
      sym_comment,
      sym_block_comment,
  [611875] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16726), 1,
      anon_sym_EQ,
    STATE(14207), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16724), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [611895] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16728), 1,
      anon_sym_COMMA,
    ACTIONS(16730), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15188), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14208), 2,
      sym_comment,
      sym_block_comment,
  [611921] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16712), 1,
      anon_sym_COMMA,
    STATE(14408), 1,
      aux_sym_enum_case_definitions_repeat1,
    STATE(14209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16710), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [611943] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16734), 1,
      anon_sym_EQ,
    STATE(14210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16732), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [611963] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16736), 1,
      anon_sym_COMMA,
    ACTIONS(16738), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15245), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14211), 2,
      sym_comment,
      sym_block_comment,
  [611989] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15415), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [612007] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15417), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [612025] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16316), 1,
      anon_sym_finally,
    STATE(13838), 1,
      sym_finally_clause,
    STATE(14214), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 3,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
  [612047] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16740), 1,
      anon_sym_COMMA,
    ACTIONS(16742), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15484), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14215), 2,
      sym_comment,
      sym_block_comment,
  [612073] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14216), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16744), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [612091] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16152), 1,
      anon_sym_COLON,
    ACTIONS(16154), 1,
      anon_sym_LBRACE,
    ACTIONS(16158), 1,
      anon_sym_derives,
    STATE(14470), 1,
      sym_enum_body,
    STATE(15350), 1,
      sym_derives_clause,
    STATE(14217), 2,
      sym_comment,
      sym_block_comment,
  [612117] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14320), 1,
      aux_sym__block_repeat1,
    ACTIONS(647), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(16746), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14218), 2,
      sym_comment,
      sym_block_comment,
  [612139] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6416), 1,
      anon_sym_LBRACE,
    ACTIONS(13242), 1,
      anon_sym_COLON,
    STATE(14502), 1,
      sym_template_body,
    STATE(9113), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(14219), 2,
      sym_comment,
      sym_block_comment,
  [612163] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14220), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16700), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [612181] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16748), 1,
      anon_sym_COMMA,
    ACTIONS(16750), 1,
      anon_sym_RPAREN,
    STATE(14892), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14221), 2,
      sym_comment,
      sym_block_comment,
  [612207] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16643), 1,
      anon_sym_COMMA,
    STATE(14271), 1,
      aux_sym_enum_case_definitions_repeat1,
    STATE(14222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16710), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [612229] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16752), 1,
      anon_sym_COMMA,
    ACTIONS(16754), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15269), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14223), 2,
      sym_comment,
      sym_block_comment,
  [612255] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16758), 1,
      anon_sym_EQ,
    STATE(14224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16756), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [612275] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14225), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16760), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [612293] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14226), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16762), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [612311] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16764), 1,
      anon_sym_COMMA,
    ACTIONS(16766), 1,
      anon_sym_RPAREN,
    STATE(14897), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14227), 2,
      sym_comment,
      sym_block_comment,
  [612337] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16768), 1,
      anon_sym_COMMA,
    ACTIONS(16770), 1,
      anon_sym_RPAREN,
    STATE(14798), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14228), 2,
      sym_comment,
      sym_block_comment,
  [612363] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16293), 1,
      anon_sym_finally,
    STATE(13806), 1,
      sym_finally_clause,
    STATE(14229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 3,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
  [612385] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16238), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [612403] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14231), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10706), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [612421] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14232), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10710), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [612439] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16772), 1,
      anon_sym_COMMA,
    ACTIONS(16774), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15842), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14233), 2,
      sym_comment,
      sym_block_comment,
  [612465] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16643), 1,
      anon_sym_COMMA,
    STATE(14273), 1,
      aux_sym_enum_case_definitions_repeat1,
    STATE(14234), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16710), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [612487] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16776), 1,
      anon_sym_COMMA,
    ACTIONS(16778), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15338), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14235), 2,
      sym_comment,
      sym_block_comment,
  [612513] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16780), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [612531] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14237), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [612549] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16784), 1,
      anon_sym_EQ,
    STATE(14238), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16782), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [612569] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14239), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16786), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [612587] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16152), 1,
      anon_sym_COLON,
    ACTIONS(16154), 1,
      anon_sym_LBRACE,
    ACTIONS(16158), 1,
      anon_sym_derives,
    STATE(14727), 1,
      sym_enum_body,
    STATE(15389), 1,
      sym_derives_clause,
    STATE(14240), 2,
      sym_comment,
      sym_block_comment,
  [612613] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [612631] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16788), 1,
      anon_sym_EQ,
    STATE(14242), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16756), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [612651] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16790), 1,
      anon_sym_RBRACE,
    ACTIONS(16792), 1,
      anon_sym_COMMA,
    ACTIONS(16794), 1,
      anon_sym_EQ_GT,
    ACTIONS(16796), 1,
      anon_sym_as,
    STATE(15396), 1,
      aux_sym_namespace_selectors_repeat1,
    STATE(14243), 2,
      sym_comment,
      sym_block_comment,
  [612677] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16798), 1,
      anon_sym_COMMA,
    ACTIONS(16800), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15320), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14244), 2,
      sym_comment,
      sym_block_comment,
  [612703] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16435), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [612721] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16802), 1,
      anon_sym_COMMA,
    ACTIONS(16804), 1,
      anon_sym_RPAREN,
    STATE(14825), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14246), 2,
      sym_comment,
      sym_block_comment,
  [612747] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16806), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [612765] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14248), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16808), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [612783] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16810), 1,
      anon_sym_EQ,
    STATE(14249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16732), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [612803] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16812), 1,
      anon_sym_with,
    ACTIONS(9418), 3,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
    STATE(14250), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
  [612823] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14251), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8481), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
  [612841] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14252), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10714), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [612859] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [612877] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    ACTIONS(16815), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14254), 2,
      sym_comment,
      sym_block_comment,
  [612901] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16712), 1,
      anon_sym_COMMA,
    STATE(14202), 1,
      aux_sym_enum_case_definitions_repeat1,
    STATE(14255), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16645), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [612923] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14259), 1,
      aux_sym__block_repeat1,
    ACTIONS(15944), 2,
      sym__outdent,
      anon_sym_case,
    ACTIONS(15964), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14256), 2,
      sym_comment,
      sym_block_comment,
  [612945] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    STATE(14190), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(15962), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14257), 2,
      sym_comment,
      sym_block_comment,
  [612969] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10033), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [612987] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14333), 1,
      aux_sym__block_repeat1,
    ACTIONS(647), 2,
      sym__outdent,
      anon_sym_case,
    ACTIONS(16817), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14259), 2,
      sym_comment,
      sym_block_comment,
  [613009] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16819), 1,
      anon_sym_SEMI,
    ACTIONS(16821), 1,
      anon_sym_else,
    STATE(14260), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 3,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_do,
  [613031] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14261), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16823), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613049] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15514), 1,
      anon_sym_do,
    ACTIONS(16825), 1,
      anon_sym_SEMI,
    ACTIONS(16827), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14262), 2,
      sym_comment,
      sym_block_comment,
  [613073] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14263), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16829), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613091] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16831), 1,
      anon_sym_COMMA,
    ACTIONS(16833), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15354), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14264), 2,
      sym_comment,
      sym_block_comment,
  [613117] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14265), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16835), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613135] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    STATE(14190), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(15966), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14266), 2,
      sym_comment,
      sym_block_comment,
  [613159] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14267), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16837), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613177] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16839), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613195] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13570), 1,
      anon_sym_LPAREN,
    STATE(15479), 1,
      sym_arguments,
    STATE(14269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15496), 3,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_derives,
  [613217] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16127), 1,
      anon_sym_finally,
    STATE(13806), 1,
      sym_finally_clause,
    STATE(14270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 3,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_do,
  [613239] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16841), 1,
      anon_sym_COMMA,
    ACTIONS(16844), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    STATE(14271), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_case_definitions_repeat1,
  [613259] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16846), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613277] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16643), 1,
      anon_sym_COMMA,
    STATE(14271), 1,
      aux_sym_enum_case_definitions_repeat1,
    STATE(14273), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16848), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [613299] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16837), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613317] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16621), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [613335] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14276), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16850), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613353] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16852), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613371] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16854), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613389] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16856), 1,
      anon_sym_COMMA,
    ACTIONS(16858), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15475), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14279), 2,
      sym_comment,
      sym_block_comment,
  [613415] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16860), 1,
      anon_sym_COMMA,
    ACTIONS(16862), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15379), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14280), 2,
      sym_comment,
      sym_block_comment,
  [613441] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14281), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15488), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [613459] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16158), 1,
      anon_sym_derives,
    ACTIONS(16160), 1,
      anon_sym_COLON,
    ACTIONS(16162), 1,
      anon_sym_LBRACE,
    STATE(14276), 1,
      sym_enum_body,
    STATE(14929), 1,
      sym_derives_clause,
    STATE(14282), 2,
      sym_comment,
      sym_block_comment,
  [613485] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14283), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [613503] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16864), 1,
      anon_sym_SEMI,
    ACTIONS(16867), 1,
      anon_sym_else,
    STATE(14284), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 3,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_do,
  [613525] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15514), 1,
      anon_sym_do,
    ACTIONS(16870), 1,
      anon_sym_SEMI,
    ACTIONS(16873), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14285), 2,
      sym_comment,
      sym_block_comment,
  [613549] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16876), 1,
      anon_sym_SEMI,
    ACTIONS(16878), 1,
      sym__automatic_semicolon,
    STATE(14322), 1,
      aux_sym_enumerators_repeat1,
    ACTIONS(7164), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(14286), 2,
      sym_comment,
      sym_block_comment,
  [613573] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16578), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [613591] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16880), 1,
      anon_sym_COMMA,
    ACTIONS(16882), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15237), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14288), 2,
      sym_comment,
      sym_block_comment,
  [613617] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16884), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613635] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16158), 1,
      anon_sym_derives,
    ACTIONS(16160), 1,
      anon_sym_COLON,
    ACTIONS(16162), 1,
      anon_sym_LBRACE,
    STATE(14339), 1,
      sym_enum_body,
    STATE(15036), 1,
      sym_derives_clause,
    STATE(14290), 2,
      sym_comment,
      sym_block_comment,
  [613661] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16884), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613679] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16886), 1,
      anon_sym_COMMA,
    ACTIONS(16888), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15404), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14292), 2,
      sym_comment,
      sym_block_comment,
  [613705] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16890), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613723] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14294), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16892), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613741] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14295), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16894), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613759] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14296), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16896), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613777] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    ACTIONS(16898), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14297), 2,
      sym_comment,
      sym_block_comment,
  [613801] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16900), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613819] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16902), 1,
      anon_sym_COMMA,
    ACTIONS(16904), 1,
      anon_sym_RPAREN,
    STATE(14805), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14299), 2,
      sym_comment,
      sym_block_comment,
  [613845] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14300), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15560), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [613863] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16906), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613881] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16908), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613899] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16910), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [613917] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16912), 1,
      anon_sym_COMMA,
    ACTIONS(16914), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15413), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14304), 2,
      sym_comment,
      sym_block_comment,
  [613943] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16916), 1,
      anon_sym_COMMA,
    ACTIONS(16918), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15382), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14305), 2,
      sym_comment,
      sym_block_comment,
  [613969] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16920), 1,
      anon_sym_COMMA,
    ACTIONS(16922), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15565), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14306), 2,
      sym_comment,
      sym_block_comment,
  [613995] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16924), 1,
      anon_sym_COMMA,
    ACTIONS(16926), 1,
      anon_sym_RPAREN,
    STATE(14746), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14307), 2,
      sym_comment,
      sym_block_comment,
  [614021] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16592), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [614039] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16607), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [614057] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6214), 1,
      anon_sym_LBRACE,
    ACTIONS(12868), 1,
      anon_sym_COLON,
    STATE(14326), 1,
      sym_template_body,
    STATE(6278), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(14310), 2,
      sym_comment,
      sym_block_comment,
  [614081] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14311), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16928), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [614099] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    ACTIONS(16930), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14312), 2,
      sym_comment,
      sym_block_comment,
  [614123] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14313), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16932), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [614141] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    ACTIONS(16934), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14314), 2,
      sym_comment,
      sym_block_comment,
  [614165] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16936), 1,
      anon_sym_SEMI,
    ACTIONS(16938), 1,
      sym__automatic_semicolon,
    STATE(14323), 1,
      aux_sym_enumerators_repeat1,
    ACTIONS(7164), 2,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
    STATE(14315), 2,
      sym_comment,
      sym_block_comment,
  [614189] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16940), 1,
      anon_sym_COMMA,
    ACTIONS(16942), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15427), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14316), 2,
      sym_comment,
      sym_block_comment,
  [614215] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16944), 1,
      anon_sym_COMMA,
    ACTIONS(16946), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15154), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14317), 2,
      sym_comment,
      sym_block_comment,
  [614241] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16948), 1,
      anon_sym_COMMA,
    ACTIONS(16950), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15575), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14318), 2,
      sym_comment,
      sym_block_comment,
  [614267] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    ACTIONS(16952), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14319), 2,
      sym_comment,
      sym_block_comment,
  [614291] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16344), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(16954), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14320), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__block_repeat1,
  [614311] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16450), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [614329] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16459), 2,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(16957), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14322), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enumerators_repeat1,
  [614349] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16459), 2,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
    ACTIONS(16960), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14323), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enumerators_repeat1,
  [614369] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16963), 1,
      anon_sym_COMMA,
    ACTIONS(16965), 1,
      anon_sym_RPAREN,
    STATE(14803), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14324), 2,
      sym_comment,
      sym_block_comment,
  [614395] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14325), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16967), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [614413] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14326), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16969), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [614431] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14327), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16971), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [614449] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14328), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16973), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [614467] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14329), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16975), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [614485] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14330), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16975), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [614503] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14331), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16977), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [614521] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16979), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [614539] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16344), 2,
      sym__outdent,
      anon_sym_case,
    ACTIONS(16981), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14333), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__block_repeat1,
  [614559] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16984), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [614577] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(16986), 1,
      anon_sym_COMMA,
    ACTIONS(16988), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15452), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14335), 2,
      sym_comment,
      sym_block_comment,
  [614603] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16990), 1,
      anon_sym_EQ,
    STATE(14336), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16724), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [614623] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16992), 1,
      anon_sym_SEMI,
    ACTIONS(16994), 1,
      anon_sym_else,
    STATE(14337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 3,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
  [614645] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15514), 1,
      anon_sym_while,
    ACTIONS(16996), 1,
      anon_sym_SEMI,
    ACTIONS(16998), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14338), 2,
      sym_comment,
      sym_block_comment,
  [614669] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14339), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17000), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [614687] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17002), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [614705] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15488), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [614723] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17004), 1,
      anon_sym_COMMA,
    ACTIONS(17006), 1,
      anon_sym_RPAREN,
    STATE(14811), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14342), 2,
      sym_comment,
      sym_block_comment,
  [614749] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14343), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17008), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [614767] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    ACTIONS(17010), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14344), 2,
      sym_comment,
      sym_block_comment,
  [614791] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    ACTIONS(17012), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14345), 2,
      sym_comment,
      sym_block_comment,
  [614815] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17014), 1,
      anon_sym_SEMI,
    ACTIONS(17017), 1,
      anon_sym_else,
    STATE(14346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15504), 3,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
  [614837] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15514), 1,
      anon_sym_while,
    ACTIONS(17020), 1,
      anon_sym_SEMI,
    ACTIONS(17023), 1,
      anon_sym_else,
    ACTIONS(15511), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14347), 2,
      sym_comment,
      sym_block_comment,
  [614861] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17026), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [614879] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17028), 1,
      anon_sym_COMMA,
    ACTIONS(17030), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15460), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14349), 2,
      sym_comment,
      sym_block_comment,
  [614905] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14350), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15415), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [614923] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17032), 1,
      anon_sym_COMMA,
    ACTIONS(17034), 1,
      anon_sym_RPAREN,
    STATE(14824), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14351), 2,
      sym_comment,
      sym_block_comment,
  [614949] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16474), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [614967] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14353), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8114), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [614985] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14354), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17036), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615003] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17038), 1,
      anon_sym_COMMA,
    ACTIONS(17040), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15482), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14355), 2,
      sym_comment,
      sym_block_comment,
  [615029] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14356), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11900), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [615047] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17042), 1,
      anon_sym_COMMA,
    ACTIONS(17044), 1,
      anon_sym_RPAREN,
    STATE(14782), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14357), 2,
      sym_comment,
      sym_block_comment,
  [615073] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17046), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615091] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17048), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615109] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16876), 1,
      anon_sym_SEMI,
    ACTIONS(17052), 1,
      sym__automatic_semicolon,
    STATE(14286), 1,
      aux_sym_enumerators_repeat1,
    ACTIONS(17050), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(14360), 2,
      sym_comment,
      sym_block_comment,
  [615133] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14361), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17054), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615151] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17056), 1,
      anon_sym_COMMA,
    ACTIONS(17058), 1,
      anon_sym_RPAREN,
    STATE(14831), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14362), 2,
      sym_comment,
      sym_block_comment,
  [615177] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17060), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615195] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14364), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17062), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615213] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14365), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16314), 5,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
  [615231] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17064), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615249] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16103), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [615267] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17066), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615285] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17068), 1,
      anon_sym_COMMA,
    ACTIONS(17070), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15524), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14369), 2,
      sym_comment,
      sym_block_comment,
  [615311] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17072), 1,
      anon_sym_COMMA,
    ACTIONS(17074), 1,
      anon_sym_RPAREN,
    STATE(15126), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14370), 2,
      sym_comment,
      sym_block_comment,
  [615337] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17076), 1,
      anon_sym_COMMA,
    ACTIONS(17078), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15628), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14371), 2,
      sym_comment,
      sym_block_comment,
  [615363] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16936), 1,
      anon_sym_SEMI,
    ACTIONS(17080), 1,
      sym__automatic_semicolon,
    STATE(14315), 1,
      aux_sym_enumerators_repeat1,
    ACTIONS(17050), 2,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
    STATE(14372), 2,
      sym_comment,
      sym_block_comment,
  [615387] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16478), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [615405] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14374), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17082), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615423] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14375), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17084), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615441] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14376), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17086), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615459] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14377), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17088), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615477] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    ACTIONS(17090), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14378), 2,
      sym_comment,
      sym_block_comment,
  [615501] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14379), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17092), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615519] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14380), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17094), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615537] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14381), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15422), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [615555] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17096), 1,
      anon_sym_COMMA,
    ACTIONS(17098), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15584), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14382), 2,
      sym_comment,
      sym_block_comment,
  [615581] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14383), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [615599] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10524), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [615617] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17100), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615635] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17102), 1,
      anon_sym_COMMA,
    ACTIONS(17104), 1,
      anon_sym_RPAREN,
    STATE(14841), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14386), 2,
      sym_comment,
      sym_block_comment,
  [615661] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16794), 1,
      anon_sym_EQ_GT,
    ACTIONS(16796), 1,
      anon_sym_as,
    ACTIONS(17106), 1,
      anon_sym_RBRACE,
    ACTIONS(17108), 1,
      anon_sym_COMMA,
    STATE(15340), 1,
      aux_sym_namespace_selectors_repeat1,
    STATE(14387), 2,
      sym_comment,
      sym_block_comment,
  [615687] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17110), 1,
      anon_sym_COMMA,
    ACTIONS(17112), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15616), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14388), 2,
      sym_comment,
      sym_block_comment,
  [615713] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    ACTIONS(17114), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14389), 2,
      sym_comment,
      sym_block_comment,
  [615737] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15415), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [615755] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14391), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [615773] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14392), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10039), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [615791] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14393), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17116), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615809] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17118), 1,
      anon_sym_COMMA,
    ACTIONS(17120), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15420), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14394), 2,
      sym_comment,
      sym_block_comment,
  [615835] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17122), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615853] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    STATE(14190), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(15429), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14396), 2,
      sym_comment,
      sym_block_comment,
  [615877] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17124), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615895] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17126), 1,
      anon_sym_COMMA,
    ACTIONS(17128), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15742), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14398), 2,
      sym_comment,
      sym_block_comment,
  [615921] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17130), 1,
      anon_sym_COMMA,
    ACTIONS(17132), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15232), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14399), 2,
      sym_comment,
      sym_block_comment,
  [615947] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17134), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615965] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(5114), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [615983] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14402), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8903), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
  [616001] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8907), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
  [616019] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17136), 1,
      anon_sym_COMMA,
    ACTIONS(16844), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(14404), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_case_definitions_repeat1,
  [616039] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14405), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17139), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [616057] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8623), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
  [616075] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17141), 1,
      anon_sym_COMMA,
    ACTIONS(17143), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15788), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14407), 2,
      sym_comment,
      sym_block_comment,
  [616101] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16712), 1,
      anon_sym_COMMA,
    STATE(14404), 1,
      aux_sym_enum_case_definitions_repeat1,
    STATE(14408), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16848), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [616123] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17145), 1,
      anon_sym_EQ,
    STATE(14409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16782), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [616143] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16192), 1,
      anon_sym_finally,
    STATE(13838), 1,
      sym_finally_clause,
    STATE(14410), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13286), 3,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_do,
  [616165] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    STATE(14190), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(17147), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14411), 2,
      sym_comment,
      sym_block_comment,
  [616189] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17149), 1,
      anon_sym_COMMA,
    ACTIONS(17151), 1,
      anon_sym_RPAREN,
    STATE(14735), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14412), 2,
      sym_comment,
      sym_block_comment,
  [616215] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17153), 1,
      anon_sym_COMMA,
    ACTIONS(17155), 1,
      anon_sym_RPAREN,
    STATE(15075), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14413), 2,
      sym_comment,
      sym_block_comment,
  [616241] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14414), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15547), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [616259] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13408), 1,
      anon_sym_COLON,
    STATE(14190), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15113), 1,
      sym_context_bound,
    ACTIONS(15958), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14415), 2,
      sym_comment,
      sym_block_comment,
  [616283] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    ACTIONS(17157), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14416), 2,
      sym_comment,
      sym_block_comment,
  [616307] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17159), 1,
      anon_sym_COMMA,
    ACTIONS(17161), 1,
      anon_sym_RPAREN,
    STATE(14760), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14417), 2,
      sym_comment,
      sym_block_comment,
  [616333] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17163), 1,
      anon_sym_LBRACE,
    ACTIONS(17165), 1,
      sym__indent,
    STATE(12959), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14418), 2,
      sym_comment,
      sym_block_comment,
  [616354] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17169), 1,
      anon_sym_COMMA,
    STATE(14617), 1,
      aux_sym_identifiers_repeat1,
    ACTIONS(17167), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    STATE(14419), 2,
      sym_comment,
      sym_block_comment,
  [616375] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16844), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [616392] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17173), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14421), 2,
      sym_comment,
      sym_block_comment,
  [616415] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17177), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14422), 2,
      sym_comment,
      sym_block_comment,
  [616438] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17179), 1,
      anon_sym_COMMA,
    STATE(14430), 1,
      aux_sym_derives_clause_repeat1,
    ACTIONS(15673), 2,
      anon_sym_COLON,
      anon_sym_LBRACE,
    STATE(14423), 2,
      sym_comment,
      sym_block_comment,
  [616459] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14424), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17181), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [616476] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(17183), 1,
      anon_sym_while,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14425), 2,
      sym_comment,
      sym_block_comment,
  [616499] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(661), 1,
      anon_sym_RBRACE,
    STATE(14463), 1,
      aux_sym__enum_block_repeat1,
    ACTIONS(17185), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14426), 2,
      sym_comment,
      sym_block_comment,
  [616520] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17187), 1,
      anon_sym_RBRACE,
    ACTIONS(17189), 1,
      anon_sym_case,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14427), 2,
      sym_comment,
      sym_block_comment,
  [616543] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17191), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14428), 2,
      sym_comment,
      sym_block_comment,
  [616566] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14429), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17026), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [616583] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17179), 1,
      anon_sym_COMMA,
    STATE(14515), 1,
      aux_sym_derives_clause_repeat1,
    ACTIONS(15838), 2,
      anon_sym_COLON,
      anon_sym_LBRACE,
    STATE(14430), 2,
      sym_comment,
      sym_block_comment,
  [616604] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14431), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17054), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [616621] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17193), 1,
      anon_sym_RBRACE,
    STATE(14435), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14432), 2,
      sym_comment,
      sym_block_comment,
  [616644] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17195), 1,
      anon_sym_LBRACE,
    ACTIONS(17197), 1,
      sym__indent,
    STATE(13398), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14433), 2,
      sym_comment,
      sym_block_comment,
  [616665] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17199), 1,
      anon_sym_case,
    ACTIONS(17202), 1,
      sym__outdent,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14434), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__indented_type_cases_repeat1,
  [616686] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17204), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14435), 2,
      sym_comment,
      sym_block_comment,
  [616709] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17206), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14436), 2,
      sym_comment,
      sym_block_comment,
  [616732] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17208), 1,
      anon_sym_LBRACE,
    ACTIONS(17210), 1,
      sym__indent,
    STATE(13927), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14437), 2,
      sym_comment,
      sym_block_comment,
  [616753] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17094), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [616770] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17212), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14439), 2,
      sym_comment,
      sym_block_comment,
  [616793] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17214), 1,
      anon_sym_LBRACE,
    ACTIONS(17216), 1,
      sym__indent,
    STATE(12004), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14440), 2,
      sym_comment,
      sym_block_comment,
  [616814] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17218), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14441), 2,
      sym_comment,
      sym_block_comment,
  [616837] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14442), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16690), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [616854] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14443), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17116), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [616871] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14444), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16760), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [616888] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17220), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14445), 2,
      sym_comment,
      sym_block_comment,
  [616911] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17222), 1,
      anon_sym_RBRACE,
    STATE(14427), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14446), 2,
      sym_comment,
      sym_block_comment,
  [616934] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14447), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16829), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [616951] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14448), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16786), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [616968] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17224), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14449), 2,
      sym_comment,
      sym_block_comment,
  [616991] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17226), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14450), 2,
      sym_comment,
      sym_block_comment,
  [617014] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16272), 1,
      sym__outdent,
    STATE(14516), 1,
      aux_sym__enum_block_repeat1,
    ACTIONS(16307), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14451), 2,
      sym_comment,
      sym_block_comment,
  [617035] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17228), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14452), 2,
      sym_comment,
      sym_block_comment,
  [617058] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17230), 1,
      anon_sym_LBRACE,
    ACTIONS(17232), 1,
      sym__indent,
    STATE(13817), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14453), 2,
      sym_comment,
      sym_block_comment,
  [617079] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17234), 1,
      anon_sym_EQ,
    STATE(14454), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16756), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [617098] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17122), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [617115] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14456), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17134), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [617132] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17236), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14457), 2,
      sym_comment,
      sym_block_comment,
  [617155] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14458), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15931), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [617172] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16637), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [617189] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17238), 1,
      anon_sym_RBRACE,
    STATE(14537), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14460), 2,
      sym_comment,
      sym_block_comment,
  [617212] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17240), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14461), 2,
      sym_comment,
      sym_block_comment,
  [617235] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17242), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14462), 2,
      sym_comment,
      sym_block_comment,
  [617258] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16445), 1,
      anon_sym_RBRACE,
    ACTIONS(17244), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14463), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__enum_block_repeat1,
  [617277] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17247), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14464), 2,
      sym_comment,
      sym_block_comment,
  [617300] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    ACTIONS(17249), 1,
      anon_sym_COLON,
    STATE(13330), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14465), 2,
      sym_comment,
      sym_block_comment,
  [617323] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17251), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14466), 2,
      sym_comment,
      sym_block_comment,
  [617346] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17253), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14467), 2,
      sym_comment,
      sym_block_comment,
  [617369] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17255), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14468), 2,
      sym_comment,
      sym_block_comment,
  [617392] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17257), 1,
      anon_sym_COMMA,
    ACTIONS(17259), 1,
      anon_sym_RPAREN,
    STATE(15290), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14469), 2,
      sym_comment,
      sym_block_comment,
  [617415] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16850), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [617432] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17261), 1,
      anon_sym_EQ,
    STATE(14471), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16782), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [617451] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17263), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14472), 2,
      sym_comment,
      sym_block_comment,
  [617474] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16900), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [617491] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(17265), 1,
      anon_sym_while,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14474), 2,
      sym_comment,
      sym_block_comment,
  [617514] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17267), 1,
      anon_sym_LBRACE,
    ACTIONS(17269), 1,
      sym__indent,
    STATE(13175), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14475), 2,
      sym_comment,
      sym_block_comment,
  [617535] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(471), 1,
      ts_builtin_sym_end,
    STATE(14621), 1,
      aux_sym_compilation_unit_repeat1,
    ACTIONS(17271), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14476), 2,
      sym_comment,
      sym_block_comment,
  [617556] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(17273), 1,
      anon_sym_while,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14477), 2,
      sym_comment,
      sym_block_comment,
  [617579] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16344), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [617596] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17275), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14479), 2,
      sym_comment,
      sym_block_comment,
  [617619] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14480), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7166), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_do,
      anon_sym_yield,
  [617636] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7176), 1,
      sym__outdent,
    ACTIONS(17277), 1,
      anon_sym_SEMI,
    ACTIONS(17279), 1,
      sym__automatic_semicolon,
    STATE(14601), 1,
      aux_sym_enumerators_repeat1,
    STATE(14481), 2,
      sym_comment,
      sym_block_comment,
  [617659] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(443), 1,
      ts_builtin_sym_end,
    STATE(14551), 1,
      aux_sym_compilation_unit_repeat1,
    ACTIONS(17281), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14482), 2,
      sym_comment,
      sym_block_comment,
  [617680] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(647), 1,
      anon_sym_RBRACE,
    STATE(14524), 1,
      aux_sym__block_repeat1,
    ACTIONS(17283), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14483), 2,
      sym_comment,
      sym_block_comment,
  [617701] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17285), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14484), 2,
      sym_comment,
      sym_block_comment,
  [617724] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(17287), 1,
      anon_sym_while,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14485), 2,
      sym_comment,
      sym_block_comment,
  [617747] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_LBRACE,
    ACTIONS(17291), 1,
      sym__indent,
    STATE(13092), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14486), 2,
      sym_comment,
      sym_block_comment,
  [617768] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16762), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [617785] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17230), 1,
      anon_sym_LBRACE,
    ACTIONS(17232), 1,
      sym__indent,
    STATE(13641), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14488), 2,
      sym_comment,
      sym_block_comment,
  [617806] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(435), 1,
      ts_builtin_sym_end,
    STATE(14476), 1,
      aux_sym_compilation_unit_repeat1,
    ACTIONS(17293), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14489), 2,
      sym_comment,
      sym_block_comment,
  [617827] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16344), 1,
      sym__outdent,
    ACTIONS(17295), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14490), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__block_repeat1,
  [617846] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17298), 1,
      anon_sym_RBRACE,
    ACTIONS(17300), 1,
      anon_sym_case,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14491), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_indented_cases_repeat1,
  [617867] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8080), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_LPAREN,
  [617884] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17303), 1,
      anon_sym_RBRACE,
    STATE(14583), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14493), 2,
      sym_comment,
      sym_block_comment,
  [617907] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17305), 1,
      anon_sym_EQ,
    STATE(14494), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16732), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [617926] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17307), 1,
      anon_sym_LBRACE,
    ACTIONS(17309), 1,
      sym__indent,
    STATE(13930), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14495), 2,
      sym_comment,
      sym_block_comment,
  [617947] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14496), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17008), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [617964] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17311), 1,
      anon_sym_RBRACE,
    STATE(14573), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14497), 2,
      sym_comment,
      sym_block_comment,
  [617987] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17313), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14498), 2,
      sym_comment,
      sym_block_comment,
  [618010] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16692), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [618027] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17315), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14500), 2,
      sym_comment,
      sym_block_comment,
  [618050] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17319), 1,
      anon_sym_EQ,
    ACTIONS(17317), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14501), 2,
      sym_comment,
      sym_block_comment,
  [618071] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16969), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [618088] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16973), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [618105] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14504), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16984), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [618122] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14505), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17046), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [618139] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17321), 1,
      anon_sym_LBRACE,
    ACTIONS(17323), 1,
      sym__indent,
    STATE(12419), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14506), 2,
      sym_comment,
      sym_block_comment,
  [618160] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(17325), 1,
      anon_sym_while,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14507), 2,
      sym_comment,
      sym_block_comment,
  [618183] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17329), 1,
      anon_sym_EQ,
    ACTIONS(17327), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14508), 2,
      sym_comment,
      sym_block_comment,
  [618204] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17333), 1,
      anon_sym_EQ,
    ACTIONS(17331), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14509), 2,
      sym_comment,
      sym_block_comment,
  [618225] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17335), 1,
      anon_sym_LBRACE,
    ACTIONS(17337), 1,
      sym__indent,
    STATE(11553), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14510), 2,
      sym_comment,
      sym_block_comment,
  [618246] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14511), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17002), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [618263] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17084), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [618280] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17339), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14513), 2,
      sym_comment,
      sym_block_comment,
  [618303] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17341), 1,
      anon_sym_LBRACE,
    ACTIONS(17343), 1,
      sym__indent,
    STATE(11956), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14514), 2,
      sym_comment,
      sym_block_comment,
  [618324] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17345), 1,
      anon_sym_COMMA,
    ACTIONS(15736), 2,
      anon_sym_COLON,
      anon_sym_LBRACE,
    STATE(14515), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_derives_clause_repeat1,
  [618343] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(661), 1,
      sym__outdent,
    STATE(14562), 1,
      aux_sym__enum_block_repeat1,
    ACTIONS(17348), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14516), 2,
      sym_comment,
      sym_block_comment,
  [618364] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16344), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [618381] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16276), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_if,
      anon_sym_SEMI,
  [618398] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17350), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14519), 2,
      sym_comment,
      sym_block_comment,
  [618421] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14520), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17181), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [618438] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17352), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14521), 2,
      sym_comment,
      sym_block_comment,
  [618461] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(17354), 1,
      anon_sym_while,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14522), 2,
      sym_comment,
      sym_block_comment,
  [618484] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17356), 1,
      anon_sym_RBRACE,
    STATE(14572), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14523), 2,
      sym_comment,
      sym_block_comment,
  [618507] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16344), 1,
      anon_sym_RBRACE,
    ACTIONS(17358), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14524), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__block_repeat1,
  [618526] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17208), 1,
      anon_sym_LBRACE,
    ACTIONS(17210), 1,
      sym__indent,
    STATE(13980), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14525), 2,
      sym_comment,
      sym_block_comment,
  [618547] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17361), 1,
      anon_sym_LBRACE,
    ACTIONS(17363), 1,
      sym__indent,
    STATE(13437), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14526), 2,
      sym_comment,
      sym_block_comment,
  [618568] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17365), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14527), 2,
      sym_comment,
      sym_block_comment,
  [618591] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17100), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [618608] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17367), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14529), 2,
      sym_comment,
      sym_block_comment,
  [618631] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17369), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14530), 2,
      sym_comment,
      sym_block_comment,
  [618654] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17341), 1,
      anon_sym_LBRACE,
    ACTIONS(17343), 1,
      sym__indent,
    STATE(11883), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14531), 2,
      sym_comment,
      sym_block_comment,
  [618675] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17371), 1,
      anon_sym_RBRACE,
    STATE(14613), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14532), 2,
      sym_comment,
      sym_block_comment,
  [618698] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14533), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16744), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [618715] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17373), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14534), 2,
      sym_comment,
      sym_block_comment,
  [618738] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17375), 1,
      anon_sym_LBRACE,
    ACTIONS(17377), 1,
      sym__indent,
    STATE(12926), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14535), 2,
      sym_comment,
      sym_block_comment,
  [618759] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17379), 1,
      anon_sym_RBRACE,
    STATE(14706), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14536), 2,
      sym_comment,
      sym_block_comment,
  [618782] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17381), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14537), 2,
      sym_comment,
      sym_block_comment,
  [618805] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17383), 1,
      anon_sym_COMMA,
    ACTIONS(17385), 1,
      anon_sym_RPAREN,
    STATE(15552), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14538), 2,
      sym_comment,
      sym_block_comment,
  [618828] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17387), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14539), 2,
      sym_comment,
      sym_block_comment,
  [618851] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16594), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14540), 2,
      sym_comment,
      sym_block_comment,
  [618874] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_SEMI,
    ACTIONS(17389), 1,
      sym__automatic_semicolon,
    ACTIONS(17391), 1,
      sym__outdent,
    STATE(14481), 1,
      aux_sym_enumerators_repeat1,
    STATE(14541), 2,
      sym_comment,
      sym_block_comment,
  [618897] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16906), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [618914] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17395), 1,
      anon_sym_EQ,
    ACTIONS(17393), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14543), 2,
      sym_comment,
      sym_block_comment,
  [618935] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17397), 1,
      anon_sym_EQ,
    STATE(14544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16724), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [618954] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14545), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16665), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [618971] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    ACTIONS(17399), 1,
      anon_sym_COLON,
    STATE(13330), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14546), 2,
      sym_comment,
      sym_block_comment,
  [618994] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(17401), 1,
      anon_sym_while,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14547), 2,
      sym_comment,
      sym_block_comment,
  [619017] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17307), 1,
      anon_sym_LBRACE,
    ACTIONS(17309), 1,
      sym__indent,
    STATE(13851), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14548), 2,
      sym_comment,
      sym_block_comment,
  [619038] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17403), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_do,
      anon_sym_yield,
  [619055] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17405), 1,
      anon_sym_RBRACE,
    STATE(14498), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14550), 2,
      sym_comment,
      sym_block_comment,
  [619078] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(435), 1,
      ts_builtin_sym_end,
    STATE(14621), 1,
      aux_sym_compilation_unit_repeat1,
    ACTIONS(17293), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14551), 2,
      sym_comment,
      sym_block_comment,
  [619099] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    ACTIONS(17407), 1,
      anon_sym_COLON,
    STATE(13330), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14552), 2,
      sym_comment,
      sym_block_comment,
  [619122] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16806), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [619139] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17409), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14554), 2,
      sym_comment,
      sym_block_comment,
  [619162] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16808), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [619179] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17411), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14556), 2,
      sym_comment,
      sym_block_comment,
  [619202] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17413), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14557), 2,
      sym_comment,
      sym_block_comment,
  [619225] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14558), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16823), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [619242] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17415), 1,
      anon_sym_COLON,
    ACTIONS(17419), 1,
      anon_sym_EQ,
    ACTIONS(17417), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14559), 2,
      sym_comment,
      sym_block_comment,
  [619263] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17421), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14560), 2,
      sym_comment,
      sym_block_comment,
  [619286] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17423), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14561), 2,
      sym_comment,
      sym_block_comment,
  [619309] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16445), 1,
      sym__outdent,
    ACTIONS(17425), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14562), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__enum_block_repeat1,
  [619328] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14563), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16835), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [619345] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17214), 1,
      anon_sym_LBRACE,
    ACTIONS(17216), 1,
      sym__indent,
    STATE(11986), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14564), 2,
      sym_comment,
      sym_block_comment,
  [619366] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16516), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14565), 2,
      sym_comment,
      sym_block_comment,
  [619389] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17428), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14566), 2,
      sym_comment,
      sym_block_comment,
  [619412] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17430), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14567), 2,
      sym_comment,
      sym_block_comment,
  [619435] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16846), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [619452] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17432), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14569), 2,
      sym_comment,
      sym_block_comment,
  [619475] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16611), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14570), 2,
      sym_comment,
      sym_block_comment,
  [619498] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16476), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14571), 2,
      sym_comment,
      sym_block_comment,
  [619521] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17434), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14572), 2,
      sym_comment,
      sym_block_comment,
  [619544] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17436), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14573), 2,
      sym_comment,
      sym_block_comment,
  [619567] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17438), 1,
      anon_sym_COMMA,
    ACTIONS(17440), 1,
      anon_sym_RPAREN,
    STATE(15385), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14574), 2,
      sym_comment,
      sym_block_comment,
  [619590] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17442), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14575), 2,
      sym_comment,
      sym_block_comment,
  [619613] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17444), 1,
      anon_sym_COMMA,
    ACTIONS(17447), 2,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(14576), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_tuple_type_repeat1,
  [619632] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17449), 1,
      anon_sym_LBRACE,
    ACTIONS(17451), 1,
      sym__indent,
    STATE(13699), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14577), 2,
      sym_comment,
      sym_block_comment,
  [619653] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17453), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14578), 2,
      sym_comment,
      sym_block_comment,
  [619676] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17455), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_do,
      anon_sym_yield,
  [619693] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17267), 1,
      anon_sym_LBRACE,
    ACTIONS(17269), 1,
      sym__indent,
    STATE(13264), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14580), 2,
      sym_comment,
      sym_block_comment,
  [619714] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17457), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14581), 2,
      sym_comment,
      sym_block_comment,
  [619737] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17459), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14582), 2,
      sym_comment,
      sym_block_comment,
  [619760] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17461), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14583), 2,
      sym_comment,
      sym_block_comment,
  [619783] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17463), 1,
      anon_sym_RBRACE,
    STATE(14534), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14584), 2,
      sym_comment,
      sym_block_comment,
  [619806] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17465), 1,
      anon_sym_LBRACE,
    ACTIONS(17467), 1,
      sym__indent,
    STATE(12581), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14585), 2,
      sym_comment,
      sym_block_comment,
  [619827] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(17469), 1,
      anon_sym_while,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14586), 2,
      sym_comment,
      sym_block_comment,
  [619850] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17471), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14587), 2,
      sym_comment,
      sym_block_comment,
  [619873] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(17473), 1,
      anon_sym_while,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14588), 2,
      sym_comment,
      sym_block_comment,
  [619896] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17475), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14589), 2,
      sym_comment,
      sym_block_comment,
  [619919] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16839), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [619936] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16560), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14591), 2,
      sym_comment,
      sym_block_comment,
  [619959] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16486), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14592), 2,
      sym_comment,
      sym_block_comment,
  [619982] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17477), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14593), 2,
      sym_comment,
      sym_block_comment,
  [620005] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14594), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16967), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [620022] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17479), 1,
      anon_sym_LBRACE,
    ACTIONS(17481), 1,
      sym__indent,
    STATE(13445), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14595), 2,
      sym_comment,
      sym_block_comment,
  [620043] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17483), 1,
      anon_sym_COLON,
    ACTIONS(17487), 1,
      anon_sym_EQ,
    ACTIONS(17485), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14596), 2,
      sym_comment,
      sym_block_comment,
  [620064] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16780), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [620081] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10404), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [620098] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16854), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [620115] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16837), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [620132] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16459), 1,
      sym__outdent,
    ACTIONS(17489), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14601), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enumerators_repeat1,
  [620151] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14602), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16892), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [620168] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    ACTIONS(17492), 1,
      anon_sym_COLON,
    STATE(13330), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14603), 2,
      sym_comment,
      sym_block_comment,
  [620191] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16837), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [620208] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17494), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14605), 2,
      sym_comment,
      sym_block_comment,
  [620231] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(17496), 1,
      anon_sym_while,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14606), 2,
      sym_comment,
      sym_block_comment,
  [620254] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17498), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14607), 2,
      sym_comment,
      sym_block_comment,
  [620277] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16884), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [620294] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(17500), 1,
      anon_sym_while,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14609), 2,
      sym_comment,
      sym_block_comment,
  [620317] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14610), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16975), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [620334] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14611), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16884), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [620351] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16975), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [620368] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17502), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14613), 2,
      sym_comment,
      sym_block_comment,
  [620391] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17479), 1,
      anon_sym_LBRACE,
    ACTIONS(17481), 1,
      sym__indent,
    STATE(13497), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14614), 2,
      sym_comment,
      sym_block_comment,
  [620412] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17163), 1,
      anon_sym_LBRACE,
    ACTIONS(17165), 1,
      sym__indent,
    STATE(12753), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14615), 2,
      sym_comment,
      sym_block_comment,
  [620433] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17504), 1,
      anon_sym_RBRACE,
    STATE(14682), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14616), 2,
      sym_comment,
      sym_block_comment,
  [620456] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17508), 1,
      anon_sym_COMMA,
    ACTIONS(17506), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    STATE(14617), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_identifiers_repeat1,
  [620475] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17375), 1,
      anon_sym_LBRACE,
    ACTIONS(17377), 1,
      sym__indent,
    STATE(12893), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14618), 2,
      sym_comment,
      sym_block_comment,
  [620496] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14619), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16977), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [620513] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9735), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_LPAREN,
  [620530] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17511), 1,
      ts_builtin_sym_end,
    ACTIONS(17513), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14621), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compilation_unit_repeat1,
  [620549] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16979), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [620566] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17516), 1,
      anon_sym_LBRACE,
    ACTIONS(17518), 1,
      sym__indent,
    STATE(13613), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14623), 2,
      sym_comment,
      sym_block_comment,
  [620587] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17520), 1,
      anon_sym_LBRACE,
    ACTIONS(17522), 1,
      sym__indent,
    STATE(13716), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14624), 2,
      sym_comment,
      sym_block_comment,
  [620608] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16474), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LT_PERCENT,
  [620625] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17524), 1,
      anon_sym_COLON,
    ACTIONS(17527), 1,
      anon_sym_COMMA,
    ACTIONS(17530), 1,
      anon_sym_EQ,
    STATE(14419), 1,
      aux_sym_identifiers_repeat1,
    STATE(14626), 2,
      sym_comment,
      sym_block_comment,
  [620648] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17532), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14627), 2,
      sym_comment,
      sym_block_comment,
  [620671] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16890), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [620688] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16896), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [620705] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15944), 1,
      sym__outdent,
    STATE(14683), 1,
      aux_sym__block_repeat1,
    ACTIONS(16380), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14630), 2,
      sym_comment,
      sym_block_comment,
  [620726] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17516), 1,
      anon_sym_LBRACE,
    ACTIONS(17518), 1,
      sym__indent,
    STATE(13405), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14631), 2,
      sym_comment,
      sym_block_comment,
  [620747] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17534), 1,
      anon_sym_RBRACE,
    STATE(14575), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14632), 2,
      sym_comment,
      sym_block_comment,
  [620770] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    ACTIONS(17536), 1,
      anon_sym_COLON,
    STATE(13330), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14633), 2,
      sym_comment,
      sym_block_comment,
  [620793] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14535), 1,
      anon_sym_LPAREN,
    ACTIONS(17538), 1,
      sym__automatic_semicolon,
    STATE(13761), 1,
      aux_sym__full_enum_def_repeat1,
    STATE(14220), 1,
      sym_class_parameters,
    STATE(14634), 2,
      sym_comment,
      sym_block_comment,
  [620816] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16971), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [620833] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16617), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14636), 2,
      sym_comment,
      sym_block_comment,
  [620856] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17540), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14637), 2,
      sym_comment,
      sym_block_comment,
  [620879] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14638), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16894), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [620896] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17542), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14639), 2,
      sym_comment,
      sym_block_comment,
  [620919] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17544), 1,
      anon_sym_RBRACE,
    STATE(14450), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14640), 2,
      sym_comment,
      sym_block_comment,
  [620942] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15931), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [620959] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17546), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14642), 2,
      sym_comment,
      sym_block_comment,
  [620982] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16547), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14643), 2,
      sym_comment,
      sym_block_comment,
  [621005] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17548), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14644), 2,
      sym_comment,
      sym_block_comment,
  [621028] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17550), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14645), 2,
      sym_comment,
      sym_block_comment,
  [621051] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(17552), 1,
      anon_sym_while,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14646), 2,
      sym_comment,
      sym_block_comment,
  [621074] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17465), 1,
      anon_sym_LBRACE,
    ACTIONS(17467), 1,
      sym__indent,
    STATE(12609), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14647), 2,
      sym_comment,
      sym_block_comment,
  [621095] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17554), 1,
      anon_sym_RBRACE,
    STATE(14581), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14648), 2,
      sym_comment,
      sym_block_comment,
  [621118] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17048), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [621135] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17558), 1,
      anon_sym_EQ,
    ACTIONS(17556), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14650), 2,
      sym_comment,
      sym_block_comment,
  [621156] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17321), 1,
      anon_sym_LBRACE,
    ACTIONS(17323), 1,
      sym__indent,
    STATE(12454), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14651), 2,
      sym_comment,
      sym_block_comment,
  [621177] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17560), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14652), 2,
      sym_comment,
      sym_block_comment,
  [621200] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(17562), 1,
      anon_sym_while,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14653), 2,
      sym_comment,
      sym_block_comment,
  [621223] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17564), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LT_PERCENT,
  [621240] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16272), 1,
      anon_sym_RBRACE,
    STATE(14426), 1,
      aux_sym__enum_block_repeat1,
    ACTIONS(16274), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14655), 2,
      sym_comment,
      sym_block_comment,
  [621261] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17566), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14656), 2,
      sym_comment,
      sym_block_comment,
  [621284] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17568), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14657), 2,
      sym_comment,
      sym_block_comment,
  [621307] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17570), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14658), 2,
      sym_comment,
      sym_block_comment,
  [621330] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17572), 1,
      anon_sym_COLON,
    ACTIONS(17576), 1,
      anon_sym_EQ,
    ACTIONS(17574), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14659), 2,
      sym_comment,
      sym_block_comment,
  [621351] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16518), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14660), 2,
      sym_comment,
      sym_block_comment,
  [621374] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17578), 1,
      anon_sym_RBRACE,
    STATE(14690), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14661), 2,
      sym_comment,
      sym_block_comment,
  [621397] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17580), 1,
      anon_sym_RBRACE,
    STATE(14582), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14662), 2,
      sym_comment,
      sym_block_comment,
  [621420] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16488), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14663), 2,
      sym_comment,
      sym_block_comment,
  [621443] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16852), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [621460] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17584), 1,
      anon_sym_EQ,
    ACTIONS(17582), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14665), 2,
      sym_comment,
      sym_block_comment,
  [621481] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17335), 1,
      anon_sym_LBRACE,
    ACTIONS(17337), 1,
      sym__indent,
    STATE(11565), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14666), 2,
      sym_comment,
      sym_block_comment,
  [621502] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17586), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14667), 2,
      sym_comment,
      sym_block_comment,
  [621525] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17520), 1,
      anon_sym_LBRACE,
    ACTIONS(17522), 1,
      sym__indent,
    STATE(13777), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14668), 2,
      sym_comment,
      sym_block_comment,
  [621546] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16428), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14669), 2,
      sym_comment,
      sym_block_comment,
  [621569] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17588), 1,
      anon_sym_RBRACE,
    STATE(14479), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14670), 2,
      sym_comment,
      sym_block_comment,
  [621592] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16675), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [621609] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17590), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14672), 2,
      sym_comment,
      sym_block_comment,
  [621632] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17060), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [621649] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(17594), 1,
      anon_sym_EQ,
    ACTIONS(17592), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14674), 2,
      sym_comment,
      sym_block_comment,
  [621670] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17596), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14675), 2,
      sym_comment,
      sym_block_comment,
  [621693] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17064), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [621710] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15944), 1,
      anon_sym_RBRACE,
    STATE(14483), 1,
      aux_sym__block_repeat1,
    ACTIONS(16342), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14677), 2,
      sym_comment,
      sym_block_comment,
  [621731] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14678), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17082), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [621748] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17062), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [621765] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14680), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17598), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LT_PERCENT,
  [621782] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17600), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14681), 2,
      sym_comment,
      sym_block_comment,
  [621805] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17602), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14682), 2,
      sym_comment,
      sym_block_comment,
  [621828] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(647), 1,
      sym__outdent,
    STATE(14490), 1,
      aux_sym__block_repeat1,
    ACTIONS(17604), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14683), 2,
      sym_comment,
      sym_block_comment,
  [621849] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(17606), 1,
      anon_sym_while,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14684), 2,
      sym_comment,
      sym_block_comment,
  [621872] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17066), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [621889] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16615), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14686), 2,
      sym_comment,
      sym_block_comment,
  [621912] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16441), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14687), 2,
      sym_comment,
      sym_block_comment,
  [621935] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17608), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14688), 2,
      sym_comment,
      sym_block_comment,
  [621958] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17298), 1,
      sym__outdent,
    ACTIONS(17610), 1,
      anon_sym_case,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14689), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_indented_cases_repeat1,
  [621979] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17613), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14690), 2,
      sym_comment,
      sym_block_comment,
  [622002] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16609), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14691), 2,
      sym_comment,
      sym_block_comment,
  [622025] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17088), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [622042] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16482), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14693), 2,
      sym_comment,
      sym_block_comment,
  [622065] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14694), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16908), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [622082] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    ACTIONS(17615), 1,
      anon_sym_COLON,
    STATE(13330), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14695), 2,
      sym_comment,
      sym_block_comment,
  [622105] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17617), 1,
      anon_sym_COLON,
    ACTIONS(17621), 1,
      anon_sym_EQ,
    ACTIONS(17619), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14696), 2,
      sym_comment,
      sym_block_comment,
  [622126] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17124), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [622143] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17139), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [622160] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14699), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17086), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [622177] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(17623), 1,
      anon_sym_while,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14700), 2,
      sym_comment,
      sym_block_comment,
  [622200] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17625), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14701), 2,
      sym_comment,
      sym_block_comment,
  [622223] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16844), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [622240] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17195), 1,
      anon_sym_LBRACE,
    ACTIONS(17197), 1,
      sym__indent,
    STATE(13333), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14703), 2,
      sym_comment,
      sym_block_comment,
  [622261] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17092), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [622278] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(17627), 1,
      anon_sym_while,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14705), 2,
      sym_comment,
      sym_block_comment,
  [622301] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17629), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14706), 2,
      sym_comment,
      sym_block_comment,
  [622324] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16545), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14707), 2,
      sym_comment,
      sym_block_comment,
  [622347] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17361), 1,
      anon_sym_LBRACE,
    ACTIONS(17363), 1,
      sym__indent,
    STATE(13539), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14708), 2,
      sym_comment,
      sym_block_comment,
  [622368] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17631), 1,
      anon_sym_RBRACE,
    STATE(14468), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14709), 2,
      sym_comment,
      sym_block_comment,
  [622391] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17449), 1,
      anon_sym_LBRACE,
    ACTIONS(17451), 1,
      sym__indent,
    STATE(13680), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14710), 2,
      sym_comment,
      sym_block_comment,
  [622412] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    ACTIONS(17633), 1,
      sym__outdent,
    STATE(14434), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(14711), 2,
      sym_comment,
      sym_block_comment,
  [622435] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14401), 1,
      anon_sym_LPAREN,
    ACTIONS(17635), 1,
      sym__automatic_semicolon,
    STATE(13827), 1,
      aux_sym__full_enum_def_repeat1,
    STATE(14199), 1,
      sym_class_parameters,
    STATE(14712), 2,
      sym_comment,
      sym_block_comment,
  [622458] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16794), 1,
      anon_sym_EQ_GT,
    ACTIONS(16796), 1,
      anon_sym_as,
    ACTIONS(17637), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(14713), 2,
      sym_comment,
      sym_block_comment,
  [622479] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14714), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16910), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [622496] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_LBRACE,
    ACTIONS(17291), 1,
      sym__indent,
    STATE(13057), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14715), 2,
      sym_comment,
      sym_block_comment,
  [622517] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16928), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [622534] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16461), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14717), 2,
      sym_comment,
      sym_block_comment,
  [622557] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16663), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [622574] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    ACTIONS(17639), 1,
      sym__outdent,
    STATE(14689), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14719), 2,
      sym_comment,
      sym_block_comment,
  [622597] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(17641), 1,
      anon_sym_while,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14720), 2,
      sym_comment,
      sym_block_comment,
  [622620] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(17643), 1,
      anon_sym_while,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14721), 2,
      sym_comment,
      sym_block_comment,
  [622643] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4136), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
  [622660] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    ACTIONS(17645), 1,
      anon_sym_COLON,
    STATE(13330), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14723), 2,
      sym_comment,
      sym_block_comment,
  [622683] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16932), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [622700] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6938), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
  [622717] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17189), 1,
      anon_sym_case,
    ACTIONS(17647), 1,
      anon_sym_RBRACE,
    STATE(14491), 1,
      aux_sym_indented_cases_repeat1,
    STATE(15947), 1,
      sym_case_clause,
    STATE(14726), 2,
      sym_comment,
      sym_block_comment,
  [622740] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17000), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [622757] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16582), 1,
      anon_sym_RPAREN,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14728), 2,
      sym_comment,
      sym_block_comment,
  [622780] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17649), 1,
      anon_sym_DOT,
    STATE(14729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8006), 3,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
  [622799] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    ACTIONS(17651), 1,
      anon_sym_COLON,
    STATE(13330), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(14730), 2,
      sym_comment,
      sym_block_comment,
  [622822] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17036), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [622839] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17653), 1,
      anon_sym_COMMA,
    ACTIONS(17655), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14732), 2,
      sym_comment,
      sym_block_comment,
  [622859] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17657), 1,
      anon_sym_COMMA,
    ACTIONS(17659), 1,
      anon_sym_RPAREN,
    STATE(14847), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14733), 2,
      sym_comment,
      sym_block_comment,
  [622879] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17661), 1,
      anon_sym_COMMA,
    ACTIONS(17663), 1,
      anon_sym_RBRACK,
    STATE(14737), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14734), 2,
      sym_comment,
      sym_block_comment,
  [622899] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5478), 1,
      anon_sym_RPAREN,
    ACTIONS(17665), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14735), 2,
      sym_comment,
      sym_block_comment,
  [622919] = 6,
    ACTIONS(17667), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(17669), 1,
      sym__comment_text,
    ACTIONS(17671), 1,
      anon_sym_GT,
    ACTIONS(17673), 1,
      anon_sym_SLASH_STAR,
    STATE(17876), 1,
      sym_using_directive,
    STATE(14736), 2,
      sym_comment,
      sym_block_comment,
  [622939] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5338), 1,
      anon_sym_RBRACK,
    ACTIONS(17675), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14737), 2,
      sym_comment,
      sym_block_comment,
  [622959] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17677), 1,
      anon_sym_COMMA,
    ACTIONS(17679), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14738), 2,
      sym_comment,
      sym_block_comment,
  [622979] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17681), 1,
      anon_sym_COMMA,
    ACTIONS(17683), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14739), 2,
      sym_comment,
      sym_block_comment,
  [622999] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17685), 1,
      anon_sym_COMMA,
    ACTIONS(17687), 1,
      anon_sym_RBRACK,
    STATE(14743), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14740), 2,
      sym_comment,
      sym_block_comment,
  [623019] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15007), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(7490), 1,
      sym_type_arguments,
    STATE(14741), 2,
      sym_comment,
      sym_block_comment,
  [623039] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6048), 1,
      anon_sym_RPAREN,
    ACTIONS(17689), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14742), 2,
      sym_comment,
      sym_block_comment,
  [623059] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5360), 1,
      anon_sym_RBRACK,
    ACTIONS(17691), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14743), 2,
      sym_comment,
      sym_block_comment,
  [623079] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17693), 1,
      anon_sym_COMMA,
    ACTIONS(17695), 1,
      anon_sym_RPAREN,
    STATE(14864), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14744), 2,
      sym_comment,
      sym_block_comment,
  [623099] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17697), 1,
      anon_sym_COMMA,
    ACTIONS(17699), 1,
      anon_sym_RBRACK,
    STATE(14747), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14745), 2,
      sym_comment,
      sym_block_comment,
  [623119] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5492), 1,
      anon_sym_RPAREN,
    ACTIONS(17701), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14746), 2,
      sym_comment,
      sym_block_comment,
  [623139] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5384), 1,
      anon_sym_RBRACK,
    ACTIONS(17703), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14747), 2,
      sym_comment,
      sym_block_comment,
  [623159] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17705), 1,
      anon_sym_COMMA,
    ACTIONS(17707), 1,
      anon_sym_RBRACK,
    STATE(14774), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14748), 2,
      sym_comment,
      sym_block_comment,
  [623179] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(17711), 1,
      sym__interpolated_string_end,
    STATE(14770), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(14749), 2,
      sym_comment,
      sym_block_comment,
  [623199] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17711), 1,
      sym__interpolated_multiline_string_end,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    STATE(14771), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(14750), 2,
      sym_comment,
      sym_block_comment,
  [623219] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17715), 1,
      anon_sym_COMMA,
    ACTIONS(17717), 1,
      anon_sym_RPAREN,
    STATE(15584), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14751), 2,
      sym_comment,
      sym_block_comment,
  [623239] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17719), 1,
      anon_sym_COMMA,
    ACTIONS(17721), 1,
      anon_sym_RPAREN,
    STATE(15170), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14752), 2,
      sym_comment,
      sym_block_comment,
  [623259] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17723), 1,
      anon_sym_COMMA,
    ACTIONS(17725), 1,
      anon_sym_RBRACK,
    STATE(14756), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14753), 2,
      sym_comment,
      sym_block_comment,
  [623279] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12161), 1,
      sym__arrow_then_type,
    ACTIONS(17727), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(14754), 2,
      sym_comment,
      sym_block_comment,
  [623297] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6066), 1,
      anon_sym_RPAREN,
    ACTIONS(17729), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14755), 2,
      sym_comment,
      sym_block_comment,
  [623317] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5404), 1,
      anon_sym_RBRACK,
    ACTIONS(17731), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14756), 2,
      sym_comment,
      sym_block_comment,
  [623337] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17733), 1,
      anon_sym_COMMA,
    ACTIONS(17735), 1,
      anon_sym_RPAREN,
    STATE(15616), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14757), 2,
      sym_comment,
      sym_block_comment,
  [623357] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17737), 1,
      anon_sym_COMMA,
    ACTIONS(17739), 1,
      anon_sym_RBRACK,
    STATE(14832), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14758), 2,
      sym_comment,
      sym_block_comment,
  [623377] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17741), 1,
      anon_sym_COMMA,
    ACTIONS(17743), 1,
      anon_sym_RBRACK,
    STATE(14761), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14759), 2,
      sym_comment,
      sym_block_comment,
  [623397] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5512), 1,
      anon_sym_RPAREN,
    ACTIONS(17745), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14760), 2,
      sym_comment,
      sym_block_comment,
  [623417] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5422), 1,
      anon_sym_RBRACK,
    ACTIONS(17747), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14761), 2,
      sym_comment,
      sym_block_comment,
  [623437] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5376), 1,
      anon_sym_RPAREN,
    ACTIONS(17749), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14762), 2,
      sym_comment,
      sym_block_comment,
  [623457] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17751), 1,
      anon_sym_COMMA,
    ACTIONS(17753), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14763), 2,
      sym_comment,
      sym_block_comment,
  [623477] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17755), 1,
      anon_sym_COMMA,
    ACTIONS(17757), 1,
      anon_sym_RPAREN,
    STATE(15742), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14764), 2,
      sym_comment,
      sym_block_comment,
  [623497] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17759), 1,
      anon_sym_COMMA,
    ACTIONS(17761), 1,
      anon_sym_RBRACK,
    STATE(14767), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14765), 2,
      sym_comment,
      sym_block_comment,
  [623517] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5534), 1,
      anon_sym_RPAREN,
    ACTIONS(17763), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14766), 2,
      sym_comment,
      sym_block_comment,
  [623537] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5436), 1,
      anon_sym_RBRACK,
    ACTIONS(17765), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14767), 2,
      sym_comment,
      sym_block_comment,
  [623557] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17767), 1,
      anon_sym_COMMA,
    ACTIONS(17769), 1,
      anon_sym_RBRACK,
    STATE(14785), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14768), 2,
      sym_comment,
      sym_block_comment,
  [623577] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17771), 1,
      anon_sym_COMMA,
    ACTIONS(17773), 1,
      anon_sym_RPAREN,
    STATE(15788), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14769), 2,
      sym_comment,
      sym_block_comment,
  [623597] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(17775), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(14770), 2,
      sym_comment,
      sym_block_comment,
  [623617] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(17775), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(14771), 2,
      sym_comment,
      sym_block_comment,
  [623637] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17777), 1,
      anon_sym_COMMA,
    ACTIONS(17779), 1,
      anon_sym_RBRACK,
    STATE(14775), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14772), 2,
      sym_comment,
      sym_block_comment,
  [623657] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6084), 1,
      anon_sym_RPAREN,
    ACTIONS(17781), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14773), 2,
      sym_comment,
      sym_block_comment,
  [623677] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5756), 1,
      anon_sym_RBRACK,
    ACTIONS(17783), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14774), 2,
      sym_comment,
      sym_block_comment,
  [623697] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5448), 1,
      anon_sym_RBRACK,
    ACTIONS(17785), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14775), 2,
      sym_comment,
      sym_block_comment,
  [623717] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17787), 1,
      anon_sym_COMMA,
    ACTIONS(17789), 1,
      anon_sym_RBRACK,
    STATE(14858), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14776), 2,
      sym_comment,
      sym_block_comment,
  [623737] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5532), 1,
      anon_sym_RPAREN,
    ACTIONS(17791), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14777), 2,
      sym_comment,
      sym_block_comment,
  [623757] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17793), 1,
      anon_sym_COMMA,
    ACTIONS(17795), 1,
      anon_sym_RPAREN,
    STATE(14884), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14778), 2,
      sym_comment,
      sym_block_comment,
  [623777] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17797), 1,
      anon_sym_COMMA,
    ACTIONS(17799), 1,
      anon_sym_RBRACK,
    STATE(14860), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14779), 2,
      sym_comment,
      sym_block_comment,
  [623797] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17801), 1,
      anon_sym_COMMA,
    ACTIONS(17803), 1,
      anon_sym_RBRACK,
    STATE(14783), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14780), 2,
      sym_comment,
      sym_block_comment,
  [623817] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8072), 1,
      anon_sym_RPAREN,
    ACTIONS(17805), 1,
      anon_sym_COMMA,
    STATE(15198), 1,
      aux_sym_class_parameters_repeat1,
    STATE(14781), 2,
      sym_comment,
      sym_block_comment,
  [623837] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5554), 1,
      anon_sym_RPAREN,
    ACTIONS(17807), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14782), 2,
      sym_comment,
      sym_block_comment,
  [623857] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5468), 1,
      anon_sym_RBRACK,
    ACTIONS(17809), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14783), 2,
      sym_comment,
      sym_block_comment,
  [623877] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(17811), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(14784), 2,
      sym_comment,
      sym_block_comment,
  [623897] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5770), 1,
      anon_sym_RBRACK,
    ACTIONS(17813), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14785), 2,
      sym_comment,
      sym_block_comment,
  [623917] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17815), 1,
      anon_sym_COMMA,
    ACTIONS(17817), 1,
      anon_sym_RPAREN,
    STATE(14735), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14786), 2,
      sym_comment,
      sym_block_comment,
  [623937] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4282), 1,
      sym__indent,
    STATE(7520), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(14787), 2,
      sym_comment,
      sym_block_comment,
  [623955] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17819), 1,
      anon_sym_COMMA,
    ACTIONS(17821), 1,
      anon_sym_RBRACK,
    STATE(14790), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14788), 2,
      sym_comment,
      sym_block_comment,
  [623975] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5566), 1,
      anon_sym_RPAREN,
    ACTIONS(17823), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14789), 2,
      sym_comment,
      sym_block_comment,
  [623995] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5480), 1,
      anon_sym_RBRACK,
    ACTIONS(17825), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14790), 2,
      sym_comment,
      sym_block_comment,
  [624015] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(17827), 1,
      sym__interpolated_string_end,
    STATE(15532), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(14791), 2,
      sym_comment,
      sym_block_comment,
  [624035] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(17811), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(14792), 2,
      sym_comment,
      sym_block_comment,
  [624055] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17829), 1,
      anon_sym_COMMA,
    ACTIONS(17831), 1,
      anon_sym_RPAREN,
    STATE(14746), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14793), 2,
      sym_comment,
      sym_block_comment,
  [624075] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17833), 1,
      anon_sym_COMMA,
    ACTIONS(17835), 1,
      anon_sym_RPAREN,
    STATE(14777), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14794), 2,
      sym_comment,
      sym_block_comment,
  [624095] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(17837), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(14795), 2,
      sym_comment,
      sym_block_comment,
  [624115] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17839), 1,
      anon_sym_COMMA,
    ACTIONS(17841), 1,
      anon_sym_RBRACK,
    STATE(14799), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14796), 2,
      sym_comment,
      sym_block_comment,
  [624135] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(17837), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(14797), 2,
      sym_comment,
      sym_block_comment,
  [624155] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5588), 1,
      anon_sym_RPAREN,
    ACTIONS(17843), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14798), 2,
      sym_comment,
      sym_block_comment,
  [624175] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5496), 1,
      anon_sym_RBRACK,
    ACTIONS(17845), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14799), 2,
      sym_comment,
      sym_block_comment,
  [624195] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11755), 1,
      anon_sym_RPAREN,
    ACTIONS(17847), 1,
      anon_sym_COMMA,
    STATE(14800), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_case_class_pattern_repeat1,
  [624213] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12707), 1,
      anon_sym_RPAREN,
    ACTIONS(17850), 1,
      anon_sym_COMMA,
    STATE(15210), 1,
      aux_sym_parameters_repeat1,
    STATE(14801), 2,
      sym_comment,
      sym_block_comment,
  [624233] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17852), 1,
      anon_sym_COMMA,
    ACTIONS(17854), 1,
      anon_sym_RPAREN,
    STATE(14760), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14802), 2,
      sym_comment,
      sym_block_comment,
  [624253] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5936), 1,
      anon_sym_RPAREN,
    ACTIONS(17856), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14803), 2,
      sym_comment,
      sym_block_comment,
  [624273] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17858), 1,
      anon_sym_COMMA,
    ACTIONS(17860), 1,
      anon_sym_RBRACK,
    STATE(14806), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14804), 2,
      sym_comment,
      sym_block_comment,
  [624293] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5606), 1,
      anon_sym_RPAREN,
    ACTIONS(17862), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14805), 2,
      sym_comment,
      sym_block_comment,
  [624313] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5516), 1,
      anon_sym_RBRACK,
    ACTIONS(17864), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14806), 2,
      sym_comment,
      sym_block_comment,
  [624333] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5368), 1,
      anon_sym_RPAREN,
    ACTIONS(17866), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14807), 2,
      sym_comment,
      sym_block_comment,
  [624353] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7300), 1,
      anon_sym_RPAREN,
    ACTIONS(17868), 1,
      anon_sym_COMMA,
    STATE(14800), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(14808), 2,
      sym_comment,
      sym_block_comment,
  [624373] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17870), 1,
      anon_sym_COMMA,
    ACTIONS(17872), 1,
      anon_sym_RPAREN,
    STATE(14766), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14809), 2,
      sym_comment,
      sym_block_comment,
  [624393] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17874), 1,
      anon_sym_COMMA,
    ACTIONS(17876), 1,
      anon_sym_RBRACK,
    STATE(14813), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14810), 2,
      sym_comment,
      sym_block_comment,
  [624413] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5630), 1,
      anon_sym_RPAREN,
    ACTIONS(17878), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14811), 2,
      sym_comment,
      sym_block_comment,
  [624433] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17880), 1,
      anon_sym_COMMA,
    ACTIONS(17882), 1,
      anon_sym_RPAREN,
    STATE(15565), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14812), 2,
      sym_comment,
      sym_block_comment,
  [624453] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5536), 1,
      anon_sym_RBRACK,
    ACTIONS(17884), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14813), 2,
      sym_comment,
      sym_block_comment,
  [624473] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15615), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(8908), 1,
      sym_type_arguments,
    STATE(14814), 2,
      sym_comment,
      sym_block_comment,
  [624493] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17886), 1,
      anon_sym_COMMA,
    ACTIONS(17888), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(14815), 2,
      sym_comment,
      sym_block_comment,
  [624513] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17890), 1,
      anon_sym_COMMA,
    ACTIONS(17892), 1,
      anon_sym_RPAREN,
    STATE(14782), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14816), 2,
      sym_comment,
      sym_block_comment,
  [624533] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17894), 1,
      anon_sym_COMMA,
    ACTIONS(17896), 1,
      anon_sym_RBRACK,
    STATE(14819), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14817), 2,
      sym_comment,
      sym_block_comment,
  [624553] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5272), 1,
      anon_sym_RPAREN,
    ACTIONS(17898), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14818), 2,
      sym_comment,
      sym_block_comment,
  [624573] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5556), 1,
      anon_sym_RBRACK,
    ACTIONS(17900), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14819), 2,
      sym_comment,
      sym_block_comment,
  [624593] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17902), 1,
      anon_sym_COMMA,
    ACTIONS(17904), 1,
      anon_sym_RBRACK,
    STATE(14842), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14820), 2,
      sym_comment,
      sym_block_comment,
  [624613] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17906), 1,
      anon_sym_COMMA,
    ACTIONS(17908), 1,
      anon_sym_RPAREN,
    STATE(14789), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14821), 2,
      sym_comment,
      sym_block_comment,
  [624633] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(17910), 1,
      sym__interpolated_string_end,
    STATE(14852), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(14822), 2,
      sym_comment,
      sym_block_comment,
  [624653] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17912), 1,
      anon_sym_COMMA,
    ACTIONS(17914), 1,
      anon_sym_RBRACK,
    STATE(14826), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14823), 2,
      sym_comment,
      sym_block_comment,
  [624673] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5674), 1,
      anon_sym_RPAREN,
    ACTIONS(17916), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14824), 2,
      sym_comment,
      sym_block_comment,
  [624693] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6020), 1,
      anon_sym_RPAREN,
    ACTIONS(17918), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14825), 2,
      sym_comment,
      sym_block_comment,
  [624713] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5570), 1,
      anon_sym_RBRACK,
    ACTIONS(17920), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14826), 2,
      sym_comment,
      sym_block_comment,
  [624733] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(17910), 1,
      sym__interpolated_multiline_string_end,
    STATE(14854), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(14827), 2,
      sym_comment,
      sym_block_comment,
  [624753] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17922), 1,
      anon_sym_COMMA,
    ACTIONS(17924), 1,
      anon_sym_RPAREN,
    STATE(15513), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14828), 2,
      sym_comment,
      sym_block_comment,
  [624773] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12579), 1,
      sym__arrow_then_type,
    ACTIONS(17926), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(14829), 2,
      sym_comment,
      sym_block_comment,
  [624791] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17928), 1,
      anon_sym_COMMA,
    ACTIONS(17930), 1,
      anon_sym_RPAREN,
    STATE(14798), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14830), 2,
      sym_comment,
      sym_block_comment,
  [624811] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6074), 1,
      anon_sym_RPAREN,
    ACTIONS(17932), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14831), 2,
      sym_comment,
      sym_block_comment,
  [624831] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5330), 1,
      anon_sym_RBRACK,
    ACTIONS(17934), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14832), 2,
      sym_comment,
      sym_block_comment,
  [624851] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17936), 1,
      anon_sym_COMMA,
    ACTIONS(17938), 1,
      anon_sym_RBRACK,
    STATE(14835), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14833), 2,
      sym_comment,
      sym_block_comment,
  [624871] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5294), 1,
      anon_sym_RPAREN,
    ACTIONS(17940), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14834), 2,
      sym_comment,
      sym_block_comment,
  [624891] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5592), 1,
      anon_sym_RBRACK,
    ACTIONS(17942), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14835), 2,
      sym_comment,
      sym_block_comment,
  [624911] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5220), 1,
      anon_sym_RPAREN,
    ACTIONS(17944), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14836), 2,
      sym_comment,
      sym_block_comment,
  [624931] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14837), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17511), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [624947] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(17827), 1,
      sym__interpolated_multiline_string_end,
    STATE(15598), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(14838), 2,
      sym_comment,
      sym_block_comment,
  [624967] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17946), 1,
      anon_sym_COMMA,
    ACTIONS(17948), 1,
      anon_sym_RPAREN,
    STATE(14805), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14839), 2,
      sym_comment,
      sym_block_comment,
  [624987] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17950), 1,
      anon_sym_COMMA,
    ACTIONS(17952), 1,
      anon_sym_RBRACK,
    STATE(14843), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14840), 2,
      sym_comment,
      sym_block_comment,
  [625007] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5688), 1,
      anon_sym_RPAREN,
    ACTIONS(17954), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14841), 2,
      sym_comment,
      sym_block_comment,
  [625027] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5790), 1,
      anon_sym_RBRACK,
    ACTIONS(17956), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14842), 2,
      sym_comment,
      sym_block_comment,
  [625047] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5610), 1,
      anon_sym_RBRACK,
    ACTIONS(17958), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14843), 2,
      sym_comment,
      sym_block_comment,
  [625067] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17960), 1,
      anon_sym_COMMA,
    ACTIONS(17962), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14844), 2,
      sym_comment,
      sym_block_comment,
  [625087] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17964), 1,
      anon_sym_COMMA,
    ACTIONS(17966), 1,
      anon_sym_RPAREN,
    STATE(14811), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14845), 2,
      sym_comment,
      sym_block_comment,
  [625107] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17968), 1,
      anon_sym_COMMA,
    ACTIONS(17970), 1,
      anon_sym_RBRACK,
    STATE(14849), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14846), 2,
      sym_comment,
      sym_block_comment,
  [625127] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5334), 1,
      anon_sym_RPAREN,
    ACTIONS(17972), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14847), 2,
      sym_comment,
      sym_block_comment,
  [625147] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4532), 1,
      sym__indent,
    STATE(6739), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(14848), 2,
      sym_comment,
      sym_block_comment,
  [625165] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5632), 1,
      anon_sym_RBRACK,
    ACTIONS(17974), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14849), 2,
      sym_comment,
      sym_block_comment,
  [625185] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17976), 1,
      anon_sym_COMMA,
    ACTIONS(17978), 1,
      anon_sym_RBRACK,
    STATE(14868), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14850), 2,
      sym_comment,
      sym_block_comment,
  [625205] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12808), 1,
      sym__arrow_then_type,
    ACTIONS(17980), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(14851), 2,
      sym_comment,
      sym_block_comment,
  [625223] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(17982), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(14852), 2,
      sym_comment,
      sym_block_comment,
  [625243] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17984), 1,
      anon_sym_COMMA,
    ACTIONS(17986), 1,
      anon_sym_RPAREN,
    STATE(14905), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14853), 2,
      sym_comment,
      sym_block_comment,
  [625263] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(17982), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(14854), 2,
      sym_comment,
      sym_block_comment,
  [625283] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17988), 1,
      anon_sym_COMMA,
    ACTIONS(17990), 1,
      anon_sym_RBRACK,
    STATE(14857), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14855), 2,
      sym_comment,
      sym_block_comment,
  [625303] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5708), 1,
      anon_sym_RPAREN,
    ACTIONS(17992), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14856), 2,
      sym_comment,
      sym_block_comment,
  [625323] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5652), 1,
      anon_sym_RBRACK,
    ACTIONS(17994), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14857), 2,
      sym_comment,
      sym_block_comment,
  [625343] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5552), 1,
      anon_sym_RBRACK,
    ACTIONS(17996), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14858), 2,
      sym_comment,
      sym_block_comment,
  [625363] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5568), 1,
      anon_sym_RPAREN,
    ACTIONS(17998), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14859), 2,
      sym_comment,
      sym_block_comment,
  [625383] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5576), 1,
      anon_sym_RBRACK,
    ACTIONS(18000), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14860), 2,
      sym_comment,
      sym_block_comment,
  [625403] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4252), 1,
      sym__indent,
    STATE(5698), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(14861), 2,
      sym_comment,
      sym_block_comment,
  [625421] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18002), 1,
      anon_sym_COMMA,
    ACTIONS(18004), 1,
      anon_sym_RPAREN,
    STATE(14824), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14862), 2,
      sym_comment,
      sym_block_comment,
  [625441] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18006), 1,
      anon_sym_COMMA,
    ACTIONS(18008), 1,
      anon_sym_RBRACK,
    STATE(14866), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14863), 2,
      sym_comment,
      sym_block_comment,
  [625461] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5380), 1,
      anon_sym_RPAREN,
    ACTIONS(18010), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14864), 2,
      sym_comment,
      sym_block_comment,
  [625481] = 5,
    ACTIONS(17673), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18014), 1,
      anon_sym_STAR_SLASH,
    STATE(15631), 1,
      aux_sym_block_comment_repeat1,
    ACTIONS(18012), 2,
      anon_sym_SLASH_SLASH,
      aux_sym_block_comment_token1,
    STATE(14865), 2,
      sym_comment,
      sym_block_comment,
  [625499] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5676), 1,
      anon_sym_RBRACK,
    ACTIONS(18016), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14866), 2,
      sym_comment,
      sym_block_comment,
  [625519] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18018), 1,
      anon_sym_COMMA,
    ACTIONS(18020), 1,
      anon_sym_RBRACK,
    STATE(15015), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14867), 2,
      sym_comment,
      sym_block_comment,
  [625539] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5796), 1,
      anon_sym_RBRACK,
    ACTIONS(18022), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14868), 2,
      sym_comment,
      sym_block_comment,
  [625559] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18024), 1,
      anon_sym_COMMA,
    ACTIONS(18026), 1,
      anon_sym_RPAREN,
    STATE(14841), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14869), 2,
      sym_comment,
      sym_block_comment,
  [625579] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4340), 1,
      sym__indent,
    STATE(8944), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(14870), 2,
      sym_comment,
      sym_block_comment,
  [625597] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18028), 1,
      anon_sym_COMMA,
    ACTIONS(18030), 1,
      anon_sym_RBRACK,
    STATE(14873), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14871), 2,
      sym_comment,
      sym_block_comment,
  [625617] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5722), 1,
      anon_sym_RPAREN,
    ACTIONS(18032), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14872), 2,
      sym_comment,
      sym_block_comment,
  [625637] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5692), 1,
      anon_sym_RBRACK,
    ACTIONS(18034), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14873), 2,
      sym_comment,
      sym_block_comment,
  [625657] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8114), 1,
      anon_sym_with,
    ACTIONS(9124), 1,
      anon_sym_LPAREN,
    STATE(16693), 1,
      sym_arguments,
    STATE(14874), 2,
      sym_comment,
      sym_block_comment,
  [625677] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18036), 1,
      anon_sym_COMMA,
    ACTIONS(18038), 1,
      anon_sym_RPAREN,
    STATE(14856), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14875), 2,
      sym_comment,
      sym_block_comment,
  [625697] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18040), 1,
      anon_sym_COMMA,
    ACTIONS(18042), 1,
      anon_sym_RBRACK,
    STATE(14878), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14876), 2,
      sym_comment,
      sym_block_comment,
  [625717] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5742), 1,
      anon_sym_RPAREN,
    ACTIONS(18044), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14877), 2,
      sym_comment,
      sym_block_comment,
  [625737] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5710), 1,
      anon_sym_RBRACK,
    ACTIONS(18046), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14878), 2,
      sym_comment,
      sym_block_comment,
  [625757] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18048), 1,
      anon_sym_COMMA,
    ACTIONS(18050), 1,
      anon_sym_RPAREN,
    STATE(15467), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14879), 2,
      sym_comment,
      sym_block_comment,
  [625777] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(18052), 3,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [625793] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3994), 1,
      anon_sym_RPAREN,
    ACTIONS(18054), 1,
      anon_sym_COMMA,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14881), 2,
      sym_comment,
      sym_block_comment,
  [625813] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18056), 1,
      anon_sym_COMMA,
    ACTIONS(18058), 1,
      anon_sym_RPAREN,
    STATE(14872), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14882), 2,
      sym_comment,
      sym_block_comment,
  [625833] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18060), 1,
      anon_sym_COMMA,
    ACTIONS(18062), 1,
      anon_sym_RBRACK,
    STATE(14885), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14883), 2,
      sym_comment,
      sym_block_comment,
  [625853] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5466), 1,
      anon_sym_RPAREN,
    ACTIONS(18064), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14884), 2,
      sym_comment,
      sym_block_comment,
  [625873] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5724), 1,
      anon_sym_RBRACK,
    ACTIONS(18066), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14885), 2,
      sym_comment,
      sym_block_comment,
  [625893] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18068), 1,
      anon_sym_COMMA,
    ACTIONS(18070), 1,
      anon_sym_RBRACK,
    STATE(14900), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14886), 2,
      sym_comment,
      sym_block_comment,
  [625913] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11864), 1,
      sym__arrow_then_type,
    ACTIONS(18072), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(14887), 2,
      sym_comment,
      sym_block_comment,
  [625931] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18074), 1,
      anon_sym_COMMA,
    ACTIONS(18076), 1,
      anon_sym_RPAREN,
    STATE(14877), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14888), 2,
      sym_comment,
      sym_block_comment,
  [625951] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18078), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(14889), 2,
      sym_comment,
      sym_block_comment,
  [625971] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18078), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(14890), 2,
      sym_comment,
      sym_block_comment,
  [625991] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18080), 1,
      anon_sym_COMMA,
    ACTIONS(18082), 1,
      anon_sym_RBRACK,
    STATE(14893), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14891), 2,
      sym_comment,
      sym_block_comment,
  [626011] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5762), 1,
      anon_sym_RPAREN,
    ACTIONS(18084), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14892), 2,
      sym_comment,
      sym_block_comment,
  [626031] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5746), 1,
      anon_sym_RBRACK,
    ACTIONS(18086), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14893), 2,
      sym_comment,
      sym_block_comment,
  [626051] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5672), 1,
      anon_sym_RPAREN,
    ACTIONS(18088), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14894), 2,
      sym_comment,
      sym_block_comment,
  [626071] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18090), 1,
      anon_sym_COMMA,
    ACTIONS(18092), 1,
      anon_sym_RPAREN,
    STATE(14892), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14895), 2,
      sym_comment,
      sym_block_comment,
  [626091] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18094), 1,
      anon_sym_COMMA,
    ACTIONS(18096), 1,
      anon_sym_RBRACK,
    STATE(14899), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14896), 2,
      sym_comment,
      sym_block_comment,
  [626111] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5788), 1,
      anon_sym_RPAREN,
    ACTIONS(18098), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14897), 2,
      sym_comment,
      sym_block_comment,
  [626131] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5236), 1,
      anon_sym_RBRACK,
    ACTIONS(18100), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14898), 2,
      sym_comment,
      sym_block_comment,
  [626151] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5766), 1,
      anon_sym_RBRACK,
    ACTIONS(18102), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14899), 2,
      sym_comment,
      sym_block_comment,
  [626171] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5816), 1,
      anon_sym_RBRACK,
    ACTIONS(18104), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14900), 2,
      sym_comment,
      sym_block_comment,
  [626191] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15867), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9368), 1,
      sym_type_arguments,
    STATE(14901), 2,
      sym_comment,
      sym_block_comment,
  [626211] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18106), 1,
      anon_sym_COMMA,
    ACTIONS(18108), 1,
      anon_sym_RBRACK,
    STATE(15095), 1,
      aux_sym_type_parameters_repeat1,
    STATE(14902), 2,
      sym_comment,
      sym_block_comment,
  [626231] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18110), 1,
      anon_sym_COMMA,
    ACTIONS(18112), 1,
      anon_sym_RPAREN,
    STATE(14897), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14903), 2,
      sym_comment,
      sym_block_comment,
  [626251] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18114), 1,
      anon_sym_COMMA,
    ACTIONS(18116), 1,
      anon_sym_RBRACK,
    STATE(14906), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14904), 2,
      sym_comment,
      sym_block_comment,
  [626271] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5650), 1,
      anon_sym_RPAREN,
    ACTIONS(18118), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14905), 2,
      sym_comment,
      sym_block_comment,
  [626291] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5792), 1,
      anon_sym_RBRACK,
    ACTIONS(18120), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14906), 2,
      sym_comment,
      sym_block_comment,
  [626311] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18122), 1,
      anon_sym_COMMA,
    ACTIONS(18124), 1,
      anon_sym_RBRACK,
    STATE(14909), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14907), 2,
      sym_comment,
      sym_block_comment,
  [626331] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8396), 1,
      anon_sym_RPAREN,
    ACTIONS(18126), 1,
      anon_sym_COMMA,
    STATE(15203), 1,
      aux_sym_class_parameters_repeat1,
    STATE(14908), 2,
      sym_comment,
      sym_block_comment,
  [626351] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5824), 1,
      anon_sym_RBRACK,
    ACTIONS(18128), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14909), 2,
      sym_comment,
      sym_block_comment,
  [626371] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18130), 1,
      sym__interpolated_string_end,
    STATE(14934), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(14910), 2,
      sym_comment,
      sym_block_comment,
  [626391] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18130), 1,
      sym__interpolated_multiline_string_end,
    STATE(14935), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(14911), 2,
      sym_comment,
      sym_block_comment,
  [626411] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18132), 1,
      anon_sym_COMMA,
    ACTIONS(18134), 1,
      anon_sym_RBRACK,
    STATE(14914), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14912), 2,
      sym_comment,
      sym_block_comment,
  [626431] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18136), 1,
      anon_sym_COMMA,
    ACTIONS(18138), 1,
      anon_sym_RPAREN,
    STATE(15594), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14913), 2,
      sym_comment,
      sym_block_comment,
  [626451] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5840), 1,
      anon_sym_RBRACK,
    ACTIONS(18140), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14914), 2,
      sym_comment,
      sym_block_comment,
  [626471] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13473), 1,
      sym__arrow_then_type,
    ACTIONS(18142), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(14915), 2,
      sym_comment,
      sym_block_comment,
  [626489] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5720), 1,
      anon_sym_RPAREN,
    ACTIONS(18144), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14916), 2,
      sym_comment,
      sym_block_comment,
  [626509] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18146), 1,
      anon_sym_COMMA,
    ACTIONS(18148), 1,
      anon_sym_RBRACK,
    STATE(14918), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14917), 2,
      sym_comment,
      sym_block_comment,
  [626529] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5852), 1,
      anon_sym_RBRACK,
    ACTIONS(18150), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14918), 2,
      sym_comment,
      sym_block_comment,
  [626549] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18152), 1,
      anon_sym_COMMA,
    ACTIONS(18154), 1,
      anon_sym_RBRACK,
    STATE(14920), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14919), 2,
      sym_comment,
      sym_block_comment,
  [626569] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5868), 1,
      anon_sym_RBRACK,
    ACTIONS(18156), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14920), 2,
      sym_comment,
      sym_block_comment,
  [626589] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5538), 1,
      anon_sym_RBRACK,
    ACTIONS(18158), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14921), 2,
      sym_comment,
      sym_block_comment,
  [626609] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18160), 1,
      anon_sym_COMMA,
    ACTIONS(18162), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14922), 2,
      sym_comment,
      sym_block_comment,
  [626629] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18164), 1,
      anon_sym_COMMA,
    ACTIONS(18166), 1,
      anon_sym_RBRACK,
    STATE(14925), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14923), 2,
      sym_comment,
      sym_block_comment,
  [626649] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8244), 1,
      anon_sym_RPAREN,
    ACTIONS(18168), 1,
      anon_sym_COMMA,
    STATE(15247), 1,
      aux_sym_class_parameters_repeat1,
    STATE(14924), 2,
      sym_comment,
      sym_block_comment,
  [626669] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5890), 1,
      anon_sym_RBRACK,
    ACTIONS(18170), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14925), 2,
      sym_comment,
      sym_block_comment,
  [626689] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18172), 1,
      anon_sym_COMMA,
    ACTIONS(18174), 1,
      anon_sym_RBRACK,
    STATE(14927), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14926), 2,
      sym_comment,
      sym_block_comment,
  [626709] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5902), 1,
      anon_sym_RBRACK,
    ACTIONS(18176), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14927), 2,
      sym_comment,
      sym_block_comment,
  [626729] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18178), 1,
      anon_sym_COMMA,
    ACTIONS(18180), 1,
      anon_sym_RBRACK,
    STATE(14930), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14928), 2,
      sym_comment,
      sym_block_comment,
  [626749] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16160), 1,
      anon_sym_COLON,
    ACTIONS(16162), 1,
      anon_sym_LBRACE,
    STATE(14348), 1,
      sym_enum_body,
    STATE(14929), 2,
      sym_comment,
      sym_block_comment,
  [626769] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5920), 1,
      anon_sym_RBRACK,
    ACTIONS(18182), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14930), 2,
      sym_comment,
      sym_block_comment,
  [626789] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18184), 1,
      anon_sym_COMMA,
    ACTIONS(18186), 1,
      anon_sym_RBRACK,
    STATE(14948), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14931), 2,
      sym_comment,
      sym_block_comment,
  [626809] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18188), 1,
      anon_sym_COMMA,
    ACTIONS(18190), 1,
      anon_sym_RBRACK,
    STATE(14933), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14932), 2,
      sym_comment,
      sym_block_comment,
  [626829] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5940), 1,
      anon_sym_RBRACK,
    ACTIONS(18192), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14933), 2,
      sym_comment,
      sym_block_comment,
  [626849] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18194), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(14934), 2,
      sym_comment,
      sym_block_comment,
  [626869] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18194), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(14935), 2,
      sym_comment,
      sym_block_comment,
  [626889] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18196), 1,
      anon_sym_COMMA,
    ACTIONS(18198), 1,
      anon_sym_RBRACK,
    STATE(14937), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14936), 2,
      sym_comment,
      sym_block_comment,
  [626909] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5968), 1,
      anon_sym_RBRACK,
    ACTIONS(18200), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14937), 2,
      sym_comment,
      sym_block_comment,
  [626929] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18202), 1,
      anon_sym_COMMA,
    ACTIONS(18204), 1,
      anon_sym_RBRACK,
    STATE(14940), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14938), 2,
      sym_comment,
      sym_block_comment,
  [626949] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5608), 1,
      anon_sym_RPAREN,
    ACTIONS(18206), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14939), 2,
      sym_comment,
      sym_block_comment,
  [626969] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5996), 1,
      anon_sym_RBRACK,
    ACTIONS(18208), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14940), 2,
      sym_comment,
      sym_block_comment,
  [626989] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18210), 1,
      anon_sym_COMMA,
    ACTIONS(18212), 1,
      anon_sym_RBRACK,
    STATE(14942), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14941), 2,
      sym_comment,
      sym_block_comment,
  [627009] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6046), 1,
      anon_sym_RBRACK,
    ACTIONS(18214), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14942), 2,
      sym_comment,
      sym_block_comment,
  [627029] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18216), 1,
      anon_sym_COMMA,
    ACTIONS(18218), 1,
      anon_sym_RBRACK,
    STATE(14944), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14943), 2,
      sym_comment,
      sym_block_comment,
  [627049] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5120), 1,
      anon_sym_RBRACK,
    ACTIONS(18220), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14944), 2,
      sym_comment,
      sym_block_comment,
  [627069] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18222), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(14945), 2,
      sym_comment,
      sym_block_comment,
  [627089] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18224), 1,
      anon_sym_COMMA,
    ACTIONS(18226), 1,
      anon_sym_RBRACK,
    STATE(14947), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14946), 2,
      sym_comment,
      sym_block_comment,
  [627109] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5124), 1,
      anon_sym_RBRACK,
    ACTIONS(18228), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14947), 2,
      sym_comment,
      sym_block_comment,
  [627129] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5822), 1,
      anon_sym_RBRACK,
    ACTIONS(18230), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14948), 2,
      sym_comment,
      sym_block_comment,
  [627149] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18232), 1,
      anon_sym_COMMA,
    ACTIONS(18234), 1,
      anon_sym_RBRACK,
    STATE(14950), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14949), 2,
      sym_comment,
      sym_block_comment,
  [627169] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5128), 1,
      anon_sym_RBRACK,
    ACTIONS(18236), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14950), 2,
      sym_comment,
      sym_block_comment,
  [627189] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4372), 1,
      sym__indent,
    STATE(9387), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(14951), 2,
      sym_comment,
      sym_block_comment,
  [627207] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18238), 1,
      anon_sym_COMMA,
    ACTIONS(18240), 1,
      anon_sym_RBRACK,
    STATE(14953), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14952), 2,
      sym_comment,
      sym_block_comment,
  [627227] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5132), 1,
      anon_sym_RBRACK,
    ACTIONS(18242), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14953), 2,
      sym_comment,
      sym_block_comment,
  [627247] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18244), 1,
      anon_sym_COMMA,
    ACTIONS(18246), 1,
      anon_sym_RBRACK,
    STATE(14955), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14954), 2,
      sym_comment,
      sym_block_comment,
  [627267] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5136), 1,
      anon_sym_RBRACK,
    ACTIONS(18248), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14955), 2,
      sym_comment,
      sym_block_comment,
  [627287] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18250), 1,
      anon_sym_COMMA,
    ACTIONS(18252), 1,
      anon_sym_RBRACK,
    STATE(14957), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14956), 2,
      sym_comment,
      sym_block_comment,
  [627307] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5140), 1,
      anon_sym_RBRACK,
    ACTIONS(18254), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14957), 2,
      sym_comment,
      sym_block_comment,
  [627327] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18256), 1,
      anon_sym_COMMA,
    ACTIONS(18258), 1,
      anon_sym_RBRACK,
    STATE(14959), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14958), 2,
      sym_comment,
      sym_block_comment,
  [627347] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5144), 1,
      anon_sym_RBRACK,
    ACTIONS(18260), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14959), 2,
      sym_comment,
      sym_block_comment,
  [627367] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18262), 1,
      anon_sym_COMMA,
    ACTIONS(18264), 1,
      anon_sym_RPAREN,
    STATE(15500), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14960), 2,
      sym_comment,
      sym_block_comment,
  [627387] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18266), 1,
      anon_sym_COMMA,
    ACTIONS(18268), 1,
      anon_sym_RBRACK,
    STATE(14962), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14961), 2,
      sym_comment,
      sym_block_comment,
  [627407] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5148), 1,
      anon_sym_RBRACK,
    ACTIONS(18270), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14962), 2,
      sym_comment,
      sym_block_comment,
  [627427] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18272), 1,
      anon_sym_COMMA,
    ACTIONS(18274), 1,
      anon_sym_RBRACK,
    STATE(14965), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14963), 2,
      sym_comment,
      sym_block_comment,
  [627447] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16117), 1,
      anon_sym_LBRACK,
    STATE(9943), 1,
      sym_type_arguments,
    STATE(14964), 2,
      sym_comment,
      sym_block_comment,
  [627467] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5152), 1,
      anon_sym_RBRACK,
    ACTIONS(18276), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14965), 2,
      sym_comment,
      sym_block_comment,
  [627487] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18222), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(14966), 2,
      sym_comment,
      sym_block_comment,
  [627507] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18278), 1,
      anon_sym_COMMA,
    ACTIONS(18280), 1,
      anon_sym_RBRACK,
    STATE(14968), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14967), 2,
      sym_comment,
      sym_block_comment,
  [627527] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5156), 1,
      anon_sym_RBRACK,
    ACTIONS(18282), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14968), 2,
      sym_comment,
      sym_block_comment,
  [627547] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18284), 1,
      anon_sym_COMMA,
    ACTIONS(18286), 1,
      anon_sym_RBRACK,
    STATE(14970), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14969), 2,
      sym_comment,
      sym_block_comment,
  [627567] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5160), 1,
      anon_sym_RBRACK,
    ACTIONS(18288), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14970), 2,
      sym_comment,
      sym_block_comment,
  [627587] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18290), 1,
      anon_sym_COMMA,
    ACTIONS(18292), 1,
      anon_sym_RBRACK,
    STATE(14973), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14971), 2,
      sym_comment,
      sym_block_comment,
  [627607] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18294), 1,
      anon_sym_COMMA,
    ACTIONS(18296), 1,
      anon_sym_RBRACK,
    STATE(14983), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14972), 2,
      sym_comment,
      sym_block_comment,
  [627627] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5164), 1,
      anon_sym_RBRACK,
    ACTIONS(18298), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14973), 2,
      sym_comment,
      sym_block_comment,
  [627647] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18300), 1,
      anon_sym_COMMA,
    ACTIONS(18302), 1,
      anon_sym_RBRACK,
    STATE(14975), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14974), 2,
      sym_comment,
      sym_block_comment,
  [627667] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5168), 1,
      anon_sym_RBRACK,
    ACTIONS(18304), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14975), 2,
      sym_comment,
      sym_block_comment,
  [627687] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18306), 1,
      anon_sym_COMMA,
    ACTIONS(18308), 1,
      anon_sym_RBRACK,
    STATE(14978), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14976), 2,
      sym_comment,
      sym_block_comment,
  [627707] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4766), 1,
      sym__indent,
    STATE(10862), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(14977), 2,
      sym_comment,
      sym_block_comment,
  [627725] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5172), 1,
      anon_sym_RBRACK,
    ACTIONS(18310), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14978), 2,
      sym_comment,
      sym_block_comment,
  [627745] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14740), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(6704), 1,
      sym_type_arguments,
    STATE(14979), 2,
      sym_comment,
      sym_block_comment,
  [627765] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5202), 1,
      anon_sym_RPAREN,
    ACTIONS(18312), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14980), 2,
      sym_comment,
      sym_block_comment,
  [627785] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13574), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(6201), 1,
      sym_type_arguments,
    STATE(14981), 2,
      sym_comment,
      sym_block_comment,
  [627805] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14720), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(6885), 1,
      sym_type_arguments,
    STATE(14982), 2,
      sym_comment,
      sym_block_comment,
  [627825] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5836), 1,
      anon_sym_RBRACK,
    ACTIONS(18314), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14983), 2,
      sym_comment,
      sym_block_comment,
  [627845] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18316), 1,
      sym__interpolated_string_end,
    STATE(14998), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(14984), 2,
      sym_comment,
      sym_block_comment,
  [627865] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18316), 1,
      sym__interpolated_multiline_string_end,
    STATE(14999), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(14985), 2,
      sym_comment,
      sym_block_comment,
  [627885] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18318), 1,
      anon_sym_COMMA,
    ACTIONS(18320), 1,
      anon_sym_RPAREN,
    STATE(15669), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14986), 2,
      sym_comment,
      sym_block_comment,
  [627905] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13433), 1,
      sym__arrow_then_type,
    ACTIONS(18322), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(14987), 2,
      sym_comment,
      sym_block_comment,
  [627923] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    ACTIONS(18324), 1,
      anon_sym_COLON,
    STATE(15610), 1,
      aux_sym_val_declaration_repeat1,
    STATE(14988), 2,
      sym_comment,
      sym_block_comment,
  [627943] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18326), 1,
      anon_sym_COMMA,
    ACTIONS(18328), 1,
      anon_sym_RPAREN,
    STATE(15420), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14989), 2,
      sym_comment,
      sym_block_comment,
  [627963] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(18330), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(14990), 2,
      sym_comment,
      sym_block_comment,
  [627983] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8629), 1,
      sym__arrow_then_type,
    ACTIONS(18332), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(14991), 2,
      sym_comment,
      sym_block_comment,
  [628001] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18334), 1,
      anon_sym_COMMA,
    ACTIONS(18336), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14992), 2,
      sym_comment,
      sym_block_comment,
  [628021] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18338), 1,
      sym__interpolated_string_end,
    STATE(15070), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(14993), 2,
      sym_comment,
      sym_block_comment,
  [628041] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18340), 1,
      anon_sym_COMMA,
    ACTIONS(18342), 1,
      anon_sym_RBRACK,
    STATE(15008), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14994), 2,
      sym_comment,
      sym_block_comment,
  [628061] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18344), 1,
      anon_sym_COMMA,
    ACTIONS(18346), 1,
      anon_sym_RPAREN,
    STATE(15556), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14995), 2,
      sym_comment,
      sym_block_comment,
  [628081] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18338), 1,
      sym__interpolated_multiline_string_end,
    STATE(15071), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(14996), 2,
      sym_comment,
      sym_block_comment,
  [628101] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    STATE(14527), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(14997), 2,
      sym_comment,
      sym_block_comment,
  [628121] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18348), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(14998), 2,
      sym_comment,
      sym_block_comment,
  [628141] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18348), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(14999), 2,
      sym_comment,
      sym_block_comment,
  [628161] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5646), 1,
      anon_sym_RPAREN,
    ACTIONS(18350), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15000), 2,
      sym_comment,
      sym_block_comment,
  [628181] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18352), 1,
      anon_sym_COMMA,
    ACTIONS(18354), 1,
      anon_sym_RBRACK,
    STATE(15004), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15001), 2,
      sym_comment,
      sym_block_comment,
  [628201] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18356), 1,
      sym__interpolated_string_end,
    STATE(15110), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15002), 2,
      sym_comment,
      sym_block_comment,
  [628221] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18358), 1,
      anon_sym_COMMA,
    ACTIONS(18360), 1,
      anon_sym_RBRACK,
    STATE(15014), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15003), 2,
      sym_comment,
      sym_block_comment,
  [628241] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18362), 1,
      anon_sym_COMMA,
    ACTIONS(18364), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15004), 2,
      sym_comment,
      sym_block_comment,
  [628261] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14644), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15005), 2,
      sym_comment,
      sym_block_comment,
  [628281] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18356), 1,
      sym__interpolated_multiline_string_end,
    STATE(15111), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15006), 2,
      sym_comment,
      sym_block_comment,
  [628301] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18366), 1,
      anon_sym_COMMA,
    ACTIONS(18368), 1,
      anon_sym_RPAREN,
    STATE(14939), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15007), 2,
      sym_comment,
      sym_block_comment,
  [628321] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5850), 1,
      anon_sym_RBRACK,
    ACTIONS(18370), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15008), 2,
      sym_comment,
      sym_block_comment,
  [628341] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4430), 1,
      sym__indent,
    STATE(6226), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15009), 2,
      sym_comment,
      sym_block_comment,
  [628359] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5232), 1,
      anon_sym_RPAREN,
    ACTIONS(18372), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15010), 2,
      sym_comment,
      sym_block_comment,
  [628379] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18374), 1,
      anon_sym_COMMA,
    ACTIONS(18376), 1,
      anon_sym_RPAREN,
    STATE(14807), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15011), 2,
      sym_comment,
      sym_block_comment,
  [628399] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10990), 1,
      sym__arrow_then_type,
    ACTIONS(18378), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15012), 2,
      sym_comment,
      sym_block_comment,
  [628417] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13077), 1,
      sym__arrow_then_type,
    ACTIONS(18380), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15013), 2,
      sym_comment,
      sym_block_comment,
  [628435] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5864), 1,
      anon_sym_RBRACK,
    ACTIONS(18382), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15014), 2,
      sym_comment,
      sym_block_comment,
  [628455] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5190), 1,
      anon_sym_RBRACK,
    ACTIONS(18384), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15015), 2,
      sym_comment,
      sym_block_comment,
  [628475] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11244), 1,
      sym__arrow_then_type,
    ACTIONS(18386), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15016), 2,
      sym_comment,
      sym_block_comment,
  [628493] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18388), 1,
      anon_sym_COMMA,
    ACTIONS(18390), 1,
      anon_sym_RBRACK,
    STATE(15079), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15017), 2,
      sym_comment,
      sym_block_comment,
  [628513] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11864), 1,
      sym__arrow_then_type,
    ACTIONS(18392), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15018), 2,
      sym_comment,
      sym_block_comment,
  [628531] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11675), 1,
      sym__arrow_then_type,
    ACTIONS(18394), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15019), 2,
      sym_comment,
      sym_block_comment,
  [628549] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13228), 1,
      sym__arrow_then_type,
    ACTIONS(18396), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15020), 2,
      sym_comment,
      sym_block_comment,
  [628567] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12808), 1,
      sym__arrow_then_type,
    ACTIONS(18398), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15021), 2,
      sym_comment,
      sym_block_comment,
  [628585] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11939), 1,
      sym__arrow_then_type,
    ACTIONS(18400), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15022), 2,
      sym_comment,
      sym_block_comment,
  [628603] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13077), 1,
      sym__arrow_then_type,
    ACTIONS(18402), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15023), 2,
      sym_comment,
      sym_block_comment,
  [628621] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13191), 1,
      sym__arrow_then_type,
    ACTIONS(18404), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15024), 2,
      sym_comment,
      sym_block_comment,
  [628639] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11135), 1,
      sym__arrow_then_type,
    ACTIONS(18406), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15025), 2,
      sym_comment,
      sym_block_comment,
  [628657] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12161), 1,
      sym__arrow_then_type,
    ACTIONS(18408), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15026), 2,
      sym_comment,
      sym_block_comment,
  [628675] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12579), 1,
      sym__arrow_then_type,
    ACTIONS(18410), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15027), 2,
      sym_comment,
      sym_block_comment,
  [628693] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13473), 1,
      sym__arrow_then_type,
    ACTIONS(18412), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15028), 2,
      sym_comment,
      sym_block_comment,
  [628711] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13433), 1,
      sym__arrow_then_type,
    ACTIONS(18414), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15029), 2,
      sym_comment,
      sym_block_comment,
  [628729] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12846), 1,
      sym__arrow_then_type,
    ACTIONS(18416), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15030), 2,
      sym_comment,
      sym_block_comment,
  [628747] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13472), 1,
      sym__arrow_then_type,
    ACTIONS(18418), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15031), 2,
      sym_comment,
      sym_block_comment,
  [628765] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11478), 1,
      sym__arrow_then_type,
    ACTIONS(18420), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15032), 2,
      sym_comment,
      sym_block_comment,
  [628783] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13024), 1,
      sym__arrow_then_type,
    ACTIONS(18422), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15033), 2,
      sym_comment,
      sym_block_comment,
  [628801] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13041), 1,
      sym__arrow_then_type,
    ACTIONS(18424), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15034), 2,
      sym_comment,
      sym_block_comment,
  [628819] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    ACTIONS(18426), 1,
      anon_sym_COLON,
    STATE(15610), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15035), 2,
      sym_comment,
      sym_block_comment,
  [628839] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16160), 1,
      anon_sym_COLON,
    ACTIONS(16162), 1,
      anon_sym_LBRACE,
    STATE(14376), 1,
      sym_enum_body,
    STATE(15036), 2,
      sym_comment,
      sym_block_comment,
  [628859] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15020), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(7663), 1,
      sym_type_arguments,
    STATE(15037), 2,
      sym_comment,
      sym_block_comment,
  [628879] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18428), 1,
      anon_sym_COMMA,
    ACTIONS(18430), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15038), 2,
      sym_comment,
      sym_block_comment,
  [628899] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18432), 1,
      anon_sym_COMMA,
    ACTIONS(18434), 1,
      anon_sym_RPAREN,
    STATE(15628), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15039), 2,
      sym_comment,
      sym_block_comment,
  [628919] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18436), 1,
      anon_sym_COMMA,
    ACTIONS(18438), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15040), 2,
      sym_comment,
      sym_block_comment,
  [628939] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18440), 1,
      anon_sym_COMMA,
    ACTIONS(18442), 1,
      anon_sym_RBRACK,
    STATE(15065), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15041), 2,
      sym_comment,
      sym_block_comment,
  [628959] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18444), 1,
      sym__interpolated_string_end,
    STATE(15073), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15042), 2,
      sym_comment,
      sym_block_comment,
  [628979] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(18446), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15043), 2,
      sym_comment,
      sym_block_comment,
  [628999] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18448), 1,
      anon_sym_COMMA,
    ACTIONS(18450), 1,
      anon_sym_RPAREN,
    STATE(15338), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15044), 2,
      sym_comment,
      sym_block_comment,
  [629019] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18444), 1,
      sym__interpolated_multiline_string_end,
    STATE(15074), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15045), 2,
      sym_comment,
      sym_block_comment,
  [629039] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18452), 1,
      anon_sym_COMMA,
    ACTIONS(18454), 1,
      anon_sym_RPAREN,
    STATE(15842), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15046), 2,
      sym_comment,
      sym_block_comment,
  [629059] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12846), 1,
      sym__arrow_then_type,
    ACTIONS(18456), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15047), 2,
      sym_comment,
      sym_block_comment,
  [629077] = 4,
    ACTIONS(17673), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18461), 1,
      anon_sym_STAR_SLASH,
    ACTIONS(18458), 2,
      anon_sym_SLASH_SLASH,
      aux_sym_block_comment_token1,
    STATE(15048), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_block_comment_repeat1,
  [629093] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5264), 1,
      anon_sym_RPAREN,
    ACTIONS(18463), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15049), 2,
      sym_comment,
      sym_block_comment,
  [629113] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    STATE(14519), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(15050), 2,
      sym_comment,
      sym_block_comment,
  [629133] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18465), 1,
      anon_sym_COMMA,
    ACTIONS(18467), 1,
      anon_sym_RBRACK,
    STATE(14815), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15051), 2,
      sym_comment,
      sym_block_comment,
  [629153] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18469), 1,
      anon_sym_COMMA,
    ACTIONS(18471), 1,
      anon_sym_RBRACK,
    STATE(15054), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15052), 2,
      sym_comment,
      sym_block_comment,
  [629173] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18473), 1,
      anon_sym_LPAREN,
    ACTIONS(18475), 1,
      sym__automatic_semicolon,
    STATE(13211), 1,
      sym_class_parameters,
    STATE(15053), 2,
      sym_comment,
      sym_block_comment,
  [629193] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18477), 1,
      anon_sym_COMMA,
    ACTIONS(18479), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15054), 2,
      sym_comment,
      sym_block_comment,
  [629213] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14554), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15055), 2,
      sym_comment,
      sym_block_comment,
  [629233] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18481), 1,
      anon_sym_COMMA,
    ACTIONS(18483), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15056), 2,
      sym_comment,
      sym_block_comment,
  [629253] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11244), 1,
      sym__arrow_then_type,
    ACTIONS(18485), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15057), 2,
      sym_comment,
      sym_block_comment,
  [629271] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11864), 1,
      sym__arrow_then_type,
    ACTIONS(18487), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15058), 2,
      sym_comment,
      sym_block_comment,
  [629289] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11675), 1,
      sym__arrow_then_type,
    ACTIONS(18489), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15059), 2,
      sym_comment,
      sym_block_comment,
  [629307] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12808), 1,
      sym__arrow_then_type,
    ACTIONS(18491), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15060), 2,
      sym_comment,
      sym_block_comment,
  [629325] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11939), 1,
      sym__arrow_then_type,
    ACTIONS(18493), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15061), 2,
      sym_comment,
      sym_block_comment,
  [629343] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11135), 1,
      sym__arrow_then_type,
    ACTIONS(18495), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15062), 2,
      sym_comment,
      sym_block_comment,
  [629361] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12161), 1,
      sym__arrow_then_type,
    ACTIONS(18497), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15063), 2,
      sym_comment,
      sym_block_comment,
  [629379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11478), 1,
      sym__arrow_then_type,
    ACTIONS(18499), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15064), 2,
      sym_comment,
      sym_block_comment,
  [629397] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5892), 1,
      anon_sym_RBRACK,
    ACTIONS(18501), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15065), 2,
      sym_comment,
      sym_block_comment,
  [629417] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16459), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [629433] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18503), 1,
      anon_sym_COMMA,
    ACTIONS(18505), 1,
      anon_sym_RBRACK,
    STATE(15082), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15067), 2,
      sym_comment,
      sym_block_comment,
  [629453] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6018), 1,
      anon_sym_RPAREN,
    ACTIONS(18507), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15068), 2,
      sym_comment,
      sym_block_comment,
  [629473] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18509), 1,
      anon_sym_COMMA,
    ACTIONS(18511), 1,
      anon_sym_RBRACK,
    STATE(15102), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15069), 2,
      sym_comment,
      sym_block_comment,
  [629493] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18513), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15070), 2,
      sym_comment,
      sym_block_comment,
  [629513] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18513), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15071), 2,
      sym_comment,
      sym_block_comment,
  [629533] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(18515), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15072), 2,
      sym_comment,
      sym_block_comment,
  [629553] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18517), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15073), 2,
      sym_comment,
      sym_block_comment,
  [629573] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18517), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15074), 2,
      sym_comment,
      sym_block_comment,
  [629593] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5350), 1,
      anon_sym_RPAREN,
    ACTIONS(18519), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15075), 2,
      sym_comment,
      sym_block_comment,
  [629613] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    STATE(14557), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(15076), 2,
      sym_comment,
      sym_block_comment,
  [629633] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18521), 1,
      anon_sym_COMMA,
    ACTIONS(18523), 1,
      anon_sym_RPAREN,
    STATE(15572), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15077), 2,
      sym_comment,
      sym_block_comment,
  [629653] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18525), 1,
      anon_sym_COMMA,
    ACTIONS(18527), 1,
      anon_sym_RBRACK,
    STATE(15080), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15078), 2,
      sym_comment,
      sym_block_comment,
  [629673] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5590), 1,
      anon_sym_RBRACK,
    ACTIONS(18529), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15079), 2,
      sym_comment,
      sym_block_comment,
  [629693] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18531), 1,
      anon_sym_COMMA,
    ACTIONS(18533), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15080), 2,
      sym_comment,
      sym_block_comment,
  [629713] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14657), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15081), 2,
      sym_comment,
      sym_block_comment,
  [629733] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5874), 1,
      anon_sym_RBRACK,
    ACTIONS(18535), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15082), 2,
      sym_comment,
      sym_block_comment,
  [629753] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4462), 1,
      sym__indent,
    STATE(7698), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15083), 2,
      sym_comment,
      sym_block_comment,
  [629771] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11244), 1,
      sym__arrow_then_type,
    ACTIONS(18537), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15084), 2,
      sym_comment,
      sym_block_comment,
  [629789] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11864), 1,
      sym__arrow_then_type,
    ACTIONS(18539), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15085), 2,
      sym_comment,
      sym_block_comment,
  [629807] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11675), 1,
      sym__arrow_then_type,
    ACTIONS(18541), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15086), 2,
      sym_comment,
      sym_block_comment,
  [629825] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12808), 1,
      sym__arrow_then_type,
    ACTIONS(18543), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15087), 2,
      sym_comment,
      sym_block_comment,
  [629843] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11939), 1,
      sym__arrow_then_type,
    ACTIONS(18545), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15088), 2,
      sym_comment,
      sym_block_comment,
  [629861] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11135), 1,
      sym__arrow_then_type,
    ACTIONS(18547), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15089), 2,
      sym_comment,
      sym_block_comment,
  [629879] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12161), 1,
      sym__arrow_then_type,
    ACTIONS(18549), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15090), 2,
      sym_comment,
      sym_block_comment,
  [629897] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11478), 1,
      sym__arrow_then_type,
    ACTIONS(18551), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15091), 2,
      sym_comment,
      sym_block_comment,
  [629915] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5410), 1,
      anon_sym_RPAREN,
    ACTIONS(18553), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15092), 2,
      sym_comment,
      sym_block_comment,
  [629935] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18555), 1,
      anon_sym_COMMA,
    ACTIONS(18557), 1,
      anon_sym_RBRACK,
    STATE(15096), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15093), 2,
      sym_comment,
      sym_block_comment,
  [629955] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6092), 1,
      anon_sym_RPAREN,
    ACTIONS(18559), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15094), 2,
      sym_comment,
      sym_block_comment,
  [629975] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18561), 1,
      anon_sym_COMMA,
    ACTIONS(18564), 1,
      anon_sym_RBRACK,
    STATE(15095), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_type_parameters_repeat1,
  [629993] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5930), 1,
      anon_sym_RBRACK,
    ACTIONS(18566), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15096), 2,
      sym_comment,
      sym_block_comment,
  [630013] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18568), 1,
      anon_sym_COMMA,
    ACTIONS(18570), 1,
      anon_sym_RBRACK,
    STATE(15157), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15097), 2,
      sym_comment,
      sym_block_comment,
  [630033] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(18572), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15098), 2,
      sym_comment,
      sym_block_comment,
  [630053] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18574), 1,
      sym__interpolated_string_end,
    STATE(15278), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15099), 2,
      sym_comment,
      sym_block_comment,
  [630073] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18576), 1,
      anon_sym_COMMA,
    ACTIONS(18578), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15100), 2,
      sym_comment,
      sym_block_comment,
  [630093] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18574), 1,
      sym__interpolated_multiline_string_end,
    STATE(15282), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15101), 2,
      sym_comment,
      sym_block_comment,
  [630113] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5614), 1,
      anon_sym_RBRACK,
    ACTIONS(18580), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15102), 2,
      sym_comment,
      sym_block_comment,
  [630133] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    STATE(14627), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(15103), 2,
      sym_comment,
      sym_block_comment,
  [630153] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4730), 1,
      sym__indent,
    STATE(6907), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15104), 2,
      sym_comment,
      sym_block_comment,
  [630171] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14421), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15105), 2,
      sym_comment,
      sym_block_comment,
  [630191] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18582), 1,
      anon_sym_COMMA,
    ACTIONS(18584), 1,
      anon_sym_RPAREN,
    STATE(15599), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15106), 2,
      sym_comment,
      sym_block_comment,
  [630211] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11244), 1,
      sym__arrow_then_type,
    ACTIONS(18586), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15107), 2,
      sym_comment,
      sym_block_comment,
  [630229] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11864), 1,
      sym__arrow_then_type,
    ACTIONS(18588), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15108), 2,
      sym_comment,
      sym_block_comment,
  [630247] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12808), 1,
      sym__arrow_then_type,
    ACTIONS(18590), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15109), 2,
      sym_comment,
      sym_block_comment,
  [630265] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18592), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15110), 2,
      sym_comment,
      sym_block_comment,
  [630285] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18592), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15111), 2,
      sym_comment,
      sym_block_comment,
  [630305] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18594), 1,
      anon_sym_COMMA,
    ACTIONS(18596), 1,
      anon_sym_RPAREN,
    STATE(15494), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15112), 2,
      sym_comment,
      sym_block_comment,
  [630325] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(18598), 3,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [630341] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18600), 1,
      anon_sym_COMMA,
    ACTIONS(18602), 1,
      anon_sym_RBRACK,
    STATE(15125), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15114), 2,
      sym_comment,
      sym_block_comment,
  [630361] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15498), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(8490), 1,
      sym_type_arguments,
    STATE(15115), 2,
      sym_comment,
      sym_block_comment,
  [630381] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(18604), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15116), 2,
      sym_comment,
      sym_block_comment,
  [630401] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18606), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18609), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_interpolated_string_repeat2,
  [630419] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11244), 1,
      sym__arrow_then_type,
    ACTIONS(18611), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15118), 2,
      sym_comment,
      sym_block_comment,
  [630437] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    STATE(14639), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(15119), 2,
      sym_comment,
      sym_block_comment,
  [630457] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6104), 1,
      anon_sym_RPAREN,
    ACTIONS(18613), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15120), 2,
      sym_comment,
      sym_block_comment,
  [630477] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14439), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15121), 2,
      sym_comment,
      sym_block_comment,
  [630497] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12665), 1,
      anon_sym_RPAREN,
    ACTIONS(18615), 1,
      anon_sym_COMMA,
    STATE(15339), 1,
      aux_sym_parameters_repeat1,
    STATE(15122), 2,
      sym_comment,
      sym_block_comment,
  [630517] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11244), 1,
      sym__arrow_then_type,
    ACTIONS(18617), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15123), 2,
      sym_comment,
      sym_block_comment,
  [630535] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    ACTIONS(18619), 1,
      anon_sym_COLON,
    STATE(15610), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15124), 2,
      sym_comment,
      sym_block_comment,
  [630555] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5964), 1,
      anon_sym_RBRACK,
    ACTIONS(18621), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15125), 2,
      sym_comment,
      sym_block_comment,
  [630575] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5956), 1,
      anon_sym_RPAREN,
    ACTIONS(18623), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15126), 2,
      sym_comment,
      sym_block_comment,
  [630595] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18625), 1,
      sym__interpolated_string_end,
    STATE(15151), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15127), 2,
      sym_comment,
      sym_block_comment,
  [630615] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18625), 1,
      sym__interpolated_multiline_string_end,
    STATE(15153), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15128), 2,
      sym_comment,
      sym_block_comment,
  [630635] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18627), 1,
      anon_sym_COMMA,
    ACTIONS(18629), 1,
      anon_sym_RBRACK,
    STATE(15158), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15129), 2,
      sym_comment,
      sym_block_comment,
  [630655] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(18631), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15130), 2,
      sym_comment,
      sym_block_comment,
  [630675] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18633), 1,
      anon_sym_COMMA,
    ACTIONS(18635), 1,
      anon_sym_RPAREN,
    STATE(15764), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15131), 2,
      sym_comment,
      sym_block_comment,
  [630695] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18637), 1,
      anon_sym_COMMA,
    ACTIONS(18639), 1,
      anon_sym_RBRACK,
    STATE(15095), 1,
      aux_sym_type_parameters_repeat1,
    STATE(15132), 2,
      sym_comment,
      sym_block_comment,
  [630715] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13472), 1,
      sym__arrow_then_type,
    ACTIONS(18641), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15133), 2,
      sym_comment,
      sym_block_comment,
  [630733] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    STATE(14645), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(15134), 2,
      sym_comment,
      sym_block_comment,
  [630753] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    ACTIONS(18643), 1,
      anon_sym_COLON,
    STATE(15610), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15135), 2,
      sym_comment,
      sym_block_comment,
  [630773] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17594), 1,
      anon_sym_EQ,
    ACTIONS(17592), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15136), 2,
      sym_comment,
      sym_block_comment,
  [630791] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18645), 1,
      anon_sym_COMMA,
    ACTIONS(18647), 1,
      anon_sym_RBRACK,
    STATE(15286), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15137), 2,
      sym_comment,
      sym_block_comment,
  [630811] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14578), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15138), 2,
      sym_comment,
      sym_block_comment,
  [630831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4404), 1,
      sym__indent,
    STATE(8258), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15139), 2,
      sym_comment,
      sym_block_comment,
  [630849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11244), 1,
      sym__arrow_then_type,
    ACTIONS(18649), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15140), 2,
      sym_comment,
      sym_block_comment,
  [630867] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5002), 1,
      anon_sym_RPAREN,
    ACTIONS(18651), 1,
      anon_sym_COMMA,
    STATE(15459), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15141), 2,
      sym_comment,
      sym_block_comment,
  [630887] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18653), 1,
      anon_sym_COMMA,
    ACTIONS(18655), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15142), 2,
      sym_comment,
      sym_block_comment,
  [630907] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12620), 1,
      anon_sym_RPAREN,
    ACTIONS(18657), 1,
      anon_sym_COMMA,
    STATE(15122), 1,
      aux_sym_parameters_repeat1,
    STATE(15143), 2,
      sym_comment,
      sym_block_comment,
  [630927] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(18659), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15144), 2,
      sym_comment,
      sym_block_comment,
  [630947] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18661), 1,
      anon_sym_COMMA,
    ACTIONS(18663), 1,
      anon_sym_RPAREN,
    STATE(15719), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15145), 2,
      sym_comment,
      sym_block_comment,
  [630967] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18665), 1,
      anon_sym_COMMA,
    ACTIONS(18667), 1,
      anon_sym_RBRACK,
    STATE(15095), 1,
      aux_sym_type_parameters_repeat1,
    STATE(15146), 2,
      sym_comment,
      sym_block_comment,
  [630987] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    STATE(14569), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(15147), 2,
      sym_comment,
      sym_block_comment,
  [631007] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18669), 1,
      anon_sym_COMMA,
    ACTIONS(18671), 1,
      anon_sym_RBRACK,
    STATE(15161), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15148), 2,
      sym_comment,
      sym_block_comment,
  [631027] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15438), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(8556), 1,
      sym_type_arguments,
    STATE(15149), 2,
      sym_comment,
      sym_block_comment,
  [631047] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14637), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15150), 2,
      sym_comment,
      sym_block_comment,
  [631067] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18673), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15151), 2,
      sym_comment,
      sym_block_comment,
  [631087] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18675), 1,
      anon_sym_COMMA,
    ACTIONS(18677), 1,
      anon_sym_RBRACK,
    STATE(15163), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15152), 2,
      sym_comment,
      sym_block_comment,
  [631107] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18673), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15153), 2,
      sym_comment,
      sym_block_comment,
  [631127] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5370), 1,
      anon_sym_RPAREN,
    ACTIONS(18679), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15154), 2,
      sym_comment,
      sym_block_comment,
  [631147] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17106), 1,
      anon_sym_RBRACE,
    ACTIONS(17108), 1,
      anon_sym_COMMA,
    STATE(15340), 1,
      aux_sym_namespace_selectors_repeat1,
    STATE(15155), 2,
      sym_comment,
      sym_block_comment,
  [631167] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5550), 1,
      anon_sym_RPAREN,
    ACTIONS(18681), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15156), 2,
      sym_comment,
      sym_block_comment,
  [631187] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5378), 1,
      anon_sym_RBRACK,
    ACTIONS(18683), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15157), 2,
      sym_comment,
      sym_block_comment,
  [631207] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5452), 1,
      anon_sym_RBRACK,
    ACTIONS(18685), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15158), 2,
      sym_comment,
      sym_block_comment,
  [631227] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(18687), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15159), 2,
      sym_comment,
      sym_block_comment,
  [631247] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4568), 1,
      sym__indent,
    STATE(8375), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15160), 2,
      sym_comment,
      sym_block_comment,
  [631265] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5896), 1,
      anon_sym_RBRACK,
    ACTIONS(18689), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15161), 2,
      sym_comment,
      sym_block_comment,
  [631285] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    STATE(14566), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(15162), 2,
      sym_comment,
      sym_block_comment,
  [631305] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5980), 1,
      anon_sym_RBRACK,
    ACTIONS(18691), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15163), 2,
      sym_comment,
      sym_block_comment,
  [631325] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4630), 1,
      sym__indent,
    STATE(8564), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15164), 2,
      sym_comment,
      sym_block_comment,
  [631343] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14672), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15165), 2,
      sym_comment,
      sym_block_comment,
  [631363] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8224), 1,
      anon_sym_RPAREN,
    ACTIONS(18693), 1,
      anon_sym_COMMA,
    STATE(15221), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15166), 2,
      sym_comment,
      sym_block_comment,
  [631383] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16645), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [631399] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(18695), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15168), 2,
      sym_comment,
      sym_block_comment,
  [631419] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18697), 1,
      anon_sym_COMMA,
    ACTIONS(18699), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15169), 2,
      sym_comment,
      sym_block_comment,
  [631439] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5764), 1,
      anon_sym_RPAREN,
    ACTIONS(18701), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15170), 2,
      sym_comment,
      sym_block_comment,
  [631459] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    STATE(14472), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(15171), 2,
      sym_comment,
      sym_block_comment,
  [631479] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14521), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15172), 2,
      sym_comment,
      sym_block_comment,
  [631499] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18703), 1,
      anon_sym_COMMA,
    ACTIONS(18705), 1,
      anon_sym_RPAREN,
    STATE(15647), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15173), 2,
      sym_comment,
      sym_block_comment,
  [631519] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18707), 1,
      sym__interpolated_string_end,
    STATE(15185), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15174), 2,
      sym_comment,
      sym_block_comment,
  [631539] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18707), 1,
      sym__interpolated_multiline_string_end,
    STATE(15186), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15175), 2,
      sym_comment,
      sym_block_comment,
  [631559] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18709), 1,
      anon_sym_COMMA,
    ACTIONS(18711), 1,
      anon_sym_RPAREN,
    STATE(15836), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15176), 2,
      sym_comment,
      sym_block_comment,
  [631579] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18713), 1,
      anon_sym_COMMA,
    ACTIONS(18715), 1,
      anon_sym_RBRACK,
    STATE(15189), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15177), 2,
      sym_comment,
      sym_block_comment,
  [631599] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11478), 1,
      sym__arrow_then_type,
    ACTIONS(18717), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15178), 2,
      sym_comment,
      sym_block_comment,
  [631617] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(18719), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15179), 2,
      sym_comment,
      sym_block_comment,
  [631637] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    STATE(14656), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(15180), 2,
      sym_comment,
      sym_block_comment,
  [631657] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(18721), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [631673] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14658), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15182), 2,
      sym_comment,
      sym_block_comment,
  [631693] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5290), 1,
      anon_sym_RPAREN,
    ACTIONS(18723), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15183), 2,
      sym_comment,
      sym_block_comment,
  [631713] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18725), 1,
      anon_sym_COMMA,
    ACTIONS(18727), 1,
      anon_sym_RBRACK,
    STATE(15191), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15184), 2,
      sym_comment,
      sym_block_comment,
  [631733] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18729), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15185), 2,
      sym_comment,
      sym_block_comment,
  [631753] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18729), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15186), 2,
      sym_comment,
      sym_block_comment,
  [631773] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14577), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(6918), 1,
      sym_type_arguments,
    STATE(15187), 2,
      sym_comment,
      sym_block_comment,
  [631793] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5402), 1,
      anon_sym_RPAREN,
    ACTIONS(18731), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15188), 2,
      sym_comment,
      sym_block_comment,
  [631813] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5990), 1,
      anon_sym_RBRACK,
    ACTIONS(18733), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15189), 2,
      sym_comment,
      sym_block_comment,
  [631833] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(18735), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15190), 2,
      sym_comment,
      sym_block_comment,
  [631853] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5918), 1,
      anon_sym_RBRACK,
    ACTIONS(18737), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15191), 2,
      sym_comment,
      sym_block_comment,
  [631873] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    STATE(14461), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(15192), 2,
      sym_comment,
      sym_block_comment,
  [631893] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18739), 1,
      anon_sym_COMMA,
    ACTIONS(18741), 1,
      anon_sym_RPAREN,
    STATE(15141), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15193), 2,
      sym_comment,
      sym_block_comment,
  [631913] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14529), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15194), 2,
      sym_comment,
      sym_block_comment,
  [631933] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17259), 1,
      anon_sym_RPAREN,
    ACTIONS(18743), 1,
      anon_sym_COMMA,
    STATE(15204), 1,
      aux_sym_parameters_repeat1,
    STATE(15195), 2,
      sym_comment,
      sym_block_comment,
  [631953] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8629), 1,
      sym__arrow_then_type,
    ACTIONS(18745), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15196), 2,
      sym_comment,
      sym_block_comment,
  [631971] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18747), 1,
      anon_sym_COMMA,
    ACTIONS(18749), 1,
      anon_sym_RPAREN,
    STATE(15441), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15197), 2,
      sym_comment,
      sym_block_comment,
  [631991] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8224), 1,
      anon_sym_RPAREN,
    ACTIONS(18693), 1,
      anon_sym_COMMA,
    STATE(15247), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15198), 2,
      sym_comment,
      sym_block_comment,
  [632011] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5912), 1,
      anon_sym_RPAREN,
    ACTIONS(18751), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15199), 2,
      sym_comment,
      sym_block_comment,
  [632031] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8226), 1,
      anon_sym_RPAREN,
    ACTIONS(18753), 1,
      anon_sym_COMMA,
    STATE(15695), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15200), 2,
      sym_comment,
      sym_block_comment,
  [632051] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18755), 1,
      anon_sym_COMMA,
    ACTIONS(18757), 1,
      anon_sym_RPAREN,
    STATE(15814), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15201), 2,
      sym_comment,
      sym_block_comment,
  [632071] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(18759), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15202), 2,
      sym_comment,
      sym_block_comment,
  [632091] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8226), 1,
      anon_sym_RPAREN,
    ACTIONS(18753), 1,
      anon_sym_COMMA,
    STATE(15247), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15203), 2,
      sym_comment,
      sym_block_comment,
  [632111] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5010), 1,
      anon_sym_RPAREN,
    ACTIONS(18761), 1,
      anon_sym_COMMA,
    STATE(15339), 1,
      aux_sym_parameters_repeat1,
    STATE(15204), 2,
      sym_comment,
      sym_block_comment,
  [632131] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17257), 1,
      anon_sym_COMMA,
    ACTIONS(17259), 1,
      anon_sym_RPAREN,
    STATE(15290), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15205), 2,
      sym_comment,
      sym_block_comment,
  [632151] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    STATE(14462), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(15206), 2,
      sym_comment,
      sym_block_comment,
  [632171] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18763), 1,
      anon_sym_COMMA,
    ACTIONS(18765), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15207), 2,
      sym_comment,
      sym_block_comment,
  [632191] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14711), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15208), 2,
      sym_comment,
      sym_block_comment,
  [632211] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18767), 1,
      anon_sym_COMMA,
    ACTIONS(18769), 1,
      anon_sym_RBRACK,
    STATE(15224), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15209), 2,
      sym_comment,
      sym_block_comment,
  [632231] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12620), 1,
      anon_sym_RPAREN,
    ACTIONS(18657), 1,
      anon_sym_COMMA,
    STATE(15339), 1,
      aux_sym_parameters_repeat1,
    STATE(15210), 2,
      sym_comment,
      sym_block_comment,
  [632251] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18771), 1,
      sym__interpolated_string_end,
    STATE(15279), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15211), 2,
      sym_comment,
      sym_block_comment,
  [632271] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5298), 1,
      anon_sym_RPAREN,
    ACTIONS(18773), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15212), 2,
      sym_comment,
      sym_block_comment,
  [632291] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18775), 1,
      sym__interpolated_string_end,
    STATE(15226), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15213), 2,
      sym_comment,
      sym_block_comment,
  [632311] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18775), 1,
      sym__interpolated_multiline_string_end,
    STATE(15228), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15214), 2,
      sym_comment,
      sym_block_comment,
  [632331] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18771), 1,
      sym__interpolated_multiline_string_end,
    STATE(15280), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15215), 2,
      sym_comment,
      sym_block_comment,
  [632351] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(18777), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15216), 2,
      sym_comment,
      sym_block_comment,
  [632371] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5910), 1,
      anon_sym_RPAREN,
    ACTIONS(18779), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15217), 2,
      sym_comment,
      sym_block_comment,
  [632391] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18781), 1,
      anon_sym_COMMA,
    ACTIONS(18783), 1,
      anon_sym_RPAREN,
    STATE(14803), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15218), 2,
      sym_comment,
      sym_block_comment,
  [632411] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15929), 1,
      sym__arrow_then_type,
    ACTIONS(18785), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15219), 2,
      sym_comment,
      sym_block_comment,
  [632429] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    STATE(14605), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(15220), 2,
      sym_comment,
      sym_block_comment,
  [632449] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8230), 1,
      anon_sym_RPAREN,
    ACTIONS(18787), 1,
      anon_sym_COMMA,
    STATE(15247), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15221), 2,
      sym_comment,
      sym_block_comment,
  [632469] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14642), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15222), 2,
      sym_comment,
      sym_block_comment,
  [632489] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18789), 1,
      anon_sym_COMMA,
    ACTIONS(18791), 1,
      anon_sym_RBRACK,
    STATE(15251), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15223), 2,
      sym_comment,
      sym_block_comment,
  [632509] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6002), 1,
      anon_sym_RBRACK,
    ACTIONS(18793), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15224), 2,
      sym_comment,
      sym_block_comment,
  [632529] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18795), 1,
      anon_sym_COMMA,
    ACTIONS(18797), 1,
      anon_sym_RBRACK,
    STATE(15239), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15225), 2,
      sym_comment,
      sym_block_comment,
  [632549] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18799), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15226), 2,
      sym_comment,
      sym_block_comment,
  [632569] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(18801), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15227), 2,
      sym_comment,
      sym_block_comment,
  [632589] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18799), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15228), 2,
      sym_comment,
      sym_block_comment,
  [632609] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18803), 1,
      anon_sym_COMMA,
    ACTIONS(18805), 1,
      anon_sym_RPAREN,
    STATE(15000), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15229), 2,
      sym_comment,
      sym_block_comment,
  [632629] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    STATE(14428), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(15230), 2,
      sym_comment,
      sym_block_comment,
  [632649] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13191), 1,
      sym__arrow_then_type,
    ACTIONS(18807), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15231), 2,
      sym_comment,
      sym_block_comment,
  [632667] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5446), 1,
      anon_sym_RPAREN,
    ACTIONS(18809), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15232), 2,
      sym_comment,
      sym_block_comment,
  [632687] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18811), 1,
      anon_sym_COMMA,
    ACTIONS(18813), 1,
      anon_sym_RBRACK,
    STATE(15381), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15233), 2,
      sym_comment,
      sym_block_comment,
  [632707] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14667), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15234), 2,
      sym_comment,
      sym_block_comment,
  [632727] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15424), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(8507), 1,
      sym_type_arguments,
    STATE(15235), 2,
      sym_comment,
      sym_block_comment,
  [632747] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15103), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [632763] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6030), 1,
      anon_sym_RPAREN,
    ACTIONS(18815), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15237), 2,
      sym_comment,
      sym_block_comment,
  [632783] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18817), 1,
      anon_sym_COMMA,
    ACTIONS(18819), 1,
      anon_sym_RPAREN,
    STATE(15697), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15238), 2,
      sym_comment,
      sym_block_comment,
  [632803] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5938), 1,
      anon_sym_RBRACK,
    ACTIONS(18821), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15239), 2,
      sym_comment,
      sym_block_comment,
  [632823] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17395), 1,
      anon_sym_EQ,
    ACTIONS(17393), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15240), 2,
      sym_comment,
      sym_block_comment,
  [632841] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(18823), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15241), 2,
      sym_comment,
      sym_block_comment,
  [632861] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18825), 1,
      anon_sym_COMMA,
    ACTIONS(18827), 1,
      anon_sym_RBRACK,
    STATE(15248), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15242), 2,
      sym_comment,
      sym_block_comment,
  [632881] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    STATE(14513), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(15243), 2,
      sym_comment,
      sym_block_comment,
  [632901] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14587), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15244), 2,
      sym_comment,
      sym_block_comment,
  [632921] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5398), 1,
      anon_sym_RPAREN,
    ACTIONS(18829), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15245), 2,
      sym_comment,
      sym_block_comment,
  [632941] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18831), 1,
      anon_sym_COMMA,
    ACTIONS(18833), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15246), 2,
      sym_comment,
      sym_block_comment,
  [632961] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18835), 1,
      anon_sym_COMMA,
    ACTIONS(18838), 1,
      anon_sym_RPAREN,
    STATE(15247), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_class_parameters_repeat1,
  [632979] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6012), 1,
      anon_sym_RBRACK,
    ACTIONS(18840), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15248), 2,
      sym_comment,
      sym_block_comment,
  [632999] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(18842), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15249), 2,
      sym_comment,
      sym_block_comment,
  [633019] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    STATE(14593), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(15250), 2,
      sym_comment,
      sym_block_comment,
  [633039] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5626), 1,
      anon_sym_RBRACK,
    ACTIONS(18844), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15251), 2,
      sym_comment,
      sym_block_comment,
  [633059] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18846), 1,
      sym__interpolated_string_end,
    STATE(15265), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15252), 2,
      sym_comment,
      sym_block_comment,
  [633079] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18846), 1,
      sym__interpolated_multiline_string_end,
    STATE(15267), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15253), 2,
      sym_comment,
      sym_block_comment,
  [633099] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14567), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15254), 2,
      sym_comment,
      sym_block_comment,
  [633119] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18848), 1,
      anon_sym_COMMA,
    ACTIONS(18850), 1,
      anon_sym_RPAREN,
    STATE(15126), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15255), 2,
      sym_comment,
      sym_block_comment,
  [633139] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13024), 1,
      sym__arrow_then_type,
    ACTIONS(18852), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15256), 2,
      sym_comment,
      sym_block_comment,
  [633157] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18854), 1,
      sym__interpolated_string_end,
    STATE(14945), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15257), 2,
      sym_comment,
      sym_block_comment,
  [633177] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18856), 1,
      sym__interpolated_string_end,
    STATE(15331), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15258), 2,
      sym_comment,
      sym_block_comment,
  [633197] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18858), 1,
      anon_sym_COMMA,
    ACTIONS(18860), 1,
      anon_sym_RPAREN,
    STATE(14825), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15259), 2,
      sym_comment,
      sym_block_comment,
  [633217] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(18862), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15260), 2,
      sym_comment,
      sym_block_comment,
  [633237] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15261), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(18864), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [633253] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18866), 1,
      anon_sym_COMMA,
    ACTIONS(18868), 1,
      anon_sym_RBRACK,
    STATE(15273), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15262), 2,
      sym_comment,
      sym_block_comment,
  [633273] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18856), 1,
      sym__interpolated_multiline_string_end,
    STATE(15356), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15263), 2,
      sym_comment,
      sym_block_comment,
  [633293] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18870), 1,
      anon_sym_COMMA,
    ACTIONS(18872), 1,
      anon_sym_RBRACK,
    STATE(15272), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15264), 2,
      sym_comment,
      sym_block_comment,
  [633313] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18874), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15265), 2,
      sym_comment,
      sym_block_comment,
  [633333] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14675), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15266), 2,
      sym_comment,
      sym_block_comment,
  [633353] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18874), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15267), 2,
      sym_comment,
      sym_block_comment,
  [633373] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5690), 1,
      anon_sym_RPAREN,
    ACTIONS(18876), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15268), 2,
      sym_comment,
      sym_block_comment,
  [633393] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5642), 1,
      anon_sym_RPAREN,
    ACTIONS(18878), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15269), 2,
      sym_comment,
      sym_block_comment,
  [633413] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18880), 1,
      anon_sym_COMMA,
    ACTIONS(18882), 1,
      anon_sym_RBRACK,
    STATE(15309), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15270), 2,
      sym_comment,
      sym_block_comment,
  [633433] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18884), 1,
      anon_sym_COMMA,
    ACTIONS(18886), 1,
      anon_sym_RPAREN,
    STATE(15092), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15271), 2,
      sym_comment,
      sym_block_comment,
  [633453] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5958), 1,
      anon_sym_RBRACK,
    ACTIONS(18888), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15272), 2,
      sym_comment,
      sym_block_comment,
  [633473] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6022), 1,
      anon_sym_RBRACK,
    ACTIONS(18890), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15273), 2,
      sym_comment,
      sym_block_comment,
  [633493] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14560), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15274), 2,
      sym_comment,
      sym_block_comment,
  [633513] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10691), 1,
      sym__arrow_then_type,
    ACTIONS(18892), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15275), 2,
      sym_comment,
      sym_block_comment,
  [633531] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18854), 1,
      sym__interpolated_multiline_string_end,
    STATE(14966), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15276), 2,
      sym_comment,
      sym_block_comment,
  [633551] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16445), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [633567] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18894), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15278), 2,
      sym_comment,
      sym_block_comment,
  [633587] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18896), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15279), 2,
      sym_comment,
      sym_block_comment,
  [633607] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18896), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15280), 2,
      sym_comment,
      sym_block_comment,
  [633627] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12880), 1,
      anon_sym_RPAREN,
    ACTIONS(18898), 1,
      anon_sym_COMMA,
    STATE(15590), 1,
      aux_sym_bindings_repeat1,
    STATE(15281), 2,
      sym_comment,
      sym_block_comment,
  [633647] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18894), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15282), 2,
      sym_comment,
      sym_block_comment,
  [633667] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5458), 1,
      anon_sym_RPAREN,
    ACTIONS(18900), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15283), 2,
      sym_comment,
      sym_block_comment,
  [633687] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18902), 1,
      anon_sym_COMMA,
    ACTIONS(18904), 1,
      anon_sym_RPAREN,
    STATE(15237), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15284), 2,
      sym_comment,
      sym_block_comment,
  [633707] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14466), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15285), 2,
      sym_comment,
      sym_block_comment,
  [633727] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5514), 1,
      anon_sym_RBRACK,
    ACTIONS(18906), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15286), 2,
      sym_comment,
      sym_block_comment,
  [633747] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15105), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(7547), 1,
      sym_type_arguments,
    STATE(15287), 2,
      sym_comment,
      sym_block_comment,
  [633767] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18908), 1,
      anon_sym_COMMA,
    ACTIONS(18910), 1,
      anon_sym_RBRACK,
    STATE(15294), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15288), 2,
      sym_comment,
      sym_block_comment,
  [633787] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18912), 1,
      anon_sym_COMMA,
    ACTIONS(18914), 1,
      anon_sym_RPAREN,
    STATE(15412), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15289), 2,
      sym_comment,
      sym_block_comment,
  [633807] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5010), 1,
      anon_sym_RPAREN,
    ACTIONS(18916), 1,
      anon_sym_COMMA,
    STATE(15459), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15290), 2,
      sym_comment,
      sym_block_comment,
  [633827] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13041), 1,
      sym__arrow_then_type,
    ACTIONS(18918), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15291), 2,
      sym_comment,
      sym_block_comment,
  [633845] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5314), 1,
      anon_sym_RPAREN,
    ACTIONS(18920), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15292), 2,
      sym_comment,
      sym_block_comment,
  [633865] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14688), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15293), 2,
      sym_comment,
      sym_block_comment,
  [633885] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6032), 1,
      anon_sym_RBRACK,
    ACTIONS(18922), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15294), 2,
      sym_comment,
      sym_block_comment,
  [633905] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18924), 1,
      anon_sym_COMMA,
    ACTIONS(18926), 1,
      anon_sym_RBRACK,
    STATE(15303), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15295), 2,
      sym_comment,
      sym_block_comment,
  [633925] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18928), 1,
      anon_sym_COMMA,
    ACTIONS(18930), 1,
      anon_sym_RBRACK,
    STATE(15847), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15296), 2,
      sym_comment,
      sym_block_comment,
  [633945] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15297), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16710), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [633961] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5726), 1,
      anon_sym_RPAREN,
    ACTIONS(18932), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15298), 2,
      sym_comment,
      sym_block_comment,
  [633981] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4166), 1,
      sym__indent,
    STATE(9339), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15299), 2,
      sym_comment,
      sym_block_comment,
  [633999] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17329), 1,
      anon_sym_EQ,
    ACTIONS(17327), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15300), 2,
      sym_comment,
      sym_block_comment,
  [634017] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14467), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15301), 2,
      sym_comment,
      sym_block_comment,
  [634037] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    STATE(14452), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(15302), 2,
      sym_comment,
      sym_block_comment,
  [634057] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5666), 1,
      anon_sym_RBRACK,
    ACTIONS(18934), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15303), 2,
      sym_comment,
      sym_block_comment,
  [634077] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18936), 1,
      sym__interpolated_string_end,
    STATE(15345), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15304), 2,
      sym_comment,
      sym_block_comment,
  [634097] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18936), 1,
      sym__interpolated_multiline_string_end,
    STATE(15346), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15305), 2,
      sym_comment,
      sym_block_comment,
  [634117] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18938), 1,
      anon_sym_COMMA,
    ACTIONS(18940), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15306), 2,
      sym_comment,
      sym_block_comment,
  [634137] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18942), 1,
      anon_sym_LPAREN,
    ACTIONS(18944), 1,
      sym__automatic_semicolon,
    STATE(13392), 1,
      sym_class_parameters,
    STATE(15307), 2,
      sym_comment,
      sym_block_comment,
  [634157] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(18864), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [634173] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5654), 1,
      anon_sym_RBRACK,
    ACTIONS(18946), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15309), 2,
      sym_comment,
      sym_block_comment,
  [634193] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18948), 1,
      anon_sym_COMMA,
    ACTIONS(18950), 1,
      anon_sym_RPAREN,
    STATE(15835), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15310), 2,
      sym_comment,
      sym_block_comment,
  [634213] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16152), 1,
      anon_sym_COLON,
    ACTIONS(16154), 1,
      anon_sym_LBRACE,
    STATE(14473), 1,
      sym_enum_body,
    STATE(15311), 2,
      sym_comment,
      sym_block_comment,
  [634233] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15312), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15960), 3,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
  [634249] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4848), 1,
      sym__indent,
    STATE(6937), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15313), 2,
      sym_comment,
      sym_block_comment,
  [634267] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14561), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15314), 2,
      sym_comment,
      sym_block_comment,
  [634287] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18952), 1,
      anon_sym_COMMA,
    ACTIONS(18954), 1,
      anon_sym_RBRACK,
    STATE(15321), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15315), 2,
      sym_comment,
      sym_block_comment,
  [634307] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18956), 1,
      anon_sym_COMMA,
    ACTIONS(18958), 1,
      anon_sym_RBRACK,
    STATE(15351), 1,
      aux_sym_type_parameters_repeat1,
    STATE(15316), 2,
      sym_comment,
      sym_block_comment,
  [634327] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12725), 1,
      anon_sym_RPAREN,
    ACTIONS(18960), 1,
      anon_sym_COMMA,
    STATE(15357), 1,
      aux_sym_parameters_repeat1,
    STATE(15317), 2,
      sym_comment,
      sym_block_comment,
  [634347] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18962), 1,
      anon_sym_COMMA,
    ACTIONS(18964), 1,
      anon_sym_RPAREN,
    STATE(15358), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15318), 2,
      sym_comment,
      sym_block_comment,
  [634367] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11266), 1,
      sym__arrow_then_type,
    ACTIONS(18966), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15319), 2,
      sym_comment,
      sym_block_comment,
  [634385] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5884), 1,
      anon_sym_RPAREN,
    ACTIONS(18968), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15320), 2,
      sym_comment,
      sym_block_comment,
  [634405] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6040), 1,
      anon_sym_RBRACK,
    ACTIONS(18970), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15321), 2,
      sym_comment,
      sym_block_comment,
  [634425] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14652), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15322), 2,
      sym_comment,
      sym_block_comment,
  [634445] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18972), 1,
      anon_sym_COMMA,
    ACTIONS(18974), 1,
      anon_sym_RPAREN,
    STATE(15281), 1,
      aux_sym_bindings_repeat1,
    STATE(15323), 2,
      sym_comment,
      sym_block_comment,
  [634465] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18976), 1,
      anon_sym_COMMA,
    ACTIONS(18978), 1,
      anon_sym_RPAREN,
    STATE(15199), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15324), 2,
      sym_comment,
      sym_block_comment,
  [634485] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18980), 1,
      anon_sym_COMMA,
    ACTIONS(18982), 1,
      anon_sym_RBRACK,
    STATE(15384), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15325), 2,
      sym_comment,
      sym_block_comment,
  [634505] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16160), 1,
      anon_sym_COLON,
    ACTIONS(16162), 1,
      anon_sym_LBRACE,
    STATE(14380), 1,
      sym_enum_body,
    STATE(15326), 2,
      sym_comment,
      sym_block_comment,
  [634525] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18984), 1,
      anon_sym_COMMA,
    ACTIONS(18986), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15327), 2,
      sym_comment,
      sym_block_comment,
  [634545] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14436), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15328), 2,
      sym_comment,
      sym_block_comment,
  [634565] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15329), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16445), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [634581] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5180), 1,
      anon_sym_RPAREN,
    ACTIONS(18988), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15330), 2,
      sym_comment,
      sym_block_comment,
  [634601] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(18990), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15331), 2,
      sym_comment,
      sym_block_comment,
  [634621] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18992), 1,
      anon_sym_COMMA,
    ACTIONS(18994), 1,
      anon_sym_RBRACK,
    STATE(15344), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15332), 2,
      sym_comment,
      sym_block_comment,
  [634641] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    ACTIONS(18996), 1,
      anon_sym_COLON,
    STATE(15610), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15333), 2,
      sym_comment,
      sym_block_comment,
  [634661] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    ACTIONS(18998), 1,
      anon_sym_COLON,
    STATE(15610), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15334), 2,
      sym_comment,
      sym_block_comment,
  [634681] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    ACTIONS(19000), 1,
      anon_sym_COLON,
    STATE(15610), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15335), 2,
      sym_comment,
      sym_block_comment,
  [634701] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14445), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15336), 2,
      sym_comment,
      sym_block_comment,
  [634721] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    ACTIONS(19002), 1,
      anon_sym_COLON,
    STATE(15610), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15337), 2,
      sym_comment,
      sym_block_comment,
  [634741] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5508), 1,
      anon_sym_RPAREN,
    ACTIONS(19004), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15338), 2,
      sym_comment,
      sym_block_comment,
  [634761] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19006), 1,
      anon_sym_COMMA,
    ACTIONS(19009), 1,
      anon_sym_RPAREN,
    STATE(15339), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_parameters_repeat1,
  [634779] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12530), 1,
      anon_sym_RBRACE,
    ACTIONS(19011), 1,
      anon_sym_COMMA,
    STATE(15837), 1,
      aux_sym_namespace_selectors_repeat1,
    STATE(15340), 2,
      sym_comment,
      sym_block_comment,
  [634799] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19013), 1,
      anon_sym_COMMA,
    ACTIONS(19015), 1,
      anon_sym_RBRACK,
    STATE(15365), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15341), 2,
      sym_comment,
      sym_block_comment,
  [634819] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17175), 1,
      anon_sym_case,
    STATE(14457), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16060), 1,
      sym_case_clause,
    STATE(15342), 2,
      sym_comment,
      sym_block_comment,
  [634839] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19017), 1,
      anon_sym_COMMA,
    ACTIONS(19019), 1,
      anon_sym_RPAREN,
    STATE(14742), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15343), 2,
      sym_comment,
      sym_block_comment,
  [634859] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5530), 1,
      anon_sym_RBRACK,
    ACTIONS(19021), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15344), 2,
      sym_comment,
      sym_block_comment,
  [634879] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(19023), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15345), 2,
      sym_comment,
      sym_block_comment,
  [634899] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19023), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15346), 2,
      sym_comment,
      sym_block_comment,
  [634919] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15347), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17447), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [634935] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19025), 1,
      anon_sym_COMMA,
    ACTIONS(19027), 1,
      anon_sym_RBRACK,
    STATE(15359), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15348), 2,
      sym_comment,
      sym_block_comment,
  [634955] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8188), 1,
      anon_sym_RPAREN,
    ACTIONS(19029), 1,
      anon_sym_COMMA,
    STATE(15376), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15349), 2,
      sym_comment,
      sym_block_comment,
  [634975] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16152), 1,
      anon_sym_COLON,
    ACTIONS(16154), 1,
      anon_sym_LBRACE,
    STATE(14429), 1,
      sym_enum_body,
    STATE(15350), 2,
      sym_comment,
      sym_block_comment,
  [634995] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19031), 1,
      anon_sym_COMMA,
    ACTIONS(19033), 1,
      anon_sym_RBRACK,
    STATE(15095), 1,
      aux_sym_type_parameters_repeat1,
    STATE(15351), 2,
      sym_comment,
      sym_block_comment,
  [635015] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12656), 1,
      anon_sym_RPAREN,
    ACTIONS(19035), 1,
      anon_sym_COMMA,
    STATE(15380), 1,
      aux_sym_parameters_repeat1,
    STATE(15352), 2,
      sym_comment,
      sym_block_comment,
  [635035] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17440), 1,
      anon_sym_RPAREN,
    ACTIONS(19037), 1,
      anon_sym_COMMA,
    STATE(15383), 1,
      aux_sym_parameters_repeat1,
    STATE(15353), 2,
      sym_comment,
      sym_block_comment,
  [635055] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5182), 1,
      anon_sym_RPAREN,
    ACTIONS(19039), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15354), 2,
      sym_comment,
      sym_block_comment,
  [635075] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17438), 1,
      anon_sym_COMMA,
    ACTIONS(17440), 1,
      anon_sym_RPAREN,
    STATE(15385), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15355), 2,
      sym_comment,
      sym_block_comment,
  [635095] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18990), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15356), 2,
      sym_comment,
      sym_block_comment,
  [635115] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12656), 1,
      anon_sym_RPAREN,
    ACTIONS(19035), 1,
      anon_sym_COMMA,
    STATE(15339), 1,
      aux_sym_parameters_repeat1,
    STATE(15357), 2,
      sym_comment,
      sym_block_comment,
  [635135] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5644), 1,
      anon_sym_RPAREN,
    ACTIONS(19041), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15358), 2,
      sym_comment,
      sym_block_comment,
  [635155] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6050), 1,
      anon_sym_RBRACK,
    ACTIONS(19043), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15359), 2,
      sym_comment,
      sym_block_comment,
  [635175] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13708), 1,
      anon_sym_LPAREN,
    STATE(13662), 1,
      sym_parameters,
    STATE(13782), 1,
      sym__using_parameters_clause,
    STATE(15360), 2,
      sym_comment,
      sym_block_comment,
  [635195] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(19045), 1,
      anon_sym_RPAREN,
    STATE(14800), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(15361), 2,
      sym_comment,
      sym_block_comment,
  [635215] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15362), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16710), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [635231] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19047), 1,
      anon_sym_COMMA,
    ACTIONS(19049), 1,
      anon_sym_RPAREN,
    STATE(15460), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15363), 2,
      sym_comment,
      sym_block_comment,
  [635251] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5226), 1,
      anon_sym_RPAREN,
    ACTIONS(19051), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15364), 2,
      sym_comment,
      sym_block_comment,
  [635271] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5694), 1,
      anon_sym_RBRACK,
    ACTIONS(19053), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15365), 2,
      sym_comment,
      sym_block_comment,
  [635291] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19055), 1,
      anon_sym_COMMA,
    ACTIONS(19057), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15366), 2,
      sym_comment,
      sym_block_comment,
  [635311] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19059), 1,
      anon_sym_COMMA,
    ACTIONS(19061), 1,
      anon_sym_RPAREN,
    STATE(15575), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15367), 2,
      sym_comment,
      sym_block_comment,
  [635331] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19063), 1,
      anon_sym_COMMA,
    ACTIONS(19065), 1,
      anon_sym_RPAREN,
    STATE(15068), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15368), 2,
      sym_comment,
      sym_block_comment,
  [635351] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16152), 1,
      anon_sym_COLON,
    ACTIONS(16154), 1,
      anon_sym_LBRACE,
    STATE(14438), 1,
      sym_enum_body,
    STATE(15369), 2,
      sym_comment,
      sym_block_comment,
  [635371] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17171), 1,
      anon_sym_case,
    STATE(14539), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16031), 1,
      sym_type_case_clause,
    STATE(15370), 2,
      sym_comment,
      sym_block_comment,
  [635391] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19067), 1,
      anon_sym_COMMA,
    ACTIONS(19069), 1,
      anon_sym_RBRACK,
    STATE(14921), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15371), 2,
      sym_comment,
      sym_block_comment,
  [635411] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19071), 1,
      anon_sym_COMMA,
    ACTIONS(19073), 1,
      anon_sym_RBRACK,
    STATE(15387), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15372), 2,
      sym_comment,
      sym_block_comment,
  [635431] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8298), 1,
      anon_sym_RPAREN,
    ACTIONS(19075), 1,
      anon_sym_COMMA,
    STATE(15393), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15373), 2,
      sym_comment,
      sym_block_comment,
  [635451] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8300), 1,
      anon_sym_RPAREN,
    ACTIONS(19077), 1,
      anon_sym_COMMA,
    STATE(15395), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15374), 2,
      sym_comment,
      sym_block_comment,
  [635471] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4508), 1,
      sym__indent,
    STATE(10439), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15375), 2,
      sym_comment,
      sym_block_comment,
  [635489] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8300), 1,
      anon_sym_RPAREN,
    ACTIONS(19077), 1,
      anon_sym_COMMA,
    STATE(15247), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15376), 2,
      sym_comment,
      sym_block_comment,
  [635509] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19079), 1,
      anon_sym_COMMA,
    ACTIONS(19081), 1,
      anon_sym_RBRACK,
    STATE(15386), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15377), 2,
      sym_comment,
      sym_block_comment,
  [635529] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16790), 1,
      anon_sym_RBRACE,
    ACTIONS(16792), 1,
      anon_sym_COMMA,
    STATE(15396), 1,
      aux_sym_namespace_selectors_repeat1,
    STATE(15378), 2,
      sym_comment,
      sym_block_comment,
  [635549] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5194), 1,
      anon_sym_RPAREN,
    ACTIONS(19083), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15379), 2,
      sym_comment,
      sym_block_comment,
  [635569] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12614), 1,
      anon_sym_RPAREN,
    ACTIONS(19085), 1,
      anon_sym_COMMA,
    STATE(15339), 1,
      aux_sym_parameters_repeat1,
    STATE(15380), 2,
      sym_comment,
      sym_block_comment,
  [635589] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5284), 1,
      anon_sym_RBRACK,
    ACTIONS(19087), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15381), 2,
      sym_comment,
      sym_block_comment,
  [635609] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5118), 1,
      anon_sym_RPAREN,
    ACTIONS(19089), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15382), 2,
      sym_comment,
      sym_block_comment,
  [635629] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5054), 1,
      anon_sym_RPAREN,
    ACTIONS(19091), 1,
      anon_sym_COMMA,
    STATE(15339), 1,
      aux_sym_parameters_repeat1,
    STATE(15383), 2,
      sym_comment,
      sym_block_comment,
  [635649] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5420), 1,
      anon_sym_RBRACK,
    ACTIONS(19093), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15384), 2,
      sym_comment,
      sym_block_comment,
  [635669] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5054), 1,
      anon_sym_RPAREN,
    ACTIONS(19095), 1,
      anon_sym_COMMA,
    STATE(15459), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15385), 2,
      sym_comment,
      sym_block_comment,
  [635689] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5372), 1,
      anon_sym_RBRACK,
    ACTIONS(19097), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15386), 2,
      sym_comment,
      sym_block_comment,
  [635709] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6058), 1,
      anon_sym_RBRACK,
    ACTIONS(19099), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15387), 2,
      sym_comment,
      sym_block_comment,
  [635729] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7262), 1,
      anon_sym_RPAREN,
    ACTIONS(19101), 1,
      anon_sym_COMMA,
    STATE(14800), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(15388), 2,
      sym_comment,
      sym_block_comment,
  [635749] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16152), 1,
      anon_sym_COLON,
    ACTIONS(16154), 1,
      anon_sym_LBRACE,
    STATE(14699), 1,
      sym_enum_body,
    STATE(15389), 2,
      sym_comment,
      sym_block_comment,
  [635769] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4692), 1,
      sym__indent,
    STATE(8175), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15390), 2,
      sym_comment,
      sym_block_comment,
  [635787] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8304), 1,
      anon_sym_RPAREN,
    ACTIONS(19103), 1,
      anon_sym_COMMA,
    STATE(15402), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15391), 2,
      sym_comment,
      sym_block_comment,
  [635807] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4496), 1,
      sym__indent,
    STATE(10124), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15392), 2,
      sym_comment,
      sym_block_comment,
  [635825] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8304), 1,
      anon_sym_RPAREN,
    ACTIONS(19103), 1,
      anon_sym_COMMA,
    STATE(15247), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15393), 2,
      sym_comment,
      sym_block_comment,
  [635845] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5760), 1,
      anon_sym_RBRACK,
    ACTIONS(19105), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15394), 2,
      sym_comment,
      sym_block_comment,
  [635865] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8306), 1,
      anon_sym_RPAREN,
    ACTIONS(19107), 1,
      anon_sym_COMMA,
    STATE(15247), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15395), 2,
      sym_comment,
      sym_block_comment,
  [635885] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12498), 1,
      anon_sym_RBRACE,
    ACTIONS(19109), 1,
      anon_sym_COMMA,
    STATE(15837), 1,
      aux_sym_namespace_selectors_repeat1,
    STATE(15396), 2,
      sym_comment,
      sym_block_comment,
  [635905] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19111), 1,
      anon_sym_COMMA,
    ACTIONS(19113), 1,
      anon_sym_RPAREN,
    STATE(14755), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15397), 2,
      sym_comment,
      sym_block_comment,
  [635925] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16480), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [635941] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19115), 1,
      anon_sym_COMMA,
    ACTIONS(19117), 1,
      anon_sym_RBRACK,
    STATE(15423), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15399), 2,
      sym_comment,
      sym_block_comment,
  [635961] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19119), 1,
      anon_sym_COMMA,
    ACTIONS(19121), 1,
      anon_sym_RBRACK,
    STATE(15406), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15400), 2,
      sym_comment,
      sym_block_comment,
  [635981] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8334), 1,
      anon_sym_RPAREN,
    ACTIONS(19123), 1,
      anon_sym_COMMA,
    STATE(15405), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15401), 2,
      sym_comment,
      sym_block_comment,
  [636001] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8308), 1,
      anon_sym_RPAREN,
    ACTIONS(19125), 1,
      anon_sym_COMMA,
    STATE(15247), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15402), 2,
      sym_comment,
      sym_block_comment,
  [636021] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19127), 1,
      anon_sym_COMMA,
    ACTIONS(19130), 1,
      anon_sym_RBRACK,
    STATE(15403), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_type_lambda_repeat1,
  [636039] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5214), 1,
      anon_sym_RPAREN,
    ACTIONS(19132), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15404), 2,
      sym_comment,
      sym_block_comment,
  [636059] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8336), 1,
      anon_sym_RPAREN,
    ACTIONS(19134), 1,
      anon_sym_COMMA,
    STATE(15247), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15405), 2,
      sym_comment,
      sym_block_comment,
  [636079] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6068), 1,
      anon_sym_RBRACK,
    ACTIONS(19136), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15406), 2,
      sym_comment,
      sym_block_comment,
  [636099] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19138), 1,
      anon_sym_COMMA,
    ACTIONS(19140), 1,
      anon_sym_RPAREN,
    STATE(14836), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15407), 2,
      sym_comment,
      sym_block_comment,
  [636119] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15671), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(8802), 1,
      sym_type_arguments,
    STATE(15408), 2,
      sym_comment,
      sym_block_comment,
  [636139] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19142), 1,
      anon_sym_COMMA,
    ACTIONS(19144), 1,
      anon_sym_RPAREN,
    STATE(15217), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15409), 2,
      sym_comment,
      sym_block_comment,
  [636159] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19146), 1,
      anon_sym_COMMA,
    ACTIONS(19148), 1,
      anon_sym_RPAREN,
    STATE(14831), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15410), 2,
      sym_comment,
      sym_block_comment,
  [636179] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19150), 1,
      anon_sym_COMMA,
    ACTIONS(19152), 1,
      anon_sym_RBRACK,
    STATE(15415), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15411), 2,
      sym_comment,
      sym_block_comment,
  [636199] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5624), 1,
      anon_sym_RPAREN,
    ACTIONS(19154), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15412), 2,
      sym_comment,
      sym_block_comment,
  [636219] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5230), 1,
      anon_sym_RPAREN,
    ACTIONS(19156), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15413), 2,
      sym_comment,
      sym_block_comment,
  [636239] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19158), 1,
      anon_sym_COMMA,
    ACTIONS(19160), 1,
      anon_sym_RBRACK,
    STATE(15421), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15414), 2,
      sym_comment,
      sym_block_comment,
  [636259] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6076), 1,
      anon_sym_RBRACK,
    ACTIONS(19162), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15415), 2,
      sym_comment,
      sym_block_comment,
  [636279] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13397), 1,
      anon_sym_LPAREN,
    STATE(13330), 1,
      sym_parameters,
    STATE(13396), 1,
      sym__using_parameters_clause,
    STATE(15416), 2,
      sym_comment,
      sym_block_comment,
  [636299] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6028), 1,
      anon_sym_RPAREN,
    ACTIONS(19164), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15417), 2,
      sym_comment,
      sym_block_comment,
  [636319] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13374), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(5685), 1,
      sym_type_arguments,
    STATE(15418), 2,
      sym_comment,
      sym_block_comment,
  [636339] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16645), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [636355] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5584), 1,
      anon_sym_RPAREN,
    ACTIONS(19166), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15420), 2,
      sym_comment,
      sym_block_comment,
  [636375] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5224), 1,
      anon_sym_RBRACK,
    ACTIONS(19168), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15421), 2,
      sym_comment,
      sym_block_comment,
  [636395] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19170), 1,
      anon_sym_COMMA,
    ACTIONS(19172), 1,
      anon_sym_RPAREN,
    STATE(14773), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15422), 2,
      sym_comment,
      sym_block_comment,
  [636415] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6112), 1,
      anon_sym_RBRACK,
    ACTIONS(19174), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15423), 2,
      sym_comment,
      sym_block_comment,
  [636435] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19176), 1,
      anon_sym_COMMA,
    ACTIONS(19178), 1,
      anon_sym_RBRACK,
    STATE(15430), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15424), 2,
      sym_comment,
      sym_block_comment,
  [636455] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(19180), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [636471] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(19182), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15426), 2,
      sym_comment,
      sym_block_comment,
  [636491] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5248), 1,
      anon_sym_RPAREN,
    ACTIONS(19184), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15427), 2,
      sym_comment,
      sym_block_comment,
  [636511] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4308), 1,
      sym__indent,
    STATE(6586), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15428), 2,
      sym_comment,
      sym_block_comment,
  [636529] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(19186), 1,
      sym__interpolated_string_end,
    STATE(15462), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15429), 2,
      sym_comment,
      sym_block_comment,
  [636549] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6086), 1,
      anon_sym_RBRACK,
    ACTIONS(19188), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15430), 2,
      sym_comment,
      sym_block_comment,
  [636569] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19186), 1,
      sym__interpolated_multiline_string_end,
    STATE(15466), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15431), 2,
      sym_comment,
      sym_block_comment,
  [636589] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19190), 1,
      anon_sym_COMMA,
    ACTIONS(19192), 1,
      anon_sym_RPAREN,
    STATE(15268), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15432), 2,
      sym_comment,
      sym_block_comment,
  [636609] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10868), 1,
      sym__arrow_then_type,
    ACTIONS(19194), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15433), 2,
      sym_comment,
      sym_block_comment,
  [636627] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(19196), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15434), 2,
      sym_comment,
      sym_block_comment,
  [636645] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19199), 1,
      anon_sym_COMMA,
    ACTIONS(19201), 1,
      anon_sym_RPAREN,
    STATE(15094), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15435), 2,
      sym_comment,
      sym_block_comment,
  [636665] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19203), 1,
      anon_sym_COMMA,
    ACTIONS(19205), 1,
      anon_sym_RPAREN,
    STATE(15475), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15436), 2,
      sym_comment,
      sym_block_comment,
  [636685] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19207), 1,
      anon_sym_COMMA,
    ACTIONS(19209), 1,
      anon_sym_RBRACK,
    STATE(15440), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15437), 2,
      sym_comment,
      sym_block_comment,
  [636705] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19211), 1,
      anon_sym_COMMA,
    ACTIONS(19213), 1,
      anon_sym_RBRACK,
    STATE(15443), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15438), 2,
      sym_comment,
      sym_block_comment,
  [636725] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5754), 1,
      anon_sym_RPAREN,
    ACTIONS(19215), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15439), 2,
      sym_comment,
      sym_block_comment,
  [636745] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6094), 1,
      anon_sym_RBRACK,
    ACTIONS(19217), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15440), 2,
      sym_comment,
      sym_block_comment,
  [636765] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5620), 1,
      anon_sym_RPAREN,
    ACTIONS(19219), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15441), 2,
      sym_comment,
      sym_block_comment,
  [636785] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15413), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(8372), 1,
      sym_type_arguments,
    STATE(15442), 2,
      sym_comment,
      sym_block_comment,
  [636805] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5856), 1,
      anon_sym_RBRACK,
    ACTIONS(19221), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15443), 2,
      sym_comment,
      sym_block_comment,
  [636825] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16392), 1,
      anon_sym_LBRACK,
    STATE(10254), 1,
      sym_type_arguments,
    STATE(15444), 2,
      sym_comment,
      sym_block_comment,
  [636845] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19223), 1,
      anon_sym_COMMA,
    ACTIONS(19225), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15445), 2,
      sym_comment,
      sym_block_comment,
  [636865] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19227), 1,
      anon_sym_COMMA,
    ACTIONS(19229), 1,
      anon_sym_RPAREN,
    STATE(15120), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15446), 2,
      sym_comment,
      sym_block_comment,
  [636885] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19231), 1,
      anon_sym_COMMA,
    ACTIONS(19233), 1,
      anon_sym_RBRACK,
    STATE(15456), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15447), 2,
      sym_comment,
      sym_block_comment,
  [636905] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15873), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9356), 1,
      sym_type_arguments,
    STATE(15448), 2,
      sym_comment,
      sym_block_comment,
  [636925] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(19235), 1,
      sym__interpolated_string_end,
    STATE(15485), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15449), 2,
      sym_comment,
      sym_block_comment,
  [636945] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15450), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(18721), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [636961] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19235), 1,
      sym__interpolated_multiline_string_end,
    STATE(15488), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15451), 2,
      sym_comment,
      sym_block_comment,
  [636981] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5260), 1,
      anon_sym_RPAREN,
    ACTIONS(19237), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15452), 2,
      sym_comment,
      sym_block_comment,
  [637001] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19239), 1,
      anon_sym_COMMA,
    ACTIONS(19241), 1,
      anon_sym_RPAREN,
    STATE(15417), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15453), 2,
      sym_comment,
      sym_block_comment,
  [637021] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19243), 1,
      anon_sym_COMMA,
    ACTIONS(19245), 1,
      anon_sym_RPAREN,
    STATE(15283), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15454), 2,
      sym_comment,
      sym_block_comment,
  [637041] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(16986), 1,
      sym__arrow_then_type,
    ACTIONS(19247), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15455), 2,
      sym_comment,
      sym_block_comment,
  [637059] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6106), 1,
      anon_sym_RBRACK,
    ACTIONS(19249), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15456), 2,
      sym_comment,
      sym_block_comment,
  [637079] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19251), 1,
      anon_sym_COMMA,
    ACTIONS(19253), 1,
      anon_sym_RBRACK,
    STATE(15492), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15457), 2,
      sym_comment,
      sym_block_comment,
  [637099] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19255), 1,
      anon_sym_COMMA,
    ACTIONS(19257), 1,
      anon_sym_RBRACK,
    STATE(15463), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15458), 2,
      sym_comment,
      sym_block_comment,
  [637119] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19259), 1,
      anon_sym_COMMA,
    ACTIONS(19262), 1,
      anon_sym_RPAREN,
    STATE(15459), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__using_parameters_clause_repeat1,
  [637137] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5668), 1,
      anon_sym_RPAREN,
    ACTIONS(19264), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15460), 2,
      sym_comment,
      sym_block_comment,
  [637157] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19266), 1,
      anon_sym_COMMA,
    ACTIONS(19268), 1,
      anon_sym_RPAREN,
    STATE(15156), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15461), 2,
      sym_comment,
      sym_block_comment,
  [637177] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(19270), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15462), 2,
      sym_comment,
      sym_block_comment,
  [637197] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6064), 1,
      anon_sym_RBRACK,
    ACTIONS(19272), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15463), 2,
      sym_comment,
      sym_block_comment,
  [637217] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19274), 1,
      anon_sym_COMMA,
    ACTIONS(19276), 1,
      anon_sym_RBRACK,
    STATE(15468), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15464), 2,
      sym_comment,
      sym_block_comment,
  [637237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(19262), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15465), 2,
      sym_comment,
      sym_block_comment,
  [637255] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19270), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15466), 2,
      sym_comment,
      sym_block_comment,
  [637275] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5812), 1,
      anon_sym_RPAREN,
    ACTIONS(19278), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15467), 2,
      sym_comment,
      sym_block_comment,
  [637295] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5670), 1,
      anon_sym_RBRACK,
    ACTIONS(19280), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15468), 2,
      sym_comment,
      sym_block_comment,
  [637315] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16160), 1,
      anon_sym_COLON,
    ACTIONS(16162), 1,
      anon_sym_LBRACE,
    STATE(14298), 1,
      sym_enum_body,
    STATE(15469), 2,
      sym_comment,
      sym_block_comment,
  [637335] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19282), 1,
      anon_sym_COMMA,
    ACTIONS(19284), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15470), 2,
      sym_comment,
      sym_block_comment,
  [637355] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(19286), 1,
      sym__interpolated_string_end,
    STATE(15538), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15471), 2,
      sym_comment,
      sym_block_comment,
  [637375] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19286), 1,
      sym__interpolated_multiline_string_end,
    STATE(15571), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15472), 2,
      sym_comment,
      sym_block_comment,
  [637395] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(19288), 1,
      anon_sym_RPAREN,
    STATE(14800), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(15473), 2,
      sym_comment,
      sym_block_comment,
  [637415] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16402), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [637431] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5810), 1,
      anon_sym_RPAREN,
    ACTIONS(19290), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15475), 2,
      sym_comment,
      sym_block_comment,
  [637451] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19292), 1,
      anon_sym_COMMA,
    ACTIONS(19294), 1,
      anon_sym_RPAREN,
    STATE(15183), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15476), 2,
      sym_comment,
      sym_block_comment,
  [637471] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19296), 1,
      anon_sym_COMMA,
    ACTIONS(19298), 1,
      anon_sym_RPAREN,
    STATE(14762), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15477), 2,
      sym_comment,
      sym_block_comment,
  [637491] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19300), 1,
      anon_sym_COMMA,
    ACTIONS(19302), 1,
      anon_sym_RBRACK,
    STATE(15507), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15478), 2,
      sym_comment,
      sym_block_comment,
  [637511] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15931), 3,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_derives,
  [637527] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19304), 1,
      anon_sym_COMMA,
    ACTIONS(19306), 1,
      anon_sym_RBRACK,
    STATE(15487), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15480), 2,
      sym_comment,
      sym_block_comment,
  [637547] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17558), 1,
      anon_sym_EQ,
    ACTIONS(17556), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15481), 2,
      sym_comment,
      sym_block_comment,
  [637565] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5318), 1,
      anon_sym_RPAREN,
    ACTIONS(19308), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15482), 2,
      sym_comment,
      sym_block_comment,
  [637585] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19310), 1,
      anon_sym_COMMA,
    ACTIONS(19312), 1,
      anon_sym_RBRACK,
    STATE(15489), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15483), 2,
      sym_comment,
      sym_block_comment,
  [637605] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5712), 1,
      anon_sym_RPAREN,
    ACTIONS(19314), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15484), 2,
      sym_comment,
      sym_block_comment,
  [637625] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(19316), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15485), 2,
      sym_comment,
      sym_block_comment,
  [637645] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15486), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(19318), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [637661] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5332), 1,
      anon_sym_RBRACK,
    ACTIONS(19320), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15487), 2,
      sym_comment,
      sym_block_comment,
  [637681] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19316), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15488), 2,
      sym_comment,
      sym_block_comment,
  [637701] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5414), 1,
      anon_sym_RBRACK,
    ACTIONS(19322), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15489), 2,
      sym_comment,
      sym_block_comment,
  [637721] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15871), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9400), 1,
      sym_type_arguments,
    STATE(15490), 2,
      sym_comment,
      sym_block_comment,
  [637741] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17333), 1,
      anon_sym_EQ,
    ACTIONS(17331), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15491), 2,
      sym_comment,
      sym_block_comment,
  [637759] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5696), 1,
      anon_sym_RBRACK,
    ACTIONS(19324), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15492), 2,
      sym_comment,
      sym_block_comment,
  [637779] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17319), 1,
      anon_sym_EQ,
    ACTIONS(17317), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15493), 2,
      sym_comment,
      sym_block_comment,
  [637797] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5274), 1,
      anon_sym_RPAREN,
    ACTIONS(19326), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15494), 2,
      sym_comment,
      sym_block_comment,
  [637817] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19328), 1,
      anon_sym_COMMA,
    ACTIONS(19330), 1,
      anon_sym_RPAREN,
    STATE(15245), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15495), 2,
      sym_comment,
      sym_block_comment,
  [637837] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4198), 1,
      sym__indent,
    STATE(8832), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15496), 2,
      sym_comment,
      sym_block_comment,
  [637855] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19332), 1,
      anon_sym_COMMA,
    ACTIONS(19334), 1,
      anon_sym_RBRACK,
    STATE(15501), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15497), 2,
      sym_comment,
      sym_block_comment,
  [637875] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15498), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(19336), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [637891] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(19338), 1,
      sym__interpolated_string_end,
    STATE(14889), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15499), 2,
      sym_comment,
      sym_block_comment,
  [637911] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5834), 1,
      anon_sym_RPAREN,
    ACTIONS(19340), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15500), 2,
      sym_comment,
      sym_block_comment,
  [637931] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5442), 1,
      anon_sym_RBRACK,
    ACTIONS(19342), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15501), 2,
      sym_comment,
      sym_block_comment,
  [637951] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(19344), 1,
      sym__interpolated_string_end,
    STATE(15526), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15502), 2,
      sym_comment,
      sym_block_comment,
  [637971] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19344), 1,
      sym__interpolated_multiline_string_end,
    STATE(15527), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15503), 2,
      sym_comment,
      sym_block_comment,
  [637991] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19346), 1,
      anon_sym_COMMA,
    ACTIONS(19348), 1,
      anon_sym_RPAREN,
    STATE(14894), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15504), 2,
      sym_comment,
      sym_block_comment,
  [638011] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19350), 1,
      anon_sym_COMMA,
    ACTIONS(19352), 1,
      anon_sym_RBRACK,
    STATE(15530), 1,
      aux_sym_type_parameters_repeat1,
    STATE(15505), 2,
      sym_comment,
      sym_block_comment,
  [638031] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19338), 1,
      sym__interpolated_multiline_string_end,
    STATE(14890), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15506), 2,
      sym_comment,
      sym_block_comment,
  [638051] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5464), 1,
      anon_sym_RBRACK,
    ACTIONS(19354), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15507), 2,
      sym_comment,
      sym_block_comment,
  [638071] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12618), 1,
      anon_sym_RPAREN,
    ACTIONS(19356), 1,
      anon_sym_COMMA,
    STATE(15536), 1,
      aux_sym_parameters_repeat1,
    STATE(15508), 2,
      sym_comment,
      sym_block_comment,
  [638091] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19358), 1,
      anon_sym_COMMA,
    ACTIONS(19360), 1,
      anon_sym_RPAREN,
    STATE(15537), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15509), 2,
      sym_comment,
      sym_block_comment,
  [638111] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11244), 1,
      sym__arrow_then_type,
    ACTIONS(19362), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15510), 2,
      sym_comment,
      sym_block_comment,
  [638129] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4244), 1,
      sym__indent,
    STATE(9208), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15511), 2,
      sym_comment,
      sym_block_comment,
  [638147] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19364), 1,
      anon_sym_COMMA,
    ACTIONS(19366), 1,
      anon_sym_RBRACK,
    STATE(15517), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15512), 2,
      sym_comment,
      sym_block_comment,
  [638167] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5794), 1,
      anon_sym_RPAREN,
    ACTIONS(19368), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15513), 2,
      sym_comment,
      sym_block_comment,
  [638187] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19370), 1,
      anon_sym_COMMA,
    ACTIONS(19372), 1,
      anon_sym_RPAREN,
    STATE(15269), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15514), 2,
      sym_comment,
      sym_block_comment,
  [638207] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19374), 1,
      anon_sym_DOLLAR,
    STATE(15515), 2,
      sym_comment,
      sym_block_comment,
    STATE(16105), 2,
      sym__dollar_escape,
      sym_interpolation,
  [638225] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19376), 1,
      anon_sym_COMMA,
    ACTIONS(19378), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15516), 2,
      sym_comment,
      sym_block_comment,
  [638245] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5758), 1,
      anon_sym_RBRACK,
    ACTIONS(19380), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15517), 2,
      sym_comment,
      sym_block_comment,
  [638265] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19382), 1,
      anon_sym_COMMA,
    ACTIONS(19384), 1,
      anon_sym_RBRACK,
    STATE(15528), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15518), 2,
      sym_comment,
      sym_block_comment,
  [638285] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    ACTIONS(19386), 1,
      anon_sym_COLON,
    STATE(15610), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15519), 2,
      sym_comment,
      sym_block_comment,
  [638305] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    ACTIONS(19388), 1,
      anon_sym_COLON,
    STATE(15610), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15520), 2,
      sym_comment,
      sym_block_comment,
  [638325] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    ACTIONS(19390), 1,
      anon_sym_COLON,
    STATE(15610), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15521), 2,
      sym_comment,
      sym_block_comment,
  [638345] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12406), 1,
      anon_sym_COMMA,
    ACTIONS(19392), 1,
      anon_sym_COLON,
    STATE(15610), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15522), 2,
      sym_comment,
      sym_block_comment,
  [638365] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19394), 1,
      anon_sym_COMMA,
    ACTIONS(19396), 1,
      anon_sym_RBRACK,
    STATE(15543), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15523), 2,
      sym_comment,
      sym_block_comment,
  [638385] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5358), 1,
      anon_sym_RPAREN,
    ACTIONS(19398), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 2,
      sym_comment,
      sym_block_comment,
  [638405] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19400), 1,
      anon_sym_COMMA,
    ACTIONS(19402), 1,
      anon_sym_RPAREN,
    STATE(15484), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15525), 2,
      sym_comment,
      sym_block_comment,
  [638425] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(19404), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15526), 2,
      sym_comment,
      sym_block_comment,
  [638445] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19404), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15527), 2,
      sym_comment,
      sym_block_comment,
  [638465] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5648), 1,
      anon_sym_RBRACK,
    ACTIONS(19406), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15528), 2,
      sym_comment,
      sym_block_comment,
  [638485] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8134), 1,
      anon_sym_RPAREN,
    ACTIONS(19408), 1,
      anon_sym_COMMA,
    STATE(15549), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15529), 2,
      sym_comment,
      sym_block_comment,
  [638505] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19410), 1,
      anon_sym_COMMA,
    ACTIONS(19412), 1,
      anon_sym_RBRACK,
    STATE(15095), 1,
      aux_sym_type_parameters_repeat1,
    STATE(15530), 2,
      sym_comment,
      sym_block_comment,
  [638525] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12616), 1,
      anon_sym_RPAREN,
    ACTIONS(19414), 1,
      anon_sym_COMMA,
    STATE(15550), 1,
      aux_sym_parameters_repeat1,
    STATE(15531), 2,
      sym_comment,
      sym_block_comment,
  [638545] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(19416), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15532), 2,
      sym_comment,
      sym_block_comment,
  [638565] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17385), 1,
      anon_sym_RPAREN,
    ACTIONS(19418), 1,
      anon_sym_COMMA,
    STATE(15551), 1,
      aux_sym_parameters_repeat1,
    STATE(15533), 2,
      sym_comment,
      sym_block_comment,
  [638585] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19420), 1,
      anon_sym_DOLLAR,
    STATE(15534), 2,
      sym_comment,
      sym_block_comment,
    STATE(16086), 2,
      sym__dollar_escape,
      sym_interpolation,
  [638603] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17383), 1,
      anon_sym_COMMA,
    ACTIONS(17385), 1,
      anon_sym_RPAREN,
    STATE(15552), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15535), 2,
      sym_comment,
      sym_block_comment,
  [638623] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12616), 1,
      anon_sym_RPAREN,
    ACTIONS(19414), 1,
      anon_sym_COMMA,
    STATE(15339), 1,
      aux_sym_parameters_repeat1,
    STATE(15536), 2,
      sym_comment,
      sym_block_comment,
  [638643] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6102), 1,
      anon_sym_RPAREN,
    ACTIONS(19422), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15537), 2,
      sym_comment,
      sym_block_comment,
  [638663] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(19424), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15538), 2,
      sym_comment,
      sym_block_comment,
  [638683] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10311), 1,
      anon_sym_COMMA,
    ACTIONS(19426), 1,
      anon_sym_RPAREN,
    STATE(14800), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(15539), 2,
      sym_comment,
      sym_block_comment,
  [638703] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(19428), 1,
      sym__interpolated_string_end,
    STATE(14795), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15540), 2,
      sym_comment,
      sym_block_comment,
  [638723] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(19430), 1,
      sym__interpolated_string_end,
    STATE(15831), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15541), 2,
      sym_comment,
      sym_block_comment,
  [638743] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19432), 1,
      anon_sym_COMMA,
    ACTIONS(19434), 1,
      anon_sym_RPAREN,
    STATE(15320), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15542), 2,
      sym_comment,
      sym_block_comment,
  [638763] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5396), 1,
      anon_sym_RBRACK,
    ACTIONS(19436), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15543), 2,
      sym_comment,
      sym_block_comment,
  [638783] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4204), 1,
      sym__indent,
    STATE(9561), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15544), 2,
      sym_comment,
      sym_block_comment,
  [638801] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19438), 1,
      anon_sym_COMMA,
    ACTIONS(19440), 1,
      anon_sym_RPAREN,
    STATE(14980), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15545), 2,
      sym_comment,
      sym_block_comment,
  [638821] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19430), 1,
      sym__interpolated_multiline_string_end,
    STATE(15833), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15546), 2,
      sym_comment,
      sym_block_comment,
  [638841] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8302), 1,
      anon_sym_RPAREN,
    ACTIONS(19442), 1,
      anon_sym_COMMA,
    STATE(15557), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15547), 2,
      sym_comment,
      sym_block_comment,
  [638861] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19444), 1,
      anon_sym_COMMA,
    ACTIONS(19446), 1,
      anon_sym_RBRACK,
    STATE(15146), 1,
      aux_sym_type_parameters_repeat1,
    STATE(15548), 2,
      sym_comment,
      sym_block_comment,
  [638881] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8302), 1,
      anon_sym_RPAREN,
    ACTIONS(19442), 1,
      anon_sym_COMMA,
    STATE(15247), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15549), 2,
      sym_comment,
      sym_block_comment,
  [638901] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12671), 1,
      anon_sym_RPAREN,
    ACTIONS(19448), 1,
      anon_sym_COMMA,
    STATE(15339), 1,
      aux_sym_parameters_repeat1,
    STATE(15550), 2,
      sym_comment,
      sym_block_comment,
  [638921] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5008), 1,
      anon_sym_RPAREN,
    ACTIONS(19450), 1,
      anon_sym_COMMA,
    STATE(15339), 1,
      aux_sym_parameters_repeat1,
    STATE(15551), 2,
      sym_comment,
      sym_block_comment,
  [638941] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5008), 1,
      anon_sym_RPAREN,
    ACTIONS(19452), 1,
      anon_sym_COMMA,
    STATE(15459), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15552), 2,
      sym_comment,
      sym_block_comment,
  [638961] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19454), 1,
      anon_sym_COMMA,
    ACTIONS(19456), 1,
      anon_sym_RBRACK,
    STATE(14902), 1,
      aux_sym_type_parameters_repeat1,
    STATE(15553), 2,
      sym_comment,
      sym_block_comment,
  [638981] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19458), 1,
      anon_sym_COMMA,
    ACTIONS(19460), 1,
      anon_sym_RBRACK,
    STATE(15559), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15554), 2,
      sym_comment,
      sym_block_comment,
  [639001] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7298), 1,
      anon_sym_RPAREN,
    ACTIONS(19462), 1,
      anon_sym_COMMA,
    STATE(14800), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(15555), 2,
      sym_comment,
      sym_block_comment,
  [639021] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5862), 1,
      anon_sym_RPAREN,
    ACTIONS(19464), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15556), 2,
      sym_comment,
      sym_block_comment,
  [639041] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8334), 1,
      anon_sym_RPAREN,
    ACTIONS(19123), 1,
      anon_sym_COMMA,
    STATE(15247), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15557), 2,
      sym_comment,
      sym_block_comment,
  [639061] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19466), 1,
      anon_sym_COMMA,
    ACTIONS(19468), 1,
      anon_sym_RBRACK,
    STATE(15568), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15558), 2,
      sym_comment,
      sym_block_comment,
  [639081] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5934), 1,
      anon_sym_RBRACK,
    ACTIONS(19470), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15559), 2,
      sym_comment,
      sym_block_comment,
  [639101] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8306), 1,
      anon_sym_RPAREN,
    ACTIONS(19107), 1,
      anon_sym_COMMA,
    STATE(15563), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15560), 2,
      sym_comment,
      sym_block_comment,
  [639121] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19472), 1,
      anon_sym_COMMA,
    ACTIONS(19474), 1,
      anon_sym_RBRACK,
    STATE(15602), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15561), 2,
      sym_comment,
      sym_block_comment,
  [639141] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19476), 1,
      anon_sym_COMMA,
    ACTIONS(19478), 1,
      anon_sym_RPAREN,
    STATE(15330), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15562), 2,
      sym_comment,
      sym_block_comment,
  [639161] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8310), 1,
      anon_sym_RPAREN,
    ACTIONS(19480), 1,
      anon_sym_COMMA,
    STATE(15247), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15563), 2,
      sym_comment,
      sym_block_comment,
  [639181] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11675), 1,
      sym__arrow_then_type,
    ACTIONS(19482), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15564), 2,
      sym_comment,
      sym_block_comment,
  [639199] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5786), 1,
      anon_sym_RPAREN,
    ACTIONS(19484), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15565), 2,
      sym_comment,
      sym_block_comment,
  [639219] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19486), 1,
      anon_sym_COMMA,
    ACTIONS(19488), 1,
      anon_sym_RPAREN,
    STATE(15364), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15566), 2,
      sym_comment,
      sym_block_comment,
  [639239] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19490), 1,
      anon_sym_COMMA,
    ACTIONS(19492), 1,
      anon_sym_RPAREN,
    STATE(15354), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15567), 2,
      sym_comment,
      sym_block_comment,
  [639259] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5204), 1,
      anon_sym_RBRACK,
    ACTIONS(19494), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15568), 2,
      sym_comment,
      sym_block_comment,
  [639279] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19496), 1,
      anon_sym_COMMA,
    ACTIONS(19498), 1,
      anon_sym_RBRACK,
    STATE(15573), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15569), 2,
      sym_comment,
      sym_block_comment,
  [639299] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11244), 1,
      sym__arrow_then_type,
    ACTIONS(19500), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15570), 2,
      sym_comment,
      sym_block_comment,
  [639317] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19424), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15571), 2,
      sym_comment,
      sym_block_comment,
  [639337] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5928), 1,
      anon_sym_RPAREN,
    ACTIONS(19502), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15572), 2,
      sym_comment,
      sym_block_comment,
  [639357] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5184), 1,
      anon_sym_RBRACK,
    ACTIONS(19504), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15573), 2,
      sym_comment,
      sym_block_comment,
  [639377] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(19506), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15574), 2,
      sym_comment,
      sym_block_comment,
  [639395] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6056), 1,
      anon_sym_RPAREN,
    ACTIONS(19508), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15575), 2,
      sym_comment,
      sym_block_comment,
  [639415] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19510), 1,
      anon_sym_COMMA,
    ACTIONS(19512), 1,
      anon_sym_RPAREN,
    STATE(15379), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15576), 2,
      sym_comment,
      sym_block_comment,
  [639435] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15645), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(8850), 1,
      sym_type_arguments,
    STATE(15577), 2,
      sym_comment,
      sym_block_comment,
  [639455] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19428), 1,
      sym__interpolated_multiline_string_end,
    STATE(14797), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15578), 2,
      sym_comment,
      sym_block_comment,
  [639475] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19514), 1,
      anon_sym_COMMA,
    ACTIONS(19516), 1,
      anon_sym_RBRACK,
    STATE(15586), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15579), 2,
      sym_comment,
      sym_block_comment,
  [639495] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17012), 1,
      anon_sym_RPAREN,
    ACTIONS(19518), 1,
      anon_sym_COMMA,
    STATE(15580), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_tuple_expression_repeat1,
  [639513] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19521), 1,
      anon_sym_COMMA,
    ACTIONS(19523), 1,
      anon_sym_RPAREN,
    STATE(15010), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15581), 2,
      sym_comment,
      sym_block_comment,
  [639533] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19525), 1,
      anon_sym_COLON,
    ACTIONS(19527), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15582), 2,
      sym_comment,
      sym_block_comment,
  [639551] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15609), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9167), 1,
      sym_type_arguments,
    STATE(15583), 2,
      sym_comment,
      sym_block_comment,
  [639571] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5400), 1,
      anon_sym_RPAREN,
    ACTIONS(19529), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15584), 2,
      sym_comment,
      sym_block_comment,
  [639591] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19531), 1,
      sym__interpolated_string_middle,
    ACTIONS(19534), 1,
      sym__interpolated_string_end,
    STATE(15585), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_interpolated_string_repeat1,
  [639609] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5198), 1,
      anon_sym_RBRACK,
    ACTIONS(19536), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15586), 2,
      sym_comment,
      sym_block_comment,
  [639629] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19538), 1,
      anon_sym_COMMA,
    ACTIONS(19540), 1,
      anon_sym_RBRACK,
    STATE(15597), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15587), 2,
      sym_comment,
      sym_block_comment,
  [639649] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19542), 1,
      anon_sym_COLON,
    ACTIONS(19544), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15588), 2,
      sym_comment,
      sym_block_comment,
  [639667] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(19546), 1,
      anon_sym_LBRACK,
    STATE(10786), 1,
      sym_type_arguments,
    STATE(15589), 2,
      sym_comment,
      sym_block_comment,
  [639687] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19548), 1,
      anon_sym_COMMA,
    ACTIONS(19551), 1,
      anon_sym_RPAREN,
    STATE(15590), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_bindings_repeat1,
  [639705] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19553), 1,
      anon_sym_COMMA,
    ACTIONS(19555), 1,
      anon_sym_RPAREN,
    STATE(15404), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15591), 2,
      sym_comment,
      sym_block_comment,
  [639725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15892), 1,
      anon_sym_STAR,
    ACTIONS(19557), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15592), 2,
      sym_comment,
      sym_block_comment,
  [639743] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(19559), 1,
      sym__interpolated_string_end,
    STATE(15711), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15593), 2,
      sym_comment,
      sym_block_comment,
  [639763] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5818), 1,
      anon_sym_RPAREN,
    ACTIONS(19561), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15594), 2,
      sym_comment,
      sym_block_comment,
  [639783] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19559), 1,
      sym__interpolated_multiline_string_end,
    STATE(15716), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15595), 2,
      sym_comment,
      sym_block_comment,
  [639803] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19563), 1,
      anon_sym_COMMA,
    ACTIONS(19565), 1,
      anon_sym_RBRACK,
    STATE(15600), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15596), 2,
      sym_comment,
      sym_block_comment,
  [639823] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5242), 1,
      anon_sym_RBRACK,
    ACTIONS(19567), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15597), 2,
      sym_comment,
      sym_block_comment,
  [639843] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19416), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15598), 2,
      sym_comment,
      sym_block_comment,
  [639863] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5954), 1,
      anon_sym_RPAREN,
    ACTIONS(19569), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15599), 2,
      sym_comment,
      sym_block_comment,
  [639883] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5216), 1,
      anon_sym_RBRACK,
    ACTIONS(19571), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15600), 2,
      sym_comment,
      sym_block_comment,
  [639903] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19573), 1,
      anon_sym_COMMA,
    ACTIONS(19575), 1,
      anon_sym_RPAREN,
    STATE(15382), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15601), 2,
      sym_comment,
      sym_block_comment,
  [639923] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5716), 1,
      anon_sym_RBRACK,
    ACTIONS(19577), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15602), 2,
      sym_comment,
      sym_block_comment,
  [639943] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15869), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(9611), 1,
      sym_type_arguments,
    STATE(15603), 2,
      sym_comment,
      sym_block_comment,
  [639963] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17506), 3,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ,
  [639979] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19579), 1,
      anon_sym_COMMA,
    ACTIONS(19581), 1,
      anon_sym_RPAREN,
    STATE(15298), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15605), 2,
      sym_comment,
      sym_block_comment,
  [639999] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11135), 1,
      sym__arrow_then_type,
    ACTIONS(19583), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15606), 2,
      sym_comment,
      sym_block_comment,
  [640017] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19585), 1,
      anon_sym_COMMA,
    ACTIONS(19587), 1,
      anon_sym_RPAREN,
    STATE(15413), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15607), 2,
      sym_comment,
      sym_block_comment,
  [640037] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19589), 1,
      anon_sym_COMMA,
    ACTIONS(19591), 1,
      anon_sym_RBRACK,
    STATE(15618), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15608), 2,
      sym_comment,
      sym_block_comment,
  [640057] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19593), 1,
      anon_sym_COMMA,
    ACTIONS(19595), 1,
      anon_sym_RPAREN,
    STATE(15049), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15609), 2,
      sym_comment,
      sym_block_comment,
  [640077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19597), 1,
      anon_sym_COLON,
    ACTIONS(19599), 1,
      anon_sym_COMMA,
    STATE(15610), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_val_declaration_repeat1,
  [640095] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(19602), 1,
      sym__interpolated_string_end,
    STATE(15623), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15611), 2,
      sym_comment,
      sym_block_comment,
  [640115] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19602), 1,
      sym__interpolated_multiline_string_end,
    STATE(15624), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15612), 2,
      sym_comment,
      sym_block_comment,
  [640135] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19604), 1,
      anon_sym_COMMA,
    ACTIONS(19606), 1,
      anon_sym_RBRACK,
    STATE(15626), 1,
      aux_sym_type_parameters_repeat1,
    STATE(15613), 2,
      sym_comment,
      sym_block_comment,
  [640155] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19608), 1,
      anon_sym_COMMA,
    ACTIONS(19610), 1,
      anon_sym_RPAREN,
    STATE(15627), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15614), 2,
      sym_comment,
      sym_block_comment,
  [640175] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11594), 1,
      sym__arrow_then_type,
    ACTIONS(19612), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15615), 2,
      sym_comment,
      sym_block_comment,
  [640193] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5416), 1,
      anon_sym_RPAREN,
    ACTIONS(19614), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15616), 2,
      sym_comment,
      sym_block_comment,
  [640213] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19616), 1,
      anon_sym_COMMA,
    ACTIONS(19618), 1,
      anon_sym_RPAREN,
    STATE(14859), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15617), 2,
      sym_comment,
      sym_block_comment,
  [640233] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5234), 1,
      anon_sym_RBRACK,
    ACTIONS(19620), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15618), 2,
      sym_comment,
      sym_block_comment,
  [640253] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19622), 1,
      anon_sym_COMMA,
    ACTIONS(19624), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15619), 2,
      sym_comment,
      sym_block_comment,
  [640273] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19626), 1,
      anon_sym_COMMA,
    ACTIONS(19628), 1,
      anon_sym_RBRACK,
    STATE(15633), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15620), 2,
      sym_comment,
      sym_block_comment,
  [640293] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19630), 1,
      anon_sym_COMMA,
    ACTIONS(19632), 1,
      anon_sym_RBRACK,
    STATE(15638), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15621), 2,
      sym_comment,
      sym_block_comment,
  [640313] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11939), 1,
      sym__arrow_then_type,
    ACTIONS(19634), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15622), 2,
      sym_comment,
      sym_block_comment,
  [640331] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(19636), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15623), 2,
      sym_comment,
      sym_block_comment,
  [640351] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19636), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15624), 2,
      sym_comment,
      sym_block_comment,
  [640371] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8122), 1,
      anon_sym_RPAREN,
    ACTIONS(19638), 1,
      anon_sym_COMMA,
    STATE(15648), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15625), 2,
      sym_comment,
      sym_block_comment,
  [640391] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19640), 1,
      anon_sym_COMMA,
    ACTIONS(19642), 1,
      anon_sym_RBRACK,
    STATE(15095), 1,
      aux_sym_type_parameters_repeat1,
    STATE(15626), 2,
      sym_comment,
      sym_block_comment,
  [640411] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5456), 1,
      anon_sym_RPAREN,
    ACTIONS(19644), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15627), 2,
      sym_comment,
      sym_block_comment,
  [640431] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5888), 1,
      anon_sym_RPAREN,
    ACTIONS(19646), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15628), 2,
      sym_comment,
      sym_block_comment,
  [640451] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19648), 1,
      anon_sym_COMMA,
    ACTIONS(19650), 1,
      anon_sym_RPAREN,
    STATE(15427), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15629), 2,
      sym_comment,
      sym_block_comment,
  [640471] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19652), 1,
      anon_sym_COMMA,
    ACTIONS(19654), 1,
      anon_sym_RBRACK,
    STATE(15632), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15630), 2,
      sym_comment,
      sym_block_comment,
  [640491] = 5,
    ACTIONS(17673), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19656), 1,
      anon_sym_STAR_SLASH,
    STATE(15048), 1,
      aux_sym_block_comment_repeat1,
    ACTIONS(18012), 2,
      anon_sym_SLASH_SLASH,
      aux_sym_block_comment_token1,
    STATE(15631), 2,
      sym_comment,
      sym_block_comment,
  [640509] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19658), 1,
      anon_sym_COMMA,
    ACTIONS(19660), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15632), 2,
      sym_comment,
      sym_block_comment,
  [640529] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5266), 1,
      anon_sym_RBRACK,
    ACTIONS(19662), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15633), 2,
      sym_comment,
      sym_block_comment,
  [640549] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(19664), 1,
      sym__interpolated_string_end,
    STATE(15735), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15634), 2,
      sym_comment,
      sym_block_comment,
  [640569] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19664), 1,
      sym__interpolated_multiline_string_end,
    STATE(15737), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15635), 2,
      sym_comment,
      sym_block_comment,
  [640589] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19666), 1,
      anon_sym_COMMA,
    ACTIONS(19668), 1,
      anon_sym_RBRACK,
    STATE(15651), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15636), 2,
      sym_comment,
      sym_block_comment,
  [640609] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19670), 1,
      anon_sym_COMMA,
    ACTIONS(19672), 1,
      anon_sym_RBRACK,
    STATE(15132), 1,
      aux_sym_type_parameters_repeat1,
    STATE(15637), 2,
      sym_comment,
      sym_block_comment,
  [640629] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5490), 1,
      anon_sym_RBRACK,
    ACTIONS(19674), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15638), 2,
      sym_comment,
      sym_block_comment,
  [640649] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19676), 1,
      anon_sym_COMMA,
    ACTIONS(19678), 1,
      anon_sym_RBRACK,
    STATE(15640), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15639), 2,
      sym_comment,
      sym_block_comment,
  [640669] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19680), 1,
      anon_sym_COMMA,
    ACTIONS(19682), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15640), 2,
      sym_comment,
      sym_block_comment,
  [640689] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19684), 1,
      anon_sym_COMMA,
    ACTIONS(19686), 1,
      anon_sym_RPAREN,
    STATE(15732), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15641), 2,
      sym_comment,
      sym_block_comment,
  [640709] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4238), 1,
      sym__indent,
    STATE(9676), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15642), 2,
      sym_comment,
      sym_block_comment,
  [640727] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13228), 1,
      sym__arrow_then_type,
    ACTIONS(19688), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15643), 2,
      sym_comment,
      sym_block_comment,
  [640745] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19690), 1,
      anon_sym_COMMA,
    ACTIONS(19692), 1,
      anon_sym_RBRACK,
    STATE(15645), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15644), 2,
      sym_comment,
      sym_block_comment,
  [640765] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19694), 1,
      anon_sym_COMMA,
    ACTIONS(19696), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15645), 2,
      sym_comment,
      sym_block_comment,
  [640785] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8348), 1,
      anon_sym_RPAREN,
    ACTIONS(19698), 1,
      anon_sym_COMMA,
    STATE(15670), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15646), 2,
      sym_comment,
      sym_block_comment,
  [640805] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5988), 1,
      anon_sym_RPAREN,
    ACTIONS(19700), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15647), 2,
      sym_comment,
      sym_block_comment,
  [640825] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8348), 1,
      anon_sym_RPAREN,
    ACTIONS(19698), 1,
      anon_sym_COMMA,
    STATE(15247), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15648), 2,
      sym_comment,
      sym_block_comment,
  [640845] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19702), 1,
      anon_sym_COMMA,
    ACTIONS(19704), 1,
      anon_sym_RBRACK,
    STATE(15650), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15649), 2,
      sym_comment,
      sym_block_comment,
  [640865] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19706), 1,
      anon_sym_COMMA,
    ACTIONS(19708), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15650), 2,
      sym_comment,
      sym_block_comment,
  [640885] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5250), 1,
      anon_sym_RBRACK,
    ACTIONS(19710), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15651), 2,
      sym_comment,
      sym_block_comment,
  [640905] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19712), 1,
      anon_sym_COMMA,
    ACTIONS(19714), 1,
      anon_sym_RBRACK,
    STATE(15653), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15652), 2,
      sym_comment,
      sym_block_comment,
  [640925] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19716), 1,
      anon_sym_COMMA,
    ACTIONS(19718), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15653), 2,
      sym_comment,
      sym_block_comment,
  [640945] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19720), 1,
      anon_sym_COMMA,
    ACTIONS(19722), 1,
      anon_sym_RBRACK,
    STATE(15655), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15654), 2,
      sym_comment,
      sym_block_comment,
  [640965] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19724), 1,
      anon_sym_COMMA,
    ACTIONS(19726), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15655), 2,
      sym_comment,
      sym_block_comment,
  [640985] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19728), 1,
      anon_sym_COMMA,
    ACTIONS(19730), 1,
      anon_sym_RBRACK,
    STATE(15657), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15656), 2,
      sym_comment,
      sym_block_comment,
  [641005] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19732), 1,
      anon_sym_COMMA,
    ACTIONS(19734), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15657), 2,
      sym_comment,
      sym_block_comment,
  [641025] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19736), 1,
      anon_sym_COMMA,
    ACTIONS(19738), 1,
      anon_sym_RPAREN,
    STATE(15212), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15658), 2,
      sym_comment,
      sym_block_comment,
  [641045] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19740), 1,
      anon_sym_COMMA,
    ACTIONS(19742), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15659), 2,
      sym_comment,
      sym_block_comment,
  [641065] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19744), 1,
      anon_sym_COMMA,
    ACTIONS(19746), 1,
      anon_sym_RBRACK,
    STATE(15661), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15660), 2,
      sym_comment,
      sym_block_comment,
  [641085] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19748), 1,
      anon_sym_COMMA,
    ACTIONS(19750), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15661), 2,
      sym_comment,
      sym_block_comment,
  [641105] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19752), 1,
      anon_sym_COMMA,
    ACTIONS(19754), 1,
      anon_sym_RBRACK,
    STATE(15663), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15662), 2,
      sym_comment,
      sym_block_comment,
  [641125] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19756), 1,
      anon_sym_COMMA,
    ACTIONS(19758), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15663), 2,
      sym_comment,
      sym_block_comment,
  [641145] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19760), 1,
      anon_sym_COMMA,
    ACTIONS(19762), 1,
      anon_sym_RBRACK,
    STATE(15666), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15664), 2,
      sym_comment,
      sym_block_comment,
  [641165] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19764), 1,
      anon_sym_COMMA,
    ACTIONS(19766), 1,
      anon_sym_RBRACK,
    STATE(15676), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15665), 2,
      sym_comment,
      sym_block_comment,
  [641185] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19768), 1,
      anon_sym_COMMA,
    ACTIONS(19770), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15666), 2,
      sym_comment,
      sym_block_comment,
  [641205] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19772), 1,
      anon_sym_COMMA,
    ACTIONS(19774), 1,
      anon_sym_RBRACK,
    STATE(15668), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15667), 2,
      sym_comment,
      sym_block_comment,
  [641225] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19776), 1,
      anon_sym_COMMA,
    ACTIONS(19778), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15668), 2,
      sym_comment,
      sym_block_comment,
  [641245] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5846), 1,
      anon_sym_RPAREN,
    ACTIONS(19780), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15669), 2,
      sym_comment,
      sym_block_comment,
  [641265] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8350), 1,
      anon_sym_RPAREN,
    ACTIONS(19782), 1,
      anon_sym_COMMA,
    STATE(15247), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15670), 2,
      sym_comment,
      sym_block_comment,
  [641285] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19784), 1,
      anon_sym_COMMA,
    ACTIONS(19786), 1,
      anon_sym_RBRACK,
    STATE(15672), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15671), 2,
      sym_comment,
      sym_block_comment,
  [641305] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19788), 1,
      anon_sym_COMMA,
    ACTIONS(19790), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15672), 2,
      sym_comment,
      sym_block_comment,
  [641325] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19792), 1,
      anon_sym_COMMA,
    ACTIONS(19794), 1,
      anon_sym_RBRACK,
    STATE(15675), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15673), 2,
      sym_comment,
      sym_block_comment,
  [641345] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8230), 1,
      anon_sym_RPAREN,
    ACTIONS(18787), 1,
      anon_sym_COMMA,
    STATE(14924), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15674), 2,
      sym_comment,
      sym_block_comment,
  [641365] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19796), 1,
      anon_sym_COMMA,
    ACTIONS(19798), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15675), 2,
      sym_comment,
      sym_block_comment,
  [641385] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5300), 1,
      anon_sym_RBRACK,
    ACTIONS(19800), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15676), 2,
      sym_comment,
      sym_block_comment,
  [641405] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19802), 1,
      anon_sym_COMMA,
    ACTIONS(19804), 1,
      anon_sym_RPAREN,
    STATE(15452), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15677), 2,
      sym_comment,
      sym_block_comment,
  [641425] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8350), 1,
      anon_sym_RPAREN,
    ACTIONS(19782), 1,
      anon_sym_COMMA,
    STATE(15689), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15678), 2,
      sym_comment,
      sym_block_comment,
  [641445] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19806), 1,
      anon_sym_COMMA,
    ACTIONS(19808), 1,
      anon_sym_RBRACK,
    STATE(15680), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15679), 2,
      sym_comment,
      sym_block_comment,
  [641465] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19810), 1,
      anon_sym_COMMA,
    ACTIONS(19812), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15680), 2,
      sym_comment,
      sym_block_comment,
  [641485] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19814), 1,
      anon_sym_COMMA,
    ACTIONS(19816), 1,
      anon_sym_RBRACK,
    STATE(15682), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15681), 2,
      sym_comment,
      sym_block_comment,
  [641505] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19818), 1,
      anon_sym_COMMA,
    ACTIONS(19820), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15682), 2,
      sym_comment,
      sym_block_comment,
  [641525] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19822), 1,
      anon_sym_COMMA,
    ACTIONS(19824), 1,
      anon_sym_RBRACK,
    STATE(15776), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15683), 2,
      sym_comment,
      sym_block_comment,
  [641545] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19826), 1,
      anon_sym_COMMA,
    ACTIONS(19828), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15684), 2,
      sym_comment,
      sym_block_comment,
  [641565] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19830), 1,
      anon_sym_COMMA,
    ACTIONS(19832), 1,
      anon_sym_RBRACK,
    STATE(15687), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15685), 2,
      sym_comment,
      sym_block_comment,
  [641585] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19834), 1,
      anon_sym_COMMA,
    ACTIONS(19836), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15686), 2,
      sym_comment,
      sym_block_comment,
  [641605] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19838), 1,
      anon_sym_COMMA,
    ACTIONS(19840), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15687), 2,
      sym_comment,
      sym_block_comment,
  [641625] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19842), 1,
      anon_sym_COMMA,
    ACTIONS(19844), 1,
      anon_sym_RBRACK,
    STATE(15705), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15688), 2,
      sym_comment,
      sym_block_comment,
  [641645] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8352), 1,
      anon_sym_RPAREN,
    ACTIONS(19846), 1,
      anon_sym_COMMA,
    STATE(15247), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15689), 2,
      sym_comment,
      sym_block_comment,
  [641665] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19848), 1,
      anon_sym_COMMA,
    ACTIONS(19850), 1,
      anon_sym_RBRACK,
    STATE(15691), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15690), 2,
      sym_comment,
      sym_block_comment,
  [641685] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19852), 1,
      anon_sym_COMMA,
    ACTIONS(19854), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15691), 2,
      sym_comment,
      sym_block_comment,
  [641705] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19856), 1,
      anon_sym_COMMA,
    ACTIONS(19858), 1,
      anon_sym_RBRACK,
    STATE(15693), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15692), 2,
      sym_comment,
      sym_block_comment,
  [641725] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19860), 1,
      anon_sym_COMMA,
    ACTIONS(19862), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15693), 2,
      sym_comment,
      sym_block_comment,
  [641745] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19864), 1,
      anon_sym_COMMA,
    ACTIONS(19866), 1,
      anon_sym_RBRACK,
    STATE(15696), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15694), 2,
      sym_comment,
      sym_block_comment,
  [641765] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8242), 1,
      anon_sym_RPAREN,
    ACTIONS(19868), 1,
      anon_sym_COMMA,
    STATE(15247), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15695), 2,
      sym_comment,
      sym_block_comment,
  [641785] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19870), 1,
      anon_sym_COMMA,
    ACTIONS(19872), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15696), 2,
      sym_comment,
      sym_block_comment,
  [641805] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6010), 1,
      anon_sym_RPAREN,
    ACTIONS(19874), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15697), 2,
      sym_comment,
      sym_block_comment,
  [641825] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19876), 1,
      anon_sym_COMMA,
    ACTIONS(19878), 1,
      anon_sym_RBRACK,
    STATE(15699), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15698), 2,
      sym_comment,
      sym_block_comment,
  [641845] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19880), 1,
      anon_sym_COMMA,
    ACTIONS(19882), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15699), 2,
      sym_comment,
      sym_block_comment,
  [641865] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19884), 1,
      anon_sym_COMMA,
    ACTIONS(19886), 1,
      anon_sym_RBRACK,
    STATE(15701), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15700), 2,
      sym_comment,
      sym_block_comment,
  [641885] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19888), 1,
      anon_sym_COMMA,
    ACTIONS(19890), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15701), 2,
      sym_comment,
      sym_block_comment,
  [641905] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19892), 1,
      anon_sym_COMMA,
    ACTIONS(19894), 1,
      anon_sym_RBRACK,
    STATE(15704), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15702), 2,
      sym_comment,
      sym_block_comment,
  [641925] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19896), 1,
      anon_sym_COMMA,
    ACTIONS(19898), 1,
      anon_sym_RPAREN,
    STATE(15292), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15703), 2,
      sym_comment,
      sym_block_comment,
  [641945] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19900), 1,
      anon_sym_COMMA,
    ACTIONS(19902), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15704), 2,
      sym_comment,
      sym_block_comment,
  [641965] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5262), 1,
      anon_sym_RBRACK,
    ACTIONS(19904), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15705), 2,
      sym_comment,
      sym_block_comment,
  [641985] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19906), 1,
      anon_sym_COMMA,
    ACTIONS(19908), 1,
      anon_sym_RBRACK,
    STATE(15708), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15706), 2,
      sym_comment,
      sym_block_comment,
  [642005] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19910), 1,
      anon_sym_COMMA,
    ACTIONS(19912), 1,
      anon_sym_RBRACK,
    STATE(15783), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15707), 2,
      sym_comment,
      sym_block_comment,
  [642025] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19914), 1,
      anon_sym_COMMA,
    ACTIONS(19916), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15708), 2,
      sym_comment,
      sym_block_comment,
  [642045] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19918), 1,
      anon_sym_COMMA,
    ACTIONS(19920), 1,
      anon_sym_RBRACK,
    STATE(15710), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15709), 2,
      sym_comment,
      sym_block_comment,
  [642065] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19922), 1,
      anon_sym_COMMA,
    ACTIONS(19924), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15710), 2,
      sym_comment,
      sym_block_comment,
  [642085] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(19926), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15711), 2,
      sym_comment,
      sym_block_comment,
  [642105] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19928), 1,
      anon_sym_COMMA,
    ACTIONS(19930), 1,
      anon_sym_RBRACK,
    STATE(15714), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15712), 2,
      sym_comment,
      sym_block_comment,
  [642125] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19932), 1,
      anon_sym_COMMA,
    ACTIONS(19934), 1,
      anon_sym_RBRACK,
    STATE(15724), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15713), 2,
      sym_comment,
      sym_block_comment,
  [642145] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19936), 1,
      anon_sym_COMMA,
    ACTIONS(19938), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15714), 2,
      sym_comment,
      sym_block_comment,
  [642165] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19940), 1,
      anon_sym_COMMA,
    ACTIONS(19942), 1,
      anon_sym_RBRACK,
    STATE(15717), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15715), 2,
      sym_comment,
      sym_block_comment,
  [642185] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19926), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15716), 2,
      sym_comment,
      sym_block_comment,
  [642205] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19944), 1,
      anon_sym_COMMA,
    ACTIONS(19946), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15717), 2,
      sym_comment,
      sym_block_comment,
  [642225] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17584), 1,
      anon_sym_EQ,
    ACTIONS(17582), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15718), 2,
      sym_comment,
      sym_block_comment,
  [642243] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5978), 1,
      anon_sym_RPAREN,
    ACTIONS(19948), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15719), 2,
      sym_comment,
      sym_block_comment,
  [642263] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19950), 1,
      anon_sym_COMMA,
    ACTIONS(19952), 1,
      anon_sym_RBRACK,
    STATE(15721), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15720), 2,
      sym_comment,
      sym_block_comment,
  [642283] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19954), 1,
      anon_sym_COMMA,
    ACTIONS(19956), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15721), 2,
      sym_comment,
      sym_block_comment,
  [642303] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19958), 1,
      anon_sym_COMMA,
    ACTIONS(19960), 1,
      anon_sym_RBRACK,
    STATE(15723), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15722), 2,
      sym_comment,
      sym_block_comment,
  [642323] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19962), 1,
      anon_sym_COMMA,
    ACTIONS(19964), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15723), 2,
      sym_comment,
      sym_block_comment,
  [642343] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5316), 1,
      anon_sym_RBRACK,
    ACTIONS(19966), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15724), 2,
      sym_comment,
      sym_block_comment,
  [642363] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19968), 1,
      anon_sym_COMMA,
    ACTIONS(19970), 1,
      anon_sym_RBRACK,
    STATE(15726), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15725), 2,
      sym_comment,
      sym_block_comment,
  [642383] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19972), 1,
      anon_sym_COMMA,
    ACTIONS(19974), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15726), 2,
      sym_comment,
      sym_block_comment,
  [642403] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19976), 1,
      anon_sym_COMMA,
    ACTIONS(19978), 1,
      anon_sym_RPAREN,
    STATE(14818), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15727), 2,
      sym_comment,
      sym_block_comment,
  [642423] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19980), 1,
      anon_sym_COMMA,
    ACTIONS(19982), 1,
      anon_sym_RBRACK,
    STATE(15729), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15728), 2,
      sym_comment,
      sym_block_comment,
  [642443] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19984), 1,
      anon_sym_COMMA,
    ACTIONS(19986), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15729), 2,
      sym_comment,
      sym_block_comment,
  [642463] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19988), 1,
      anon_sym_COMMA,
    ACTIONS(19990), 1,
      anon_sym_RBRACK,
    STATE(15731), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15730), 2,
      sym_comment,
      sym_block_comment,
  [642483] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19992), 1,
      anon_sym_COMMA,
    ACTIONS(19994), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15731), 2,
      sym_comment,
      sym_block_comment,
  [642503] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5494), 1,
      anon_sym_RPAREN,
    ACTIONS(19996), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15732), 2,
      sym_comment,
      sym_block_comment,
  [642523] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19998), 1,
      anon_sym_COMMA,
    ACTIONS(20000), 1,
      anon_sym_RBRACK,
    STATE(15749), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15733), 2,
      sym_comment,
      sym_block_comment,
  [642543] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20002), 1,
      anon_sym_COMMA,
    ACTIONS(20004), 1,
      anon_sym_RBRACK,
    STATE(15736), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15734), 2,
      sym_comment,
      sym_block_comment,
  [642563] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(20006), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15735), 2,
      sym_comment,
      sym_block_comment,
  [642583] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20008), 1,
      anon_sym_COMMA,
    ACTIONS(20010), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15736), 2,
      sym_comment,
      sym_block_comment,
  [642603] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20006), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15737), 2,
      sym_comment,
      sym_block_comment,
  [642623] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20012), 1,
      anon_sym_COMMA,
    ACTIONS(20014), 1,
      anon_sym_RBRACK,
    STATE(15739), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15738), 2,
      sym_comment,
      sym_block_comment,
  [642643] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20016), 1,
      anon_sym_COMMA,
    ACTIONS(20018), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15739), 2,
      sym_comment,
      sym_block_comment,
  [642663] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20020), 1,
      anon_sym_COMMA,
    ACTIONS(20022), 1,
      anon_sym_RBRACK,
    STATE(15741), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15740), 2,
      sym_comment,
      sym_block_comment,
  [642683] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20024), 1,
      anon_sym_COMMA,
    ACTIONS(20026), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15741), 2,
      sym_comment,
      sym_block_comment,
  [642703] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5434), 1,
      anon_sym_RPAREN,
    ACTIONS(20028), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15742), 2,
      sym_comment,
      sym_block_comment,
  [642723] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20030), 1,
      anon_sym_COMMA,
    ACTIONS(20032), 1,
      anon_sym_RBRACK,
    STATE(15744), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15743), 2,
      sym_comment,
      sym_block_comment,
  [642743] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20034), 1,
      anon_sym_COMMA,
    ACTIONS(20036), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15744), 2,
      sym_comment,
      sym_block_comment,
  [642763] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5326), 1,
      anon_sym_RPAREN,
    ACTIONS(20038), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15745), 2,
      sym_comment,
      sym_block_comment,
  [642783] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20040), 1,
      anon_sym_COMMA,
    ACTIONS(20042), 1,
      anon_sym_RBRACK,
    STATE(15747), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15746), 2,
      sym_comment,
      sym_block_comment,
  [642803] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20044), 1,
      anon_sym_COMMA,
    ACTIONS(20046), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15747), 2,
      sym_comment,
      sym_block_comment,
  [642823] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20048), 1,
      anon_sym_COMMA,
    ACTIONS(20050), 1,
      anon_sym_RBRACK,
    STATE(15750), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15748), 2,
      sym_comment,
      sym_block_comment,
  [642843] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5276), 1,
      anon_sym_RBRACK,
    ACTIONS(20052), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15749), 2,
      sym_comment,
      sym_block_comment,
  [642863] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20054), 1,
      anon_sym_COMMA,
    ACTIONS(20056), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15750), 2,
      sym_comment,
      sym_block_comment,
  [642883] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20058), 1,
      anon_sym_COMMA,
    ACTIONS(20060), 1,
      anon_sym_RPAREN,
    STATE(15075), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15751), 2,
      sym_comment,
      sym_block_comment,
  [642903] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20062), 1,
      anon_sym_COMMA,
    ACTIONS(20064), 1,
      anon_sym_RBRACK,
    STATE(15753), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15752), 2,
      sym_comment,
      sym_block_comment,
  [642923] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20066), 1,
      anon_sym_COMMA,
    ACTIONS(20068), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15753), 2,
      sym_comment,
      sym_block_comment,
  [642943] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20070), 1,
      anon_sym_COMMA,
    ACTIONS(20072), 1,
      anon_sym_RBRACK,
    STATE(15755), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15754), 2,
      sym_comment,
      sym_block_comment,
  [642963] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20074), 1,
      anon_sym_COMMA,
    ACTIONS(20076), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15755), 2,
      sym_comment,
      sym_block_comment,
  [642983] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20078), 1,
      anon_sym_COMMA,
    ACTIONS(20080), 1,
      anon_sym_RBRACK,
    STATE(15757), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15756), 2,
      sym_comment,
      sym_block_comment,
  [643003] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20082), 1,
      anon_sym_COMMA,
    ACTIONS(20084), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15757), 2,
      sym_comment,
      sym_block_comment,
  [643023] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20086), 1,
      anon_sym_COMMA,
    ACTIONS(20088), 1,
      anon_sym_RBRACK,
    STATE(15770), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15758), 2,
      sym_comment,
      sym_block_comment,
  [643043] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20090), 1,
      anon_sym_COMMA,
    ACTIONS(20092), 1,
      anon_sym_RBRACK,
    STATE(15760), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15759), 2,
      sym_comment,
      sym_block_comment,
  [643063] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20094), 1,
      anon_sym_COMMA,
    ACTIONS(20096), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15760), 2,
      sym_comment,
      sym_block_comment,
  [643083] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20098), 1,
      anon_sym_COMMA,
    ACTIONS(20100), 1,
      anon_sym_RBRACK,
    STATE(15762), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15761), 2,
      sym_comment,
      sym_block_comment,
  [643103] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20102), 1,
      anon_sym_COMMA,
    ACTIONS(20104), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15762), 2,
      sym_comment,
      sym_block_comment,
  [643123] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20106), 1,
      anon_sym_COMMA,
    ACTIONS(20108), 1,
      anon_sym_RBRACK,
    STATE(15765), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15763), 2,
      sym_comment,
      sym_block_comment,
  [643143] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5894), 1,
      anon_sym_RPAREN,
    ACTIONS(20110), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15764), 2,
      sym_comment,
      sym_block_comment,
  [643163] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20112), 1,
      anon_sym_COMMA,
    ACTIONS(20114), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15765), 2,
      sym_comment,
      sym_block_comment,
  [643183] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20116), 1,
      anon_sym_COMMA,
    ACTIONS(20118), 1,
      anon_sym_RBRACK,
    STATE(15767), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15766), 2,
      sym_comment,
      sym_block_comment,
  [643203] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20120), 1,
      anon_sym_COMMA,
    ACTIONS(20122), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15767), 2,
      sym_comment,
      sym_block_comment,
  [643223] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20124), 1,
      anon_sym_COMMA,
    ACTIONS(20126), 1,
      anon_sym_RPAREN,
    STATE(14834), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15768), 2,
      sym_comment,
      sym_block_comment,
  [643243] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20128), 1,
      anon_sym_COMMA,
    ACTIONS(20130), 1,
      anon_sym_RBRACK,
    STATE(15771), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15769), 2,
      sym_comment,
      sym_block_comment,
  [643263] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5352), 1,
      anon_sym_RBRACK,
    ACTIONS(20132), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15770), 2,
      sym_comment,
      sym_block_comment,
  [643283] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20134), 1,
      anon_sym_COMMA,
    ACTIONS(20136), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15771), 2,
      sym_comment,
      sym_block_comment,
  [643303] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20138), 1,
      anon_sym_COMMA,
    ACTIONS(20140), 1,
      anon_sym_RBRACK,
    STATE(15773), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15772), 2,
      sym_comment,
      sym_block_comment,
  [643323] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20142), 1,
      anon_sym_COMMA,
    ACTIONS(20144), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15773), 2,
      sym_comment,
      sym_block_comment,
  [643343] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20146), 1,
      anon_sym_COMMA,
    ACTIONS(20148), 1,
      anon_sym_RBRACK,
    STATE(15775), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15774), 2,
      sym_comment,
      sym_block_comment,
  [643363] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20150), 1,
      anon_sym_COMMA,
    ACTIONS(20152), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15775), 2,
      sym_comment,
      sym_block_comment,
  [643383] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5730), 1,
      anon_sym_RBRACK,
    ACTIONS(20154), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15776), 2,
      sym_comment,
      sym_block_comment,
  [643403] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15777), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(19180), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [643419] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20156), 1,
      anon_sym_COMMA,
    ACTIONS(20158), 1,
      anon_sym_RBRACK,
    STATE(15780), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15778), 2,
      sym_comment,
      sym_block_comment,
  [643439] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20160), 1,
      anon_sym_COMMA,
    ACTIONS(20162), 1,
      anon_sym_RBRACK,
    STATE(15801), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15779), 2,
      sym_comment,
      sym_block_comment,
  [643459] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20164), 1,
      anon_sym_COMMA,
    ACTIONS(20166), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15780), 2,
      sym_comment,
      sym_block_comment,
  [643479] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20168), 1,
      anon_sym_COMMA,
    ACTIONS(20170), 1,
      anon_sym_RBRACK,
    STATE(15782), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15781), 2,
      sym_comment,
      sym_block_comment,
  [643499] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20172), 1,
      anon_sym_COMMA,
    ACTIONS(20174), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15782), 2,
      sym_comment,
      sym_block_comment,
  [643519] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5502), 1,
      anon_sym_RBRACK,
    ACTIONS(20176), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15783), 2,
      sym_comment,
      sym_block_comment,
  [643539] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20178), 1,
      anon_sym_COMMA,
    ACTIONS(20180), 1,
      anon_sym_RBRACK,
    STATE(15785), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15784), 2,
      sym_comment,
      sym_block_comment,
  [643559] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20182), 1,
      anon_sym_COMMA,
    ACTIONS(20184), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15785), 2,
      sym_comment,
      sym_block_comment,
  [643579] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20186), 1,
      anon_sym_COMMA,
    ACTIONS(20188), 1,
      anon_sym_RBRACK,
    STATE(15787), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15786), 2,
      sym_comment,
      sym_block_comment,
  [643599] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20190), 1,
      anon_sym_COMMA,
    ACTIONS(20192), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15787), 2,
      sym_comment,
      sym_block_comment,
  [643619] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5444), 1,
      anon_sym_RPAREN,
    ACTIONS(20194), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15788), 2,
      sym_comment,
      sym_block_comment,
  [643639] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4208), 1,
      sym__indent,
    STATE(8875), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15789), 2,
      sym_comment,
      sym_block_comment,
  [643657] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20196), 1,
      anon_sym_COMMA,
    ACTIONS(20198), 1,
      anon_sym_RBRACK,
    STATE(15791), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15790), 2,
      sym_comment,
      sym_block_comment,
  [643677] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20200), 1,
      anon_sym_COMMA,
    ACTIONS(20202), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15791), 2,
      sym_comment,
      sym_block_comment,
  [643697] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13549), 1,
      anon_sym_LBRACK,
    ACTIONS(15886), 1,
      anon_sym_match,
    STATE(6641), 1,
      sym_type_arguments,
    STATE(15792), 2,
      sym_comment,
      sym_block_comment,
  [643717] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20204), 1,
      anon_sym_COMMA,
    ACTIONS(20206), 1,
      anon_sym_RBRACK,
    STATE(15794), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15793), 2,
      sym_comment,
      sym_block_comment,
  [643737] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20208), 1,
      anon_sym_COMMA,
    ACTIONS(20210), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15794), 2,
      sym_comment,
      sym_block_comment,
  [643757] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4760), 1,
      sym__indent,
    STATE(10023), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15795), 2,
      sym_comment,
      sym_block_comment,
  [643775] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20212), 1,
      anon_sym_COMMA,
    ACTIONS(20214), 1,
      anon_sym_RBRACK,
    STATE(15797), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15796), 2,
      sym_comment,
      sym_block_comment,
  [643795] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20216), 1,
      anon_sym_COMMA,
    ACTIONS(20218), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15797), 2,
      sym_comment,
      sym_block_comment,
  [643815] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20220), 1,
      anon_sym_COMMA,
    ACTIONS(20222), 1,
      anon_sym_RPAREN,
    STATE(15154), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15798), 2,
      sym_comment,
      sym_block_comment,
  [643835] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20224), 1,
      anon_sym_COMMA,
    ACTIONS(20226), 1,
      anon_sym_RBRACK,
    STATE(15800), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15799), 2,
      sym_comment,
      sym_block_comment,
  [643855] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20228), 1,
      anon_sym_COMMA,
    ACTIONS(20230), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15800), 2,
      sym_comment,
      sym_block_comment,
  [643875] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5296), 1,
      anon_sym_RBRACK,
    ACTIONS(20232), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15801), 2,
      sym_comment,
      sym_block_comment,
  [643895] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20234), 1,
      anon_sym_COMMA,
    ACTIONS(20236), 1,
      anon_sym_RBRACK,
    STATE(15803), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15802), 2,
      sym_comment,
      sym_block_comment,
  [643915] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20238), 1,
      anon_sym_COMMA,
    ACTIONS(20240), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15803), 2,
      sym_comment,
      sym_block_comment,
  [643935] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20242), 1,
      anon_sym_COMMA,
    ACTIONS(20244), 1,
      anon_sym_RBRACK,
    STATE(15805), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15804), 2,
      sym_comment,
      sym_block_comment,
  [643955] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20246), 1,
      anon_sym_COMMA,
    ACTIONS(20248), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15805), 2,
      sym_comment,
      sym_block_comment,
  [643975] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20250), 1,
      anon_sym_COMMA,
    ACTIONS(20252), 1,
      anon_sym_RBRACK,
    STATE(15807), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15806), 2,
      sym_comment,
      sym_block_comment,
  [643995] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20254), 1,
      anon_sym_COMMA,
    ACTIONS(20256), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15807), 2,
      sym_comment,
      sym_block_comment,
  [644015] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20258), 1,
      anon_sym_COMMA,
    ACTIONS(20260), 1,
      anon_sym_RBRACK,
    STATE(15821), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15808), 2,
      sym_comment,
      sym_block_comment,
  [644035] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20262), 1,
      anon_sym_COMMA,
    ACTIONS(20264), 1,
      anon_sym_RBRACK,
    STATE(15810), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15809), 2,
      sym_comment,
      sym_block_comment,
  [644055] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20266), 1,
      anon_sym_COMMA,
    ACTIONS(20268), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15810), 2,
      sym_comment,
      sym_block_comment,
  [644075] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20270), 1,
      anon_sym_COMMA,
    ACTIONS(20272), 1,
      anon_sym_RBRACK,
    STATE(15812), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15811), 2,
      sym_comment,
      sym_block_comment,
  [644095] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20274), 1,
      anon_sym_COMMA,
    ACTIONS(20276), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15812), 2,
      sym_comment,
      sym_block_comment,
  [644115] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20278), 1,
      anon_sym_COMMA,
    ACTIONS(20280), 1,
      anon_sym_RBRACK,
    STATE(15815), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15813), 2,
      sym_comment,
      sym_block_comment,
  [644135] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6000), 1,
      anon_sym_RPAREN,
    ACTIONS(20282), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15814), 2,
      sym_comment,
      sym_block_comment,
  [644155] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20284), 1,
      anon_sym_COMMA,
    ACTIONS(20286), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15815), 2,
      sym_comment,
      sym_block_comment,
  [644175] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20288), 1,
      anon_sym_COMMA,
    ACTIONS(20290), 1,
      anon_sym_RBRACK,
    STATE(15818), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15816), 2,
      sym_comment,
      sym_block_comment,
  [644195] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20292), 1,
      anon_sym_COMMA,
    ACTIONS(20294), 1,
      anon_sym_RBRACK,
    STATE(14898), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15817), 2,
      sym_comment,
      sym_block_comment,
  [644215] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20296), 1,
      anon_sym_COMMA,
    ACTIONS(20298), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15818), 2,
      sym_comment,
      sym_block_comment,
  [644235] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20300), 1,
      anon_sym_COMMA,
    ACTIONS(20302), 1,
      anon_sym_RBRACK,
    STATE(15820), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15819), 2,
      sym_comment,
      sym_block_comment,
  [644255] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20304), 1,
      anon_sym_COMMA,
    ACTIONS(20306), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15820), 2,
      sym_comment,
      sym_block_comment,
  [644275] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5374), 1,
      anon_sym_RBRACK,
    ACTIONS(20308), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15821), 2,
      sym_comment,
      sym_block_comment,
  [644295] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20310), 1,
      anon_sym_COMMA,
    ACTIONS(20312), 1,
      anon_sym_RBRACK,
    STATE(15823), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15822), 2,
      sym_comment,
      sym_block_comment,
  [644315] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20314), 1,
      anon_sym_COMMA,
    ACTIONS(20316), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15823), 2,
      sym_comment,
      sym_block_comment,
  [644335] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20318), 1,
      anon_sym_COMMA,
    ACTIONS(20320), 1,
      anon_sym_RBRACK,
    STATE(15825), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15824), 2,
      sym_comment,
      sym_block_comment,
  [644355] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20322), 1,
      anon_sym_COMMA,
    ACTIONS(20324), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15825), 2,
      sym_comment,
      sym_block_comment,
  [644375] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20326), 1,
      anon_sym_COMMA,
    ACTIONS(20328), 1,
      anon_sym_RPAREN,
    STATE(15580), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15826), 2,
      sym_comment,
      sym_block_comment,
  [644395] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(20330), 1,
      sym__interpolated_string_end,
    STATE(14784), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15827), 2,
      sym_comment,
      sym_block_comment,
  [644415] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20332), 1,
      anon_sym_COMMA,
    ACTIONS(20334), 1,
      anon_sym_RPAREN,
    STATE(15482), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15828), 2,
      sym_comment,
      sym_block_comment,
  [644435] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20330), 1,
      sym__interpolated_multiline_string_end,
    STATE(14792), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15829), 2,
      sym_comment,
      sym_block_comment,
  [644455] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20336), 1,
      anon_sym_COMMA,
    ACTIONS(20338), 1,
      anon_sym_RBRACK,
    STATE(15839), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15830), 2,
      sym_comment,
      sym_block_comment,
  [644475] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      sym__interpolated_string_middle,
    ACTIONS(20340), 1,
      sym__interpolated_string_end,
    STATE(15585), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15831), 2,
      sym_comment,
      sym_block_comment,
  [644495] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20342), 1,
      anon_sym_COMMA,
    ACTIONS(20344), 1,
      anon_sym_RPAREN,
    STATE(15188), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15832), 2,
      sym_comment,
      sym_block_comment,
  [644515] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17713), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20340), 1,
      sym__interpolated_multiline_string_end,
    STATE(15117), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15833), 2,
      sym_comment,
      sym_block_comment,
  [644535] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20346), 1,
      anon_sym_COMMA,
    ACTIONS(20348), 1,
      anon_sym_RBRACK,
    STATE(15840), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15834), 2,
      sym_comment,
      sym_block_comment,
  [644555] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6038), 1,
      anon_sym_RPAREN,
    ACTIONS(20350), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15835), 2,
      sym_comment,
      sym_block_comment,
  [644575] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5916), 1,
      anon_sym_RPAREN,
    ACTIONS(20352), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15836), 2,
      sym_comment,
      sym_block_comment,
  [644595] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17637), 1,
      anon_sym_RBRACE,
    ACTIONS(20354), 1,
      anon_sym_COMMA,
    STATE(15837), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_namespace_selectors_repeat1,
  [644613] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20357), 1,
      anon_sym_COMMA,
    ACTIONS(20359), 1,
      anon_sym_RPAREN,
    STATE(15745), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15838), 2,
      sym_comment,
      sym_block_comment,
  [644633] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5320), 1,
      anon_sym_RBRACK,
    ACTIONS(20361), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15839), 2,
      sym_comment,
      sym_block_comment,
  [644653] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5408), 1,
      anon_sym_RBRACK,
    ACTIONS(20363), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15840), 2,
      sym_comment,
      sym_block_comment,
  [644673] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20365), 1,
      anon_sym_COMMA,
    ACTIONS(20367), 1,
      anon_sym_RPAREN,
    STATE(14916), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15841), 2,
      sym_comment,
      sym_block_comment,
  [644693] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5872), 1,
      anon_sym_RPAREN,
    ACTIONS(20369), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15842), 2,
      sym_comment,
      sym_block_comment,
  [644713] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11244), 1,
      sym__arrow_then_type,
    ACTIONS(20371), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15843), 2,
      sym_comment,
      sym_block_comment,
  [644731] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20373), 1,
      anon_sym_COMMA,
    ACTIONS(20375), 1,
      anon_sym_RBRACK,
    STATE(15394), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15844), 2,
      sym_comment,
      sym_block_comment,
  [644751] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15886), 1,
      anon_sym_match,
    ACTIONS(16137), 1,
      anon_sym_LBRACK,
    STATE(9978), 1,
      sym_type_arguments,
    STATE(15845), 2,
      sym_comment,
      sym_block_comment,
  [644771] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20377), 1,
      anon_sym_COMMA,
    ACTIONS(20379), 1,
      anon_sym_RPAREN,
    STATE(15439), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15846), 2,
      sym_comment,
      sym_block_comment,
  [644791] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5312), 1,
      anon_sym_RBRACK,
    ACTIONS(20381), 1,
      anon_sym_COMMA,
    STATE(14576), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15847), 2,
      sym_comment,
      sym_block_comment,
  [644811] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20383), 1,
      anon_sym_COMMA,
    ACTIONS(20385), 1,
      anon_sym_RPAREN,
    STATE(15232), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15848), 2,
      sym_comment,
      sym_block_comment,
  [644831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4248), 1,
      sym__indent,
    STATE(7458), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15849), 2,
      sym_comment,
      sym_block_comment,
  [644849] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20387), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15850), 2,
      sym_comment,
      sym_block_comment,
  [644864] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20389), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15851), 2,
      sym_comment,
      sym_block_comment,
  [644879] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20391), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15852), 2,
      sym_comment,
      sym_block_comment,
  [644894] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20393), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15853), 2,
      sym_comment,
      sym_block_comment,
  [644909] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20395), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15854), 2,
      sym_comment,
      sym_block_comment,
  [644924] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20397), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15855), 2,
      sym_comment,
      sym_block_comment,
  [644939] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20399), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15856), 2,
      sym_comment,
      sym_block_comment,
  [644954] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20401), 2,
      anon_sym_COLON,
      anon_sym_COMMA,
    STATE(15857), 2,
      sym_comment,
      sym_block_comment,
  [644969] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20403), 1,
      anon_sym_COLON,
    ACTIONS(20405), 1,
      anon_sym_EQ,
    STATE(15858), 2,
      sym_comment,
      sym_block_comment,
  [644986] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20407), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15859), 2,
      sym_comment,
      sym_block_comment,
  [645001] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20409), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15860), 2,
      sym_comment,
      sym_block_comment,
  [645016] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20411), 2,
      sym__outdent,
      anon_sym_case,
    STATE(15861), 2,
      sym_comment,
      sym_block_comment,
  [645031] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10404), 2,
      sym__interpolated_multiline_string_middle,
      sym__interpolated_multiline_string_end,
    STATE(15862), 2,
      sym_comment,
      sym_block_comment,
  [645046] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20413), 1,
      anon_sym_COLON,
    ACTIONS(20415), 1,
      anon_sym_EQ,
    STATE(15863), 2,
      sym_comment,
      sym_block_comment,
  [645063] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20417), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15864), 2,
      sym_comment,
      sym_block_comment,
  [645078] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20419), 1,
      anon_sym_LPAREN,
    STATE(13384), 1,
      sym_parenthesized_expression,
    STATE(15865), 2,
      sym_comment,
      sym_block_comment,
  [645095] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20421), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15866), 2,
      sym_comment,
      sym_block_comment,
  [645110] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20423), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15867), 2,
      sym_comment,
      sym_block_comment,
  [645125] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20425), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15868), 2,
      sym_comment,
      sym_block_comment,
  [645140] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20427), 1,
      sym__indent,
    STATE(13047), 1,
      sym__indented_type_cases,
    STATE(15869), 2,
      sym_comment,
      sym_block_comment,
  [645157] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20429), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15870), 2,
      sym_comment,
      sym_block_comment,
  [645172] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20431), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15871), 2,
      sym_comment,
      sym_block_comment,
  [645187] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20433), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15872), 2,
      sym_comment,
      sym_block_comment,
  [645202] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19262), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15873), 2,
      sym_comment,
      sym_block_comment,
  [645217] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10404), 2,
      sym__interpolated_string_middle,
      sym__interpolated_string_end,
    STATE(15874), 2,
      sym_comment,
      sym_block_comment,
  [645232] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20435), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15875), 2,
      sym_comment,
      sym_block_comment,
  [645247] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20437), 1,
      anon_sym_COLON,
    ACTIONS(20439), 1,
      anon_sym_EQ,
    STATE(15876), 2,
      sym_comment,
      sym_block_comment,
  [645264] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20441), 1,
      anon_sym_LPAREN,
    STATE(13533), 1,
      sym_parenthesized_expression,
    STATE(15877), 2,
      sym_comment,
      sym_block_comment,
  [645281] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10710), 2,
      anon_sym_with,
      anon_sym_LPAREN,
    STATE(15878), 2,
      sym_comment,
      sym_block_comment,
  [645296] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20443), 1,
      anon_sym_EQ_GT,
    ACTIONS(20445), 1,
      anon_sym_QMARK_EQ_GT,
    STATE(15879), 2,
      sym_comment,
      sym_block_comment,
  [645313] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20447), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15880), 2,
      sym_comment,
      sym_block_comment,
  [645328] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20449), 1,
      sym__indent,
    STATE(13518), 1,
      sym__indented_type_cases,
    STATE(15881), 2,
      sym_comment,
      sym_block_comment,
  [645345] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20451), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(15882), 2,
      sym_comment,
      sym_block_comment,
  [645360] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20453), 1,
      anon_sym_COLON,
    ACTIONS(20455), 1,
      anon_sym_EQ,
    STATE(15883), 2,
      sym_comment,
      sym_block_comment,
  [645377] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20457), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15884), 2,
      sym_comment,
      sym_block_comment,
  [645392] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20459), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15885), 2,
      sym_comment,
      sym_block_comment,
  [645407] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20461), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15886), 2,
      sym_comment,
      sym_block_comment,
  [645422] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20463), 1,
      sym__indent,
    STATE(11598), 1,
      sym__indented_type_cases,
    STATE(15887), 2,
      sym_comment,
      sym_block_comment,
  [645439] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15160), 1,
      anon_sym_object,
    ACTIONS(15164), 1,
      anon_sym_class,
    STATE(15888), 2,
      sym_comment,
      sym_block_comment,
  [645456] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20465), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15889), 2,
      sym_comment,
      sym_block_comment,
  [645471] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20467), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(15890), 2,
      sym_comment,
      sym_block_comment,
  [645486] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20469), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15891), 2,
      sym_comment,
      sym_block_comment,
  [645501] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20471), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15892), 2,
      sym_comment,
      sym_block_comment,
  [645516] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20473), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15893), 2,
      sym_comment,
      sym_block_comment,
  [645531] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20475), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15894), 2,
      sym_comment,
      sym_block_comment,
  [645546] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20477), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15895), 2,
      sym_comment,
      sym_block_comment,
  [645561] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20479), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15896), 2,
      sym_comment,
      sym_block_comment,
  [645576] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20481), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15897), 2,
      sym_comment,
      sym_block_comment,
  [645591] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20483), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15898), 2,
      sym_comment,
      sym_block_comment,
  [645606] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20485), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15899), 2,
      sym_comment,
      sym_block_comment,
  [645621] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20487), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15900), 2,
      sym_comment,
      sym_block_comment,
  [645636] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20489), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15901), 2,
      sym_comment,
      sym_block_comment,
  [645651] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20491), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15902), 2,
      sym_comment,
      sym_block_comment,
  [645666] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20493), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15903), 2,
      sym_comment,
      sym_block_comment,
  [645681] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20495), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15904), 2,
      sym_comment,
      sym_block_comment,
  [645696] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20497), 1,
      anon_sym_LPAREN,
    STATE(13495), 1,
      sym_parenthesized_expression,
    STATE(15905), 2,
      sym_comment,
      sym_block_comment,
  [645713] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20499), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15906), 2,
      sym_comment,
      sym_block_comment,
  [645728] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20501), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15907), 2,
      sym_comment,
      sym_block_comment,
  [645743] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20503), 1,
      anon_sym_COLON,
    ACTIONS(20505), 1,
      anon_sym_EQ,
    STATE(15908), 2,
      sym_comment,
      sym_block_comment,
  [645760] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20507), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15909), 2,
      sym_comment,
      sym_block_comment,
  [645775] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20509), 2,
      sym__outdent,
      anon_sym_case,
    STATE(15910), 2,
      sym_comment,
      sym_block_comment,
  [645790] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20511), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15911), 2,
      sym_comment,
      sym_block_comment,
  [645805] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20513), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15912), 2,
      sym_comment,
      sym_block_comment,
  [645820] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20515), 1,
      anon_sym_object,
    ACTIONS(20517), 1,
      anon_sym_class,
    STATE(15913), 2,
      sym_comment,
      sym_block_comment,
  [645837] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20519), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15914), 2,
      sym_comment,
      sym_block_comment,
  [645852] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20521), 1,
      sym__indent,
    STATE(17056), 1,
      sym__indented_type_cases,
    STATE(15915), 2,
      sym_comment,
      sym_block_comment,
  [645869] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20523), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15916), 2,
      sym_comment,
      sym_block_comment,
  [645884] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20525), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15917), 2,
      sym_comment,
      sym_block_comment,
  [645899] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20527), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15918), 2,
      sym_comment,
      sym_block_comment,
  [645914] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20529), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15919), 2,
      sym_comment,
      sym_block_comment,
  [645929] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20531), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15920), 2,
      sym_comment,
      sym_block_comment,
  [645944] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11914), 2,
      sym__outdent,
      anon_sym_case,
    STATE(15921), 2,
      sym_comment,
      sym_block_comment,
  [645959] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20533), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(15922), 2,
      sym_comment,
      sym_block_comment,
  [645974] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20535), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15923), 2,
      sym_comment,
      sym_block_comment,
  [645989] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5114), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(15924), 2,
      sym_comment,
      sym_block_comment,
  [646004] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20537), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15925), 2,
      sym_comment,
      sym_block_comment,
  [646019] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20539), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15926), 2,
      sym_comment,
      sym_block_comment,
  [646034] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20541), 1,
      anon_sym_LPAREN,
    STATE(12925), 1,
      sym_parenthesized_expression,
    STATE(15927), 2,
      sym_comment,
      sym_block_comment,
  [646051] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20543), 1,
      sym__indent,
    STATE(14553), 1,
      sym_with_template_body,
    STATE(15928), 2,
      sym_comment,
      sym_block_comment,
  [646068] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11924), 2,
      sym__outdent,
      anon_sym_case,
    STATE(15929), 2,
      sym_comment,
      sym_block_comment,
  [646083] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20545), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15930), 2,
      sym_comment,
      sym_block_comment,
  [646098] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20547), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15931), 2,
      sym_comment,
      sym_block_comment,
  [646113] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11939), 2,
      sym__outdent,
      anon_sym_case,
    STATE(15932), 2,
      sym_comment,
      sym_block_comment,
  [646128] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20549), 2,
      sym__interpolated_string_middle,
      sym__interpolated_string_end,
    STATE(15933), 2,
      sym_comment,
      sym_block_comment,
  [646143] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20551), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15934), 2,
      sym_comment,
      sym_block_comment,
  [646158] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20553), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15935), 2,
      sym_comment,
      sym_block_comment,
  [646173] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8140), 1,
      anon_sym_object,
    ACTIONS(8144), 1,
      anon_sym_class,
    STATE(15936), 2,
      sym_comment,
      sym_block_comment,
  [646190] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20555), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15937), 2,
      sym_comment,
      sym_block_comment,
  [646205] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20557), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15938), 2,
      sym_comment,
      sym_block_comment,
  [646220] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20559), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15939), 2,
      sym_comment,
      sym_block_comment,
  [646235] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20561), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15940), 2,
      sym_comment,
      sym_block_comment,
  [646250] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20563), 1,
      anon_sym_LPAREN,
    STATE(13636), 1,
      sym_parenthesized_expression,
    STATE(15941), 2,
      sym_comment,
      sym_block_comment,
  [646267] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20565), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15942), 2,
      sym_comment,
      sym_block_comment,
  [646282] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20567), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15943), 2,
      sym_comment,
      sym_block_comment,
  [646297] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20569), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15944), 2,
      sym_comment,
      sym_block_comment,
  [646312] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11900), 2,
      sym__outdent,
      anon_sym_case,
    STATE(15945), 2,
      sym_comment,
      sym_block_comment,
  [646327] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20571), 1,
      sym__indent,
    STATE(12620), 1,
      sym__indented_type_cases,
    STATE(15946), 2,
      sym_comment,
      sym_block_comment,
  [646344] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20573), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    STATE(15947), 2,
      sym_comment,
      sym_block_comment,
  [646359] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10039), 2,
      anon_sym_with,
      anon_sym_LPAREN,
    STATE(15948), 2,
      sym_comment,
      sym_block_comment,
  [646374] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20575), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15949), 2,
      sym_comment,
      sym_block_comment,
  [646389] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20577), 1,
      anon_sym_LPAREN,
    STATE(13847), 1,
      sym_parenthesized_expression,
    STATE(15950), 2,
      sym_comment,
      sym_block_comment,
  [646406] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20579), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15951), 2,
      sym_comment,
      sym_block_comment,
  [646421] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20581), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(15952), 2,
      sym_comment,
      sym_block_comment,
  [646436] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20583), 1,
      anon_sym_LPAREN,
    STATE(12003), 1,
      sym_parenthesized_expression,
    STATE(15953), 2,
      sym_comment,
      sym_block_comment,
  [646453] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20585), 1,
      sym__indent,
    STATE(8434), 1,
      sym__indented_type_cases,
    STATE(15954), 2,
      sym_comment,
      sym_block_comment,
  [646470] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20587), 1,
      anon_sym_COLON,
    ACTIONS(20589), 1,
      anon_sym_EQ,
    STATE(15955), 2,
      sym_comment,
      sym_block_comment,
  [646487] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20591), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(15956), 2,
      sym_comment,
      sym_block_comment,
  [646502] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19009), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15957), 2,
      sym_comment,
      sym_block_comment,
  [646517] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20593), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(15958), 2,
      sym_comment,
      sym_block_comment,
  [646532] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20595), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15959), 2,
      sym_comment,
      sym_block_comment,
  [646547] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20597), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15960), 2,
      sym_comment,
      sym_block_comment,
  [646562] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20599), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15961), 2,
      sym_comment,
      sym_block_comment,
  [646577] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20601), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15962), 2,
      sym_comment,
      sym_block_comment,
  [646592] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20411), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    STATE(15963), 2,
      sym_comment,
      sym_block_comment,
  [646607] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20603), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15964), 2,
      sym_comment,
      sym_block_comment,
  [646622] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20605), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15965), 2,
      sym_comment,
      sym_block_comment,
  [646637] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20607), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15966), 2,
      sym_comment,
      sym_block_comment,
  [646652] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20609), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15967), 2,
      sym_comment,
      sym_block_comment,
  [646667] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20611), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15968), 2,
      sym_comment,
      sym_block_comment,
  [646682] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20613), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15969), 2,
      sym_comment,
      sym_block_comment,
  [646697] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20615), 1,
      sym__indent,
    STATE(11987), 1,
      sym__indented_type_cases,
    STATE(15970), 2,
      sym_comment,
      sym_block_comment,
  [646714] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20617), 1,
      anon_sym_LPAREN,
    STATE(13769), 1,
      sym_parenthesized_expression,
    STATE(15971), 2,
      sym_comment,
      sym_block_comment,
  [646731] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20619), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15972), 2,
      sym_comment,
      sym_block_comment,
  [646746] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20621), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15973), 2,
      sym_comment,
      sym_block_comment,
  [646761] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20623), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15974), 2,
      sym_comment,
      sym_block_comment,
  [646776] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20625), 1,
      sym__indent,
    STATE(10849), 1,
      sym__indented_type_cases,
    STATE(15975), 2,
      sym_comment,
      sym_block_comment,
  [646793] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20627), 1,
      anon_sym_COLON,
    ACTIONS(20629), 1,
      anon_sym_EQ,
    STATE(15976), 2,
      sym_comment,
      sym_block_comment,
  [646810] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20631), 1,
      sym__indent,
    STATE(13271), 1,
      sym__indented_type_cases,
    STATE(15977), 2,
      sym_comment,
      sym_block_comment,
  [646827] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20633), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15978), 2,
      sym_comment,
      sym_block_comment,
  [646842] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20635), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15979), 2,
      sym_comment,
      sym_block_comment,
  [646857] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20637), 1,
      anon_sym_COLON,
    ACTIONS(20639), 1,
      anon_sym_EQ,
    STATE(15980), 2,
      sym_comment,
      sym_block_comment,
  [646874] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20641), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15981), 2,
      sym_comment,
      sym_block_comment,
  [646889] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20643), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15982), 2,
      sym_comment,
      sym_block_comment,
  [646904] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20645), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15983), 2,
      sym_comment,
      sym_block_comment,
  [646919] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20647), 2,
      sym__interpolated_multiline_string_middle,
      sym__interpolated_multiline_string_end,
    STATE(15984), 2,
      sym_comment,
      sym_block_comment,
  [646934] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20649), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15985), 2,
      sym_comment,
      sym_block_comment,
  [646949] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20651), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(15986), 2,
      sym_comment,
      sym_block_comment,
  [646964] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20653), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15987), 2,
      sym_comment,
      sym_block_comment,
  [646979] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20655), 1,
      sym__indent,
    STATE(10906), 1,
      sym__indented_type_cases,
    STATE(15988), 2,
      sym_comment,
      sym_block_comment,
  [646996] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20657), 1,
      anon_sym_object,
    ACTIONS(20659), 1,
      anon_sym_class,
    STATE(15989), 2,
      sym_comment,
      sym_block_comment,
  [647013] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20661), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15990), 2,
      sym_comment,
      sym_block_comment,
  [647028] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20663), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15991), 2,
      sym_comment,
      sym_block_comment,
  [647043] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20665), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15992), 2,
      sym_comment,
      sym_block_comment,
  [647058] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20667), 1,
      sym__indent,
    STATE(11477), 1,
      sym__indented_type_cases,
    STATE(15993), 2,
      sym_comment,
      sym_block_comment,
  [647075] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20669), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15994), 2,
      sym_comment,
      sym_block_comment,
  [647090] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20671), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15995), 2,
      sym_comment,
      sym_block_comment,
  [647105] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20673), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15996), 2,
      sym_comment,
      sym_block_comment,
  [647120] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20675), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15997), 2,
      sym_comment,
      sym_block_comment,
  [647135] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20677), 1,
      sym__indent,
    STATE(11486), 1,
      sym__indented_type_cases,
    STATE(15998), 2,
      sym_comment,
      sym_block_comment,
  [647152] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20679), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(15999), 2,
      sym_comment,
      sym_block_comment,
  [647167] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10426), 2,
      sym__interpolated_multiline_string_middle,
      sym__interpolated_multiline_string_end,
    STATE(16000), 2,
      sym_comment,
      sym_block_comment,
  [647182] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20681), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16001), 2,
      sym_comment,
      sym_block_comment,
  [647197] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20683), 1,
      anon_sym_LPAREN,
    STATE(11564), 1,
      sym_parenthesized_expression,
    STATE(16002), 2,
      sym_comment,
      sym_block_comment,
  [647214] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20685), 1,
      anon_sym_LPAREN,
    STATE(13697), 1,
      sym_parenthesized_expression,
    STATE(16003), 2,
      sym_comment,
      sym_block_comment,
  [647231] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20687), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16004), 2,
      sym_comment,
      sym_block_comment,
  [647246] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20689), 1,
      anon_sym_LPAREN,
    STATE(12102), 1,
      sym_parenthesized_expression,
    STATE(16005), 2,
      sym_comment,
      sym_block_comment,
  [647263] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20691), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16006), 2,
      sym_comment,
      sym_block_comment,
  [647278] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20693), 1,
      sym__indent,
    STATE(11268), 1,
      sym__indented_type_cases,
    STATE(16007), 2,
      sym_comment,
      sym_block_comment,
  [647295] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20695), 1,
      sym__indent,
    STATE(12872), 1,
      sym__indented_type_cases,
    STATE(16008), 2,
      sym_comment,
      sym_block_comment,
  [647312] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20445), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16009), 2,
      sym_comment,
      sym_block_comment,
  [647327] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10050), 2,
      anon_sym_with,
      anon_sym_LPAREN,
    STATE(16010), 2,
      sym_comment,
      sym_block_comment,
  [647342] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20697), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16011), 2,
      sym_comment,
      sym_block_comment,
  [647357] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20699), 1,
      sym__indent,
    STATE(13544), 1,
      sym__indented_type_cases,
    STATE(16012), 2,
      sym_comment,
      sym_block_comment,
  [647374] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20701), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16013), 2,
      sym_comment,
      sym_block_comment,
  [647389] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20703), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16014), 2,
      sym_comment,
      sym_block_comment,
  [647404] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18838), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(16015), 2,
      sym_comment,
      sym_block_comment,
  [647419] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20705), 1,
      anon_sym_COLON,
    ACTIONS(20707), 1,
      anon_sym_EQ,
    STATE(16016), 2,
      sym_comment,
      sym_block_comment,
  [647436] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10029), 2,
      anon_sym_with,
      anon_sym_LPAREN,
    STATE(16017), 2,
      sym_comment,
      sym_block_comment,
  [647451] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20709), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16018), 2,
      sym_comment,
      sym_block_comment,
  [647466] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20711), 1,
      sym__indent,
    STATE(12972), 1,
      sym__indented_type_cases,
    STATE(16019), 2,
      sym_comment,
      sym_block_comment,
  [647483] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20713), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16020), 2,
      sym_comment,
      sym_block_comment,
  [647498] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20715), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16021), 2,
      sym_comment,
      sym_block_comment,
  [647513] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20717), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16022), 2,
      sym_comment,
      sym_block_comment,
  [647528] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20719), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16023), 2,
      sym_comment,
      sym_block_comment,
  [647543] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20721), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16024), 2,
      sym_comment,
      sym_block_comment,
  [647558] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11841), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16025), 2,
      sym_comment,
      sym_block_comment,
  [647573] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20723), 1,
      anon_sym_LPAREN,
    STATE(13257), 1,
      sym_parenthesized_expression,
    STATE(16026), 2,
      sym_comment,
      sym_block_comment,
  [647590] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20725), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16027), 2,
      sym_comment,
      sym_block_comment,
  [647605] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20727), 1,
      sym__indent,
    STATE(12884), 1,
      sym__indented_type_cases,
    STATE(16028), 2,
      sym_comment,
      sym_block_comment,
  [647622] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20729), 1,
      sym__indent,
    STATE(13155), 1,
      sym__indented_type_cases,
    STATE(16029), 2,
      sym_comment,
      sym_block_comment,
  [647639] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20731), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16030), 2,
      sym_comment,
      sym_block_comment,
  [647654] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20733), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16031), 2,
      sym_comment,
      sym_block_comment,
  [647669] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20735), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16032), 2,
      sym_comment,
      sym_block_comment,
  [647684] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20737), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16033), 2,
      sym_comment,
      sym_block_comment,
  [647699] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20739), 1,
      sym__indent,
    STATE(11283), 1,
      sym__indented_type_cases,
    STATE(16034), 2,
      sym_comment,
      sym_block_comment,
  [647716] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20741), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16035), 2,
      sym_comment,
      sym_block_comment,
  [647731] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15341), 1,
      anon_sym_object,
    ACTIONS(15345), 1,
      anon_sym_class,
    STATE(16036), 2,
      sym_comment,
      sym_block_comment,
  [647748] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20743), 1,
      sym__indent,
    STATE(16100), 1,
      sym__indented_type_cases,
    STATE(16037), 2,
      sym_comment,
      sym_block_comment,
  [647765] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20745), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16038), 2,
      sym_comment,
      sym_block_comment,
  [647780] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20747), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16039), 2,
      sym_comment,
      sym_block_comment,
  [647795] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20749), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16040), 2,
      sym_comment,
      sym_block_comment,
  [647810] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20751), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16041), 2,
      sym_comment,
      sym_block_comment,
  [647825] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20753), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16042), 2,
      sym_comment,
      sym_block_comment,
  [647840] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20755), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16043), 2,
      sym_comment,
      sym_block_comment,
  [647855] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20757), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16044), 2,
      sym_comment,
      sym_block_comment,
  [647870] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20759), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16045), 2,
      sym_comment,
      sym_block_comment,
  [647885] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20761), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16046), 2,
      sym_comment,
      sym_block_comment,
  [647900] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20763), 1,
      sym__indent,
    STATE(13037), 1,
      sym__indented_type_cases,
    STATE(16047), 2,
      sym_comment,
      sym_block_comment,
  [647917] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20765), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16048), 2,
      sym_comment,
      sym_block_comment,
  [647932] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16450), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(16049), 2,
      sym_comment,
      sym_block_comment,
  [647947] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20767), 1,
      anon_sym_LPAREN,
    STATE(12453), 1,
      sym_parenthesized_expression,
    STATE(16050), 2,
      sym_comment,
      sym_block_comment,
  [647964] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20769), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(16051), 2,
      sym_comment,
      sym_block_comment,
  [647979] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20771), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16052), 2,
      sym_comment,
      sym_block_comment,
  [647994] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20773), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16053), 2,
      sym_comment,
      sym_block_comment,
  [648009] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20775), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(16054), 2,
      sym_comment,
      sym_block_comment,
  [648024] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20777), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16055), 2,
      sym_comment,
      sym_block_comment,
  [648039] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20779), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16056), 2,
      sym_comment,
      sym_block_comment,
  [648054] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20781), 1,
      anon_sym_LPAREN,
    STATE(13091), 1,
      sym_parenthesized_expression,
    STATE(16057), 2,
      sym_comment,
      sym_block_comment,
  [648071] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20783), 1,
      sym__indent,
    STATE(14247), 1,
      sym_with_template_body,
    STATE(16058), 2,
      sym_comment,
      sym_block_comment,
  [648088] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20785), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16059), 2,
      sym_comment,
      sym_block_comment,
  [648103] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20573), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16060), 2,
      sym_comment,
      sym_block_comment,
  [648118] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20787), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16061), 2,
      sym_comment,
      sym_block_comment,
  [648133] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20789), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16062), 2,
      sym_comment,
      sym_block_comment,
  [648148] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10714), 2,
      anon_sym_with,
      anon_sym_LPAREN,
    STATE(16063), 2,
      sym_comment,
      sym_block_comment,
  [648163] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20791), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16064), 2,
      sym_comment,
      sym_block_comment,
  [648178] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20793), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16065), 2,
      sym_comment,
      sym_block_comment,
  [648193] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20795), 2,
      sym__interpolated_string_middle,
      sym__interpolated_string_end,
    STATE(16066), 2,
      sym_comment,
      sym_block_comment,
  [648208] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20797), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16067), 2,
      sym_comment,
      sym_block_comment,
  [648223] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11881), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16068), 2,
      sym_comment,
      sym_block_comment,
  [648238] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20799), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16069), 2,
      sym_comment,
      sym_block_comment,
  [648253] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20801), 1,
      anon_sym_COLON,
    ACTIONS(20803), 1,
      anon_sym_EQ,
    STATE(16070), 2,
      sym_comment,
      sym_block_comment,
  [648270] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20795), 2,
      sym__interpolated_multiline_string_middle,
      sym__interpolated_multiline_string_end,
    STATE(16071), 2,
      sym_comment,
      sym_block_comment,
  [648285] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20805), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16072), 2,
      sym_comment,
      sym_block_comment,
  [648300] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10046), 2,
      anon_sym_with,
      anon_sym_LPAREN,
    STATE(16073), 2,
      sym_comment,
      sym_block_comment,
  [648315] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20807), 1,
      anon_sym_LPAREN,
    STATE(13977), 1,
      sym_parenthesized_expression,
    STATE(16074), 2,
      sym_comment,
      sym_block_comment,
  [648332] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20809), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16075), 2,
      sym_comment,
      sym_block_comment,
  [648347] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10426), 2,
      sym__interpolated_string_middle,
      sym__interpolated_string_end,
    STATE(16076), 2,
      sym_comment,
      sym_block_comment,
  [648362] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20811), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16077), 2,
      sym_comment,
      sym_block_comment,
  [648377] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20813), 2,
      sym__interpolated_string_middle,
      sym__interpolated_string_end,
    STATE(16078), 2,
      sym_comment,
      sym_block_comment,
  [648392] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20813), 2,
      sym__interpolated_multiline_string_middle,
      sym__interpolated_multiline_string_end,
    STATE(16079), 2,
      sym_comment,
      sym_block_comment,
  [648407] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20815), 2,
      sym__interpolated_string_middle,
      sym__interpolated_string_end,
    STATE(16080), 2,
      sym_comment,
      sym_block_comment,
  [648422] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20815), 2,
      sym__interpolated_multiline_string_middle,
      sym__interpolated_multiline_string_end,
    STATE(16081), 2,
      sym_comment,
      sym_block_comment,
  [648437] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20817), 1,
      anon_sym_LPAREN,
    STATE(13521), 1,
      sym_parenthesized_expression,
    STATE(16082), 2,
      sym_comment,
      sym_block_comment,
  [648454] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20819), 1,
      sym__indent,
    STATE(11875), 1,
      sym__indented_type_cases,
    STATE(16083), 2,
      sym_comment,
      sym_block_comment,
  [648471] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20821), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16084), 2,
      sym_comment,
      sym_block_comment,
  [648486] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20823), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16085), 2,
      sym_comment,
      sym_block_comment,
  [648501] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18609), 2,
      sym__interpolated_multiline_string_middle,
      sym__interpolated_multiline_string_end,
    STATE(16086), 2,
      sym_comment,
      sym_block_comment,
  [648516] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20825), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16087), 2,
      sym_comment,
      sym_block_comment,
  [648531] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20827), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16088), 2,
      sym_comment,
      sym_block_comment,
  [648546] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8094), 1,
      anon_sym_object,
    ACTIONS(8098), 1,
      anon_sym_class,
    STATE(16089), 2,
      sym_comment,
      sym_block_comment,
  [648563] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19506), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(16090), 2,
      sym_comment,
      sym_block_comment,
  [648578] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20829), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16091), 2,
      sym_comment,
      sym_block_comment,
  [648593] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20831), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16092), 2,
      sym_comment,
      sym_block_comment,
  [648608] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20833), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16093), 2,
      sym_comment,
      sym_block_comment,
  [648623] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20835), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16094), 2,
      sym_comment,
      sym_block_comment,
  [648638] = 3,
    ACTIONS(17673), 1,
      anon_sym_SLASH_STAR,
    STATE(16095), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(20837), 3,
      anon_sym_SLASH_SLASH,
      aux_sym_block_comment_token1,
      anon_sym_STAR_SLASH,
  [648651] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20839), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16096), 2,
      sym_comment,
      sym_block_comment,
  [648666] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8410), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16097), 2,
      sym_comment,
      sym_block_comment,
  [648681] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20841), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16098), 2,
      sym_comment,
      sym_block_comment,
  [648696] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20843), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16099), 2,
      sym_comment,
      sym_block_comment,
  [648711] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11873), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16100), 2,
      sym_comment,
      sym_block_comment,
  [648726] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20845), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16101), 2,
      sym_comment,
      sym_block_comment,
  [648741] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20847), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16102), 2,
      sym_comment,
      sym_block_comment,
  [648756] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20849), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16103), 2,
      sym_comment,
      sym_block_comment,
  [648771] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20851), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16104), 2,
      sym_comment,
      sym_block_comment,
  [648786] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19534), 2,
      sym__interpolated_string_middle,
      sym__interpolated_string_end,
    STATE(16105), 2,
      sym_comment,
      sym_block_comment,
  [648801] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20853), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16106), 2,
      sym_comment,
      sym_block_comment,
  [648816] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19551), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(16107), 2,
      sym_comment,
      sym_block_comment,
  [648831] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20855), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16108), 2,
      sym_comment,
      sym_block_comment,
  [648846] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20857), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16109), 2,
      sym_comment,
      sym_block_comment,
  [648861] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20859), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16110), 2,
      sym_comment,
      sym_block_comment,
  [648876] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20861), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16111), 2,
      sym_comment,
      sym_block_comment,
  [648891] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20863), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16112), 2,
      sym_comment,
      sym_block_comment,
  [648906] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20865), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16113), 2,
      sym_comment,
      sym_block_comment,
  [648921] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17637), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(16114), 2,
      sym_comment,
      sym_block_comment,
  [648936] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20867), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16115), 2,
      sym_comment,
      sym_block_comment,
  [648951] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20869), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16116), 2,
      sym_comment,
      sym_block_comment,
  [648966] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20871), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16117), 2,
      sym_comment,
      sym_block_comment,
  [648981] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20873), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(16118), 2,
      sym_comment,
      sym_block_comment,
  [648996] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20875), 1,
      anon_sym_LPAREN,
    STATE(12958), 1,
      sym_parenthesized_expression,
    STATE(16119), 2,
      sym_comment,
      sym_block_comment,
  [649013] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20877), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16120), 2,
      sym_comment,
      sym_block_comment,
  [649028] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20879), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16121), 2,
      sym_comment,
      sym_block_comment,
  [649043] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20881), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16122), 2,
      sym_comment,
      sym_block_comment,
  [649058] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20883), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16123), 2,
      sym_comment,
      sym_block_comment,
  [649073] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20885), 1,
      sym__indent,
    STATE(11139), 1,
      sym__indented_type_cases,
    STATE(16124), 2,
      sym_comment,
      sym_block_comment,
  [649090] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19557), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(16125), 2,
      sym_comment,
      sym_block_comment,
  [649105] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20887), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16126), 2,
      sym_comment,
      sym_block_comment,
  [649120] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20889), 1,
      sym__indent,
    STATE(13515), 1,
      sym__indented_type_cases,
    STATE(16127), 2,
      sym_comment,
      sym_block_comment,
  [649137] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10033), 2,
      anon_sym_with,
      anon_sym_LPAREN,
    STATE(16128), 2,
      sym_comment,
      sym_block_comment,
  [649152] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20891), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16129), 2,
      sym_comment,
      sym_block_comment,
  [649167] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20893), 1,
      anon_sym_LPAREN,
    STATE(12606), 1,
      sym_parenthesized_expression,
    STATE(16130), 2,
      sym_comment,
      sym_block_comment,
  [649184] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20895), 1,
      sym__indent,
    STATE(11808), 1,
      sym__indented_type_cases,
    STATE(16131), 2,
      sym_comment,
      sym_block_comment,
  [649201] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15908), 1,
      anon_sym_EQ_GT,
    ACTIONS(20897), 1,
      anon_sym_COLON,
    STATE(16132), 2,
      sym_comment,
      sym_block_comment,
  [649218] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20899), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16133), 2,
      sym_comment,
      sym_block_comment,
  [649233] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20901), 1,
      sym__indent,
    STATE(11067), 1,
      sym__indented_type_cases,
    STATE(16134), 2,
      sym_comment,
      sym_block_comment,
  [649250] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20903), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16135), 2,
      sym_comment,
      sym_block_comment,
  [649265] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20905), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16136), 2,
      sym_comment,
      sym_block_comment,
  [649280] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11877), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16137), 2,
      sym_comment,
      sym_block_comment,
  [649295] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20907), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16138), 2,
      sym_comment,
      sym_block_comment,
  [649310] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10706), 2,
      anon_sym_with,
      anon_sym_LPAREN,
    STATE(16139), 2,
      sym_comment,
      sym_block_comment,
  [649325] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20909), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16140), 2,
      sym_comment,
      sym_block_comment,
  [649340] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20911), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16141), 2,
      sym_comment,
      sym_block_comment,
  [649355] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20913), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16142), 2,
      sym_comment,
      sym_block_comment,
  [649370] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20915), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16143), 2,
      sym_comment,
      sym_block_comment,
  [649385] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11904), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16144), 2,
      sym_comment,
      sym_block_comment,
  [649400] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20917), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16145), 2,
      sym_comment,
      sym_block_comment,
  [649415] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20919), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16146), 2,
      sym_comment,
      sym_block_comment,
  [649430] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20921), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16147), 2,
      sym_comment,
      sym_block_comment,
  [649445] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20923), 1,
      anon_sym_RBRACE,
    STATE(16148), 2,
      sym_comment,
      sym_block_comment,
  [649459] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20925), 1,
      sym__outdent,
    STATE(16149), 2,
      sym_comment,
      sym_block_comment,
  [649473] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12960), 1,
      anon_sym_DOT,
    STATE(16150), 2,
      sym_comment,
      sym_block_comment,
  [649487] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20927), 1,
      anon_sym_EQ_GT_GT,
    STATE(16151), 2,
      sym_comment,
      sym_block_comment,
  [649501] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20443), 1,
      anon_sym_EQ_GT,
    STATE(16152), 2,
      sym_comment,
      sym_block_comment,
  [649515] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20929), 1,
      anon_sym_do,
    STATE(16153), 2,
      sym_comment,
      sym_block_comment,
  [649529] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20931), 1,
      anon_sym_EQ_GT_GT,
    STATE(16154), 2,
      sym_comment,
      sym_block_comment,
  [649543] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20933), 1,
      anon_sym_RPAREN,
    STATE(16155), 2,
      sym_comment,
      sym_block_comment,
  [649557] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20935), 1,
      anon_sym_EQ_GT_GT,
    STATE(16156), 2,
      sym_comment,
      sym_block_comment,
  [649571] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20937), 1,
      sym__outdent,
    STATE(16157), 2,
      sym_comment,
      sym_block_comment,
  [649585] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20939), 1,
      anon_sym_RBRACE,
    STATE(16158), 2,
      sym_comment,
      sym_block_comment,
  [649599] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20941), 1,
      anon_sym_RBRACE,
    STATE(16159), 2,
      sym_comment,
      sym_block_comment,
  [649613] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20943), 1,
      anon_sym_else,
    STATE(16160), 2,
      sym_comment,
      sym_block_comment,
  [649627] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8108), 1,
      anon_sym_def,
    STATE(16161), 2,
      sym_comment,
      sym_block_comment,
  [649641] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20945), 1,
      anon_sym_RPAREN,
    STATE(16162), 2,
      sym_comment,
      sym_block_comment,
  [649655] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20947), 1,
      anon_sym_RBRACE,
    STATE(16163), 2,
      sym_comment,
      sym_block_comment,
  [649669] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20949), 1,
      sym__outdent,
    STATE(16164), 2,
      sym_comment,
      sym_block_comment,
  [649683] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20951), 1,
      anon_sym_EQ_GT,
    STATE(16165), 2,
      sym_comment,
      sym_block_comment,
  [649697] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20953), 1,
      anon_sym_else,
    STATE(16166), 2,
      sym_comment,
      sym_block_comment,
  [649711] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20947), 1,
      anon_sym_RPAREN,
    STATE(16167), 2,
      sym_comment,
      sym_block_comment,
  [649725] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20955), 1,
      anon_sym_EQ_GT_GT,
    STATE(16168), 2,
      sym_comment,
      sym_block_comment,
  [649739] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20957), 1,
      anon_sym_RBRACE,
    STATE(16169), 2,
      sym_comment,
      sym_block_comment,
  [649753] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20959), 1,
      anon_sym_EQ_GT_GT,
    STATE(16170), 2,
      sym_comment,
      sym_block_comment,
  [649767] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20961), 1,
      anon_sym_EQ_GT_GT,
    STATE(16171), 2,
      sym_comment,
      sym_block_comment,
  [649781] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20963), 1,
      anon_sym_EQ_GT_GT,
    STATE(16172), 2,
      sym_comment,
      sym_block_comment,
  [649795] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20965), 1,
      anon_sym_RPAREN,
    STATE(16173), 2,
      sym_comment,
      sym_block_comment,
  [649809] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20967), 1,
      sym__outdent,
    STATE(16174), 2,
      sym_comment,
      sym_block_comment,
  [649823] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20969), 1,
      anon_sym_RBRACE,
    STATE(16175), 2,
      sym_comment,
      sym_block_comment,
  [649837] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20971), 1,
      sym__outdent,
    STATE(16176), 2,
      sym_comment,
      sym_block_comment,
  [649851] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20973), 1,
      anon_sym_COLON,
    STATE(16177), 2,
      sym_comment,
      sym_block_comment,
  [649865] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11846), 1,
      anon_sym_DOT,
    STATE(16178), 2,
      sym_comment,
      sym_block_comment,
  [649879] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20975), 1,
      anon_sym_RBRACE,
    STATE(16179), 2,
      sym_comment,
      sym_block_comment,
  [649893] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20975), 1,
      anon_sym_RPAREN,
    STATE(16180), 2,
      sym_comment,
      sym_block_comment,
  [649907] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20977), 1,
      anon_sym_RPAREN,
    STATE(16181), 2,
      sym_comment,
      sym_block_comment,
  [649921] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20979), 1,
      sym__outdent,
    STATE(16182), 2,
      sym_comment,
      sym_block_comment,
  [649935] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20981), 1,
      sym__outdent,
    STATE(16183), 2,
      sym_comment,
      sym_block_comment,
  [649949] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20983), 1,
      anon_sym_RPAREN,
    STATE(16184), 2,
      sym_comment,
      sym_block_comment,
  [649963] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20985), 1,
      anon_sym_RPAREN,
    STATE(16185), 2,
      sym_comment,
      sym_block_comment,
  [649977] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20987), 1,
      anon_sym_RPAREN,
    STATE(16186), 2,
      sym_comment,
      sym_block_comment,
  [649991] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20989), 1,
      sym__outdent,
    STATE(16187), 2,
      sym_comment,
      sym_block_comment,
  [650005] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20991), 1,
      anon_sym_RBRACE,
    STATE(16188), 2,
      sym_comment,
      sym_block_comment,
  [650019] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20993), 1,
      anon_sym_RPAREN,
    STATE(16189), 2,
      sym_comment,
      sym_block_comment,
  [650033] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20995), 1,
      anon_sym_else,
    STATE(16190), 2,
      sym_comment,
      sym_block_comment,
  [650047] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20997), 1,
      anon_sym_RBRACE,
    STATE(16191), 2,
      sym_comment,
      sym_block_comment,
  [650061] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20999), 1,
      anon_sym_RPAREN,
    STATE(16192), 2,
      sym_comment,
      sym_block_comment,
  [650075] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21001), 1,
      anon_sym_else,
    STATE(16193), 2,
      sym_comment,
      sym_block_comment,
  [650089] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21003), 1,
      anon_sym_else,
    STATE(16194), 2,
      sym_comment,
      sym_block_comment,
  [650103] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21005), 1,
      anon_sym_EQ_GT,
    STATE(16195), 2,
      sym_comment,
      sym_block_comment,
  [650117] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21007), 1,
      anon_sym_RPAREN,
    STATE(16196), 2,
      sym_comment,
      sym_block_comment,
  [650131] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21009), 1,
      sym__outdent,
    STATE(16197), 2,
      sym_comment,
      sym_block_comment,
  [650145] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21011), 1,
      anon_sym_EQ_GT_GT,
    STATE(16198), 2,
      sym_comment,
      sym_block_comment,
  [650159] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21013), 1,
      sym__outdent,
    STATE(16199), 2,
      sym_comment,
      sym_block_comment,
  [650173] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21015), 1,
      anon_sym_EQ_GT_GT,
    STATE(16200), 2,
      sym_comment,
      sym_block_comment,
  [650187] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21017), 1,
      anon_sym_EQ_GT_GT,
    STATE(16201), 2,
      sym_comment,
      sym_block_comment,
  [650201] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21019), 1,
      anon_sym_EQ_GT_GT,
    STATE(16202), 2,
      sym_comment,
      sym_block_comment,
  [650215] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15172), 1,
      anon_sym_type,
    STATE(16203), 2,
      sym_comment,
      sym_block_comment,
  [650229] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21021), 1,
      anon_sym_RPAREN,
    STATE(16204), 2,
      sym_comment,
      sym_block_comment,
  [650243] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21023), 1,
      sym__outdent,
    STATE(16205), 2,
      sym_comment,
      sym_block_comment,
  [650257] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21025), 1,
      anon_sym_RPAREN,
    STATE(16206), 2,
      sym_comment,
      sym_block_comment,
  [650271] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21027), 1,
      anon_sym_COLON,
    STATE(16207), 2,
      sym_comment,
      sym_block_comment,
  [650285] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10980), 1,
      anon_sym_DOT,
    STATE(16208), 2,
      sym_comment,
      sym_block_comment,
  [650299] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21029), 1,
      sym__outdent,
    STATE(16209), 2,
      sym_comment,
      sym_block_comment,
  [650313] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21031), 1,
      anon_sym_else,
    STATE(16210), 2,
      sym_comment,
      sym_block_comment,
  [650327] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21033), 1,
      anon_sym_RPAREN,
    STATE(16211), 2,
      sym_comment,
      sym_block_comment,
  [650341] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21035), 1,
      anon_sym_RPAREN,
    STATE(16212), 2,
      sym_comment,
      sym_block_comment,
  [650355] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21037), 1,
      sym__outdent,
    STATE(16213), 2,
      sym_comment,
      sym_block_comment,
  [650369] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21039), 1,
      sym__outdent,
    STATE(16214), 2,
      sym_comment,
      sym_block_comment,
  [650383] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21041), 1,
      anon_sym_RPAREN,
    STATE(16215), 2,
      sym_comment,
      sym_block_comment,
  [650397] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21043), 1,
      anon_sym_RBRACE,
    STATE(16216), 2,
      sym_comment,
      sym_block_comment,
  [650411] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21045), 1,
      anon_sym_RBRACE,
    STATE(16217), 2,
      sym_comment,
      sym_block_comment,
  [650425] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21047), 1,
      anon_sym_RBRACE,
    STATE(16218), 2,
      sym_comment,
      sym_block_comment,
  [650439] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21049), 1,
      sym__outdent,
    STATE(16219), 2,
      sym_comment,
      sym_block_comment,
  [650453] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21051), 1,
      anon_sym_else,
    STATE(16220), 2,
      sym_comment,
      sym_block_comment,
  [650467] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21053), 1,
      anon_sym_RPAREN,
    STATE(16221), 2,
      sym_comment,
      sym_block_comment,
  [650481] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21055), 1,
      anon_sym_else,
    STATE(16222), 2,
      sym_comment,
      sym_block_comment,
  [650495] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21057), 1,
      anon_sym_RPAREN,
    STATE(16223), 2,
      sym_comment,
      sym_block_comment,
  [650509] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21059), 1,
      anon_sym_RBRACE,
    STATE(16224), 2,
      sym_comment,
      sym_block_comment,
  [650523] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21061), 1,
      anon_sym_EQ_GT,
    STATE(16225), 2,
      sym_comment,
      sym_block_comment,
  [650537] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21063), 1,
      sym__outdent,
    STATE(16226), 2,
      sym_comment,
      sym_block_comment,
  [650551] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21065), 1,
      anon_sym_do,
    STATE(16227), 2,
      sym_comment,
      sym_block_comment,
  [650565] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21067), 1,
      anon_sym_EQ_GT_GT,
    STATE(16228), 2,
      sym_comment,
      sym_block_comment,
  [650579] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21069), 1,
      sym__outdent,
    STATE(16229), 2,
      sym_comment,
      sym_block_comment,
  [650593] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21071), 1,
      anon_sym_EQ_GT_GT,
    STATE(16230), 2,
      sym_comment,
      sym_block_comment,
  [650607] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21073), 1,
      anon_sym_EQ_GT_GT,
    STATE(16231), 2,
      sym_comment,
      sym_block_comment,
  [650621] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21075), 1,
      anon_sym_EQ_GT_GT,
    STATE(16232), 2,
      sym_comment,
      sym_block_comment,
  [650635] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21077), 1,
      sym__outdent,
    STATE(16233), 2,
      sym_comment,
      sym_block_comment,
  [650649] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21079), 1,
      anon_sym_RPAREN,
    STATE(16234), 2,
      sym_comment,
      sym_block_comment,
  [650663] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21081), 1,
      anon_sym_RBRACE,
    STATE(16235), 2,
      sym_comment,
      sym_block_comment,
  [650677] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21083), 1,
      sym__outdent,
    STATE(16236), 2,
      sym_comment,
      sym_block_comment,
  [650691] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21085), 1,
      anon_sym_COLON,
    STATE(16237), 2,
      sym_comment,
      sym_block_comment,
  [650705] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11621), 1,
      anon_sym_DOT,
    STATE(16238), 2,
      sym_comment,
      sym_block_comment,
  [650719] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21059), 1,
      anon_sym_RBRACK,
    STATE(16239), 2,
      sym_comment,
      sym_block_comment,
  [650733] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21087), 1,
      anon_sym_RBRACE,
    STATE(16240), 2,
      sym_comment,
      sym_block_comment,
  [650747] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21089), 1,
      anon_sym_RBRACE,
    STATE(16241), 2,
      sym_comment,
      sym_block_comment,
  [650761] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21091), 1,
      anon_sym_RBRACE,
    STATE(16242), 2,
      sym_comment,
      sym_block_comment,
  [650775] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21093), 1,
      sym__outdent,
    STATE(16243), 2,
      sym_comment,
      sym_block_comment,
  [650789] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21095), 1,
      anon_sym_else,
    STATE(16244), 2,
      sym_comment,
      sym_block_comment,
  [650803] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21097), 1,
      anon_sym_RPAREN,
    STATE(16245), 2,
      sym_comment,
      sym_block_comment,
  [650817] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21091), 1,
      anon_sym_RBRACK,
    STATE(16246), 2,
      sym_comment,
      sym_block_comment,
  [650831] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21099), 1,
      sym__outdent,
    STATE(16247), 2,
      sym_comment,
      sym_block_comment,
  [650845] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21101), 1,
      anon_sym_RPAREN,
    STATE(16248), 2,
      sym_comment,
      sym_block_comment,
  [650859] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21103), 1,
      sym__outdent,
    STATE(16249), 2,
      sym_comment,
      sym_block_comment,
  [650873] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21105), 1,
      sym__outdent,
    STATE(16250), 2,
      sym_comment,
      sym_block_comment,
  [650887] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21107), 1,
      sym__outdent,
    STATE(16251), 2,
      sym_comment,
      sym_block_comment,
  [650901] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21109), 1,
      sym__outdent,
    STATE(16252), 2,
      sym_comment,
      sym_block_comment,
  [650915] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21111), 1,
      sym__outdent,
    STATE(16253), 2,
      sym_comment,
      sym_block_comment,
  [650929] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21113), 1,
      anon_sym_do,
    STATE(16254), 2,
      sym_comment,
      sym_block_comment,
  [650943] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21115), 1,
      anon_sym_EQ_GT,
    STATE(16255), 2,
      sym_comment,
      sym_block_comment,
  [650957] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21117), 1,
      anon_sym_RBRACE,
    STATE(16256), 2,
      sym_comment,
      sym_block_comment,
  [650971] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21119), 1,
      anon_sym_RBRACE,
    STATE(16257), 2,
      sym_comment,
      sym_block_comment,
  [650985] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21121), 1,
      anon_sym_EQ_GT_GT,
    STATE(16258), 2,
      sym_comment,
      sym_block_comment,
  [650999] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21123), 1,
      anon_sym_RBRACE,
    STATE(16259), 2,
      sym_comment,
      sym_block_comment,
  [651013] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21125), 1,
      anon_sym_EQ_GT_GT,
    STATE(16260), 2,
      sym_comment,
      sym_block_comment,
  [651027] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21127), 1,
      anon_sym_EQ_GT_GT,
    STATE(16261), 2,
      sym_comment,
      sym_block_comment,
  [651041] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21129), 1,
      anon_sym_EQ_GT_GT,
    STATE(16262), 2,
      sym_comment,
      sym_block_comment,
  [651055] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21119), 1,
      anon_sym_RPAREN,
    STATE(16263), 2,
      sym_comment,
      sym_block_comment,
  [651069] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21131), 1,
      anon_sym_do,
    STATE(16264), 2,
      sym_comment,
      sym_block_comment,
  [651083] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21133), 1,
      anon_sym_COLON,
    STATE(16265), 2,
      sym_comment,
      sym_block_comment,
  [651097] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11406), 1,
      anon_sym_DOT,
    STATE(16266), 2,
      sym_comment,
      sym_block_comment,
  [651111] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21135), 1,
      anon_sym_with,
    STATE(16267), 2,
      sym_comment,
      sym_block_comment,
  [651125] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21137), 1,
      anon_sym_RPAREN,
    STATE(16268), 2,
      sym_comment,
      sym_block_comment,
  [651139] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21139), 1,
      anon_sym_RPAREN,
    STATE(16269), 2,
      sym_comment,
      sym_block_comment,
  [651153] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21141), 1,
      sym__outdent,
    STATE(16270), 2,
      sym_comment,
      sym_block_comment,
  [651167] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21143), 1,
      sym__outdent,
    STATE(16271), 2,
      sym_comment,
      sym_block_comment,
  [651181] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21145), 1,
      anon_sym_RBRACE,
    STATE(16272), 2,
      sym_comment,
      sym_block_comment,
  [651195] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21117), 1,
      anon_sym_RBRACK,
    STATE(16273), 2,
      sym_comment,
      sym_block_comment,
  [651209] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21147), 1,
      anon_sym_RBRACK,
    STATE(16274), 2,
      sym_comment,
      sym_block_comment,
  [651223] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21149), 1,
      anon_sym_RPAREN,
    STATE(16275), 2,
      sym_comment,
      sym_block_comment,
  [651237] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21151), 1,
      sym__outdent,
    STATE(16276), 2,
      sym_comment,
      sym_block_comment,
  [651251] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21153), 1,
      anon_sym_RBRACE,
    STATE(16277), 2,
      sym_comment,
      sym_block_comment,
  [651265] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21155), 1,
      anon_sym_RPAREN,
    STATE(16278), 2,
      sym_comment,
      sym_block_comment,
  [651279] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15174), 1,
      anon_sym_def,
    STATE(16279), 2,
      sym_comment,
      sym_block_comment,
  [651293] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21157), 1,
      sym__outdent,
    STATE(16280), 2,
      sym_comment,
      sym_block_comment,
  [651307] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21045), 1,
      anon_sym_RPAREN,
    STATE(16281), 2,
      sym_comment,
      sym_block_comment,
  [651321] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21159), 1,
      anon_sym_EQ_GT,
    STATE(16282), 2,
      sym_comment,
      sym_block_comment,
  [651335] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21161), 1,
      anon_sym_RBRACK,
    STATE(16283), 2,
      sym_comment,
      sym_block_comment,
  [651349] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21163), 1,
      anon_sym_RPAREN,
    STATE(16284), 2,
      sym_comment,
      sym_block_comment,
  [651363] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21165), 1,
      anon_sym_EQ_GT_GT,
    STATE(16285), 2,
      sym_comment,
      sym_block_comment,
  [651377] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21167), 1,
      anon_sym_else,
    STATE(16286), 2,
      sym_comment,
      sym_block_comment,
  [651391] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21169), 1,
      anon_sym_EQ_GT_GT,
    STATE(16287), 2,
      sym_comment,
      sym_block_comment,
  [651405] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21171), 1,
      anon_sym_EQ_GT_GT,
    STATE(16288), 2,
      sym_comment,
      sym_block_comment,
  [651419] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21173), 1,
      anon_sym_EQ_GT_GT,
    STATE(16289), 2,
      sym_comment,
      sym_block_comment,
  [651433] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21175), 1,
      anon_sym_RBRACE,
    STATE(16290), 2,
      sym_comment,
      sym_block_comment,
  [651447] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21175), 1,
      anon_sym_RBRACK,
    STATE(16291), 2,
      sym_comment,
      sym_block_comment,
  [651461] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21177), 1,
      anon_sym_COLON,
    STATE(16292), 2,
      sym_comment,
      sym_block_comment,
  [651475] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10883), 1,
      anon_sym_DOT,
    STATE(16293), 2,
      sym_comment,
      sym_block_comment,
  [651489] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21179), 1,
      anon_sym_RBRACE,
    STATE(16294), 2,
      sym_comment,
      sym_block_comment,
  [651503] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21181), 1,
      anon_sym_RBRACE,
    STATE(16295), 2,
      sym_comment,
      sym_block_comment,
  [651517] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21181), 1,
      anon_sym_RBRACK,
    STATE(16296), 2,
      sym_comment,
      sym_block_comment,
  [651531] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21183), 1,
      anon_sym_RBRACE,
    STATE(16297), 2,
      sym_comment,
      sym_block_comment,
  [651545] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21179), 1,
      anon_sym_RPAREN,
    STATE(16298), 2,
      sym_comment,
      sym_block_comment,
  [651559] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21185), 1,
      anon_sym_RBRACE,
    STATE(16299), 2,
      sym_comment,
      sym_block_comment,
  [651573] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21187), 1,
      anon_sym_COLON,
    STATE(16300), 2,
      sym_comment,
      sym_block_comment,
  [651587] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21185), 1,
      anon_sym_RPAREN,
    STATE(16301), 2,
      sym_comment,
      sym_block_comment,
  [651601] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21189), 1,
      anon_sym_RPAREN,
    STATE(16302), 2,
      sym_comment,
      sym_block_comment,
  [651615] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21191), 1,
      anon_sym_RPAREN,
    STATE(16303), 2,
      sym_comment,
      sym_block_comment,
  [651629] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8176), 1,
      anon_sym_DOT,
    STATE(16304), 2,
      sym_comment,
      sym_block_comment,
  [651643] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21193), 1,
      sym__outdent,
    STATE(16305), 2,
      sym_comment,
      sym_block_comment,
  [651657] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21195), 1,
      anon_sym_RBRACE,
    STATE(16306), 2,
      sym_comment,
      sym_block_comment,
  [651671] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21197), 1,
      anon_sym_RBRACE,
    STATE(16307), 2,
      sym_comment,
      sym_block_comment,
  [651685] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21199), 1,
      anon_sym_do,
    STATE(16308), 2,
      sym_comment,
      sym_block_comment,
  [651699] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21201), 1,
      anon_sym_EQ_GT_GT,
    STATE(16309), 2,
      sym_comment,
      sym_block_comment,
  [651713] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21203), 1,
      anon_sym_RBRACE,
    STATE(16310), 2,
      sym_comment,
      sym_block_comment,
  [651727] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21205), 1,
      anon_sym_EQ_GT_GT,
    STATE(16311), 2,
      sym_comment,
      sym_block_comment,
  [651741] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21207), 1,
      anon_sym_EQ_GT_GT,
    STATE(16312), 2,
      sym_comment,
      sym_block_comment,
  [651755] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21209), 1,
      anon_sym_EQ_GT_GT,
    STATE(16313), 2,
      sym_comment,
      sym_block_comment,
  [651769] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21211), 1,
      anon_sym_RBRACE,
    STATE(16314), 2,
      sym_comment,
      sym_block_comment,
  [651783] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21213), 1,
      anon_sym_else,
    STATE(16315), 2,
      sym_comment,
      sym_block_comment,
  [651797] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21215), 1,
      anon_sym_COLON,
    STATE(16316), 2,
      sym_comment,
      sym_block_comment,
  [651811] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13354), 1,
      anon_sym_DOT,
    STATE(16317), 2,
      sym_comment,
      sym_block_comment,
  [651825] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8218), 1,
      anon_sym_def,
    STATE(16318), 2,
      sym_comment,
      sym_block_comment,
  [651839] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21217), 1,
      anon_sym_LPAREN,
    STATE(16319), 2,
      sym_comment,
      sym_block_comment,
  [651853] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21219), 1,
      anon_sym_else,
    STATE(16320), 2,
      sym_comment,
      sym_block_comment,
  [651867] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21221), 1,
      anon_sym_RBRACE,
    STATE(16321), 2,
      sym_comment,
      sym_block_comment,
  [651881] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21221), 1,
      anon_sym_RBRACK,
    STATE(16322), 2,
      sym_comment,
      sym_block_comment,
  [651895] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21223), 1,
      anon_sym_else,
    STATE(16323), 2,
      sym_comment,
      sym_block_comment,
  [651909] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21225), 1,
      anon_sym_RPAREN,
    STATE(16324), 2,
      sym_comment,
      sym_block_comment,
  [651923] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21227), 1,
      anon_sym_RBRACE,
    STATE(16325), 2,
      sym_comment,
      sym_block_comment,
  [651937] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21229), 1,
      sym__outdent,
    STATE(16326), 2,
      sym_comment,
      sym_block_comment,
  [651951] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21231), 1,
      anon_sym_RBRACE,
    STATE(16327), 2,
      sym_comment,
      sym_block_comment,
  [651965] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21233), 1,
      anon_sym_RPAREN,
    STATE(16328), 2,
      sym_comment,
      sym_block_comment,
  [651979] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21235), 1,
      sym__outdent,
    STATE(16329), 2,
      sym_comment,
      sym_block_comment,
  [651993] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21237), 1,
      anon_sym_RPAREN,
    STATE(16330), 2,
      sym_comment,
      sym_block_comment,
  [652007] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21239), 1,
      sym__outdent,
    STATE(16331), 2,
      sym_comment,
      sym_block_comment,
  [652021] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21241), 1,
      anon_sym_RPAREN,
    STATE(16332), 2,
      sym_comment,
      sym_block_comment,
  [652035] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21243), 1,
      anon_sym_EQ_GT_GT,
    STATE(16333), 2,
      sym_comment,
      sym_block_comment,
  [652049] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21245), 1,
      anon_sym_EQ_GT_GT,
    STATE(16334), 2,
      sym_comment,
      sym_block_comment,
  [652063] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21247), 1,
      anon_sym_EQ_GT_GT,
    STATE(16335), 2,
      sym_comment,
      sym_block_comment,
  [652077] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21249), 1,
      anon_sym_EQ_GT_GT,
    STATE(16336), 2,
      sym_comment,
      sym_block_comment,
  [652091] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21251), 1,
      sym__outdent,
    STATE(16337), 2,
      sym_comment,
      sym_block_comment,
  [652105] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21253), 1,
      anon_sym_RBRACE,
    STATE(16338), 2,
      sym_comment,
      sym_block_comment,
  [652119] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21255), 1,
      anon_sym_COLON,
    STATE(16339), 2,
      sym_comment,
      sym_block_comment,
  [652133] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10070), 1,
      anon_sym_DOT,
    STATE(16340), 2,
      sym_comment,
      sym_block_comment,
  [652147] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21257), 1,
      anon_sym_RPAREN,
    STATE(16341), 2,
      sym_comment,
      sym_block_comment,
  [652161] = 4,
    ACTIONS(17667), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(17673), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21259), 1,
      sym_using_directive_key,
    STATE(16342), 2,
      sym_comment,
      sym_block_comment,
  [652175] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21261), 1,
      anon_sym_type,
    STATE(16343), 2,
      sym_comment,
      sym_block_comment,
  [652189] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21263), 1,
      sym__outdent,
    STATE(16344), 2,
      sym_comment,
      sym_block_comment,
  [652203] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21265), 1,
      anon_sym_do,
    STATE(16345), 2,
      sym_comment,
      sym_block_comment,
  [652217] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21267), 1,
      sym__outdent,
    STATE(16346), 2,
      sym_comment,
      sym_block_comment,
  [652231] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21269), 1,
      anon_sym_RBRACE,
    STATE(16347), 2,
      sym_comment,
      sym_block_comment,
  [652245] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21271), 1,
      anon_sym_RBRACE,
    STATE(16348), 2,
      sym_comment,
      sym_block_comment,
  [652259] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(577), 1,
      sym__outdent,
    STATE(16349), 2,
      sym_comment,
      sym_block_comment,
  [652273] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21273), 1,
      anon_sym_EQ_GT,
    STATE(16350), 2,
      sym_comment,
      sym_block_comment,
  [652287] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21275), 1,
      sym__outdent,
    STATE(16351), 2,
      sym_comment,
      sym_block_comment,
  [652301] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21277), 1,
      anon_sym_RPAREN,
    STATE(16352), 2,
      sym_comment,
      sym_block_comment,
  [652315] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21279), 1,
      anon_sym_EQ_GT,
    STATE(16353), 2,
      sym_comment,
      sym_block_comment,
  [652329] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21281), 1,
      sym__outdent,
    STATE(16354), 2,
      sym_comment,
      sym_block_comment,
  [652343] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21283), 1,
      anon_sym_do,
    STATE(16355), 2,
      sym_comment,
      sym_block_comment,
  [652357] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21285), 1,
      anon_sym_EQ_GT_GT,
    STATE(16356), 2,
      sym_comment,
      sym_block_comment,
  [652371] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21287), 1,
      anon_sym_EQ_GT_GT,
    STATE(16357), 2,
      sym_comment,
      sym_block_comment,
  [652385] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21289), 1,
      anon_sym_EQ_GT_GT,
    STATE(16358), 2,
      sym_comment,
      sym_block_comment,
  [652399] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21291), 1,
      anon_sym_EQ_GT_GT,
    STATE(16359), 2,
      sym_comment,
      sym_block_comment,
  [652413] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21269), 1,
      anon_sym_RPAREN,
    STATE(16360), 2,
      sym_comment,
      sym_block_comment,
  [652427] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21293), 1,
      anon_sym_RBRACE,
    STATE(16361), 2,
      sym_comment,
      sym_block_comment,
  [652441] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21295), 1,
      anon_sym_COLON,
    STATE(16362), 2,
      sym_comment,
      sym_block_comment,
  [652455] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8987), 1,
      anon_sym_DOT,
    STATE(16363), 2,
      sym_comment,
      sym_block_comment,
  [652469] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21297), 1,
      anon_sym_else,
    STATE(16364), 2,
      sym_comment,
      sym_block_comment,
  [652483] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21299), 1,
      sym__outdent,
    STATE(16365), 2,
      sym_comment,
      sym_block_comment,
  [652497] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21301), 1,
      anon_sym_RPAREN,
    STATE(16366), 2,
      sym_comment,
      sym_block_comment,
  [652511] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21303), 1,
      anon_sym_RBRACE,
    STATE(16367), 2,
      sym_comment,
      sym_block_comment,
  [652525] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21305), 1,
      sym__outdent,
    STATE(16368), 2,
      sym_comment,
      sym_block_comment,
  [652539] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21307), 1,
      sym__outdent,
    STATE(16369), 2,
      sym_comment,
      sym_block_comment,
  [652553] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21309), 1,
      anon_sym_RPAREN,
    STATE(16370), 2,
      sym_comment,
      sym_block_comment,
  [652567] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21227), 1,
      anon_sym_RBRACK,
    STATE(16371), 2,
      sym_comment,
      sym_block_comment,
  [652581] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21311), 1,
      anon_sym_RBRACE,
    STATE(16372), 2,
      sym_comment,
      sym_block_comment,
  [652595] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21313), 1,
      anon_sym_EQ_GT,
    STATE(16373), 2,
      sym_comment,
      sym_block_comment,
  [652609] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21315), 1,
      anon_sym_RPAREN,
    STATE(16374), 2,
      sym_comment,
      sym_block_comment,
  [652623] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20997), 1,
      anon_sym_RBRACK,
    STATE(16375), 2,
      sym_comment,
      sym_block_comment,
  [652637] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21317), 1,
      anon_sym_EQ_GT_GT,
    STATE(16376), 2,
      sym_comment,
      sym_block_comment,
  [652651] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21319), 1,
      anon_sym_EQ_GT_GT,
    STATE(16377), 2,
      sym_comment,
      sym_block_comment,
  [652665] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21321), 1,
      anon_sym_EQ_GT_GT,
    STATE(16378), 2,
      sym_comment,
      sym_block_comment,
  [652679] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21323), 1,
      anon_sym_EQ_GT_GT,
    STATE(16379), 2,
      sym_comment,
      sym_block_comment,
  [652693] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21325), 1,
      anon_sym_else,
    STATE(16380), 2,
      sym_comment,
      sym_block_comment,
  [652707] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21327), 1,
      sym__outdent,
    STATE(16381), 2,
      sym_comment,
      sym_block_comment,
  [652721] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21329), 1,
      anon_sym_COLON,
    STATE(16382), 2,
      sym_comment,
      sym_block_comment,
  [652735] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9567), 1,
      anon_sym_DOT,
    STATE(16383), 2,
      sym_comment,
      sym_block_comment,
  [652749] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21331), 1,
      anon_sym_RBRACE,
    STATE(16384), 2,
      sym_comment,
      sym_block_comment,
  [652763] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21303), 1,
      anon_sym_RBRACK,
    STATE(16385), 2,
      sym_comment,
      sym_block_comment,
  [652777] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21333), 1,
      anon_sym_RBRACE,
    STATE(16386), 2,
      sym_comment,
      sym_block_comment,
  [652791] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21335), 1,
      anon_sym_RPAREN,
    STATE(16387), 2,
      sym_comment,
      sym_block_comment,
  [652805] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21337), 1,
      sym__outdent,
    STATE(16388), 2,
      sym_comment,
      sym_block_comment,
  [652819] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21339), 1,
      sym__outdent,
    STATE(16389), 2,
      sym_comment,
      sym_block_comment,
  [652833] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21341), 1,
      anon_sym_EQ_GT,
    STATE(16390), 2,
      sym_comment,
      sym_block_comment,
  [652847] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21343), 1,
      anon_sym_RPAREN,
    STATE(16391), 2,
      sym_comment,
      sym_block_comment,
  [652861] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21345), 1,
      anon_sym_LPAREN,
    STATE(16392), 2,
      sym_comment,
      sym_block_comment,
  [652875] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21347), 1,
      anon_sym_do,
    STATE(16393), 2,
      sym_comment,
      sym_block_comment,
  [652889] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16065), 1,
      anon_sym_DOT,
    STATE(16394), 2,
      sym_comment,
      sym_block_comment,
  [652903] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21349), 1,
      anon_sym_EQ,
    STATE(16395), 2,
      sym_comment,
      sym_block_comment,
  [652917] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21351), 1,
      anon_sym_RBRACE,
    STATE(16396), 2,
      sym_comment,
      sym_block_comment,
  [652931] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21353), 1,
      anon_sym_EQ_GT_GT,
    STATE(16397), 2,
      sym_comment,
      sym_block_comment,
  [652945] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21355), 1,
      anon_sym_EQ_GT_GT,
    STATE(16398), 2,
      sym_comment,
      sym_block_comment,
  [652959] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21357), 1,
      anon_sym_EQ_GT_GT,
    STATE(16399), 2,
      sym_comment,
      sym_block_comment,
  [652973] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21359), 1,
      anon_sym_EQ_GT_GT,
    STATE(16400), 2,
      sym_comment,
      sym_block_comment,
  [652987] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21361), 1,
      anon_sym_EQ,
    STATE(16401), 2,
      sym_comment,
      sym_block_comment,
  [653001] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21363), 1,
      anon_sym_EQ_GT_GT,
    STATE(16402), 2,
      sym_comment,
      sym_block_comment,
  [653015] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20897), 1,
      anon_sym_COLON,
    STATE(16403), 2,
      sym_comment,
      sym_block_comment,
  [653029] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11002), 1,
      anon_sym_DOT,
    STATE(16404), 2,
      sym_comment,
      sym_block_comment,
  [653043] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21365), 1,
      anon_sym_else,
    STATE(16405), 2,
      sym_comment,
      sym_block_comment,
  [653057] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21367), 1,
      anon_sym_RBRACE,
    STATE(16406), 2,
      sym_comment,
      sym_block_comment,
  [653071] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21369), 1,
      anon_sym_RBRACK,
    STATE(16407), 2,
      sym_comment,
      sym_block_comment,
  [653085] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21371), 1,
      anon_sym_RBRACE,
    STATE(16408), 2,
      sym_comment,
      sym_block_comment,
  [653099] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21373), 1,
      sym__outdent,
    STATE(16409), 2,
      sym_comment,
      sym_block_comment,
  [653113] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21375), 1,
      anon_sym_RPAREN,
    STATE(16410), 2,
      sym_comment,
      sym_block_comment,
  [653127] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21377), 1,
      anon_sym_RBRACE,
    STATE(16411), 2,
      sym_comment,
      sym_block_comment,
  [653141] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21379), 1,
      anon_sym_RBRACE,
    STATE(16412), 2,
      sym_comment,
      sym_block_comment,
  [653155] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21377), 1,
      anon_sym_RPAREN,
    STATE(16413), 2,
      sym_comment,
      sym_block_comment,
  [653169] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21381), 1,
      anon_sym_RBRACE,
    STATE(16414), 2,
      sym_comment,
      sym_block_comment,
  [653183] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21383), 1,
      anon_sym_EQ_GT_GT,
    STATE(16415), 2,
      sym_comment,
      sym_block_comment,
  [653197] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21385), 1,
      anon_sym_RPAREN,
    STATE(16416), 2,
      sym_comment,
      sym_block_comment,
  [653211] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21387), 1,
      anon_sym_else,
    STATE(16417), 2,
      sym_comment,
      sym_block_comment,
  [653225] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21389), 1,
      anon_sym_EQ_GT_GT,
    STATE(16418), 2,
      sym_comment,
      sym_block_comment,
  [653239] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21391), 1,
      anon_sym_EQ_GT_GT,
    STATE(16419), 2,
      sym_comment,
      sym_block_comment,
  [653253] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21393), 1,
      anon_sym_EQ_GT_GT,
    STATE(16420), 2,
      sym_comment,
      sym_block_comment,
  [653267] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21395), 1,
      anon_sym_EQ_GT_GT,
    STATE(16421), 2,
      sym_comment,
      sym_block_comment,
  [653281] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21397), 1,
      anon_sym_RPAREN,
    STATE(16422), 2,
      sym_comment,
      sym_block_comment,
  [653295] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21399), 1,
      anon_sym_EQ_GT_GT,
    STATE(16423), 2,
      sym_comment,
      sym_block_comment,
  [653309] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21401), 1,
      anon_sym_COLON,
    STATE(16424), 2,
      sym_comment,
      sym_block_comment,
  [653323] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10638), 1,
      anon_sym_DOT,
    STATE(16425), 2,
      sym_comment,
      sym_block_comment,
  [653337] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21403), 1,
      sym__outdent,
    STATE(16426), 2,
      sym_comment,
      sym_block_comment,
  [653351] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21405), 1,
      anon_sym_RBRACE,
    STATE(16427), 2,
      sym_comment,
      sym_block_comment,
  [653365] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21405), 1,
      anon_sym_RPAREN,
    STATE(16428), 2,
      sym_comment,
      sym_block_comment,
  [653379] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21381), 1,
      anon_sym_RPAREN,
    STATE(16429), 2,
      sym_comment,
      sym_block_comment,
  [653393] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21407), 1,
      anon_sym_EQ_GT_GT,
    STATE(16430), 2,
      sym_comment,
      sym_block_comment,
  [653407] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21409), 1,
      anon_sym_EQ_GT_GT,
    STATE(16431), 2,
      sym_comment,
      sym_block_comment,
  [653421] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21411), 1,
      anon_sym_RPAREN,
    STATE(16432), 2,
      sym_comment,
      sym_block_comment,
  [653435] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21413), 1,
      sym__outdent,
    STATE(16433), 2,
      sym_comment,
      sym_block_comment,
  [653449] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21415), 1,
      sym__outdent,
    STATE(16434), 2,
      sym_comment,
      sym_block_comment,
  [653463] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21417), 1,
      anon_sym_RBRACE,
    STATE(16435), 2,
      sym_comment,
      sym_block_comment,
  [653477] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21419), 1,
      anon_sym_RPAREN,
    STATE(16436), 2,
      sym_comment,
      sym_block_comment,
  [653491] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21421), 1,
      anon_sym_RPAREN,
    STATE(16437), 2,
      sym_comment,
      sym_block_comment,
  [653505] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21423), 1,
      sym__outdent,
    STATE(16438), 2,
      sym_comment,
      sym_block_comment,
  [653519] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21425), 1,
      anon_sym_EQ_GT_GT,
    STATE(16439), 2,
      sym_comment,
      sym_block_comment,
  [653533] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21427), 1,
      anon_sym_EQ_GT_GT,
    STATE(16440), 2,
      sym_comment,
      sym_block_comment,
  [653547] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21429), 1,
      anon_sym_EQ_GT_GT,
    STATE(16441), 2,
      sym_comment,
      sym_block_comment,
  [653561] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21431), 1,
      anon_sym_EQ_GT_GT,
    STATE(16442), 2,
      sym_comment,
      sym_block_comment,
  [653575] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21433), 1,
      sym__outdent,
    STATE(16443), 2,
      sym_comment,
      sym_block_comment,
  [653589] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21417), 1,
      anon_sym_RBRACK,
    STATE(16444), 2,
      sym_comment,
      sym_block_comment,
  [653603] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21435), 1,
      anon_sym_COLON,
    STATE(16445), 2,
      sym_comment,
      sym_block_comment,
  [653617] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11806), 1,
      anon_sym_DOT,
    STATE(16446), 2,
      sym_comment,
      sym_block_comment,
  [653631] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21437), 1,
      anon_sym_RBRACE,
    STATE(16447), 2,
      sym_comment,
      sym_block_comment,
  [653645] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21439), 1,
      sym__outdent,
    STATE(16448), 2,
      sym_comment,
      sym_block_comment,
  [653659] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21441), 1,
      anon_sym_EQ_GT_GT,
    STATE(16449), 2,
      sym_comment,
      sym_block_comment,
  [653673] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21443), 1,
      sym__outdent,
    STATE(16450), 2,
      sym_comment,
      sym_block_comment,
  [653687] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21445), 1,
      sym__outdent,
    STATE(16451), 2,
      sym_comment,
      sym_block_comment,
  [653701] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21447), 1,
      anon_sym_else,
    STATE(16452), 2,
      sym_comment,
      sym_block_comment,
  [653715] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21449), 1,
      anon_sym_RPAREN,
    STATE(16453), 2,
      sym_comment,
      sym_block_comment,
  [653729] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21451), 1,
      anon_sym_RPAREN,
    STATE(16454), 2,
      sym_comment,
      sym_block_comment,
  [653743] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21453), 1,
      sym__outdent,
    STATE(16455), 2,
      sym_comment,
      sym_block_comment,
  [653757] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21455), 1,
      sym__outdent,
    STATE(16456), 2,
      sym_comment,
      sym_block_comment,
  [653771] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21457), 1,
      anon_sym_RPAREN,
    STATE(16457), 2,
      sym_comment,
      sym_block_comment,
  [653785] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21459), 1,
      anon_sym_RBRACE,
    STATE(16458), 2,
      sym_comment,
      sym_block_comment,
  [653799] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21461), 1,
      anon_sym_else,
    STATE(16459), 2,
      sym_comment,
      sym_block_comment,
  [653813] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21463), 1,
      anon_sym_EQ_GT_GT,
    STATE(16460), 2,
      sym_comment,
      sym_block_comment,
  [653827] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21465), 1,
      anon_sym_EQ_GT_GT,
    STATE(16461), 2,
      sym_comment,
      sym_block_comment,
  [653841] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21467), 1,
      anon_sym_EQ_GT_GT,
    STATE(16462), 2,
      sym_comment,
      sym_block_comment,
  [653855] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21469), 1,
      anon_sym_EQ_GT_GT,
    STATE(16463), 2,
      sym_comment,
      sym_block_comment,
  [653869] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21471), 1,
      anon_sym_RPAREN,
    STATE(16464), 2,
      sym_comment,
      sym_block_comment,
  [653883] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21473), 1,
      sym__outdent,
    STATE(16465), 2,
      sym_comment,
      sym_block_comment,
  [653897] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21475), 1,
      anon_sym_COLON,
    STATE(16466), 2,
      sym_comment,
      sym_block_comment,
  [653911] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11692), 1,
      anon_sym_DOT,
    STATE(16467), 2,
      sym_comment,
      sym_block_comment,
  [653925] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21477), 1,
      anon_sym_RBRACE,
    STATE(16468), 2,
      sym_comment,
      sym_block_comment,
  [653939] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21479), 1,
      anon_sym_RPAREN,
    STATE(16469), 2,
      sym_comment,
      sym_block_comment,
  [653953] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21481), 1,
      anon_sym_RPAREN,
    STATE(16470), 2,
      sym_comment,
      sym_block_comment,
  [653967] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21483), 1,
      anon_sym_RPAREN,
    STATE(16471), 2,
      sym_comment,
      sym_block_comment,
  [653981] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21485), 1,
      anon_sym_RBRACK,
    STATE(16472), 2,
      sym_comment,
      sym_block_comment,
  [653995] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21487), 1,
      sym__outdent,
    STATE(16473), 2,
      sym_comment,
      sym_block_comment,
  [654009] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21489), 1,
      anon_sym_else,
    STATE(16474), 2,
      sym_comment,
      sym_block_comment,
  [654023] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21491), 1,
      sym__outdent,
    STATE(16475), 2,
      sym_comment,
      sym_block_comment,
  [654037] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21477), 1,
      anon_sym_RBRACK,
    STATE(16476), 2,
      sym_comment,
      sym_block_comment,
  [654051] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21493), 1,
      anon_sym_COLON,
    STATE(16477), 2,
      sym_comment,
      sym_block_comment,
  [654065] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21495), 1,
      sym__outdent,
    STATE(16478), 2,
      sym_comment,
      sym_block_comment,
  [654079] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21437), 1,
      anon_sym_RPAREN,
    STATE(16479), 2,
      sym_comment,
      sym_block_comment,
  [654093] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21497), 1,
      sym__outdent,
    STATE(16480), 2,
      sym_comment,
      sym_block_comment,
  [654107] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21499), 1,
      anon_sym_EQ_GT_GT,
    STATE(16481), 2,
      sym_comment,
      sym_block_comment,
  [654121] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21501), 1,
      anon_sym_EQ_GT_GT,
    STATE(16482), 2,
      sym_comment,
      sym_block_comment,
  [654135] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21503), 1,
      anon_sym_EQ_GT_GT,
    STATE(16483), 2,
      sym_comment,
      sym_block_comment,
  [654149] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21505), 1,
      anon_sym_EQ_GT_GT,
    STATE(16484), 2,
      sym_comment,
      sym_block_comment,
  [654163] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21507), 1,
      sym__outdent,
    STATE(16485), 2,
      sym_comment,
      sym_block_comment,
  [654177] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10558), 1,
      anon_sym_DOT,
    STATE(16486), 2,
      sym_comment,
      sym_block_comment,
  [654191] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21509), 1,
      anon_sym_COLON,
    STATE(16487), 2,
      sym_comment,
      sym_block_comment,
  [654205] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11059), 1,
      anon_sym_DOT,
    STATE(16488), 2,
      sym_comment,
      sym_block_comment,
  [654219] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21511), 1,
      anon_sym_RPAREN,
    STATE(16489), 2,
      sym_comment,
      sym_block_comment,
  [654233] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21513), 1,
      anon_sym_else,
    STATE(16490), 2,
      sym_comment,
      sym_block_comment,
  [654247] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21515), 1,
      anon_sym_RBRACE,
    STATE(16491), 2,
      sym_comment,
      sym_block_comment,
  [654261] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21517), 1,
      anon_sym_RBRACE,
    STATE(16492), 2,
      sym_comment,
      sym_block_comment,
  [654275] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21519), 1,
      anon_sym_RPAREN,
    STATE(16493), 2,
      sym_comment,
      sym_block_comment,
  [654289] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21521), 1,
      sym__outdent,
    STATE(16494), 2,
      sym_comment,
      sym_block_comment,
  [654303] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21523), 1,
      anon_sym_else,
    STATE(16495), 2,
      sym_comment,
      sym_block_comment,
  [654317] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21525), 1,
      anon_sym_RBRACE,
    STATE(16496), 2,
      sym_comment,
      sym_block_comment,
  [654331] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21527), 1,
      anon_sym_RPAREN,
    STATE(16497), 2,
      sym_comment,
      sym_block_comment,
  [654345] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21529), 1,
      sym__outdent,
    STATE(16498), 2,
      sym_comment,
      sym_block_comment,
  [654359] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21531), 1,
      anon_sym_EQ_GT_GT,
    STATE(16499), 2,
      sym_comment,
      sym_block_comment,
  [654373] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21533), 1,
      anon_sym_RPAREN,
    STATE(16500), 2,
      sym_comment,
      sym_block_comment,
  [654387] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21535), 1,
      anon_sym_EQ_GT_GT,
    STATE(16501), 2,
      sym_comment,
      sym_block_comment,
  [654401] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21537), 1,
      anon_sym_EQ_GT_GT,
    STATE(16502), 2,
      sym_comment,
      sym_block_comment,
  [654415] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21539), 1,
      anon_sym_EQ_GT_GT,
    STATE(16503), 2,
      sym_comment,
      sym_block_comment,
  [654429] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21541), 1,
      anon_sym_EQ_GT_GT,
    STATE(16504), 2,
      sym_comment,
      sym_block_comment,
  [654443] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21543), 1,
      anon_sym_EQ_GT_GT,
    STATE(16505), 2,
      sym_comment,
      sym_block_comment,
  [654457] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21545), 1,
      anon_sym_RBRACE,
    STATE(16506), 2,
      sym_comment,
      sym_block_comment,
  [654471] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21547), 1,
      anon_sym_else,
    STATE(16507), 2,
      sym_comment,
      sym_block_comment,
  [654485] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21549), 1,
      anon_sym_COLON,
    STATE(16508), 2,
      sym_comment,
      sym_block_comment,
  [654499] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9807), 1,
      anon_sym_DOT,
    STATE(16509), 2,
      sym_comment,
      sym_block_comment,
  [654513] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21551), 1,
      anon_sym_RBRACE,
    STATE(16510), 2,
      sym_comment,
      sym_block_comment,
  [654527] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21553), 1,
      anon_sym_RBRACE,
    STATE(16511), 2,
      sym_comment,
      sym_block_comment,
  [654541] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21555), 1,
      anon_sym_RBRACE,
    STATE(16512), 2,
      sym_comment,
      sym_block_comment,
  [654555] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21557), 1,
      sym__outdent,
    STATE(16513), 2,
      sym_comment,
      sym_block_comment,
  [654569] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21559), 1,
      anon_sym_RPAREN,
    STATE(16514), 2,
      sym_comment,
      sym_block_comment,
  [654583] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21561), 1,
      anon_sym_else,
    STATE(16515), 2,
      sym_comment,
      sym_block_comment,
  [654597] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21563), 1,
      sym__outdent,
    STATE(16516), 2,
      sym_comment,
      sym_block_comment,
  [654611] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21565), 1,
      sym__outdent,
    STATE(16517), 2,
      sym_comment,
      sym_block_comment,
  [654625] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21567), 1,
      anon_sym_RPAREN,
    STATE(16518), 2,
      sym_comment,
      sym_block_comment,
  [654639] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21569), 1,
      anon_sym_EQ_GT_GT,
    STATE(16519), 2,
      sym_comment,
      sym_block_comment,
  [654653] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21571), 1,
      sym__outdent,
    STATE(16520), 2,
      sym_comment,
      sym_block_comment,
  [654667] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21573), 1,
      anon_sym_else,
    STATE(16521), 2,
      sym_comment,
      sym_block_comment,
  [654681] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21575), 1,
      anon_sym_RPAREN,
    STATE(16522), 2,
      sym_comment,
      sym_block_comment,
  [654695] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21577), 1,
      anon_sym_EQ_GT_GT,
    STATE(16523), 2,
      sym_comment,
      sym_block_comment,
  [654709] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21579), 1,
      anon_sym_EQ_GT_GT,
    STATE(16524), 2,
      sym_comment,
      sym_block_comment,
  [654723] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21581), 1,
      anon_sym_EQ_GT_GT,
    STATE(16525), 2,
      sym_comment,
      sym_block_comment,
  [654737] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21583), 1,
      anon_sym_EQ_GT_GT,
    STATE(16526), 2,
      sym_comment,
      sym_block_comment,
  [654751] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21585), 1,
      anon_sym_EQ_GT_GT,
    STATE(16527), 2,
      sym_comment,
      sym_block_comment,
  [654765] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21587), 1,
      sym__outdent,
    STATE(16528), 2,
      sym_comment,
      sym_block_comment,
  [654779] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21589), 1,
      anon_sym_COLON,
    STATE(16529), 2,
      sym_comment,
      sym_block_comment,
  [654793] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11088), 1,
      anon_sym_DOT,
    STATE(16530), 2,
      sym_comment,
      sym_block_comment,
  [654807] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21591), 1,
      anon_sym_do,
    STATE(16531), 2,
      sym_comment,
      sym_block_comment,
  [654821] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21593), 1,
      anon_sym_else,
    STATE(16532), 2,
      sym_comment,
      sym_block_comment,
  [654835] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21595), 1,
      anon_sym_RPAREN,
    STATE(16533), 2,
      sym_comment,
      sym_block_comment,
  [654849] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21597), 1,
      anon_sym_RPAREN,
    STATE(16534), 2,
      sym_comment,
      sym_block_comment,
  [654863] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21599), 1,
      anon_sym_RBRACE,
    STATE(16535), 2,
      sym_comment,
      sym_block_comment,
  [654877] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21601), 1,
      anon_sym_RPAREN,
    STATE(16536), 2,
      sym_comment,
      sym_block_comment,
  [654891] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21195), 1,
      anon_sym_RBRACK,
    STATE(16537), 2,
      sym_comment,
      sym_block_comment,
  [654905] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21603), 1,
      sym__outdent,
    STATE(16538), 2,
      sym_comment,
      sym_block_comment,
  [654919] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21605), 1,
      sym__outdent,
    STATE(16539), 2,
      sym_comment,
      sym_block_comment,
  [654933] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21607), 1,
      anon_sym_RBRACE,
    STATE(16540), 2,
      sym_comment,
      sym_block_comment,
  [654947] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21609), 1,
      anon_sym_RBRACE,
    STATE(16541), 2,
      sym_comment,
      sym_block_comment,
  [654961] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21555), 1,
      anon_sym_RBRACK,
    STATE(16542), 2,
      sym_comment,
      sym_block_comment,
  [654975] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21611), 1,
      anon_sym_EQ_GT_GT,
    STATE(16543), 2,
      sym_comment,
      sym_block_comment,
  [654989] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21613), 1,
      anon_sym_EQ_GT_GT,
    STATE(16544), 2,
      sym_comment,
      sym_block_comment,
  [655003] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21615), 1,
      anon_sym_EQ_GT_GT,
    STATE(16545), 2,
      sym_comment,
      sym_block_comment,
  [655017] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21617), 1,
      anon_sym_EQ_GT_GT,
    STATE(16546), 2,
      sym_comment,
      sym_block_comment,
  [655031] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21545), 1,
      anon_sym_RBRACK,
    STATE(16547), 2,
      sym_comment,
      sym_block_comment,
  [655045] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21619), 1,
      anon_sym_RPAREN,
    STATE(16548), 2,
      sym_comment,
      sym_block_comment,
  [655059] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21621), 1,
      anon_sym_COLON,
    STATE(16549), 2,
      sym_comment,
      sym_block_comment,
  [655073] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10929), 1,
      anon_sym_DOT,
    STATE(16550), 2,
      sym_comment,
      sym_block_comment,
  [655087] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21623), 1,
      anon_sym_do,
    STATE(16551), 2,
      sym_comment,
      sym_block_comment,
  [655101] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21625), 1,
      anon_sym_type,
    STATE(16552), 2,
      sym_comment,
      sym_block_comment,
  [655115] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21627), 1,
      anon_sym_RBRACE,
    STATE(16553), 2,
      sym_comment,
      sym_block_comment,
  [655129] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21629), 1,
      sym__outdent,
    STATE(16554), 2,
      sym_comment,
      sym_block_comment,
  [655143] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21631), 1,
      anon_sym_EQ_GT,
    STATE(16555), 2,
      sym_comment,
      sym_block_comment,
  [655157] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21633), 1,
      anon_sym_LPAREN,
    STATE(16556), 2,
      sym_comment,
      sym_block_comment,
  [655171] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15405), 1,
      anon_sym_type,
    STATE(16557), 2,
      sym_comment,
      sym_block_comment,
  [655185] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21635), 1,
      anon_sym_else,
    STATE(16558), 2,
      sym_comment,
      sym_block_comment,
  [655199] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21637), 1,
      anon_sym_RBRACE,
    STATE(16559), 2,
      sym_comment,
      sym_block_comment,
  [655213] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21637), 1,
      anon_sym_RPAREN,
    STATE(16560), 2,
      sym_comment,
      sym_block_comment,
  [655227] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21639), 1,
      sym__outdent,
    STATE(16561), 2,
      sym_comment,
      sym_block_comment,
  [655241] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21641), 1,
      anon_sym_RPAREN,
    STATE(16562), 2,
      sym_comment,
      sym_block_comment,
  [655255] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21643), 1,
      anon_sym_EQ_GT_GT,
    STATE(16563), 2,
      sym_comment,
      sym_block_comment,
  [655269] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21645), 1,
      anon_sym_EQ_GT_GT,
    STATE(16564), 2,
      sym_comment,
      sym_block_comment,
  [655283] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21647), 1,
      anon_sym_EQ_GT_GT,
    STATE(16565), 2,
      sym_comment,
      sym_block_comment,
  [655297] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21649), 1,
      anon_sym_EQ_GT_GT,
    STATE(16566), 2,
      sym_comment,
      sym_block_comment,
  [655311] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21651), 1,
      sym__outdent,
    STATE(16567), 2,
      sym_comment,
      sym_block_comment,
  [655325] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21653), 1,
      anon_sym_RBRACE,
    STATE(16568), 2,
      sym_comment,
      sym_block_comment,
  [655339] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21655), 1,
      anon_sym_COLON,
    STATE(16569), 2,
      sym_comment,
      sym_block_comment,
  [655353] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11480), 1,
      anon_sym_DOT,
    STATE(16570), 2,
      sym_comment,
      sym_block_comment,
  [655367] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17649), 1,
      anon_sym_DOT,
    STATE(16571), 2,
      sym_comment,
      sym_block_comment,
  [655381] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21657), 1,
      anon_sym_else,
    STATE(16572), 2,
      sym_comment,
      sym_block_comment,
  [655395] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21659), 1,
      anon_sym_EQ_GT_GT,
    STATE(16573), 2,
      sym_comment,
      sym_block_comment,
  [655409] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21661), 1,
      anon_sym_RPAREN,
    STATE(16574), 2,
      sym_comment,
      sym_block_comment,
  [655423] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21663), 1,
      anon_sym_else,
    STATE(16575), 2,
      sym_comment,
      sym_block_comment,
  [655437] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21665), 1,
      sym__outdent,
    STATE(16576), 2,
      sym_comment,
      sym_block_comment,
  [655451] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21667), 1,
      anon_sym_RPAREN,
    STATE(16577), 2,
      sym_comment,
      sym_block_comment,
  [655465] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21669), 1,
      anon_sym_RPAREN,
    STATE(16578), 2,
      sym_comment,
      sym_block_comment,
  [655479] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21671), 1,
      sym__outdent,
    STATE(16579), 2,
      sym_comment,
      sym_block_comment,
  [655493] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21673), 1,
      anon_sym_EQ_GT_GT,
    STATE(16580), 2,
      sym_comment,
      sym_block_comment,
  [655507] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21675), 1,
      anon_sym_RBRACE,
    STATE(16581), 2,
      sym_comment,
      sym_block_comment,
  [655521] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21677), 1,
      anon_sym_RBRACE,
    STATE(16582), 2,
      sym_comment,
      sym_block_comment,
  [655535] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21679), 1,
      anon_sym_EQ_GT_GT,
    STATE(16583), 2,
      sym_comment,
      sym_block_comment,
  [655549] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21681), 1,
      anon_sym_EQ_GT_GT,
    STATE(16584), 2,
      sym_comment,
      sym_block_comment,
  [655563] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21683), 1,
      anon_sym_EQ_GT_GT,
    STATE(16585), 2,
      sym_comment,
      sym_block_comment,
  [655577] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21685), 1,
      anon_sym_EQ_GT_GT,
    STATE(16586), 2,
      sym_comment,
      sym_block_comment,
  [655591] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21687), 1,
      anon_sym_else,
    STATE(16587), 2,
      sym_comment,
      sym_block_comment,
  [655605] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21689), 1,
      anon_sym_EQ_GT_GT,
    STATE(16588), 2,
      sym_comment,
      sym_block_comment,
  [655619] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21691), 1,
      anon_sym_COLON,
    STATE(16589), 2,
      sym_comment,
      sym_block_comment,
  [655633] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11348), 1,
      anon_sym_DOT,
    STATE(16590), 2,
      sym_comment,
      sym_block_comment,
  [655647] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21693), 1,
      anon_sym_EQ_GT_GT,
    STATE(16591), 2,
      sym_comment,
      sym_block_comment,
  [655661] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21695), 1,
      anon_sym_RPAREN,
    STATE(16592), 2,
      sym_comment,
      sym_block_comment,
  [655675] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21697), 1,
      sym__outdent,
    STATE(16593), 2,
      sym_comment,
      sym_block_comment,
  [655689] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21699), 1,
      anon_sym_else,
    STATE(16594), 2,
      sym_comment,
      sym_block_comment,
  [655703] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21701), 1,
      anon_sym_RBRACE,
    STATE(16595), 2,
      sym_comment,
      sym_block_comment,
  [655717] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21703), 1,
      anon_sym_RPAREN,
    STATE(16596), 2,
      sym_comment,
      sym_block_comment,
  [655731] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21705), 1,
      anon_sym_RPAREN,
    STATE(16597), 2,
      sym_comment,
      sym_block_comment,
  [655745] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21707), 1,
      sym__outdent,
    STATE(16598), 2,
      sym_comment,
      sym_block_comment,
  [655759] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21709), 1,
      anon_sym_RBRACE,
    STATE(16599), 2,
      sym_comment,
      sym_block_comment,
  [655773] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21711), 1,
      anon_sym_RPAREN,
    STATE(16600), 2,
      sym_comment,
      sym_block_comment,
  [655787] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21713), 1,
      sym__outdent,
    STATE(16601), 2,
      sym_comment,
      sym_block_comment,
  [655801] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21715), 1,
      anon_sym_RBRACE,
    STATE(16602), 2,
      sym_comment,
      sym_block_comment,
  [655815] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21717), 1,
      anon_sym_EQ_GT_GT,
    STATE(16603), 2,
      sym_comment,
      sym_block_comment,
  [655829] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21719), 1,
      anon_sym_EQ_GT_GT,
    STATE(16604), 2,
      sym_comment,
      sym_block_comment,
  [655843] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21721), 1,
      anon_sym_EQ_GT_GT,
    STATE(16605), 2,
      sym_comment,
      sym_block_comment,
  [655857] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21723), 1,
      anon_sym_EQ_GT_GT,
    STATE(16606), 2,
      sym_comment,
      sym_block_comment,
  [655871] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21725), 1,
      anon_sym_else,
    STATE(16607), 2,
      sym_comment,
      sym_block_comment,
  [655885] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21727), 1,
      anon_sym_RPAREN,
    STATE(16608), 2,
      sym_comment,
      sym_block_comment,
  [655899] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21729), 1,
      anon_sym_COLON,
    STATE(16609), 2,
      sym_comment,
      sym_block_comment,
  [655913] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11869), 1,
      anon_sym_DOT,
    STATE(16610), 2,
      sym_comment,
      sym_block_comment,
  [655927] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21731), 1,
      anon_sym_RBRACE,
    STATE(16611), 2,
      sym_comment,
      sym_block_comment,
  [655941] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21733), 1,
      anon_sym_RPAREN,
    STATE(16612), 2,
      sym_comment,
      sym_block_comment,
  [655955] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21735), 1,
      sym__outdent,
    STATE(16613), 2,
      sym_comment,
      sym_block_comment,
  [655969] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21737), 1,
      sym__outdent,
    STATE(16614), 2,
      sym_comment,
      sym_block_comment,
  [655983] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21739), 1,
      anon_sym_do,
    STATE(16615), 2,
      sym_comment,
      sym_block_comment,
  [655997] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21741), 1,
      anon_sym_RPAREN,
    STATE(16616), 2,
      sym_comment,
      sym_block_comment,
  [656011] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21743), 1,
      sym__outdent,
    STATE(16617), 2,
      sym_comment,
      sym_block_comment,
  [656025] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21745), 1,
      anon_sym_RBRACE,
    STATE(16618), 2,
      sym_comment,
      sym_block_comment,
  [656039] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21747), 1,
      anon_sym_RPAREN,
    STATE(16619), 2,
      sym_comment,
      sym_block_comment,
  [656053] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21749), 1,
      anon_sym_RPAREN,
    STATE(16620), 2,
      sym_comment,
      sym_block_comment,
  [656067] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21751), 1,
      ts_builtin_sym_end,
    STATE(16621), 2,
      sym_comment,
      sym_block_comment,
  [656081] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21753), 1,
      sym__outdent,
    STATE(16622), 2,
      sym_comment,
      sym_block_comment,
  [656095] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21755), 1,
      anon_sym_EQ_GT_GT,
    STATE(16623), 2,
      sym_comment,
      sym_block_comment,
  [656109] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21757), 1,
      anon_sym_EQ_GT_GT,
    STATE(16624), 2,
      sym_comment,
      sym_block_comment,
  [656123] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21759), 1,
      anon_sym_EQ_GT_GT,
    STATE(16625), 2,
      sym_comment,
      sym_block_comment,
  [656137] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21761), 1,
      anon_sym_EQ_GT_GT,
    STATE(16626), 2,
      sym_comment,
      sym_block_comment,
  [656151] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21763), 1,
      sym__outdent,
    STATE(16627), 2,
      sym_comment,
      sym_block_comment,
  [656165] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21765), 1,
      anon_sym_RBRACE,
    STATE(16628), 2,
      sym_comment,
      sym_block_comment,
  [656179] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21767), 1,
      anon_sym_COLON,
    STATE(16629), 2,
      sym_comment,
      sym_block_comment,
  [656193] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11510), 1,
      anon_sym_DOT,
    STATE(16630), 2,
      sym_comment,
      sym_block_comment,
  [656207] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21769), 1,
      sym__outdent,
    STATE(16631), 2,
      sym_comment,
      sym_block_comment,
  [656221] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21771), 1,
      anon_sym_RBRACE,
    STATE(16632), 2,
      sym_comment,
      sym_block_comment,
  [656235] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21773), 1,
      anon_sym_RPAREN,
    STATE(16633), 2,
      sym_comment,
      sym_block_comment,
  [656249] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21775), 1,
      sym__outdent,
    STATE(16634), 2,
      sym_comment,
      sym_block_comment,
  [656263] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21777), 1,
      anon_sym_else,
    STATE(16635), 2,
      sym_comment,
      sym_block_comment,
  [656277] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21779), 1,
      anon_sym_do,
    STATE(16636), 2,
      sym_comment,
      sym_block_comment,
  [656291] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21781), 1,
      anon_sym_RBRACE,
    STATE(16637), 2,
      sym_comment,
      sym_block_comment,
  [656305] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21783), 1,
      anon_sym_COLON,
    STATE(16638), 2,
      sym_comment,
      sym_block_comment,
  [656319] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21785), 1,
      anon_sym_RPAREN,
    STATE(16639), 2,
      sym_comment,
      sym_block_comment,
  [656333] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9805), 1,
      anon_sym_DOT,
    STATE(16640), 2,
      sym_comment,
      sym_block_comment,
  [656347] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21787), 1,
      sym__outdent,
    STATE(16641), 2,
      sym_comment,
      sym_block_comment,
  [656361] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21789), 1,
      sym__outdent,
    STATE(16642), 2,
      sym_comment,
      sym_block_comment,
  [656375] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21791), 1,
      anon_sym_EQ_GT_GT,
    STATE(16643), 2,
      sym_comment,
      sym_block_comment,
  [656389] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21793), 1,
      anon_sym_EQ_GT_GT,
    STATE(16644), 2,
      sym_comment,
      sym_block_comment,
  [656403] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21795), 1,
      anon_sym_EQ_GT_GT,
    STATE(16645), 2,
      sym_comment,
      sym_block_comment,
  [656417] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21797), 1,
      anon_sym_EQ_GT_GT,
    STATE(16646), 2,
      sym_comment,
      sym_block_comment,
  [656431] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21799), 1,
      anon_sym_RBRACE,
    STATE(16647), 2,
      sym_comment,
      sym_block_comment,
  [656445] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21801), 1,
      anon_sym_do,
    STATE(16648), 2,
      sym_comment,
      sym_block_comment,
  [656459] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21803), 1,
      anon_sym_COLON,
    STATE(16649), 2,
      sym_comment,
      sym_block_comment,
  [656473] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12814), 1,
      anon_sym_DOT,
    STATE(16650), 2,
      sym_comment,
      sym_block_comment,
  [656487] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21805), 1,
      anon_sym_RBRACE,
    STATE(16651), 2,
      sym_comment,
      sym_block_comment,
  [656501] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21807), 1,
      anon_sym_RBRACE,
    STATE(16652), 2,
      sym_comment,
      sym_block_comment,
  [656515] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21809), 1,
      anon_sym_RPAREN,
    STATE(16653), 2,
      sym_comment,
      sym_block_comment,
  [656529] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21811), 1,
      sym__outdent,
    STATE(16654), 2,
      sym_comment,
      sym_block_comment,
  [656543] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21813), 1,
      anon_sym_else,
    STATE(16655), 2,
      sym_comment,
      sym_block_comment,
  [656557] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21815), 1,
      anon_sym_RPAREN,
    STATE(16656), 2,
      sym_comment,
      sym_block_comment,
  [656571] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21817), 1,
      anon_sym_else,
    STATE(16657), 2,
      sym_comment,
      sym_block_comment,
  [656585] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12593), 1,
      anon_sym_DOT,
    STATE(16658), 2,
      sym_comment,
      sym_block_comment,
  [656599] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21819), 1,
      sym__outdent,
    STATE(16659), 2,
      sym_comment,
      sym_block_comment,
  [656613] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21821), 1,
      anon_sym_RBRACE,
    STATE(16660), 2,
      sym_comment,
      sym_block_comment,
  [656627] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21821), 1,
      anon_sym_RPAREN,
    STATE(16661), 2,
      sym_comment,
      sym_block_comment,
  [656641] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21823), 1,
      anon_sym_RBRACE,
    STATE(16662), 2,
      sym_comment,
      sym_block_comment,
  [656655] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21825), 1,
      anon_sym_EQ_GT_GT,
    STATE(16663), 2,
      sym_comment,
      sym_block_comment,
  [656669] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21827), 1,
      anon_sym_EQ_GT_GT,
    STATE(16664), 2,
      sym_comment,
      sym_block_comment,
  [656683] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21829), 1,
      anon_sym_EQ_GT_GT,
    STATE(16665), 2,
      sym_comment,
      sym_block_comment,
  [656697] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21831), 1,
      anon_sym_EQ_GT_GT,
    STATE(16666), 2,
      sym_comment,
      sym_block_comment,
  [656711] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21833), 1,
      sym__outdent,
    STATE(16667), 2,
      sym_comment,
      sym_block_comment,
  [656725] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21835), 1,
      sym__outdent,
    STATE(16668), 2,
      sym_comment,
      sym_block_comment,
  [656739] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21837), 1,
      anon_sym_COLON,
    STATE(16669), 2,
      sym_comment,
      sym_block_comment,
  [656753] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12426), 1,
      anon_sym_DOT,
    STATE(16670), 2,
      sym_comment,
      sym_block_comment,
  [656767] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21839), 1,
      anon_sym_RBRACE,
    STATE(16671), 2,
      sym_comment,
      sym_block_comment,
  [656781] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21841), 1,
      anon_sym_RPAREN,
    STATE(16672), 2,
      sym_comment,
      sym_block_comment,
  [656795] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21843), 1,
      sym__outdent,
    STATE(16673), 2,
      sym_comment,
      sym_block_comment,
  [656809] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21845), 1,
      anon_sym_RPAREN,
    STATE(16674), 2,
      sym_comment,
      sym_block_comment,
  [656823] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21847), 1,
      anon_sym_do,
    STATE(16675), 2,
      sym_comment,
      sym_block_comment,
  [656837] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21849), 1,
      sym__outdent,
    STATE(16676), 2,
      sym_comment,
      sym_block_comment,
  [656851] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21851), 1,
      anon_sym_RPAREN,
    STATE(16677), 2,
      sym_comment,
      sym_block_comment,
  [656865] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21853), 1,
      sym__outdent,
    STATE(16678), 2,
      sym_comment,
      sym_block_comment,
  [656879] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21855), 1,
      anon_sym_RPAREN,
    STATE(16679), 2,
      sym_comment,
      sym_block_comment,
  [656893] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21857), 1,
      sym__outdent,
    STATE(16680), 2,
      sym_comment,
      sym_block_comment,
  [656907] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21859), 1,
      anon_sym_RBRACE,
    STATE(16681), 2,
      sym_comment,
      sym_block_comment,
  [656921] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21861), 1,
      anon_sym_EQ_GT_GT,
    STATE(16682), 2,
      sym_comment,
      sym_block_comment,
  [656935] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21863), 1,
      anon_sym_EQ_GT_GT,
    STATE(16683), 2,
      sym_comment,
      sym_block_comment,
  [656949] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21865), 1,
      anon_sym_EQ_GT_GT,
    STATE(16684), 2,
      sym_comment,
      sym_block_comment,
  [656963] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21867), 1,
      anon_sym_EQ_GT_GT,
    STATE(16685), 2,
      sym_comment,
      sym_block_comment,
  [656977] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21869), 1,
      anon_sym_else,
    STATE(16686), 2,
      sym_comment,
      sym_block_comment,
  [656991] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21871), 1,
      anon_sym_do,
    STATE(16687), 2,
      sym_comment,
      sym_block_comment,
  [657005] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21873), 1,
      anon_sym_COLON,
    STATE(16688), 2,
      sym_comment,
      sym_block_comment,
  [657019] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9347), 1,
      anon_sym_DOT,
    STATE(16689), 2,
      sym_comment,
      sym_block_comment,
  [657033] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21875), 1,
      anon_sym_RPAREN,
    STATE(16690), 2,
      sym_comment,
      sym_block_comment,
  [657047] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21859), 1,
      anon_sym_RPAREN,
    STATE(16691), 2,
      sym_comment,
      sym_block_comment,
  [657061] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21877), 1,
      anon_sym_else,
    STATE(16692), 2,
      sym_comment,
      sym_block_comment,
  [657075] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10524), 1,
      anon_sym_with,
    STATE(16693), 2,
      sym_comment,
      sym_block_comment,
  [657089] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21879), 1,
      anon_sym_else,
    STATE(16694), 2,
      sym_comment,
      sym_block_comment,
  [657103] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21881), 1,
      anon_sym_RBRACE,
    STATE(16695), 2,
      sym_comment,
      sym_block_comment,
  [657117] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21883), 1,
      anon_sym_RPAREN,
    STATE(16696), 2,
      sym_comment,
      sym_block_comment,
  [657131] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21885), 1,
      sym__outdent,
    STATE(16697), 2,
      sym_comment,
      sym_block_comment,
  [657145] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21887), 1,
      sym__outdent,
    STATE(16698), 2,
      sym_comment,
      sym_block_comment,
  [657159] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21889), 1,
      anon_sym_RBRACE,
    STATE(16699), 2,
      sym_comment,
      sym_block_comment,
  [657173] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21891), 1,
      sym__outdent,
    STATE(16700), 2,
      sym_comment,
      sym_block_comment,
  [657187] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21893), 1,
      anon_sym_EQ_GT_GT,
    STATE(16701), 2,
      sym_comment,
      sym_block_comment,
  [657201] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21895), 1,
      anon_sym_EQ_GT_GT,
    STATE(16702), 2,
      sym_comment,
      sym_block_comment,
  [657215] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21897), 1,
      anon_sym_EQ_GT_GT,
    STATE(16703), 2,
      sym_comment,
      sym_block_comment,
  [657229] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21899), 1,
      anon_sym_EQ_GT_GT,
    STATE(16704), 2,
      sym_comment,
      sym_block_comment,
  [657243] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21901), 1,
      anon_sym_else,
    STATE(16705), 2,
      sym_comment,
      sym_block_comment,
  [657257] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21889), 1,
      anon_sym_RBRACK,
    STATE(16706), 2,
      sym_comment,
      sym_block_comment,
  [657271] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21903), 1,
      anon_sym_COLON,
    STATE(16707), 2,
      sym_comment,
      sym_block_comment,
  [657285] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9179), 1,
      anon_sym_DOT,
    STATE(16708), 2,
      sym_comment,
      sym_block_comment,
  [657299] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21905), 1,
      anon_sym_RBRACE,
    STATE(16709), 2,
      sym_comment,
      sym_block_comment,
  [657313] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21907), 1,
      anon_sym_RBRACE,
    STATE(16710), 2,
      sym_comment,
      sym_block_comment,
  [657327] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21909), 1,
      anon_sym_RPAREN,
    STATE(16711), 2,
      sym_comment,
      sym_block_comment,
  [657341] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21911), 1,
      anon_sym_RPAREN,
    STATE(16712), 2,
      sym_comment,
      sym_block_comment,
  [657355] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21913), 1,
      anon_sym_RPAREN,
    STATE(16713), 2,
      sym_comment,
      sym_block_comment,
  [657369] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21915), 1,
      anon_sym_do,
    STATE(16714), 2,
      sym_comment,
      sym_block_comment,
  [657383] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21917), 1,
      sym__outdent,
    STATE(16715), 2,
      sym_comment,
      sym_block_comment,
  [657397] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21919), 1,
      anon_sym_else,
    STATE(16716), 2,
      sym_comment,
      sym_block_comment,
  [657411] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21921), 1,
      sym__outdent,
    STATE(16717), 2,
      sym_comment,
      sym_block_comment,
  [657425] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21923), 1,
      anon_sym_RPAREN,
    STATE(16718), 2,
      sym_comment,
      sym_block_comment,
  [657439] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21925), 1,
      anon_sym_EQ_GT,
    STATE(16719), 2,
      sym_comment,
      sym_block_comment,
  [657453] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21927), 1,
      anon_sym_EQ_GT_GT,
    STATE(16720), 2,
      sym_comment,
      sym_block_comment,
  [657467] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21929), 1,
      anon_sym_EQ_GT_GT,
    STATE(16721), 2,
      sym_comment,
      sym_block_comment,
  [657481] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21931), 1,
      anon_sym_EQ_GT_GT,
    STATE(16722), 2,
      sym_comment,
      sym_block_comment,
  [657495] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21933), 1,
      anon_sym_EQ_GT_GT,
    STATE(16723), 2,
      sym_comment,
      sym_block_comment,
  [657509] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21905), 1,
      anon_sym_RBRACK,
    STATE(16724), 2,
      sym_comment,
      sym_block_comment,
  [657523] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21935), 1,
      anon_sym_do,
    STATE(16725), 2,
      sym_comment,
      sym_block_comment,
  [657537] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21937), 1,
      anon_sym_COLON,
    STATE(16726), 2,
      sym_comment,
      sym_block_comment,
  [657551] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10171), 1,
      anon_sym_DOT,
    STATE(16727), 2,
      sym_comment,
      sym_block_comment,
  [657565] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21745), 1,
      anon_sym_RBRACK,
    STATE(16728), 2,
      sym_comment,
      sym_block_comment,
  [657579] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21939), 1,
      anon_sym_RBRACE,
    STATE(16729), 2,
      sym_comment,
      sym_block_comment,
  [657593] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21941), 1,
      anon_sym_EQ_GT_GT,
    STATE(16730), 2,
      sym_comment,
      sym_block_comment,
  [657607] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21943), 1,
      anon_sym_EQ_GT_GT,
    STATE(16731), 2,
      sym_comment,
      sym_block_comment,
  [657621] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21945), 1,
      anon_sym_RBRACE,
    STATE(16732), 2,
      sym_comment,
      sym_block_comment,
  [657635] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21947), 1,
      anon_sym_RBRACE,
    STATE(16733), 2,
      sym_comment,
      sym_block_comment,
  [657649] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21949), 1,
      anon_sym_EQ_GT_GT,
    STATE(16734), 2,
      sym_comment,
      sym_block_comment,
  [657663] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21951), 1,
      anon_sym_EQ_GT_GT,
    STATE(16735), 2,
      sym_comment,
      sym_block_comment,
  [657677] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21953), 1,
      anon_sym_EQ_GT_GT,
    STATE(16736), 2,
      sym_comment,
      sym_block_comment,
  [657691] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21955), 1,
      anon_sym_RBRACE,
    STATE(16737), 2,
      sym_comment,
      sym_block_comment,
  [657705] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21957), 1,
      anon_sym_do,
    STATE(16738), 2,
      sym_comment,
      sym_block_comment,
  [657719] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21959), 1,
      anon_sym_EQ_GT_GT,
    STATE(16739), 2,
      sym_comment,
      sym_block_comment,
  [657733] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21961), 1,
      anon_sym_EQ_GT_GT,
    STATE(16740), 2,
      sym_comment,
      sym_block_comment,
  [657747] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21963), 1,
      anon_sym_EQ_GT_GT,
    STATE(16741), 2,
      sym_comment,
      sym_block_comment,
  [657761] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21965), 1,
      anon_sym_EQ_GT_GT,
    STATE(16742), 2,
      sym_comment,
      sym_block_comment,
  [657775] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21967), 1,
      sym__outdent,
    STATE(16743), 2,
      sym_comment,
      sym_block_comment,
  [657789] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21969), 1,
      anon_sym_RPAREN,
    STATE(16744), 2,
      sym_comment,
      sym_block_comment,
  [657803] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21971), 1,
      anon_sym_COLON,
    STATE(16745), 2,
      sym_comment,
      sym_block_comment,
  [657817] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9353), 1,
      anon_sym_DOT,
    STATE(16746), 2,
      sym_comment,
      sym_block_comment,
  [657831] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21973), 1,
      sym__outdent,
    STATE(16747), 2,
      sym_comment,
      sym_block_comment,
  [657845] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21975), 1,
      anon_sym_RBRACE,
    STATE(16748), 2,
      sym_comment,
      sym_block_comment,
  [657859] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21975), 1,
      anon_sym_RPAREN,
    STATE(16749), 2,
      sym_comment,
      sym_block_comment,
  [657873] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21977), 1,
      sym__outdent,
    STATE(16750), 2,
      sym_comment,
      sym_block_comment,
  [657887] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21979), 1,
      anon_sym_RBRACE,
    STATE(16751), 2,
      sym_comment,
      sym_block_comment,
  [657901] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21981), 1,
      anon_sym_RBRACE,
    STATE(16752), 2,
      sym_comment,
      sym_block_comment,
  [657915] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21983), 1,
      anon_sym_else,
    STATE(16753), 2,
      sym_comment,
      sym_block_comment,
  [657929] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21985), 1,
      anon_sym_RPAREN,
    STATE(16754), 2,
      sym_comment,
      sym_block_comment,
  [657943] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21987), 1,
      sym__outdent,
    STATE(16755), 2,
      sym_comment,
      sym_block_comment,
  [657957] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21989), 1,
      anon_sym_RBRACE,
    STATE(16756), 2,
      sym_comment,
      sym_block_comment,
  [657971] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21991), 1,
      anon_sym_RPAREN,
    STATE(16757), 2,
      sym_comment,
      sym_block_comment,
  [657985] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21993), 1,
      anon_sym_EQ_GT_GT,
    STATE(16758), 2,
      sym_comment,
      sym_block_comment,
  [657999] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21995), 1,
      anon_sym_EQ_GT_GT,
    STATE(16759), 2,
      sym_comment,
      sym_block_comment,
  [658013] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21997), 1,
      anon_sym_EQ_GT_GT,
    STATE(16760), 2,
      sym_comment,
      sym_block_comment,
  [658027] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21999), 1,
      anon_sym_EQ_GT_GT,
    STATE(16761), 2,
      sym_comment,
      sym_block_comment,
  [658041] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22001), 1,
      sym__outdent,
    STATE(16762), 2,
      sym_comment,
      sym_block_comment,
  [658055] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22003), 1,
      anon_sym_RPAREN,
    STATE(16763), 2,
      sym_comment,
      sym_block_comment,
  [658069] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9904), 1,
      anon_sym_DOT,
    STATE(16764), 2,
      sym_comment,
      sym_block_comment,
  [658083] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15906), 1,
      anon_sym_COLON,
    STATE(16765), 2,
      sym_comment,
      sym_block_comment,
  [658097] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22005), 1,
      anon_sym_RPAREN,
    STATE(16766), 2,
      sym_comment,
      sym_block_comment,
  [658111] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22007), 1,
      anon_sym_RBRACE,
    STATE(16767), 2,
      sym_comment,
      sym_block_comment,
  [658125] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11784), 1,
      anon_sym_DOT,
    STATE(16768), 2,
      sym_comment,
      sym_block_comment,
  [658139] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22009), 1,
      sym__outdent,
    STATE(16769), 2,
      sym_comment,
      sym_block_comment,
  [658153] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22011), 1,
      anon_sym_RPAREN,
    STATE(16770), 2,
      sym_comment,
      sym_block_comment,
  [658167] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22013), 1,
      anon_sym_else,
    STATE(16771), 2,
      sym_comment,
      sym_block_comment,
  [658181] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21675), 1,
      anon_sym_RBRACK,
    STATE(16772), 2,
      sym_comment,
      sym_block_comment,
  [658195] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22015), 1,
      anon_sym_RBRACE,
    STATE(16773), 2,
      sym_comment,
      sym_block_comment,
  [658209] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22017), 1,
      anon_sym_RPAREN,
    STATE(16774), 2,
      sym_comment,
      sym_block_comment,
  [658223] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22019), 1,
      anon_sym_RPAREN,
    STATE(16775), 2,
      sym_comment,
      sym_block_comment,
  [658237] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22021), 1,
      anon_sym_EQ_GT_GT,
    STATE(16776), 2,
      sym_comment,
      sym_block_comment,
  [658251] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22023), 1,
      anon_sym_EQ_GT_GT,
    STATE(16777), 2,
      sym_comment,
      sym_block_comment,
  [658265] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22025), 1,
      anon_sym_EQ_GT_GT,
    STATE(16778), 2,
      sym_comment,
      sym_block_comment,
  [658279] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22027), 1,
      anon_sym_EQ_GT_GT,
    STATE(16779), 2,
      sym_comment,
      sym_block_comment,
  [658293] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22029), 1,
      sym__outdent,
    STATE(16780), 2,
      sym_comment,
      sym_block_comment,
  [658307] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22031), 1,
      sym__outdent,
    STATE(16781), 2,
      sym_comment,
      sym_block_comment,
  [658321] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9685), 1,
      anon_sym_DOT,
    STATE(16782), 2,
      sym_comment,
      sym_block_comment,
  [658335] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22033), 1,
      anon_sym_RPAREN,
    STATE(16783), 2,
      sym_comment,
      sym_block_comment,
  [658349] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22035), 1,
      anon_sym_RBRACE,
    STATE(16784), 2,
      sym_comment,
      sym_block_comment,
  [658363] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22037), 1,
      anon_sym_RBRACE,
    STATE(16785), 2,
      sym_comment,
      sym_block_comment,
  [658377] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22039), 1,
      sym__outdent,
    STATE(16786), 2,
      sym_comment,
      sym_block_comment,
  [658391] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22041), 1,
      sym__outdent,
    STATE(16787), 2,
      sym_comment,
      sym_block_comment,
  [658405] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22043), 1,
      anon_sym_else,
    STATE(16788), 2,
      sym_comment,
      sym_block_comment,
  [658419] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22045), 1,
      anon_sym_RPAREN,
    STATE(16789), 2,
      sym_comment,
      sym_block_comment,
  [658433] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22047), 1,
      sym__outdent,
    STATE(16790), 2,
      sym_comment,
      sym_block_comment,
  [658447] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22037), 1,
      anon_sym_RPAREN,
    STATE(16791), 2,
      sym_comment,
      sym_block_comment,
  [658461] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10029), 1,
      anon_sym_EQ_GT,
    STATE(16792), 2,
      sym_comment,
      sym_block_comment,
  [658475] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22049), 1,
      anon_sym_RPAREN,
    STATE(16793), 2,
      sym_comment,
      sym_block_comment,
  [658489] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22051), 1,
      anon_sym_EQ_GT_GT,
    STATE(16794), 2,
      sym_comment,
      sym_block_comment,
  [658503] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22053), 1,
      anon_sym_EQ_GT_GT,
    STATE(16795), 2,
      sym_comment,
      sym_block_comment,
  [658517] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22055), 1,
      anon_sym_EQ_GT_GT,
    STATE(16796), 2,
      sym_comment,
      sym_block_comment,
  [658531] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22057), 1,
      anon_sym_EQ_GT_GT,
    STATE(16797), 2,
      sym_comment,
      sym_block_comment,
  [658545] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22059), 1,
      sym__outdent,
    STATE(16798), 2,
      sym_comment,
      sym_block_comment,
  [658559] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10033), 1,
      anon_sym_EQ_GT,
    STATE(16799), 2,
      sym_comment,
      sym_block_comment,
  [658573] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11416), 1,
      anon_sym_DOT,
    STATE(16800), 2,
      sym_comment,
      sym_block_comment,
  [658587] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22061), 1,
      sym__outdent,
    STATE(16801), 2,
      sym_comment,
      sym_block_comment,
  [658601] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22063), 1,
      anon_sym_RBRACE,
    STATE(16802), 2,
      sym_comment,
      sym_block_comment,
  [658615] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22065), 1,
      sym__outdent,
    STATE(16803), 2,
      sym_comment,
      sym_block_comment,
  [658629] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22067), 1,
      anon_sym_EQ_GT,
    STATE(16804), 2,
      sym_comment,
      sym_block_comment,
  [658643] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22063), 1,
      anon_sym_RBRACK,
    STATE(16805), 2,
      sym_comment,
      sym_block_comment,
  [658657] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22069), 1,
      anon_sym_else,
    STATE(16806), 2,
      sym_comment,
      sym_block_comment,
  [658671] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22071), 1,
      anon_sym_COLON,
    STATE(16807), 2,
      sym_comment,
      sym_block_comment,
  [658685] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22073), 1,
      anon_sym_RBRACE,
    STATE(16808), 2,
      sym_comment,
      sym_block_comment,
  [658699] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22075), 1,
      anon_sym_RBRACE,
    STATE(16809), 2,
      sym_comment,
      sym_block_comment,
  [658713] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10039), 1,
      anon_sym_EQ_GT,
    STATE(16810), 2,
      sym_comment,
      sym_block_comment,
  [658727] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22077), 1,
      anon_sym_RBRACE,
    STATE(16811), 2,
      sym_comment,
      sym_block_comment,
  [658741] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22079), 1,
      anon_sym_EQ_GT_GT,
    STATE(16812), 2,
      sym_comment,
      sym_block_comment,
  [658755] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22081), 1,
      anon_sym_EQ_GT_GT,
    STATE(16813), 2,
      sym_comment,
      sym_block_comment,
  [658769] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22083), 1,
      anon_sym_EQ_GT_GT,
    STATE(16814), 2,
      sym_comment,
      sym_block_comment,
  [658783] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22085), 1,
      anon_sym_EQ_GT_GT,
    STATE(16815), 2,
      sym_comment,
      sym_block_comment,
  [658797] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22087), 1,
      anon_sym_do,
    STATE(16816), 2,
      sym_comment,
      sym_block_comment,
  [658811] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22073), 1,
      anon_sym_RBRACK,
    STATE(16817), 2,
      sym_comment,
      sym_block_comment,
  [658825] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10391), 1,
      anon_sym_DOT,
    STATE(16818), 2,
      sym_comment,
      sym_block_comment,
  [658839] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22089), 1,
      anon_sym_do,
    STATE(16819), 2,
      sym_comment,
      sym_block_comment,
  [658853] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22091), 1,
      anon_sym_do,
    STATE(16820), 2,
      sym_comment,
      sym_block_comment,
  [658867] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22093), 1,
      anon_sym_RPAREN,
    STATE(16821), 2,
      sym_comment,
      sym_block_comment,
  [658881] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10046), 1,
      anon_sym_EQ_GT,
    STATE(16822), 2,
      sym_comment,
      sym_block_comment,
  [658895] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22095), 1,
      sym__outdent,
    STATE(16823), 2,
      sym_comment,
      sym_block_comment,
  [658909] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22097), 1,
      anon_sym_EQ_GT,
    STATE(16824), 2,
      sym_comment,
      sym_block_comment,
  [658923] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22099), 1,
      anon_sym_LPAREN,
    STATE(16825), 2,
      sym_comment,
      sym_block_comment,
  [658937] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22101), 1,
      anon_sym_RBRACE,
    STATE(16826), 2,
      sym_comment,
      sym_block_comment,
  [658951] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22103), 1,
      anon_sym_RBRACE,
    STATE(16827), 2,
      sym_comment,
      sym_block_comment,
  [658965] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21309), 1,
      anon_sym_RBRACE,
    STATE(16828), 2,
      sym_comment,
      sym_block_comment,
  [658979] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10050), 1,
      anon_sym_EQ_GT,
    STATE(16829), 2,
      sym_comment,
      sym_block_comment,
  [658993] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22105), 1,
      anon_sym_EQ_GT_GT,
    STATE(16830), 2,
      sym_comment,
      sym_block_comment,
  [659007] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22107), 1,
      anon_sym_EQ_GT_GT,
    STATE(16831), 2,
      sym_comment,
      sym_block_comment,
  [659021] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22109), 1,
      anon_sym_EQ_GT_GT,
    STATE(16832), 2,
      sym_comment,
      sym_block_comment,
  [659035] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22111), 1,
      anon_sym_EQ_GT_GT,
    STATE(16833), 2,
      sym_comment,
      sym_block_comment,
  [659049] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22113), 1,
      anon_sym_EQ_GT_GT,
    STATE(16834), 2,
      sym_comment,
      sym_block_comment,
  [659063] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14219), 1,
      anon_sym_DOT,
    STATE(16835), 2,
      sym_comment,
      sym_block_comment,
  [659077] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8216), 1,
      anon_sym_type,
    STATE(16836), 2,
      sym_comment,
      sym_block_comment,
  [659091] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22115), 1,
      anon_sym_RPAREN,
    STATE(16837), 2,
      sym_comment,
      sym_block_comment,
  [659105] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22117), 1,
      sym__outdent,
    STATE(16838), 2,
      sym_comment,
      sym_block_comment,
  [659119] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22119), 1,
      anon_sym_EQ_GT_GT,
    STATE(16839), 2,
      sym_comment,
      sym_block_comment,
  [659133] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22121), 1,
      anon_sym_EQ_GT_GT,
    STATE(16840), 2,
      sym_comment,
      sym_block_comment,
  [659147] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22123), 1,
      anon_sym_RBRACE,
    STATE(16841), 2,
      sym_comment,
      sym_block_comment,
  [659161] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22125), 1,
      anon_sym_RPAREN,
    STATE(16842), 2,
      sym_comment,
      sym_block_comment,
  [659175] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22127), 1,
      sym__outdent,
    STATE(16843), 2,
      sym_comment,
      sym_block_comment,
  [659189] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22123), 1,
      anon_sym_RPAREN,
    STATE(16844), 2,
      sym_comment,
      sym_block_comment,
  [659203] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22129), 1,
      anon_sym_EQ_GT_GT,
    STATE(16845), 2,
      sym_comment,
      sym_block_comment,
  [659217] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22131), 1,
      anon_sym_RPAREN,
    STATE(16846), 2,
      sym_comment,
      sym_block_comment,
  [659231] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22133), 1,
      anon_sym_EQ_GT_GT,
    STATE(16847), 2,
      sym_comment,
      sym_block_comment,
  [659245] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22135), 1,
      anon_sym_EQ_GT_GT,
    STATE(16848), 2,
      sym_comment,
      sym_block_comment,
  [659259] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22137), 1,
      anon_sym_EQ_GT_GT,
    STATE(16849), 2,
      sym_comment,
      sym_block_comment,
  [659273] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22139), 1,
      anon_sym_EQ_GT_GT,
    STATE(16850), 2,
      sym_comment,
      sym_block_comment,
  [659287] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22141), 1,
      anon_sym_RPAREN,
    STATE(16851), 2,
      sym_comment,
      sym_block_comment,
  [659301] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22143), 1,
      sym__outdent,
    STATE(16852), 2,
      sym_comment,
      sym_block_comment,
  [659315] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13269), 1,
      anon_sym_DOT,
    STATE(16853), 2,
      sym_comment,
      sym_block_comment,
  [659329] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22145), 1,
      anon_sym_RPAREN,
    STATE(16854), 2,
      sym_comment,
      sym_block_comment,
  [659343] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22147), 1,
      sym__outdent,
    STATE(16855), 2,
      sym_comment,
      sym_block_comment,
  [659357] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22149), 1,
      anon_sym_else,
    STATE(16856), 2,
      sym_comment,
      sym_block_comment,
  [659371] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22151), 1,
      sym__outdent,
    STATE(16857), 2,
      sym_comment,
      sym_block_comment,
  [659385] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22153), 1,
      sym__outdent,
    STATE(16858), 2,
      sym_comment,
      sym_block_comment,
  [659399] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8114), 1,
      anon_sym_with,
    STATE(16859), 2,
      sym_comment,
      sym_block_comment,
  [659413] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22155), 1,
      anon_sym_else,
    STATE(16860), 2,
      sym_comment,
      sym_block_comment,
  [659427] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22157), 1,
      anon_sym_COLON,
    STATE(16861), 2,
      sym_comment,
      sym_block_comment,
  [659441] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22159), 1,
      anon_sym_else,
    STATE(16862), 2,
      sym_comment,
      sym_block_comment,
  [659455] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10732), 1,
      anon_sym_DOT,
    STATE(16863), 2,
      sym_comment,
      sym_block_comment,
  [659469] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22161), 1,
      anon_sym_RBRACE,
    STATE(16864), 2,
      sym_comment,
      sym_block_comment,
  [659483] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22163), 1,
      anon_sym_EQ_GT_GT,
    STATE(16865), 2,
      sym_comment,
      sym_block_comment,
  [659497] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22165), 1,
      anon_sym_EQ_GT_GT,
    STATE(16866), 2,
      sym_comment,
      sym_block_comment,
  [659511] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22167), 1,
      anon_sym_EQ_GT_GT,
    STATE(16867), 2,
      sym_comment,
      sym_block_comment,
  [659525] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22169), 1,
      anon_sym_EQ_GT_GT,
    STATE(16868), 2,
      sym_comment,
      sym_block_comment,
  [659539] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22171), 1,
      anon_sym_RPAREN,
    STATE(16869), 2,
      sym_comment,
      sym_block_comment,
  [659553] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22173), 1,
      anon_sym_RBRACE,
    STATE(16870), 2,
      sym_comment,
      sym_block_comment,
  [659567] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13279), 1,
      anon_sym_DOT,
    STATE(16871), 2,
      sym_comment,
      sym_block_comment,
  [659581] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22175), 1,
      anon_sym_RPAREN,
    STATE(16872), 2,
      sym_comment,
      sym_block_comment,
  [659595] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22177), 1,
      anon_sym_RBRACE,
    STATE(16873), 2,
      sym_comment,
      sym_block_comment,
  [659609] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22179), 1,
      sym__outdent,
    STATE(16874), 2,
      sym_comment,
      sym_block_comment,
  [659623] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22181), 1,
      sym__outdent,
    STATE(16875), 2,
      sym_comment,
      sym_block_comment,
  [659637] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22183), 1,
      sym__outdent,
    STATE(16876), 2,
      sym_comment,
      sym_block_comment,
  [659651] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22185), 1,
      anon_sym_RPAREN,
    STATE(16877), 2,
      sym_comment,
      sym_block_comment,
  [659665] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22187), 1,
      sym__outdent,
    STATE(16878), 2,
      sym_comment,
      sym_block_comment,
  [659679] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8410), 1,
      anon_sym_EQ_GT,
    STATE(16879), 2,
      sym_comment,
      sym_block_comment,
  [659693] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22189), 1,
      sym__outdent,
    STATE(16880), 2,
      sym_comment,
      sym_block_comment,
  [659707] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22191), 1,
      anon_sym_do,
    STATE(16881), 2,
      sym_comment,
      sym_block_comment,
  [659721] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22193), 1,
      anon_sym_do,
    STATE(16882), 2,
      sym_comment,
      sym_block_comment,
  [659735] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22195), 1,
      anon_sym_EQ_GT_GT,
    STATE(16883), 2,
      sym_comment,
      sym_block_comment,
  [659749] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22197), 1,
      anon_sym_EQ_GT_GT,
    STATE(16884), 2,
      sym_comment,
      sym_block_comment,
  [659763] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22199), 1,
      anon_sym_EQ_GT_GT,
    STATE(16885), 2,
      sym_comment,
      sym_block_comment,
  [659777] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22201), 1,
      anon_sym_EQ_GT_GT,
    STATE(16886), 2,
      sym_comment,
      sym_block_comment,
  [659791] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22203), 1,
      anon_sym_else,
    STATE(16887), 2,
      sym_comment,
      sym_block_comment,
  [659805] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22205), 1,
      anon_sym_RBRACE,
    STATE(16888), 2,
      sym_comment,
      sym_block_comment,
  [659819] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11344), 1,
      anon_sym_DOT,
    STATE(16889), 2,
      sym_comment,
      sym_block_comment,
  [659833] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22207), 1,
      anon_sym_RPAREN,
    STATE(16890), 2,
      sym_comment,
      sym_block_comment,
  [659847] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22205), 1,
      anon_sym_RPAREN,
    STATE(16891), 2,
      sym_comment,
      sym_block_comment,
  [659861] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22209), 1,
      anon_sym_RBRACE,
    STATE(16892), 2,
      sym_comment,
      sym_block_comment,
  [659875] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22211), 1,
      anon_sym_RPAREN,
    STATE(16893), 2,
      sym_comment,
      sym_block_comment,
  [659889] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22213), 1,
      sym__outdent,
    STATE(16894), 2,
      sym_comment,
      sym_block_comment,
  [659903] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22215), 1,
      anon_sym_RBRACE,
    STATE(16895), 2,
      sym_comment,
      sym_block_comment,
  [659917] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22217), 1,
      anon_sym_RBRACE,
    STATE(16896), 2,
      sym_comment,
      sym_block_comment,
  [659931] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22161), 1,
      anon_sym_RPAREN,
    STATE(16897), 2,
      sym_comment,
      sym_block_comment,
  [659945] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22219), 1,
      anon_sym_else,
    STATE(16898), 2,
      sym_comment,
      sym_block_comment,
  [659959] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22221), 1,
      sym__outdent,
    STATE(16899), 2,
      sym_comment,
      sym_block_comment,
  [659973] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21715), 1,
      anon_sym_RBRACK,
    STATE(16900), 2,
      sym_comment,
      sym_block_comment,
  [659987] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22223), 1,
      anon_sym_EQ_GT_GT,
    STATE(16901), 2,
      sym_comment,
      sym_block_comment,
  [660001] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22225), 1,
      anon_sym_EQ_GT_GT,
    STATE(16902), 2,
      sym_comment,
      sym_block_comment,
  [660015] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22227), 1,
      anon_sym_EQ_GT_GT,
    STATE(16903), 2,
      sym_comment,
      sym_block_comment,
  [660029] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22229), 1,
      anon_sym_EQ_GT_GT,
    STATE(16904), 2,
      sym_comment,
      sym_block_comment,
  [660043] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9698), 1,
      anon_sym_DOT,
    STATE(16905), 2,
      sym_comment,
      sym_block_comment,
  [660057] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22231), 1,
      anon_sym_RPAREN,
    STATE(16906), 2,
      sym_comment,
      sym_block_comment,
  [660071] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22233), 1,
      sym__outdent,
    STATE(16907), 2,
      sym_comment,
      sym_block_comment,
  [660085] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22235), 1,
      anon_sym_RPAREN,
    STATE(16908), 2,
      sym_comment,
      sym_block_comment,
  [660099] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22237), 1,
      anon_sym_RPAREN,
    STATE(16909), 2,
      sym_comment,
      sym_block_comment,
  [660113] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22239), 1,
      anon_sym_RPAREN,
    STATE(16910), 2,
      sym_comment,
      sym_block_comment,
  [660127] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22241), 1,
      anon_sym_else,
    STATE(16911), 2,
      sym_comment,
      sym_block_comment,
  [660141] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22243), 1,
      sym__outdent,
    STATE(16912), 2,
      sym_comment,
      sym_block_comment,
  [660155] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22245), 1,
      anon_sym_EQ_GT_GT,
    STATE(16913), 2,
      sym_comment,
      sym_block_comment,
  [660169] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22247), 1,
      anon_sym_EQ_GT_GT,
    STATE(16914), 2,
      sym_comment,
      sym_block_comment,
  [660183] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22249), 1,
      anon_sym_EQ_GT_GT,
    STATE(16915), 2,
      sym_comment,
      sym_block_comment,
  [660197] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22251), 1,
      anon_sym_EQ_GT_GT,
    STATE(16916), 2,
      sym_comment,
      sym_block_comment,
  [660211] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11115), 1,
      anon_sym_DOT,
    STATE(16917), 2,
      sym_comment,
      sym_block_comment,
  [660225] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22253), 1,
      anon_sym_RBRACE,
    STATE(16918), 2,
      sym_comment,
      sym_block_comment,
  [660239] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22255), 1,
      anon_sym_RBRACE,
    STATE(16919), 2,
      sym_comment,
      sym_block_comment,
  [660253] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22257), 1,
      anon_sym_do,
    STATE(16920), 2,
      sym_comment,
      sym_block_comment,
  [660267] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22259), 1,
      anon_sym_EQ_GT,
    STATE(16921), 2,
      sym_comment,
      sym_block_comment,
  [660281] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22261), 1,
      sym__outdent,
    STATE(16922), 2,
      sym_comment,
      sym_block_comment,
  [660295] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22263), 1,
      anon_sym_do,
    STATE(16923), 2,
      sym_comment,
      sym_block_comment,
  [660309] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22265), 1,
      anon_sym_RPAREN,
    STATE(16924), 2,
      sym_comment,
      sym_block_comment,
  [660323] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22267), 1,
      anon_sym_EQ_GT_GT,
    STATE(16925), 2,
      sym_comment,
      sym_block_comment,
  [660337] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22269), 1,
      anon_sym_EQ_GT_GT,
    STATE(16926), 2,
      sym_comment,
      sym_block_comment,
  [660351] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22271), 1,
      anon_sym_EQ_GT_GT,
    STATE(16927), 2,
      sym_comment,
      sym_block_comment,
  [660365] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22273), 1,
      anon_sym_EQ_GT_GT,
    STATE(16928), 2,
      sym_comment,
      sym_block_comment,
  [660379] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10763), 1,
      anon_sym_DOT,
    STATE(16929), 2,
      sym_comment,
      sym_block_comment,
  [660393] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22275), 1,
      anon_sym_EQ_GT_GT,
    STATE(16930), 2,
      sym_comment,
      sym_block_comment,
  [660407] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22277), 1,
      anon_sym_RPAREN,
    STATE(16931), 2,
      sym_comment,
      sym_block_comment,
  [660421] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22279), 1,
      sym__outdent,
    STATE(16932), 2,
      sym_comment,
      sym_block_comment,
  [660435] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22281), 1,
      anon_sym_EQ_GT_GT,
    STATE(16933), 2,
      sym_comment,
      sym_block_comment,
  [660449] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22283), 1,
      anon_sym_EQ_GT_GT,
    STATE(16934), 2,
      sym_comment,
      sym_block_comment,
  [660463] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22285), 1,
      sym__outdent,
    STATE(16935), 2,
      sym_comment,
      sym_block_comment,
  [660477] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22287), 1,
      anon_sym_RBRACE,
    STATE(16936), 2,
      sym_comment,
      sym_block_comment,
  [660491] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22289), 1,
      anon_sym_EQ_GT_GT,
    STATE(16937), 2,
      sym_comment,
      sym_block_comment,
  [660505] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22291), 1,
      anon_sym_EQ_GT_GT,
    STATE(16938), 2,
      sym_comment,
      sym_block_comment,
  [660519] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22293), 1,
      anon_sym_EQ_GT_GT,
    STATE(16939), 2,
      sym_comment,
      sym_block_comment,
  [660533] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22295), 1,
      anon_sym_EQ_GT_GT,
    STATE(16940), 2,
      sym_comment,
      sym_block_comment,
  [660547] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10462), 1,
      anon_sym_DOT,
    STATE(16941), 2,
      sym_comment,
      sym_block_comment,
  [660561] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22297), 1,
      anon_sym_EQ_GT_GT,
    STATE(16942), 2,
      sym_comment,
      sym_block_comment,
  [660575] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22299), 1,
      anon_sym_RBRACE,
    STATE(16943), 2,
      sym_comment,
      sym_block_comment,
  [660589] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22301), 1,
      anon_sym_RPAREN,
    STATE(16944), 2,
      sym_comment,
      sym_block_comment,
  [660603] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22303), 1,
      sym__outdent,
    STATE(16945), 2,
      sym_comment,
      sym_block_comment,
  [660617] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22305), 1,
      anon_sym_RPAREN,
    STATE(16946), 2,
      sym_comment,
      sym_block_comment,
  [660631] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22307), 1,
      sym__outdent,
    STATE(16947), 2,
      sym_comment,
      sym_block_comment,
  [660645] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22309), 1,
      anon_sym_EQ_GT_GT,
    STATE(16948), 2,
      sym_comment,
      sym_block_comment,
  [660659] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22311), 1,
      anon_sym_EQ_GT_GT,
    STATE(16949), 2,
      sym_comment,
      sym_block_comment,
  [660673] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22313), 1,
      anon_sym_EQ_GT_GT,
    STATE(16950), 2,
      sym_comment,
      sym_block_comment,
  [660687] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22315), 1,
      anon_sym_EQ_GT_GT,
    STATE(16951), 2,
      sym_comment,
      sym_block_comment,
  [660701] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15431), 1,
      anon_sym_DOT,
    STATE(16952), 2,
      sym_comment,
      sym_block_comment,
  [660715] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22317), 1,
      sym__outdent,
    STATE(16953), 2,
      sym_comment,
      sym_block_comment,
  [660729] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22319), 1,
      anon_sym_COLON,
    STATE(16954), 2,
      sym_comment,
      sym_block_comment,
  [660743] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22321), 1,
      anon_sym_RPAREN,
    STATE(16955), 2,
      sym_comment,
      sym_block_comment,
  [660757] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22323), 1,
      sym__outdent,
    STATE(16956), 2,
      sym_comment,
      sym_block_comment,
  [660771] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22325), 1,
      anon_sym_RBRACE,
    STATE(16957), 2,
      sym_comment,
      sym_block_comment,
  [660785] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22327), 1,
      anon_sym_using,
    STATE(16958), 2,
      sym_comment,
      sym_block_comment,
  [660799] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22329), 1,
      anon_sym_EQ_GT_GT,
    STATE(16959), 2,
      sym_comment,
      sym_block_comment,
  [660813] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22331), 1,
      anon_sym_EQ_GT_GT,
    STATE(16960), 2,
      sym_comment,
      sym_block_comment,
  [660827] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22333), 1,
      anon_sym_EQ_GT_GT,
    STATE(16961), 2,
      sym_comment,
      sym_block_comment,
  [660841] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22335), 1,
      anon_sym_EQ_GT_GT,
    STATE(16962), 2,
      sym_comment,
      sym_block_comment,
  [660855] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10648), 1,
      anon_sym_DOT,
    STATE(16963), 2,
      sym_comment,
      sym_block_comment,
  [660869] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22325), 1,
      anon_sym_RPAREN,
    STATE(16964), 2,
      sym_comment,
      sym_block_comment,
  [660883] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22337), 1,
      sym__outdent,
    STATE(16965), 2,
      sym_comment,
      sym_block_comment,
  [660897] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11685), 1,
      anon_sym_DOT,
    STATE(16966), 2,
      sym_comment,
      sym_block_comment,
  [660911] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22339), 1,
      sym__outdent,
    STATE(16967), 2,
      sym_comment,
      sym_block_comment,
  [660925] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22341), 1,
      anon_sym_RPAREN,
    STATE(16968), 2,
      sym_comment,
      sym_block_comment,
  [660939] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22343), 1,
      anon_sym_RBRACE,
    STATE(16969), 2,
      sym_comment,
      sym_block_comment,
  [660953] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22345), 1,
      anon_sym_EQ_GT_GT,
    STATE(16970), 2,
      sym_comment,
      sym_block_comment,
  [660967] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22347), 1,
      anon_sym_EQ_GT_GT,
    STATE(16971), 2,
      sym_comment,
      sym_block_comment,
  [660981] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22349), 1,
      anon_sym_EQ_GT_GT,
    STATE(16972), 2,
      sym_comment,
      sym_block_comment,
  [660995] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22351), 1,
      anon_sym_EQ_GT_GT,
    STATE(16973), 2,
      sym_comment,
      sym_block_comment,
  [661009] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11652), 1,
      anon_sym_DOT,
    STATE(16974), 2,
      sym_comment,
      sym_block_comment,
  [661023] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22343), 1,
      anon_sym_RPAREN,
    STATE(16975), 2,
      sym_comment,
      sym_block_comment,
  [661037] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22353), 1,
      sym__outdent,
    STATE(16976), 2,
      sym_comment,
      sym_block_comment,
  [661051] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22355), 1,
      anon_sym_RBRACE,
    STATE(16977), 2,
      sym_comment,
      sym_block_comment,
  [661065] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22357), 1,
      anon_sym_RPAREN,
    STATE(16978), 2,
      sym_comment,
      sym_block_comment,
  [661079] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22359), 1,
      anon_sym_else,
    STATE(16979), 2,
      sym_comment,
      sym_block_comment,
  [661093] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22361), 1,
      sym__outdent,
    STATE(16980), 2,
      sym_comment,
      sym_block_comment,
  [661107] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22363), 1,
      anon_sym_EQ_GT_GT,
    STATE(16981), 2,
      sym_comment,
      sym_block_comment,
  [661121] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22365), 1,
      anon_sym_EQ_GT_GT,
    STATE(16982), 2,
      sym_comment,
      sym_block_comment,
  [661135] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22367), 1,
      anon_sym_EQ_GT_GT,
    STATE(16983), 2,
      sym_comment,
      sym_block_comment,
  [661149] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22369), 1,
      anon_sym_EQ_GT_GT,
    STATE(16984), 2,
      sym_comment,
      sym_block_comment,
  [661163] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12962), 1,
      anon_sym_DOT,
    STATE(16985), 2,
      sym_comment,
      sym_block_comment,
  [661177] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11924), 1,
      anon_sym_EQ_GT,
    STATE(16986), 2,
      sym_comment,
      sym_block_comment,
  [661191] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22355), 1,
      anon_sym_RPAREN,
    STATE(16987), 2,
      sym_comment,
      sym_block_comment,
  [661205] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22371), 1,
      anon_sym_RBRACE,
    STATE(16988), 2,
      sym_comment,
      sym_block_comment,
  [661219] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22373), 1,
      anon_sym_else,
    STATE(16989), 2,
      sym_comment,
      sym_block_comment,
  [661233] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22253), 1,
      anon_sym_RBRACK,
    STATE(16990), 2,
      sym_comment,
      sym_block_comment,
  [661247] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22375), 1,
      anon_sym_COLON,
    STATE(16991), 2,
      sym_comment,
      sym_block_comment,
  [661261] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22377), 1,
      anon_sym_EQ_GT_GT,
    STATE(16992), 2,
      sym_comment,
      sym_block_comment,
  [661275] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22379), 1,
      anon_sym_EQ_GT_GT,
    STATE(16993), 2,
      sym_comment,
      sym_block_comment,
  [661289] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22381), 1,
      anon_sym_EQ_GT_GT,
    STATE(16994), 2,
      sym_comment,
      sym_block_comment,
  [661303] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22383), 1,
      anon_sym_EQ_GT_GT,
    STATE(16995), 2,
      sym_comment,
      sym_block_comment,
  [661317] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11248), 1,
      anon_sym_DOT,
    STATE(16996), 2,
      sym_comment,
      sym_block_comment,
  [661331] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22385), 1,
      anon_sym_RBRACE,
    STATE(16997), 2,
      sym_comment,
      sym_block_comment,
  [661345] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22387), 1,
      anon_sym_RBRACK,
    STATE(16998), 2,
      sym_comment,
      sym_block_comment,
  [661359] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22385), 1,
      anon_sym_RBRACK,
    STATE(16999), 2,
      sym_comment,
      sym_block_comment,
  [661373] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22389), 1,
      anon_sym_else,
    STATE(17000), 2,
      sym_comment,
      sym_block_comment,
  [661387] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22391), 1,
      anon_sym_RBRACE,
    STATE(17001), 2,
      sym_comment,
      sym_block_comment,
  [661401] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22391), 1,
      anon_sym_RBRACK,
    STATE(17002), 2,
      sym_comment,
      sym_block_comment,
  [661415] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22393), 1,
      anon_sym_EQ_GT_GT,
    STATE(17003), 2,
      sym_comment,
      sym_block_comment,
  [661429] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22395), 1,
      anon_sym_EQ_GT_GT,
    STATE(17004), 2,
      sym_comment,
      sym_block_comment,
  [661443] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22397), 1,
      anon_sym_EQ_GT_GT,
    STATE(17005), 2,
      sym_comment,
      sym_block_comment,
  [661457] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22399), 1,
      anon_sym_EQ_GT_GT,
    STATE(17006), 2,
      sym_comment,
      sym_block_comment,
  [661471] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8455), 1,
      anon_sym_DOT,
    STATE(17007), 2,
      sym_comment,
      sym_block_comment,
  [661485] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22401), 1,
      anon_sym_RBRACE,
    STATE(17008), 2,
      sym_comment,
      sym_block_comment,
  [661499] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22401), 1,
      anon_sym_RBRACK,
    STATE(17009), 2,
      sym_comment,
      sym_block_comment,
  [661513] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22403), 1,
      anon_sym_RBRACE,
    STATE(17010), 2,
      sym_comment,
      sym_block_comment,
  [661527] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22405), 1,
      anon_sym_else,
    STATE(17011), 2,
      sym_comment,
      sym_block_comment,
  [661541] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22407), 1,
      sym__outdent,
    STATE(17012), 2,
      sym_comment,
      sym_block_comment,
  [661555] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22409), 1,
      anon_sym_RPAREN,
    STATE(17013), 2,
      sym_comment,
      sym_block_comment,
  [661569] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22411), 1,
      anon_sym_EQ_GT_GT,
    STATE(17014), 2,
      sym_comment,
      sym_block_comment,
  [661583] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22413), 1,
      anon_sym_EQ_GT_GT,
    STATE(17015), 2,
      sym_comment,
      sym_block_comment,
  [661597] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22415), 1,
      anon_sym_EQ_GT_GT,
    STATE(17016), 2,
      sym_comment,
      sym_block_comment,
  [661611] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22417), 1,
      anon_sym_EQ_GT_GT,
    STATE(17017), 2,
      sym_comment,
      sym_block_comment,
  [661625] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9527), 1,
      anon_sym_DOT,
    STATE(17018), 2,
      sym_comment,
      sym_block_comment,
  [661639] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22419), 1,
      anon_sym_RBRACE,
    STATE(17019), 2,
      sym_comment,
      sym_block_comment,
  [661653] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22421), 1,
      sym__outdent,
    STATE(17020), 2,
      sym_comment,
      sym_block_comment,
  [661667] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22423), 1,
      anon_sym_RBRACE,
    STATE(17021), 2,
      sym_comment,
      sym_block_comment,
  [661681] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22425), 1,
      anon_sym_RBRACE,
    STATE(17022), 2,
      sym_comment,
      sym_block_comment,
  [661695] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22075), 1,
      anon_sym_RPAREN,
    STATE(17023), 2,
      sym_comment,
      sym_block_comment,
  [661709] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9177), 1,
      anon_sym_DOT,
    STATE(17024), 2,
      sym_comment,
      sym_block_comment,
  [661723] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22427), 1,
      anon_sym_RBRACE,
    STATE(17025), 2,
      sym_comment,
      sym_block_comment,
  [661737] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22429), 1,
      anon_sym_RPAREN,
    STATE(17026), 2,
      sym_comment,
      sym_block_comment,
  [661751] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22431), 1,
      anon_sym_RBRACE,
    STATE(17027), 2,
      sym_comment,
      sym_block_comment,
  [661765] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22403), 1,
      anon_sym_RBRACK,
    STATE(17028), 2,
      sym_comment,
      sym_block_comment,
  [661779] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22433), 1,
      anon_sym_else,
    STATE(17029), 2,
      sym_comment,
      sym_block_comment,
  [661793] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9212), 1,
      anon_sym_DOT,
    STATE(17030), 2,
      sym_comment,
      sym_block_comment,
  [661807] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22435), 1,
      sym__outdent,
    STATE(17031), 2,
      sym_comment,
      sym_block_comment,
  [661821] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22437), 1,
      anon_sym_RBRACE,
    STATE(17032), 2,
      sym_comment,
      sym_block_comment,
  [661835] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22439), 1,
      anon_sym_RPAREN,
    STATE(17033), 2,
      sym_comment,
      sym_block_comment,
  [661849] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22441), 1,
      anon_sym_RPAREN,
    STATE(17034), 2,
      sym_comment,
      sym_block_comment,
  [661863] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10203), 1,
      anon_sym_DOT,
    STATE(17035), 2,
      sym_comment,
      sym_block_comment,
  [661877] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22443), 1,
      sym__outdent,
    STATE(17036), 2,
      sym_comment,
      sym_block_comment,
  [661891] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22445), 1,
      sym__outdent,
    STATE(17037), 2,
      sym_comment,
      sym_block_comment,
  [661905] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22447), 1,
      anon_sym_EQ_GT,
    STATE(17038), 2,
      sym_comment,
      sym_block_comment,
  [661919] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22449), 1,
      anon_sym_RPAREN,
    STATE(17039), 2,
      sym_comment,
      sym_block_comment,
  [661933] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22451), 1,
      anon_sym_RPAREN,
    STATE(17040), 2,
      sym_comment,
      sym_block_comment,
  [661947] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14862), 1,
      anon_sym_DOT,
    STATE(17041), 2,
      sym_comment,
      sym_block_comment,
  [661961] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21653), 1,
      anon_sym_RBRACK,
    STATE(17042), 2,
      sym_comment,
      sym_block_comment,
  [661975] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22453), 1,
      sym__outdent,
    STATE(17043), 2,
      sym_comment,
      sym_block_comment,
  [661989] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22455), 1,
      anon_sym_EQ_GT,
    STATE(17044), 2,
      sym_comment,
      sym_block_comment,
  [662003] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22457), 1,
      sym__outdent,
    STATE(17045), 2,
      sym_comment,
      sym_block_comment,
  [662017] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22459), 1,
      anon_sym_EQ_GT_GT,
    STATE(17046), 2,
      sym_comment,
      sym_block_comment,
  [662031] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10334), 1,
      anon_sym_DOT,
    STATE(17047), 2,
      sym_comment,
      sym_block_comment,
  [662045] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22461), 1,
      anon_sym_RPAREN,
    STATE(17048), 2,
      sym_comment,
      sym_block_comment,
  [662059] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22463), 1,
      anon_sym_EQ_GT_GT,
    STATE(17049), 2,
      sym_comment,
      sym_block_comment,
  [662073] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22465), 1,
      anon_sym_EQ_GT_GT,
    STATE(17050), 2,
      sym_comment,
      sym_block_comment,
  [662087] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22467), 1,
      anon_sym_EQ_GT_GT,
    STATE(17051), 2,
      sym_comment,
      sym_block_comment,
  [662101] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22469), 1,
      sym__outdent,
    STATE(17052), 2,
      sym_comment,
      sym_block_comment,
  [662115] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10221), 1,
      anon_sym_DOT,
    STATE(17053), 2,
      sym_comment,
      sym_block_comment,
  [662129] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22471), 1,
      sym__outdent,
    STATE(17054), 2,
      sym_comment,
      sym_block_comment,
  [662143] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22425), 1,
      anon_sym_RBRACK,
    STATE(17055), 2,
      sym_comment,
      sym_block_comment,
  [662157] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11873), 1,
      anon_sym_EQ_GT,
    STATE(17056), 2,
      sym_comment,
      sym_block_comment,
  [662171] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22473), 1,
      anon_sym_RPAREN,
    STATE(17057), 2,
      sym_comment,
      sym_block_comment,
  [662185] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22475), 1,
      anon_sym_COLON,
    STATE(17058), 2,
      sym_comment,
      sym_block_comment,
  [662199] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10389), 1,
      anon_sym_DOT,
    STATE(17059), 2,
      sym_comment,
      sym_block_comment,
  [662213] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10823), 1,
      anon_sym_DOT,
    STATE(17060), 2,
      sym_comment,
      sym_block_comment,
  [662227] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22477), 1,
      anon_sym_RBRACE,
    STATE(17061), 2,
      sym_comment,
      sym_block_comment,
  [662241] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22479), 1,
      anon_sym_else,
    STATE(17062), 2,
      sym_comment,
      sym_block_comment,
  [662255] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22481), 1,
      sym__outdent,
    STATE(17063), 2,
      sym_comment,
      sym_block_comment,
  [662269] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22483), 1,
      sym__outdent,
    STATE(17064), 2,
      sym_comment,
      sym_block_comment,
  [662283] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11414), 1,
      anon_sym_DOT,
    STATE(17065), 2,
      sym_comment,
      sym_block_comment,
  [662297] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11881), 1,
      anon_sym_EQ_GT,
    STATE(17066), 2,
      sym_comment,
      sym_block_comment,
  [662311] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22485), 1,
      anon_sym_RPAREN,
    STATE(17067), 2,
      sym_comment,
      sym_block_comment,
  [662325] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22487), 1,
      sym__outdent,
    STATE(17068), 2,
      sym_comment,
      sym_block_comment,
  [662339] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22489), 1,
      anon_sym_RBRACE,
    STATE(17069), 2,
      sym_comment,
      sym_block_comment,
  [662353] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22491), 1,
      sym__outdent,
    STATE(17070), 2,
      sym_comment,
      sym_block_comment,
  [662367] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10292), 1,
      anon_sym_DOT,
    STATE(17071), 2,
      sym_comment,
      sym_block_comment,
  [662381] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22493), 1,
      anon_sym_do,
    STATE(17072), 2,
      sym_comment,
      sym_block_comment,
  [662395] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22495), 1,
      anon_sym_RPAREN,
    STATE(17073), 2,
      sym_comment,
      sym_block_comment,
  [662409] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22497), 1,
      anon_sym_RBRACK,
    STATE(17074), 2,
      sym_comment,
      sym_block_comment,
  [662423] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22499), 1,
      anon_sym_EQ,
    STATE(17075), 2,
      sym_comment,
      sym_block_comment,
  [662437] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21147), 1,
      anon_sym_RBRACE,
    STATE(17076), 2,
      sym_comment,
      sym_block_comment,
  [662451] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14126), 1,
      anon_sym_DOT,
    STATE(17077), 2,
      sym_comment,
      sym_block_comment,
  [662465] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22501), 1,
      anon_sym_EQ,
    STATE(17078), 2,
      sym_comment,
      sym_block_comment,
  [662479] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22503), 1,
      anon_sym_RPAREN,
    STATE(17079), 2,
      sym_comment,
      sym_block_comment,
  [662493] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22505), 1,
      anon_sym_RBRACE,
    STATE(17080), 2,
      sym_comment,
      sym_block_comment,
  [662507] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22507), 1,
      anon_sym_RBRACE,
    STATE(17081), 2,
      sym_comment,
      sym_block_comment,
  [662521] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21771), 1,
      anon_sym_RPAREN,
    STATE(17082), 2,
      sym_comment,
      sym_block_comment,
  [662535] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11669), 1,
      anon_sym_DOT,
    STATE(17083), 2,
      sym_comment,
      sym_block_comment,
  [662549] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22509), 1,
      anon_sym_RPAREN,
    STATE(17084), 2,
      sym_comment,
      sym_block_comment,
  [662563] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22511), 1,
      anon_sym_RPAREN,
    STATE(17085), 2,
      sym_comment,
      sym_block_comment,
  [662577] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22513), 1,
      anon_sym_else,
    STATE(17086), 2,
      sym_comment,
      sym_block_comment,
  [662591] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22515), 1,
      anon_sym_RPAREN,
    STATE(17087), 2,
      sym_comment,
      sym_block_comment,
  [662605] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22517), 1,
      anon_sym_RBRACE,
    STATE(17088), 2,
      sym_comment,
      sym_block_comment,
  [662619] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11117), 1,
      anon_sym_DOT,
    STATE(17089), 2,
      sym_comment,
      sym_block_comment,
  [662633] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22519), 1,
      anon_sym_RPAREN,
    STATE(17090), 2,
      sym_comment,
      sym_block_comment,
  [662647] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22521), 1,
      anon_sym_RPAREN,
    STATE(17091), 2,
      sym_comment,
      sym_block_comment,
  [662661] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22523), 1,
      anon_sym_RBRACE,
    STATE(17092), 2,
      sym_comment,
      sym_block_comment,
  [662675] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22525), 1,
      sym__outdent,
    STATE(17093), 2,
      sym_comment,
      sym_block_comment,
  [662689] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22527), 1,
      sym__outdent,
    STATE(17094), 2,
      sym_comment,
      sym_block_comment,
  [662703] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12675), 1,
      anon_sym_DOT,
    STATE(17095), 2,
      sym_comment,
      sym_block_comment,
  [662717] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22529), 1,
      anon_sym_EQ_GT_GT,
    STATE(17096), 2,
      sym_comment,
      sym_block_comment,
  [662731] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11841), 1,
      anon_sym_EQ_GT,
    STATE(17097), 2,
      sym_comment,
      sym_block_comment,
  [662745] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11877), 1,
      anon_sym_EQ_GT,
    STATE(17098), 2,
      sym_comment,
      sym_block_comment,
  [662759] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22531), 1,
      anon_sym_RPAREN,
    STATE(17099), 2,
      sym_comment,
      sym_block_comment,
  [662773] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11904), 1,
      anon_sym_EQ_GT,
    STATE(17100), 2,
      sym_comment,
      sym_block_comment,
  [662787] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11601), 1,
      anon_sym_DOT,
    STATE(17101), 2,
      sym_comment,
      sym_block_comment,
  [662801] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11914), 1,
      anon_sym_EQ_GT,
    STATE(17102), 2,
      sym_comment,
      sym_block_comment,
  [662815] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22533), 1,
      sym__outdent,
    STATE(17103), 2,
      sym_comment,
      sym_block_comment,
  [662829] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11939), 1,
      anon_sym_EQ_GT,
    STATE(17104), 2,
      sym_comment,
      sym_block_comment,
  [662843] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22535), 1,
      anon_sym_do,
    STATE(17105), 2,
      sym_comment,
      sym_block_comment,
  [662857] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22537), 1,
      anon_sym_RPAREN,
    STATE(17106), 2,
      sym_comment,
      sym_block_comment,
  [662871] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12864), 1,
      anon_sym_DOT,
    STATE(17107), 2,
      sym_comment,
      sym_block_comment,
  [662885] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22539), 1,
      anon_sym_RBRACE,
    STATE(17108), 2,
      sym_comment,
      sym_block_comment,
  [662899] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22541), 1,
      anon_sym_EQ_GT,
    STATE(17109), 2,
      sym_comment,
      sym_block_comment,
  [662913] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22543), 1,
      anon_sym_RPAREN,
    STATE(17110), 2,
      sym_comment,
      sym_block_comment,
  [662927] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22545), 1,
      anon_sym_RPAREN,
    STATE(17111), 2,
      sym_comment,
      sym_block_comment,
  [662941] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22547), 1,
      anon_sym_else,
    STATE(17112), 2,
      sym_comment,
      sym_block_comment,
  [662955] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9509), 1,
      anon_sym_DOT,
    STATE(17113), 2,
      sym_comment,
      sym_block_comment,
  [662969] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22539), 1,
      anon_sym_RPAREN,
    STATE(17114), 2,
      sym_comment,
      sym_block_comment,
  [662983] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22549), 1,
      sym__outdent,
    STATE(17115), 2,
      sym_comment,
      sym_block_comment,
  [662997] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22523), 1,
      anon_sym_RPAREN,
    STATE(17116), 2,
      sym_comment,
      sym_block_comment,
  [663011] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22551), 1,
      sym__outdent,
    STATE(17117), 2,
      sym_comment,
      sym_block_comment,
  [663025] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21485), 1,
      anon_sym_RBRACE,
    STATE(17118), 2,
      sym_comment,
      sym_block_comment,
  [663039] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8973), 1,
      anon_sym_DOT,
    STATE(17119), 2,
      sym_comment,
      sym_block_comment,
  [663053] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22553), 1,
      anon_sym_EQ_GT_GT,
    STATE(17120), 2,
      sym_comment,
      sym_block_comment,
  [663067] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22555), 1,
      anon_sym_EQ_GT_GT,
    STATE(17121), 2,
      sym_comment,
      sym_block_comment,
  [663081] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22557), 1,
      sym__outdent,
    STATE(17122), 2,
      sym_comment,
      sym_block_comment,
  [663095] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22559), 1,
      anon_sym_EQ_GT_GT,
    STATE(17123), 2,
      sym_comment,
      sym_block_comment,
  [663109] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22561), 1,
      anon_sym_EQ_GT_GT,
    STATE(17124), 2,
      sym_comment,
      sym_block_comment,
  [663123] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9557), 1,
      anon_sym_DOT,
    STATE(17125), 2,
      sym_comment,
      sym_block_comment,
  [663137] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22563), 1,
      anon_sym_RPAREN,
    STATE(17126), 2,
      sym_comment,
      sym_block_comment,
  [663151] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22565), 1,
      sym__outdent,
    STATE(17127), 2,
      sym_comment,
      sym_block_comment,
  [663165] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22567), 1,
      anon_sym_RPAREN,
    STATE(17128), 2,
      sym_comment,
      sym_block_comment,
  [663179] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22569), 1,
      anon_sym_RBRACE,
    STATE(17129), 2,
      sym_comment,
      sym_block_comment,
  [663193] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22571), 1,
      anon_sym_EQ_GT_GT,
    STATE(17130), 2,
      sym_comment,
      sym_block_comment,
  [663207] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10682), 1,
      anon_sym_DOT,
    STATE(17131), 2,
      sym_comment,
      sym_block_comment,
  [663221] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22573), 1,
      anon_sym_EQ_GT_GT,
    STATE(17132), 2,
      sym_comment,
      sym_block_comment,
  [663235] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22575), 1,
      anon_sym_RPAREN,
    STATE(17133), 2,
      sym_comment,
      sym_block_comment,
  [663249] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22577), 1,
      anon_sym_EQ_GT_GT,
    STATE(17134), 2,
      sym_comment,
      sym_block_comment,
  [663263] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22579), 1,
      sym__outdent,
    STATE(17135), 2,
      sym_comment,
      sym_block_comment,
  [663277] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22581), 1,
      sym__outdent,
    STATE(17136), 2,
      sym_comment,
      sym_block_comment,
  [663291] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9582), 1,
      anon_sym_DOT,
    STATE(17137), 2,
      sym_comment,
      sym_block_comment,
  [663305] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22583), 1,
      sym__outdent,
    STATE(17138), 2,
      sym_comment,
      sym_block_comment,
  [663319] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22585), 1,
      anon_sym_RPAREN,
    STATE(17139), 2,
      sym_comment,
      sym_block_comment,
  [663333] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22587), 1,
      anon_sym_COLON,
    STATE(17140), 2,
      sym_comment,
      sym_block_comment,
  [663347] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22589), 1,
      anon_sym_RBRACE,
    STATE(17141), 2,
      sym_comment,
      sym_block_comment,
  [663361] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11757), 1,
      anon_sym_DOT,
    STATE(17142), 2,
      sym_comment,
      sym_block_comment,
  [663375] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13406), 1,
      anon_sym_DOT,
    STATE(17143), 2,
      sym_comment,
      sym_block_comment,
  [663389] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22591), 1,
      anon_sym_else,
    STATE(17144), 2,
      sym_comment,
      sym_block_comment,
  [663403] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22593), 1,
      anon_sym_RBRACE,
    STATE(17145), 2,
      sym_comment,
      sym_block_comment,
  [663417] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22595), 1,
      sym__outdent,
    STATE(17146), 2,
      sym_comment,
      sym_block_comment,
  [663431] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22597), 1,
      anon_sym_else,
    STATE(17147), 2,
      sym_comment,
      sym_block_comment,
  [663445] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22517), 1,
      anon_sym_RPAREN,
    STATE(17148), 2,
      sym_comment,
      sym_block_comment,
  [663459] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10819), 1,
      anon_sym_DOT,
    STATE(17149), 2,
      sym_comment,
      sym_block_comment,
  [663473] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22599), 1,
      sym__outdent,
    STATE(17150), 2,
      sym_comment,
      sym_block_comment,
  [663487] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22601), 1,
      anon_sym_RPAREN,
    STATE(17151), 2,
      sym_comment,
      sym_block_comment,
  [663501] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22603), 1,
      anon_sym_RPAREN,
    STATE(17152), 2,
      sym_comment,
      sym_block_comment,
  [663515] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22605), 1,
      sym__outdent,
    STATE(17153), 2,
      sym_comment,
      sym_block_comment,
  [663529] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21369), 1,
      anon_sym_RBRACE,
    STATE(17154), 2,
      sym_comment,
      sym_block_comment,
  [663543] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15077), 1,
      anon_sym_DOT,
    STATE(17155), 2,
      sym_comment,
      sym_block_comment,
  [663557] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22607), 1,
      anon_sym_RPAREN,
    STATE(17156), 2,
      sym_comment,
      sym_block_comment,
  [663571] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22609), 1,
      sym__outdent,
    STATE(17157), 2,
      sym_comment,
      sym_block_comment,
  [663585] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22611), 1,
      anon_sym_else,
    STATE(17158), 2,
      sym_comment,
      sym_block_comment,
  [663599] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22613), 1,
      sym__outdent,
    STATE(17159), 2,
      sym_comment,
      sym_block_comment,
  [663613] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22615), 1,
      anon_sym_RPAREN,
    STATE(17160), 2,
      sym_comment,
      sym_block_comment,
  [663627] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9439), 1,
      anon_sym_DOT,
    STATE(17161), 2,
      sym_comment,
      sym_block_comment,
  [663641] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22617), 1,
      anon_sym_RPAREN,
    STATE(17162), 2,
      sym_comment,
      sym_block_comment,
  [663655] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22619), 1,
      anon_sym_RBRACE,
    STATE(17163), 2,
      sym_comment,
      sym_block_comment,
  [663669] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22621), 1,
      anon_sym_RPAREN,
    STATE(17164), 2,
      sym_comment,
      sym_block_comment,
  [663683] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22623), 1,
      anon_sym_RPAREN,
    STATE(17165), 2,
      sym_comment,
      sym_block_comment,
  [663697] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22625), 1,
      anon_sym_RPAREN,
    STATE(17166), 2,
      sym_comment,
      sym_block_comment,
  [663711] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10761), 1,
      anon_sym_DOT,
    STATE(17167), 2,
      sym_comment,
      sym_block_comment,
  [663725] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22627), 1,
      sym__outdent,
    STATE(17168), 2,
      sym_comment,
      sym_block_comment,
  [663739] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22629), 1,
      sym__outdent,
    STATE(17169), 2,
      sym_comment,
      sym_block_comment,
  [663753] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22631), 1,
      anon_sym_RPAREN,
    STATE(17170), 2,
      sym_comment,
      sym_block_comment,
  [663767] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22633), 1,
      anon_sym_RPAREN,
    STATE(17171), 2,
      sym_comment,
      sym_block_comment,
  [663781] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22635), 1,
      anon_sym_RBRACE,
    STATE(17172), 2,
      sym_comment,
      sym_block_comment,
  [663795] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15152), 1,
      anon_sym_DOT,
    STATE(17173), 2,
      sym_comment,
      sym_block_comment,
  [663809] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22637), 1,
      anon_sym_RBRACE,
    STATE(17174), 2,
      sym_comment,
      sym_block_comment,
  [663823] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22639), 1,
      anon_sym_else,
    STATE(17175), 2,
      sym_comment,
      sym_block_comment,
  [663837] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22641), 1,
      anon_sym_RBRACE,
    STATE(17176), 2,
      sym_comment,
      sym_block_comment,
  [663851] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22643), 1,
      anon_sym_do,
    STATE(17177), 2,
      sym_comment,
      sym_block_comment,
  [663865] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22645), 1,
      anon_sym_RPAREN,
    STATE(17178), 2,
      sym_comment,
      sym_block_comment,
  [663879] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10646), 1,
      anon_sym_DOT,
    STATE(17179), 2,
      sym_comment,
      sym_block_comment,
  [663893] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22647), 1,
      anon_sym_RBRACE,
    STATE(17180), 2,
      sym_comment,
      sym_block_comment,
  [663907] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22649), 1,
      anon_sym_RBRACE,
    STATE(17181), 2,
      sym_comment,
      sym_block_comment,
  [663921] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22651), 1,
      anon_sym_RBRACE,
    STATE(17182), 2,
      sym_comment,
      sym_block_comment,
  [663935] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22653), 1,
      anon_sym_else,
    STATE(17183), 2,
      sym_comment,
      sym_block_comment,
  [663949] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22655), 1,
      anon_sym_RBRACE,
    STATE(17184), 2,
      sym_comment,
      sym_block_comment,
  [663963] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11067), 1,
      anon_sym_DOT,
    STATE(17185), 2,
      sym_comment,
      sym_block_comment,
  [663977] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22657), 1,
      anon_sym_EQ_GT,
    STATE(17186), 2,
      sym_comment,
      sym_block_comment,
  [663991] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22659), 1,
      anon_sym_RBRACE,
    STATE(17187), 2,
      sym_comment,
      sym_block_comment,
  [664005] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22659), 1,
      anon_sym_RBRACK,
    STATE(17188), 2,
      sym_comment,
      sym_block_comment,
  [664019] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22661), 1,
      anon_sym_EQ_GT_GT,
    STATE(17189), 2,
      sym_comment,
      sym_block_comment,
  [664033] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22663), 1,
      anon_sym_RBRACE,
    STATE(17190), 2,
      sym_comment,
      sym_block_comment,
  [664047] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8927), 1,
      anon_sym_DOT,
    STATE(17191), 2,
      sym_comment,
      sym_block_comment,
  [664061] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22665), 1,
      anon_sym_EQ_GT_GT,
    STATE(17192), 2,
      sym_comment,
      sym_block_comment,
  [664075] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22667), 1,
      anon_sym_EQ_GT_GT,
    STATE(17193), 2,
      sym_comment,
      sym_block_comment,
  [664089] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22669), 1,
      anon_sym_EQ_GT_GT,
    STATE(17194), 2,
      sym_comment,
      sym_block_comment,
  [664103] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22671), 1,
      anon_sym_RPAREN,
    STATE(17195), 2,
      sym_comment,
      sym_block_comment,
  [664117] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22673), 1,
      sym__outdent,
    STATE(17196), 2,
      sym_comment,
      sym_block_comment,
  [664131] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12028), 1,
      anon_sym_DOT,
    STATE(17197), 2,
      sym_comment,
      sym_block_comment,
  [664145] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22675), 1,
      anon_sym_RBRACE,
    STATE(17198), 2,
      sym_comment,
      sym_block_comment,
  [664159] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22677), 1,
      anon_sym_RBRACE,
    STATE(17199), 2,
      sym_comment,
      sym_block_comment,
  [664173] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22679), 1,
      anon_sym_do,
    STATE(17200), 2,
      sym_comment,
      sym_block_comment,
  [664187] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22681), 1,
      anon_sym_RPAREN,
    STATE(17201), 2,
      sym_comment,
      sym_block_comment,
  [664201] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22683), 1,
      anon_sym_do,
    STATE(17202), 2,
      sym_comment,
      sym_block_comment,
  [664215] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9463), 1,
      anon_sym_DOT,
    STATE(17203), 2,
      sym_comment,
      sym_block_comment,
  [664229] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22685), 1,
      anon_sym_do,
    STATE(17204), 2,
      sym_comment,
      sym_block_comment,
  [664243] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22687), 1,
      anon_sym_COLON,
    STATE(17205), 2,
      sym_comment,
      sym_block_comment,
  [664257] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15450), 1,
      anon_sym_DOT,
    STATE(17206), 2,
      sym_comment,
      sym_block_comment,
  [664271] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22689), 1,
      sym__outdent,
    STATE(17207), 2,
      sym_comment,
      sym_block_comment,
  [664285] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22691), 1,
      anon_sym_RBRACE,
    STATE(17208), 2,
      sym_comment,
      sym_block_comment,
  [664299] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10901), 1,
      anon_sym_DOT,
    STATE(17209), 2,
      sym_comment,
      sym_block_comment,
  [664313] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22693), 1,
      anon_sym_RBRACE,
    STATE(17210), 2,
      sym_comment,
      sym_block_comment,
  [664327] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22695), 1,
      anon_sym_RBRACE,
    STATE(17211), 2,
      sym_comment,
      sym_block_comment,
  [664341] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22697), 1,
      anon_sym_RPAREN,
    STATE(17212), 2,
      sym_comment,
      sym_block_comment,
  [664355] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22691), 1,
      anon_sym_RPAREN,
    STATE(17213), 2,
      sym_comment,
      sym_block_comment,
  [664369] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22699), 1,
      sym__outdent,
    STATE(17214), 2,
      sym_comment,
      sym_block_comment,
  [664383] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9725), 1,
      anon_sym_DOT,
    STATE(17215), 2,
      sym_comment,
      sym_block_comment,
  [664397] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22701), 1,
      anon_sym_RPAREN,
    STATE(17216), 2,
      sym_comment,
      sym_block_comment,
  [664411] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22703), 1,
      anon_sym_RBRACE,
    STATE(17217), 2,
      sym_comment,
      sym_block_comment,
  [664425] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22705), 1,
      sym__outdent,
    STATE(17218), 2,
      sym_comment,
      sym_block_comment,
  [664439] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22707), 1,
      anon_sym_else,
    STATE(17219), 2,
      sym_comment,
      sym_block_comment,
  [664453] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22709), 1,
      sym__outdent,
    STATE(17220), 2,
      sym_comment,
      sym_block_comment,
  [664467] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13989), 1,
      anon_sym_DOT,
    STATE(17221), 2,
      sym_comment,
      sym_block_comment,
  [664481] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22711), 1,
      anon_sym_RPAREN,
    STATE(17222), 2,
      sym_comment,
      sym_block_comment,
  [664495] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22713), 1,
      anon_sym_RPAREN,
    STATE(17223), 2,
      sym_comment,
      sym_block_comment,
  [664509] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22715), 1,
      anon_sym_else,
    STATE(17224), 2,
      sym_comment,
      sym_block_comment,
  [664523] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22717), 1,
      sym__outdent,
    STATE(17225), 2,
      sym_comment,
      sym_block_comment,
  [664537] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22719), 1,
      anon_sym_RBRACE,
    STATE(17226), 2,
      sym_comment,
      sym_block_comment,
  [664551] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11122), 1,
      anon_sym_DOT,
    STATE(17227), 2,
      sym_comment,
      sym_block_comment,
  [664565] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22721), 1,
      anon_sym_RBRACE,
    STATE(17228), 2,
      sym_comment,
      sym_block_comment,
  [664579] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22723), 1,
      anon_sym_RBRACE,
    STATE(17229), 2,
      sym_comment,
      sym_block_comment,
  [664593] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22725), 1,
      sym__outdent,
    STATE(17230), 2,
      sym_comment,
      sym_block_comment,
  [664607] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22727), 1,
      sym__outdent,
    STATE(17231), 2,
      sym_comment,
      sym_block_comment,
  [664621] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22729), 1,
      sym__outdent,
    STATE(17232), 2,
      sym_comment,
      sym_block_comment,
  [664635] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15065), 1,
      anon_sym_DOT,
    STATE(17233), 2,
      sym_comment,
      sym_block_comment,
  [664649] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22731), 1,
      anon_sym_RPAREN,
    STATE(17234), 2,
      sym_comment,
      sym_block_comment,
  [664663] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22733), 1,
      sym__outdent,
    STATE(17235), 2,
      sym_comment,
      sym_block_comment,
  [664677] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22735), 1,
      anon_sym_RPAREN,
    STATE(17236), 2,
      sym_comment,
      sym_block_comment,
  [664691] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22737), 1,
      anon_sym_RBRACE,
    STATE(17237), 2,
      sym_comment,
      sym_block_comment,
  [664705] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22739), 1,
      sym__outdent,
    STATE(17238), 2,
      sym_comment,
      sym_block_comment,
  [664719] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11367), 1,
      anon_sym_DOT,
    STATE(17239), 2,
      sym_comment,
      sym_block_comment,
  [664733] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22741), 1,
      anon_sym_else,
    STATE(17240), 2,
      sym_comment,
      sym_block_comment,
  [664747] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22743), 1,
      anon_sym_else,
    STATE(17241), 2,
      sym_comment,
      sym_block_comment,
  [664761] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22745), 1,
      anon_sym_do,
    STATE(17242), 2,
      sym_comment,
      sym_block_comment,
  [664775] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22747), 1,
      sym__outdent,
    STATE(17243), 2,
      sym_comment,
      sym_block_comment,
  [664789] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22749), 1,
      anon_sym_RPAREN,
    STATE(17244), 2,
      sym_comment,
      sym_block_comment,
  [664803] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12796), 1,
      anon_sym_DOT,
    STATE(17245), 2,
      sym_comment,
      sym_block_comment,
  [664817] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22751), 1,
      anon_sym_RPAREN,
    STATE(17246), 2,
      sym_comment,
      sym_block_comment,
  [664831] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22753), 1,
      anon_sym_RPAREN,
    STATE(17247), 2,
      sym_comment,
      sym_block_comment,
  [664845] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22755), 1,
      sym__outdent,
    STATE(17248), 2,
      sym_comment,
      sym_block_comment,
  [664859] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22757), 1,
      sym__outdent,
    STATE(17249), 2,
      sym_comment,
      sym_block_comment,
  [664873] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22759), 1,
      anon_sym_RBRACE,
    STATE(17250), 2,
      sym_comment,
      sym_block_comment,
  [664887] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9135), 1,
      anon_sym_DOT,
    STATE(17251), 2,
      sym_comment,
      sym_block_comment,
  [664901] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22761), 1,
      anon_sym_else,
    STATE(17252), 2,
      sym_comment,
      sym_block_comment,
  [664915] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22759), 1,
      anon_sym_RPAREN,
    STATE(17253), 2,
      sym_comment,
      sym_block_comment,
  [664929] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22763), 1,
      anon_sym_RBRACE,
    STATE(17254), 2,
      sym_comment,
      sym_block_comment,
  [664943] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22765), 1,
      anon_sym_EQ_GT,
    STATE(17255), 2,
      sym_comment,
      sym_block_comment,
  [664957] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22767), 1,
      anon_sym_RBRACE,
    STATE(17256), 2,
      sym_comment,
      sym_block_comment,
  [664971] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9761), 1,
      anon_sym_DOT,
    STATE(17257), 2,
      sym_comment,
      sym_block_comment,
  [664985] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22769), 1,
      anon_sym_RPAREN,
    STATE(17258), 2,
      sym_comment,
      sym_block_comment,
  [664999] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22771), 1,
      anon_sym_RPAREN,
    STATE(17259), 2,
      sym_comment,
      sym_block_comment,
  [665013] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22773), 1,
      sym__outdent,
    STATE(17260), 2,
      sym_comment,
      sym_block_comment,
  [665027] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22775), 1,
      anon_sym_RBRACE,
    STATE(17261), 2,
      sym_comment,
      sym_block_comment,
  [665041] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22777), 1,
      anon_sym_RBRACE,
    STATE(17262), 2,
      sym_comment,
      sym_block_comment,
  [665055] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13467), 1,
      anon_sym_DOT,
    STATE(17263), 2,
      sym_comment,
      sym_block_comment,
  [665069] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22779), 1,
      anon_sym_EQ_GT_GT,
    STATE(17264), 2,
      sym_comment,
      sym_block_comment,
  [665083] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22781), 1,
      anon_sym_RBRACE,
    STATE(17265), 2,
      sym_comment,
      sym_block_comment,
  [665097] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22783), 1,
      anon_sym_EQ_GT_GT,
    STATE(17266), 2,
      sym_comment,
      sym_block_comment,
  [665111] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22785), 1,
      anon_sym_EQ_GT_GT,
    STATE(17267), 2,
      sym_comment,
      sym_block_comment,
  [665125] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22787), 1,
      anon_sym_do,
    STATE(17268), 2,
      sym_comment,
      sym_block_comment,
  [665139] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9790), 1,
      anon_sym_DOT,
    STATE(17269), 2,
      sym_comment,
      sym_block_comment,
  [665153] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22789), 1,
      anon_sym_EQ_GT_GT,
    STATE(17270), 2,
      sym_comment,
      sym_block_comment,
  [665167] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22775), 1,
      anon_sym_RBRACK,
    STATE(17271), 2,
      sym_comment,
      sym_block_comment,
  [665181] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22791), 1,
      sym__outdent,
    STATE(17272), 2,
      sym_comment,
      sym_block_comment,
  [665195] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22497), 1,
      anon_sym_RBRACE,
    STATE(17273), 2,
      sym_comment,
      sym_block_comment,
  [665209] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22793), 1,
      anon_sym_RPAREN,
    STATE(17274), 2,
      sym_comment,
      sym_block_comment,
  [665223] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10697), 1,
      anon_sym_DOT,
    STATE(17275), 2,
      sym_comment,
      sym_block_comment,
  [665237] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22795), 1,
      anon_sym_COLON,
    STATE(17276), 2,
      sym_comment,
      sym_block_comment,
  [665251] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22797), 1,
      anon_sym_RPAREN,
    STATE(17277), 2,
      sym_comment,
      sym_block_comment,
  [665265] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22799), 1,
      anon_sym_RBRACE,
    STATE(17278), 2,
      sym_comment,
      sym_block_comment,
  [665279] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22801), 1,
      anon_sym_RBRACE,
    STATE(17279), 2,
      sym_comment,
      sym_block_comment,
  [665293] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9399), 1,
      anon_sym_DOT,
    STATE(17280), 2,
      sym_comment,
      sym_block_comment,
  [665307] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14419), 1,
      anon_sym_DOT,
    STATE(17281), 2,
      sym_comment,
      sym_block_comment,
  [665321] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22803), 1,
      sym__outdent,
    STATE(17282), 2,
      sym_comment,
      sym_block_comment,
  [665335] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22805), 1,
      anon_sym_do,
    STATE(17283), 2,
      sym_comment,
      sym_block_comment,
  [665349] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22807), 1,
      anon_sym_RPAREN,
    STATE(17284), 2,
      sym_comment,
      sym_block_comment,
  [665363] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22809), 1,
      sym__outdent,
    STATE(17285), 2,
      sym_comment,
      sym_block_comment,
  [665377] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22695), 1,
      anon_sym_RBRACK,
    STATE(17286), 2,
      sym_comment,
      sym_block_comment,
  [665391] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22811), 1,
      sym__outdent,
    STATE(17287), 2,
      sym_comment,
      sym_block_comment,
  [665405] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22813), 1,
      anon_sym_RBRACE,
    STATE(17288), 2,
      sym_comment,
      sym_block_comment,
  [665419] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22815), 1,
      anon_sym_do,
    STATE(17289), 2,
      sym_comment,
      sym_block_comment,
  [665433] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22817), 1,
      sym__outdent,
    STATE(17290), 2,
      sym_comment,
      sym_block_comment,
  [665447] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22819), 1,
      anon_sym_RPAREN,
    STATE(17291), 2,
      sym_comment,
      sym_block_comment,
  [665461] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22821), 1,
      anon_sym_RBRACE,
    STATE(17292), 2,
      sym_comment,
      sym_block_comment,
  [665475] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22823), 1,
      anon_sym_RPAREN,
    STATE(17293), 2,
      sym_comment,
      sym_block_comment,
  [665489] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22825), 1,
      anon_sym_do,
    STATE(17294), 2,
      sym_comment,
      sym_block_comment,
  [665503] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22827), 1,
      anon_sym_RPAREN,
    STATE(17295), 2,
      sym_comment,
      sym_block_comment,
  [665517] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22829), 1,
      anon_sym_else,
    STATE(17296), 2,
      sym_comment,
      sym_block_comment,
  [665531] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22831), 1,
      anon_sym_RPAREN,
    STATE(17297), 2,
      sym_comment,
      sym_block_comment,
  [665545] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22833), 1,
      sym__outdent,
    STATE(17298), 2,
      sym_comment,
      sym_block_comment,
  [665559] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22835), 1,
      anon_sym_RBRACE,
    STATE(17299), 2,
      sym_comment,
      sym_block_comment,
  [665573] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22837), 1,
      anon_sym_RBRACE,
    STATE(17300), 2,
      sym_comment,
      sym_block_comment,
  [665587] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22839), 1,
      anon_sym_else,
    STATE(17301), 2,
      sym_comment,
      sym_block_comment,
  [665601] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22841), 1,
      anon_sym_RPAREN,
    STATE(17302), 2,
      sym_comment,
      sym_block_comment,
  [665615] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22843), 1,
      sym__outdent,
    STATE(17303), 2,
      sym_comment,
      sym_block_comment,
  [665629] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22845), 1,
      sym__outdent,
    STATE(17304), 2,
      sym_comment,
      sym_block_comment,
  [665643] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22847), 1,
      sym__outdent,
    STATE(17305), 2,
      sym_comment,
      sym_block_comment,
  [665657] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22849), 1,
      sym__outdent,
    STATE(17306), 2,
      sym_comment,
      sym_block_comment,
  [665671] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22851), 1,
      anon_sym_else,
    STATE(17307), 2,
      sym_comment,
      sym_block_comment,
  [665685] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22853), 1,
      anon_sym_RPAREN,
    STATE(17308), 2,
      sym_comment,
      sym_block_comment,
  [665699] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22855), 1,
      anon_sym_RBRACE,
    STATE(17309), 2,
      sym_comment,
      sym_block_comment,
  [665713] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22855), 1,
      anon_sym_RPAREN,
    STATE(17310), 2,
      sym_comment,
      sym_block_comment,
  [665727] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22857), 1,
      anon_sym_RBRACE,
    STATE(17311), 2,
      sym_comment,
      sym_block_comment,
  [665741] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22859), 1,
      anon_sym_RBRACE,
    STATE(17312), 2,
      sym_comment,
      sym_block_comment,
  [665755] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22857), 1,
      anon_sym_RPAREN,
    STATE(17313), 2,
      sym_comment,
      sym_block_comment,
  [665769] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22861), 1,
      sym__outdent,
    STATE(17314), 2,
      sym_comment,
      sym_block_comment,
  [665783] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22863), 1,
      sym__outdent,
    STATE(17315), 2,
      sym_comment,
      sym_block_comment,
  [665797] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22865), 1,
      anon_sym_RBRACE,
    STATE(17316), 2,
      sym_comment,
      sym_block_comment,
  [665811] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22865), 1,
      anon_sym_RBRACK,
    STATE(17317), 2,
      sym_comment,
      sym_block_comment,
  [665825] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22867), 1,
      anon_sym_RBRACE,
    STATE(17318), 2,
      sym_comment,
      sym_block_comment,
  [665839] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22867), 1,
      anon_sym_RBRACK,
    STATE(17319), 2,
      sym_comment,
      sym_block_comment,
  [665853] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22869), 1,
      anon_sym_EQ_GT,
    STATE(17320), 2,
      sym_comment,
      sym_block_comment,
  [665867] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22871), 1,
      anon_sym_RPAREN,
    STATE(17321), 2,
      sym_comment,
      sym_block_comment,
  [665881] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22873), 1,
      anon_sym_EQ,
    STATE(17322), 2,
      sym_comment,
      sym_block_comment,
  [665895] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22875), 1,
      anon_sym_do,
    STATE(17323), 2,
      sym_comment,
      sym_block_comment,
  [665909] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22877), 1,
      sym__outdent,
    STATE(17324), 2,
      sym_comment,
      sym_block_comment,
  [665923] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22879), 1,
      anon_sym_RBRACE,
    STATE(17325), 2,
      sym_comment,
      sym_block_comment,
  [665937] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22881), 1,
      anon_sym_EQ_GT_GT,
    STATE(17326), 2,
      sym_comment,
      sym_block_comment,
  [665951] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22883), 1,
      anon_sym_RPAREN,
    STATE(17327), 2,
      sym_comment,
      sym_block_comment,
  [665965] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22885), 1,
      anon_sym_else,
    STATE(17328), 2,
      sym_comment,
      sym_block_comment,
  [665979] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22887), 1,
      sym__outdent,
    STATE(17329), 2,
      sym_comment,
      sym_block_comment,
  [665993] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22889), 1,
      anon_sym_EQ_GT_GT,
    STATE(17330), 2,
      sym_comment,
      sym_block_comment,
  [666007] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22891), 1,
      anon_sym_RPAREN,
    STATE(17331), 2,
      sym_comment,
      sym_block_comment,
  [666021] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22893), 1,
      sym__outdent,
    STATE(17332), 2,
      sym_comment,
      sym_block_comment,
  [666035] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22895), 1,
      anon_sym_EQ_GT_GT,
    STATE(17333), 2,
      sym_comment,
      sym_block_comment,
  [666049] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22897), 1,
      sym__outdent,
    STATE(17334), 2,
      sym_comment,
      sym_block_comment,
  [666063] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22899), 1,
      sym__outdent,
    STATE(17335), 2,
      sym_comment,
      sym_block_comment,
  [666077] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22901), 1,
      anon_sym_EQ_GT_GT,
    STATE(17336), 2,
      sym_comment,
      sym_block_comment,
  [666091] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22903), 1,
      anon_sym_RBRACE,
    STATE(17337), 2,
      sym_comment,
      sym_block_comment,
  [666105] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22905), 1,
      anon_sym_RBRACE,
    STATE(17338), 2,
      sym_comment,
      sym_block_comment,
  [666119] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22905), 1,
      anon_sym_RPAREN,
    STATE(17339), 2,
      sym_comment,
      sym_block_comment,
  [666133] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22907), 1,
      anon_sym_RPAREN,
    STATE(17340), 2,
      sym_comment,
      sym_block_comment,
  [666147] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22909), 1,
      anon_sym_RPAREN,
    STATE(17341), 2,
      sym_comment,
      sym_block_comment,
  [666161] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22911), 1,
      anon_sym_RBRACE,
    STATE(17342), 2,
      sym_comment,
      sym_block_comment,
  [666175] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22913), 1,
      anon_sym_else,
    STATE(17343), 2,
      sym_comment,
      sym_block_comment,
  [666189] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22915), 1,
      anon_sym_COLON,
    STATE(17344), 2,
      sym_comment,
      sym_block_comment,
  [666203] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22917), 1,
      sym__indent,
    STATE(17345), 2,
      sym_comment,
      sym_block_comment,
  [666217] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8150), 1,
      anon_sym_def,
    STATE(17346), 2,
      sym_comment,
      sym_block_comment,
  [666231] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22919), 1,
      anon_sym_RBRACE,
    STATE(17347), 2,
      sym_comment,
      sym_block_comment,
  [666245] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22921), 1,
      sym__indent,
    STATE(17348), 2,
      sym_comment,
      sym_block_comment,
  [666259] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22923), 1,
      anon_sym_else,
    STATE(17349), 2,
      sym_comment,
      sym_block_comment,
  [666273] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15351), 1,
      anon_sym_def,
    STATE(17350), 2,
      sym_comment,
      sym_block_comment,
  [666287] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9656), 1,
      anon_sym_DOT,
    STATE(17351), 2,
      sym_comment,
      sym_block_comment,
  [666301] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22925), 1,
      anon_sym_else,
    STATE(17352), 2,
      sym_comment,
      sym_block_comment,
  [666315] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22927), 1,
      anon_sym_RBRACE,
    STATE(17353), 2,
      sym_comment,
      sym_block_comment,
  [666329] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22929), 1,
      sym__outdent,
    STATE(17354), 2,
      sym_comment,
      sym_block_comment,
  [666343] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22931), 1,
      anon_sym_EQ,
    STATE(17355), 2,
      sym_comment,
      sym_block_comment,
  [666357] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22933), 1,
      anon_sym_RPAREN,
    STATE(17356), 2,
      sym_comment,
      sym_block_comment,
  [666371] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22935), 1,
      sym__outdent,
    STATE(17357), 2,
      sym_comment,
      sym_block_comment,
  [666385] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22937), 1,
      anon_sym_EQ,
    STATE(17358), 2,
      sym_comment,
      sym_block_comment,
  [666399] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22939), 1,
      sym__outdent,
    STATE(17359), 2,
      sym_comment,
      sym_block_comment,
  [666413] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22215), 1,
      anon_sym_RBRACK,
    STATE(17360), 2,
      sym_comment,
      sym_block_comment,
  [666427] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22941), 1,
      anon_sym_else,
    STATE(17361), 2,
      sym_comment,
      sym_block_comment,
  [666441] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22919), 1,
      anon_sym_RPAREN,
    STATE(17362), 2,
      sym_comment,
      sym_block_comment,
  [666455] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22943), 1,
      anon_sym_EQ,
    STATE(17363), 2,
      sym_comment,
      sym_block_comment,
  [666469] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22945), 1,
      anon_sym_RBRACE,
    STATE(17364), 2,
      sym_comment,
      sym_block_comment,
  [666483] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22947), 1,
      sym__outdent,
    STATE(17365), 2,
      sym_comment,
      sym_block_comment,
  [666497] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22949), 1,
      anon_sym_RBRACE,
    STATE(17366), 2,
      sym_comment,
      sym_block_comment,
  [666511] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22951), 1,
      sym__indent,
    STATE(17367), 2,
      sym_comment,
      sym_block_comment,
  [666525] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22953), 1,
      anon_sym_RPAREN,
    STATE(17368), 2,
      sym_comment,
      sym_block_comment,
  [666539] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22955), 1,
      anon_sym_else,
    STATE(17369), 2,
      sym_comment,
      sym_block_comment,
  [666553] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22957), 1,
      anon_sym_RBRACE,
    STATE(17370), 2,
      sym_comment,
      sym_block_comment,
  [666567] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22959), 1,
      anon_sym_RBRACE,
    STATE(17371), 2,
      sym_comment,
      sym_block_comment,
  [666581] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22961), 1,
      anon_sym_RPAREN,
    STATE(17372), 2,
      sym_comment,
      sym_block_comment,
  [666595] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22963), 1,
      anon_sym_RPAREN,
    STATE(17373), 2,
      sym_comment,
      sym_block_comment,
  [666609] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22965), 1,
      anon_sym_RBRACE,
    STATE(17374), 2,
      sym_comment,
      sym_block_comment,
  [666623] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22967), 1,
      anon_sym_COLON,
    STATE(17375), 2,
      sym_comment,
      sym_block_comment,
  [666637] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13434), 1,
      sym__indent,
    STATE(17376), 2,
      sym_comment,
      sym_block_comment,
  [666651] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22969), 1,
      sym__outdent,
    STATE(17377), 2,
      sym_comment,
      sym_block_comment,
  [666665] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11900), 1,
      anon_sym_EQ_GT,
    STATE(17378), 2,
      sym_comment,
      sym_block_comment,
  [666679] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22971), 1,
      sym__outdent,
    STATE(17379), 2,
      sym_comment,
      sym_block_comment,
  [666693] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22973), 1,
      anon_sym_RPAREN,
    STATE(17380), 2,
      sym_comment,
      sym_block_comment,
  [666707] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22949), 1,
      anon_sym_RPAREN,
    STATE(17381), 2,
      sym_comment,
      sym_block_comment,
  [666721] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22965), 1,
      anon_sym_RPAREN,
    STATE(17382), 2,
      sym_comment,
      sym_block_comment,
  [666735] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22975), 1,
      anon_sym_RPAREN,
    STATE(17383), 2,
      sym_comment,
      sym_block_comment,
  [666749] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22977), 1,
      anon_sym_COLON,
    STATE(17384), 2,
      sym_comment,
      sym_block_comment,
  [666763] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22979), 1,
      sym__indent,
    STATE(17385), 2,
      sym_comment,
      sym_block_comment,
  [666777] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22981), 1,
      anon_sym_EQ_GT,
    STATE(17386), 2,
      sym_comment,
      sym_block_comment,
  [666791] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22983), 1,
      anon_sym_RBRACE,
    STATE(17387), 2,
      sym_comment,
      sym_block_comment,
  [666805] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22985), 1,
      sym__outdent,
    STATE(17388), 2,
      sym_comment,
      sym_block_comment,
  [666819] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22987), 1,
      anon_sym_EQ_GT_GT,
    STATE(17389), 2,
      sym_comment,
      sym_block_comment,
  [666833] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22989), 1,
      anon_sym_RBRACE,
    STATE(17390), 2,
      sym_comment,
      sym_block_comment,
  [666847] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22991), 1,
      anon_sym_RPAREN,
    STATE(17391), 2,
      sym_comment,
      sym_block_comment,
  [666861] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22993), 1,
      sym__indent,
    STATE(17392), 2,
      sym_comment,
      sym_block_comment,
  [666875] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22995), 1,
      anon_sym_EQ_GT_GT,
    STATE(17393), 2,
      sym_comment,
      sym_block_comment,
  [666889] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22997), 1,
      anon_sym_do,
    STATE(17394), 2,
      sym_comment,
      sym_block_comment,
  [666903] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22999), 1,
      anon_sym_EQ_GT_GT,
    STATE(17395), 2,
      sym_comment,
      sym_block_comment,
  [666917] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23001), 1,
      anon_sym_EQ_GT_GT,
    STATE(17396), 2,
      sym_comment,
      sym_block_comment,
  [666931] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23003), 1,
      sym__outdent,
    STATE(17397), 2,
      sym_comment,
      sym_block_comment,
  [666945] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23005), 1,
      anon_sym_EQ_GT_GT,
    STATE(17398), 2,
      sym_comment,
      sym_block_comment,
  [666959] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23007), 1,
      sym__indent,
    STATE(17399), 2,
      sym_comment,
      sym_block_comment,
  [666973] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23009), 1,
      anon_sym_else,
    STATE(17400), 2,
      sym_comment,
      sym_block_comment,
  [666987] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23011), 1,
      sym__indent,
    STATE(17401), 2,
      sym_comment,
      sym_block_comment,
  [667001] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23013), 1,
      anon_sym_do,
    STATE(17402), 2,
      sym_comment,
      sym_block_comment,
  [667015] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23015), 1,
      anon_sym_RBRACE,
    STATE(17403), 2,
      sym_comment,
      sym_block_comment,
  [667029] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23017), 1,
      sym__outdent,
    STATE(17404), 2,
      sym_comment,
      sym_block_comment,
  [667043] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23015), 1,
      anon_sym_RPAREN,
    STATE(17405), 2,
      sym_comment,
      sym_block_comment,
  [667057] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23019), 1,
      sym__indent,
    STATE(17406), 2,
      sym_comment,
      sym_block_comment,
  [667071] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23021), 1,
      anon_sym_RBRACE,
    STATE(17407), 2,
      sym_comment,
      sym_block_comment,
  [667085] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23023), 1,
      anon_sym_RBRACE,
    STATE(17408), 2,
      sym_comment,
      sym_block_comment,
  [667099] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23025), 1,
      anon_sym_COLON,
    STATE(17409), 2,
      sym_comment,
      sym_block_comment,
  [667113] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12846), 1,
      anon_sym_DOT,
    STATE(17410), 2,
      sym_comment,
      sym_block_comment,
  [667127] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23027), 1,
      anon_sym_RPAREN,
    STATE(17411), 2,
      sym_comment,
      sym_block_comment,
  [667141] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23029), 1,
      anon_sym_RBRACE,
    STATE(17412), 2,
      sym_comment,
      sym_block_comment,
  [667155] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23031), 1,
      sym__indent,
    STATE(17413), 2,
      sym_comment,
      sym_block_comment,
  [667169] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23033), 1,
      anon_sym_RPAREN,
    STATE(17414), 2,
      sym_comment,
      sym_block_comment,
  [667183] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23035), 1,
      sym__outdent,
    STATE(17415), 2,
      sym_comment,
      sym_block_comment,
  [667197] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23037), 1,
      sym__outdent,
    STATE(17416), 2,
      sym_comment,
      sym_block_comment,
  [667211] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23039), 1,
      sym__outdent,
    STATE(17417), 2,
      sym_comment,
      sym_block_comment,
  [667225] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23041), 1,
      anon_sym_RBRACE,
    STATE(17418), 2,
      sym_comment,
      sym_block_comment,
  [667239] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23043), 1,
      anon_sym_else,
    STATE(17419), 2,
      sym_comment,
      sym_block_comment,
  [667253] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23045), 1,
      sym__indent,
    STATE(17420), 2,
      sym_comment,
      sym_block_comment,
  [667267] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23047), 1,
      anon_sym_RPAREN,
    STATE(17421), 2,
      sym_comment,
      sym_block_comment,
  [667281] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23041), 1,
      anon_sym_RPAREN,
    STATE(17422), 2,
      sym_comment,
      sym_block_comment,
  [667295] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23049), 1,
      anon_sym_else,
    STATE(17423), 2,
      sym_comment,
      sym_block_comment,
  [667309] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15407), 1,
      anon_sym_def,
    STATE(17424), 2,
      sym_comment,
      sym_block_comment,
  [667323] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22989), 1,
      anon_sym_RBRACK,
    STATE(17425), 2,
      sym_comment,
      sym_block_comment,
  [667337] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23029), 1,
      anon_sym_RBRACK,
    STATE(17426), 2,
      sym_comment,
      sym_block_comment,
  [667351] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23051), 1,
      sym__indent,
    STATE(17427), 2,
      sym_comment,
      sym_block_comment,
  [667365] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23053), 1,
      anon_sym_else,
    STATE(17428), 2,
      sym_comment,
      sym_block_comment,
  [667379] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23055), 1,
      sym__outdent,
    STATE(17429), 2,
      sym_comment,
      sym_block_comment,
  [667393] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23057), 1,
      anon_sym_RBRACE,
    STATE(17430), 2,
      sym_comment,
      sym_block_comment,
  [667407] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23059), 1,
      anon_sym_RPAREN,
    STATE(17431), 2,
      sym_comment,
      sym_block_comment,
  [667421] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23061), 1,
      sym__outdent,
    STATE(17432), 2,
      sym_comment,
      sym_block_comment,
  [667435] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23063), 1,
      anon_sym_RBRACE,
    STATE(17433), 2,
      sym_comment,
      sym_block_comment,
  [667449] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23065), 1,
      sym__indent,
    STATE(17434), 2,
      sym_comment,
      sym_block_comment,
  [667463] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23067), 1,
      sym__outdent,
    STATE(17435), 2,
      sym_comment,
      sym_block_comment,
  [667477] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23069), 1,
      anon_sym_RBRACE,
    STATE(17436), 2,
      sym_comment,
      sym_block_comment,
  [667491] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23071), 1,
      anon_sym_RBRACE,
    STATE(17437), 2,
      sym_comment,
      sym_block_comment,
  [667505] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23073), 1,
      anon_sym_RPAREN,
    STATE(17438), 2,
      sym_comment,
      sym_block_comment,
  [667519] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23075), 1,
      sym__outdent,
    STATE(17439), 2,
      sym_comment,
      sym_block_comment,
  [667533] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23077), 1,
      anon_sym_EQ_GT_GT,
    STATE(17440), 2,
      sym_comment,
      sym_block_comment,
  [667547] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23079), 1,
      sym__indent,
    STATE(17441), 2,
      sym_comment,
      sym_block_comment,
  [667561] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23081), 1,
      anon_sym_else,
    STATE(17442), 2,
      sym_comment,
      sym_block_comment,
  [667575] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23083), 1,
      anon_sym_RBRACE,
    STATE(17443), 2,
      sym_comment,
      sym_block_comment,
  [667589] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23085), 1,
      anon_sym_do,
    STATE(17444), 2,
      sym_comment,
      sym_block_comment,
  [667603] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23083), 1,
      anon_sym_RPAREN,
    STATE(17445), 2,
      sym_comment,
      sym_block_comment,
  [667617] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23087), 1,
      anon_sym_else,
    STATE(17446), 2,
      sym_comment,
      sym_block_comment,
  [667631] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23089), 1,
      anon_sym_EQ_GT_GT,
    STATE(17447), 2,
      sym_comment,
      sym_block_comment,
  [667645] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23091), 1,
      sym__indent,
    STATE(17448), 2,
      sym_comment,
      sym_block_comment,
  [667659] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23057), 1,
      anon_sym_RBRACK,
    STATE(17449), 2,
      sym_comment,
      sym_block_comment,
  [667673] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23093), 1,
      anon_sym_else,
    STATE(17450), 2,
      sym_comment,
      sym_block_comment,
  [667687] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23095), 1,
      anon_sym_RBRACE,
    STATE(17451), 2,
      sym_comment,
      sym_block_comment,
  [667701] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23097), 1,
      anon_sym_RBRACE,
    STATE(17452), 2,
      sym_comment,
      sym_block_comment,
  [667715] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23099), 1,
      anon_sym_EQ_GT,
    STATE(17453), 2,
      sym_comment,
      sym_block_comment,
  [667729] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23101), 1,
      anon_sym_RBRACE,
    STATE(17454), 2,
      sym_comment,
      sym_block_comment,
  [667743] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23103), 1,
      sym__indent,
    STATE(17455), 2,
      sym_comment,
      sym_block_comment,
  [667757] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23105), 1,
      anon_sym_RBRACE,
    STATE(17456), 2,
      sym_comment,
      sym_block_comment,
  [667771] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23107), 1,
      anon_sym_RPAREN,
    STATE(17457), 2,
      sym_comment,
      sym_block_comment,
  [667785] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23109), 1,
      anon_sym_EQ_GT_GT,
    STATE(17458), 2,
      sym_comment,
      sym_block_comment,
  [667799] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23111), 1,
      sym__outdent,
    STATE(17459), 2,
      sym_comment,
      sym_block_comment,
  [667813] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23063), 1,
      anon_sym_RBRACK,
    STATE(17460), 2,
      sym_comment,
      sym_block_comment,
  [667827] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23113), 1,
      anon_sym_RBRACE,
    STATE(17461), 2,
      sym_comment,
      sym_block_comment,
  [667841] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23115), 1,
      sym__indent,
    STATE(17462), 2,
      sym_comment,
      sym_block_comment,
  [667855] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23117), 1,
      anon_sym_RPAREN,
    STATE(17463), 2,
      sym_comment,
      sym_block_comment,
  [667869] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23119), 1,
      anon_sym_else,
    STATE(17464), 2,
      sym_comment,
      sym_block_comment,
  [667883] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23121), 1,
      anon_sym_EQ_GT_GT,
    STATE(17465), 2,
      sym_comment,
      sym_block_comment,
  [667897] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23123), 1,
      anon_sym_EQ_GT_GT,
    STATE(17466), 2,
      sym_comment,
      sym_block_comment,
  [667911] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23125), 1,
      anon_sym_EQ_GT_GT,
    STATE(17467), 2,
      sym_comment,
      sym_block_comment,
  [667925] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23127), 1,
      anon_sym_EQ_GT_GT,
    STATE(17468), 2,
      sym_comment,
      sym_block_comment,
  [667939] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23129), 1,
      sym__indent,
    STATE(17469), 2,
      sym_comment,
      sym_block_comment,
  [667953] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23131), 1,
      sym__outdent,
    STATE(17470), 2,
      sym_comment,
      sym_block_comment,
  [667967] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23133), 1,
      anon_sym_RBRACE,
    STATE(17471), 2,
      sym_comment,
      sym_block_comment,
  [667981] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23133), 1,
      anon_sym_RPAREN,
    STATE(17472), 2,
      sym_comment,
      sym_block_comment,
  [667995] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23135), 1,
      anon_sym_RBRACK,
    STATE(17473), 2,
      sym_comment,
      sym_block_comment,
  [668009] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23137), 1,
      anon_sym_COLON,
    STATE(17474), 2,
      sym_comment,
      sym_block_comment,
  [668023] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23139), 1,
      anon_sym_RBRACE,
    STATE(17475), 2,
      sym_comment,
      sym_block_comment,
  [668037] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23141), 1,
      sym__indent,
    STATE(17476), 2,
      sym_comment,
      sym_block_comment,
  [668051] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12658), 1,
      anon_sym_DOT,
    STATE(17477), 2,
      sym_comment,
      sym_block_comment,
  [668065] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23143), 1,
      anon_sym_RPAREN,
    STATE(17478), 2,
      sym_comment,
      sym_block_comment,
  [668079] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23145), 1,
      anon_sym_RBRACE,
    STATE(17479), 2,
      sym_comment,
      sym_block_comment,
  [668093] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23139), 1,
      anon_sym_RBRACK,
    STATE(17480), 2,
      sym_comment,
      sym_block_comment,
  [668107] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23147), 1,
      sym__outdent,
    STATE(17481), 2,
      sym_comment,
      sym_block_comment,
  [668121] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23149), 1,
      sym__indent,
    STATE(17482), 2,
      sym_comment,
      sym_block_comment,
  [668135] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23145), 1,
      anon_sym_RBRACK,
    STATE(17483), 2,
      sym_comment,
      sym_block_comment,
  [668149] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23151), 1,
      anon_sym_RBRACE,
    STATE(17484), 2,
      sym_comment,
      sym_block_comment,
  [668163] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23153), 1,
      sym__outdent,
    STATE(17485), 2,
      sym_comment,
      sym_block_comment,
  [668177] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23155), 1,
      anon_sym_RPAREN,
    STATE(17486), 2,
      sym_comment,
      sym_block_comment,
  [668191] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23157), 1,
      anon_sym_RPAREN,
    STATE(17487), 2,
      sym_comment,
      sym_block_comment,
  [668205] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23159), 1,
      sym__indent,
    STATE(17488), 2,
      sym_comment,
      sym_block_comment,
  [668219] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23161), 1,
      anon_sym_RBRACE,
    STATE(17489), 2,
      sym_comment,
      sym_block_comment,
  [668233] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23163), 1,
      sym__outdent,
    STATE(17490), 2,
      sym_comment,
      sym_block_comment,
  [668247] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23165), 1,
      sym__indent,
    STATE(17491), 2,
      sym_comment,
      sym_block_comment,
  [668261] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23167), 1,
      anon_sym_RPAREN,
    STATE(17492), 2,
      sym_comment,
      sym_block_comment,
  [668275] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23169), 1,
      anon_sym_do,
    STATE(17493), 2,
      sym_comment,
      sym_block_comment,
  [668289] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23171), 1,
      sym__indent,
    STATE(17494), 2,
      sym_comment,
      sym_block_comment,
  [668303] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23173), 1,
      anon_sym_else,
    STATE(17495), 2,
      sym_comment,
      sym_block_comment,
  [668317] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23175), 1,
      anon_sym_RPAREN,
    STATE(17496), 2,
      sym_comment,
      sym_block_comment,
  [668331] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8148), 1,
      anon_sym_type,
    STATE(17497), 2,
      sym_comment,
      sym_block_comment,
  [668345] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23177), 1,
      anon_sym_do,
    STATE(17498), 2,
      sym_comment,
      sym_block_comment,
  [668359] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23179), 1,
      sym__outdent,
    STATE(17499), 2,
      sym_comment,
      sym_block_comment,
  [668373] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23181), 1,
      sym__indent,
    STATE(17500), 2,
      sym_comment,
      sym_block_comment,
  [668387] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23183), 1,
      anon_sym_COLON,
    STATE(17501), 2,
      sym_comment,
      sym_block_comment,
  [668401] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23151), 1,
      anon_sym_RBRACK,
    STATE(17502), 2,
      sym_comment,
      sym_block_comment,
  [668415] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23185), 1,
      sym__outdent,
    STATE(17503), 2,
      sym_comment,
      sym_block_comment,
  [668429] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23187), 1,
      sym__outdent,
    STATE(17504), 2,
      sym_comment,
      sym_block_comment,
  [668443] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23189), 1,
      anon_sym_RBRACE,
    STATE(17505), 2,
      sym_comment,
      sym_block_comment,
  [668457] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23191), 1,
      sym__indent,
    STATE(17506), 2,
      sym_comment,
      sym_block_comment,
  [668471] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23193), 1,
      anon_sym_RPAREN,
    STATE(17507), 2,
      sym_comment,
      sym_block_comment,
  [668485] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23195), 1,
      sym__outdent,
    STATE(17508), 2,
      sym_comment,
      sym_block_comment,
  [668499] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23197), 1,
      anon_sym_RPAREN,
    STATE(17509), 2,
      sym_comment,
      sym_block_comment,
  [668513] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23199), 1,
      anon_sym_RBRACE,
    STATE(17510), 2,
      sym_comment,
      sym_block_comment,
  [668527] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23201), 1,
      anon_sym_RPAREN,
    STATE(17511), 2,
      sym_comment,
      sym_block_comment,
  [668541] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23203), 1,
      sym__indent,
    STATE(17512), 2,
      sym_comment,
      sym_block_comment,
  [668555] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23205), 1,
      anon_sym_EQ_GT,
    STATE(17513), 2,
      sym_comment,
      sym_block_comment,
  [668569] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23207), 1,
      anon_sym_RPAREN,
    STATE(17514), 2,
      sym_comment,
      sym_block_comment,
  [668583] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23209), 1,
      anon_sym_with,
    STATE(17515), 2,
      sym_comment,
      sym_block_comment,
  [668597] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23211), 1,
      sym__outdent,
    STATE(17516), 2,
      sym_comment,
      sym_block_comment,
  [668611] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23213), 1,
      sym__outdent,
    STATE(17517), 2,
      sym_comment,
      sym_block_comment,
  [668625] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23215), 1,
      sym__indent,
    STATE(17518), 2,
      sym_comment,
      sym_block_comment,
  [668639] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23217), 1,
      anon_sym_EQ_GT_GT,
    STATE(17519), 2,
      sym_comment,
      sym_block_comment,
  [668653] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23219), 1,
      anon_sym_RBRACE,
    STATE(17520), 2,
      sym_comment,
      sym_block_comment,
  [668667] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12125), 1,
      anon_sym_DOT,
    STATE(17521), 2,
      sym_comment,
      sym_block_comment,
  [668681] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23219), 1,
      anon_sym_RPAREN,
    STATE(17522), 2,
      sym_comment,
      sym_block_comment,
  [668695] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23221), 1,
      anon_sym_EQ_GT_GT,
    STATE(17523), 2,
      sym_comment,
      sym_block_comment,
  [668709] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23223), 1,
      sym__indent,
    STATE(17524), 2,
      sym_comment,
      sym_block_comment,
  [668723] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23225), 1,
      anon_sym_EQ_GT_GT,
    STATE(17525), 2,
      sym_comment,
      sym_block_comment,
  [668737] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23227), 1,
      anon_sym_EQ_GT_GT,
    STATE(17526), 2,
      sym_comment,
      sym_block_comment,
  [668751] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23229), 1,
      anon_sym_RPAREN,
    STATE(17527), 2,
      sym_comment,
      sym_block_comment,
  [668765] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23231), 1,
      anon_sym_RPAREN,
    STATE(17528), 2,
      sym_comment,
      sym_block_comment,
  [668779] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23233), 1,
      sym__outdent,
    STATE(17529), 2,
      sym_comment,
      sym_block_comment,
  [668793] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23235), 1,
      sym__indent,
    STATE(17530), 2,
      sym_comment,
      sym_block_comment,
  [668807] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23199), 1,
      anon_sym_RBRACK,
    STATE(17531), 2,
      sym_comment,
      sym_block_comment,
  [668821] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23237), 1,
      sym__outdent,
    STATE(17532), 2,
      sym_comment,
      sym_block_comment,
  [668835] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23239), 1,
      anon_sym_else,
    STATE(17533), 2,
      sym_comment,
      sym_block_comment,
  [668849] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16714), 1,
      anon_sym_COLON,
    STATE(17534), 2,
      sym_comment,
      sym_block_comment,
  [668863] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11712), 1,
      anon_sym_DOT,
    STATE(17535), 2,
      sym_comment,
      sym_block_comment,
  [668877] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23241), 1,
      sym__indent,
    STATE(17536), 2,
      sym_comment,
      sym_block_comment,
  [668891] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23243), 1,
      anon_sym_do,
    STATE(17537), 2,
      sym_comment,
      sym_block_comment,
  [668905] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20983), 1,
      anon_sym_RBRACE,
    STATE(17538), 2,
      sym_comment,
      sym_block_comment,
  [668919] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23245), 1,
      anon_sym_RPAREN,
    STATE(17539), 2,
      sym_comment,
      sym_block_comment,
  [668933] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23247), 1,
      anon_sym_then,
    STATE(17540), 2,
      sym_comment,
      sym_block_comment,
  [668947] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23249), 1,
      sym__outdent,
    STATE(17541), 2,
      sym_comment,
      sym_block_comment,
  [668961] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23251), 1,
      sym__indent,
    STATE(17542), 2,
      sym_comment,
      sym_block_comment,
  [668975] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23253), 1,
      anon_sym_RBRACE,
    STATE(17543), 2,
      sym_comment,
      sym_block_comment,
  [668989] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23255), 1,
      anon_sym_else,
    STATE(17544), 2,
      sym_comment,
      sym_block_comment,
  [669003] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23257), 1,
      anon_sym_do,
    STATE(17545), 2,
      sym_comment,
      sym_block_comment,
  [669017] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23259), 1,
      anon_sym_RBRACE,
    STATE(17546), 2,
      sym_comment,
      sym_block_comment,
  [669031] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23261), 1,
      sym__outdent,
    STATE(17547), 2,
      sym_comment,
      sym_block_comment,
  [669045] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23263), 1,
      sym__indent,
    STATE(17548), 2,
      sym_comment,
      sym_block_comment,
  [669059] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23265), 1,
      anon_sym_RPAREN,
    STATE(17549), 2,
      sym_comment,
      sym_block_comment,
  [669073] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23267), 1,
      anon_sym_RPAREN,
    STATE(17550), 2,
      sym_comment,
      sym_block_comment,
  [669087] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23269), 1,
      sym__outdent,
    STATE(17551), 2,
      sym_comment,
      sym_block_comment,
  [669101] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23271), 1,
      sym__outdent,
    STATE(17552), 2,
      sym_comment,
      sym_block_comment,
  [669115] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23273), 1,
      anon_sym_do,
    STATE(17553), 2,
      sym_comment,
      sym_block_comment,
  [669129] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23275), 1,
      sym__indent,
    STATE(17554), 2,
      sym_comment,
      sym_block_comment,
  [669143] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23277), 1,
      anon_sym_else,
    STATE(17555), 2,
      sym_comment,
      sym_block_comment,
  [669157] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23279), 1,
      anon_sym_RBRACE,
    STATE(17556), 2,
      sym_comment,
      sym_block_comment,
  [669171] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23281), 1,
      sym__outdent,
    STATE(17557), 2,
      sym_comment,
      sym_block_comment,
  [669185] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23283), 1,
      anon_sym_RPAREN,
    STATE(17558), 2,
      sym_comment,
      sym_block_comment,
  [669199] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23285), 1,
      anon_sym_else,
    STATE(17559), 2,
      sym_comment,
      sym_block_comment,
  [669213] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23287), 1,
      sym__indent,
    STATE(17560), 2,
      sym_comment,
      sym_block_comment,
  [669227] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23289), 1,
      anon_sym_LPAREN,
    STATE(17561), 2,
      sym_comment,
      sym_block_comment,
  [669241] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23291), 1,
      sym__outdent,
    STATE(17562), 2,
      sym_comment,
      sym_block_comment,
  [669255] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23293), 1,
      anon_sym_else,
    STATE(17563), 2,
      sym_comment,
      sym_block_comment,
  [669269] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23295), 1,
      anon_sym_else,
    STATE(17564), 2,
      sym_comment,
      sym_block_comment,
  [669283] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23297), 1,
      anon_sym_RBRACE,
    STATE(17565), 2,
      sym_comment,
      sym_block_comment,
  [669297] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23299), 1,
      sym__indent,
    STATE(17566), 2,
      sym_comment,
      sym_block_comment,
  [669311] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23301), 1,
      anon_sym_RPAREN,
    STATE(17567), 2,
      sym_comment,
      sym_block_comment,
  [669325] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23303), 1,
      anon_sym_RBRACE,
    STATE(17568), 2,
      sym_comment,
      sym_block_comment,
  [669339] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23305), 1,
      anon_sym_RBRACE,
    STATE(17569), 2,
      sym_comment,
      sym_block_comment,
  [669353] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23307), 1,
      anon_sym_RPAREN,
    STATE(17570), 2,
      sym_comment,
      sym_block_comment,
  [669367] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23309), 1,
      sym__outdent,
    STATE(17571), 2,
      sym_comment,
      sym_block_comment,
  [669381] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23311), 1,
      sym__indent,
    STATE(17572), 2,
      sym_comment,
      sym_block_comment,
  [669395] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23313), 1,
      anon_sym_EQ_GT,
    STATE(17573), 2,
      sym_comment,
      sym_block_comment,
  [669409] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23315), 1,
      anon_sym_RPAREN,
    STATE(17574), 2,
      sym_comment,
      sym_block_comment,
  [669423] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23317), 1,
      sym__outdent,
    STATE(17575), 2,
      sym_comment,
      sym_block_comment,
  [669437] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11900), 1,
      anon_sym_with,
    STATE(17576), 2,
      sym_comment,
      sym_block_comment,
  [669451] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23319), 1,
      sym__outdent,
    STATE(17577), 2,
      sym_comment,
      sym_block_comment,
  [669465] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23321), 1,
      sym__indent,
    STATE(17578), 2,
      sym_comment,
      sym_block_comment,
  [669479] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23323), 1,
      sym__outdent,
    STATE(17579), 2,
      sym_comment,
      sym_block_comment,
  [669493] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23325), 1,
      anon_sym_EQ_GT_GT,
    STATE(17580), 2,
      sym_comment,
      sym_block_comment,
  [669507] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23327), 1,
      anon_sym_RBRACE,
    STATE(17581), 2,
      sym_comment,
      sym_block_comment,
  [669521] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23329), 1,
      anon_sym_EQ_GT_GT,
    STATE(17582), 2,
      sym_comment,
      sym_block_comment,
  [669535] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23331), 1,
      anon_sym_EQ_GT_GT,
    STATE(17583), 2,
      sym_comment,
      sym_block_comment,
  [669549] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23333), 1,
      sym__indent,
    STATE(17584), 2,
      sym_comment,
      sym_block_comment,
  [669563] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23335), 1,
      anon_sym_EQ_GT_GT,
    STATE(17585), 2,
      sym_comment,
      sym_block_comment,
  [669577] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23297), 1,
      anon_sym_RPAREN,
    STATE(17586), 2,
      sym_comment,
      sym_block_comment,
  [669591] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23337), 1,
      anon_sym_LPAREN,
    STATE(17587), 2,
      sym_comment,
      sym_block_comment,
  [669605] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23339), 1,
      sym__outdent,
    STATE(17588), 2,
      sym_comment,
      sym_block_comment,
  [669619] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23341), 1,
      anon_sym_do,
    STATE(17589), 2,
      sym_comment,
      sym_block_comment,
  [669633] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23343), 1,
      sym__indent,
    STATE(17590), 2,
      sym_comment,
      sym_block_comment,
  [669647] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23345), 1,
      sym__outdent,
    STATE(17591), 2,
      sym_comment,
      sym_block_comment,
  [669661] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23347), 1,
      anon_sym_COLON,
    STATE(17592), 2,
      sym_comment,
      sym_block_comment,
  [669675] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10460), 1,
      anon_sym_DOT,
    STATE(17593), 2,
      sym_comment,
      sym_block_comment,
  [669689] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23349), 1,
      anon_sym_RPAREN,
    STATE(17594), 2,
      sym_comment,
      sym_block_comment,
  [669703] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23351), 1,
      anon_sym_type,
    STATE(17595), 2,
      sym_comment,
      sym_block_comment,
  [669717] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23353), 1,
      sym__indent,
    STATE(17596), 2,
      sym_comment,
      sym_block_comment,
  [669731] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23355), 1,
      anon_sym_RBRACE,
    STATE(17597), 2,
      sym_comment,
      sym_block_comment,
  [669745] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23357), 1,
      sym__outdent,
    STATE(17598), 2,
      sym_comment,
      sym_block_comment,
  [669759] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23359), 1,
      anon_sym_else,
    STATE(17599), 2,
      sym_comment,
      sym_block_comment,
  [669773] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23361), 1,
      anon_sym_RBRACE,
    STATE(17600), 2,
      sym_comment,
      sym_block_comment,
  [669787] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23363), 1,
      anon_sym_RPAREN,
    STATE(17601), 2,
      sym_comment,
      sym_block_comment,
  [669801] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23365), 1,
      sym__indent,
    STATE(17602), 2,
      sym_comment,
      sym_block_comment,
  [669815] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23367), 1,
      sym__outdent,
    STATE(17603), 2,
      sym_comment,
      sym_block_comment,
  [669829] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23369), 1,
      sym__outdent,
    STATE(17604), 2,
      sym_comment,
      sym_block_comment,
  [669843] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23371), 1,
      anon_sym_else,
    STATE(17605), 2,
      sym_comment,
      sym_block_comment,
  [669857] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23373), 1,
      anon_sym_RBRACE,
    STATE(17606), 2,
      sym_comment,
      sym_block_comment,
  [669871] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23375), 1,
      anon_sym_RPAREN,
    STATE(17607), 2,
      sym_comment,
      sym_block_comment,
  [669885] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23377), 1,
      sym__indent,
    STATE(17608), 2,
      sym_comment,
      sym_block_comment,
  [669899] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23379), 1,
      sym__outdent,
    STATE(17609), 2,
      sym_comment,
      sym_block_comment,
  [669913] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23355), 1,
      anon_sym_RBRACK,
    STATE(17610), 2,
      sym_comment,
      sym_block_comment,
  [669927] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23381), 1,
      anon_sym_RBRACE,
    STATE(17611), 2,
      sym_comment,
      sym_block_comment,
  [669941] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23381), 1,
      anon_sym_RPAREN,
    STATE(17612), 2,
      sym_comment,
      sym_block_comment,
  [669955] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23383), 1,
      sym__indent,
    STATE(17613), 2,
      sym_comment,
      sym_block_comment,
  [669969] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23385), 1,
      anon_sym_do,
    STATE(17614), 2,
      sym_comment,
      sym_block_comment,
  [669983] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23387), 1,
      anon_sym_else,
    STATE(17615), 2,
      sym_comment,
      sym_block_comment,
  [669997] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22945), 1,
      anon_sym_RPAREN,
    STATE(17616), 2,
      sym_comment,
      sym_block_comment,
  [670011] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22701), 1,
      anon_sym_RBRACE,
    STATE(17617), 2,
      sym_comment,
      sym_block_comment,
  [670025] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23389), 1,
      sym__outdent,
    STATE(17618), 2,
      sym_comment,
      sym_block_comment,
  [670039] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23391), 1,
      sym__indent,
    STATE(17619), 2,
      sym_comment,
      sym_block_comment,
  [670053] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15349), 1,
      anon_sym_type,
    STATE(17620), 2,
      sym_comment,
      sym_block_comment,
  [670067] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23393), 1,
      anon_sym_RPAREN,
    STATE(17621), 2,
      sym_comment,
      sym_block_comment,
  [670081] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23395), 1,
      anon_sym_EQ_GT,
    STATE(17622), 2,
      sym_comment,
      sym_block_comment,
  [670095] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23397), 1,
      sym__outdent,
    STATE(17623), 2,
      sym_comment,
      sym_block_comment,
  [670109] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23399), 1,
      anon_sym_RBRACE,
    STATE(17624), 2,
      sym_comment,
      sym_block_comment,
  [670123] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23401), 1,
      sym__indent,
    STATE(17625), 2,
      sym_comment,
      sym_block_comment,
  [670137] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23403), 1,
      anon_sym_RPAREN,
    STATE(17626), 2,
      sym_comment,
      sym_block_comment,
  [670151] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23279), 1,
      anon_sym_RPAREN,
    STATE(17627), 2,
      sym_comment,
      sym_block_comment,
  [670165] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23405), 1,
      anon_sym_else,
    STATE(17628), 2,
      sym_comment,
      sym_block_comment,
  [670179] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23407), 1,
      anon_sym_EQ_GT,
    STATE(17629), 2,
      sym_comment,
      sym_block_comment,
  [670193] = 4,
    ACTIONS(17667), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(17673), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23409), 1,
      sym_using_directive_value,
    STATE(17630), 2,
      sym_comment,
      sym_block_comment,
  [670207] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23411), 1,
      sym__indent,
    STATE(17631), 2,
      sym_comment,
      sym_block_comment,
  [670221] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23413), 1,
      sym__outdent,
    STATE(17632), 2,
      sym_comment,
      sym_block_comment,
  [670235] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23415), 1,
      anon_sym_EQ_GT,
    STATE(17633), 2,
      sym_comment,
      sym_block_comment,
  [670249] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23417), 1,
      anon_sym_RPAREN,
    STATE(17634), 2,
      sym_comment,
      sym_block_comment,
  [670263] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23373), 1,
      anon_sym_RBRACK,
    STATE(17635), 2,
      sym_comment,
      sym_block_comment,
  [670277] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23419), 1,
      anon_sym_else,
    STATE(17636), 2,
      sym_comment,
      sym_block_comment,
  [670291] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23421), 1,
      sym__indent,
    STATE(17637), 2,
      sym_comment,
      sym_block_comment,
  [670305] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23399), 1,
      anon_sym_RBRACK,
    STATE(17638), 2,
      sym_comment,
      sym_block_comment,
  [670319] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23423), 1,
      anon_sym_else,
    STATE(17639), 2,
      sym_comment,
      sym_block_comment,
  [670333] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23425), 1,
      anon_sym_EQ_GT_GT,
    STATE(17640), 2,
      sym_comment,
      sym_block_comment,
  [670347] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23427), 1,
      anon_sym_RBRACE,
    STATE(17641), 2,
      sym_comment,
      sym_block_comment,
  [670361] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23429), 1,
      sym__outdent,
    STATE(17642), 2,
      sym_comment,
      sym_block_comment,
  [670375] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23431), 1,
      sym__indent,
    STATE(17643), 2,
      sym_comment,
      sym_block_comment,
  [670389] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23433), 1,
      anon_sym_EQ_GT_GT,
    STATE(17644), 2,
      sym_comment,
      sym_block_comment,
  [670403] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23435), 1,
      anon_sym_EQ_GT_GT,
    STATE(17645), 2,
      sym_comment,
      sym_block_comment,
  [670417] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23437), 1,
      anon_sym_EQ_GT_GT,
    STATE(17646), 2,
      sym_comment,
      sym_block_comment,
  [670431] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23439), 1,
      anon_sym_RPAREN,
    STATE(17647), 2,
      sym_comment,
      sym_block_comment,
  [670445] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23441), 1,
      sym__outdent,
    STATE(17648), 2,
      sym_comment,
      sym_block_comment,
  [670459] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23443), 1,
      sym__indent,
    STATE(17649), 2,
      sym_comment,
      sym_block_comment,
  [670473] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23445), 1,
      anon_sym_RPAREN,
    STATE(17650), 2,
      sym_comment,
      sym_block_comment,
  [670487] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23113), 1,
      anon_sym_RPAREN,
    STATE(17651), 2,
      sym_comment,
      sym_block_comment,
  [670501] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23447), 1,
      anon_sym_RBRACE,
    STATE(17652), 2,
      sym_comment,
      sym_block_comment,
  [670515] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23449), 1,
      anon_sym_RBRACE,
    STATE(17653), 2,
      sym_comment,
      sym_block_comment,
  [670529] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23451), 1,
      anon_sym_else,
    STATE(17654), 2,
      sym_comment,
      sym_block_comment,
  [670543] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23453), 1,
      sym__indent,
    STATE(17655), 2,
      sym_comment,
      sym_block_comment,
  [670557] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23455), 1,
      sym__outdent,
    STATE(17656), 2,
      sym_comment,
      sym_block_comment,
  [670571] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23457), 1,
      anon_sym_do,
    STATE(17657), 2,
      sym_comment,
      sym_block_comment,
  [670585] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23459), 1,
      anon_sym_do,
    STATE(17658), 2,
      sym_comment,
      sym_block_comment,
  [670599] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23461), 1,
      anon_sym_COLON,
    STATE(17659), 2,
      sym_comment,
      sym_block_comment,
  [670613] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16043), 1,
      anon_sym_DOT,
    STATE(17660), 2,
      sym_comment,
      sym_block_comment,
  [670627] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23463), 1,
      sym__indent,
    STATE(17661), 2,
      sym_comment,
      sym_block_comment,
  [670641] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23465), 1,
      anon_sym_RBRACE,
    STATE(17662), 2,
      sym_comment,
      sym_block_comment,
  [670655] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23467), 1,
      sym__outdent,
    STATE(17663), 2,
      sym_comment,
      sym_block_comment,
  [670669] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23469), 1,
      sym__outdent,
    STATE(17664), 2,
      sym_comment,
      sym_block_comment,
  [670683] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23449), 1,
      anon_sym_RBRACK,
    STATE(17665), 2,
      sym_comment,
      sym_block_comment,
  [670697] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23471), 1,
      sym__outdent,
    STATE(17666), 2,
      sym_comment,
      sym_block_comment,
  [670711] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23473), 1,
      sym__indent,
    STATE(17667), 2,
      sym_comment,
      sym_block_comment,
  [670725] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23475), 1,
      anon_sym_RBRACE,
    STATE(17668), 2,
      sym_comment,
      sym_block_comment,
  [670739] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23477), 1,
      anon_sym_RPAREN,
    STATE(17669), 2,
      sym_comment,
      sym_block_comment,
  [670753] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23479), 1,
      anon_sym_do,
    STATE(17670), 2,
      sym_comment,
      sym_block_comment,
  [670767] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23481), 1,
      anon_sym_RBRACE,
    STATE(17671), 2,
      sym_comment,
      sym_block_comment,
  [670781] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23483), 1,
      anon_sym_RBRACE,
    STATE(17672), 2,
      sym_comment,
      sym_block_comment,
  [670795] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23485), 1,
      sym__indent,
    STATE(17673), 2,
      sym_comment,
      sym_block_comment,
  [670809] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23465), 1,
      anon_sym_RPAREN,
    STATE(17674), 2,
      sym_comment,
      sym_block_comment,
  [670823] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23487), 1,
      anon_sym_RPAREN,
    STATE(17675), 2,
      sym_comment,
      sym_block_comment,
  [670837] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23489), 1,
      anon_sym_RPAREN,
    STATE(17676), 2,
      sym_comment,
      sym_block_comment,
  [670851] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23491), 1,
      sym__outdent,
    STATE(17677), 2,
      sym_comment,
      sym_block_comment,
  [670865] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23493), 1,
      sym__outdent,
    STATE(17678), 2,
      sym_comment,
      sym_block_comment,
  [670879] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23495), 1,
      sym__indent,
    STATE(17679), 2,
      sym_comment,
      sym_block_comment,
  [670893] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23481), 1,
      anon_sym_RPAREN,
    STATE(17680), 2,
      sym_comment,
      sym_block_comment,
  [670907] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23497), 1,
      anon_sym_RPAREN,
    STATE(17681), 2,
      sym_comment,
      sym_block_comment,
  [670921] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23499), 1,
      sym__outdent,
    STATE(17682), 2,
      sym_comment,
      sym_block_comment,
  [670935] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23501), 1,
      anon_sym_RBRACE,
    STATE(17683), 2,
      sym_comment,
      sym_block_comment,
  [670949] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23501), 1,
      anon_sym_RBRACK,
    STATE(17684), 2,
      sym_comment,
      sym_block_comment,
  [670963] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23503), 1,
      sym__indent,
    STATE(17685), 2,
      sym_comment,
      sym_block_comment,
  [670977] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23505), 1,
      anon_sym_RBRACE,
    STATE(17686), 2,
      sym_comment,
      sym_block_comment,
  [670991] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23507), 1,
      anon_sym_do,
    STATE(17687), 2,
      sym_comment,
      sym_block_comment,
  [671005] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23505), 1,
      anon_sym_RBRACK,
    STATE(17688), 2,
      sym_comment,
      sym_block_comment,
  [671019] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23509), 1,
      anon_sym_RBRACE,
    STATE(17689), 2,
      sym_comment,
      sym_block_comment,
  [671033] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23511), 1,
      anon_sym_RBRACE,
    STATE(17690), 2,
      sym_comment,
      sym_block_comment,
  [671047] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23513), 1,
      sym__indent,
    STATE(17691), 2,
      sym_comment,
      sym_block_comment,
  [671061] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23515), 1,
      anon_sym_EQ_GT,
    STATE(17692), 2,
      sym_comment,
      sym_block_comment,
  [671075] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23517), 1,
      anon_sym_RPAREN,
    STATE(17693), 2,
      sym_comment,
      sym_block_comment,
  [671089] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23509), 1,
      anon_sym_RBRACK,
    STATE(17694), 2,
      sym_comment,
      sym_block_comment,
  [671103] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23519), 1,
      anon_sym_EQ_GT_GT,
    STATE(17695), 2,
      sym_comment,
      sym_block_comment,
  [671117] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23521), 1,
      sym__outdent,
    STATE(17696), 2,
      sym_comment,
      sym_block_comment,
  [671131] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23523), 1,
      sym__indent,
    STATE(17697), 2,
      sym_comment,
      sym_block_comment,
  [671145] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23525), 1,
      anon_sym_RBRACE,
    STATE(17698), 2,
      sym_comment,
      sym_block_comment,
  [671159] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23527), 1,
      anon_sym_RPAREN,
    STATE(17699), 2,
      sym_comment,
      sym_block_comment,
  [671173] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23529), 1,
      anon_sym_EQ_GT_GT,
    STATE(17700), 2,
      sym_comment,
      sym_block_comment,
  [671187] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23531), 1,
      anon_sym_EQ_GT_GT,
    STATE(17701), 2,
      sym_comment,
      sym_block_comment,
  [671201] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23533), 1,
      anon_sym_do,
    STATE(17702), 2,
      sym_comment,
      sym_block_comment,
  [671215] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23535), 1,
      sym__indent,
    STATE(17703), 2,
      sym_comment,
      sym_block_comment,
  [671229] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23537), 1,
      anon_sym_EQ_GT_GT,
    STATE(17704), 2,
      sym_comment,
      sym_block_comment,
  [671243] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23539), 1,
      anon_sym_RPAREN,
    STATE(17705), 2,
      sym_comment,
      sym_block_comment,
  [671257] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23541), 1,
      sym__outdent,
    STATE(17706), 2,
      sym_comment,
      sym_block_comment,
  [671271] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23543), 1,
      anon_sym_RPAREN,
    STATE(17707), 2,
      sym_comment,
      sym_block_comment,
  [671285] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23545), 1,
      sym__indent,
    STATE(17708), 2,
      sym_comment,
      sym_block_comment,
  [671299] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23547), 1,
      anon_sym_RPAREN,
    STATE(17709), 2,
      sym_comment,
      sym_block_comment,
  [671313] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23549), 1,
      anon_sym_COLON,
    STATE(17710), 2,
      sym_comment,
      sym_block_comment,
  [671327] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(17711), 2,
      sym_comment,
      sym_block_comment,
  [671341] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23551), 1,
      sym__outdent,
    STATE(17712), 2,
      sym_comment,
      sym_block_comment,
  [671355] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23553), 1,
      sym__indent,
    STATE(17713), 2,
      sym_comment,
      sym_block_comment,
  [671369] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23555), 1,
      sym__outdent,
    STATE(17714), 2,
      sym_comment,
      sym_block_comment,
  [671383] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23557), 1,
      anon_sym_RBRACE,
    STATE(17715), 2,
      sym_comment,
      sym_block_comment,
  [671397] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23559), 1,
      anon_sym_RPAREN,
    STATE(17716), 2,
      sym_comment,
      sym_block_comment,
  [671411] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23557), 1,
      anon_sym_RPAREN,
    STATE(17717), 2,
      sym_comment,
      sym_block_comment,
  [671425] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23561), 1,
      sym__indent,
    STATE(17718), 2,
      sym_comment,
      sym_block_comment,
  [671439] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23563), 1,
      sym__outdent,
    STATE(17719), 2,
      sym_comment,
      sym_block_comment,
  [671453] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23565), 1,
      anon_sym_RPAREN,
    STATE(17720), 2,
      sym_comment,
      sym_block_comment,
  [671467] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23567), 1,
      sym__outdent,
    STATE(17721), 2,
      sym_comment,
      sym_block_comment,
  [671481] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23569), 1,
      anon_sym_RPAREN,
    STATE(17722), 2,
      sym_comment,
      sym_block_comment,
  [671495] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23571), 1,
      sym__indent,
    STATE(17723), 2,
      sym_comment,
      sym_block_comment,
  [671509] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23573), 1,
      sym__outdent,
    STATE(17724), 2,
      sym_comment,
      sym_block_comment,
  [671523] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23575), 1,
      anon_sym_RPAREN,
    STATE(17725), 2,
      sym_comment,
      sym_block_comment,
  [671537] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23577), 1,
      anon_sym_EQ_GT,
    STATE(17726), 2,
      sym_comment,
      sym_block_comment,
  [671551] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23579), 1,
      sym__outdent,
    STATE(17727), 2,
      sym_comment,
      sym_block_comment,
  [671565] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23581), 1,
      sym__indent,
    STATE(17728), 2,
      sym_comment,
      sym_block_comment,
  [671579] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23583), 1,
      sym__outdent,
    STATE(17729), 2,
      sym_comment,
      sym_block_comment,
  [671593] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23585), 1,
      sym__outdent,
    STATE(17730), 2,
      sym_comment,
      sym_block_comment,
  [671607] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23587), 1,
      anon_sym_RBRACE,
    STATE(17731), 2,
      sym_comment,
      sym_block_comment,
  [671621] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23589), 1,
      sym__outdent,
    STATE(17732), 2,
      sym_comment,
      sym_block_comment,
  [671635] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23591), 1,
      sym__indent,
    STATE(17733), 2,
      sym_comment,
      sym_block_comment,
  [671649] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21411), 1,
      anon_sym_RBRACE,
    STATE(17734), 2,
      sym_comment,
      sym_block_comment,
  [671663] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23593), 1,
      anon_sym_else,
    STATE(17735), 2,
      sym_comment,
      sym_block_comment,
  [671677] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23595), 1,
      anon_sym_else,
    STATE(17736), 2,
      sym_comment,
      sym_block_comment,
  [671691] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23597), 1,
      anon_sym_else,
    STATE(17737), 2,
      sym_comment,
      sym_block_comment,
  [671705] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23599), 1,
      sym__indent,
    STATE(17738), 2,
      sym_comment,
      sym_block_comment,
  [671719] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23601), 1,
      anon_sym_type,
    STATE(17739), 2,
      sym_comment,
      sym_block_comment,
  [671733] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23603), 1,
      anon_sym_RPAREN,
    STATE(17740), 2,
      sym_comment,
      sym_block_comment,
  [671747] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23605), 1,
      sym__outdent,
    STATE(17741), 2,
      sym_comment,
      sym_block_comment,
  [671761] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23607), 1,
      anon_sym_else,
    STATE(17742), 2,
      sym_comment,
      sym_block_comment,
  [671775] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23609), 1,
      sym__indent,
    STATE(17743), 2,
      sym_comment,
      sym_block_comment,
  [671789] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23611), 1,
      anon_sym_LPAREN,
    STATE(17744), 2,
      sym_comment,
      sym_block_comment,
  [671803] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23613), 1,
      anon_sym_EQ_GT,
    STATE(17745), 2,
      sym_comment,
      sym_block_comment,
  [671817] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23615), 1,
      anon_sym_RPAREN,
    STATE(17746), 2,
      sym_comment,
      sym_block_comment,
  [671831] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23617), 1,
      sym__outdent,
    STATE(17747), 2,
      sym_comment,
      sym_block_comment,
  [671845] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23619), 1,
      sym__indent,
    STATE(17748), 2,
      sym_comment,
      sym_block_comment,
  [671859] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23621), 1,
      anon_sym_EQ_GT_GT,
    STATE(17749), 2,
      sym_comment,
      sym_block_comment,
  [671873] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23623), 1,
      anon_sym_RPAREN,
    STATE(17750), 2,
      sym_comment,
      sym_block_comment,
  [671887] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23625), 1,
      anon_sym_RBRACE,
    STATE(17751), 2,
      sym_comment,
      sym_block_comment,
  [671901] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23627), 1,
      sym__outdent,
    STATE(17752), 2,
      sym_comment,
      sym_block_comment,
  [671915] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23629), 1,
      sym__indent,
    STATE(17753), 2,
      sym_comment,
      sym_block_comment,
  [671929] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23631), 1,
      anon_sym_EQ_GT_GT,
    STATE(17754), 2,
      sym_comment,
      sym_block_comment,
  [671943] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23633), 1,
      anon_sym_EQ_GT_GT,
    STATE(17755), 2,
      sym_comment,
      sym_block_comment,
  [671957] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23635), 1,
      anon_sym_EQ_GT_GT,
    STATE(17756), 2,
      sym_comment,
      sym_block_comment,
  [671971] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23637), 1,
      anon_sym_RBRACE,
    STATE(17757), 2,
      sym_comment,
      sym_block_comment,
  [671985] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23639), 1,
      sym__indent,
    STATE(17758), 2,
      sym_comment,
      sym_block_comment,
  [671999] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23641), 1,
      sym__indent,
    STATE(17759), 2,
      sym_comment,
      sym_block_comment,
  [672013] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23643), 1,
      sym__indent,
    STATE(17760), 2,
      sym_comment,
      sym_block_comment,
  [672027] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23645), 1,
      sym__indent,
    STATE(17761), 2,
      sym_comment,
      sym_block_comment,
  [672041] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23647), 1,
      sym__indent,
    STATE(17762), 2,
      sym_comment,
      sym_block_comment,
  [672055] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23649), 1,
      sym__indent,
    STATE(17763), 2,
      sym_comment,
      sym_block_comment,
  [672069] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23651), 1,
      sym__indent,
    STATE(17764), 2,
      sym_comment,
      sym_block_comment,
  [672083] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23653), 1,
      sym__indent,
    STATE(17765), 2,
      sym_comment,
      sym_block_comment,
  [672097] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23655), 1,
      sym__indent,
    STATE(17766), 2,
      sym_comment,
      sym_block_comment,
  [672111] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23657), 1,
      sym__indent,
    STATE(17767), 2,
      sym_comment,
      sym_block_comment,
  [672125] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23659), 1,
      sym__indent,
    STATE(17768), 2,
      sym_comment,
      sym_block_comment,
  [672139] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23661), 1,
      sym__indent,
    STATE(17769), 2,
      sym_comment,
      sym_block_comment,
  [672153] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23663), 1,
      sym__indent,
    STATE(17770), 2,
      sym_comment,
      sym_block_comment,
  [672167] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23665), 1,
      sym__indent,
    STATE(17771), 2,
      sym_comment,
      sym_block_comment,
  [672181] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23667), 1,
      sym__indent,
    STATE(17772), 2,
      sym_comment,
      sym_block_comment,
  [672195] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23669), 1,
      sym__indent,
    STATE(17773), 2,
      sym_comment,
      sym_block_comment,
  [672209] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23671), 1,
      sym__indent,
    STATE(17774), 2,
      sym_comment,
      sym_block_comment,
  [672223] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23673), 1,
      sym__indent,
    STATE(17775), 2,
      sym_comment,
      sym_block_comment,
  [672237] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23675), 1,
      sym__indent,
    STATE(17776), 2,
      sym_comment,
      sym_block_comment,
  [672251] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23677), 1,
      sym__indent,
    STATE(17777), 2,
      sym_comment,
      sym_block_comment,
  [672265] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23679), 1,
      sym__indent,
    STATE(17778), 2,
      sym_comment,
      sym_block_comment,
  [672279] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23681), 1,
      sym__indent,
    STATE(17779), 2,
      sym_comment,
      sym_block_comment,
  [672293] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23683), 1,
      sym__indent,
    STATE(17780), 2,
      sym_comment,
      sym_block_comment,
  [672307] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23685), 1,
      sym__indent,
    STATE(17781), 2,
      sym_comment,
      sym_block_comment,
  [672321] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23687), 1,
      sym__indent,
    STATE(17782), 2,
      sym_comment,
      sym_block_comment,
  [672335] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23689), 1,
      sym__indent,
    STATE(17783), 2,
      sym_comment,
      sym_block_comment,
  [672349] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23691), 1,
      sym__indent,
    STATE(17784), 2,
      sym_comment,
      sym_block_comment,
  [672363] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23693), 1,
      sym__indent,
    STATE(17785), 2,
      sym_comment,
      sym_block_comment,
  [672377] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23695), 1,
      sym__indent,
    STATE(17786), 2,
      sym_comment,
      sym_block_comment,
  [672391] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23697), 1,
      sym__indent,
    STATE(17787), 2,
      sym_comment,
      sym_block_comment,
  [672405] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23699), 1,
      sym__indent,
    STATE(17788), 2,
      sym_comment,
      sym_block_comment,
  [672419] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23701), 1,
      sym__indent,
    STATE(17789), 2,
      sym_comment,
      sym_block_comment,
  [672433] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23703), 1,
      sym__indent,
    STATE(17790), 2,
      sym_comment,
      sym_block_comment,
  [672447] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23705), 1,
      sym__indent,
    STATE(17791), 2,
      sym_comment,
      sym_block_comment,
  [672461] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23707), 1,
      sym__indent,
    STATE(17792), 2,
      sym_comment,
      sym_block_comment,
  [672475] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23709), 1,
      sym__indent,
    STATE(17793), 2,
      sym_comment,
      sym_block_comment,
  [672489] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23711), 1,
      sym__indent,
    STATE(17794), 2,
      sym_comment,
      sym_block_comment,
  [672503] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23713), 1,
      sym__indent,
    STATE(17795), 2,
      sym_comment,
      sym_block_comment,
  [672517] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23715), 1,
      sym__indent,
    STATE(17796), 2,
      sym_comment,
      sym_block_comment,
  [672531] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23717), 1,
      sym__indent,
    STATE(17797), 2,
      sym_comment,
      sym_block_comment,
  [672545] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23719), 1,
      sym__indent,
    STATE(17798), 2,
      sym_comment,
      sym_block_comment,
  [672559] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23721), 1,
      sym__indent,
    STATE(17799), 2,
      sym_comment,
      sym_block_comment,
  [672573] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23723), 1,
      sym__indent,
    STATE(17800), 2,
      sym_comment,
      sym_block_comment,
  [672587] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23725), 1,
      sym__indent,
    STATE(17801), 2,
      sym_comment,
      sym_block_comment,
  [672601] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23727), 1,
      sym__indent,
    STATE(17802), 2,
      sym_comment,
      sym_block_comment,
  [672615] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23729), 1,
      sym__indent,
    STATE(17803), 2,
      sym_comment,
      sym_block_comment,
  [672629] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23731), 1,
      sym__indent,
    STATE(17804), 2,
      sym_comment,
      sym_block_comment,
  [672643] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23733), 1,
      sym__indent,
    STATE(17805), 2,
      sym_comment,
      sym_block_comment,
  [672657] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23735), 1,
      sym__indent,
    STATE(17806), 2,
      sym_comment,
      sym_block_comment,
  [672671] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23737), 1,
      sym__indent,
    STATE(17807), 2,
      sym_comment,
      sym_block_comment,
  [672685] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23739), 1,
      sym__indent,
    STATE(17808), 2,
      sym_comment,
      sym_block_comment,
  [672699] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23741), 1,
      sym__indent,
    STATE(17809), 2,
      sym_comment,
      sym_block_comment,
  [672713] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23743), 1,
      anon_sym_else,
    STATE(17810), 2,
      sym_comment,
      sym_block_comment,
  [672727] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23745), 1,
      anon_sym_else,
    STATE(17811), 2,
      sym_comment,
      sym_block_comment,
  [672741] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23747), 1,
      anon_sym_RBRACE,
    STATE(17812), 2,
      sym_comment,
      sym_block_comment,
  [672755] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15643), 1,
      anon_sym_DOT,
    STATE(17813), 2,
      sym_comment,
      sym_block_comment,
  [672769] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23749), 1,
      anon_sym_RPAREN,
    STATE(17814), 2,
      sym_comment,
      sym_block_comment,
  [672783] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23751), 1,
      anon_sym_EQ,
    STATE(17815), 2,
      sym_comment,
      sym_block_comment,
  [672797] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23753), 1,
      anon_sym_else,
    STATE(17816), 2,
      sym_comment,
      sym_block_comment,
  [672811] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23755), 1,
      anon_sym_COLON,
    STATE(17817), 2,
      sym_comment,
      sym_block_comment,
  [672825] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23757), 1,
      anon_sym_RBRACE,
    STATE(17818), 2,
      sym_comment,
      sym_block_comment,
  [672839] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12705), 1,
      anon_sym_DOT,
    STATE(17819), 2,
      sym_comment,
      sym_block_comment,
  [672853] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23759), 1,
      anon_sym_RBRACE,
    STATE(17820), 2,
      sym_comment,
      sym_block_comment,
  [672867] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23761), 1,
      anon_sym_RPAREN,
    STATE(17821), 2,
      sym_comment,
      sym_block_comment,
  [672881] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23763), 1,
      anon_sym_do,
    STATE(17822), 2,
      sym_comment,
      sym_block_comment,
  [672895] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23765), 1,
      anon_sym_RPAREN,
    STATE(17823), 2,
      sym_comment,
      sym_block_comment,
  [672909] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23767), 1,
      anon_sym_EQ,
    STATE(17824), 2,
      sym_comment,
      sym_block_comment,
  [672923] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23769), 1,
      anon_sym_else,
    STATE(17825), 2,
      sym_comment,
      sym_block_comment,
  [672937] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23771), 1,
      sym__outdent,
    STATE(17826), 2,
      sym_comment,
      sym_block_comment,
  [672951] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23773), 1,
      anon_sym_RBRACE,
    STATE(17827), 2,
      sym_comment,
      sym_block_comment,
  [672965] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23775), 1,
      anon_sym_else,
    STATE(17828), 2,
      sym_comment,
      sym_block_comment,
  [672979] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23777), 1,
      anon_sym_RPAREN,
    STATE(17829), 2,
      sym_comment,
      sym_block_comment,
  [672993] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23779), 1,
      sym__outdent,
    STATE(17830), 2,
      sym_comment,
      sym_block_comment,
  [673007] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23781), 1,
      anon_sym_RBRACE,
    STATE(17831), 2,
      sym_comment,
      sym_block_comment,
  [673021] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23783), 1,
      anon_sym_RBRACE,
    STATE(17832), 2,
      sym_comment,
      sym_block_comment,
  [673035] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23783), 1,
      anon_sym_RPAREN,
    STATE(17833), 2,
      sym_comment,
      sym_block_comment,
  [673049] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8106), 1,
      anon_sym_type,
    STATE(17834), 2,
      sym_comment,
      sym_block_comment,
  [673063] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23785), 1,
      anon_sym_RBRACE,
    STATE(17835), 2,
      sym_comment,
      sym_block_comment,
  [673077] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23787), 1,
      anon_sym_RPAREN,
    STATE(17836), 2,
      sym_comment,
      sym_block_comment,
  [673091] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23789), 1,
      sym__outdent,
    STATE(17837), 2,
      sym_comment,
      sym_block_comment,
  [673105] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23759), 1,
      anon_sym_RPAREN,
    STATE(17838), 2,
      sym_comment,
      sym_block_comment,
  [673119] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23791), 1,
      sym__outdent,
    STATE(17839), 2,
      sym_comment,
      sym_block_comment,
  [673133] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23793), 1,
      sym__outdent,
    STATE(17840), 2,
      sym_comment,
      sym_block_comment,
  [673147] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23795), 1,
      anon_sym_RPAREN,
    STATE(17841), 2,
      sym_comment,
      sym_block_comment,
  [673161] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23797), 1,
      anon_sym_RPAREN,
    STATE(17842), 2,
      sym_comment,
      sym_block_comment,
  [673175] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23799), 1,
      anon_sym_else,
    STATE(17843), 2,
      sym_comment,
      sym_block_comment,
  [673189] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23801), 1,
      sym__outdent,
    STATE(17844), 2,
      sym_comment,
      sym_block_comment,
  [673203] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20993), 1,
      anon_sym_RBRACE,
    STATE(17845), 2,
      sym_comment,
      sym_block_comment,
  [673217] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23803), 1,
      anon_sym_RPAREN,
    STATE(17846), 2,
      sym_comment,
      sym_block_comment,
  [673231] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23805), 1,
      sym__outdent,
    STATE(17847), 2,
      sym_comment,
      sym_block_comment,
  [673245] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23807), 1,
      anon_sym_RPAREN,
    STATE(17848), 2,
      sym_comment,
      sym_block_comment,
  [673259] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23809), 1,
      anon_sym_RBRACE,
    STATE(17849), 2,
      sym_comment,
      sym_block_comment,
  [673273] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23811), 1,
      anon_sym_else,
    STATE(17850), 2,
      sym_comment,
      sym_block_comment,
  [673287] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23813), 1,
      anon_sym_RBRACE,
    STATE(17851), 2,
      sym_comment,
      sym_block_comment,
  [673301] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23815), 1,
      anon_sym_EQ_GT_GT,
    STATE(17852), 2,
      sym_comment,
      sym_block_comment,
  [673315] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23817), 1,
      anon_sym_EQ_GT,
    STATE(17853), 2,
      sym_comment,
      sym_block_comment,
  [673329] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23819), 1,
      anon_sym_else,
    STATE(17854), 2,
      sym_comment,
      sym_block_comment,
  [673343] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23821), 1,
      anon_sym_RBRACE,
    STATE(17855), 2,
      sym_comment,
      sym_block_comment,
  [673357] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23823), 1,
      sym__outdent,
    STATE(17856), 2,
      sym_comment,
      sym_block_comment,
  [673371] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23825), 1,
      anon_sym_EQ_GT_GT,
    STATE(17857), 2,
      sym_comment,
      sym_block_comment,
  [673385] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23827), 1,
      anon_sym_EQ_GT_GT,
    STATE(17858), 2,
      sym_comment,
      sym_block_comment,
  [673399] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23829), 1,
      sym__outdent,
    STATE(17859), 2,
      sym_comment,
      sym_block_comment,
  [673413] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23831), 1,
      anon_sym_EQ_GT_GT,
    STATE(17860), 2,
      sym_comment,
      sym_block_comment,
  [673427] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23833), 1,
      anon_sym_EQ_GT_GT,
    STATE(17861), 2,
      sym_comment,
      sym_block_comment,
  [673441] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23835), 1,
      anon_sym_do,
    STATE(17862), 2,
      sym_comment,
      sym_block_comment,
  [673455] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23837), 1,
      anon_sym_EQ_GT_GT,
    STATE(17863), 2,
      sym_comment,
      sym_block_comment,
  [673469] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23839), 1,
      sym__outdent,
    STATE(17864), 2,
      sym_comment,
      sym_block_comment,
  [673483] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23841), 1,
      anon_sym_else,
    STATE(17865), 2,
      sym_comment,
      sym_block_comment,
  [673497] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23843), 1,
      anon_sym_do,
    STATE(17866), 2,
      sym_comment,
      sym_block_comment,
  [673511] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23845), 1,
      anon_sym_RBRACE,
    STATE(17867), 2,
      sym_comment,
      sym_block_comment,
  [673525] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23847), 1,
      sym__outdent,
    STATE(17868), 2,
      sym_comment,
      sym_block_comment,
  [673539] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23849), 1,
      anon_sym_do,
    STATE(17869), 2,
      sym_comment,
      sym_block_comment,
  [673553] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23851), 1,
      anon_sym_COLON,
    STATE(17870), 2,
      sym_comment,
      sym_block_comment,
  [673567] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11593), 1,
      anon_sym_DOT,
    STATE(17871), 2,
      sym_comment,
      sym_block_comment,
  [673581] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23853), 1,
      anon_sym_RBRACE,
    STATE(17872), 2,
      sym_comment,
      sym_block_comment,
  [673595] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23853), 1,
      anon_sym_RPAREN,
    STATE(17873), 2,
      sym_comment,
      sym_block_comment,
  [673609] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23855), 1,
      sym__outdent,
    STATE(17874), 2,
      sym_comment,
      sym_block_comment,
  [673623] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23857), 1,
      sym__outdent,
    STATE(17875), 2,
      sym_comment,
      sym_block_comment,
  [673637] = 1,
    ACTIONS(23859), 1,
      ts_builtin_sym_end,
  [673641] = 1,
    ACTIONS(23861), 1,
      ts_builtin_sym_end,
  [673645] = 1,
    ACTIONS(23863), 1,
      ts_builtin_sym_end,
  [673649] = 1,
    ACTIONS(23865), 1,
      ts_builtin_sym_end,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2351)] = 0,
  [SMALL_STATE(2352)] = 147,
  [SMALL_STATE(2353)] = 294,
  [SMALL_STATE(2354)] = 441,
  [SMALL_STATE(2355)] = 588,
  [SMALL_STATE(2356)] = 735,
  [SMALL_STATE(2357)] = 882,
  [SMALL_STATE(2358)] = 1029,
  [SMALL_STATE(2359)] = 1176,
  [SMALL_STATE(2360)] = 1323,
  [SMALL_STATE(2361)] = 1470,
  [SMALL_STATE(2362)] = 1617,
  [SMALL_STATE(2363)] = 1764,
  [SMALL_STATE(2364)] = 1911,
  [SMALL_STATE(2365)] = 2058,
  [SMALL_STATE(2366)] = 2205,
  [SMALL_STATE(2367)] = 2352,
  [SMALL_STATE(2368)] = 2499,
  [SMALL_STATE(2369)] = 2646,
  [SMALL_STATE(2370)] = 2793,
  [SMALL_STATE(2371)] = 2940,
  [SMALL_STATE(2372)] = 3087,
  [SMALL_STATE(2373)] = 3234,
  [SMALL_STATE(2374)] = 3381,
  [SMALL_STATE(2375)] = 3528,
  [SMALL_STATE(2376)] = 3675,
  [SMALL_STATE(2377)] = 3822,
  [SMALL_STATE(2378)] = 3969,
  [SMALL_STATE(2379)] = 4116,
  [SMALL_STATE(2380)] = 4263,
  [SMALL_STATE(2381)] = 4410,
  [SMALL_STATE(2382)] = 4557,
  [SMALL_STATE(2383)] = 4704,
  [SMALL_STATE(2384)] = 4851,
  [SMALL_STATE(2385)] = 4998,
  [SMALL_STATE(2386)] = 5145,
  [SMALL_STATE(2387)] = 5292,
  [SMALL_STATE(2388)] = 5439,
  [SMALL_STATE(2389)] = 5586,
  [SMALL_STATE(2390)] = 5733,
  [SMALL_STATE(2391)] = 5880,
  [SMALL_STATE(2392)] = 6027,
  [SMALL_STATE(2393)] = 6174,
  [SMALL_STATE(2394)] = 6321,
  [SMALL_STATE(2395)] = 6468,
  [SMALL_STATE(2396)] = 6615,
  [SMALL_STATE(2397)] = 6762,
  [SMALL_STATE(2398)] = 6909,
  [SMALL_STATE(2399)] = 7056,
  [SMALL_STATE(2400)] = 7130,
  [SMALL_STATE(2401)] = 7204,
  [SMALL_STATE(2402)] = 7278,
  [SMALL_STATE(2403)] = 7352,
  [SMALL_STATE(2404)] = 7426,
  [SMALL_STATE(2405)] = 7500,
  [SMALL_STATE(2406)] = 7574,
  [SMALL_STATE(2407)] = 7719,
  [SMALL_STATE(2408)] = 7866,
  [SMALL_STATE(2409)] = 7939,
  [SMALL_STATE(2410)] = 8086,
  [SMALL_STATE(2411)] = 8231,
  [SMALL_STATE(2412)] = 8376,
  [SMALL_STATE(2413)] = 8512,
  [SMALL_STATE(2414)] = 8648,
  [SMALL_STATE(2415)] = 8784,
  [SMALL_STATE(2416)] = 8920,
  [SMALL_STATE(2417)] = 9056,
  [SMALL_STATE(2418)] = 9192,
  [SMALL_STATE(2419)] = 9328,
  [SMALL_STATE(2420)] = 9464,
  [SMALL_STATE(2421)] = 9600,
  [SMALL_STATE(2422)] = 9736,
  [SMALL_STATE(2423)] = 9872,
  [SMALL_STATE(2424)] = 10008,
  [SMALL_STATE(2425)] = 10144,
  [SMALL_STATE(2426)] = 10280,
  [SMALL_STATE(2427)] = 10416,
  [SMALL_STATE(2428)] = 10552,
  [SMALL_STATE(2429)] = 10688,
  [SMALL_STATE(2430)] = 10824,
  [SMALL_STATE(2431)] = 10960,
  [SMALL_STATE(2432)] = 11096,
  [SMALL_STATE(2433)] = 11232,
  [SMALL_STATE(2434)] = 11368,
  [SMALL_STATE(2435)] = 11504,
  [SMALL_STATE(2436)] = 11640,
  [SMALL_STATE(2437)] = 11771,
  [SMALL_STATE(2438)] = 11902,
  [SMALL_STATE(2439)] = 12033,
  [SMALL_STATE(2440)] = 12164,
  [SMALL_STATE(2441)] = 12295,
  [SMALL_STATE(2442)] = 12426,
  [SMALL_STATE(2443)] = 12557,
  [SMALL_STATE(2444)] = 12688,
  [SMALL_STATE(2445)] = 12819,
  [SMALL_STATE(2446)] = 12950,
  [SMALL_STATE(2447)] = 13081,
  [SMALL_STATE(2448)] = 13212,
  [SMALL_STATE(2449)] = 13343,
  [SMALL_STATE(2450)] = 13474,
  [SMALL_STATE(2451)] = 13605,
  [SMALL_STATE(2452)] = 13736,
  [SMALL_STATE(2453)] = 13867,
  [SMALL_STATE(2454)] = 13998,
  [SMALL_STATE(2455)] = 14129,
  [SMALL_STATE(2456)] = 14260,
  [SMALL_STATE(2457)] = 14391,
  [SMALL_STATE(2458)] = 14522,
  [SMALL_STATE(2459)] = 14653,
  [SMALL_STATE(2460)] = 14784,
  [SMALL_STATE(2461)] = 14915,
  [SMALL_STATE(2462)] = 15046,
  [SMALL_STATE(2463)] = 15177,
  [SMALL_STATE(2464)] = 15308,
  [SMALL_STATE(2465)] = 15381,
  [SMALL_STATE(2466)] = 15512,
  [SMALL_STATE(2467)] = 15643,
  [SMALL_STATE(2468)] = 15774,
  [SMALL_STATE(2469)] = 15905,
  [SMALL_STATE(2470)] = 16036,
  [SMALL_STATE(2471)] = 16167,
  [SMALL_STATE(2472)] = 16298,
  [SMALL_STATE(2473)] = 16429,
  [SMALL_STATE(2474)] = 16560,
  [SMALL_STATE(2475)] = 16691,
  [SMALL_STATE(2476)] = 16822,
  [SMALL_STATE(2477)] = 16953,
  [SMALL_STATE(2478)] = 17084,
  [SMALL_STATE(2479)] = 17215,
  [SMALL_STATE(2480)] = 17346,
  [SMALL_STATE(2481)] = 17477,
  [SMALL_STATE(2482)] = 17608,
  [SMALL_STATE(2483)] = 17739,
  [SMALL_STATE(2484)] = 17870,
  [SMALL_STATE(2485)] = 18001,
  [SMALL_STATE(2486)] = 18132,
  [SMALL_STATE(2487)] = 18263,
  [SMALL_STATE(2488)] = 18394,
  [SMALL_STATE(2489)] = 18525,
  [SMALL_STATE(2490)] = 18656,
  [SMALL_STATE(2491)] = 18787,
  [SMALL_STATE(2492)] = 18918,
  [SMALL_STATE(2493)] = 19049,
  [SMALL_STATE(2494)] = 19180,
  [SMALL_STATE(2495)] = 19311,
  [SMALL_STATE(2496)] = 19442,
  [SMALL_STATE(2497)] = 19573,
  [SMALL_STATE(2498)] = 19704,
  [SMALL_STATE(2499)] = 19835,
  [SMALL_STATE(2500)] = 19966,
  [SMALL_STATE(2501)] = 20097,
  [SMALL_STATE(2502)] = 20228,
  [SMALL_STATE(2503)] = 20359,
  [SMALL_STATE(2504)] = 20490,
  [SMALL_STATE(2505)] = 20621,
  [SMALL_STATE(2506)] = 20752,
  [SMALL_STATE(2507)] = 20883,
  [SMALL_STATE(2508)] = 21014,
  [SMALL_STATE(2509)] = 21145,
  [SMALL_STATE(2510)] = 21276,
  [SMALL_STATE(2511)] = 21407,
  [SMALL_STATE(2512)] = 21538,
  [SMALL_STATE(2513)] = 21669,
  [SMALL_STATE(2514)] = 21800,
  [SMALL_STATE(2515)] = 21931,
  [SMALL_STATE(2516)] = 22062,
  [SMALL_STATE(2517)] = 22193,
  [SMALL_STATE(2518)] = 22324,
  [SMALL_STATE(2519)] = 22455,
  [SMALL_STATE(2520)] = 22586,
  [SMALL_STATE(2521)] = 22717,
  [SMALL_STATE(2522)] = 22848,
  [SMALL_STATE(2523)] = 22979,
  [SMALL_STATE(2524)] = 23110,
  [SMALL_STATE(2525)] = 23241,
  [SMALL_STATE(2526)] = 23372,
  [SMALL_STATE(2527)] = 23503,
  [SMALL_STATE(2528)] = 23634,
  [SMALL_STATE(2529)] = 23765,
  [SMALL_STATE(2530)] = 23896,
  [SMALL_STATE(2531)] = 24027,
  [SMALL_STATE(2532)] = 24158,
  [SMALL_STATE(2533)] = 24289,
  [SMALL_STATE(2534)] = 24420,
  [SMALL_STATE(2535)] = 24551,
  [SMALL_STATE(2536)] = 24682,
  [SMALL_STATE(2537)] = 24813,
  [SMALL_STATE(2538)] = 24944,
  [SMALL_STATE(2539)] = 25075,
  [SMALL_STATE(2540)] = 25206,
  [SMALL_STATE(2541)] = 25337,
  [SMALL_STATE(2542)] = 25468,
  [SMALL_STATE(2543)] = 25599,
  [SMALL_STATE(2544)] = 25730,
  [SMALL_STATE(2545)] = 25861,
  [SMALL_STATE(2546)] = 25992,
  [SMALL_STATE(2547)] = 26123,
  [SMALL_STATE(2548)] = 26254,
  [SMALL_STATE(2549)] = 26385,
  [SMALL_STATE(2550)] = 26516,
  [SMALL_STATE(2551)] = 26647,
  [SMALL_STATE(2552)] = 26778,
  [SMALL_STATE(2553)] = 26909,
  [SMALL_STATE(2554)] = 27040,
  [SMALL_STATE(2555)] = 27171,
  [SMALL_STATE(2556)] = 27302,
  [SMALL_STATE(2557)] = 27433,
  [SMALL_STATE(2558)] = 27564,
  [SMALL_STATE(2559)] = 27695,
  [SMALL_STATE(2560)] = 27826,
  [SMALL_STATE(2561)] = 27957,
  [SMALL_STATE(2562)] = 28088,
  [SMALL_STATE(2563)] = 28219,
  [SMALL_STATE(2564)] = 28347,
  [SMALL_STATE(2565)] = 28475,
  [SMALL_STATE(2566)] = 28603,
  [SMALL_STATE(2567)] = 28731,
  [SMALL_STATE(2568)] = 28859,
  [SMALL_STATE(2569)] = 28987,
  [SMALL_STATE(2570)] = 29115,
  [SMALL_STATE(2571)] = 29243,
  [SMALL_STATE(2572)] = 29315,
  [SMALL_STATE(2573)] = 29443,
  [SMALL_STATE(2574)] = 29571,
  [SMALL_STATE(2575)] = 29643,
  [SMALL_STATE(2576)] = 29714,
  [SMALL_STATE(2577)] = 29785,
  [SMALL_STATE(2578)] = 29856,
  [SMALL_STATE(2579)] = 29981,
  [SMALL_STATE(2580)] = 30052,
  [SMALL_STATE(2581)] = 30176,
  [SMALL_STATE(2582)] = 30300,
  [SMALL_STATE(2583)] = 30424,
  [SMALL_STATE(2584)] = 30548,
  [SMALL_STATE(2585)] = 30672,
  [SMALL_STATE(2586)] = 30796,
  [SMALL_STATE(2587)] = 30920,
  [SMALL_STATE(2588)] = 31044,
  [SMALL_STATE(2589)] = 31168,
  [SMALL_STATE(2590)] = 31292,
  [SMALL_STATE(2591)] = 31416,
  [SMALL_STATE(2592)] = 31540,
  [SMALL_STATE(2593)] = 31664,
  [SMALL_STATE(2594)] = 31788,
  [SMALL_STATE(2595)] = 31912,
  [SMALL_STATE(2596)] = 32036,
  [SMALL_STATE(2597)] = 32160,
  [SMALL_STATE(2598)] = 32284,
  [SMALL_STATE(2599)] = 32408,
  [SMALL_STATE(2600)] = 32532,
  [SMALL_STATE(2601)] = 32656,
  [SMALL_STATE(2602)] = 32780,
  [SMALL_STATE(2603)] = 32904,
  [SMALL_STATE(2604)] = 33028,
  [SMALL_STATE(2605)] = 33152,
  [SMALL_STATE(2606)] = 33276,
  [SMALL_STATE(2607)] = 33400,
  [SMALL_STATE(2608)] = 33524,
  [SMALL_STATE(2609)] = 33648,
  [SMALL_STATE(2610)] = 33772,
  [SMALL_STATE(2611)] = 33896,
  [SMALL_STATE(2612)] = 34020,
  [SMALL_STATE(2613)] = 34144,
  [SMALL_STATE(2614)] = 34268,
  [SMALL_STATE(2615)] = 34392,
  [SMALL_STATE(2616)] = 34516,
  [SMALL_STATE(2617)] = 34640,
  [SMALL_STATE(2618)] = 34764,
  [SMALL_STATE(2619)] = 34888,
  [SMALL_STATE(2620)] = 35012,
  [SMALL_STATE(2621)] = 35136,
  [SMALL_STATE(2622)] = 35260,
  [SMALL_STATE(2623)] = 35384,
  [SMALL_STATE(2624)] = 35508,
  [SMALL_STATE(2625)] = 35632,
  [SMALL_STATE(2626)] = 35756,
  [SMALL_STATE(2627)] = 35880,
  [SMALL_STATE(2628)] = 36004,
  [SMALL_STATE(2629)] = 36128,
  [SMALL_STATE(2630)] = 36252,
  [SMALL_STATE(2631)] = 36376,
  [SMALL_STATE(2632)] = 36500,
  [SMALL_STATE(2633)] = 36624,
  [SMALL_STATE(2634)] = 36748,
  [SMALL_STATE(2635)] = 36872,
  [SMALL_STATE(2636)] = 36996,
  [SMALL_STATE(2637)] = 37120,
  [SMALL_STATE(2638)] = 37244,
  [SMALL_STATE(2639)] = 37368,
  [SMALL_STATE(2640)] = 37492,
  [SMALL_STATE(2641)] = 37616,
  [SMALL_STATE(2642)] = 37740,
  [SMALL_STATE(2643)] = 37864,
  [SMALL_STATE(2644)] = 37988,
  [SMALL_STATE(2645)] = 38112,
  [SMALL_STATE(2646)] = 38236,
  [SMALL_STATE(2647)] = 38360,
  [SMALL_STATE(2648)] = 38484,
  [SMALL_STATE(2649)] = 38608,
  [SMALL_STATE(2650)] = 38732,
  [SMALL_STATE(2651)] = 38856,
  [SMALL_STATE(2652)] = 38980,
  [SMALL_STATE(2653)] = 39104,
  [SMALL_STATE(2654)] = 39228,
  [SMALL_STATE(2655)] = 39352,
  [SMALL_STATE(2656)] = 39476,
  [SMALL_STATE(2657)] = 39600,
  [SMALL_STATE(2658)] = 39724,
  [SMALL_STATE(2659)] = 39848,
  [SMALL_STATE(2660)] = 39972,
  [SMALL_STATE(2661)] = 40096,
  [SMALL_STATE(2662)] = 40220,
  [SMALL_STATE(2663)] = 40344,
  [SMALL_STATE(2664)] = 40468,
  [SMALL_STATE(2665)] = 40592,
  [SMALL_STATE(2666)] = 40716,
  [SMALL_STATE(2667)] = 40840,
  [SMALL_STATE(2668)] = 40964,
  [SMALL_STATE(2669)] = 41088,
  [SMALL_STATE(2670)] = 41212,
  [SMALL_STATE(2671)] = 41336,
  [SMALL_STATE(2672)] = 41460,
  [SMALL_STATE(2673)] = 41584,
  [SMALL_STATE(2674)] = 41708,
  [SMALL_STATE(2675)] = 41832,
  [SMALL_STATE(2676)] = 41956,
  [SMALL_STATE(2677)] = 42080,
  [SMALL_STATE(2678)] = 42204,
  [SMALL_STATE(2679)] = 42328,
  [SMALL_STATE(2680)] = 42452,
  [SMALL_STATE(2681)] = 42576,
  [SMALL_STATE(2682)] = 42700,
  [SMALL_STATE(2683)] = 42824,
  [SMALL_STATE(2684)] = 42948,
  [SMALL_STATE(2685)] = 43072,
  [SMALL_STATE(2686)] = 43196,
  [SMALL_STATE(2687)] = 43320,
  [SMALL_STATE(2688)] = 43444,
  [SMALL_STATE(2689)] = 43568,
  [SMALL_STATE(2690)] = 43692,
  [SMALL_STATE(2691)] = 43816,
  [SMALL_STATE(2692)] = 43940,
  [SMALL_STATE(2693)] = 44064,
  [SMALL_STATE(2694)] = 44188,
  [SMALL_STATE(2695)] = 44312,
  [SMALL_STATE(2696)] = 44436,
  [SMALL_STATE(2697)] = 44560,
  [SMALL_STATE(2698)] = 44684,
  [SMALL_STATE(2699)] = 44808,
  [SMALL_STATE(2700)] = 44932,
  [SMALL_STATE(2701)] = 45056,
  [SMALL_STATE(2702)] = 45180,
  [SMALL_STATE(2703)] = 45304,
  [SMALL_STATE(2704)] = 45428,
  [SMALL_STATE(2705)] = 45552,
  [SMALL_STATE(2706)] = 45676,
  [SMALL_STATE(2707)] = 45800,
  [SMALL_STATE(2708)] = 45924,
  [SMALL_STATE(2709)] = 46048,
  [SMALL_STATE(2710)] = 46172,
  [SMALL_STATE(2711)] = 46296,
  [SMALL_STATE(2712)] = 46420,
  [SMALL_STATE(2713)] = 46544,
  [SMALL_STATE(2714)] = 46668,
  [SMALL_STATE(2715)] = 46792,
  [SMALL_STATE(2716)] = 46916,
  [SMALL_STATE(2717)] = 47040,
  [SMALL_STATE(2718)] = 47164,
  [SMALL_STATE(2719)] = 47288,
  [SMALL_STATE(2720)] = 47412,
  [SMALL_STATE(2721)] = 47536,
  [SMALL_STATE(2722)] = 47660,
  [SMALL_STATE(2723)] = 47784,
  [SMALL_STATE(2724)] = 47908,
  [SMALL_STATE(2725)] = 48032,
  [SMALL_STATE(2726)] = 48156,
  [SMALL_STATE(2727)] = 48280,
  [SMALL_STATE(2728)] = 48404,
  [SMALL_STATE(2729)] = 48528,
  [SMALL_STATE(2730)] = 48652,
  [SMALL_STATE(2731)] = 48776,
  [SMALL_STATE(2732)] = 48900,
  [SMALL_STATE(2733)] = 49024,
  [SMALL_STATE(2734)] = 49148,
  [SMALL_STATE(2735)] = 49272,
  [SMALL_STATE(2736)] = 49396,
  [SMALL_STATE(2737)] = 49520,
  [SMALL_STATE(2738)] = 49644,
  [SMALL_STATE(2739)] = 49768,
  [SMALL_STATE(2740)] = 49892,
  [SMALL_STATE(2741)] = 50016,
  [SMALL_STATE(2742)] = 50140,
  [SMALL_STATE(2743)] = 50264,
  [SMALL_STATE(2744)] = 50388,
  [SMALL_STATE(2745)] = 50512,
  [SMALL_STATE(2746)] = 50636,
  [SMALL_STATE(2747)] = 50760,
  [SMALL_STATE(2748)] = 50884,
  [SMALL_STATE(2749)] = 51008,
  [SMALL_STATE(2750)] = 51132,
  [SMALL_STATE(2751)] = 51256,
  [SMALL_STATE(2752)] = 51380,
  [SMALL_STATE(2753)] = 51504,
  [SMALL_STATE(2754)] = 51628,
  [SMALL_STATE(2755)] = 51752,
  [SMALL_STATE(2756)] = 51876,
  [SMALL_STATE(2757)] = 52000,
  [SMALL_STATE(2758)] = 52124,
  [SMALL_STATE(2759)] = 52248,
  [SMALL_STATE(2760)] = 52372,
  [SMALL_STATE(2761)] = 52496,
  [SMALL_STATE(2762)] = 52620,
  [SMALL_STATE(2763)] = 52744,
  [SMALL_STATE(2764)] = 52868,
  [SMALL_STATE(2765)] = 52992,
  [SMALL_STATE(2766)] = 53116,
  [SMALL_STATE(2767)] = 53240,
  [SMALL_STATE(2768)] = 53364,
  [SMALL_STATE(2769)] = 53488,
  [SMALL_STATE(2770)] = 53612,
  [SMALL_STATE(2771)] = 53736,
  [SMALL_STATE(2772)] = 53860,
  [SMALL_STATE(2773)] = 53984,
  [SMALL_STATE(2774)] = 54108,
  [SMALL_STATE(2775)] = 54232,
  [SMALL_STATE(2776)] = 54356,
  [SMALL_STATE(2777)] = 54480,
  [SMALL_STATE(2778)] = 54604,
  [SMALL_STATE(2779)] = 54728,
  [SMALL_STATE(2780)] = 54852,
  [SMALL_STATE(2781)] = 54976,
  [SMALL_STATE(2782)] = 55100,
  [SMALL_STATE(2783)] = 55224,
  [SMALL_STATE(2784)] = 55348,
  [SMALL_STATE(2785)] = 55472,
  [SMALL_STATE(2786)] = 55596,
  [SMALL_STATE(2787)] = 55720,
  [SMALL_STATE(2788)] = 55844,
  [SMALL_STATE(2789)] = 55968,
  [SMALL_STATE(2790)] = 56092,
  [SMALL_STATE(2791)] = 56216,
  [SMALL_STATE(2792)] = 56340,
  [SMALL_STATE(2793)] = 56464,
  [SMALL_STATE(2794)] = 56588,
  [SMALL_STATE(2795)] = 56712,
  [SMALL_STATE(2796)] = 56836,
  [SMALL_STATE(2797)] = 56960,
  [SMALL_STATE(2798)] = 57084,
  [SMALL_STATE(2799)] = 57208,
  [SMALL_STATE(2800)] = 57332,
  [SMALL_STATE(2801)] = 57456,
  [SMALL_STATE(2802)] = 57580,
  [SMALL_STATE(2803)] = 57704,
  [SMALL_STATE(2804)] = 57828,
  [SMALL_STATE(2805)] = 57952,
  [SMALL_STATE(2806)] = 58076,
  [SMALL_STATE(2807)] = 58200,
  [SMALL_STATE(2808)] = 58324,
  [SMALL_STATE(2809)] = 58448,
  [SMALL_STATE(2810)] = 58572,
  [SMALL_STATE(2811)] = 58696,
  [SMALL_STATE(2812)] = 58820,
  [SMALL_STATE(2813)] = 58944,
  [SMALL_STATE(2814)] = 59068,
  [SMALL_STATE(2815)] = 59192,
  [SMALL_STATE(2816)] = 59316,
  [SMALL_STATE(2817)] = 59440,
  [SMALL_STATE(2818)] = 59564,
  [SMALL_STATE(2819)] = 59688,
  [SMALL_STATE(2820)] = 59812,
  [SMALL_STATE(2821)] = 59936,
  [SMALL_STATE(2822)] = 60060,
  [SMALL_STATE(2823)] = 60184,
  [SMALL_STATE(2824)] = 60308,
  [SMALL_STATE(2825)] = 60432,
  [SMALL_STATE(2826)] = 60556,
  [SMALL_STATE(2827)] = 60680,
  [SMALL_STATE(2828)] = 60804,
  [SMALL_STATE(2829)] = 60928,
  [SMALL_STATE(2830)] = 61052,
  [SMALL_STATE(2831)] = 61176,
  [SMALL_STATE(2832)] = 61300,
  [SMALL_STATE(2833)] = 61424,
  [SMALL_STATE(2834)] = 61548,
  [SMALL_STATE(2835)] = 61672,
  [SMALL_STATE(2836)] = 61796,
  [SMALL_STATE(2837)] = 61920,
  [SMALL_STATE(2838)] = 62044,
  [SMALL_STATE(2839)] = 62168,
  [SMALL_STATE(2840)] = 62292,
  [SMALL_STATE(2841)] = 62416,
  [SMALL_STATE(2842)] = 62540,
  [SMALL_STATE(2843)] = 62664,
  [SMALL_STATE(2844)] = 62788,
  [SMALL_STATE(2845)] = 62912,
  [SMALL_STATE(2846)] = 63036,
  [SMALL_STATE(2847)] = 63160,
  [SMALL_STATE(2848)] = 63284,
  [SMALL_STATE(2849)] = 63408,
  [SMALL_STATE(2850)] = 63532,
  [SMALL_STATE(2851)] = 63656,
  [SMALL_STATE(2852)] = 63780,
  [SMALL_STATE(2853)] = 63904,
  [SMALL_STATE(2854)] = 64028,
  [SMALL_STATE(2855)] = 64152,
  [SMALL_STATE(2856)] = 64276,
  [SMALL_STATE(2857)] = 64400,
  [SMALL_STATE(2858)] = 64524,
  [SMALL_STATE(2859)] = 64648,
  [SMALL_STATE(2860)] = 64772,
  [SMALL_STATE(2861)] = 64896,
  [SMALL_STATE(2862)] = 65020,
  [SMALL_STATE(2863)] = 65144,
  [SMALL_STATE(2864)] = 65268,
  [SMALL_STATE(2865)] = 65392,
  [SMALL_STATE(2866)] = 65516,
  [SMALL_STATE(2867)] = 65640,
  [SMALL_STATE(2868)] = 65764,
  [SMALL_STATE(2869)] = 65888,
  [SMALL_STATE(2870)] = 66012,
  [SMALL_STATE(2871)] = 66136,
  [SMALL_STATE(2872)] = 66260,
  [SMALL_STATE(2873)] = 66384,
  [SMALL_STATE(2874)] = 66508,
  [SMALL_STATE(2875)] = 66632,
  [SMALL_STATE(2876)] = 66756,
  [SMALL_STATE(2877)] = 66880,
  [SMALL_STATE(2878)] = 67004,
  [SMALL_STATE(2879)] = 67128,
  [SMALL_STATE(2880)] = 67252,
  [SMALL_STATE(2881)] = 67376,
  [SMALL_STATE(2882)] = 67500,
  [SMALL_STATE(2883)] = 67624,
  [SMALL_STATE(2884)] = 67748,
  [SMALL_STATE(2885)] = 67872,
  [SMALL_STATE(2886)] = 67996,
  [SMALL_STATE(2887)] = 68120,
  [SMALL_STATE(2888)] = 68244,
  [SMALL_STATE(2889)] = 68368,
  [SMALL_STATE(2890)] = 68492,
  [SMALL_STATE(2891)] = 68616,
  [SMALL_STATE(2892)] = 68740,
  [SMALL_STATE(2893)] = 68864,
  [SMALL_STATE(2894)] = 68988,
  [SMALL_STATE(2895)] = 69112,
  [SMALL_STATE(2896)] = 69236,
  [SMALL_STATE(2897)] = 69306,
  [SMALL_STATE(2898)] = 69430,
  [SMALL_STATE(2899)] = 69554,
  [SMALL_STATE(2900)] = 69678,
  [SMALL_STATE(2901)] = 69802,
  [SMALL_STATE(2902)] = 69926,
  [SMALL_STATE(2903)] = 70050,
  [SMALL_STATE(2904)] = 70174,
  [SMALL_STATE(2905)] = 70298,
  [SMALL_STATE(2906)] = 70422,
  [SMALL_STATE(2907)] = 70546,
  [SMALL_STATE(2908)] = 70670,
  [SMALL_STATE(2909)] = 70794,
  [SMALL_STATE(2910)] = 70918,
  [SMALL_STATE(2911)] = 71042,
  [SMALL_STATE(2912)] = 71166,
  [SMALL_STATE(2913)] = 71290,
  [SMALL_STATE(2914)] = 71414,
  [SMALL_STATE(2915)] = 71538,
  [SMALL_STATE(2916)] = 71662,
  [SMALL_STATE(2917)] = 71786,
  [SMALL_STATE(2918)] = 71910,
  [SMALL_STATE(2919)] = 72034,
  [SMALL_STATE(2920)] = 72158,
  [SMALL_STATE(2921)] = 72282,
  [SMALL_STATE(2922)] = 72406,
  [SMALL_STATE(2923)] = 72530,
  [SMALL_STATE(2924)] = 72654,
  [SMALL_STATE(2925)] = 72778,
  [SMALL_STATE(2926)] = 72902,
  [SMALL_STATE(2927)] = 72972,
  [SMALL_STATE(2928)] = 73096,
  [SMALL_STATE(2929)] = 73220,
  [SMALL_STATE(2930)] = 73344,
  [SMALL_STATE(2931)] = 73468,
  [SMALL_STATE(2932)] = 73592,
  [SMALL_STATE(2933)] = 73716,
  [SMALL_STATE(2934)] = 73840,
  [SMALL_STATE(2935)] = 73964,
  [SMALL_STATE(2936)] = 74088,
  [SMALL_STATE(2937)] = 74212,
  [SMALL_STATE(2938)] = 74336,
  [SMALL_STATE(2939)] = 74460,
  [SMALL_STATE(2940)] = 74584,
  [SMALL_STATE(2941)] = 74708,
  [SMALL_STATE(2942)] = 74832,
  [SMALL_STATE(2943)] = 74956,
  [SMALL_STATE(2944)] = 75080,
  [SMALL_STATE(2945)] = 75204,
  [SMALL_STATE(2946)] = 75328,
  [SMALL_STATE(2947)] = 75452,
  [SMALL_STATE(2948)] = 75576,
  [SMALL_STATE(2949)] = 75700,
  [SMALL_STATE(2950)] = 75824,
  [SMALL_STATE(2951)] = 75948,
  [SMALL_STATE(2952)] = 76072,
  [SMALL_STATE(2953)] = 76196,
  [SMALL_STATE(2954)] = 76320,
  [SMALL_STATE(2955)] = 76444,
  [SMALL_STATE(2956)] = 76568,
  [SMALL_STATE(2957)] = 76692,
  [SMALL_STATE(2958)] = 76816,
  [SMALL_STATE(2959)] = 76940,
  [SMALL_STATE(2960)] = 77064,
  [SMALL_STATE(2961)] = 77188,
  [SMALL_STATE(2962)] = 77312,
  [SMALL_STATE(2963)] = 77436,
  [SMALL_STATE(2964)] = 77560,
  [SMALL_STATE(2965)] = 77684,
  [SMALL_STATE(2966)] = 77754,
  [SMALL_STATE(2967)] = 77878,
  [SMALL_STATE(2968)] = 78002,
  [SMALL_STATE(2969)] = 78126,
  [SMALL_STATE(2970)] = 78250,
  [SMALL_STATE(2971)] = 78374,
  [SMALL_STATE(2972)] = 78498,
  [SMALL_STATE(2973)] = 78622,
  [SMALL_STATE(2974)] = 78746,
  [SMALL_STATE(2975)] = 78870,
  [SMALL_STATE(2976)] = 78994,
  [SMALL_STATE(2977)] = 79118,
  [SMALL_STATE(2978)] = 79242,
  [SMALL_STATE(2979)] = 79366,
  [SMALL_STATE(2980)] = 79490,
  [SMALL_STATE(2981)] = 79614,
  [SMALL_STATE(2982)] = 79738,
  [SMALL_STATE(2983)] = 79862,
  [SMALL_STATE(2984)] = 79986,
  [SMALL_STATE(2985)] = 80110,
  [SMALL_STATE(2986)] = 80234,
  [SMALL_STATE(2987)] = 80358,
  [SMALL_STATE(2988)] = 80482,
  [SMALL_STATE(2989)] = 80606,
  [SMALL_STATE(2990)] = 80730,
  [SMALL_STATE(2991)] = 80854,
  [SMALL_STATE(2992)] = 80978,
  [SMALL_STATE(2993)] = 81048,
  [SMALL_STATE(2994)] = 81172,
  [SMALL_STATE(2995)] = 81296,
  [SMALL_STATE(2996)] = 81420,
  [SMALL_STATE(2997)] = 81544,
  [SMALL_STATE(2998)] = 81668,
  [SMALL_STATE(2999)] = 81792,
  [SMALL_STATE(3000)] = 81916,
  [SMALL_STATE(3001)] = 82040,
  [SMALL_STATE(3002)] = 82164,
  [SMALL_STATE(3003)] = 82288,
  [SMALL_STATE(3004)] = 82412,
  [SMALL_STATE(3005)] = 82536,
  [SMALL_STATE(3006)] = 82660,
  [SMALL_STATE(3007)] = 82784,
  [SMALL_STATE(3008)] = 82908,
  [SMALL_STATE(3009)] = 83032,
  [SMALL_STATE(3010)] = 83156,
  [SMALL_STATE(3011)] = 83280,
  [SMALL_STATE(3012)] = 83404,
  [SMALL_STATE(3013)] = 83528,
  [SMALL_STATE(3014)] = 83652,
  [SMALL_STATE(3015)] = 83776,
  [SMALL_STATE(3016)] = 83900,
  [SMALL_STATE(3017)] = 84024,
  [SMALL_STATE(3018)] = 84148,
  [SMALL_STATE(3019)] = 84272,
  [SMALL_STATE(3020)] = 84396,
  [SMALL_STATE(3021)] = 84520,
  [SMALL_STATE(3022)] = 84644,
  [SMALL_STATE(3023)] = 84768,
  [SMALL_STATE(3024)] = 84892,
  [SMALL_STATE(3025)] = 85016,
  [SMALL_STATE(3026)] = 85140,
  [SMALL_STATE(3027)] = 85264,
  [SMALL_STATE(3028)] = 85388,
  [SMALL_STATE(3029)] = 85512,
  [SMALL_STATE(3030)] = 85636,
  [SMALL_STATE(3031)] = 85760,
  [SMALL_STATE(3032)] = 85884,
  [SMALL_STATE(3033)] = 86008,
  [SMALL_STATE(3034)] = 86132,
  [SMALL_STATE(3035)] = 86256,
  [SMALL_STATE(3036)] = 86380,
  [SMALL_STATE(3037)] = 86504,
  [SMALL_STATE(3038)] = 86628,
  [SMALL_STATE(3039)] = 86752,
  [SMALL_STATE(3040)] = 86876,
  [SMALL_STATE(3041)] = 87000,
  [SMALL_STATE(3042)] = 87124,
  [SMALL_STATE(3043)] = 87248,
  [SMALL_STATE(3044)] = 87372,
  [SMALL_STATE(3045)] = 87496,
  [SMALL_STATE(3046)] = 87620,
  [SMALL_STATE(3047)] = 87744,
  [SMALL_STATE(3048)] = 87868,
  [SMALL_STATE(3049)] = 87992,
  [SMALL_STATE(3050)] = 88116,
  [SMALL_STATE(3051)] = 88240,
  [SMALL_STATE(3052)] = 88364,
  [SMALL_STATE(3053)] = 88488,
  [SMALL_STATE(3054)] = 88612,
  [SMALL_STATE(3055)] = 88736,
  [SMALL_STATE(3056)] = 88860,
  [SMALL_STATE(3057)] = 88984,
  [SMALL_STATE(3058)] = 89108,
  [SMALL_STATE(3059)] = 89232,
  [SMALL_STATE(3060)] = 89356,
  [SMALL_STATE(3061)] = 89480,
  [SMALL_STATE(3062)] = 89604,
  [SMALL_STATE(3063)] = 89728,
  [SMALL_STATE(3064)] = 89852,
  [SMALL_STATE(3065)] = 89976,
  [SMALL_STATE(3066)] = 90100,
  [SMALL_STATE(3067)] = 90224,
  [SMALL_STATE(3068)] = 90348,
  [SMALL_STATE(3069)] = 90472,
  [SMALL_STATE(3070)] = 90596,
  [SMALL_STATE(3071)] = 90720,
  [SMALL_STATE(3072)] = 90844,
  [SMALL_STATE(3073)] = 90968,
  [SMALL_STATE(3074)] = 91092,
  [SMALL_STATE(3075)] = 91216,
  [SMALL_STATE(3076)] = 91340,
  [SMALL_STATE(3077)] = 91464,
  [SMALL_STATE(3078)] = 91588,
  [SMALL_STATE(3079)] = 91712,
  [SMALL_STATE(3080)] = 91836,
  [SMALL_STATE(3081)] = 91960,
  [SMALL_STATE(3082)] = 92084,
  [SMALL_STATE(3083)] = 92205,
  [SMALL_STATE(3084)] = 92326,
  [SMALL_STATE(3085)] = 92447,
  [SMALL_STATE(3086)] = 92568,
  [SMALL_STATE(3087)] = 92689,
  [SMALL_STATE(3088)] = 92810,
  [SMALL_STATE(3089)] = 92931,
  [SMALL_STATE(3090)] = 93052,
  [SMALL_STATE(3091)] = 93173,
  [SMALL_STATE(3092)] = 93294,
  [SMALL_STATE(3093)] = 93415,
  [SMALL_STATE(3094)] = 93536,
  [SMALL_STATE(3095)] = 93657,
  [SMALL_STATE(3096)] = 93778,
  [SMALL_STATE(3097)] = 93899,
  [SMALL_STATE(3098)] = 94020,
  [SMALL_STATE(3099)] = 94141,
  [SMALL_STATE(3100)] = 94262,
  [SMALL_STATE(3101)] = 94383,
  [SMALL_STATE(3102)] = 94504,
  [SMALL_STATE(3103)] = 94625,
  [SMALL_STATE(3104)] = 94746,
  [SMALL_STATE(3105)] = 94867,
  [SMALL_STATE(3106)] = 94988,
  [SMALL_STATE(3107)] = 95109,
  [SMALL_STATE(3108)] = 95230,
  [SMALL_STATE(3109)] = 95351,
  [SMALL_STATE(3110)] = 95472,
  [SMALL_STATE(3111)] = 95593,
  [SMALL_STATE(3112)] = 95714,
  [SMALL_STATE(3113)] = 95835,
  [SMALL_STATE(3114)] = 95956,
  [SMALL_STATE(3115)] = 96077,
  [SMALL_STATE(3116)] = 96198,
  [SMALL_STATE(3117)] = 96319,
  [SMALL_STATE(3118)] = 96440,
  [SMALL_STATE(3119)] = 96561,
  [SMALL_STATE(3120)] = 96682,
  [SMALL_STATE(3121)] = 96803,
  [SMALL_STATE(3122)] = 96924,
  [SMALL_STATE(3123)] = 97045,
  [SMALL_STATE(3124)] = 97166,
  [SMALL_STATE(3125)] = 97235,
  [SMALL_STATE(3126)] = 97356,
  [SMALL_STATE(3127)] = 97477,
  [SMALL_STATE(3128)] = 97598,
  [SMALL_STATE(3129)] = 97719,
  [SMALL_STATE(3130)] = 97840,
  [SMALL_STATE(3131)] = 97961,
  [SMALL_STATE(3132)] = 98082,
  [SMALL_STATE(3133)] = 98203,
  [SMALL_STATE(3134)] = 98324,
  [SMALL_STATE(3135)] = 98445,
  [SMALL_STATE(3136)] = 98566,
  [SMALL_STATE(3137)] = 98687,
  [SMALL_STATE(3138)] = 98808,
  [SMALL_STATE(3139)] = 98929,
  [SMALL_STATE(3140)] = 99050,
  [SMALL_STATE(3141)] = 99171,
  [SMALL_STATE(3142)] = 99292,
  [SMALL_STATE(3143)] = 99413,
  [SMALL_STATE(3144)] = 99534,
  [SMALL_STATE(3145)] = 99655,
  [SMALL_STATE(3146)] = 99776,
  [SMALL_STATE(3147)] = 99897,
  [SMALL_STATE(3148)] = 100018,
  [SMALL_STATE(3149)] = 100139,
  [SMALL_STATE(3150)] = 100260,
  [SMALL_STATE(3151)] = 100381,
  [SMALL_STATE(3152)] = 100502,
  [SMALL_STATE(3153)] = 100623,
  [SMALL_STATE(3154)] = 100744,
  [SMALL_STATE(3155)] = 100865,
  [SMALL_STATE(3156)] = 100986,
  [SMALL_STATE(3157)] = 101107,
  [SMALL_STATE(3158)] = 101228,
  [SMALL_STATE(3159)] = 101349,
  [SMALL_STATE(3160)] = 101470,
  [SMALL_STATE(3161)] = 101591,
  [SMALL_STATE(3162)] = 101712,
  [SMALL_STATE(3163)] = 101833,
  [SMALL_STATE(3164)] = 101954,
  [SMALL_STATE(3165)] = 102075,
  [SMALL_STATE(3166)] = 102196,
  [SMALL_STATE(3167)] = 102317,
  [SMALL_STATE(3168)] = 102438,
  [SMALL_STATE(3169)] = 102559,
  [SMALL_STATE(3170)] = 102680,
  [SMALL_STATE(3171)] = 102801,
  [SMALL_STATE(3172)] = 102922,
  [SMALL_STATE(3173)] = 103043,
  [SMALL_STATE(3174)] = 103164,
  [SMALL_STATE(3175)] = 103285,
  [SMALL_STATE(3176)] = 103406,
  [SMALL_STATE(3177)] = 103527,
  [SMALL_STATE(3178)] = 103648,
  [SMALL_STATE(3179)] = 103769,
  [SMALL_STATE(3180)] = 103890,
  [SMALL_STATE(3181)] = 104011,
  [SMALL_STATE(3182)] = 104132,
  [SMALL_STATE(3183)] = 104253,
  [SMALL_STATE(3184)] = 104374,
  [SMALL_STATE(3185)] = 104443,
  [SMALL_STATE(3186)] = 104564,
  [SMALL_STATE(3187)] = 104685,
  [SMALL_STATE(3188)] = 104806,
  [SMALL_STATE(3189)] = 104927,
  [SMALL_STATE(3190)] = 105048,
  [SMALL_STATE(3191)] = 105169,
  [SMALL_STATE(3192)] = 105290,
  [SMALL_STATE(3193)] = 105411,
  [SMALL_STATE(3194)] = 105532,
  [SMALL_STATE(3195)] = 105653,
  [SMALL_STATE(3196)] = 105774,
  [SMALL_STATE(3197)] = 105895,
  [SMALL_STATE(3198)] = 106016,
  [SMALL_STATE(3199)] = 106137,
  [SMALL_STATE(3200)] = 106258,
  [SMALL_STATE(3201)] = 106379,
  [SMALL_STATE(3202)] = 106500,
  [SMALL_STATE(3203)] = 106621,
  [SMALL_STATE(3204)] = 106742,
  [SMALL_STATE(3205)] = 106863,
  [SMALL_STATE(3206)] = 106984,
  [SMALL_STATE(3207)] = 107105,
  [SMALL_STATE(3208)] = 107226,
  [SMALL_STATE(3209)] = 107347,
  [SMALL_STATE(3210)] = 107468,
  [SMALL_STATE(3211)] = 107589,
  [SMALL_STATE(3212)] = 107710,
  [SMALL_STATE(3213)] = 107831,
  [SMALL_STATE(3214)] = 107952,
  [SMALL_STATE(3215)] = 108073,
  [SMALL_STATE(3216)] = 108194,
  [SMALL_STATE(3217)] = 108315,
  [SMALL_STATE(3218)] = 108436,
  [SMALL_STATE(3219)] = 108557,
  [SMALL_STATE(3220)] = 108678,
  [SMALL_STATE(3221)] = 108799,
  [SMALL_STATE(3222)] = 108920,
  [SMALL_STATE(3223)] = 109041,
  [SMALL_STATE(3224)] = 109162,
  [SMALL_STATE(3225)] = 109283,
  [SMALL_STATE(3226)] = 109404,
  [SMALL_STATE(3227)] = 109525,
  [SMALL_STATE(3228)] = 109646,
  [SMALL_STATE(3229)] = 109767,
  [SMALL_STATE(3230)] = 109888,
  [SMALL_STATE(3231)] = 110009,
  [SMALL_STATE(3232)] = 110130,
  [SMALL_STATE(3233)] = 110251,
  [SMALL_STATE(3234)] = 110372,
  [SMALL_STATE(3235)] = 110493,
  [SMALL_STATE(3236)] = 110614,
  [SMALL_STATE(3237)] = 110735,
  [SMALL_STATE(3238)] = 110856,
  [SMALL_STATE(3239)] = 110977,
  [SMALL_STATE(3240)] = 111098,
  [SMALL_STATE(3241)] = 111219,
  [SMALL_STATE(3242)] = 111340,
  [SMALL_STATE(3243)] = 111461,
  [SMALL_STATE(3244)] = 111582,
  [SMALL_STATE(3245)] = 111703,
  [SMALL_STATE(3246)] = 111824,
  [SMALL_STATE(3247)] = 111945,
  [SMALL_STATE(3248)] = 112066,
  [SMALL_STATE(3249)] = 112187,
  [SMALL_STATE(3250)] = 112308,
  [SMALL_STATE(3251)] = 112429,
  [SMALL_STATE(3252)] = 112550,
  [SMALL_STATE(3253)] = 112671,
  [SMALL_STATE(3254)] = 112792,
  [SMALL_STATE(3255)] = 112913,
  [SMALL_STATE(3256)] = 113034,
  [SMALL_STATE(3257)] = 113155,
  [SMALL_STATE(3258)] = 113276,
  [SMALL_STATE(3259)] = 113397,
  [SMALL_STATE(3260)] = 113518,
  [SMALL_STATE(3261)] = 113639,
  [SMALL_STATE(3262)] = 113760,
  [SMALL_STATE(3263)] = 113881,
  [SMALL_STATE(3264)] = 114002,
  [SMALL_STATE(3265)] = 114123,
  [SMALL_STATE(3266)] = 114244,
  [SMALL_STATE(3267)] = 114365,
  [SMALL_STATE(3268)] = 114486,
  [SMALL_STATE(3269)] = 114607,
  [SMALL_STATE(3270)] = 114728,
  [SMALL_STATE(3271)] = 114849,
  [SMALL_STATE(3272)] = 114970,
  [SMALL_STATE(3273)] = 115091,
  [SMALL_STATE(3274)] = 115212,
  [SMALL_STATE(3275)] = 115333,
  [SMALL_STATE(3276)] = 115454,
  [SMALL_STATE(3277)] = 115575,
  [SMALL_STATE(3278)] = 115696,
  [SMALL_STATE(3279)] = 115817,
  [SMALL_STATE(3280)] = 115938,
  [SMALL_STATE(3281)] = 116059,
  [SMALL_STATE(3282)] = 116180,
  [SMALL_STATE(3283)] = 116301,
  [SMALL_STATE(3284)] = 116422,
  [SMALL_STATE(3285)] = 116543,
  [SMALL_STATE(3286)] = 116664,
  [SMALL_STATE(3287)] = 116785,
  [SMALL_STATE(3288)] = 116906,
  [SMALL_STATE(3289)] = 117027,
  [SMALL_STATE(3290)] = 117148,
  [SMALL_STATE(3291)] = 117269,
  [SMALL_STATE(3292)] = 117390,
  [SMALL_STATE(3293)] = 117511,
  [SMALL_STATE(3294)] = 117632,
  [SMALL_STATE(3295)] = 117753,
  [SMALL_STATE(3296)] = 117874,
  [SMALL_STATE(3297)] = 117995,
  [SMALL_STATE(3298)] = 118116,
  [SMALL_STATE(3299)] = 118237,
  [SMALL_STATE(3300)] = 118358,
  [SMALL_STATE(3301)] = 118479,
  [SMALL_STATE(3302)] = 118600,
  [SMALL_STATE(3303)] = 118721,
  [SMALL_STATE(3304)] = 118842,
  [SMALL_STATE(3305)] = 118963,
  [SMALL_STATE(3306)] = 119084,
  [SMALL_STATE(3307)] = 119205,
  [SMALL_STATE(3308)] = 119326,
  [SMALL_STATE(3309)] = 119447,
  [SMALL_STATE(3310)] = 119568,
  [SMALL_STATE(3311)] = 119689,
  [SMALL_STATE(3312)] = 119810,
  [SMALL_STATE(3313)] = 119931,
  [SMALL_STATE(3314)] = 120052,
  [SMALL_STATE(3315)] = 120173,
  [SMALL_STATE(3316)] = 120294,
  [SMALL_STATE(3317)] = 120415,
  [SMALL_STATE(3318)] = 120536,
  [SMALL_STATE(3319)] = 120657,
  [SMALL_STATE(3320)] = 120778,
  [SMALL_STATE(3321)] = 120899,
  [SMALL_STATE(3322)] = 121020,
  [SMALL_STATE(3323)] = 121141,
  [SMALL_STATE(3324)] = 121262,
  [SMALL_STATE(3325)] = 121383,
  [SMALL_STATE(3326)] = 121504,
  [SMALL_STATE(3327)] = 121625,
  [SMALL_STATE(3328)] = 121746,
  [SMALL_STATE(3329)] = 121815,
  [SMALL_STATE(3330)] = 121936,
  [SMALL_STATE(3331)] = 122057,
  [SMALL_STATE(3332)] = 122178,
  [SMALL_STATE(3333)] = 122299,
  [SMALL_STATE(3334)] = 122420,
  [SMALL_STATE(3335)] = 122541,
  [SMALL_STATE(3336)] = 122662,
  [SMALL_STATE(3337)] = 122783,
  [SMALL_STATE(3338)] = 122904,
  [SMALL_STATE(3339)] = 123025,
  [SMALL_STATE(3340)] = 123146,
  [SMALL_STATE(3341)] = 123267,
  [SMALL_STATE(3342)] = 123388,
  [SMALL_STATE(3343)] = 123509,
  [SMALL_STATE(3344)] = 123630,
  [SMALL_STATE(3345)] = 123751,
  [SMALL_STATE(3346)] = 123872,
  [SMALL_STATE(3347)] = 123993,
  [SMALL_STATE(3348)] = 124114,
  [SMALL_STATE(3349)] = 124235,
  [SMALL_STATE(3350)] = 124356,
  [SMALL_STATE(3351)] = 124477,
  [SMALL_STATE(3352)] = 124598,
  [SMALL_STATE(3353)] = 124719,
  [SMALL_STATE(3354)] = 124840,
  [SMALL_STATE(3355)] = 124961,
  [SMALL_STATE(3356)] = 125082,
  [SMALL_STATE(3357)] = 125203,
  [SMALL_STATE(3358)] = 125324,
  [SMALL_STATE(3359)] = 125445,
  [SMALL_STATE(3360)] = 125566,
  [SMALL_STATE(3361)] = 125687,
  [SMALL_STATE(3362)] = 125808,
  [SMALL_STATE(3363)] = 125929,
  [SMALL_STATE(3364)] = 126050,
  [SMALL_STATE(3365)] = 126171,
  [SMALL_STATE(3366)] = 126292,
  [SMALL_STATE(3367)] = 126413,
  [SMALL_STATE(3368)] = 126534,
  [SMALL_STATE(3369)] = 126655,
  [SMALL_STATE(3370)] = 126776,
  [SMALL_STATE(3371)] = 126897,
  [SMALL_STATE(3372)] = 127018,
  [SMALL_STATE(3373)] = 127139,
  [SMALL_STATE(3374)] = 127260,
  [SMALL_STATE(3375)] = 127381,
  [SMALL_STATE(3376)] = 127502,
  [SMALL_STATE(3377)] = 127623,
  [SMALL_STATE(3378)] = 127744,
  [SMALL_STATE(3379)] = 127865,
  [SMALL_STATE(3380)] = 127986,
  [SMALL_STATE(3381)] = 128107,
  [SMALL_STATE(3382)] = 128228,
  [SMALL_STATE(3383)] = 128349,
  [SMALL_STATE(3384)] = 128470,
  [SMALL_STATE(3385)] = 128591,
  [SMALL_STATE(3386)] = 128712,
  [SMALL_STATE(3387)] = 128833,
  [SMALL_STATE(3388)] = 128954,
  [SMALL_STATE(3389)] = 129075,
  [SMALL_STATE(3390)] = 129196,
  [SMALL_STATE(3391)] = 129265,
  [SMALL_STATE(3392)] = 129386,
  [SMALL_STATE(3393)] = 129507,
  [SMALL_STATE(3394)] = 129628,
  [SMALL_STATE(3395)] = 129749,
  [SMALL_STATE(3396)] = 129870,
  [SMALL_STATE(3397)] = 129991,
  [SMALL_STATE(3398)] = 130112,
  [SMALL_STATE(3399)] = 130233,
  [SMALL_STATE(3400)] = 130354,
  [SMALL_STATE(3401)] = 130475,
  [SMALL_STATE(3402)] = 130596,
  [SMALL_STATE(3403)] = 130717,
  [SMALL_STATE(3404)] = 130838,
  [SMALL_STATE(3405)] = 130959,
  [SMALL_STATE(3406)] = 131080,
  [SMALL_STATE(3407)] = 131201,
  [SMALL_STATE(3408)] = 131322,
  [SMALL_STATE(3409)] = 131443,
  [SMALL_STATE(3410)] = 131564,
  [SMALL_STATE(3411)] = 131685,
  [SMALL_STATE(3412)] = 131806,
  [SMALL_STATE(3413)] = 131927,
  [SMALL_STATE(3414)] = 132048,
  [SMALL_STATE(3415)] = 132169,
  [SMALL_STATE(3416)] = 132290,
  [SMALL_STATE(3417)] = 132411,
  [SMALL_STATE(3418)] = 132532,
  [SMALL_STATE(3419)] = 132653,
  [SMALL_STATE(3420)] = 132774,
  [SMALL_STATE(3421)] = 132895,
  [SMALL_STATE(3422)] = 133016,
  [SMALL_STATE(3423)] = 133137,
  [SMALL_STATE(3424)] = 133258,
  [SMALL_STATE(3425)] = 133379,
  [SMALL_STATE(3426)] = 133500,
  [SMALL_STATE(3427)] = 133621,
  [SMALL_STATE(3428)] = 133742,
  [SMALL_STATE(3429)] = 133863,
  [SMALL_STATE(3430)] = 133984,
  [SMALL_STATE(3431)] = 134105,
  [SMALL_STATE(3432)] = 134226,
  [SMALL_STATE(3433)] = 134347,
  [SMALL_STATE(3434)] = 134468,
  [SMALL_STATE(3435)] = 134589,
  [SMALL_STATE(3436)] = 134710,
  [SMALL_STATE(3437)] = 134831,
  [SMALL_STATE(3438)] = 134952,
  [SMALL_STATE(3439)] = 135073,
  [SMALL_STATE(3440)] = 135194,
  [SMALL_STATE(3441)] = 135315,
  [SMALL_STATE(3442)] = 135436,
  [SMALL_STATE(3443)] = 135557,
  [SMALL_STATE(3444)] = 135678,
  [SMALL_STATE(3445)] = 135799,
  [SMALL_STATE(3446)] = 135920,
  [SMALL_STATE(3447)] = 136041,
  [SMALL_STATE(3448)] = 136162,
  [SMALL_STATE(3449)] = 136283,
  [SMALL_STATE(3450)] = 136404,
  [SMALL_STATE(3451)] = 136525,
  [SMALL_STATE(3452)] = 136646,
  [SMALL_STATE(3453)] = 136767,
  [SMALL_STATE(3454)] = 136888,
  [SMALL_STATE(3455)] = 137009,
  [SMALL_STATE(3456)] = 137130,
  [SMALL_STATE(3457)] = 137251,
  [SMALL_STATE(3458)] = 137372,
  [SMALL_STATE(3459)] = 137493,
  [SMALL_STATE(3460)] = 137614,
  [SMALL_STATE(3461)] = 137735,
  [SMALL_STATE(3462)] = 137856,
  [SMALL_STATE(3463)] = 137977,
  [SMALL_STATE(3464)] = 138098,
  [SMALL_STATE(3465)] = 138219,
  [SMALL_STATE(3466)] = 138340,
  [SMALL_STATE(3467)] = 138461,
  [SMALL_STATE(3468)] = 138582,
  [SMALL_STATE(3469)] = 138703,
  [SMALL_STATE(3470)] = 138824,
  [SMALL_STATE(3471)] = 138945,
  [SMALL_STATE(3472)] = 139066,
  [SMALL_STATE(3473)] = 139187,
  [SMALL_STATE(3474)] = 139308,
  [SMALL_STATE(3475)] = 139429,
  [SMALL_STATE(3476)] = 139550,
  [SMALL_STATE(3477)] = 139671,
  [SMALL_STATE(3478)] = 139792,
  [SMALL_STATE(3479)] = 139913,
  [SMALL_STATE(3480)] = 140034,
  [SMALL_STATE(3481)] = 140155,
  [SMALL_STATE(3482)] = 140276,
  [SMALL_STATE(3483)] = 140397,
  [SMALL_STATE(3484)] = 140518,
  [SMALL_STATE(3485)] = 140639,
  [SMALL_STATE(3486)] = 140760,
  [SMALL_STATE(3487)] = 140881,
  [SMALL_STATE(3488)] = 141002,
  [SMALL_STATE(3489)] = 141123,
  [SMALL_STATE(3490)] = 141244,
  [SMALL_STATE(3491)] = 141365,
  [SMALL_STATE(3492)] = 141486,
  [SMALL_STATE(3493)] = 141607,
  [SMALL_STATE(3494)] = 141728,
  [SMALL_STATE(3495)] = 141849,
  [SMALL_STATE(3496)] = 141970,
  [SMALL_STATE(3497)] = 142091,
  [SMALL_STATE(3498)] = 142212,
  [SMALL_STATE(3499)] = 142333,
  [SMALL_STATE(3500)] = 142454,
  [SMALL_STATE(3501)] = 142575,
  [SMALL_STATE(3502)] = 142696,
  [SMALL_STATE(3503)] = 142817,
  [SMALL_STATE(3504)] = 142938,
  [SMALL_STATE(3505)] = 143059,
  [SMALL_STATE(3506)] = 143180,
  [SMALL_STATE(3507)] = 143301,
  [SMALL_STATE(3508)] = 143422,
  [SMALL_STATE(3509)] = 143543,
  [SMALL_STATE(3510)] = 143664,
  [SMALL_STATE(3511)] = 143785,
  [SMALL_STATE(3512)] = 143906,
  [SMALL_STATE(3513)] = 144027,
  [SMALL_STATE(3514)] = 144148,
  [SMALL_STATE(3515)] = 144269,
  [SMALL_STATE(3516)] = 144390,
  [SMALL_STATE(3517)] = 144511,
  [SMALL_STATE(3518)] = 144632,
  [SMALL_STATE(3519)] = 144753,
  [SMALL_STATE(3520)] = 144874,
  [SMALL_STATE(3521)] = 144995,
  [SMALL_STATE(3522)] = 145116,
  [SMALL_STATE(3523)] = 145237,
  [SMALL_STATE(3524)] = 145358,
  [SMALL_STATE(3525)] = 145479,
  [SMALL_STATE(3526)] = 145600,
  [SMALL_STATE(3527)] = 145721,
  [SMALL_STATE(3528)] = 145842,
  [SMALL_STATE(3529)] = 145963,
  [SMALL_STATE(3530)] = 146084,
  [SMALL_STATE(3531)] = 146205,
  [SMALL_STATE(3532)] = 146326,
  [SMALL_STATE(3533)] = 146447,
  [SMALL_STATE(3534)] = 146568,
  [SMALL_STATE(3535)] = 146689,
  [SMALL_STATE(3536)] = 146810,
  [SMALL_STATE(3537)] = 146931,
  [SMALL_STATE(3538)] = 147052,
  [SMALL_STATE(3539)] = 147173,
  [SMALL_STATE(3540)] = 147294,
  [SMALL_STATE(3541)] = 147415,
  [SMALL_STATE(3542)] = 147536,
  [SMALL_STATE(3543)] = 147657,
  [SMALL_STATE(3544)] = 147778,
  [SMALL_STATE(3545)] = 147899,
  [SMALL_STATE(3546)] = 148020,
  [SMALL_STATE(3547)] = 148141,
  [SMALL_STATE(3548)] = 148262,
  [SMALL_STATE(3549)] = 148383,
  [SMALL_STATE(3550)] = 148504,
  [SMALL_STATE(3551)] = 148625,
  [SMALL_STATE(3552)] = 148746,
  [SMALL_STATE(3553)] = 148867,
  [SMALL_STATE(3554)] = 148988,
  [SMALL_STATE(3555)] = 149109,
  [SMALL_STATE(3556)] = 149230,
  [SMALL_STATE(3557)] = 149351,
  [SMALL_STATE(3558)] = 149472,
  [SMALL_STATE(3559)] = 149593,
  [SMALL_STATE(3560)] = 149714,
  [SMALL_STATE(3561)] = 149835,
  [SMALL_STATE(3562)] = 149956,
  [SMALL_STATE(3563)] = 150077,
  [SMALL_STATE(3564)] = 150198,
  [SMALL_STATE(3565)] = 150319,
  [SMALL_STATE(3566)] = 150440,
  [SMALL_STATE(3567)] = 150561,
  [SMALL_STATE(3568)] = 150682,
  [SMALL_STATE(3569)] = 150803,
  [SMALL_STATE(3570)] = 150924,
  [SMALL_STATE(3571)] = 151045,
  [SMALL_STATE(3572)] = 151166,
  [SMALL_STATE(3573)] = 151287,
  [SMALL_STATE(3574)] = 151408,
  [SMALL_STATE(3575)] = 151529,
  [SMALL_STATE(3576)] = 151650,
  [SMALL_STATE(3577)] = 151771,
  [SMALL_STATE(3578)] = 151892,
  [SMALL_STATE(3579)] = 152013,
  [SMALL_STATE(3580)] = 152134,
  [SMALL_STATE(3581)] = 152255,
  [SMALL_STATE(3582)] = 152376,
  [SMALL_STATE(3583)] = 152497,
  [SMALL_STATE(3584)] = 152618,
  [SMALL_STATE(3585)] = 152739,
  [SMALL_STATE(3586)] = 152860,
  [SMALL_STATE(3587)] = 152981,
  [SMALL_STATE(3588)] = 153102,
  [SMALL_STATE(3589)] = 153223,
  [SMALL_STATE(3590)] = 153344,
  [SMALL_STATE(3591)] = 153413,
  [SMALL_STATE(3592)] = 153534,
  [SMALL_STATE(3593)] = 153655,
  [SMALL_STATE(3594)] = 153776,
  [SMALL_STATE(3595)] = 153897,
  [SMALL_STATE(3596)] = 154018,
  [SMALL_STATE(3597)] = 154139,
  [SMALL_STATE(3598)] = 154260,
  [SMALL_STATE(3599)] = 154381,
  [SMALL_STATE(3600)] = 154502,
  [SMALL_STATE(3601)] = 154623,
  [SMALL_STATE(3602)] = 154744,
  [SMALL_STATE(3603)] = 154865,
  [SMALL_STATE(3604)] = 154986,
  [SMALL_STATE(3605)] = 155107,
  [SMALL_STATE(3606)] = 155228,
  [SMALL_STATE(3607)] = 155349,
  [SMALL_STATE(3608)] = 155470,
  [SMALL_STATE(3609)] = 155591,
  [SMALL_STATE(3610)] = 155712,
  [SMALL_STATE(3611)] = 155833,
  [SMALL_STATE(3612)] = 155954,
  [SMALL_STATE(3613)] = 156075,
  [SMALL_STATE(3614)] = 156196,
  [SMALL_STATE(3615)] = 156317,
  [SMALL_STATE(3616)] = 156438,
  [SMALL_STATE(3617)] = 156559,
  [SMALL_STATE(3618)] = 156680,
  [SMALL_STATE(3619)] = 156801,
  [SMALL_STATE(3620)] = 156922,
  [SMALL_STATE(3621)] = 157043,
  [SMALL_STATE(3622)] = 157164,
  [SMALL_STATE(3623)] = 157285,
  [SMALL_STATE(3624)] = 157406,
  [SMALL_STATE(3625)] = 157527,
  [SMALL_STATE(3626)] = 157648,
  [SMALL_STATE(3627)] = 157769,
  [SMALL_STATE(3628)] = 157890,
  [SMALL_STATE(3629)] = 158011,
  [SMALL_STATE(3630)] = 158132,
  [SMALL_STATE(3631)] = 158253,
  [SMALL_STATE(3632)] = 158374,
  [SMALL_STATE(3633)] = 158495,
  [SMALL_STATE(3634)] = 158616,
  [SMALL_STATE(3635)] = 158737,
  [SMALL_STATE(3636)] = 158858,
  [SMALL_STATE(3637)] = 158979,
  [SMALL_STATE(3638)] = 159100,
  [SMALL_STATE(3639)] = 159221,
  [SMALL_STATE(3640)] = 159342,
  [SMALL_STATE(3641)] = 159463,
  [SMALL_STATE(3642)] = 159584,
  [SMALL_STATE(3643)] = 159705,
  [SMALL_STATE(3644)] = 159826,
  [SMALL_STATE(3645)] = 159947,
  [SMALL_STATE(3646)] = 160068,
  [SMALL_STATE(3647)] = 160189,
  [SMALL_STATE(3648)] = 160310,
  [SMALL_STATE(3649)] = 160431,
  [SMALL_STATE(3650)] = 160552,
  [SMALL_STATE(3651)] = 160673,
  [SMALL_STATE(3652)] = 160794,
  [SMALL_STATE(3653)] = 160915,
  [SMALL_STATE(3654)] = 161036,
  [SMALL_STATE(3655)] = 161157,
  [SMALL_STATE(3656)] = 161278,
  [SMALL_STATE(3657)] = 161399,
  [SMALL_STATE(3658)] = 161520,
  [SMALL_STATE(3659)] = 161641,
  [SMALL_STATE(3660)] = 161762,
  [SMALL_STATE(3661)] = 161883,
  [SMALL_STATE(3662)] = 162004,
  [SMALL_STATE(3663)] = 162125,
  [SMALL_STATE(3664)] = 162246,
  [SMALL_STATE(3665)] = 162367,
  [SMALL_STATE(3666)] = 162488,
  [SMALL_STATE(3667)] = 162609,
  [SMALL_STATE(3668)] = 162730,
  [SMALL_STATE(3669)] = 162851,
  [SMALL_STATE(3670)] = 162972,
  [SMALL_STATE(3671)] = 163093,
  [SMALL_STATE(3672)] = 163214,
  [SMALL_STATE(3673)] = 163335,
  [SMALL_STATE(3674)] = 163456,
  [SMALL_STATE(3675)] = 163577,
  [SMALL_STATE(3676)] = 163698,
  [SMALL_STATE(3677)] = 163819,
  [SMALL_STATE(3678)] = 163940,
  [SMALL_STATE(3679)] = 164061,
  [SMALL_STATE(3680)] = 164182,
  [SMALL_STATE(3681)] = 164303,
  [SMALL_STATE(3682)] = 164424,
  [SMALL_STATE(3683)] = 164545,
  [SMALL_STATE(3684)] = 164666,
  [SMALL_STATE(3685)] = 164787,
  [SMALL_STATE(3686)] = 164908,
  [SMALL_STATE(3687)] = 165029,
  [SMALL_STATE(3688)] = 165150,
  [SMALL_STATE(3689)] = 165271,
  [SMALL_STATE(3690)] = 165392,
  [SMALL_STATE(3691)] = 165513,
  [SMALL_STATE(3692)] = 165634,
  [SMALL_STATE(3693)] = 165755,
  [SMALL_STATE(3694)] = 165876,
  [SMALL_STATE(3695)] = 165997,
  [SMALL_STATE(3696)] = 166118,
  [SMALL_STATE(3697)] = 166239,
  [SMALL_STATE(3698)] = 166360,
  [SMALL_STATE(3699)] = 166481,
  [SMALL_STATE(3700)] = 166602,
  [SMALL_STATE(3701)] = 166723,
  [SMALL_STATE(3702)] = 166844,
  [SMALL_STATE(3703)] = 166965,
  [SMALL_STATE(3704)] = 167086,
  [SMALL_STATE(3705)] = 167207,
  [SMALL_STATE(3706)] = 167328,
  [SMALL_STATE(3707)] = 167449,
  [SMALL_STATE(3708)] = 167570,
  [SMALL_STATE(3709)] = 167691,
  [SMALL_STATE(3710)] = 167812,
  [SMALL_STATE(3711)] = 167933,
  [SMALL_STATE(3712)] = 168054,
  [SMALL_STATE(3713)] = 168175,
  [SMALL_STATE(3714)] = 168296,
  [SMALL_STATE(3715)] = 168417,
  [SMALL_STATE(3716)] = 168538,
  [SMALL_STATE(3717)] = 168659,
  [SMALL_STATE(3718)] = 168780,
  [SMALL_STATE(3719)] = 168901,
  [SMALL_STATE(3720)] = 169022,
  [SMALL_STATE(3721)] = 169143,
  [SMALL_STATE(3722)] = 169264,
  [SMALL_STATE(3723)] = 169385,
  [SMALL_STATE(3724)] = 169506,
  [SMALL_STATE(3725)] = 169627,
  [SMALL_STATE(3726)] = 169748,
  [SMALL_STATE(3727)] = 169869,
  [SMALL_STATE(3728)] = 169990,
  [SMALL_STATE(3729)] = 170111,
  [SMALL_STATE(3730)] = 170232,
  [SMALL_STATE(3731)] = 170353,
  [SMALL_STATE(3732)] = 170474,
  [SMALL_STATE(3733)] = 170595,
  [SMALL_STATE(3734)] = 170716,
  [SMALL_STATE(3735)] = 170837,
  [SMALL_STATE(3736)] = 170958,
  [SMALL_STATE(3737)] = 171079,
  [SMALL_STATE(3738)] = 171200,
  [SMALL_STATE(3739)] = 171321,
  [SMALL_STATE(3740)] = 171442,
  [SMALL_STATE(3741)] = 171563,
  [SMALL_STATE(3742)] = 171684,
  [SMALL_STATE(3743)] = 171805,
  [SMALL_STATE(3744)] = 171926,
  [SMALL_STATE(3745)] = 172047,
  [SMALL_STATE(3746)] = 172168,
  [SMALL_STATE(3747)] = 172289,
  [SMALL_STATE(3748)] = 172410,
  [SMALL_STATE(3749)] = 172531,
  [SMALL_STATE(3750)] = 172652,
  [SMALL_STATE(3751)] = 172773,
  [SMALL_STATE(3752)] = 172894,
  [SMALL_STATE(3753)] = 173015,
  [SMALL_STATE(3754)] = 173136,
  [SMALL_STATE(3755)] = 173257,
  [SMALL_STATE(3756)] = 173378,
  [SMALL_STATE(3757)] = 173499,
  [SMALL_STATE(3758)] = 173620,
  [SMALL_STATE(3759)] = 173741,
  [SMALL_STATE(3760)] = 173862,
  [SMALL_STATE(3761)] = 173983,
  [SMALL_STATE(3762)] = 174104,
  [SMALL_STATE(3763)] = 174225,
  [SMALL_STATE(3764)] = 174346,
  [SMALL_STATE(3765)] = 174467,
  [SMALL_STATE(3766)] = 174588,
  [SMALL_STATE(3767)] = 174709,
  [SMALL_STATE(3768)] = 174830,
  [SMALL_STATE(3769)] = 174951,
  [SMALL_STATE(3770)] = 175072,
  [SMALL_STATE(3771)] = 175193,
  [SMALL_STATE(3772)] = 175314,
  [SMALL_STATE(3773)] = 175435,
  [SMALL_STATE(3774)] = 175556,
  [SMALL_STATE(3775)] = 175677,
  [SMALL_STATE(3776)] = 175798,
  [SMALL_STATE(3777)] = 175919,
  [SMALL_STATE(3778)] = 176040,
  [SMALL_STATE(3779)] = 176161,
  [SMALL_STATE(3780)] = 176282,
  [SMALL_STATE(3781)] = 176403,
  [SMALL_STATE(3782)] = 176524,
  [SMALL_STATE(3783)] = 176645,
  [SMALL_STATE(3784)] = 176766,
  [SMALL_STATE(3785)] = 176887,
  [SMALL_STATE(3786)] = 177008,
  [SMALL_STATE(3787)] = 177129,
  [SMALL_STATE(3788)] = 177250,
  [SMALL_STATE(3789)] = 177371,
  [SMALL_STATE(3790)] = 177492,
  [SMALL_STATE(3791)] = 177613,
  [SMALL_STATE(3792)] = 177734,
  [SMALL_STATE(3793)] = 177855,
  [SMALL_STATE(3794)] = 177976,
  [SMALL_STATE(3795)] = 178097,
  [SMALL_STATE(3796)] = 178218,
  [SMALL_STATE(3797)] = 178339,
  [SMALL_STATE(3798)] = 178460,
  [SMALL_STATE(3799)] = 178581,
  [SMALL_STATE(3800)] = 178702,
  [SMALL_STATE(3801)] = 178823,
  [SMALL_STATE(3802)] = 178944,
  [SMALL_STATE(3803)] = 179065,
  [SMALL_STATE(3804)] = 179186,
  [SMALL_STATE(3805)] = 179307,
  [SMALL_STATE(3806)] = 179428,
  [SMALL_STATE(3807)] = 179549,
  [SMALL_STATE(3808)] = 179670,
  [SMALL_STATE(3809)] = 179791,
  [SMALL_STATE(3810)] = 179912,
  [SMALL_STATE(3811)] = 180033,
  [SMALL_STATE(3812)] = 180154,
  [SMALL_STATE(3813)] = 180275,
  [SMALL_STATE(3814)] = 180396,
  [SMALL_STATE(3815)] = 180517,
  [SMALL_STATE(3816)] = 180638,
  [SMALL_STATE(3817)] = 180759,
  [SMALL_STATE(3818)] = 180880,
  [SMALL_STATE(3819)] = 181001,
  [SMALL_STATE(3820)] = 181122,
  [SMALL_STATE(3821)] = 181243,
  [SMALL_STATE(3822)] = 181364,
  [SMALL_STATE(3823)] = 181485,
  [SMALL_STATE(3824)] = 181606,
  [SMALL_STATE(3825)] = 181727,
  [SMALL_STATE(3826)] = 181848,
  [SMALL_STATE(3827)] = 181969,
  [SMALL_STATE(3828)] = 182090,
  [SMALL_STATE(3829)] = 182211,
  [SMALL_STATE(3830)] = 182332,
  [SMALL_STATE(3831)] = 182453,
  [SMALL_STATE(3832)] = 182574,
  [SMALL_STATE(3833)] = 182695,
  [SMALL_STATE(3834)] = 182816,
  [SMALL_STATE(3835)] = 182937,
  [SMALL_STATE(3836)] = 183006,
  [SMALL_STATE(3837)] = 183127,
  [SMALL_STATE(3838)] = 183248,
  [SMALL_STATE(3839)] = 183369,
  [SMALL_STATE(3840)] = 183490,
  [SMALL_STATE(3841)] = 183611,
  [SMALL_STATE(3842)] = 183679,
  [SMALL_STATE(3843)] = 183747,
  [SMALL_STATE(3844)] = 183815,
  [SMALL_STATE(3845)] = 183883,
  [SMALL_STATE(3846)] = 183951,
  [SMALL_STATE(3847)] = 184066,
  [SMALL_STATE(3848)] = 184181,
  [SMALL_STATE(3849)] = 184296,
  [SMALL_STATE(3850)] = 184411,
  [SMALL_STATE(3851)] = 184474,
  [SMALL_STATE(3852)] = 184541,
  [SMALL_STATE(3853)] = 184604,
  [SMALL_STATE(3854)] = 184719,
  [SMALL_STATE(3855)] = 184834,
  [SMALL_STATE(3856)] = 184949,
  [SMALL_STATE(3857)] = 185064,
  [SMALL_STATE(3858)] = 185179,
  [SMALL_STATE(3859)] = 185294,
  [SMALL_STATE(3860)] = 185409,
  [SMALL_STATE(3861)] = 185524,
  [SMALL_STATE(3862)] = 185639,
  [SMALL_STATE(3863)] = 185754,
  [SMALL_STATE(3864)] = 185869,
  [SMALL_STATE(3865)] = 185984,
  [SMALL_STATE(3866)] = 186099,
  [SMALL_STATE(3867)] = 186214,
  [SMALL_STATE(3868)] = 186329,
  [SMALL_STATE(3869)] = 186444,
  [SMALL_STATE(3870)] = 186559,
  [SMALL_STATE(3871)] = 186674,
  [SMALL_STATE(3872)] = 186789,
  [SMALL_STATE(3873)] = 186904,
  [SMALL_STATE(3874)] = 187019,
  [SMALL_STATE(3875)] = 187134,
  [SMALL_STATE(3876)] = 187249,
  [SMALL_STATE(3877)] = 187364,
  [SMALL_STATE(3878)] = 187479,
  [SMALL_STATE(3879)] = 187594,
  [SMALL_STATE(3880)] = 187709,
  [SMALL_STATE(3881)] = 187824,
  [SMALL_STATE(3882)] = 187939,
  [SMALL_STATE(3883)] = 188054,
  [SMALL_STATE(3884)] = 188169,
  [SMALL_STATE(3885)] = 188284,
  [SMALL_STATE(3886)] = 188399,
  [SMALL_STATE(3887)] = 188514,
  [SMALL_STATE(3888)] = 188629,
  [SMALL_STATE(3889)] = 188744,
  [SMALL_STATE(3890)] = 188859,
  [SMALL_STATE(3891)] = 188974,
  [SMALL_STATE(3892)] = 189089,
  [SMALL_STATE(3893)] = 189204,
  [SMALL_STATE(3894)] = 189319,
  [SMALL_STATE(3895)] = 189434,
  [SMALL_STATE(3896)] = 189549,
  [SMALL_STATE(3897)] = 189664,
  [SMALL_STATE(3898)] = 189779,
  [SMALL_STATE(3899)] = 189894,
  [SMALL_STATE(3900)] = 190009,
  [SMALL_STATE(3901)] = 190124,
  [SMALL_STATE(3902)] = 190239,
  [SMALL_STATE(3903)] = 190354,
  [SMALL_STATE(3904)] = 190469,
  [SMALL_STATE(3905)] = 190584,
  [SMALL_STATE(3906)] = 190696,
  [SMALL_STATE(3907)] = 190808,
  [SMALL_STATE(3908)] = 190920,
  [SMALL_STATE(3909)] = 191032,
  [SMALL_STATE(3910)] = 191144,
  [SMALL_STATE(3911)] = 191256,
  [SMALL_STATE(3912)] = 191368,
  [SMALL_STATE(3913)] = 191480,
  [SMALL_STATE(3914)] = 191592,
  [SMALL_STATE(3915)] = 191704,
  [SMALL_STATE(3916)] = 191816,
  [SMALL_STATE(3917)] = 191928,
  [SMALL_STATE(3918)] = 192040,
  [SMALL_STATE(3919)] = 192152,
  [SMALL_STATE(3920)] = 192264,
  [SMALL_STATE(3921)] = 192376,
  [SMALL_STATE(3922)] = 192488,
  [SMALL_STATE(3923)] = 192600,
  [SMALL_STATE(3924)] = 192712,
  [SMALL_STATE(3925)] = 192824,
  [SMALL_STATE(3926)] = 192936,
  [SMALL_STATE(3927)] = 193048,
  [SMALL_STATE(3928)] = 193160,
  [SMALL_STATE(3929)] = 193272,
  [SMALL_STATE(3930)] = 193384,
  [SMALL_STATE(3931)] = 193496,
  [SMALL_STATE(3932)] = 193608,
  [SMALL_STATE(3933)] = 193670,
  [SMALL_STATE(3934)] = 193782,
  [SMALL_STATE(3935)] = 193894,
  [SMALL_STATE(3936)] = 194006,
  [SMALL_STATE(3937)] = 194118,
  [SMALL_STATE(3938)] = 194230,
  [SMALL_STATE(3939)] = 194342,
  [SMALL_STATE(3940)] = 194454,
  [SMALL_STATE(3941)] = 194566,
  [SMALL_STATE(3942)] = 194678,
  [SMALL_STATE(3943)] = 194790,
  [SMALL_STATE(3944)] = 194902,
  [SMALL_STATE(3945)] = 195014,
  [SMALL_STATE(3946)] = 195126,
  [SMALL_STATE(3947)] = 195238,
  [SMALL_STATE(3948)] = 195350,
  [SMALL_STATE(3949)] = 195462,
  [SMALL_STATE(3950)] = 195574,
  [SMALL_STATE(3951)] = 195686,
  [SMALL_STATE(3952)] = 195796,
  [SMALL_STATE(3953)] = 195908,
  [SMALL_STATE(3954)] = 196020,
  [SMALL_STATE(3955)] = 196132,
  [SMALL_STATE(3956)] = 196244,
  [SMALL_STATE(3957)] = 196356,
  [SMALL_STATE(3958)] = 196468,
  [SMALL_STATE(3959)] = 196580,
  [SMALL_STATE(3960)] = 196692,
  [SMALL_STATE(3961)] = 196802,
  [SMALL_STATE(3962)] = 196914,
  [SMALL_STATE(3963)] = 197026,
  [SMALL_STATE(3964)] = 197138,
  [SMALL_STATE(3965)] = 197250,
  [SMALL_STATE(3966)] = 197362,
  [SMALL_STATE(3967)] = 197474,
  [SMALL_STATE(3968)] = 197586,
  [SMALL_STATE(3969)] = 197698,
  [SMALL_STATE(3970)] = 197810,
  [SMALL_STATE(3971)] = 197922,
  [SMALL_STATE(3972)] = 198034,
  [SMALL_STATE(3973)] = 198146,
  [SMALL_STATE(3974)] = 198258,
  [SMALL_STATE(3975)] = 198370,
  [SMALL_STATE(3976)] = 198482,
  [SMALL_STATE(3977)] = 198544,
  [SMALL_STATE(3978)] = 198656,
  [SMALL_STATE(3979)] = 198768,
  [SMALL_STATE(3980)] = 198880,
  [SMALL_STATE(3981)] = 198992,
  [SMALL_STATE(3982)] = 199104,
  [SMALL_STATE(3983)] = 199216,
  [SMALL_STATE(3984)] = 199328,
  [SMALL_STATE(3985)] = 199440,
  [SMALL_STATE(3986)] = 199552,
  [SMALL_STATE(3987)] = 199664,
  [SMALL_STATE(3988)] = 199776,
  [SMALL_STATE(3989)] = 199888,
  [SMALL_STATE(3990)] = 200000,
  [SMALL_STATE(3991)] = 200112,
  [SMALL_STATE(3992)] = 200224,
  [SMALL_STATE(3993)] = 200336,
  [SMALL_STATE(3994)] = 200448,
  [SMALL_STATE(3995)] = 200560,
  [SMALL_STATE(3996)] = 200672,
  [SMALL_STATE(3997)] = 200784,
  [SMALL_STATE(3998)] = 200896,
  [SMALL_STATE(3999)] = 201008,
  [SMALL_STATE(4000)] = 201120,
  [SMALL_STATE(4001)] = 201232,
  [SMALL_STATE(4002)] = 201344,
  [SMALL_STATE(4003)] = 201456,
  [SMALL_STATE(4004)] = 201568,
  [SMALL_STATE(4005)] = 201680,
  [SMALL_STATE(4006)] = 201792,
  [SMALL_STATE(4007)] = 201904,
  [SMALL_STATE(4008)] = 202016,
  [SMALL_STATE(4009)] = 202126,
  [SMALL_STATE(4010)] = 202238,
  [SMALL_STATE(4011)] = 202350,
  [SMALL_STATE(4012)] = 202462,
  [SMALL_STATE(4013)] = 202572,
  [SMALL_STATE(4014)] = 202684,
  [SMALL_STATE(4015)] = 202796,
  [SMALL_STATE(4016)] = 202908,
  [SMALL_STATE(4017)] = 203020,
  [SMALL_STATE(4018)] = 203132,
  [SMALL_STATE(4019)] = 203244,
  [SMALL_STATE(4020)] = 203356,
  [SMALL_STATE(4021)] = 203418,
  [SMALL_STATE(4022)] = 203480,
  [SMALL_STATE(4023)] = 203592,
  [SMALL_STATE(4024)] = 203704,
  [SMALL_STATE(4025)] = 203816,
  [SMALL_STATE(4026)] = 203925,
  [SMALL_STATE(4027)] = 203986,
  [SMALL_STATE(4028)] = 204047,
  [SMALL_STATE(4029)] = 204108,
  [SMALL_STATE(4030)] = 204169,
  [SMALL_STATE(4031)] = 204230,
  [SMALL_STATE(4032)] = 204291,
  [SMALL_STATE(4033)] = 204400,
  [SMALL_STATE(4034)] = 204461,
  [SMALL_STATE(4035)] = 204522,
  [SMALL_STATE(4036)] = 204582,
  [SMALL_STATE(4037)] = 204642,
  [SMALL_STATE(4038)] = 204702,
  [SMALL_STATE(4039)] = 204762,
  [SMALL_STATE(4040)] = 204822,
  [SMALL_STATE(4041)] = 204928,
  [SMALL_STATE(4042)] = 204988,
  [SMALL_STATE(4043)] = 205094,
  [SMALL_STATE(4044)] = 205154,
  [SMALL_STATE(4045)] = 205214,
  [SMALL_STATE(4046)] = 205274,
  [SMALL_STATE(4047)] = 205380,
  [SMALL_STATE(4048)] = 205486,
  [SMALL_STATE(4049)] = 205546,
  [SMALL_STATE(4050)] = 205605,
  [SMALL_STATE(4051)] = 205664,
  [SMALL_STATE(4052)] = 205723,
  [SMALL_STATE(4053)] = 205782,
  [SMALL_STATE(4054)] = 205841,
  [SMALL_STATE(4055)] = 205900,
  [SMALL_STATE(4056)] = 205959,
  [SMALL_STATE(4057)] = 206016,
  [SMALL_STATE(4058)] = 206075,
  [SMALL_STATE(4059)] = 206134,
  [SMALL_STATE(4060)] = 206193,
  [SMALL_STATE(4061)] = 206252,
  [SMALL_STATE(4062)] = 206311,
  [SMALL_STATE(4063)] = 206368,
  [SMALL_STATE(4064)] = 206426,
  [SMALL_STATE(4065)] = 206484,
  [SMALL_STATE(4066)] = 206584,
  [SMALL_STATE(4067)] = 206642,
  [SMALL_STATE(4068)] = 206742,
  [SMALL_STATE(4069)] = 206800,
  [SMALL_STATE(4070)] = 206866,
  [SMALL_STATE(4071)] = 206924,
  [SMALL_STATE(4072)] = 206982,
  [SMALL_STATE(4073)] = 207040,
  [SMALL_STATE(4074)] = 207098,
  [SMALL_STATE(4075)] = 207156,
  [SMALL_STATE(4076)] = 207213,
  [SMALL_STATE(4077)] = 207270,
  [SMALL_STATE(4078)] = 207327,
  [SMALL_STATE(4079)] = 207384,
  [SMALL_STATE(4080)] = 207478,
  [SMALL_STATE(4081)] = 207572,
  [SMALL_STATE(4082)] = 207666,
  [SMALL_STATE(4083)] = 207760,
  [SMALL_STATE(4084)] = 207854,
  [SMALL_STATE(4085)] = 207948,
  [SMALL_STATE(4086)] = 208042,
  [SMALL_STATE(4087)] = 208136,
  [SMALL_STATE(4088)] = 208230,
  [SMALL_STATE(4089)] = 208324,
  [SMALL_STATE(4090)] = 208418,
  [SMALL_STATE(4091)] = 208474,
  [SMALL_STATE(4092)] = 208568,
  [SMALL_STATE(4093)] = 208662,
  [SMALL_STATE(4094)] = 208756,
  [SMALL_STATE(4095)] = 208850,
  [SMALL_STATE(4096)] = 208944,
  [SMALL_STATE(4097)] = 209038,
  [SMALL_STATE(4098)] = 209132,
  [SMALL_STATE(4099)] = 209226,
  [SMALL_STATE(4100)] = 209320,
  [SMALL_STATE(4101)] = 209414,
  [SMALL_STATE(4102)] = 209508,
  [SMALL_STATE(4103)] = 209602,
  [SMALL_STATE(4104)] = 209696,
  [SMALL_STATE(4105)] = 209790,
  [SMALL_STATE(4106)] = 209884,
  [SMALL_STATE(4107)] = 209978,
  [SMALL_STATE(4108)] = 210072,
  [SMALL_STATE(4109)] = 210166,
  [SMALL_STATE(4110)] = 210260,
  [SMALL_STATE(4111)] = 210354,
  [SMALL_STATE(4112)] = 210448,
  [SMALL_STATE(4113)] = 210542,
  [SMALL_STATE(4114)] = 210636,
  [SMALL_STATE(4115)] = 210730,
  [SMALL_STATE(4116)] = 210824,
  [SMALL_STATE(4117)] = 210918,
  [SMALL_STATE(4118)] = 211012,
  [SMALL_STATE(4119)] = 211106,
  [SMALL_STATE(4120)] = 211200,
  [SMALL_STATE(4121)] = 211294,
  [SMALL_STATE(4122)] = 211388,
  [SMALL_STATE(4123)] = 211482,
  [SMALL_STATE(4124)] = 211576,
  [SMALL_STATE(4125)] = 211670,
  [SMALL_STATE(4126)] = 211764,
  [SMALL_STATE(4127)] = 211858,
  [SMALL_STATE(4128)] = 211952,
  [SMALL_STATE(4129)] = 212046,
  [SMALL_STATE(4130)] = 212140,
  [SMALL_STATE(4131)] = 212234,
  [SMALL_STATE(4132)] = 212328,
  [SMALL_STATE(4133)] = 212422,
  [SMALL_STATE(4134)] = 212516,
  [SMALL_STATE(4135)] = 212610,
  [SMALL_STATE(4136)] = 212704,
  [SMALL_STATE(4137)] = 212798,
  [SMALL_STATE(4138)] = 212905,
  [SMALL_STATE(4139)] = 213012,
  [SMALL_STATE(4140)] = 213103,
  [SMALL_STATE(4141)] = 213194,
  [SMALL_STATE(4142)] = 213251,
  [SMALL_STATE(4143)] = 213342,
  [SMALL_STATE(4144)] = 213433,
  [SMALL_STATE(4145)] = 213524,
  [SMALL_STATE(4146)] = 213581,
  [SMALL_STATE(4147)] = 213638,
  [SMALL_STATE(4148)] = 213729,
  [SMALL_STATE(4149)] = 213820,
  [SMALL_STATE(4150)] = 213927,
  [SMALL_STATE(4151)] = 214034,
  [SMALL_STATE(4152)] = 214125,
  [SMALL_STATE(4153)] = 214216,
  [SMALL_STATE(4154)] = 214307,
  [SMALL_STATE(4155)] = 214398,
  [SMALL_STATE(4156)] = 214505,
  [SMALL_STATE(4157)] = 214562,
  [SMALL_STATE(4158)] = 214653,
  [SMALL_STATE(4159)] = 214710,
  [SMALL_STATE(4160)] = 214817,
  [SMALL_STATE(4161)] = 214924,
  [SMALL_STATE(4162)] = 214979,
  [SMALL_STATE(4163)] = 215036,
  [SMALL_STATE(4164)] = 215143,
  [SMALL_STATE(4165)] = 215198,
  [SMALL_STATE(4166)] = 215305,
  [SMALL_STATE(4167)] = 215362,
  [SMALL_STATE(4168)] = 215453,
  [SMALL_STATE(4169)] = 215510,
  [SMALL_STATE(4170)] = 215601,
  [SMALL_STATE(4171)] = 215708,
  [SMALL_STATE(4172)] = 215815,
  [SMALL_STATE(4173)] = 215922,
  [SMALL_STATE(4174)] = 216013,
  [SMALL_STATE(4175)] = 216104,
  [SMALL_STATE(4176)] = 216211,
  [SMALL_STATE(4177)] = 216318,
  [SMALL_STATE(4178)] = 216375,
  [SMALL_STATE(4179)] = 216482,
  [SMALL_STATE(4180)] = 216534,
  [SMALL_STATE(4181)] = 216625,
  [SMALL_STATE(4182)] = 216716,
  [SMALL_STATE(4183)] = 216807,
  [SMALL_STATE(4184)] = 216898,
  [SMALL_STATE(4185)] = 216989,
  [SMALL_STATE(4186)] = 217080,
  [SMALL_STATE(4187)] = 217171,
  [SMALL_STATE(4188)] = 217262,
  [SMALL_STATE(4189)] = 217353,
  [SMALL_STATE(4190)] = 217444,
  [SMALL_STATE(4191)] = 217535,
  [SMALL_STATE(4192)] = 217626,
  [SMALL_STATE(4193)] = 217717,
  [SMALL_STATE(4194)] = 217808,
  [SMALL_STATE(4195)] = 217899,
  [SMALL_STATE(4196)] = 217990,
  [SMALL_STATE(4197)] = 218081,
  [SMALL_STATE(4198)] = 218172,
  [SMALL_STATE(4199)] = 218263,
  [SMALL_STATE(4200)] = 218354,
  [SMALL_STATE(4201)] = 218445,
  [SMALL_STATE(4202)] = 218536,
  [SMALL_STATE(4203)] = 218627,
  [SMALL_STATE(4204)] = 218718,
  [SMALL_STATE(4205)] = 218809,
  [SMALL_STATE(4206)] = 218900,
  [SMALL_STATE(4207)] = 218991,
  [SMALL_STATE(4208)] = 219082,
  [SMALL_STATE(4209)] = 219173,
  [SMALL_STATE(4210)] = 219264,
  [SMALL_STATE(4211)] = 219355,
  [SMALL_STATE(4212)] = 219446,
  [SMALL_STATE(4213)] = 219537,
  [SMALL_STATE(4214)] = 219628,
  [SMALL_STATE(4215)] = 219719,
  [SMALL_STATE(4216)] = 219810,
  [SMALL_STATE(4217)] = 219901,
  [SMALL_STATE(4218)] = 219992,
  [SMALL_STATE(4219)] = 220083,
  [SMALL_STATE(4220)] = 220174,
  [SMALL_STATE(4221)] = 220265,
  [SMALL_STATE(4222)] = 220356,
  [SMALL_STATE(4223)] = 220447,
  [SMALL_STATE(4224)] = 220538,
  [SMALL_STATE(4225)] = 220629,
  [SMALL_STATE(4226)] = 220720,
  [SMALL_STATE(4227)] = 220811,
  [SMALL_STATE(4228)] = 220902,
  [SMALL_STATE(4229)] = 220993,
  [SMALL_STATE(4230)] = 221084,
  [SMALL_STATE(4231)] = 221175,
  [SMALL_STATE(4232)] = 221266,
  [SMALL_STATE(4233)] = 221357,
  [SMALL_STATE(4234)] = 221448,
  [SMALL_STATE(4235)] = 221539,
  [SMALL_STATE(4236)] = 221630,
  [SMALL_STATE(4237)] = 221721,
  [SMALL_STATE(4238)] = 221812,
  [SMALL_STATE(4239)] = 221903,
  [SMALL_STATE(4240)] = 221994,
  [SMALL_STATE(4241)] = 222085,
  [SMALL_STATE(4242)] = 222176,
  [SMALL_STATE(4243)] = 222267,
  [SMALL_STATE(4244)] = 222358,
  [SMALL_STATE(4245)] = 222410,
  [SMALL_STATE(4246)] = 222461,
  [SMALL_STATE(4247)] = 222553,
  [SMALL_STATE(4248)] = 222617,
  [SMALL_STATE(4249)] = 222709,
  [SMALL_STATE(4250)] = 222757,
  [SMALL_STATE(4251)] = 222849,
  [SMALL_STATE(4252)] = 222941,
  [SMALL_STATE(4253)] = 223033,
  [SMALL_STATE(4254)] = 223097,
  [SMALL_STATE(4255)] = 223188,
  [SMALL_STATE(4256)] = 223253,
  [SMALL_STATE(4257)] = 223346,
  [SMALL_STATE(4258)] = 223407,
  [SMALL_STATE(4259)] = 223498,
  [SMALL_STATE(4260)] = 223589,
  [SMALL_STATE(4261)] = 223680,
  [SMALL_STATE(4262)] = 223773,
  [SMALL_STATE(4263)] = 223866,
  [SMALL_STATE(4264)] = 223929,
  [SMALL_STATE(4265)] = 223990,
  [SMALL_STATE(4266)] = 224083,
  [SMALL_STATE(4267)] = 224176,
  [SMALL_STATE(4268)] = 224237,
  [SMALL_STATE(4269)] = 224286,
  [SMALL_STATE(4270)] = 224377,
  [SMALL_STATE(4271)] = 224468,
  [SMALL_STATE(4272)] = 224559,
  [SMALL_STATE(4273)] = 224650,
  [SMALL_STATE(4274)] = 224741,
  [SMALL_STATE(4275)] = 224832,
  [SMALL_STATE(4276)] = 224925,
  [SMALL_STATE(4277)] = 225018,
  [SMALL_STATE(4278)] = 225064,
  [SMALL_STATE(4279)] = 225124,
  [SMALL_STATE(4280)] = 225184,
  [SMALL_STATE(4281)] = 225270,
  [SMALL_STATE(4282)] = 225356,
  [SMALL_STATE(4283)] = 225442,
  [SMALL_STATE(4284)] = 225502,
  [SMALL_STATE(4285)] = 225588,
  [SMALL_STATE(4286)] = 225652,
  [SMALL_STATE(4287)] = 225712,
  [SMALL_STATE(4288)] = 225798,
  [SMALL_STATE(4289)] = 225884,
  [SMALL_STATE(4290)] = 225944,
  [SMALL_STATE(4291)] = 226006,
  [SMALL_STATE(4292)] = 226052,
  [SMALL_STATE(4293)] = 226112,
  [SMALL_STATE(4294)] = 226172,
  [SMALL_STATE(4295)] = 226218,
  [SMALL_STATE(4296)] = 226264,
  [SMALL_STATE(4297)] = 226350,
  [SMALL_STATE(4298)] = 226436,
  [SMALL_STATE(4299)] = 226522,
  [SMALL_STATE(4300)] = 226608,
  [SMALL_STATE(4301)] = 226694,
  [SMALL_STATE(4302)] = 226780,
  [SMALL_STATE(4303)] = 226866,
  [SMALL_STATE(4304)] = 226952,
  [SMALL_STATE(4305)] = 227038,
  [SMALL_STATE(4306)] = 227124,
  [SMALL_STATE(4307)] = 227210,
  [SMALL_STATE(4308)] = 227296,
  [SMALL_STATE(4309)] = 227382,
  [SMALL_STATE(4310)] = 227468,
  [SMALL_STATE(4311)] = 227554,
  [SMALL_STATE(4312)] = 227640,
  [SMALL_STATE(4313)] = 227726,
  [SMALL_STATE(4314)] = 227812,
  [SMALL_STATE(4315)] = 227898,
  [SMALL_STATE(4316)] = 227984,
  [SMALL_STATE(4317)] = 228070,
  [SMALL_STATE(4318)] = 228156,
  [SMALL_STATE(4319)] = 228242,
  [SMALL_STATE(4320)] = 228328,
  [SMALL_STATE(4321)] = 228414,
  [SMALL_STATE(4322)] = 228500,
  [SMALL_STATE(4323)] = 228586,
  [SMALL_STATE(4324)] = 228672,
  [SMALL_STATE(4325)] = 228758,
  [SMALL_STATE(4326)] = 228844,
  [SMALL_STATE(4327)] = 228930,
  [SMALL_STATE(4328)] = 229016,
  [SMALL_STATE(4329)] = 229102,
  [SMALL_STATE(4330)] = 229188,
  [SMALL_STATE(4331)] = 229274,
  [SMALL_STATE(4332)] = 229360,
  [SMALL_STATE(4333)] = 229446,
  [SMALL_STATE(4334)] = 229504,
  [SMALL_STATE(4335)] = 229590,
  [SMALL_STATE(4336)] = 229676,
  [SMALL_STATE(4337)] = 229762,
  [SMALL_STATE(4338)] = 229848,
  [SMALL_STATE(4339)] = 229934,
  [SMALL_STATE(4340)] = 230020,
  [SMALL_STATE(4341)] = 230106,
  [SMALL_STATE(4342)] = 230192,
  [SMALL_STATE(4343)] = 230278,
  [SMALL_STATE(4344)] = 230364,
  [SMALL_STATE(4345)] = 230450,
  [SMALL_STATE(4346)] = 230536,
  [SMALL_STATE(4347)] = 230622,
  [SMALL_STATE(4348)] = 230708,
  [SMALL_STATE(4349)] = 230768,
  [SMALL_STATE(4350)] = 230854,
  [SMALL_STATE(4351)] = 230940,
  [SMALL_STATE(4352)] = 231026,
  [SMALL_STATE(4353)] = 231112,
  [SMALL_STATE(4354)] = 231158,
  [SMALL_STATE(4355)] = 231244,
  [SMALL_STATE(4356)] = 231290,
  [SMALL_STATE(4357)] = 231376,
  [SMALL_STATE(4358)] = 231462,
  [SMALL_STATE(4359)] = 231548,
  [SMALL_STATE(4360)] = 231634,
  [SMALL_STATE(4361)] = 231720,
  [SMALL_STATE(4362)] = 231806,
  [SMALL_STATE(4363)] = 231892,
  [SMALL_STATE(4364)] = 231978,
  [SMALL_STATE(4365)] = 232064,
  [SMALL_STATE(4366)] = 232150,
  [SMALL_STATE(4367)] = 232236,
  [SMALL_STATE(4368)] = 232282,
  [SMALL_STATE(4369)] = 232328,
  [SMALL_STATE(4370)] = 232374,
  [SMALL_STATE(4371)] = 232438,
  [SMALL_STATE(4372)] = 232524,
  [SMALL_STATE(4373)] = 232570,
  [SMALL_STATE(4374)] = 232656,
  [SMALL_STATE(4375)] = 232742,
  [SMALL_STATE(4376)] = 232828,
  [SMALL_STATE(4377)] = 232888,
  [SMALL_STATE(4378)] = 232974,
  [SMALL_STATE(4379)] = 233034,
  [SMALL_STATE(4380)] = 233096,
  [SMALL_STATE(4381)] = 233164,
  [SMALL_STATE(4382)] = 233210,
  [SMALL_STATE(4383)] = 233296,
  [SMALL_STATE(4384)] = 233357,
  [SMALL_STATE(4385)] = 233406,
  [SMALL_STATE(4386)] = 233465,
  [SMALL_STATE(4387)] = 233518,
  [SMALL_STATE(4388)] = 233569,
  [SMALL_STATE(4389)] = 233628,
  [SMALL_STATE(4390)] = 233685,
  [SMALL_STATE(4391)] = 233744,
  [SMALL_STATE(4392)] = 233805,
  [SMALL_STATE(4393)] = 233888,
  [SMALL_STATE(4394)] = 233947,
  [SMALL_STATE(4395)] = 234008,
  [SMALL_STATE(4396)] = 234057,
  [SMALL_STATE(4397)] = 234116,
  [SMALL_STATE(4398)] = 234175,
  [SMALL_STATE(4399)] = 234222,
  [SMALL_STATE(4400)] = 234269,
  [SMALL_STATE(4401)] = 234352,
  [SMALL_STATE(4402)] = 234397,
  [SMALL_STATE(4403)] = 234480,
  [SMALL_STATE(4404)] = 234563,
  [SMALL_STATE(4405)] = 234630,
  [SMALL_STATE(4406)] = 234713,
  [SMALL_STATE(4407)] = 234760,
  [SMALL_STATE(4408)] = 234843,
  [SMALL_STATE(4409)] = 234926,
  [SMALL_STATE(4410)] = 234987,
  [SMALL_STATE(4411)] = 235070,
  [SMALL_STATE(4412)] = 235117,
  [SMALL_STATE(4413)] = 235176,
  [SMALL_STATE(4414)] = 235243,
  [SMALL_STATE(4415)] = 235326,
  [SMALL_STATE(4416)] = 235409,
  [SMALL_STATE(4417)] = 235468,
  [SMALL_STATE(4418)] = 235551,
  [SMALL_STATE(4419)] = 235634,
  [SMALL_STATE(4420)] = 235717,
  [SMALL_STATE(4421)] = 235800,
  [SMALL_STATE(4422)] = 235883,
  [SMALL_STATE(4423)] = 235966,
  [SMALL_STATE(4424)] = 236049,
  [SMALL_STATE(4425)] = 236132,
  [SMALL_STATE(4426)] = 236215,
  [SMALL_STATE(4427)] = 236274,
  [SMALL_STATE(4428)] = 236321,
  [SMALL_STATE(4429)] = 236378,
  [SMALL_STATE(4430)] = 236461,
  [SMALL_STATE(4431)] = 236544,
  [SMALL_STATE(4432)] = 236627,
  [SMALL_STATE(4433)] = 236710,
  [SMALL_STATE(4434)] = 236793,
  [SMALL_STATE(4435)] = 236876,
  [SMALL_STATE(4436)] = 236937,
  [SMALL_STATE(4437)] = 237020,
  [SMALL_STATE(4438)] = 237083,
  [SMALL_STATE(4439)] = 237166,
  [SMALL_STATE(4440)] = 237233,
  [SMALL_STATE(4441)] = 237292,
  [SMALL_STATE(4442)] = 237375,
  [SMALL_STATE(4443)] = 237458,
  [SMALL_STATE(4444)] = 237541,
  [SMALL_STATE(4445)] = 237624,
  [SMALL_STATE(4446)] = 237695,
  [SMALL_STATE(4447)] = 237778,
  [SMALL_STATE(4448)] = 237837,
  [SMALL_STATE(4449)] = 237898,
  [SMALL_STATE(4450)] = 237957,
  [SMALL_STATE(4451)] = 238016,
  [SMALL_STATE(4452)] = 238075,
  [SMALL_STATE(4453)] = 238138,
  [SMALL_STATE(4454)] = 238201,
  [SMALL_STATE(4455)] = 238260,
  [SMALL_STATE(4456)] = 238319,
  [SMALL_STATE(4457)] = 238380,
  [SMALL_STATE(4458)] = 238441,
  [SMALL_STATE(4459)] = 238500,
  [SMALL_STATE(4460)] = 238583,
  [SMALL_STATE(4461)] = 238642,
  [SMALL_STATE(4462)] = 238725,
  [SMALL_STATE(4463)] = 238784,
  [SMALL_STATE(4464)] = 238867,
  [SMALL_STATE(4465)] = 238914,
  [SMALL_STATE(4466)] = 238961,
  [SMALL_STATE(4467)] = 239044,
  [SMALL_STATE(4468)] = 239090,
  [SMALL_STATE(4469)] = 239148,
  [SMALL_STATE(4470)] = 239196,
  [SMALL_STATE(4471)] = 239242,
  [SMALL_STATE(4472)] = 239288,
  [SMALL_STATE(4473)] = 239334,
  [SMALL_STATE(4474)] = 239380,
  [SMALL_STATE(4475)] = 239426,
  [SMALL_STATE(4476)] = 239472,
  [SMALL_STATE(4477)] = 239518,
  [SMALL_STATE(4478)] = 239576,
  [SMALL_STATE(4479)] = 239626,
  [SMALL_STATE(4480)] = 239684,
  [SMALL_STATE(4481)] = 239740,
  [SMALL_STATE(4482)] = 239800,
  [SMALL_STATE(4483)] = 239858,
  [SMALL_STATE(4484)] = 239916,
  [SMALL_STATE(4485)] = 239962,
  [SMALL_STATE(4486)] = 240020,
  [SMALL_STATE(4487)] = 240078,
  [SMALL_STATE(4488)] = 240130,
  [SMALL_STATE(4489)] = 240180,
  [SMALL_STATE(4490)] = 240238,
  [SMALL_STATE(4491)] = 240284,
  [SMALL_STATE(4492)] = 240340,
  [SMALL_STATE(4493)] = 240398,
  [SMALL_STATE(4494)] = 240450,
  [SMALL_STATE(4495)] = 240508,
  [SMALL_STATE(4496)] = 240566,
  [SMALL_STATE(4497)] = 240624,
  [SMALL_STATE(4498)] = 240684,
  [SMALL_STATE(4499)] = 240732,
  [SMALL_STATE(4500)] = 240780,
  [SMALL_STATE(4501)] = 240838,
  [SMALL_STATE(4502)] = 240884,
  [SMALL_STATE(4503)] = 240930,
  [SMALL_STATE(4504)] = 240976,
  [SMALL_STATE(4505)] = 241024,
  [SMALL_STATE(4506)] = 241084,
  [SMALL_STATE(4507)] = 241136,
  [SMALL_STATE(4508)] = 241186,
  [SMALL_STATE(4509)] = 241232,
  [SMALL_STATE(4510)] = 241282,
  [SMALL_STATE(4511)] = 241340,
  [SMALL_STATE(4512)] = 241420,
  [SMALL_STATE(4513)] = 241466,
  [SMALL_STATE(4514)] = 241524,
  [SMALL_STATE(4515)] = 241582,
  [SMALL_STATE(4516)] = 241642,
  [SMALL_STATE(4517)] = 241692,
  [SMALL_STATE(4518)] = 241750,
  [SMALL_STATE(4519)] = 241812,
  [SMALL_STATE(4520)] = 241862,
  [SMALL_STATE(4521)] = 241920,
  [SMALL_STATE(4522)] = 241976,
  [SMALL_STATE(4523)] = 242036,
  [SMALL_STATE(4524)] = 242096,
  [SMALL_STATE(4525)] = 242154,
  [SMALL_STATE(4526)] = 242220,
  [SMALL_STATE(4527)] = 242266,
  [SMALL_STATE(4528)] = 242324,
  [SMALL_STATE(4529)] = 242384,
  [SMALL_STATE(4530)] = 242444,
  [SMALL_STATE(4531)] = 242490,
  [SMALL_STATE(4532)] = 242550,
  [SMALL_STATE(4533)] = 242612,
  [SMALL_STATE(4534)] = 242658,
  [SMALL_STATE(4535)] = 242718,
  [SMALL_STATE(4536)] = 242776,
  [SMALL_STATE(4537)] = 242842,
  [SMALL_STATE(4538)] = 242908,
  [SMALL_STATE(4539)] = 242966,
  [SMALL_STATE(4540)] = 243012,
  [SMALL_STATE(4541)] = 243074,
  [SMALL_STATE(4542)] = 243132,
  [SMALL_STATE(4543)] = 243178,
  [SMALL_STATE(4544)] = 243224,
  [SMALL_STATE(4545)] = 243270,
  [SMALL_STATE(4546)] = 243316,
  [SMALL_STATE(4547)] = 243362,
  [SMALL_STATE(4548)] = 243420,
  [SMALL_STATE(4549)] = 243468,
  [SMALL_STATE(4550)] = 243516,
  [SMALL_STATE(4551)] = 243574,
  [SMALL_STATE(4552)] = 243620,
  [SMALL_STATE(4553)] = 243672,
  [SMALL_STATE(4554)] = 243722,
  [SMALL_STATE(4555)] = 243780,
  [SMALL_STATE(4556)] = 243826,
  [SMALL_STATE(4557)] = 243878,
  [SMALL_STATE(4558)] = 243938,
  [SMALL_STATE(4559)] = 243998,
  [SMALL_STATE(4560)] = 244056,
  [SMALL_STATE(4561)] = 244114,
  [SMALL_STATE(4562)] = 244180,
  [SMALL_STATE(4563)] = 244232,
  [SMALL_STATE(4564)] = 244302,
  [SMALL_STATE(4565)] = 244368,
  [SMALL_STATE(4566)] = 244438,
  [SMALL_STATE(4567)] = 244487,
  [SMALL_STATE(4568)] = 244546,
  [SMALL_STATE(4569)] = 244603,
  [SMALL_STATE(4570)] = 244654,
  [SMALL_STATE(4571)] = 244703,
  [SMALL_STATE(4572)] = 244772,
  [SMALL_STATE(4573)] = 244817,
  [SMALL_STATE(4574)] = 244862,
  [SMALL_STATE(4575)] = 244909,
  [SMALL_STATE(4576)] = 244964,
  [SMALL_STATE(4577)] = 245015,
  [SMALL_STATE(4578)] = 245060,
  [SMALL_STATE(4579)] = 245105,
  [SMALL_STATE(4580)] = 245164,
  [SMALL_STATE(4581)] = 245209,
  [SMALL_STATE(4582)] = 245254,
  [SMALL_STATE(4583)] = 245299,
  [SMALL_STATE(4584)] = 245350,
  [SMALL_STATE(4585)] = 245399,
  [SMALL_STATE(4586)] = 245448,
  [SMALL_STATE(4587)] = 245507,
  [SMALL_STATE(4588)] = 245566,
  [SMALL_STATE(4589)] = 245611,
  [SMALL_STATE(4590)] = 245660,
  [SMALL_STATE(4591)] = 245717,
  [SMALL_STATE(4592)] = 245762,
  [SMALL_STATE(4593)] = 245827,
  [SMALL_STATE(4594)] = 245872,
  [SMALL_STATE(4595)] = 245917,
  [SMALL_STATE(4596)] = 245962,
  [SMALL_STATE(4597)] = 246007,
  [SMALL_STATE(4598)] = 246052,
  [SMALL_STATE(4599)] = 246097,
  [SMALL_STATE(4600)] = 246142,
  [SMALL_STATE(4601)] = 246191,
  [SMALL_STATE(4602)] = 246236,
  [SMALL_STATE(4603)] = 246287,
  [SMALL_STATE(4604)] = 246344,
  [SMALL_STATE(4605)] = 246389,
  [SMALL_STATE(4606)] = 246434,
  [SMALL_STATE(4607)] = 246479,
  [SMALL_STATE(4608)] = 246536,
  [SMALL_STATE(4609)] = 246581,
  [SMALL_STATE(4610)] = 246640,
  [SMALL_STATE(4611)] = 246687,
  [SMALL_STATE(4612)] = 246734,
  [SMALL_STATE(4613)] = 246793,
  [SMALL_STATE(4614)] = 246850,
  [SMALL_STATE(4615)] = 246901,
  [SMALL_STATE(4616)] = 246958,
  [SMALL_STATE(4617)] = 247007,
  [SMALL_STATE(4618)] = 247064,
  [SMALL_STATE(4619)] = 247109,
  [SMALL_STATE(4620)] = 247166,
  [SMALL_STATE(4621)] = 247211,
  [SMALL_STATE(4622)] = 247256,
  [SMALL_STATE(4623)] = 247315,
  [SMALL_STATE(4624)] = 247362,
  [SMALL_STATE(4625)] = 247423,
  [SMALL_STATE(4626)] = 247468,
  [SMALL_STATE(4627)] = 247513,
  [SMALL_STATE(4628)] = 247564,
  [SMALL_STATE(4629)] = 247629,
  [SMALL_STATE(4630)] = 247686,
  [SMALL_STATE(4631)] = 247733,
  [SMALL_STATE(4632)] = 247784,
  [SMALL_STATE(4633)] = 247831,
  [SMALL_STATE(4634)] = 247876,
  [SMALL_STATE(4635)] = 247921,
  [SMALL_STATE(4636)] = 247982,
  [SMALL_STATE(4637)] = 248033,
  [SMALL_STATE(4638)] = 248086,
  [SMALL_STATE(4639)] = 248155,
  [SMALL_STATE(4640)] = 248212,
  [SMALL_STATE(4641)] = 248269,
  [SMALL_STATE(4642)] = 248326,
  [SMALL_STATE(4643)] = 248385,
  [SMALL_STATE(4644)] = 248454,
  [SMALL_STATE(4645)] = 248513,
  [SMALL_STATE(4646)] = 248570,
  [SMALL_STATE(4647)] = 248615,
  [SMALL_STATE(4648)] = 248672,
  [SMALL_STATE(4649)] = 248717,
  [SMALL_STATE(4650)] = 248768,
  [SMALL_STATE(4651)] = 248817,
  [SMALL_STATE(4652)] = 248876,
  [SMALL_STATE(4653)] = 248925,
  [SMALL_STATE(4654)] = 248970,
  [SMALL_STATE(4655)] = 249015,
  [SMALL_STATE(4656)] = 249060,
  [SMALL_STATE(4657)] = 249117,
  [SMALL_STATE(4658)] = 249174,
  [SMALL_STATE(4659)] = 249231,
  [SMALL_STATE(4660)] = 249276,
  [SMALL_STATE(4661)] = 249321,
  [SMALL_STATE(4662)] = 249366,
  [SMALL_STATE(4663)] = 249411,
  [SMALL_STATE(4664)] = 249456,
  [SMALL_STATE(4665)] = 249505,
  [SMALL_STATE(4666)] = 249562,
  [SMALL_STATE(4667)] = 249619,
  [SMALL_STATE(4668)] = 249664,
  [SMALL_STATE(4669)] = 249713,
  [SMALL_STATE(4670)] = 249770,
  [SMALL_STATE(4671)] = 249815,
  [SMALL_STATE(4672)] = 249860,
  [SMALL_STATE(4673)] = 249905,
  [SMALL_STATE(4674)] = 249960,
  [SMALL_STATE(4675)] = 250005,
  [SMALL_STATE(4676)] = 250050,
  [SMALL_STATE(4677)] = 250107,
  [SMALL_STATE(4678)] = 250164,
  [SMALL_STATE(4679)] = 250209,
  [SMALL_STATE(4680)] = 250260,
  [SMALL_STATE(4681)] = 250319,
  [SMALL_STATE(4682)] = 250376,
  [SMALL_STATE(4683)] = 250433,
  [SMALL_STATE(4684)] = 250478,
  [SMALL_STATE(4685)] = 250527,
  [SMALL_STATE(4686)] = 250572,
  [SMALL_STATE(4687)] = 250631,
  [SMALL_STATE(4688)] = 250676,
  [SMALL_STATE(4689)] = 250721,
  [SMALL_STATE(4690)] = 250780,
  [SMALL_STATE(4691)] = 250831,
  [SMALL_STATE(4692)] = 250876,
  [SMALL_STATE(4693)] = 250921,
  [SMALL_STATE(4694)] = 250966,
  [SMALL_STATE(4695)] = 251031,
  [SMALL_STATE(4696)] = 251090,
  [SMALL_STATE(4697)] = 251135,
  [SMALL_STATE(4698)] = 251192,
  [SMALL_STATE(4699)] = 251249,
  [SMALL_STATE(4700)] = 251306,
  [SMALL_STATE(4701)] = 251351,
  [SMALL_STATE(4702)] = 251396,
  [SMALL_STATE(4703)] = 251443,
  [SMALL_STATE(4704)] = 251492,
  [SMALL_STATE(4705)] = 251537,
  [SMALL_STATE(4706)] = 251582,
  [SMALL_STATE(4707)] = 251639,
  [SMALL_STATE(4708)] = 251696,
  [SMALL_STATE(4709)] = 251753,
  [SMALL_STATE(4710)] = 251804,
  [SMALL_STATE(4711)] = 251869,
  [SMALL_STATE(4712)] = 251916,
  [SMALL_STATE(4713)] = 251977,
  [SMALL_STATE(4714)] = 252022,
  [SMALL_STATE(4715)] = 252087,
  [SMALL_STATE(4716)] = 252132,
  [SMALL_STATE(4717)] = 252177,
  [SMALL_STATE(4718)] = 252222,
  [SMALL_STATE(4719)] = 252267,
  [SMALL_STATE(4720)] = 252312,
  [SMALL_STATE(4721)] = 252359,
  [SMALL_STATE(4722)] = 252404,
  [SMALL_STATE(4723)] = 252449,
  [SMALL_STATE(4724)] = 252494,
  [SMALL_STATE(4725)] = 252553,
  [SMALL_STATE(4726)] = 252598,
  [SMALL_STATE(4727)] = 252643,
  [SMALL_STATE(4728)] = 252688,
  [SMALL_STATE(4729)] = 252753,
  [SMALL_STATE(4730)] = 252798,
  [SMALL_STATE(4731)] = 252843,
  [SMALL_STATE(4732)] = 252890,
  [SMALL_STATE(4733)] = 252947,
  [SMALL_STATE(4734)] = 252996,
  [SMALL_STATE(4735)] = 253041,
  [SMALL_STATE(4736)] = 253098,
  [SMALL_STATE(4737)] = 253143,
  [SMALL_STATE(4738)] = 253202,
  [SMALL_STATE(4739)] = 253249,
  [SMALL_STATE(4740)] = 253306,
  [SMALL_STATE(4741)] = 253363,
  [SMALL_STATE(4742)] = 253408,
  [SMALL_STATE(4743)] = 253453,
  [SMALL_STATE(4744)] = 253512,
  [SMALL_STATE(4745)] = 253569,
  [SMALL_STATE(4746)] = 253614,
  [SMALL_STATE(4747)] = 253679,
  [SMALL_STATE(4748)] = 253734,
  [SMALL_STATE(4749)] = 253795,
  [SMALL_STATE(4750)] = 253852,
  [SMALL_STATE(4751)] = 253899,
  [SMALL_STATE(4752)] = 253944,
  [SMALL_STATE(4753)] = 254001,
  [SMALL_STATE(4754)] = 254058,
  [SMALL_STATE(4755)] = 254113,
  [SMALL_STATE(4756)] = 254170,
  [SMALL_STATE(4757)] = 254215,
  [SMALL_STATE(4758)] = 254262,
  [SMALL_STATE(4759)] = 254314,
  [SMALL_STATE(4760)] = 254382,
  [SMALL_STATE(4761)] = 254426,
  [SMALL_STATE(4762)] = 254482,
  [SMALL_STATE(4763)] = 254526,
  [SMALL_STATE(4764)] = 254576,
  [SMALL_STATE(4765)] = 254620,
  [SMALL_STATE(4766)] = 254664,
  [SMALL_STATE(4767)] = 254708,
  [SMALL_STATE(4768)] = 254752,
  [SMALL_STATE(4769)] = 254806,
  [SMALL_STATE(4770)] = 254850,
  [SMALL_STATE(4771)] = 254894,
  [SMALL_STATE(4772)] = 254940,
  [SMALL_STATE(4773)] = 254990,
  [SMALL_STATE(4774)] = 255034,
  [SMALL_STATE(4775)] = 255078,
  [SMALL_STATE(4776)] = 255122,
  [SMALL_STATE(4777)] = 255180,
  [SMALL_STATE(4778)] = 255230,
  [SMALL_STATE(4779)] = 255278,
  [SMALL_STATE(4780)] = 255322,
  [SMALL_STATE(4781)] = 255366,
  [SMALL_STATE(4782)] = 255410,
  [SMALL_STATE(4783)] = 255456,
  [SMALL_STATE(4784)] = 255500,
  [SMALL_STATE(4785)] = 255544,
  [SMALL_STATE(4786)] = 255588,
  [SMALL_STATE(4787)] = 255636,
  [SMALL_STATE(4788)] = 255680,
  [SMALL_STATE(4789)] = 255724,
  [SMALL_STATE(4790)] = 255768,
  [SMALL_STATE(4791)] = 255812,
  [SMALL_STATE(4792)] = 255862,
  [SMALL_STATE(4793)] = 255906,
  [SMALL_STATE(4794)] = 255952,
  [SMALL_STATE(4795)] = 255996,
  [SMALL_STATE(4796)] = 256044,
  [SMALL_STATE(4797)] = 256088,
  [SMALL_STATE(4798)] = 256144,
  [SMALL_STATE(4799)] = 256188,
  [SMALL_STATE(4800)] = 256232,
  [SMALL_STATE(4801)] = 256282,
  [SMALL_STATE(4802)] = 256326,
  [SMALL_STATE(4803)] = 256370,
  [SMALL_STATE(4804)] = 256414,
  [SMALL_STATE(4805)] = 256472,
  [SMALL_STATE(4806)] = 256516,
  [SMALL_STATE(4807)] = 256566,
  [SMALL_STATE(4808)] = 256610,
  [SMALL_STATE(4809)] = 256654,
  [SMALL_STATE(4810)] = 256698,
  [SMALL_STATE(4811)] = 256744,
  [SMALL_STATE(4812)] = 256788,
  [SMALL_STATE(4813)] = 256836,
  [SMALL_STATE(4814)] = 256880,
  [SMALL_STATE(4815)] = 256924,
  [SMALL_STATE(4816)] = 256968,
  [SMALL_STATE(4817)] = 257026,
  [SMALL_STATE(4818)] = 257082,
  [SMALL_STATE(4819)] = 257126,
  [SMALL_STATE(4820)] = 257170,
  [SMALL_STATE(4821)] = 257214,
  [SMALL_STATE(4822)] = 257258,
  [SMALL_STATE(4823)] = 257302,
  [SMALL_STATE(4824)] = 257346,
  [SMALL_STATE(4825)] = 257390,
  [SMALL_STATE(4826)] = 257434,
  [SMALL_STATE(4827)] = 257480,
  [SMALL_STATE(4828)] = 257524,
  [SMALL_STATE(4829)] = 257568,
  [SMALL_STATE(4830)] = 257612,
  [SMALL_STATE(4831)] = 257656,
  [SMALL_STATE(4832)] = 257712,
  [SMALL_STATE(4833)] = 257756,
  [SMALL_STATE(4834)] = 257802,
  [SMALL_STATE(4835)] = 257846,
  [SMALL_STATE(4836)] = 257890,
  [SMALL_STATE(4837)] = 257934,
  [SMALL_STATE(4838)] = 257990,
  [SMALL_STATE(4839)] = 258040,
  [SMALL_STATE(4840)] = 258088,
  [SMALL_STATE(4841)] = 258144,
  [SMALL_STATE(4842)] = 258188,
  [SMALL_STATE(4843)] = 258232,
  [SMALL_STATE(4844)] = 258276,
  [SMALL_STATE(4845)] = 258334,
  [SMALL_STATE(4846)] = 258382,
  [SMALL_STATE(4847)] = 258428,
  [SMALL_STATE(4848)] = 258472,
  [SMALL_STATE(4849)] = 258528,
  [SMALL_STATE(4850)] = 258572,
  [SMALL_STATE(4851)] = 258628,
  [SMALL_STATE(4852)] = 258672,
  [SMALL_STATE(4853)] = 258716,
  [SMALL_STATE(4854)] = 258760,
  [SMALL_STATE(4855)] = 258806,
  [SMALL_STATE(4856)] = 258850,
  [SMALL_STATE(4857)] = 258894,
  [SMALL_STATE(4858)] = 258948,
  [SMALL_STATE(4859)] = 258992,
  [SMALL_STATE(4860)] = 259040,
  [SMALL_STATE(4861)] = 259100,
  [SMALL_STATE(4862)] = 259144,
  [SMALL_STATE(4863)] = 259188,
  [SMALL_STATE(4864)] = 259232,
  [SMALL_STATE(4865)] = 259276,
  [SMALL_STATE(4866)] = 259324,
  [SMALL_STATE(4867)] = 259370,
  [SMALL_STATE(4868)] = 259426,
  [SMALL_STATE(4869)] = 259470,
  [SMALL_STATE(4870)] = 259514,
  [SMALL_STATE(4871)] = 259560,
  [SMALL_STATE(4872)] = 259604,
  [SMALL_STATE(4873)] = 259648,
  [SMALL_STATE(4874)] = 259692,
  [SMALL_STATE(4875)] = 259736,
  [SMALL_STATE(4876)] = 259782,
  [SMALL_STATE(4877)] = 259838,
  [SMALL_STATE(4878)] = 259896,
  [SMALL_STATE(4879)] = 259946,
  [SMALL_STATE(4880)] = 259994,
  [SMALL_STATE(4881)] = 260040,
  [SMALL_STATE(4882)] = 260108,
  [SMALL_STATE(4883)] = 260152,
  [SMALL_STATE(4884)] = 260208,
  [SMALL_STATE(4885)] = 260264,
  [SMALL_STATE(4886)] = 260312,
  [SMALL_STATE(4887)] = 260368,
  [SMALL_STATE(4888)] = 260424,
  [SMALL_STATE(4889)] = 260482,
  [SMALL_STATE(4890)] = 260540,
  [SMALL_STATE(4891)] = 260584,
  [SMALL_STATE(4892)] = 260628,
  [SMALL_STATE(4893)] = 260684,
  [SMALL_STATE(4894)] = 260730,
  [SMALL_STATE(4895)] = 260790,
  [SMALL_STATE(4896)] = 260834,
  [SMALL_STATE(4897)] = 260890,
  [SMALL_STATE(4898)] = 260946,
  [SMALL_STATE(4899)] = 261004,
  [SMALL_STATE(4900)] = 261068,
  [SMALL_STATE(4901)] = 261114,
  [SMALL_STATE(4902)] = 261160,
  [SMALL_STATE(4903)] = 261204,
  [SMALL_STATE(4904)] = 261248,
  [SMALL_STATE(4905)] = 261292,
  [SMALL_STATE(4906)] = 261336,
  [SMALL_STATE(4907)] = 261380,
  [SMALL_STATE(4908)] = 261432,
  [SMALL_STATE(4909)] = 261500,
  [SMALL_STATE(4910)] = 261550,
  [SMALL_STATE(4911)] = 261598,
  [SMALL_STATE(4912)] = 261648,
  [SMALL_STATE(4913)] = 261696,
  [SMALL_STATE(4914)] = 261756,
  [SMALL_STATE(4915)] = 261812,
  [SMALL_STATE(4916)] = 261868,
  [SMALL_STATE(4917)] = 261912,
  [SMALL_STATE(4918)] = 261956,
  [SMALL_STATE(4919)] = 262012,
  [SMALL_STATE(4920)] = 262056,
  [SMALL_STATE(4921)] = 262100,
  [SMALL_STATE(4922)] = 262158,
  [SMALL_STATE(4923)] = 262202,
  [SMALL_STATE(4924)] = 262252,
  [SMALL_STATE(4925)] = 262296,
  [SMALL_STATE(4926)] = 262340,
  [SMALL_STATE(4927)] = 262384,
  [SMALL_STATE(4928)] = 262448,
  [SMALL_STATE(4929)] = 262492,
  [SMALL_STATE(4930)] = 262542,
  [SMALL_STATE(4931)] = 262586,
  [SMALL_STATE(4932)] = 262630,
  [SMALL_STATE(4933)] = 262674,
  [SMALL_STATE(4934)] = 262718,
  [SMALL_STATE(4935)] = 262764,
  [SMALL_STATE(4936)] = 262808,
  [SMALL_STATE(4937)] = 262852,
  [SMALL_STATE(4938)] = 262896,
  [SMALL_STATE(4939)] = 262940,
  [SMALL_STATE(4940)] = 262984,
  [SMALL_STATE(4941)] = 263028,
  [SMALL_STATE(4942)] = 263072,
  [SMALL_STATE(4943)] = 263132,
  [SMALL_STATE(4944)] = 263178,
  [SMALL_STATE(4945)] = 263222,
  [SMALL_STATE(4946)] = 263266,
  [SMALL_STATE(4947)] = 263310,
  [SMALL_STATE(4948)] = 263368,
  [SMALL_STATE(4949)] = 263412,
  [SMALL_STATE(4950)] = 263468,
  [SMALL_STATE(4951)] = 263516,
  [SMALL_STATE(4952)] = 263566,
  [SMALL_STATE(4953)] = 263610,
  [SMALL_STATE(4954)] = 263666,
  [SMALL_STATE(4955)] = 263722,
  [SMALL_STATE(4956)] = 263778,
  [SMALL_STATE(4957)] = 263822,
  [SMALL_STATE(4958)] = 263880,
  [SMALL_STATE(4959)] = 263944,
  [SMALL_STATE(4960)] = 263990,
  [SMALL_STATE(4961)] = 264046,
  [SMALL_STATE(4962)] = 264104,
  [SMALL_STATE(4963)] = 264152,
  [SMALL_STATE(4964)] = 264208,
  [SMALL_STATE(4965)] = 264252,
  [SMALL_STATE(4966)] = 264296,
  [SMALL_STATE(4967)] = 264354,
  [SMALL_STATE(4968)] = 264400,
  [SMALL_STATE(4969)] = 264444,
  [SMALL_STATE(4970)] = 264488,
  [SMALL_STATE(4971)] = 264544,
  [SMALL_STATE(4972)] = 264592,
  [SMALL_STATE(4973)] = 264656,
  [SMALL_STATE(4974)] = 264712,
  [SMALL_STATE(4975)] = 264756,
  [SMALL_STATE(4976)] = 264800,
  [SMALL_STATE(4977)] = 264864,
  [SMALL_STATE(4978)] = 264908,
  [SMALL_STATE(4979)] = 264952,
  [SMALL_STATE(4980)] = 264996,
  [SMALL_STATE(4981)] = 265040,
  [SMALL_STATE(4982)] = 265084,
  [SMALL_STATE(4983)] = 265128,
  [SMALL_STATE(4984)] = 265172,
  [SMALL_STATE(4985)] = 265228,
  [SMALL_STATE(4986)] = 265272,
  [SMALL_STATE(4987)] = 265316,
  [SMALL_STATE(4988)] = 265372,
  [SMALL_STATE(4989)] = 265426,
  [SMALL_STATE(4990)] = 265470,
  [SMALL_STATE(4991)] = 265534,
  [SMALL_STATE(4992)] = 265590,
  [SMALL_STATE(4993)] = 265646,
  [SMALL_STATE(4994)] = 265690,
  [SMALL_STATE(4995)] = 265748,
  [SMALL_STATE(4996)] = 265804,
  [SMALL_STATE(4997)] = 265862,
  [SMALL_STATE(4998)] = 265906,
  [SMALL_STATE(4999)] = 265962,
  [SMALL_STATE(5000)] = 266006,
  [SMALL_STATE(5001)] = 266074,
  [SMALL_STATE(5002)] = 266130,
  [SMALL_STATE(5003)] = 266186,
  [SMALL_STATE(5004)] = 266240,
  [SMALL_STATE(5005)] = 266290,
  [SMALL_STATE(5006)] = 266336,
  [SMALL_STATE(5007)] = 266392,
  [SMALL_STATE(5008)] = 266440,
  [SMALL_STATE(5009)] = 266484,
  [SMALL_STATE(5010)] = 266540,
  [SMALL_STATE(5011)] = 266588,
  [SMALL_STATE(5012)] = 266646,
  [SMALL_STATE(5013)] = 266690,
  [SMALL_STATE(5014)] = 266746,
  [SMALL_STATE(5015)] = 266790,
  [SMALL_STATE(5016)] = 266834,
  [SMALL_STATE(5017)] = 266878,
  [SMALL_STATE(5018)] = 266928,
  [SMALL_STATE(5019)] = 266976,
  [SMALL_STATE(5020)] = 267020,
  [SMALL_STATE(5021)] = 267064,
  [SMALL_STATE(5022)] = 267128,
  [SMALL_STATE(5023)] = 267184,
  [SMALL_STATE(5024)] = 267232,
  [SMALL_STATE(5025)] = 267278,
  [SMALL_STATE(5026)] = 267322,
  [SMALL_STATE(5027)] = 267378,
  [SMALL_STATE(5028)] = 267434,
  [SMALL_STATE(5029)] = 267478,
  [SMALL_STATE(5030)] = 267524,
  [SMALL_STATE(5031)] = 267580,
  [SMALL_STATE(5032)] = 267636,
  [SMALL_STATE(5033)] = 267686,
  [SMALL_STATE(5034)] = 267742,
  [SMALL_STATE(5035)] = 267788,
  [SMALL_STATE(5036)] = 267844,
  [SMALL_STATE(5037)] = 267902,
  [SMALL_STATE(5038)] = 267950,
  [SMALL_STATE(5039)] = 267994,
  [SMALL_STATE(5040)] = 268050,
  [SMALL_STATE(5041)] = 268096,
  [SMALL_STATE(5042)] = 268140,
  [SMALL_STATE(5043)] = 268184,
  [SMALL_STATE(5044)] = 268240,
  [SMALL_STATE(5045)] = 268296,
  [SMALL_STATE(5046)] = 268344,
  [SMALL_STATE(5047)] = 268394,
  [SMALL_STATE(5048)] = 268444,
  [SMALL_STATE(5049)] = 268487,
  [SMALL_STATE(5050)] = 268530,
  [SMALL_STATE(5051)] = 268575,
  [SMALL_STATE(5052)] = 268620,
  [SMALL_STATE(5053)] = 268669,
  [SMALL_STATE(5054)] = 268712,
  [SMALL_STATE(5055)] = 268767,
  [SMALL_STATE(5056)] = 268810,
  [SMALL_STATE(5057)] = 268853,
  [SMALL_STATE(5058)] = 268896,
  [SMALL_STATE(5059)] = 268949,
  [SMALL_STATE(5060)] = 268992,
  [SMALL_STATE(5061)] = 269035,
  [SMALL_STATE(5062)] = 269078,
  [SMALL_STATE(5063)] = 269121,
  [SMALL_STATE(5064)] = 269178,
  [SMALL_STATE(5065)] = 269225,
  [SMALL_STATE(5066)] = 269282,
  [SMALL_STATE(5067)] = 269325,
  [SMALL_STATE(5068)] = 269370,
  [SMALL_STATE(5069)] = 269413,
  [SMALL_STATE(5070)] = 269456,
  [SMALL_STATE(5071)] = 269499,
  [SMALL_STATE(5072)] = 269542,
  [SMALL_STATE(5073)] = 269585,
  [SMALL_STATE(5074)] = 269628,
  [SMALL_STATE(5075)] = 269671,
  [SMALL_STATE(5076)] = 269726,
  [SMALL_STATE(5077)] = 269781,
  [SMALL_STATE(5078)] = 269844,
  [SMALL_STATE(5079)] = 269887,
  [SMALL_STATE(5080)] = 269942,
  [SMALL_STATE(5081)] = 269985,
  [SMALL_STATE(5082)] = 270028,
  [SMALL_STATE(5083)] = 270071,
  [SMALL_STATE(5084)] = 270114,
  [SMALL_STATE(5085)] = 270157,
  [SMALL_STATE(5086)] = 270200,
  [SMALL_STATE(5087)] = 270245,
  [SMALL_STATE(5088)] = 270300,
  [SMALL_STATE(5089)] = 270343,
  [SMALL_STATE(5090)] = 270386,
  [SMALL_STATE(5091)] = 270429,
  [SMALL_STATE(5092)] = 270492,
  [SMALL_STATE(5093)] = 270547,
  [SMALL_STATE(5094)] = 270590,
  [SMALL_STATE(5095)] = 270633,
  [SMALL_STATE(5096)] = 270676,
  [SMALL_STATE(5097)] = 270719,
  [SMALL_STATE(5098)] = 270762,
  [SMALL_STATE(5099)] = 270805,
  [SMALL_STATE(5100)] = 270848,
  [SMALL_STATE(5101)] = 270891,
  [SMALL_STATE(5102)] = 270936,
  [SMALL_STATE(5103)] = 270979,
  [SMALL_STATE(5104)] = 271022,
  [SMALL_STATE(5105)] = 271065,
  [SMALL_STATE(5106)] = 271114,
  [SMALL_STATE(5107)] = 271161,
  [SMALL_STATE(5108)] = 271224,
  [SMALL_STATE(5109)] = 271267,
  [SMALL_STATE(5110)] = 271310,
  [SMALL_STATE(5111)] = 271353,
  [SMALL_STATE(5112)] = 271396,
  [SMALL_STATE(5113)] = 271441,
  [SMALL_STATE(5114)] = 271484,
  [SMALL_STATE(5115)] = 271527,
  [SMALL_STATE(5116)] = 271582,
  [SMALL_STATE(5117)] = 271625,
  [SMALL_STATE(5118)] = 271668,
  [SMALL_STATE(5119)] = 271711,
  [SMALL_STATE(5120)] = 271766,
  [SMALL_STATE(5121)] = 271821,
  [SMALL_STATE(5122)] = 271864,
  [SMALL_STATE(5123)] = 271907,
  [SMALL_STATE(5124)] = 271950,
  [SMALL_STATE(5125)] = 272007,
  [SMALL_STATE(5126)] = 272050,
  [SMALL_STATE(5127)] = 272093,
  [SMALL_STATE(5128)] = 272136,
  [SMALL_STATE(5129)] = 272179,
  [SMALL_STATE(5130)] = 272222,
  [SMALL_STATE(5131)] = 272265,
  [SMALL_STATE(5132)] = 272320,
  [SMALL_STATE(5133)] = 272363,
  [SMALL_STATE(5134)] = 272406,
  [SMALL_STATE(5135)] = 272449,
  [SMALL_STATE(5136)] = 272494,
  [SMALL_STATE(5137)] = 272557,
  [SMALL_STATE(5138)] = 272600,
  [SMALL_STATE(5139)] = 272643,
  [SMALL_STATE(5140)] = 272686,
  [SMALL_STATE(5141)] = 272731,
  [SMALL_STATE(5142)] = 272774,
  [SMALL_STATE(5143)] = 272823,
  [SMALL_STATE(5144)] = 272870,
  [SMALL_STATE(5145)] = 272925,
  [SMALL_STATE(5146)] = 272968,
  [SMALL_STATE(5147)] = 273011,
  [SMALL_STATE(5148)] = 273054,
  [SMALL_STATE(5149)] = 273111,
  [SMALL_STATE(5150)] = 273154,
  [SMALL_STATE(5151)] = 273203,
  [SMALL_STATE(5152)] = 273252,
  [SMALL_STATE(5153)] = 273299,
  [SMALL_STATE(5154)] = 273342,
  [SMALL_STATE(5155)] = 273385,
  [SMALL_STATE(5156)] = 273428,
  [SMALL_STATE(5157)] = 273477,
  [SMALL_STATE(5158)] = 273520,
  [SMALL_STATE(5159)] = 273565,
  [SMALL_STATE(5160)] = 273612,
  [SMALL_STATE(5161)] = 273655,
  [SMALL_STATE(5162)] = 273698,
  [SMALL_STATE(5163)] = 273741,
  [SMALL_STATE(5164)] = 273786,
  [SMALL_STATE(5165)] = 273829,
  [SMALL_STATE(5166)] = 273872,
  [SMALL_STATE(5167)] = 273915,
  [SMALL_STATE(5168)] = 273960,
  [SMALL_STATE(5169)] = 274003,
  [SMALL_STATE(5170)] = 274046,
  [SMALL_STATE(5171)] = 274089,
  [SMALL_STATE(5172)] = 274132,
  [SMALL_STATE(5173)] = 274175,
  [SMALL_STATE(5174)] = 274218,
  [SMALL_STATE(5175)] = 274261,
  [SMALL_STATE(5176)] = 274304,
  [SMALL_STATE(5177)] = 274347,
  [SMALL_STATE(5178)] = 274390,
  [SMALL_STATE(5179)] = 274433,
  [SMALL_STATE(5180)] = 274476,
  [SMALL_STATE(5181)] = 274519,
  [SMALL_STATE(5182)] = 274568,
  [SMALL_STATE(5183)] = 274623,
  [SMALL_STATE(5184)] = 274670,
  [SMALL_STATE(5185)] = 274713,
  [SMALL_STATE(5186)] = 274756,
  [SMALL_STATE(5187)] = 274805,
  [SMALL_STATE(5188)] = 274852,
  [SMALL_STATE(5189)] = 274907,
  [SMALL_STATE(5190)] = 274954,
  [SMALL_STATE(5191)] = 274997,
  [SMALL_STATE(5192)] = 275040,
  [SMALL_STATE(5193)] = 275083,
  [SMALL_STATE(5194)] = 275126,
  [SMALL_STATE(5195)] = 275169,
  [SMALL_STATE(5196)] = 275212,
  [SMALL_STATE(5197)] = 275257,
  [SMALL_STATE(5198)] = 275302,
  [SMALL_STATE(5199)] = 275357,
  [SMALL_STATE(5200)] = 275412,
  [SMALL_STATE(5201)] = 275469,
  [SMALL_STATE(5202)] = 275514,
  [SMALL_STATE(5203)] = 275563,
  [SMALL_STATE(5204)] = 275612,
  [SMALL_STATE(5205)] = 275657,
  [SMALL_STATE(5206)] = 275724,
  [SMALL_STATE(5207)] = 275791,
  [SMALL_STATE(5208)] = 275846,
  [SMALL_STATE(5209)] = 275913,
  [SMALL_STATE(5210)] = 275968,
  [SMALL_STATE(5211)] = 276023,
  [SMALL_STATE(5212)] = 276080,
  [SMALL_STATE(5213)] = 276127,
  [SMALL_STATE(5214)] = 276170,
  [SMALL_STATE(5215)] = 276213,
  [SMALL_STATE(5216)] = 276268,
  [SMALL_STATE(5217)] = 276337,
  [SMALL_STATE(5218)] = 276392,
  [SMALL_STATE(5219)] = 276455,
  [SMALL_STATE(5220)] = 276522,
  [SMALL_STATE(5221)] = 276577,
  [SMALL_STATE(5222)] = 276620,
  [SMALL_STATE(5223)] = 276675,
  [SMALL_STATE(5224)] = 276742,
  [SMALL_STATE(5225)] = 276785,
  [SMALL_STATE(5226)] = 276836,
  [SMALL_STATE(5227)] = 276891,
  [SMALL_STATE(5228)] = 276934,
  [SMALL_STATE(5229)] = 277001,
  [SMALL_STATE(5230)] = 277044,
  [SMALL_STATE(5231)] = 277087,
  [SMALL_STATE(5232)] = 277130,
  [SMALL_STATE(5233)] = 277177,
  [SMALL_STATE(5234)] = 277234,
  [SMALL_STATE(5235)] = 277289,
  [SMALL_STATE(5236)] = 277332,
  [SMALL_STATE(5237)] = 277381,
  [SMALL_STATE(5238)] = 277424,
  [SMALL_STATE(5239)] = 277469,
  [SMALL_STATE(5240)] = 277526,
  [SMALL_STATE(5241)] = 277581,
  [SMALL_STATE(5242)] = 277624,
  [SMALL_STATE(5243)] = 277671,
  [SMALL_STATE(5244)] = 277714,
  [SMALL_STATE(5245)] = 277757,
  [SMALL_STATE(5246)] = 277802,
  [SMALL_STATE(5247)] = 277857,
  [SMALL_STATE(5248)] = 277912,
  [SMALL_STATE(5249)] = 277955,
  [SMALL_STATE(5250)] = 277998,
  [SMALL_STATE(5251)] = 278065,
  [SMALL_STATE(5252)] = 278122,
  [SMALL_STATE(5253)] = 278179,
  [SMALL_STATE(5254)] = 278222,
  [SMALL_STATE(5255)] = 278267,
  [SMALL_STATE(5256)] = 278316,
  [SMALL_STATE(5257)] = 278375,
  [SMALL_STATE(5258)] = 278430,
  [SMALL_STATE(5259)] = 278473,
  [SMALL_STATE(5260)] = 278528,
  [SMALL_STATE(5261)] = 278595,
  [SMALL_STATE(5262)] = 278652,
  [SMALL_STATE(5263)] = 278695,
  [SMALL_STATE(5264)] = 278742,
  [SMALL_STATE(5265)] = 278785,
  [SMALL_STATE(5266)] = 278852,
  [SMALL_STATE(5267)] = 278909,
  [SMALL_STATE(5268)] = 278954,
  [SMALL_STATE(5269)] = 278997,
  [SMALL_STATE(5270)] = 279044,
  [SMALL_STATE(5271)] = 279087,
  [SMALL_STATE(5272)] = 279130,
  [SMALL_STATE(5273)] = 279185,
  [SMALL_STATE(5274)] = 279248,
  [SMALL_STATE(5275)] = 279291,
  [SMALL_STATE(5276)] = 279334,
  [SMALL_STATE(5277)] = 279377,
  [SMALL_STATE(5278)] = 279420,
  [SMALL_STATE(5279)] = 279463,
  [SMALL_STATE(5280)] = 279512,
  [SMALL_STATE(5281)] = 279559,
  [SMALL_STATE(5282)] = 279602,
  [SMALL_STATE(5283)] = 279645,
  [SMALL_STATE(5284)] = 279700,
  [SMALL_STATE(5285)] = 279743,
  [SMALL_STATE(5286)] = 279786,
  [SMALL_STATE(5287)] = 279829,
  [SMALL_STATE(5288)] = 279872,
  [SMALL_STATE(5289)] = 279915,
  [SMALL_STATE(5290)] = 279958,
  [SMALL_STATE(5291)] = 280001,
  [SMALL_STATE(5292)] = 280044,
  [SMALL_STATE(5293)] = 280087,
  [SMALL_STATE(5294)] = 280130,
  [SMALL_STATE(5295)] = 280185,
  [SMALL_STATE(5296)] = 280228,
  [SMALL_STATE(5297)] = 280271,
  [SMALL_STATE(5298)] = 280334,
  [SMALL_STATE(5299)] = 280389,
  [SMALL_STATE(5300)] = 280444,
  [SMALL_STATE(5301)] = 280487,
  [SMALL_STATE(5302)] = 280542,
  [SMALL_STATE(5303)] = 280599,
  [SMALL_STATE(5304)] = 280642,
  [SMALL_STATE(5305)] = 280699,
  [SMALL_STATE(5306)] = 280756,
  [SMALL_STATE(5307)] = 280799,
  [SMALL_STATE(5308)] = 280842,
  [SMALL_STATE(5309)] = 280885,
  [SMALL_STATE(5310)] = 280928,
  [SMALL_STATE(5311)] = 280975,
  [SMALL_STATE(5312)] = 281018,
  [SMALL_STATE(5313)] = 281061,
  [SMALL_STATE(5314)] = 281116,
  [SMALL_STATE(5315)] = 281159,
  [SMALL_STATE(5316)] = 281212,
  [SMALL_STATE(5317)] = 281255,
  [SMALL_STATE(5318)] = 281302,
  [SMALL_STATE(5319)] = 281345,
  [SMALL_STATE(5320)] = 281390,
  [SMALL_STATE(5321)] = 281441,
  [SMALL_STATE(5322)] = 281484,
  [SMALL_STATE(5323)] = 281529,
  [SMALL_STATE(5324)] = 281596,
  [SMALL_STATE(5325)] = 281649,
  [SMALL_STATE(5326)] = 281700,
  [SMALL_STATE(5327)] = 281755,
  [SMALL_STATE(5328)] = 281798,
  [SMALL_STATE(5329)] = 281843,
  [SMALL_STATE(5330)] = 281886,
  [SMALL_STATE(5331)] = 281953,
  [SMALL_STATE(5332)] = 281996,
  [SMALL_STATE(5333)] = 282041,
  [SMALL_STATE(5334)] = 282088,
  [SMALL_STATE(5335)] = 282131,
  [SMALL_STATE(5336)] = 282174,
  [SMALL_STATE(5337)] = 282231,
  [SMALL_STATE(5338)] = 282274,
  [SMALL_STATE(5339)] = 282317,
  [SMALL_STATE(5340)] = 282372,
  [SMALL_STATE(5341)] = 282415,
  [SMALL_STATE(5342)] = 282458,
  [SMALL_STATE(5343)] = 282501,
  [SMALL_STATE(5344)] = 282544,
  [SMALL_STATE(5345)] = 282599,
  [SMALL_STATE(5346)] = 282666,
  [SMALL_STATE(5347)] = 282721,
  [SMALL_STATE(5348)] = 282778,
  [SMALL_STATE(5349)] = 282833,
  [SMALL_STATE(5350)] = 282878,
  [SMALL_STATE(5351)] = 282921,
  [SMALL_STATE(5352)] = 282964,
  [SMALL_STATE(5353)] = 283007,
  [SMALL_STATE(5354)] = 283052,
  [SMALL_STATE(5355)] = 283095,
  [SMALL_STATE(5356)] = 283142,
  [SMALL_STATE(5357)] = 283185,
  [SMALL_STATE(5358)] = 283230,
  [SMALL_STATE(5359)] = 283273,
  [SMALL_STATE(5360)] = 283316,
  [SMALL_STATE(5361)] = 283359,
  [SMALL_STATE(5362)] = 283402,
  [SMALL_STATE(5363)] = 283445,
  [SMALL_STATE(5364)] = 283494,
  [SMALL_STATE(5365)] = 283561,
  [SMALL_STATE(5366)] = 283614,
  [SMALL_STATE(5367)] = 283663,
  [SMALL_STATE(5368)] = 283706,
  [SMALL_STATE(5369)] = 283759,
  [SMALL_STATE(5370)] = 283808,
  [SMALL_STATE(5371)] = 283863,
  [SMALL_STATE(5372)] = 283916,
  [SMALL_STATE(5373)] = 283961,
  [SMALL_STATE(5374)] = 284014,
  [SMALL_STATE(5375)] = 284071,
  [SMALL_STATE(5376)] = 284114,
  [SMALL_STATE(5377)] = 284157,
  [SMALL_STATE(5378)] = 284212,
  [SMALL_STATE(5379)] = 284255,
  [SMALL_STATE(5380)] = 284304,
  [SMALL_STATE(5381)] = 284353,
  [SMALL_STATE(5382)] = 284412,
  [SMALL_STATE(5383)] = 284455,
  [SMALL_STATE(5384)] = 284512,
  [SMALL_STATE(5385)] = 284555,
  [SMALL_STATE(5386)] = 284610,
  [SMALL_STATE(5387)] = 284653,
  [SMALL_STATE(5388)] = 284696,
  [SMALL_STATE(5389)] = 284749,
  [SMALL_STATE(5390)] = 284796,
  [SMALL_STATE(5391)] = 284859,
  [SMALL_STATE(5392)] = 284914,
  [SMALL_STATE(5393)] = 284957,
  [SMALL_STATE(5394)] = 285000,
  [SMALL_STATE(5395)] = 285043,
  [SMALL_STATE(5396)] = 285086,
  [SMALL_STATE(5397)] = 285129,
  [SMALL_STATE(5398)] = 285186,
  [SMALL_STATE(5399)] = 285229,
  [SMALL_STATE(5400)] = 285276,
  [SMALL_STATE(5401)] = 285323,
  [SMALL_STATE(5402)] = 285366,
  [SMALL_STATE(5403)] = 285421,
  [SMALL_STATE(5404)] = 285464,
  [SMALL_STATE(5405)] = 285507,
  [SMALL_STATE(5406)] = 285562,
  [SMALL_STATE(5407)] = 285605,
  [SMALL_STATE(5408)] = 285652,
  [SMALL_STATE(5409)] = 285695,
  [SMALL_STATE(5410)] = 285738,
  [SMALL_STATE(5411)] = 285797,
  [SMALL_STATE(5412)] = 285840,
  [SMALL_STATE(5413)] = 285883,
  [SMALL_STATE(5414)] = 285926,
  [SMALL_STATE(5415)] = 285971,
  [SMALL_STATE(5416)] = 286014,
  [SMALL_STATE(5417)] = 286063,
  [SMALL_STATE(5418)] = 286106,
  [SMALL_STATE(5419)] = 286161,
  [SMALL_STATE(5420)] = 286204,
  [SMALL_STATE(5421)] = 286247,
  [SMALL_STATE(5422)] = 286290,
  [SMALL_STATE(5423)] = 286335,
  [SMALL_STATE(5424)] = 286378,
  [SMALL_STATE(5425)] = 286433,
  [SMALL_STATE(5426)] = 286488,
  [SMALL_STATE(5427)] = 286531,
  [SMALL_STATE(5428)] = 286574,
  [SMALL_STATE(5429)] = 286617,
  [SMALL_STATE(5430)] = 286674,
  [SMALL_STATE(5431)] = 286717,
  [SMALL_STATE(5432)] = 286764,
  [SMALL_STATE(5433)] = 286807,
  [SMALL_STATE(5434)] = 286850,
  [SMALL_STATE(5435)] = 286893,
  [SMALL_STATE(5436)] = 286936,
  [SMALL_STATE(5437)] = 286979,
  [SMALL_STATE(5438)] = 287042,
  [SMALL_STATE(5439)] = 287085,
  [SMALL_STATE(5440)] = 287128,
  [SMALL_STATE(5441)] = 287183,
  [SMALL_STATE(5442)] = 287226,
  [SMALL_STATE(5443)] = 287279,
  [SMALL_STATE(5444)] = 287334,
  [SMALL_STATE(5445)] = 287389,
  [SMALL_STATE(5446)] = 287432,
  [SMALL_STATE(5447)] = 287487,
  [SMALL_STATE(5448)] = 287534,
  [SMALL_STATE(5449)] = 287589,
  [SMALL_STATE(5450)] = 287646,
  [SMALL_STATE(5451)] = 287701,
  [SMALL_STATE(5452)] = 287744,
  [SMALL_STATE(5453)] = 287787,
  [SMALL_STATE(5454)] = 287842,
  [SMALL_STATE(5455)] = 287901,
  [SMALL_STATE(5456)] = 287944,
  [SMALL_STATE(5457)] = 287989,
  [SMALL_STATE(5458)] = 288034,
  [SMALL_STATE(5459)] = 288079,
  [SMALL_STATE(5460)] = 288128,
  [SMALL_STATE(5461)] = 288185,
  [SMALL_STATE(5462)] = 288228,
  [SMALL_STATE(5463)] = 288273,
  [SMALL_STATE(5464)] = 288318,
  [SMALL_STATE(5465)] = 288373,
  [SMALL_STATE(5466)] = 288415,
  [SMALL_STATE(5467)] = 288459,
  [SMALL_STATE(5468)] = 288515,
  [SMALL_STATE(5469)] = 288557,
  [SMALL_STATE(5470)] = 288599,
  [SMALL_STATE(5471)] = 288641,
  [SMALL_STATE(5472)] = 288683,
  [SMALL_STATE(5473)] = 288725,
  [SMALL_STATE(5474)] = 288767,
  [SMALL_STATE(5475)] = 288809,
  [SMALL_STATE(5476)] = 288863,
  [SMALL_STATE(5477)] = 288911,
  [SMALL_STATE(5478)] = 288959,
  [SMALL_STATE(5479)] = 289005,
  [SMALL_STATE(5480)] = 289049,
  [SMALL_STATE(5481)] = 289091,
  [SMALL_STATE(5482)] = 289133,
  [SMALL_STATE(5483)] = 289181,
  [SMALL_STATE(5484)] = 289223,
  [SMALL_STATE(5485)] = 289267,
  [SMALL_STATE(5486)] = 289309,
  [SMALL_STATE(5487)] = 289351,
  [SMALL_STATE(5488)] = 289393,
  [SMALL_STATE(5489)] = 289435,
  [SMALL_STATE(5490)] = 289477,
  [SMALL_STATE(5491)] = 289525,
  [SMALL_STATE(5492)] = 289567,
  [SMALL_STATE(5493)] = 289609,
  [SMALL_STATE(5494)] = 289651,
  [SMALL_STATE(5495)] = 289693,
  [SMALL_STATE(5496)] = 289735,
  [SMALL_STATE(5497)] = 289777,
  [SMALL_STATE(5498)] = 289819,
  [SMALL_STATE(5499)] = 289861,
  [SMALL_STATE(5500)] = 289903,
  [SMALL_STATE(5501)] = 289945,
  [SMALL_STATE(5502)] = 289989,
  [SMALL_STATE(5503)] = 290031,
  [SMALL_STATE(5504)] = 290075,
  [SMALL_STATE(5505)] = 290117,
  [SMALL_STATE(5506)] = 290159,
  [SMALL_STATE(5507)] = 290201,
  [SMALL_STATE(5508)] = 290243,
  [SMALL_STATE(5509)] = 290305,
  [SMALL_STATE(5510)] = 290347,
  [SMALL_STATE(5511)] = 290389,
  [SMALL_STATE(5512)] = 290431,
  [SMALL_STATE(5513)] = 290473,
  [SMALL_STATE(5514)] = 290515,
  [SMALL_STATE(5515)] = 290557,
  [SMALL_STATE(5516)] = 290599,
  [SMALL_STATE(5517)] = 290641,
  [SMALL_STATE(5518)] = 290683,
  [SMALL_STATE(5519)] = 290725,
  [SMALL_STATE(5520)] = 290767,
  [SMALL_STATE(5521)] = 290809,
  [SMALL_STATE(5522)] = 290851,
  [SMALL_STATE(5523)] = 290893,
  [SMALL_STATE(5524)] = 290935,
  [SMALL_STATE(5525)] = 290977,
  [SMALL_STATE(5526)] = 291019,
  [SMALL_STATE(5527)] = 291061,
  [SMALL_STATE(5528)] = 291103,
  [SMALL_STATE(5529)] = 291145,
  [SMALL_STATE(5530)] = 291187,
  [SMALL_STATE(5531)] = 291229,
  [SMALL_STATE(5532)] = 291271,
  [SMALL_STATE(5533)] = 291313,
  [SMALL_STATE(5534)] = 291355,
  [SMALL_STATE(5535)] = 291397,
  [SMALL_STATE(5536)] = 291453,
  [SMALL_STATE(5537)] = 291497,
  [SMALL_STATE(5538)] = 291539,
  [SMALL_STATE(5539)] = 291581,
  [SMALL_STATE(5540)] = 291635,
  [SMALL_STATE(5541)] = 291677,
  [SMALL_STATE(5542)] = 291719,
  [SMALL_STATE(5543)] = 291761,
  [SMALL_STATE(5544)] = 291803,
  [SMALL_STATE(5545)] = 291845,
  [SMALL_STATE(5546)] = 291907,
  [SMALL_STATE(5547)] = 291961,
  [SMALL_STATE(5548)] = 292005,
  [SMALL_STATE(5549)] = 292047,
  [SMALL_STATE(5550)] = 292089,
  [SMALL_STATE(5551)] = 292131,
  [SMALL_STATE(5552)] = 292177,
  [SMALL_STATE(5553)] = 292223,
  [SMALL_STATE(5554)] = 292283,
  [SMALL_STATE(5555)] = 292325,
  [SMALL_STATE(5556)] = 292373,
  [SMALL_STATE(5557)] = 292427,
  [SMALL_STATE(5558)] = 292493,
  [SMALL_STATE(5559)] = 292559,
  [SMALL_STATE(5560)] = 292625,
  [SMALL_STATE(5561)] = 292671,
  [SMALL_STATE(5562)] = 292713,
  [SMALL_STATE(5563)] = 292779,
  [SMALL_STATE(5564)] = 292835,
  [SMALL_STATE(5565)] = 292891,
  [SMALL_STATE(5566)] = 292945,
  [SMALL_STATE(5567)] = 293001,
  [SMALL_STATE(5568)] = 293043,
  [SMALL_STATE(5569)] = 293085,
  [SMALL_STATE(5570)] = 293127,
  [SMALL_STATE(5571)] = 293169,
  [SMALL_STATE(5572)] = 293211,
  [SMALL_STATE(5573)] = 293255,
  [SMALL_STATE(5574)] = 293303,
  [SMALL_STATE(5575)] = 293349,
  [SMALL_STATE(5576)] = 293391,
  [SMALL_STATE(5577)] = 293445,
  [SMALL_STATE(5578)] = 293493,
  [SMALL_STATE(5579)] = 293535,
  [SMALL_STATE(5580)] = 293577,
  [SMALL_STATE(5581)] = 293631,
  [SMALL_STATE(5582)] = 293697,
  [SMALL_STATE(5583)] = 293763,
  [SMALL_STATE(5584)] = 293805,
  [SMALL_STATE(5585)] = 293847,
  [SMALL_STATE(5586)] = 293901,
  [SMALL_STATE(5587)] = 293943,
  [SMALL_STATE(5588)] = 293987,
  [SMALL_STATE(5589)] = 294029,
  [SMALL_STATE(5590)] = 294071,
  [SMALL_STATE(5591)] = 294113,
  [SMALL_STATE(5592)] = 294193,
  [SMALL_STATE(5593)] = 294237,
  [SMALL_STATE(5594)] = 294279,
  [SMALL_STATE(5595)] = 294325,
  [SMALL_STATE(5596)] = 294367,
  [SMALL_STATE(5597)] = 294409,
  [SMALL_STATE(5598)] = 294453,
  [SMALL_STATE(5599)] = 294507,
  [SMALL_STATE(5600)] = 294563,
  [SMALL_STATE(5601)] = 294605,
  [SMALL_STATE(5602)] = 294647,
  [SMALL_STATE(5603)] = 294691,
  [SMALL_STATE(5604)] = 294733,
  [SMALL_STATE(5605)] = 294775,
  [SMALL_STATE(5606)] = 294817,
  [SMALL_STATE(5607)] = 294859,
  [SMALL_STATE(5608)] = 294901,
  [SMALL_STATE(5609)] = 294943,
  [SMALL_STATE(5610)] = 294985,
  [SMALL_STATE(5611)] = 295027,
  [SMALL_STATE(5612)] = 295069,
  [SMALL_STATE(5613)] = 295111,
  [SMALL_STATE(5614)] = 295173,
  [SMALL_STATE(5615)] = 295221,
  [SMALL_STATE(5616)] = 295275,
  [SMALL_STATE(5617)] = 295329,
  [SMALL_STATE(5618)] = 295375,
  [SMALL_STATE(5619)] = 295429,
  [SMALL_STATE(5620)] = 295475,
  [SMALL_STATE(5621)] = 295517,
  [SMALL_STATE(5622)] = 295559,
  [SMALL_STATE(5623)] = 295611,
  [SMALL_STATE(5624)] = 295653,
  [SMALL_STATE(5625)] = 295695,
  [SMALL_STATE(5626)] = 295737,
  [SMALL_STATE(5627)] = 295779,
  [SMALL_STATE(5628)] = 295821,
  [SMALL_STATE(5629)] = 295863,
  [SMALL_STATE(5630)] = 295913,
  [SMALL_STATE(5631)] = 295965,
  [SMALL_STATE(5632)] = 296007,
  [SMALL_STATE(5633)] = 296049,
  [SMALL_STATE(5634)] = 296095,
  [SMALL_STATE(5635)] = 296137,
  [SMALL_STATE(5636)] = 296179,
  [SMALL_STATE(5637)] = 296221,
  [SMALL_STATE(5638)] = 296263,
  [SMALL_STATE(5639)] = 296329,
  [SMALL_STATE(5640)] = 296377,
  [SMALL_STATE(5641)] = 296435,
  [SMALL_STATE(5642)] = 296489,
  [SMALL_STATE(5643)] = 296531,
  [SMALL_STATE(5644)] = 296573,
  [SMALL_STATE(5645)] = 296627,
  [SMALL_STATE(5646)] = 296693,
  [SMALL_STATE(5647)] = 296747,
  [SMALL_STATE(5648)] = 296789,
  [SMALL_STATE(5649)] = 296845,
  [SMALL_STATE(5650)] = 296887,
  [SMALL_STATE(5651)] = 296929,
  [SMALL_STATE(5652)] = 296989,
  [SMALL_STATE(5653)] = 297031,
  [SMALL_STATE(5654)] = 297073,
  [SMALL_STATE(5655)] = 297127,
  [SMALL_STATE(5656)] = 297193,
  [SMALL_STATE(5657)] = 297235,
  [SMALL_STATE(5658)] = 297279,
  [SMALL_STATE(5659)] = 297321,
  [SMALL_STATE(5660)] = 297363,
  [SMALL_STATE(5661)] = 297405,
  [SMALL_STATE(5662)] = 297447,
  [SMALL_STATE(5663)] = 297489,
  [SMALL_STATE(5664)] = 297531,
  [SMALL_STATE(5665)] = 297573,
  [SMALL_STATE(5666)] = 297617,
  [SMALL_STATE(5667)] = 297671,
  [SMALL_STATE(5668)] = 297715,
  [SMALL_STATE(5669)] = 297757,
  [SMALL_STATE(5670)] = 297803,
  [SMALL_STATE(5671)] = 297845,
  [SMALL_STATE(5672)] = 297889,
  [SMALL_STATE(5673)] = 297933,
  [SMALL_STATE(5674)] = 297977,
  [SMALL_STATE(5675)] = 298019,
  [SMALL_STATE(5676)] = 298061,
  [SMALL_STATE(5677)] = 298103,
  [SMALL_STATE(5678)] = 298145,
  [SMALL_STATE(5679)] = 298187,
  [SMALL_STATE(5680)] = 298229,
  [SMALL_STATE(5681)] = 298271,
  [SMALL_STATE(5682)] = 298325,
  [SMALL_STATE(5683)] = 298367,
  [SMALL_STATE(5684)] = 298409,
  [SMALL_STATE(5685)] = 298451,
  [SMALL_STATE(5686)] = 298493,
  [SMALL_STATE(5687)] = 298535,
  [SMALL_STATE(5688)] = 298577,
  [SMALL_STATE(5689)] = 298619,
  [SMALL_STATE(5690)] = 298675,
  [SMALL_STATE(5691)] = 298717,
  [SMALL_STATE(5692)] = 298759,
  [SMALL_STATE(5693)] = 298801,
  [SMALL_STATE(5694)] = 298843,
  [SMALL_STATE(5695)] = 298885,
  [SMALL_STATE(5696)] = 298927,
  [SMALL_STATE(5697)] = 298969,
  [SMALL_STATE(5698)] = 299011,
  [SMALL_STATE(5699)] = 299053,
  [SMALL_STATE(5700)] = 299095,
  [SMALL_STATE(5701)] = 299137,
  [SMALL_STATE(5702)] = 299191,
  [SMALL_STATE(5703)] = 299233,
  [SMALL_STATE(5704)] = 299275,
  [SMALL_STATE(5705)] = 299319,
  [SMALL_STATE(5706)] = 299363,
  [SMALL_STATE(5707)] = 299405,
  [SMALL_STATE(5708)] = 299449,
  [SMALL_STATE(5709)] = 299503,
  [SMALL_STATE(5710)] = 299555,
  [SMALL_STATE(5711)] = 299603,
  [SMALL_STATE(5712)] = 299645,
  [SMALL_STATE(5713)] = 299699,
  [SMALL_STATE(5714)] = 299753,
  [SMALL_STATE(5715)] = 299799,
  [SMALL_STATE(5716)] = 299857,
  [SMALL_STATE(5717)] = 299899,
  [SMALL_STATE(5718)] = 299947,
  [SMALL_STATE(5719)] = 299989,
  [SMALL_STATE(5720)] = 300033,
  [SMALL_STATE(5721)] = 300099,
  [SMALL_STATE(5722)] = 300161,
  [SMALL_STATE(5723)] = 300209,
  [SMALL_STATE(5724)] = 300251,
  [SMALL_STATE(5725)] = 300293,
  [SMALL_STATE(5726)] = 300335,
  [SMALL_STATE(5727)] = 300389,
  [SMALL_STATE(5728)] = 300443,
  [SMALL_STATE(5729)] = 300509,
  [SMALL_STATE(5730)] = 300551,
  [SMALL_STATE(5731)] = 300593,
  [SMALL_STATE(5732)] = 300649,
  [SMALL_STATE(5733)] = 300691,
  [SMALL_STATE(5734)] = 300747,
  [SMALL_STATE(5735)] = 300789,
  [SMALL_STATE(5736)] = 300831,
  [SMALL_STATE(5737)] = 300873,
  [SMALL_STATE(5738)] = 300915,
  [SMALL_STATE(5739)] = 300957,
  [SMALL_STATE(5740)] = 301003,
  [SMALL_STATE(5741)] = 301045,
  [SMALL_STATE(5742)] = 301087,
  [SMALL_STATE(5743)] = 301141,
  [SMALL_STATE(5744)] = 301183,
  [SMALL_STATE(5745)] = 301225,
  [SMALL_STATE(5746)] = 301271,
  [SMALL_STATE(5747)] = 301313,
  [SMALL_STATE(5748)] = 301369,
  [SMALL_STATE(5749)] = 301413,
  [SMALL_STATE(5750)] = 301467,
  [SMALL_STATE(5751)] = 301509,
  [SMALL_STATE(5752)] = 301551,
  [SMALL_STATE(5753)] = 301593,
  [SMALL_STATE(5754)] = 301637,
  [SMALL_STATE(5755)] = 301679,
  [SMALL_STATE(5756)] = 301721,
  [SMALL_STATE(5757)] = 301777,
  [SMALL_STATE(5758)] = 301819,
  [SMALL_STATE(5759)] = 301861,
  [SMALL_STATE(5760)] = 301903,
  [SMALL_STATE(5761)] = 301953,
  [SMALL_STATE(5762)] = 302019,
  [SMALL_STATE(5763)] = 302061,
  [SMALL_STATE(5764)] = 302109,
  [SMALL_STATE(5765)] = 302151,
  [SMALL_STATE(5766)] = 302193,
  [SMALL_STATE(5767)] = 302235,
  [SMALL_STATE(5768)] = 302281,
  [SMALL_STATE(5769)] = 302323,
  [SMALL_STATE(5770)] = 302365,
  [SMALL_STATE(5771)] = 302419,
  [SMALL_STATE(5772)] = 302473,
  [SMALL_STATE(5773)] = 302529,
  [SMALL_STATE(5774)] = 302575,
  [SMALL_STATE(5775)] = 302631,
  [SMALL_STATE(5776)] = 302673,
  [SMALL_STATE(5777)] = 302715,
  [SMALL_STATE(5778)] = 302763,
  [SMALL_STATE(5779)] = 302805,
  [SMALL_STATE(5780)] = 302859,
  [SMALL_STATE(5781)] = 302903,
  [SMALL_STATE(5782)] = 302951,
  [SMALL_STATE(5783)] = 302993,
  [SMALL_STATE(5784)] = 303037,
  [SMALL_STATE(5785)] = 303081,
  [SMALL_STATE(5786)] = 303127,
  [SMALL_STATE(5787)] = 303169,
  [SMALL_STATE(5788)] = 303211,
  [SMALL_STATE(5789)] = 303257,
  [SMALL_STATE(5790)] = 303299,
  [SMALL_STATE(5791)] = 303341,
  [SMALL_STATE(5792)] = 303403,
  [SMALL_STATE(5793)] = 303457,
  [SMALL_STATE(5794)] = 303501,
  [SMALL_STATE(5795)] = 303545,
  [SMALL_STATE(5796)] = 303587,
  [SMALL_STATE(5797)] = 303629,
  [SMALL_STATE(5798)] = 303691,
  [SMALL_STATE(5799)] = 303733,
  [SMALL_STATE(5800)] = 303775,
  [SMALL_STATE(5801)] = 303817,
  [SMALL_STATE(5802)] = 303871,
  [SMALL_STATE(5803)] = 303913,
  [SMALL_STATE(5804)] = 303955,
  [SMALL_STATE(5805)] = 303997,
  [SMALL_STATE(5806)] = 304039,
  [SMALL_STATE(5807)] = 304081,
  [SMALL_STATE(5808)] = 304133,
  [SMALL_STATE(5809)] = 304175,
  [SMALL_STATE(5810)] = 304225,
  [SMALL_STATE(5811)] = 304267,
  [SMALL_STATE(5812)] = 304321,
  [SMALL_STATE(5813)] = 304367,
  [SMALL_STATE(5814)] = 304409,
  [SMALL_STATE(5815)] = 304451,
  [SMALL_STATE(5816)] = 304493,
  [SMALL_STATE(5817)] = 304539,
  [SMALL_STATE(5818)] = 304581,
  [SMALL_STATE(5819)] = 304635,
  [SMALL_STATE(5820)] = 304691,
  [SMALL_STATE(5821)] = 304733,
  [SMALL_STATE(5822)] = 304775,
  [SMALL_STATE(5823)] = 304841,
  [SMALL_STATE(5824)] = 304895,
  [SMALL_STATE(5825)] = 304937,
  [SMALL_STATE(5826)] = 304993,
  [SMALL_STATE(5827)] = 305055,
  [SMALL_STATE(5828)] = 305099,
  [SMALL_STATE(5829)] = 305145,
  [SMALL_STATE(5830)] = 305187,
  [SMALL_STATE(5831)] = 305229,
  [SMALL_STATE(5832)] = 305271,
  [SMALL_STATE(5833)] = 305313,
  [SMALL_STATE(5834)] = 305379,
  [SMALL_STATE(5835)] = 305421,
  [SMALL_STATE(5836)] = 305463,
  [SMALL_STATE(5837)] = 305505,
  [SMALL_STATE(5838)] = 305547,
  [SMALL_STATE(5839)] = 305601,
  [SMALL_STATE(5840)] = 305643,
  [SMALL_STATE(5841)] = 305685,
  [SMALL_STATE(5842)] = 305751,
  [SMALL_STATE(5843)] = 305805,
  [SMALL_STATE(5844)] = 305851,
  [SMALL_STATE(5845)] = 305893,
  [SMALL_STATE(5846)] = 305937,
  [SMALL_STATE(5847)] = 305985,
  [SMALL_STATE(5848)] = 306027,
  [SMALL_STATE(5849)] = 306071,
  [SMALL_STATE(5850)] = 306113,
  [SMALL_STATE(5851)] = 306155,
  [SMALL_STATE(5852)] = 306209,
  [SMALL_STATE(5853)] = 306251,
  [SMALL_STATE(5854)] = 306305,
  [SMALL_STATE(5855)] = 306351,
  [SMALL_STATE(5856)] = 306393,
  [SMALL_STATE(5857)] = 306437,
  [SMALL_STATE(5858)] = 306481,
  [SMALL_STATE(5859)] = 306537,
  [SMALL_STATE(5860)] = 306579,
  [SMALL_STATE(5861)] = 306621,
  [SMALL_STATE(5862)] = 306663,
  [SMALL_STATE(5863)] = 306705,
  [SMALL_STATE(5864)] = 306753,
  [SMALL_STATE(5865)] = 306795,
  [SMALL_STATE(5866)] = 306837,
  [SMALL_STATE(5867)] = 306881,
  [SMALL_STATE(5868)] = 306923,
  [SMALL_STATE(5869)] = 306965,
  [SMALL_STATE(5870)] = 307007,
  [SMALL_STATE(5871)] = 307051,
  [SMALL_STATE(5872)] = 307093,
  [SMALL_STATE(5873)] = 307135,
  [SMALL_STATE(5874)] = 307197,
  [SMALL_STATE(5875)] = 307239,
  [SMALL_STATE(5876)] = 307287,
  [SMALL_STATE(5877)] = 307331,
  [SMALL_STATE(5878)] = 307373,
  [SMALL_STATE(5879)] = 307415,
  [SMALL_STATE(5880)] = 307457,
  [SMALL_STATE(5881)] = 307499,
  [SMALL_STATE(5882)] = 307541,
  [SMALL_STATE(5883)] = 307583,
  [SMALL_STATE(5884)] = 307627,
  [SMALL_STATE(5885)] = 307669,
  [SMALL_STATE(5886)] = 307723,
  [SMALL_STATE(5887)] = 307765,
  [SMALL_STATE(5888)] = 307821,
  [SMALL_STATE(5889)] = 307869,
  [SMALL_STATE(5890)] = 307913,
  [SMALL_STATE(5891)] = 307955,
  [SMALL_STATE(5892)] = 308009,
  [SMALL_STATE(5893)] = 308063,
  [SMALL_STATE(5894)] = 308109,
  [SMALL_STATE(5895)] = 308151,
  [SMALL_STATE(5896)] = 308193,
  [SMALL_STATE(5897)] = 308235,
  [SMALL_STATE(5898)] = 308283,
  [SMALL_STATE(5899)] = 308325,
  [SMALL_STATE(5900)] = 308367,
  [SMALL_STATE(5901)] = 308409,
  [SMALL_STATE(5902)] = 308451,
  [SMALL_STATE(5903)] = 308493,
  [SMALL_STATE(5904)] = 308535,
  [SMALL_STATE(5905)] = 308583,
  [SMALL_STATE(5906)] = 308625,
  [SMALL_STATE(5907)] = 308667,
  [SMALL_STATE(5908)] = 308709,
  [SMALL_STATE(5909)] = 308751,
  [SMALL_STATE(5910)] = 308811,
  [SMALL_STATE(5911)] = 308857,
  [SMALL_STATE(5912)] = 308919,
  [SMALL_STATE(5913)] = 308961,
  [SMALL_STATE(5914)] = 309003,
  [SMALL_STATE(5915)] = 309045,
  [SMALL_STATE(5916)] = 309087,
  [SMALL_STATE(5917)] = 309131,
  [SMALL_STATE(5918)] = 309173,
  [SMALL_STATE(5919)] = 309219,
  [SMALL_STATE(5920)] = 309261,
  [SMALL_STATE(5921)] = 309315,
  [SMALL_STATE(5922)] = 309357,
  [SMALL_STATE(5923)] = 309403,
  [SMALL_STATE(5924)] = 309445,
  [SMALL_STATE(5925)] = 309499,
  [SMALL_STATE(5926)] = 309555,
  [SMALL_STATE(5927)] = 309597,
  [SMALL_STATE(5928)] = 309641,
  [SMALL_STATE(5929)] = 309683,
  [SMALL_STATE(5930)] = 309725,
  [SMALL_STATE(5931)] = 309767,
  [SMALL_STATE(5932)] = 309809,
  [SMALL_STATE(5933)] = 309851,
  [SMALL_STATE(5934)] = 309893,
  [SMALL_STATE(5935)] = 309939,
  [SMALL_STATE(5936)] = 309993,
  [SMALL_STATE(5937)] = 310035,
  [SMALL_STATE(5938)] = 310083,
  [SMALL_STATE(5939)] = 310127,
  [SMALL_STATE(5940)] = 310171,
  [SMALL_STATE(5941)] = 310217,
  [SMALL_STATE(5942)] = 310259,
  [SMALL_STATE(5943)] = 310321,
  [SMALL_STATE(5944)] = 310363,
  [SMALL_STATE(5945)] = 310405,
  [SMALL_STATE(5946)] = 310459,
  [SMALL_STATE(5947)] = 310501,
  [SMALL_STATE(5948)] = 310543,
  [SMALL_STATE(5949)] = 310585,
  [SMALL_STATE(5950)] = 310629,
  [SMALL_STATE(5951)] = 310671,
  [SMALL_STATE(5952)] = 310713,
  [SMALL_STATE(5953)] = 310755,
  [SMALL_STATE(5954)] = 310797,
  [SMALL_STATE(5955)] = 310839,
  [SMALL_STATE(5956)] = 310881,
  [SMALL_STATE(5957)] = 310925,
  [SMALL_STATE(5958)] = 310967,
  [SMALL_STATE(5959)] = 311015,
  [SMALL_STATE(5960)] = 311057,
  [SMALL_STATE(5961)] = 311099,
  [SMALL_STATE(5962)] = 311141,
  [SMALL_STATE(5963)] = 311187,
  [SMALL_STATE(5964)] = 311229,
  [SMALL_STATE(5965)] = 311295,
  [SMALL_STATE(5966)] = 311337,
  [SMALL_STATE(5967)] = 311379,
  [SMALL_STATE(5968)] = 311421,
  [SMALL_STATE(5969)] = 311463,
  [SMALL_STATE(5970)] = 311505,
  [SMALL_STATE(5971)] = 311547,
  [SMALL_STATE(5972)] = 311591,
  [SMALL_STATE(5973)] = 311633,
  [SMALL_STATE(5974)] = 311675,
  [SMALL_STATE(5975)] = 311717,
  [SMALL_STATE(5976)] = 311759,
  [SMALL_STATE(5977)] = 311801,
  [SMALL_STATE(5978)] = 311855,
  [SMALL_STATE(5979)] = 311897,
  [SMALL_STATE(5980)] = 311939,
  [SMALL_STATE(5981)] = 311983,
  [SMALL_STATE(5982)] = 312025,
  [SMALL_STATE(5983)] = 312081,
  [SMALL_STATE(5984)] = 312123,
  [SMALL_STATE(5985)] = 312165,
  [SMALL_STATE(5986)] = 312209,
  [SMALL_STATE(5987)] = 312251,
  [SMALL_STATE(5988)] = 312293,
  [SMALL_STATE(5989)] = 312335,
  [SMALL_STATE(5990)] = 312383,
  [SMALL_STATE(5991)] = 312427,
  [SMALL_STATE(5992)] = 312471,
  [SMALL_STATE(5993)] = 312517,
  [SMALL_STATE(5994)] = 312559,
  [SMALL_STATE(5995)] = 312600,
  [SMALL_STATE(5996)] = 312653,
  [SMALL_STATE(5997)] = 312700,
  [SMALL_STATE(5998)] = 312741,
  [SMALL_STATE(5999)] = 312782,
  [SMALL_STATE(6000)] = 312823,
  [SMALL_STATE(6001)] = 312864,
  [SMALL_STATE(6002)] = 312911,
  [SMALL_STATE(6003)] = 312952,
  [SMALL_STATE(6004)] = 312995,
  [SMALL_STATE(6005)] = 313036,
  [SMALL_STATE(6006)] = 313089,
  [SMALL_STATE(6007)] = 313130,
  [SMALL_STATE(6008)] = 313173,
  [SMALL_STATE(6009)] = 313214,
  [SMALL_STATE(6010)] = 313279,
  [SMALL_STATE(6011)] = 313322,
  [SMALL_STATE(6012)] = 313387,
  [SMALL_STATE(6013)] = 313428,
  [SMALL_STATE(6014)] = 313473,
  [SMALL_STATE(6015)] = 313514,
  [SMALL_STATE(6016)] = 313561,
  [SMALL_STATE(6017)] = 313602,
  [SMALL_STATE(6018)] = 313667,
  [SMALL_STATE(6019)] = 313710,
  [SMALL_STATE(6020)] = 313751,
  [SMALL_STATE(6021)] = 313794,
  [SMALL_STATE(6022)] = 313835,
  [SMALL_STATE(6023)] = 313876,
  [SMALL_STATE(6024)] = 313917,
  [SMALL_STATE(6025)] = 313958,
  [SMALL_STATE(6026)] = 313999,
  [SMALL_STATE(6027)] = 314040,
  [SMALL_STATE(6028)] = 314081,
  [SMALL_STATE(6029)] = 314122,
  [SMALL_STATE(6030)] = 314163,
  [SMALL_STATE(6031)] = 314204,
  [SMALL_STATE(6032)] = 314245,
  [SMALL_STATE(6033)] = 314286,
  [SMALL_STATE(6034)] = 314333,
  [SMALL_STATE(6035)] = 314374,
  [SMALL_STATE(6036)] = 314415,
  [SMALL_STATE(6037)] = 314460,
  [SMALL_STATE(6038)] = 314509,
  [SMALL_STATE(6039)] = 314556,
  [SMALL_STATE(6040)] = 314601,
  [SMALL_STATE(6041)] = 314642,
  [SMALL_STATE(6042)] = 314683,
  [SMALL_STATE(6043)] = 314734,
  [SMALL_STATE(6044)] = 314775,
  [SMALL_STATE(6045)] = 314818,
  [SMALL_STATE(6046)] = 314859,
  [SMALL_STATE(6047)] = 314900,
  [SMALL_STATE(6048)] = 314947,
  [SMALL_STATE(6049)] = 314988,
  [SMALL_STATE(6050)] = 315033,
  [SMALL_STATE(6051)] = 315074,
  [SMALL_STATE(6052)] = 315115,
  [SMALL_STATE(6053)] = 315162,
  [SMALL_STATE(6054)] = 315203,
  [SMALL_STATE(6055)] = 315244,
  [SMALL_STATE(6056)] = 315309,
  [SMALL_STATE(6057)] = 315350,
  [SMALL_STATE(6058)] = 315391,
  [SMALL_STATE(6059)] = 315432,
  [SMALL_STATE(6060)] = 315473,
  [SMALL_STATE(6061)] = 315516,
  [SMALL_STATE(6062)] = 315557,
  [SMALL_STATE(6063)] = 315598,
  [SMALL_STATE(6064)] = 315639,
  [SMALL_STATE(6065)] = 315682,
  [SMALL_STATE(6066)] = 315723,
  [SMALL_STATE(6067)] = 315764,
  [SMALL_STATE(6068)] = 315817,
  [SMALL_STATE(6069)] = 315858,
  [SMALL_STATE(6070)] = 315903,
  [SMALL_STATE(6071)] = 315946,
  [SMALL_STATE(6072)] = 315991,
  [SMALL_STATE(6073)] = 316036,
  [SMALL_STATE(6074)] = 316077,
  [SMALL_STATE(6075)] = 316118,
  [SMALL_STATE(6076)] = 316161,
  [SMALL_STATE(6077)] = 316202,
  [SMALL_STATE(6078)] = 316243,
  [SMALL_STATE(6079)] = 316284,
  [SMALL_STATE(6080)] = 316325,
  [SMALL_STATE(6081)] = 316366,
  [SMALL_STATE(6082)] = 316407,
  [SMALL_STATE(6083)] = 316452,
  [SMALL_STATE(6084)] = 316493,
  [SMALL_STATE(6085)] = 316534,
  [SMALL_STATE(6086)] = 316575,
  [SMALL_STATE(6087)] = 316640,
  [SMALL_STATE(6088)] = 316681,
  [SMALL_STATE(6089)] = 316736,
  [SMALL_STATE(6090)] = 316777,
  [SMALL_STATE(6091)] = 316830,
  [SMALL_STATE(6092)] = 316871,
  [SMALL_STATE(6093)] = 316912,
  [SMALL_STATE(6094)] = 316953,
  [SMALL_STATE(6095)] = 316994,
  [SMALL_STATE(6096)] = 317035,
  [SMALL_STATE(6097)] = 317088,
  [SMALL_STATE(6098)] = 317129,
  [SMALL_STATE(6099)] = 317170,
  [SMALL_STATE(6100)] = 317211,
  [SMALL_STATE(6101)] = 317256,
  [SMALL_STATE(6102)] = 317309,
  [SMALL_STATE(6103)] = 317356,
  [SMALL_STATE(6104)] = 317397,
  [SMALL_STATE(6105)] = 317462,
  [SMALL_STATE(6106)] = 317503,
  [SMALL_STATE(6107)] = 317546,
  [SMALL_STATE(6108)] = 317587,
  [SMALL_STATE(6109)] = 317630,
  [SMALL_STATE(6110)] = 317677,
  [SMALL_STATE(6111)] = 317718,
  [SMALL_STATE(6112)] = 317759,
  [SMALL_STATE(6113)] = 317802,
  [SMALL_STATE(6114)] = 317843,
  [SMALL_STATE(6115)] = 317884,
  [SMALL_STATE(6116)] = 317927,
  [SMALL_STATE(6117)] = 317968,
  [SMALL_STATE(6118)] = 318009,
  [SMALL_STATE(6119)] = 318050,
  [SMALL_STATE(6120)] = 318091,
  [SMALL_STATE(6121)] = 318132,
  [SMALL_STATE(6122)] = 318177,
  [SMALL_STATE(6123)] = 318220,
  [SMALL_STATE(6124)] = 318261,
  [SMALL_STATE(6125)] = 318302,
  [SMALL_STATE(6126)] = 318343,
  [SMALL_STATE(6127)] = 318388,
  [SMALL_STATE(6128)] = 318429,
  [SMALL_STATE(6129)] = 318494,
  [SMALL_STATE(6130)] = 318535,
  [SMALL_STATE(6131)] = 318576,
  [SMALL_STATE(6132)] = 318637,
  [SMALL_STATE(6133)] = 318680,
  [SMALL_STATE(6134)] = 318745,
  [SMALL_STATE(6135)] = 318786,
  [SMALL_STATE(6136)] = 318827,
  [SMALL_STATE(6137)] = 318868,
  [SMALL_STATE(6138)] = 318909,
  [SMALL_STATE(6139)] = 318974,
  [SMALL_STATE(6140)] = 319015,
  [SMALL_STATE(6141)] = 319056,
  [SMALL_STATE(6142)] = 319097,
  [SMALL_STATE(6143)] = 319138,
  [SMALL_STATE(6144)] = 319179,
  [SMALL_STATE(6145)] = 319220,
  [SMALL_STATE(6146)] = 319261,
  [SMALL_STATE(6147)] = 319302,
  [SMALL_STATE(6148)] = 319349,
  [SMALL_STATE(6149)] = 319402,
  [SMALL_STATE(6150)] = 319443,
  [SMALL_STATE(6151)] = 319484,
  [SMALL_STATE(6152)] = 319525,
  [SMALL_STATE(6153)] = 319568,
  [SMALL_STATE(6154)] = 319609,
  [SMALL_STATE(6155)] = 319652,
  [SMALL_STATE(6156)] = 319705,
  [SMALL_STATE(6157)] = 319746,
  [SMALL_STATE(6158)] = 319787,
  [SMALL_STATE(6159)] = 319828,
  [SMALL_STATE(6160)] = 319869,
  [SMALL_STATE(6161)] = 319910,
  [SMALL_STATE(6162)] = 319963,
  [SMALL_STATE(6163)] = 320004,
  [SMALL_STATE(6164)] = 320045,
  [SMALL_STATE(6165)] = 320086,
  [SMALL_STATE(6166)] = 320139,
  [SMALL_STATE(6167)] = 320184,
  [SMALL_STATE(6168)] = 320225,
  [SMALL_STATE(6169)] = 320266,
  [SMALL_STATE(6170)] = 320321,
  [SMALL_STATE(6171)] = 320362,
  [SMALL_STATE(6172)] = 320403,
  [SMALL_STATE(6173)] = 320444,
  [SMALL_STATE(6174)] = 320491,
  [SMALL_STATE(6175)] = 320532,
  [SMALL_STATE(6176)] = 320573,
  [SMALL_STATE(6177)] = 320616,
  [SMALL_STATE(6178)] = 320661,
  [SMALL_STATE(6179)] = 320702,
  [SMALL_STATE(6180)] = 320743,
  [SMALL_STATE(6181)] = 320784,
  [SMALL_STATE(6182)] = 320825,
  [SMALL_STATE(6183)] = 320880,
  [SMALL_STATE(6184)] = 320945,
  [SMALL_STATE(6185)] = 320986,
  [SMALL_STATE(6186)] = 321027,
  [SMALL_STATE(6187)] = 321092,
  [SMALL_STATE(6188)] = 321133,
  [SMALL_STATE(6189)] = 321174,
  [SMALL_STATE(6190)] = 321247,
  [SMALL_STATE(6191)] = 321312,
  [SMALL_STATE(6192)] = 321353,
  [SMALL_STATE(6193)] = 321394,
  [SMALL_STATE(6194)] = 321435,
  [SMALL_STATE(6195)] = 321476,
  [SMALL_STATE(6196)] = 321519,
  [SMALL_STATE(6197)] = 321560,
  [SMALL_STATE(6198)] = 321613,
  [SMALL_STATE(6199)] = 321654,
  [SMALL_STATE(6200)] = 321695,
  [SMALL_STATE(6201)] = 321736,
  [SMALL_STATE(6202)] = 321777,
  [SMALL_STATE(6203)] = 321818,
  [SMALL_STATE(6204)] = 321859,
  [SMALL_STATE(6205)] = 321900,
  [SMALL_STATE(6206)] = 321941,
  [SMALL_STATE(6207)] = 321994,
  [SMALL_STATE(6208)] = 322047,
  [SMALL_STATE(6209)] = 322088,
  [SMALL_STATE(6210)] = 322129,
  [SMALL_STATE(6211)] = 322170,
  [SMALL_STATE(6212)] = 322211,
  [SMALL_STATE(6213)] = 322252,
  [SMALL_STATE(6214)] = 322293,
  [SMALL_STATE(6215)] = 322336,
  [SMALL_STATE(6216)] = 322377,
  [SMALL_STATE(6217)] = 322418,
  [SMALL_STATE(6218)] = 322459,
  [SMALL_STATE(6219)] = 322500,
  [SMALL_STATE(6220)] = 322541,
  [SMALL_STATE(6221)] = 322582,
  [SMALL_STATE(6222)] = 322623,
  [SMALL_STATE(6223)] = 322664,
  [SMALL_STATE(6224)] = 322719,
  [SMALL_STATE(6225)] = 322760,
  [SMALL_STATE(6226)] = 322801,
  [SMALL_STATE(6227)] = 322842,
  [SMALL_STATE(6228)] = 322883,
  [SMALL_STATE(6229)] = 322924,
  [SMALL_STATE(6230)] = 322967,
  [SMALL_STATE(6231)] = 323008,
  [SMALL_STATE(6232)] = 323063,
  [SMALL_STATE(6233)] = 323108,
  [SMALL_STATE(6234)] = 323149,
  [SMALL_STATE(6235)] = 323194,
  [SMALL_STATE(6236)] = 323259,
  [SMALL_STATE(6237)] = 323300,
  [SMALL_STATE(6238)] = 323341,
  [SMALL_STATE(6239)] = 323382,
  [SMALL_STATE(6240)] = 323423,
  [SMALL_STATE(6241)] = 323464,
  [SMALL_STATE(6242)] = 323505,
  [SMALL_STATE(6243)] = 323546,
  [SMALL_STATE(6244)] = 323607,
  [SMALL_STATE(6245)] = 323650,
  [SMALL_STATE(6246)] = 323691,
  [SMALL_STATE(6247)] = 323734,
  [SMALL_STATE(6248)] = 323775,
  [SMALL_STATE(6249)] = 323836,
  [SMALL_STATE(6250)] = 323889,
  [SMALL_STATE(6251)] = 323930,
  [SMALL_STATE(6252)] = 323995,
  [SMALL_STATE(6253)] = 324036,
  [SMALL_STATE(6254)] = 324077,
  [SMALL_STATE(6255)] = 324120,
  [SMALL_STATE(6256)] = 324161,
  [SMALL_STATE(6257)] = 324222,
  [SMALL_STATE(6258)] = 324263,
  [SMALL_STATE(6259)] = 324304,
  [SMALL_STATE(6260)] = 324345,
  [SMALL_STATE(6261)] = 324388,
  [SMALL_STATE(6262)] = 324431,
  [SMALL_STATE(6263)] = 324472,
  [SMALL_STATE(6264)] = 324515,
  [SMALL_STATE(6265)] = 324556,
  [SMALL_STATE(6266)] = 324605,
  [SMALL_STATE(6267)] = 324646,
  [SMALL_STATE(6268)] = 324687,
  [SMALL_STATE(6269)] = 324728,
  [SMALL_STATE(6270)] = 324769,
  [SMALL_STATE(6271)] = 324810,
  [SMALL_STATE(6272)] = 324863,
  [SMALL_STATE(6273)] = 324904,
  [SMALL_STATE(6274)] = 324945,
  [SMALL_STATE(6275)] = 324990,
  [SMALL_STATE(6276)] = 325031,
  [SMALL_STATE(6277)] = 325072,
  [SMALL_STATE(6278)] = 325113,
  [SMALL_STATE(6279)] = 325154,
  [SMALL_STATE(6280)] = 325199,
  [SMALL_STATE(6281)] = 325240,
  [SMALL_STATE(6282)] = 325281,
  [SMALL_STATE(6283)] = 325322,
  [SMALL_STATE(6284)] = 325363,
  [SMALL_STATE(6285)] = 325406,
  [SMALL_STATE(6286)] = 325447,
  [SMALL_STATE(6287)] = 325488,
  [SMALL_STATE(6288)] = 325529,
  [SMALL_STATE(6289)] = 325570,
  [SMALL_STATE(6290)] = 325619,
  [SMALL_STATE(6291)] = 325660,
  [SMALL_STATE(6292)] = 325701,
  [SMALL_STATE(6293)] = 325742,
  [SMALL_STATE(6294)] = 325783,
  [SMALL_STATE(6295)] = 325844,
  [SMALL_STATE(6296)] = 325897,
  [SMALL_STATE(6297)] = 325940,
  [SMALL_STATE(6298)] = 325981,
  [SMALL_STATE(6299)] = 326022,
  [SMALL_STATE(6300)] = 326077,
  [SMALL_STATE(6301)] = 326118,
  [SMALL_STATE(6302)] = 326159,
  [SMALL_STATE(6303)] = 326202,
  [SMALL_STATE(6304)] = 326243,
  [SMALL_STATE(6305)] = 326284,
  [SMALL_STATE(6306)] = 326325,
  [SMALL_STATE(6307)] = 326366,
  [SMALL_STATE(6308)] = 326407,
  [SMALL_STATE(6309)] = 326448,
  [SMALL_STATE(6310)] = 326505,
  [SMALL_STATE(6311)] = 326546,
  [SMALL_STATE(6312)] = 326587,
  [SMALL_STATE(6313)] = 326630,
  [SMALL_STATE(6314)] = 326671,
  [SMALL_STATE(6315)] = 326712,
  [SMALL_STATE(6316)] = 326753,
  [SMALL_STATE(6317)] = 326806,
  [SMALL_STATE(6318)] = 326847,
  [SMALL_STATE(6319)] = 326888,
  [SMALL_STATE(6320)] = 326935,
  [SMALL_STATE(6321)] = 326976,
  [SMALL_STATE(6322)] = 327017,
  [SMALL_STATE(6323)] = 327058,
  [SMALL_STATE(6324)] = 327099,
  [SMALL_STATE(6325)] = 327142,
  [SMALL_STATE(6326)] = 327197,
  [SMALL_STATE(6327)] = 327242,
  [SMALL_STATE(6328)] = 327285,
  [SMALL_STATE(6329)] = 327338,
  [SMALL_STATE(6330)] = 327379,
  [SMALL_STATE(6331)] = 327420,
  [SMALL_STATE(6332)] = 327461,
  [SMALL_STATE(6333)] = 327508,
  [SMALL_STATE(6334)] = 327563,
  [SMALL_STATE(6335)] = 327604,
  [SMALL_STATE(6336)] = 327647,
  [SMALL_STATE(6337)] = 327688,
  [SMALL_STATE(6338)] = 327731,
  [SMALL_STATE(6339)] = 327796,
  [SMALL_STATE(6340)] = 327841,
  [SMALL_STATE(6341)] = 327882,
  [SMALL_STATE(6342)] = 327923,
  [SMALL_STATE(6343)] = 327964,
  [SMALL_STATE(6344)] = 328005,
  [SMALL_STATE(6345)] = 328046,
  [SMALL_STATE(6346)] = 328087,
  [SMALL_STATE(6347)] = 328128,
  [SMALL_STATE(6348)] = 328169,
  [SMALL_STATE(6349)] = 328210,
  [SMALL_STATE(6350)] = 328253,
  [SMALL_STATE(6351)] = 328294,
  [SMALL_STATE(6352)] = 328335,
  [SMALL_STATE(6353)] = 328376,
  [SMALL_STATE(6354)] = 328419,
  [SMALL_STATE(6355)] = 328460,
  [SMALL_STATE(6356)] = 328501,
  [SMALL_STATE(6357)] = 328542,
  [SMALL_STATE(6358)] = 328595,
  [SMALL_STATE(6359)] = 328636,
  [SMALL_STATE(6360)] = 328677,
  [SMALL_STATE(6361)] = 328718,
  [SMALL_STATE(6362)] = 328767,
  [SMALL_STATE(6363)] = 328808,
  [SMALL_STATE(6364)] = 328855,
  [SMALL_STATE(6365)] = 328896,
  [SMALL_STATE(6366)] = 328939,
  [SMALL_STATE(6367)] = 328980,
  [SMALL_STATE(6368)] = 329021,
  [SMALL_STATE(6369)] = 329062,
  [SMALL_STATE(6370)] = 329115,
  [SMALL_STATE(6371)] = 329176,
  [SMALL_STATE(6372)] = 329217,
  [SMALL_STATE(6373)] = 329258,
  [SMALL_STATE(6374)] = 329299,
  [SMALL_STATE(6375)] = 329340,
  [SMALL_STATE(6376)] = 329381,
  [SMALL_STATE(6377)] = 329428,
  [SMALL_STATE(6378)] = 329469,
  [SMALL_STATE(6379)] = 329510,
  [SMALL_STATE(6380)] = 329553,
  [SMALL_STATE(6381)] = 329594,
  [SMALL_STATE(6382)] = 329635,
  [SMALL_STATE(6383)] = 329688,
  [SMALL_STATE(6384)] = 329729,
  [SMALL_STATE(6385)] = 329782,
  [SMALL_STATE(6386)] = 329823,
  [SMALL_STATE(6387)] = 329864,
  [SMALL_STATE(6388)] = 329905,
  [SMALL_STATE(6389)] = 329946,
  [SMALL_STATE(6390)] = 329987,
  [SMALL_STATE(6391)] = 330028,
  [SMALL_STATE(6392)] = 330069,
  [SMALL_STATE(6393)] = 330110,
  [SMALL_STATE(6394)] = 330151,
  [SMALL_STATE(6395)] = 330192,
  [SMALL_STATE(6396)] = 330233,
  [SMALL_STATE(6397)] = 330274,
  [SMALL_STATE(6398)] = 330317,
  [SMALL_STATE(6399)] = 330358,
  [SMALL_STATE(6400)] = 330399,
  [SMALL_STATE(6401)] = 330440,
  [SMALL_STATE(6402)] = 330487,
  [SMALL_STATE(6403)] = 330528,
  [SMALL_STATE(6404)] = 330571,
  [SMALL_STATE(6405)] = 330612,
  [SMALL_STATE(6406)] = 330657,
  [SMALL_STATE(6407)] = 330698,
  [SMALL_STATE(6408)] = 330739,
  [SMALL_STATE(6409)] = 330794,
  [SMALL_STATE(6410)] = 330835,
  [SMALL_STATE(6411)] = 330876,
  [SMALL_STATE(6412)] = 330941,
  [SMALL_STATE(6413)] = 330982,
  [SMALL_STATE(6414)] = 331023,
  [SMALL_STATE(6415)] = 331064,
  [SMALL_STATE(6416)] = 331105,
  [SMALL_STATE(6417)] = 331146,
  [SMALL_STATE(6418)] = 331189,
  [SMALL_STATE(6419)] = 331230,
  [SMALL_STATE(6420)] = 331271,
  [SMALL_STATE(6421)] = 331312,
  [SMALL_STATE(6422)] = 331353,
  [SMALL_STATE(6423)] = 331394,
  [SMALL_STATE(6424)] = 331437,
  [SMALL_STATE(6425)] = 331478,
  [SMALL_STATE(6426)] = 331531,
  [SMALL_STATE(6427)] = 331572,
  [SMALL_STATE(6428)] = 331613,
  [SMALL_STATE(6429)] = 331654,
  [SMALL_STATE(6430)] = 331707,
  [SMALL_STATE(6431)] = 331748,
  [SMALL_STATE(6432)] = 331791,
  [SMALL_STATE(6433)] = 331836,
  [SMALL_STATE(6434)] = 331877,
  [SMALL_STATE(6435)] = 331918,
  [SMALL_STATE(6436)] = 331959,
  [SMALL_STATE(6437)] = 332006,
  [SMALL_STATE(6438)] = 332047,
  [SMALL_STATE(6439)] = 332090,
  [SMALL_STATE(6440)] = 332131,
  [SMALL_STATE(6441)] = 332178,
  [SMALL_STATE(6442)] = 332219,
  [SMALL_STATE(6443)] = 332272,
  [SMALL_STATE(6444)] = 332313,
  [SMALL_STATE(6445)] = 332354,
  [SMALL_STATE(6446)] = 332395,
  [SMALL_STATE(6447)] = 332436,
  [SMALL_STATE(6448)] = 332481,
  [SMALL_STATE(6449)] = 332526,
  [SMALL_STATE(6450)] = 332567,
  [SMALL_STATE(6451)] = 332608,
  [SMALL_STATE(6452)] = 332649,
  [SMALL_STATE(6453)] = 332702,
  [SMALL_STATE(6454)] = 332755,
  [SMALL_STATE(6455)] = 332798,
  [SMALL_STATE(6456)] = 332839,
  [SMALL_STATE(6457)] = 332904,
  [SMALL_STATE(6458)] = 332965,
  [SMALL_STATE(6459)] = 333006,
  [SMALL_STATE(6460)] = 333047,
  [SMALL_STATE(6461)] = 333088,
  [SMALL_STATE(6462)] = 333129,
  [SMALL_STATE(6463)] = 333176,
  [SMALL_STATE(6464)] = 333217,
  [SMALL_STATE(6465)] = 333260,
  [SMALL_STATE(6466)] = 333303,
  [SMALL_STATE(6467)] = 333344,
  [SMALL_STATE(6468)] = 333385,
  [SMALL_STATE(6469)] = 333426,
  [SMALL_STATE(6470)] = 333467,
  [SMALL_STATE(6471)] = 333508,
  [SMALL_STATE(6472)] = 333549,
  [SMALL_STATE(6473)] = 333590,
  [SMALL_STATE(6474)] = 333631,
  [SMALL_STATE(6475)] = 333674,
  [SMALL_STATE(6476)] = 333735,
  [SMALL_STATE(6477)] = 333776,
  [SMALL_STATE(6478)] = 333817,
  [SMALL_STATE(6479)] = 333858,
  [SMALL_STATE(6480)] = 333899,
  [SMALL_STATE(6481)] = 333942,
  [SMALL_STATE(6482)] = 333983,
  [SMALL_STATE(6483)] = 334024,
  [SMALL_STATE(6484)] = 334069,
  [SMALL_STATE(6485)] = 334110,
  [SMALL_STATE(6486)] = 334151,
  [SMALL_STATE(6487)] = 334192,
  [SMALL_STATE(6488)] = 334233,
  [SMALL_STATE(6489)] = 334278,
  [SMALL_STATE(6490)] = 334323,
  [SMALL_STATE(6491)] = 334364,
  [SMALL_STATE(6492)] = 334407,
  [SMALL_STATE(6493)] = 334448,
  [SMALL_STATE(6494)] = 334491,
  [SMALL_STATE(6495)] = 334532,
  [SMALL_STATE(6496)] = 334573,
  [SMALL_STATE(6497)] = 334614,
  [SMALL_STATE(6498)] = 334655,
  [SMALL_STATE(6499)] = 334696,
  [SMALL_STATE(6500)] = 334737,
  [SMALL_STATE(6501)] = 334778,
  [SMALL_STATE(6502)] = 334819,
  [SMALL_STATE(6503)] = 334860,
  [SMALL_STATE(6504)] = 334901,
  [SMALL_STATE(6505)] = 334942,
  [SMALL_STATE(6506)] = 334983,
  [SMALL_STATE(6507)] = 335024,
  [SMALL_STATE(6508)] = 335065,
  [SMALL_STATE(6509)] = 335106,
  [SMALL_STATE(6510)] = 335147,
  [SMALL_STATE(6511)] = 335208,
  [SMALL_STATE(6512)] = 335253,
  [SMALL_STATE(6513)] = 335294,
  [SMALL_STATE(6514)] = 335337,
  [SMALL_STATE(6515)] = 335378,
  [SMALL_STATE(6516)] = 335433,
  [SMALL_STATE(6517)] = 335474,
  [SMALL_STATE(6518)] = 335515,
  [SMALL_STATE(6519)] = 335562,
  [SMALL_STATE(6520)] = 335603,
  [SMALL_STATE(6521)] = 335644,
  [SMALL_STATE(6522)] = 335685,
  [SMALL_STATE(6523)] = 335726,
  [SMALL_STATE(6524)] = 335767,
  [SMALL_STATE(6525)] = 335808,
  [SMALL_STATE(6526)] = 335861,
  [SMALL_STATE(6527)] = 335908,
  [SMALL_STATE(6528)] = 335949,
  [SMALL_STATE(6529)] = 335990,
  [SMALL_STATE(6530)] = 336033,
  [SMALL_STATE(6531)] = 336080,
  [SMALL_STATE(6532)] = 336121,
  [SMALL_STATE(6533)] = 336162,
  [SMALL_STATE(6534)] = 336203,
  [SMALL_STATE(6535)] = 336244,
  [SMALL_STATE(6536)] = 336289,
  [SMALL_STATE(6537)] = 336332,
  [SMALL_STATE(6538)] = 336377,
  [SMALL_STATE(6539)] = 336420,
  [SMALL_STATE(6540)] = 336461,
  [SMALL_STATE(6541)] = 336516,
  [SMALL_STATE(6542)] = 336557,
  [SMALL_STATE(6543)] = 336598,
  [SMALL_STATE(6544)] = 336639,
  [SMALL_STATE(6545)] = 336680,
  [SMALL_STATE(6546)] = 336721,
  [SMALL_STATE(6547)] = 336762,
  [SMALL_STATE(6548)] = 336817,
  [SMALL_STATE(6549)] = 336858,
  [SMALL_STATE(6550)] = 336899,
  [SMALL_STATE(6551)] = 336940,
  [SMALL_STATE(6552)] = 336981,
  [SMALL_STATE(6553)] = 337028,
  [SMALL_STATE(6554)] = 337069,
  [SMALL_STATE(6555)] = 337110,
  [SMALL_STATE(6556)] = 337151,
  [SMALL_STATE(6557)] = 337192,
  [SMALL_STATE(6558)] = 337233,
  [SMALL_STATE(6559)] = 337274,
  [SMALL_STATE(6560)] = 337327,
  [SMALL_STATE(6561)] = 337368,
  [SMALL_STATE(6562)] = 337409,
  [SMALL_STATE(6563)] = 337450,
  [SMALL_STATE(6564)] = 337491,
  [SMALL_STATE(6565)] = 337532,
  [SMALL_STATE(6566)] = 337573,
  [SMALL_STATE(6567)] = 337626,
  [SMALL_STATE(6568)] = 337667,
  [SMALL_STATE(6569)] = 337708,
  [SMALL_STATE(6570)] = 337749,
  [SMALL_STATE(6571)] = 337810,
  [SMALL_STATE(6572)] = 337851,
  [SMALL_STATE(6573)] = 337906,
  [SMALL_STATE(6574)] = 337947,
  [SMALL_STATE(6575)] = 337988,
  [SMALL_STATE(6576)] = 338029,
  [SMALL_STATE(6577)] = 338072,
  [SMALL_STATE(6578)] = 338129,
  [SMALL_STATE(6579)] = 338170,
  [SMALL_STATE(6580)] = 338211,
  [SMALL_STATE(6581)] = 338256,
  [SMALL_STATE(6582)] = 338297,
  [SMALL_STATE(6583)] = 338338,
  [SMALL_STATE(6584)] = 338381,
  [SMALL_STATE(6585)] = 338428,
  [SMALL_STATE(6586)] = 338469,
  [SMALL_STATE(6587)] = 338510,
  [SMALL_STATE(6588)] = 338551,
  [SMALL_STATE(6589)] = 338596,
  [SMALL_STATE(6590)] = 338643,
  [SMALL_STATE(6591)] = 338684,
  [SMALL_STATE(6592)] = 338735,
  [SMALL_STATE(6593)] = 338776,
  [SMALL_STATE(6594)] = 338823,
  [SMALL_STATE(6595)] = 338868,
  [SMALL_STATE(6596)] = 338909,
  [SMALL_STATE(6597)] = 338950,
  [SMALL_STATE(6598)] = 338991,
  [SMALL_STATE(6599)] = 339036,
  [SMALL_STATE(6600)] = 339077,
  [SMALL_STATE(6601)] = 339118,
  [SMALL_STATE(6602)] = 339159,
  [SMALL_STATE(6603)] = 339200,
  [SMALL_STATE(6604)] = 339241,
  [SMALL_STATE(6605)] = 339282,
  [SMALL_STATE(6606)] = 339323,
  [SMALL_STATE(6607)] = 339376,
  [SMALL_STATE(6608)] = 339417,
  [SMALL_STATE(6609)] = 339458,
  [SMALL_STATE(6610)] = 339503,
  [SMALL_STATE(6611)] = 339558,
  [SMALL_STATE(6612)] = 339613,
  [SMALL_STATE(6613)] = 339660,
  [SMALL_STATE(6614)] = 339701,
  [SMALL_STATE(6615)] = 339744,
  [SMALL_STATE(6616)] = 339785,
  [SMALL_STATE(6617)] = 339826,
  [SMALL_STATE(6618)] = 339867,
  [SMALL_STATE(6619)] = 339908,
  [SMALL_STATE(6620)] = 339949,
  [SMALL_STATE(6621)] = 339990,
  [SMALL_STATE(6622)] = 340031,
  [SMALL_STATE(6623)] = 340074,
  [SMALL_STATE(6624)] = 340115,
  [SMALL_STATE(6625)] = 340156,
  [SMALL_STATE(6626)] = 340203,
  [SMALL_STATE(6627)] = 340244,
  [SMALL_STATE(6628)] = 340297,
  [SMALL_STATE(6629)] = 340338,
  [SMALL_STATE(6630)] = 340381,
  [SMALL_STATE(6631)] = 340434,
  [SMALL_STATE(6632)] = 340475,
  [SMALL_STATE(6633)] = 340516,
  [SMALL_STATE(6634)] = 340557,
  [SMALL_STATE(6635)] = 340598,
  [SMALL_STATE(6636)] = 340639,
  [SMALL_STATE(6637)] = 340680,
  [SMALL_STATE(6638)] = 340721,
  [SMALL_STATE(6639)] = 340762,
  [SMALL_STATE(6640)] = 340815,
  [SMALL_STATE(6641)] = 340856,
  [SMALL_STATE(6642)] = 340897,
  [SMALL_STATE(6643)] = 340938,
  [SMALL_STATE(6644)] = 340979,
  [SMALL_STATE(6645)] = 341020,
  [SMALL_STATE(6646)] = 341061,
  [SMALL_STATE(6647)] = 341102,
  [SMALL_STATE(6648)] = 341143,
  [SMALL_STATE(6649)] = 341184,
  [SMALL_STATE(6650)] = 341225,
  [SMALL_STATE(6651)] = 341266,
  [SMALL_STATE(6652)] = 341307,
  [SMALL_STATE(6653)] = 341348,
  [SMALL_STATE(6654)] = 341389,
  [SMALL_STATE(6655)] = 341432,
  [SMALL_STATE(6656)] = 341473,
  [SMALL_STATE(6657)] = 341514,
  [SMALL_STATE(6658)] = 341569,
  [SMALL_STATE(6659)] = 341610,
  [SMALL_STATE(6660)] = 341651,
  [SMALL_STATE(6661)] = 341691,
  [SMALL_STATE(6662)] = 341731,
  [SMALL_STATE(6663)] = 341777,
  [SMALL_STATE(6664)] = 341817,
  [SMALL_STATE(6665)] = 341893,
  [SMALL_STATE(6666)] = 341969,
  [SMALL_STATE(6667)] = 342009,
  [SMALL_STATE(6668)] = 342063,
  [SMALL_STATE(6669)] = 342103,
  [SMALL_STATE(6670)] = 342179,
  [SMALL_STATE(6671)] = 342249,
  [SMALL_STATE(6672)] = 342325,
  [SMALL_STATE(6673)] = 342365,
  [SMALL_STATE(6674)] = 342405,
  [SMALL_STATE(6675)] = 342475,
  [SMALL_STATE(6676)] = 342515,
  [SMALL_STATE(6677)] = 342555,
  [SMALL_STATE(6678)] = 342601,
  [SMALL_STATE(6679)] = 342641,
  [SMALL_STATE(6680)] = 342681,
  [SMALL_STATE(6681)] = 342723,
  [SMALL_STATE(6682)] = 342763,
  [SMALL_STATE(6683)] = 342827,
  [SMALL_STATE(6684)] = 342867,
  [SMALL_STATE(6685)] = 342913,
  [SMALL_STATE(6686)] = 342953,
  [SMALL_STATE(6687)] = 343005,
  [SMALL_STATE(6688)] = 343069,
  [SMALL_STATE(6689)] = 343111,
  [SMALL_STATE(6690)] = 343155,
  [SMALL_STATE(6691)] = 343195,
  [SMALL_STATE(6692)] = 343237,
  [SMALL_STATE(6693)] = 343277,
  [SMALL_STATE(6694)] = 343319,
  [SMALL_STATE(6695)] = 343395,
  [SMALL_STATE(6696)] = 343471,
  [SMALL_STATE(6697)] = 343511,
  [SMALL_STATE(6698)] = 343551,
  [SMALL_STATE(6699)] = 343593,
  [SMALL_STATE(6700)] = 343633,
  [SMALL_STATE(6701)] = 343673,
  [SMALL_STATE(6702)] = 343713,
  [SMALL_STATE(6703)] = 343783,
  [SMALL_STATE(6704)] = 343823,
  [SMALL_STATE(6705)] = 343863,
  [SMALL_STATE(6706)] = 343903,
  [SMALL_STATE(6707)] = 343943,
  [SMALL_STATE(6708)] = 343983,
  [SMALL_STATE(6709)] = 344053,
  [SMALL_STATE(6710)] = 344093,
  [SMALL_STATE(6711)] = 344133,
  [SMALL_STATE(6712)] = 344193,
  [SMALL_STATE(6713)] = 344233,
  [SMALL_STATE(6714)] = 344285,
  [SMALL_STATE(6715)] = 344339,
  [SMALL_STATE(6716)] = 344379,
  [SMALL_STATE(6717)] = 344455,
  [SMALL_STATE(6718)] = 344531,
  [SMALL_STATE(6719)] = 344571,
  [SMALL_STATE(6720)] = 344641,
  [SMALL_STATE(6721)] = 344681,
  [SMALL_STATE(6722)] = 344721,
  [SMALL_STATE(6723)] = 344791,
  [SMALL_STATE(6724)] = 344831,
  [SMALL_STATE(6725)] = 344871,
  [SMALL_STATE(6726)] = 344911,
  [SMALL_STATE(6727)] = 344951,
  [SMALL_STATE(6728)] = 344993,
  [SMALL_STATE(6729)] = 345033,
  [SMALL_STATE(6730)] = 345077,
  [SMALL_STATE(6731)] = 345117,
  [SMALL_STATE(6732)] = 345157,
  [SMALL_STATE(6733)] = 345227,
  [SMALL_STATE(6734)] = 345267,
  [SMALL_STATE(6735)] = 345321,
  [SMALL_STATE(6736)] = 345391,
  [SMALL_STATE(6737)] = 345431,
  [SMALL_STATE(6738)] = 345471,
  [SMALL_STATE(6739)] = 345511,
  [SMALL_STATE(6740)] = 345551,
  [SMALL_STATE(6741)] = 345591,
  [SMALL_STATE(6742)] = 345631,
  [SMALL_STATE(6743)] = 345671,
  [SMALL_STATE(6744)] = 345713,
  [SMALL_STATE(6745)] = 345759,
  [SMALL_STATE(6746)] = 345807,
  [SMALL_STATE(6747)] = 345847,
  [SMALL_STATE(6748)] = 345889,
  [SMALL_STATE(6749)] = 345933,
  [SMALL_STATE(6750)] = 345993,
  [SMALL_STATE(6751)] = 346045,
  [SMALL_STATE(6752)] = 346085,
  [SMALL_STATE(6753)] = 346131,
  [SMALL_STATE(6754)] = 346171,
  [SMALL_STATE(6755)] = 346215,
  [SMALL_STATE(6756)] = 346257,
  [SMALL_STATE(6757)] = 346333,
  [SMALL_STATE(6758)] = 346377,
  [SMALL_STATE(6759)] = 346417,
  [SMALL_STATE(6760)] = 346457,
  [SMALL_STATE(6761)] = 346497,
  [SMALL_STATE(6762)] = 346537,
  [SMALL_STATE(6763)] = 346577,
  [SMALL_STATE(6764)] = 346619,
  [SMALL_STATE(6765)] = 346659,
  [SMALL_STATE(6766)] = 346699,
  [SMALL_STATE(6767)] = 346739,
  [SMALL_STATE(6768)] = 346779,
  [SMALL_STATE(6769)] = 346825,
  [SMALL_STATE(6770)] = 346865,
  [SMALL_STATE(6771)] = 346929,
  [SMALL_STATE(6772)] = 346969,
  [SMALL_STATE(6773)] = 347009,
  [SMALL_STATE(6774)] = 347053,
  [SMALL_STATE(6775)] = 347093,
  [SMALL_STATE(6776)] = 347133,
  [SMALL_STATE(6777)] = 347173,
  [SMALL_STATE(6778)] = 347213,
  [SMALL_STATE(6779)] = 347253,
  [SMALL_STATE(6780)] = 347309,
  [SMALL_STATE(6781)] = 347349,
  [SMALL_STATE(6782)] = 347389,
  [SMALL_STATE(6783)] = 347429,
  [SMALL_STATE(6784)] = 347475,
  [SMALL_STATE(6785)] = 347515,
  [SMALL_STATE(6786)] = 347563,
  [SMALL_STATE(6787)] = 347603,
  [SMALL_STATE(6788)] = 347643,
  [SMALL_STATE(6789)] = 347683,
  [SMALL_STATE(6790)] = 347723,
  [SMALL_STATE(6791)] = 347763,
  [SMALL_STATE(6792)] = 347803,
  [SMALL_STATE(6793)] = 347843,
  [SMALL_STATE(6794)] = 347889,
  [SMALL_STATE(6795)] = 347931,
  [SMALL_STATE(6796)] = 347971,
  [SMALL_STATE(6797)] = 348011,
  [SMALL_STATE(6798)] = 348051,
  [SMALL_STATE(6799)] = 348091,
  [SMALL_STATE(6800)] = 348131,
  [SMALL_STATE(6801)] = 348175,
  [SMALL_STATE(6802)] = 348215,
  [SMALL_STATE(6803)] = 348255,
  [SMALL_STATE(6804)] = 348295,
  [SMALL_STATE(6805)] = 348335,
  [SMALL_STATE(6806)] = 348381,
  [SMALL_STATE(6807)] = 348423,
  [SMALL_STATE(6808)] = 348465,
  [SMALL_STATE(6809)] = 348505,
  [SMALL_STATE(6810)] = 348545,
  [SMALL_STATE(6811)] = 348597,
  [SMALL_STATE(6812)] = 348637,
  [SMALL_STATE(6813)] = 348677,
  [SMALL_STATE(6814)] = 348741,
  [SMALL_STATE(6815)] = 348783,
  [SMALL_STATE(6816)] = 348833,
  [SMALL_STATE(6817)] = 348887,
  [SMALL_STATE(6818)] = 348927,
  [SMALL_STATE(6819)] = 348969,
  [SMALL_STATE(6820)] = 349009,
  [SMALL_STATE(6821)] = 349049,
  [SMALL_STATE(6822)] = 349089,
  [SMALL_STATE(6823)] = 349135,
  [SMALL_STATE(6824)] = 349175,
  [SMALL_STATE(6825)] = 349241,
  [SMALL_STATE(6826)] = 349281,
  [SMALL_STATE(6827)] = 349321,
  [SMALL_STATE(6828)] = 349361,
  [SMALL_STATE(6829)] = 349407,
  [SMALL_STATE(6830)] = 349461,
  [SMALL_STATE(6831)] = 349501,
  [SMALL_STATE(6832)] = 349543,
  [SMALL_STATE(6833)] = 349583,
  [SMALL_STATE(6834)] = 349623,
  [SMALL_STATE(6835)] = 349663,
  [SMALL_STATE(6836)] = 349709,
  [SMALL_STATE(6837)] = 349749,
  [SMALL_STATE(6838)] = 349793,
  [SMALL_STATE(6839)] = 349833,
  [SMALL_STATE(6840)] = 349875,
  [SMALL_STATE(6841)] = 349919,
  [SMALL_STATE(6842)] = 349959,
  [SMALL_STATE(6843)] = 349999,
  [SMALL_STATE(6844)] = 350039,
  [SMALL_STATE(6845)] = 350079,
  [SMALL_STATE(6846)] = 350121,
  [SMALL_STATE(6847)] = 350165,
  [SMALL_STATE(6848)] = 350229,
  [SMALL_STATE(6849)] = 350267,
  [SMALL_STATE(6850)] = 350319,
  [SMALL_STATE(6851)] = 350363,
  [SMALL_STATE(6852)] = 350409,
  [SMALL_STATE(6853)] = 350449,
  [SMALL_STATE(6854)] = 350491,
  [SMALL_STATE(6855)] = 350531,
  [SMALL_STATE(6856)] = 350575,
  [SMALL_STATE(6857)] = 350615,
  [SMALL_STATE(6858)] = 350655,
  [SMALL_STATE(6859)] = 350695,
  [SMALL_STATE(6860)] = 350735,
  [SMALL_STATE(6861)] = 350775,
  [SMALL_STATE(6862)] = 350815,
  [SMALL_STATE(6863)] = 350855,
  [SMALL_STATE(6864)] = 350895,
  [SMALL_STATE(6865)] = 350935,
  [SMALL_STATE(6866)] = 350977,
  [SMALL_STATE(6867)] = 351021,
  [SMALL_STATE(6868)] = 351061,
  [SMALL_STATE(6869)] = 351101,
  [SMALL_STATE(6870)] = 351153,
  [SMALL_STATE(6871)] = 351193,
  [SMALL_STATE(6872)] = 351233,
  [SMALL_STATE(6873)] = 351273,
  [SMALL_STATE(6874)] = 351313,
  [SMALL_STATE(6875)] = 351353,
  [SMALL_STATE(6876)] = 351393,
  [SMALL_STATE(6877)] = 351433,
  [SMALL_STATE(6878)] = 351473,
  [SMALL_STATE(6879)] = 351513,
  [SMALL_STATE(6880)] = 351557,
  [SMALL_STATE(6881)] = 351597,
  [SMALL_STATE(6882)] = 351637,
  [SMALL_STATE(6883)] = 351677,
  [SMALL_STATE(6884)] = 351717,
  [SMALL_STATE(6885)] = 351757,
  [SMALL_STATE(6886)] = 351797,
  [SMALL_STATE(6887)] = 351837,
  [SMALL_STATE(6888)] = 351877,
  [SMALL_STATE(6889)] = 351917,
  [SMALL_STATE(6890)] = 351957,
  [SMALL_STATE(6891)] = 352017,
  [SMALL_STATE(6892)] = 352057,
  [SMALL_STATE(6893)] = 352117,
  [SMALL_STATE(6894)] = 352157,
  [SMALL_STATE(6895)] = 352197,
  [SMALL_STATE(6896)] = 352237,
  [SMALL_STATE(6897)] = 352277,
  [SMALL_STATE(6898)] = 352319,
  [SMALL_STATE(6899)] = 352359,
  [SMALL_STATE(6900)] = 352399,
  [SMALL_STATE(6901)] = 352439,
  [SMALL_STATE(6902)] = 352511,
  [SMALL_STATE(6903)] = 352551,
  [SMALL_STATE(6904)] = 352591,
  [SMALL_STATE(6905)] = 352631,
  [SMALL_STATE(6906)] = 352671,
  [SMALL_STATE(6907)] = 352711,
  [SMALL_STATE(6908)] = 352751,
  [SMALL_STATE(6909)] = 352791,
  [SMALL_STATE(6910)] = 352851,
  [SMALL_STATE(6911)] = 352891,
  [SMALL_STATE(6912)] = 352931,
  [SMALL_STATE(6913)] = 352985,
  [SMALL_STATE(6914)] = 353025,
  [SMALL_STATE(6915)] = 353077,
  [SMALL_STATE(6916)] = 353117,
  [SMALL_STATE(6917)] = 353157,
  [SMALL_STATE(6918)] = 353197,
  [SMALL_STATE(6919)] = 353237,
  [SMALL_STATE(6920)] = 353277,
  [SMALL_STATE(6921)] = 353317,
  [SMALL_STATE(6922)] = 353357,
  [SMALL_STATE(6923)] = 353397,
  [SMALL_STATE(6924)] = 353437,
  [SMALL_STATE(6925)] = 353477,
  [SMALL_STATE(6926)] = 353517,
  [SMALL_STATE(6927)] = 353557,
  [SMALL_STATE(6928)] = 353597,
  [SMALL_STATE(6929)] = 353637,
  [SMALL_STATE(6930)] = 353679,
  [SMALL_STATE(6931)] = 353719,
  [SMALL_STATE(6932)] = 353759,
  [SMALL_STATE(6933)] = 353799,
  [SMALL_STATE(6934)] = 353839,
  [SMALL_STATE(6935)] = 353879,
  [SMALL_STATE(6936)] = 353919,
  [SMALL_STATE(6937)] = 353959,
  [SMALL_STATE(6938)] = 353999,
  [SMALL_STATE(6939)] = 354041,
  [SMALL_STATE(6940)] = 354081,
  [SMALL_STATE(6941)] = 354121,
  [SMALL_STATE(6942)] = 354197,
  [SMALL_STATE(6943)] = 354241,
  [SMALL_STATE(6944)] = 354281,
  [SMALL_STATE(6945)] = 354321,
  [SMALL_STATE(6946)] = 354369,
  [SMALL_STATE(6947)] = 354409,
  [SMALL_STATE(6948)] = 354449,
  [SMALL_STATE(6949)] = 354489,
  [SMALL_STATE(6950)] = 354529,
  [SMALL_STATE(6951)] = 354575,
  [SMALL_STATE(6952)] = 354615,
  [SMALL_STATE(6953)] = 354655,
  [SMALL_STATE(6954)] = 354695,
  [SMALL_STATE(6955)] = 354735,
  [SMALL_STATE(6956)] = 354777,
  [SMALL_STATE(6957)] = 354817,
  [SMALL_STATE(6958)] = 354857,
  [SMALL_STATE(6959)] = 354933,
  [SMALL_STATE(6960)] = 354975,
  [SMALL_STATE(6961)] = 355045,
  [SMALL_STATE(6962)] = 355085,
  [SMALL_STATE(6963)] = 355125,
  [SMALL_STATE(6964)] = 355165,
  [SMALL_STATE(6965)] = 355205,
  [SMALL_STATE(6966)] = 355245,
  [SMALL_STATE(6967)] = 355293,
  [SMALL_STATE(6968)] = 355333,
  [SMALL_STATE(6969)] = 355373,
  [SMALL_STATE(6970)] = 355413,
  [SMALL_STATE(6971)] = 355465,
  [SMALL_STATE(6972)] = 355505,
  [SMALL_STATE(6973)] = 355559,
  [SMALL_STATE(6974)] = 355599,
  [SMALL_STATE(6975)] = 355639,
  [SMALL_STATE(6976)] = 355679,
  [SMALL_STATE(6977)] = 355719,
  [SMALL_STATE(6978)] = 355759,
  [SMALL_STATE(6979)] = 355819,
  [SMALL_STATE(6980)] = 355859,
  [SMALL_STATE(6981)] = 355899,
  [SMALL_STATE(6982)] = 355939,
  [SMALL_STATE(6983)] = 355979,
  [SMALL_STATE(6984)] = 356043,
  [SMALL_STATE(6985)] = 356083,
  [SMALL_STATE(6986)] = 356123,
  [SMALL_STATE(6987)] = 356163,
  [SMALL_STATE(6988)] = 356203,
  [SMALL_STATE(6989)] = 356243,
  [SMALL_STATE(6990)] = 356283,
  [SMALL_STATE(6991)] = 356323,
  [SMALL_STATE(6992)] = 356363,
  [SMALL_STATE(6993)] = 356403,
  [SMALL_STATE(6994)] = 356443,
  [SMALL_STATE(6995)] = 356497,
  [SMALL_STATE(6996)] = 356543,
  [SMALL_STATE(6997)] = 356583,
  [SMALL_STATE(6998)] = 356623,
  [SMALL_STATE(6999)] = 356665,
  [SMALL_STATE(7000)] = 356705,
  [SMALL_STATE(7001)] = 356745,
  [SMALL_STATE(7002)] = 356785,
  [SMALL_STATE(7003)] = 356825,
  [SMALL_STATE(7004)] = 356867,
  [SMALL_STATE(7005)] = 356907,
  [SMALL_STATE(7006)] = 356947,
  [SMALL_STATE(7007)] = 356989,
  [SMALL_STATE(7008)] = 357029,
  [SMALL_STATE(7009)] = 357069,
  [SMALL_STATE(7010)] = 357109,
  [SMALL_STATE(7011)] = 357149,
  [SMALL_STATE(7012)] = 357197,
  [SMALL_STATE(7013)] = 357237,
  [SMALL_STATE(7014)] = 357281,
  [SMALL_STATE(7015)] = 357321,
  [SMALL_STATE(7016)] = 357361,
  [SMALL_STATE(7017)] = 357405,
  [SMALL_STATE(7018)] = 357445,
  [SMALL_STATE(7019)] = 357485,
  [SMALL_STATE(7020)] = 357525,
  [SMALL_STATE(7021)] = 357565,
  [SMALL_STATE(7022)] = 357605,
  [SMALL_STATE(7023)] = 357649,
  [SMALL_STATE(7024)] = 357689,
  [SMALL_STATE(7025)] = 357729,
  [SMALL_STATE(7026)] = 357769,
  [SMALL_STATE(7027)] = 357809,
  [SMALL_STATE(7028)] = 357849,
  [SMALL_STATE(7029)] = 357891,
  [SMALL_STATE(7030)] = 357931,
  [SMALL_STATE(7031)] = 357971,
  [SMALL_STATE(7032)] = 358013,
  [SMALL_STATE(7033)] = 358053,
  [SMALL_STATE(7034)] = 358109,
  [SMALL_STATE(7035)] = 358149,
  [SMALL_STATE(7036)] = 358189,
  [SMALL_STATE(7037)] = 358229,
  [SMALL_STATE(7038)] = 358269,
  [SMALL_STATE(7039)] = 358309,
  [SMALL_STATE(7040)] = 358349,
  [SMALL_STATE(7041)] = 358389,
  [SMALL_STATE(7042)] = 358429,
  [SMALL_STATE(7043)] = 358469,
  [SMALL_STATE(7044)] = 358515,
  [SMALL_STATE(7045)] = 358555,
  [SMALL_STATE(7046)] = 358595,
  [SMALL_STATE(7047)] = 358635,
  [SMALL_STATE(7048)] = 358675,
  [SMALL_STATE(7049)] = 358715,
  [SMALL_STATE(7050)] = 358759,
  [SMALL_STATE(7051)] = 358801,
  [SMALL_STATE(7052)] = 358841,
  [SMALL_STATE(7053)] = 358881,
  [SMALL_STATE(7054)] = 358921,
  [SMALL_STATE(7055)] = 358961,
  [SMALL_STATE(7056)] = 359005,
  [SMALL_STATE(7057)] = 359049,
  [SMALL_STATE(7058)] = 359089,
  [SMALL_STATE(7059)] = 359135,
  [SMALL_STATE(7060)] = 359175,
  [SMALL_STATE(7061)] = 359215,
  [SMALL_STATE(7062)] = 359255,
  [SMALL_STATE(7063)] = 359295,
  [SMALL_STATE(7064)] = 359335,
  [SMALL_STATE(7065)] = 359375,
  [SMALL_STATE(7066)] = 359415,
  [SMALL_STATE(7067)] = 359455,
  [SMALL_STATE(7068)] = 359495,
  [SMALL_STATE(7069)] = 359537,
  [SMALL_STATE(7070)] = 359579,
  [SMALL_STATE(7071)] = 359617,
  [SMALL_STATE(7072)] = 359671,
  [SMALL_STATE(7073)] = 359711,
  [SMALL_STATE(7074)] = 359757,
  [SMALL_STATE(7075)] = 359799,
  [SMALL_STATE(7076)] = 359839,
  [SMALL_STATE(7077)] = 359881,
  [SMALL_STATE(7078)] = 359923,
  [SMALL_STATE(7079)] = 359967,
  [SMALL_STATE(7080)] = 360007,
  [SMALL_STATE(7081)] = 360047,
  [SMALL_STATE(7082)] = 360087,
  [SMALL_STATE(7083)] = 360127,
  [SMALL_STATE(7084)] = 360167,
  [SMALL_STATE(7085)] = 360213,
  [SMALL_STATE(7086)] = 360253,
  [SMALL_STATE(7087)] = 360299,
  [SMALL_STATE(7088)] = 360353,
  [SMALL_STATE(7089)] = 360393,
  [SMALL_STATE(7090)] = 360433,
  [SMALL_STATE(7091)] = 360473,
  [SMALL_STATE(7092)] = 360513,
  [SMALL_STATE(7093)] = 360553,
  [SMALL_STATE(7094)] = 360593,
  [SMALL_STATE(7095)] = 360633,
  [SMALL_STATE(7096)] = 360673,
  [SMALL_STATE(7097)] = 360713,
  [SMALL_STATE(7098)] = 360753,
  [SMALL_STATE(7099)] = 360793,
  [SMALL_STATE(7100)] = 360833,
  [SMALL_STATE(7101)] = 360873,
  [SMALL_STATE(7102)] = 360913,
  [SMALL_STATE(7103)] = 360953,
  [SMALL_STATE(7104)] = 360993,
  [SMALL_STATE(7105)] = 361069,
  [SMALL_STATE(7106)] = 361109,
  [SMALL_STATE(7107)] = 361149,
  [SMALL_STATE(7108)] = 361189,
  [SMALL_STATE(7109)] = 361235,
  [SMALL_STATE(7110)] = 361275,
  [SMALL_STATE(7111)] = 361315,
  [SMALL_STATE(7112)] = 361357,
  [SMALL_STATE(7113)] = 361397,
  [SMALL_STATE(7114)] = 361437,
  [SMALL_STATE(7115)] = 361477,
  [SMALL_STATE(7116)] = 361517,
  [SMALL_STATE(7117)] = 361557,
  [SMALL_STATE(7118)] = 361609,
  [SMALL_STATE(7119)] = 361649,
  [SMALL_STATE(7120)] = 361689,
  [SMALL_STATE(7121)] = 361729,
  [SMALL_STATE(7122)] = 361769,
  [SMALL_STATE(7123)] = 361809,
  [SMALL_STATE(7124)] = 361849,
  [SMALL_STATE(7125)] = 361889,
  [SMALL_STATE(7126)] = 361929,
  [SMALL_STATE(7127)] = 361969,
  [SMALL_STATE(7128)] = 362009,
  [SMALL_STATE(7129)] = 362049,
  [SMALL_STATE(7130)] = 362089,
  [SMALL_STATE(7131)] = 362129,
  [SMALL_STATE(7132)] = 362169,
  [SMALL_STATE(7133)] = 362209,
  [SMALL_STATE(7134)] = 362249,
  [SMALL_STATE(7135)] = 362295,
  [SMALL_STATE(7136)] = 362335,
  [SMALL_STATE(7137)] = 362375,
  [SMALL_STATE(7138)] = 362419,
  [SMALL_STATE(7139)] = 362459,
  [SMALL_STATE(7140)] = 362499,
  [SMALL_STATE(7141)] = 362539,
  [SMALL_STATE(7142)] = 362581,
  [SMALL_STATE(7143)] = 362621,
  [SMALL_STATE(7144)] = 362661,
  [SMALL_STATE(7145)] = 362701,
  [SMALL_STATE(7146)] = 362741,
  [SMALL_STATE(7147)] = 362783,
  [SMALL_STATE(7148)] = 362823,
  [SMALL_STATE(7149)] = 362863,
  [SMALL_STATE(7150)] = 362903,
  [SMALL_STATE(7151)] = 362943,
  [SMALL_STATE(7152)] = 362995,
  [SMALL_STATE(7153)] = 363035,
  [SMALL_STATE(7154)] = 363075,
  [SMALL_STATE(7155)] = 363115,
  [SMALL_STATE(7156)] = 363155,
  [SMALL_STATE(7157)] = 363195,
  [SMALL_STATE(7158)] = 363235,
  [SMALL_STATE(7159)] = 363275,
  [SMALL_STATE(7160)] = 363315,
  [SMALL_STATE(7161)] = 363355,
  [SMALL_STATE(7162)] = 363395,
  [SMALL_STATE(7163)] = 363441,
  [SMALL_STATE(7164)] = 363481,
  [SMALL_STATE(7165)] = 363521,
  [SMALL_STATE(7166)] = 363561,
  [SMALL_STATE(7167)] = 363601,
  [SMALL_STATE(7168)] = 363641,
  [SMALL_STATE(7169)] = 363681,
  [SMALL_STATE(7170)] = 363721,
  [SMALL_STATE(7171)] = 363761,
  [SMALL_STATE(7172)] = 363801,
  [SMALL_STATE(7173)] = 363841,
  [SMALL_STATE(7174)] = 363881,
  [SMALL_STATE(7175)] = 363921,
  [SMALL_STATE(7176)] = 363961,
  [SMALL_STATE(7177)] = 364001,
  [SMALL_STATE(7178)] = 364077,
  [SMALL_STATE(7179)] = 364117,
  [SMALL_STATE(7180)] = 364163,
  [SMALL_STATE(7181)] = 364205,
  [SMALL_STATE(7182)] = 364245,
  [SMALL_STATE(7183)] = 364285,
  [SMALL_STATE(7184)] = 364325,
  [SMALL_STATE(7185)] = 364367,
  [SMALL_STATE(7186)] = 364407,
  [SMALL_STATE(7187)] = 364447,
  [SMALL_STATE(7188)] = 364487,
  [SMALL_STATE(7189)] = 364527,
  [SMALL_STATE(7190)] = 364567,
  [SMALL_STATE(7191)] = 364607,
  [SMALL_STATE(7192)] = 364647,
  [SMALL_STATE(7193)] = 364687,
  [SMALL_STATE(7194)] = 364727,
  [SMALL_STATE(7195)] = 364769,
  [SMALL_STATE(7196)] = 364809,
  [SMALL_STATE(7197)] = 364851,
  [SMALL_STATE(7198)] = 364889,
  [SMALL_STATE(7199)] = 364933,
  [SMALL_STATE(7200)] = 364973,
  [SMALL_STATE(7201)] = 365013,
  [SMALL_STATE(7202)] = 365053,
  [SMALL_STATE(7203)] = 365093,
  [SMALL_STATE(7204)] = 365133,
  [SMALL_STATE(7205)] = 365173,
  [SMALL_STATE(7206)] = 365213,
  [SMALL_STATE(7207)] = 365253,
  [SMALL_STATE(7208)] = 365297,
  [SMALL_STATE(7209)] = 365337,
  [SMALL_STATE(7210)] = 365377,
  [SMALL_STATE(7211)] = 365417,
  [SMALL_STATE(7212)] = 365457,
  [SMALL_STATE(7213)] = 365497,
  [SMALL_STATE(7214)] = 365537,
  [SMALL_STATE(7215)] = 365579,
  [SMALL_STATE(7216)] = 365619,
  [SMALL_STATE(7217)] = 365671,
  [SMALL_STATE(7218)] = 365711,
  [SMALL_STATE(7219)] = 365751,
  [SMALL_STATE(7220)] = 365797,
  [SMALL_STATE(7221)] = 365837,
  [SMALL_STATE(7222)] = 365877,
  [SMALL_STATE(7223)] = 365917,
  [SMALL_STATE(7224)] = 365957,
  [SMALL_STATE(7225)] = 365997,
  [SMALL_STATE(7226)] = 366037,
  [SMALL_STATE(7227)] = 366079,
  [SMALL_STATE(7228)] = 366119,
  [SMALL_STATE(7229)] = 366161,
  [SMALL_STATE(7230)] = 366201,
  [SMALL_STATE(7231)] = 366241,
  [SMALL_STATE(7232)] = 366281,
  [SMALL_STATE(7233)] = 366321,
  [SMALL_STATE(7234)] = 366361,
  [SMALL_STATE(7235)] = 366401,
  [SMALL_STATE(7236)] = 366441,
  [SMALL_STATE(7237)] = 366481,
  [SMALL_STATE(7238)] = 366521,
  [SMALL_STATE(7239)] = 366561,
  [SMALL_STATE(7240)] = 366601,
  [SMALL_STATE(7241)] = 366641,
  [SMALL_STATE(7242)] = 366681,
  [SMALL_STATE(7243)] = 366721,
  [SMALL_STATE(7244)] = 366761,
  [SMALL_STATE(7245)] = 366821,
  [SMALL_STATE(7246)] = 366873,
  [SMALL_STATE(7247)] = 366933,
  [SMALL_STATE(7248)] = 366973,
  [SMALL_STATE(7249)] = 367043,
  [SMALL_STATE(7250)] = 367089,
  [SMALL_STATE(7251)] = 367129,
  [SMALL_STATE(7252)] = 367173,
  [SMALL_STATE(7253)] = 367215,
  [SMALL_STATE(7254)] = 367259,
  [SMALL_STATE(7255)] = 367299,
  [SMALL_STATE(7256)] = 367339,
  [SMALL_STATE(7257)] = 367379,
  [SMALL_STATE(7258)] = 367419,
  [SMALL_STATE(7259)] = 367461,
  [SMALL_STATE(7260)] = 367501,
  [SMALL_STATE(7261)] = 367541,
  [SMALL_STATE(7262)] = 367581,
  [SMALL_STATE(7263)] = 367621,
  [SMALL_STATE(7264)] = 367667,
  [SMALL_STATE(7265)] = 367707,
  [SMALL_STATE(7266)] = 367753,
  [SMALL_STATE(7267)] = 367793,
  [SMALL_STATE(7268)] = 367833,
  [SMALL_STATE(7269)] = 367887,
  [SMALL_STATE(7270)] = 367931,
  [SMALL_STATE(7271)] = 367975,
  [SMALL_STATE(7272)] = 368015,
  [SMALL_STATE(7273)] = 368055,
  [SMALL_STATE(7274)] = 368095,
  [SMALL_STATE(7275)] = 368135,
  [SMALL_STATE(7276)] = 368177,
  [SMALL_STATE(7277)] = 368217,
  [SMALL_STATE(7278)] = 368257,
  [SMALL_STATE(7279)] = 368303,
  [SMALL_STATE(7280)] = 368343,
  [SMALL_STATE(7281)] = 368383,
  [SMALL_STATE(7282)] = 368423,
  [SMALL_STATE(7283)] = 368487,
  [SMALL_STATE(7284)] = 368527,
  [SMALL_STATE(7285)] = 368567,
  [SMALL_STATE(7286)] = 368607,
  [SMALL_STATE(7287)] = 368651,
  [SMALL_STATE(7288)] = 368691,
  [SMALL_STATE(7289)] = 368731,
  [SMALL_STATE(7290)] = 368775,
  [SMALL_STATE(7291)] = 368817,
  [SMALL_STATE(7292)] = 368857,
  [SMALL_STATE(7293)] = 368933,
  [SMALL_STATE(7294)] = 369009,
  [SMALL_STATE(7295)] = 369049,
  [SMALL_STATE(7296)] = 369101,
  [SMALL_STATE(7297)] = 369143,
  [SMALL_STATE(7298)] = 369203,
  [SMALL_STATE(7299)] = 369279,
  [SMALL_STATE(7300)] = 369319,
  [SMALL_STATE(7301)] = 369383,
  [SMALL_STATE(7302)] = 369459,
  [SMALL_STATE(7303)] = 369499,
  [SMALL_STATE(7304)] = 369539,
  [SMALL_STATE(7305)] = 369579,
  [SMALL_STATE(7306)] = 369633,
  [SMALL_STATE(7307)] = 369673,
  [SMALL_STATE(7308)] = 369713,
  [SMALL_STATE(7309)] = 369783,
  [SMALL_STATE(7310)] = 369859,
  [SMALL_STATE(7311)] = 369903,
  [SMALL_STATE(7312)] = 369947,
  [SMALL_STATE(7313)] = 369991,
  [SMALL_STATE(7314)] = 370031,
  [SMALL_STATE(7315)] = 370077,
  [SMALL_STATE(7316)] = 370117,
  [SMALL_STATE(7317)] = 370157,
  [SMALL_STATE(7318)] = 370227,
  [SMALL_STATE(7319)] = 370271,
  [SMALL_STATE(7320)] = 370311,
  [SMALL_STATE(7321)] = 370351,
  [SMALL_STATE(7322)] = 370391,
  [SMALL_STATE(7323)] = 370431,
  [SMALL_STATE(7324)] = 370471,
  [SMALL_STATE(7325)] = 370511,
  [SMALL_STATE(7326)] = 370551,
  [SMALL_STATE(7327)] = 370591,
  [SMALL_STATE(7328)] = 370631,
  [SMALL_STATE(7329)] = 370671,
  [SMALL_STATE(7330)] = 370711,
  [SMALL_STATE(7331)] = 370751,
  [SMALL_STATE(7332)] = 370815,
  [SMALL_STATE(7333)] = 370855,
  [SMALL_STATE(7334)] = 370895,
  [SMALL_STATE(7335)] = 370959,
  [SMALL_STATE(7336)] = 371001,
  [SMALL_STATE(7337)] = 371041,
  [SMALL_STATE(7338)] = 371081,
  [SMALL_STATE(7339)] = 371123,
  [SMALL_STATE(7340)] = 371163,
  [SMALL_STATE(7341)] = 371203,
  [SMALL_STATE(7342)] = 371243,
  [SMALL_STATE(7343)] = 371295,
  [SMALL_STATE(7344)] = 371349,
  [SMALL_STATE(7345)] = 371393,
  [SMALL_STATE(7346)] = 371433,
  [SMALL_STATE(7347)] = 371473,
  [SMALL_STATE(7348)] = 371513,
  [SMALL_STATE(7349)] = 371553,
  [SMALL_STATE(7350)] = 371595,
  [SMALL_STATE(7351)] = 371635,
  [SMALL_STATE(7352)] = 371675,
  [SMALL_STATE(7353)] = 371715,
  [SMALL_STATE(7354)] = 371755,
  [SMALL_STATE(7355)] = 371795,
  [SMALL_STATE(7356)] = 371835,
  [SMALL_STATE(7357)] = 371899,
  [SMALL_STATE(7358)] = 371939,
  [SMALL_STATE(7359)] = 372003,
  [SMALL_STATE(7360)] = 372043,
  [SMALL_STATE(7361)] = 372083,
  [SMALL_STATE(7362)] = 372123,
  [SMALL_STATE(7363)] = 372163,
  [SMALL_STATE(7364)] = 372203,
  [SMALL_STATE(7365)] = 372243,
  [SMALL_STATE(7366)] = 372283,
  [SMALL_STATE(7367)] = 372337,
  [SMALL_STATE(7368)] = 372377,
  [SMALL_STATE(7369)] = 372417,
  [SMALL_STATE(7370)] = 372457,
  [SMALL_STATE(7371)] = 372497,
  [SMALL_STATE(7372)] = 372553,
  [SMALL_STATE(7373)] = 372593,
  [SMALL_STATE(7374)] = 372633,
  [SMALL_STATE(7375)] = 372673,
  [SMALL_STATE(7376)] = 372715,
  [SMALL_STATE(7377)] = 372755,
  [SMALL_STATE(7378)] = 372807,
  [SMALL_STATE(7379)] = 372859,
  [SMALL_STATE(7380)] = 372899,
  [SMALL_STATE(7381)] = 372939,
  [SMALL_STATE(7382)] = 373003,
  [SMALL_STATE(7383)] = 373045,
  [SMALL_STATE(7384)] = 373085,
  [SMALL_STATE(7385)] = 373125,
  [SMALL_STATE(7386)] = 373167,
  [SMALL_STATE(7387)] = 373207,
  [SMALL_STATE(7388)] = 373267,
  [SMALL_STATE(7389)] = 373306,
  [SMALL_STATE(7390)] = 373345,
  [SMALL_STATE(7391)] = 373406,
  [SMALL_STATE(7392)] = 373445,
  [SMALL_STATE(7393)] = 373490,
  [SMALL_STATE(7394)] = 373541,
  [SMALL_STATE(7395)] = 373580,
  [SMALL_STATE(7396)] = 373641,
  [SMALL_STATE(7397)] = 373682,
  [SMALL_STATE(7398)] = 373721,
  [SMALL_STATE(7399)] = 373760,
  [SMALL_STATE(7400)] = 373799,
  [SMALL_STATE(7401)] = 373844,
  [SMALL_STATE(7402)] = 373905,
  [SMALL_STATE(7403)] = 373944,
  [SMALL_STATE(7404)] = 373983,
  [SMALL_STATE(7405)] = 374022,
  [SMALL_STATE(7406)] = 374061,
  [SMALL_STATE(7407)] = 374104,
  [SMALL_STATE(7408)] = 374143,
  [SMALL_STATE(7409)] = 374182,
  [SMALL_STATE(7410)] = 374243,
  [SMALL_STATE(7411)] = 374282,
  [SMALL_STATE(7412)] = 374321,
  [SMALL_STATE(7413)] = 374376,
  [SMALL_STATE(7414)] = 374437,
  [SMALL_STATE(7415)] = 374498,
  [SMALL_STATE(7416)] = 374541,
  [SMALL_STATE(7417)] = 374580,
  [SMALL_STATE(7418)] = 374621,
  [SMALL_STATE(7419)] = 374682,
  [SMALL_STATE(7420)] = 374721,
  [SMALL_STATE(7421)] = 374760,
  [SMALL_STATE(7422)] = 374811,
  [SMALL_STATE(7423)] = 374850,
  [SMALL_STATE(7424)] = 374889,
  [SMALL_STATE(7425)] = 374950,
  [SMALL_STATE(7426)] = 374991,
  [SMALL_STATE(7427)] = 375030,
  [SMALL_STATE(7428)] = 375069,
  [SMALL_STATE(7429)] = 375108,
  [SMALL_STATE(7430)] = 375147,
  [SMALL_STATE(7431)] = 375186,
  [SMALL_STATE(7432)] = 375229,
  [SMALL_STATE(7433)] = 375290,
  [SMALL_STATE(7434)] = 375329,
  [SMALL_STATE(7435)] = 375368,
  [SMALL_STATE(7436)] = 375407,
  [SMALL_STATE(7437)] = 375468,
  [SMALL_STATE(7438)] = 375507,
  [SMALL_STATE(7439)] = 375546,
  [SMALL_STATE(7440)] = 375585,
  [SMALL_STATE(7441)] = 375624,
  [SMALL_STATE(7442)] = 375685,
  [SMALL_STATE(7443)] = 375724,
  [SMALL_STATE(7444)] = 375785,
  [SMALL_STATE(7445)] = 375824,
  [SMALL_STATE(7446)] = 375885,
  [SMALL_STATE(7447)] = 375924,
  [SMALL_STATE(7448)] = 375963,
  [SMALL_STATE(7449)] = 376002,
  [SMALL_STATE(7450)] = 376063,
  [SMALL_STATE(7451)] = 376130,
  [SMALL_STATE(7452)] = 376171,
  [SMALL_STATE(7453)] = 376210,
  [SMALL_STATE(7454)] = 376251,
  [SMALL_STATE(7455)] = 376294,
  [SMALL_STATE(7456)] = 376355,
  [SMALL_STATE(7457)] = 376394,
  [SMALL_STATE(7458)] = 376433,
  [SMALL_STATE(7459)] = 376472,
  [SMALL_STATE(7460)] = 376511,
  [SMALL_STATE(7461)] = 376570,
  [SMALL_STATE(7462)] = 376631,
  [SMALL_STATE(7463)] = 376670,
  [SMALL_STATE(7464)] = 376715,
  [SMALL_STATE(7465)] = 376776,
  [SMALL_STATE(7466)] = 376817,
  [SMALL_STATE(7467)] = 376856,
  [SMALL_STATE(7468)] = 376895,
  [SMALL_STATE(7469)] = 376956,
  [SMALL_STATE(7470)] = 377007,
  [SMALL_STATE(7471)] = 377046,
  [SMALL_STATE(7472)] = 377107,
  [SMALL_STATE(7473)] = 377168,
  [SMALL_STATE(7474)] = 377207,
  [SMALL_STATE(7475)] = 377246,
  [SMALL_STATE(7476)] = 377307,
  [SMALL_STATE(7477)] = 377346,
  [SMALL_STATE(7478)] = 377385,
  [SMALL_STATE(7479)] = 377424,
  [SMALL_STATE(7480)] = 377463,
  [SMALL_STATE(7481)] = 377508,
  [SMALL_STATE(7482)] = 377563,
  [SMALL_STATE(7483)] = 377624,
  [SMALL_STATE(7484)] = 377663,
  [SMALL_STATE(7485)] = 377702,
  [SMALL_STATE(7486)] = 377741,
  [SMALL_STATE(7487)] = 377782,
  [SMALL_STATE(7488)] = 377843,
  [SMALL_STATE(7489)] = 377882,
  [SMALL_STATE(7490)] = 377927,
  [SMALL_STATE(7491)] = 377966,
  [SMALL_STATE(7492)] = 378005,
  [SMALL_STATE(7493)] = 378050,
  [SMALL_STATE(7494)] = 378089,
  [SMALL_STATE(7495)] = 378128,
  [SMALL_STATE(7496)] = 378189,
  [SMALL_STATE(7497)] = 378232,
  [SMALL_STATE(7498)] = 378271,
  [SMALL_STATE(7499)] = 378322,
  [SMALL_STATE(7500)] = 378383,
  [SMALL_STATE(7501)] = 378422,
  [SMALL_STATE(7502)] = 378463,
  [SMALL_STATE(7503)] = 378502,
  [SMALL_STATE(7504)] = 378541,
  [SMALL_STATE(7505)] = 378580,
  [SMALL_STATE(7506)] = 378619,
  [SMALL_STATE(7507)] = 378680,
  [SMALL_STATE(7508)] = 378719,
  [SMALL_STATE(7509)] = 378758,
  [SMALL_STATE(7510)] = 378797,
  [SMALL_STATE(7511)] = 378858,
  [SMALL_STATE(7512)] = 378897,
  [SMALL_STATE(7513)] = 378936,
  [SMALL_STATE(7514)] = 378975,
  [SMALL_STATE(7515)] = 379036,
  [SMALL_STATE(7516)] = 379097,
  [SMALL_STATE(7517)] = 379158,
  [SMALL_STATE(7518)] = 379209,
  [SMALL_STATE(7519)] = 379248,
  [SMALL_STATE(7520)] = 379287,
  [SMALL_STATE(7521)] = 379326,
  [SMALL_STATE(7522)] = 379365,
  [SMALL_STATE(7523)] = 379426,
  [SMALL_STATE(7524)] = 379465,
  [SMALL_STATE(7525)] = 379526,
  [SMALL_STATE(7526)] = 379565,
  [SMALL_STATE(7527)] = 379604,
  [SMALL_STATE(7528)] = 379645,
  [SMALL_STATE(7529)] = 379706,
  [SMALL_STATE(7530)] = 379773,
  [SMALL_STATE(7531)] = 379814,
  [SMALL_STATE(7532)] = 379875,
  [SMALL_STATE(7533)] = 379936,
  [SMALL_STATE(7534)] = 379997,
  [SMALL_STATE(7535)] = 380056,
  [SMALL_STATE(7536)] = 380097,
  [SMALL_STATE(7537)] = 380158,
  [SMALL_STATE(7538)] = 380209,
  [SMALL_STATE(7539)] = 380272,
  [SMALL_STATE(7540)] = 380333,
  [SMALL_STATE(7541)] = 380394,
  [SMALL_STATE(7542)] = 380455,
  [SMALL_STATE(7543)] = 380496,
  [SMALL_STATE(7544)] = 380557,
  [SMALL_STATE(7545)] = 380598,
  [SMALL_STATE(7546)] = 380637,
  [SMALL_STATE(7547)] = 380698,
  [SMALL_STATE(7548)] = 380737,
  [SMALL_STATE(7549)] = 380798,
  [SMALL_STATE(7550)] = 380837,
  [SMALL_STATE(7551)] = 380898,
  [SMALL_STATE(7552)] = 380937,
  [SMALL_STATE(7553)] = 380998,
  [SMALL_STATE(7554)] = 381037,
  [SMALL_STATE(7555)] = 381076,
  [SMALL_STATE(7556)] = 381137,
  [SMALL_STATE(7557)] = 381176,
  [SMALL_STATE(7558)] = 381215,
  [SMALL_STATE(7559)] = 381276,
  [SMALL_STATE(7560)] = 381315,
  [SMALL_STATE(7561)] = 381354,
  [SMALL_STATE(7562)] = 381415,
  [SMALL_STATE(7563)] = 381454,
  [SMALL_STATE(7564)] = 381493,
  [SMALL_STATE(7565)] = 381532,
  [SMALL_STATE(7566)] = 381593,
  [SMALL_STATE(7567)] = 381632,
  [SMALL_STATE(7568)] = 381671,
  [SMALL_STATE(7569)] = 381732,
  [SMALL_STATE(7570)] = 381771,
  [SMALL_STATE(7571)] = 381810,
  [SMALL_STATE(7572)] = 381849,
  [SMALL_STATE(7573)] = 381888,
  [SMALL_STATE(7574)] = 381927,
  [SMALL_STATE(7575)] = 381988,
  [SMALL_STATE(7576)] = 382027,
  [SMALL_STATE(7577)] = 382074,
  [SMALL_STATE(7578)] = 382113,
  [SMALL_STATE(7579)] = 382152,
  [SMALL_STATE(7580)] = 382213,
  [SMALL_STATE(7581)] = 382266,
  [SMALL_STATE(7582)] = 382305,
  [SMALL_STATE(7583)] = 382366,
  [SMALL_STATE(7584)] = 382409,
  [SMALL_STATE(7585)] = 382470,
  [SMALL_STATE(7586)] = 382513,
  [SMALL_STATE(7587)] = 382552,
  [SMALL_STATE(7588)] = 382591,
  [SMALL_STATE(7589)] = 382652,
  [SMALL_STATE(7590)] = 382691,
  [SMALL_STATE(7591)] = 382732,
  [SMALL_STATE(7592)] = 382771,
  [SMALL_STATE(7593)] = 382832,
  [SMALL_STATE(7594)] = 382871,
  [SMALL_STATE(7595)] = 382932,
  [SMALL_STATE(7596)] = 382971,
  [SMALL_STATE(7597)] = 383018,
  [SMALL_STATE(7598)] = 383057,
  [SMALL_STATE(7599)] = 383096,
  [SMALL_STATE(7600)] = 383135,
  [SMALL_STATE(7601)] = 383176,
  [SMALL_STATE(7602)] = 383215,
  [SMALL_STATE(7603)] = 383254,
  [SMALL_STATE(7604)] = 383293,
  [SMALL_STATE(7605)] = 383332,
  [SMALL_STATE(7606)] = 383371,
  [SMALL_STATE(7607)] = 383416,
  [SMALL_STATE(7608)] = 383455,
  [SMALL_STATE(7609)] = 383494,
  [SMALL_STATE(7610)] = 383533,
  [SMALL_STATE(7611)] = 383572,
  [SMALL_STATE(7612)] = 383611,
  [SMALL_STATE(7613)] = 383650,
  [SMALL_STATE(7614)] = 383689,
  [SMALL_STATE(7615)] = 383728,
  [SMALL_STATE(7616)] = 383767,
  [SMALL_STATE(7617)] = 383806,
  [SMALL_STATE(7618)] = 383845,
  [SMALL_STATE(7619)] = 383884,
  [SMALL_STATE(7620)] = 383947,
  [SMALL_STATE(7621)] = 384008,
  [SMALL_STATE(7622)] = 384047,
  [SMALL_STATE(7623)] = 384086,
  [SMALL_STATE(7624)] = 384125,
  [SMALL_STATE(7625)] = 384164,
  [SMALL_STATE(7626)] = 384203,
  [SMALL_STATE(7627)] = 384242,
  [SMALL_STATE(7628)] = 384281,
  [SMALL_STATE(7629)] = 384320,
  [SMALL_STATE(7630)] = 384359,
  [SMALL_STATE(7631)] = 384404,
  [SMALL_STATE(7632)] = 384443,
  [SMALL_STATE(7633)] = 384482,
  [SMALL_STATE(7634)] = 384521,
  [SMALL_STATE(7635)] = 384560,
  [SMALL_STATE(7636)] = 384599,
  [SMALL_STATE(7637)] = 384638,
  [SMALL_STATE(7638)] = 384677,
  [SMALL_STATE(7639)] = 384716,
  [SMALL_STATE(7640)] = 384757,
  [SMALL_STATE(7641)] = 384796,
  [SMALL_STATE(7642)] = 384835,
  [SMALL_STATE(7643)] = 384876,
  [SMALL_STATE(7644)] = 384915,
  [SMALL_STATE(7645)] = 384954,
  [SMALL_STATE(7646)] = 384993,
  [SMALL_STATE(7647)] = 385054,
  [SMALL_STATE(7648)] = 385093,
  [SMALL_STATE(7649)] = 385132,
  [SMALL_STATE(7650)] = 385173,
  [SMALL_STATE(7651)] = 385212,
  [SMALL_STATE(7652)] = 385251,
  [SMALL_STATE(7653)] = 385290,
  [SMALL_STATE(7654)] = 385333,
  [SMALL_STATE(7655)] = 385372,
  [SMALL_STATE(7656)] = 385415,
  [SMALL_STATE(7657)] = 385454,
  [SMALL_STATE(7658)] = 385493,
  [SMALL_STATE(7659)] = 385532,
  [SMALL_STATE(7660)] = 385571,
  [SMALL_STATE(7661)] = 385622,
  [SMALL_STATE(7662)] = 385661,
  [SMALL_STATE(7663)] = 385700,
  [SMALL_STATE(7664)] = 385739,
  [SMALL_STATE(7665)] = 385778,
  [SMALL_STATE(7666)] = 385817,
  [SMALL_STATE(7667)] = 385856,
  [SMALL_STATE(7668)] = 385895,
  [SMALL_STATE(7669)] = 385938,
  [SMALL_STATE(7670)] = 385977,
  [SMALL_STATE(7671)] = 386018,
  [SMALL_STATE(7672)] = 386085,
  [SMALL_STATE(7673)] = 386124,
  [SMALL_STATE(7674)] = 386163,
  [SMALL_STATE(7675)] = 386234,
  [SMALL_STATE(7676)] = 386273,
  [SMALL_STATE(7677)] = 386312,
  [SMALL_STATE(7678)] = 386351,
  [SMALL_STATE(7679)] = 386390,
  [SMALL_STATE(7680)] = 386429,
  [SMALL_STATE(7681)] = 386468,
  [SMALL_STATE(7682)] = 386507,
  [SMALL_STATE(7683)] = 386546,
  [SMALL_STATE(7684)] = 386617,
  [SMALL_STATE(7685)] = 386656,
  [SMALL_STATE(7686)] = 386695,
  [SMALL_STATE(7687)] = 386756,
  [SMALL_STATE(7688)] = 386817,
  [SMALL_STATE(7689)] = 386856,
  [SMALL_STATE(7690)] = 386895,
  [SMALL_STATE(7691)] = 386934,
  [SMALL_STATE(7692)] = 386973,
  [SMALL_STATE(7693)] = 387014,
  [SMALL_STATE(7694)] = 387053,
  [SMALL_STATE(7695)] = 387094,
  [SMALL_STATE(7696)] = 387133,
  [SMALL_STATE(7697)] = 387172,
  [SMALL_STATE(7698)] = 387239,
  [SMALL_STATE(7699)] = 387278,
  [SMALL_STATE(7700)] = 387319,
  [SMALL_STATE(7701)] = 387358,
  [SMALL_STATE(7702)] = 387429,
  [SMALL_STATE(7703)] = 387468,
  [SMALL_STATE(7704)] = 387507,
  [SMALL_STATE(7705)] = 387546,
  [SMALL_STATE(7706)] = 387587,
  [SMALL_STATE(7707)] = 387658,
  [SMALL_STATE(7708)] = 387697,
  [SMALL_STATE(7709)] = 387750,
  [SMALL_STATE(7710)] = 387811,
  [SMALL_STATE(7711)] = 387872,
  [SMALL_STATE(7712)] = 387911,
  [SMALL_STATE(7713)] = 387950,
  [SMALL_STATE(7714)] = 388017,
  [SMALL_STATE(7715)] = 388056,
  [SMALL_STATE(7716)] = 388095,
  [SMALL_STATE(7717)] = 388134,
  [SMALL_STATE(7718)] = 388173,
  [SMALL_STATE(7719)] = 388212,
  [SMALL_STATE(7720)] = 388257,
  [SMALL_STATE(7721)] = 388296,
  [SMALL_STATE(7722)] = 388363,
  [SMALL_STATE(7723)] = 388402,
  [SMALL_STATE(7724)] = 388441,
  [SMALL_STATE(7725)] = 388480,
  [SMALL_STATE(7726)] = 388519,
  [SMALL_STATE(7727)] = 388558,
  [SMALL_STATE(7728)] = 388625,
  [SMALL_STATE(7729)] = 388664,
  [SMALL_STATE(7730)] = 388703,
  [SMALL_STATE(7731)] = 388742,
  [SMALL_STATE(7732)] = 388803,
  [SMALL_STATE(7733)] = 388846,
  [SMALL_STATE(7734)] = 388885,
  [SMALL_STATE(7735)] = 388926,
  [SMALL_STATE(7736)] = 388965,
  [SMALL_STATE(7737)] = 389004,
  [SMALL_STATE(7738)] = 389075,
  [SMALL_STATE(7739)] = 389118,
  [SMALL_STATE(7740)] = 389157,
  [SMALL_STATE(7741)] = 389196,
  [SMALL_STATE(7742)] = 389235,
  [SMALL_STATE(7743)] = 389274,
  [SMALL_STATE(7744)] = 389313,
  [SMALL_STATE(7745)] = 389352,
  [SMALL_STATE(7746)] = 389391,
  [SMALL_STATE(7747)] = 389430,
  [SMALL_STATE(7748)] = 389469,
  [SMALL_STATE(7749)] = 389508,
  [SMALL_STATE(7750)] = 389547,
  [SMALL_STATE(7751)] = 389588,
  [SMALL_STATE(7752)] = 389627,
  [SMALL_STATE(7753)] = 389666,
  [SMALL_STATE(7754)] = 389707,
  [SMALL_STATE(7755)] = 389770,
  [SMALL_STATE(7756)] = 389831,
  [SMALL_STATE(7757)] = 389870,
  [SMALL_STATE(7758)] = 389909,
  [SMALL_STATE(7759)] = 389948,
  [SMALL_STATE(7760)] = 389987,
  [SMALL_STATE(7761)] = 390026,
  [SMALL_STATE(7762)] = 390065,
  [SMALL_STATE(7763)] = 390104,
  [SMALL_STATE(7764)] = 390163,
  [SMALL_STATE(7765)] = 390202,
  [SMALL_STATE(7766)] = 390243,
  [SMALL_STATE(7767)] = 390282,
  [SMALL_STATE(7768)] = 390321,
  [SMALL_STATE(7769)] = 390360,
  [SMALL_STATE(7770)] = 390399,
  [SMALL_STATE(7771)] = 390452,
  [SMALL_STATE(7772)] = 390491,
  [SMALL_STATE(7773)] = 390560,
  [SMALL_STATE(7774)] = 390599,
  [SMALL_STATE(7775)] = 390638,
  [SMALL_STATE(7776)] = 390677,
  [SMALL_STATE(7777)] = 390716,
  [SMALL_STATE(7778)] = 390777,
  [SMALL_STATE(7779)] = 390822,
  [SMALL_STATE(7780)] = 390881,
  [SMALL_STATE(7781)] = 390920,
  [SMALL_STATE(7782)] = 390959,
  [SMALL_STATE(7783)] = 391000,
  [SMALL_STATE(7784)] = 391039,
  [SMALL_STATE(7785)] = 391078,
  [SMALL_STATE(7786)] = 391117,
  [SMALL_STATE(7787)] = 391158,
  [SMALL_STATE(7788)] = 391197,
  [SMALL_STATE(7789)] = 391236,
  [SMALL_STATE(7790)] = 391277,
  [SMALL_STATE(7791)] = 391316,
  [SMALL_STATE(7792)] = 391355,
  [SMALL_STATE(7793)] = 391394,
  [SMALL_STATE(7794)] = 391433,
  [SMALL_STATE(7795)] = 391478,
  [SMALL_STATE(7796)] = 391517,
  [SMALL_STATE(7797)] = 391558,
  [SMALL_STATE(7798)] = 391597,
  [SMALL_STATE(7799)] = 391640,
  [SMALL_STATE(7800)] = 391679,
  [SMALL_STATE(7801)] = 391740,
  [SMALL_STATE(7802)] = 391779,
  [SMALL_STATE(7803)] = 391818,
  [SMALL_STATE(7804)] = 391857,
  [SMALL_STATE(7805)] = 391898,
  [SMALL_STATE(7806)] = 391937,
  [SMALL_STATE(7807)] = 391976,
  [SMALL_STATE(7808)] = 392015,
  [SMALL_STATE(7809)] = 392054,
  [SMALL_STATE(7810)] = 392093,
  [SMALL_STATE(7811)] = 392154,
  [SMALL_STATE(7812)] = 392193,
  [SMALL_STATE(7813)] = 392234,
  [SMALL_STATE(7814)] = 392273,
  [SMALL_STATE(7815)] = 392336,
  [SMALL_STATE(7816)] = 392375,
  [SMALL_STATE(7817)] = 392414,
  [SMALL_STATE(7818)] = 392453,
  [SMALL_STATE(7819)] = 392492,
  [SMALL_STATE(7820)] = 392533,
  [SMALL_STATE(7821)] = 392572,
  [SMALL_STATE(7822)] = 392611,
  [SMALL_STATE(7823)] = 392650,
  [SMALL_STATE(7824)] = 392689,
  [SMALL_STATE(7825)] = 392728,
  [SMALL_STATE(7826)] = 392769,
  [SMALL_STATE(7827)] = 392808,
  [SMALL_STATE(7828)] = 392847,
  [SMALL_STATE(7829)] = 392890,
  [SMALL_STATE(7830)] = 392929,
  [SMALL_STATE(7831)] = 392968,
  [SMALL_STATE(7832)] = 393029,
  [SMALL_STATE(7833)] = 393090,
  [SMALL_STATE(7834)] = 393129,
  [SMALL_STATE(7835)] = 393170,
  [SMALL_STATE(7836)] = 393209,
  [SMALL_STATE(7837)] = 393248,
  [SMALL_STATE(7838)] = 393287,
  [SMALL_STATE(7839)] = 393326,
  [SMALL_STATE(7840)] = 393365,
  [SMALL_STATE(7841)] = 393404,
  [SMALL_STATE(7842)] = 393443,
  [SMALL_STATE(7843)] = 393482,
  [SMALL_STATE(7844)] = 393521,
  [SMALL_STATE(7845)] = 393566,
  [SMALL_STATE(7846)] = 393605,
  [SMALL_STATE(7847)] = 393644,
  [SMALL_STATE(7848)] = 393683,
  [SMALL_STATE(7849)] = 393722,
  [SMALL_STATE(7850)] = 393761,
  [SMALL_STATE(7851)] = 393800,
  [SMALL_STATE(7852)] = 393839,
  [SMALL_STATE(7853)] = 393878,
  [SMALL_STATE(7854)] = 393939,
  [SMALL_STATE(7855)] = 393978,
  [SMALL_STATE(7856)] = 394017,
  [SMALL_STATE(7857)] = 394056,
  [SMALL_STATE(7858)] = 394107,
  [SMALL_STATE(7859)] = 394148,
  [SMALL_STATE(7860)] = 394193,
  [SMALL_STATE(7861)] = 394232,
  [SMALL_STATE(7862)] = 394271,
  [SMALL_STATE(7863)] = 394310,
  [SMALL_STATE(7864)] = 394349,
  [SMALL_STATE(7865)] = 394392,
  [SMALL_STATE(7866)] = 394431,
  [SMALL_STATE(7867)] = 394470,
  [SMALL_STATE(7868)] = 394511,
  [SMALL_STATE(7869)] = 394550,
  [SMALL_STATE(7870)] = 394611,
  [SMALL_STATE(7871)] = 394658,
  [SMALL_STATE(7872)] = 394697,
  [SMALL_STATE(7873)] = 394736,
  [SMALL_STATE(7874)] = 394775,
  [SMALL_STATE(7875)] = 394814,
  [SMALL_STATE(7876)] = 394853,
  [SMALL_STATE(7877)] = 394892,
  [SMALL_STATE(7878)] = 394931,
  [SMALL_STATE(7879)] = 394976,
  [SMALL_STATE(7880)] = 395015,
  [SMALL_STATE(7881)] = 395054,
  [SMALL_STATE(7882)] = 395093,
  [SMALL_STATE(7883)] = 395134,
  [SMALL_STATE(7884)] = 395173,
  [SMALL_STATE(7885)] = 395212,
  [SMALL_STATE(7886)] = 395273,
  [SMALL_STATE(7887)] = 395312,
  [SMALL_STATE(7888)] = 395357,
  [SMALL_STATE(7889)] = 395396,
  [SMALL_STATE(7890)] = 395435,
  [SMALL_STATE(7891)] = 395476,
  [SMALL_STATE(7892)] = 395517,
  [SMALL_STATE(7893)] = 395560,
  [SMALL_STATE(7894)] = 395599,
  [SMALL_STATE(7895)] = 395662,
  [SMALL_STATE(7896)] = 395717,
  [SMALL_STATE(7897)] = 395754,
  [SMALL_STATE(7898)] = 395793,
  [SMALL_STATE(7899)] = 395832,
  [SMALL_STATE(7900)] = 395871,
  [SMALL_STATE(7901)] = 395910,
  [SMALL_STATE(7902)] = 395949,
  [SMALL_STATE(7903)] = 395990,
  [SMALL_STATE(7904)] = 396029,
  [SMALL_STATE(7905)] = 396068,
  [SMALL_STATE(7906)] = 396107,
  [SMALL_STATE(7907)] = 396146,
  [SMALL_STATE(7908)] = 396185,
  [SMALL_STATE(7909)] = 396224,
  [SMALL_STATE(7910)] = 396265,
  [SMALL_STATE(7911)] = 396306,
  [SMALL_STATE(7912)] = 396345,
  [SMALL_STATE(7913)] = 396384,
  [SMALL_STATE(7914)] = 396423,
  [SMALL_STATE(7915)] = 396484,
  [SMALL_STATE(7916)] = 396523,
  [SMALL_STATE(7917)] = 396566,
  [SMALL_STATE(7918)] = 396607,
  [SMALL_STATE(7919)] = 396668,
  [SMALL_STATE(7920)] = 396707,
  [SMALL_STATE(7921)] = 396752,
  [SMALL_STATE(7922)] = 396791,
  [SMALL_STATE(7923)] = 396832,
  [SMALL_STATE(7924)] = 396875,
  [SMALL_STATE(7925)] = 396914,
  [SMALL_STATE(7926)] = 396953,
  [SMALL_STATE(7927)] = 396992,
  [SMALL_STATE(7928)] = 397031,
  [SMALL_STATE(7929)] = 397070,
  [SMALL_STATE(7930)] = 397109,
  [SMALL_STATE(7931)] = 397154,
  [SMALL_STATE(7932)] = 397193,
  [SMALL_STATE(7933)] = 397234,
  [SMALL_STATE(7934)] = 397273,
  [SMALL_STATE(7935)] = 397314,
  [SMALL_STATE(7936)] = 397375,
  [SMALL_STATE(7937)] = 397414,
  [SMALL_STATE(7938)] = 397453,
  [SMALL_STATE(7939)] = 397492,
  [SMALL_STATE(7940)] = 397537,
  [SMALL_STATE(7941)] = 397576,
  [SMALL_STATE(7942)] = 397619,
  [SMALL_STATE(7943)] = 397690,
  [SMALL_STATE(7944)] = 397751,
  [SMALL_STATE(7945)] = 397792,
  [SMALL_STATE(7946)] = 397831,
  [SMALL_STATE(7947)] = 397870,
  [SMALL_STATE(7948)] = 397931,
  [SMALL_STATE(7949)] = 397970,
  [SMALL_STATE(7950)] = 398009,
  [SMALL_STATE(7951)] = 398048,
  [SMALL_STATE(7952)] = 398095,
  [SMALL_STATE(7953)] = 398134,
  [SMALL_STATE(7954)] = 398173,
  [SMALL_STATE(7955)] = 398212,
  [SMALL_STATE(7956)] = 398251,
  [SMALL_STATE(7957)] = 398290,
  [SMALL_STATE(7958)] = 398351,
  [SMALL_STATE(7959)] = 398390,
  [SMALL_STATE(7960)] = 398453,
  [SMALL_STATE(7961)] = 398492,
  [SMALL_STATE(7962)] = 398531,
  [SMALL_STATE(7963)] = 398592,
  [SMALL_STATE(7964)] = 398637,
  [SMALL_STATE(7965)] = 398676,
  [SMALL_STATE(7966)] = 398717,
  [SMALL_STATE(7967)] = 398756,
  [SMALL_STATE(7968)] = 398795,
  [SMALL_STATE(7969)] = 398856,
  [SMALL_STATE(7970)] = 398895,
  [SMALL_STATE(7971)] = 398936,
  [SMALL_STATE(7972)] = 398991,
  [SMALL_STATE(7973)] = 399030,
  [SMALL_STATE(7974)] = 399069,
  [SMALL_STATE(7975)] = 399108,
  [SMALL_STATE(7976)] = 399147,
  [SMALL_STATE(7977)] = 399208,
  [SMALL_STATE(7978)] = 399247,
  [SMALL_STATE(7979)] = 399286,
  [SMALL_STATE(7980)] = 399331,
  [SMALL_STATE(7981)] = 399370,
  [SMALL_STATE(7982)] = 399409,
  [SMALL_STATE(7983)] = 399450,
  [SMALL_STATE(7984)] = 399493,
  [SMALL_STATE(7985)] = 399538,
  [SMALL_STATE(7986)] = 399577,
  [SMALL_STATE(7987)] = 399616,
  [SMALL_STATE(7988)] = 399677,
  [SMALL_STATE(7989)] = 399716,
  [SMALL_STATE(7990)] = 399757,
  [SMALL_STATE(7991)] = 399796,
  [SMALL_STATE(7992)] = 399835,
  [SMALL_STATE(7993)] = 399874,
  [SMALL_STATE(7994)] = 399913,
  [SMALL_STATE(7995)] = 399984,
  [SMALL_STATE(7996)] = 400025,
  [SMALL_STATE(7997)] = 400070,
  [SMALL_STATE(7998)] = 400109,
  [SMALL_STATE(7999)] = 400148,
  [SMALL_STATE(8000)] = 400191,
  [SMALL_STATE(8001)] = 400236,
  [SMALL_STATE(8002)] = 400275,
  [SMALL_STATE(8003)] = 400338,
  [SMALL_STATE(8004)] = 400377,
  [SMALL_STATE(8005)] = 400416,
  [SMALL_STATE(8006)] = 400457,
  [SMALL_STATE(8007)] = 400518,
  [SMALL_STATE(8008)] = 400557,
  [SMALL_STATE(8009)] = 400596,
  [SMALL_STATE(8010)] = 400657,
  [SMALL_STATE(8011)] = 400696,
  [SMALL_STATE(8012)] = 400739,
  [SMALL_STATE(8013)] = 400778,
  [SMALL_STATE(8014)] = 400819,
  [SMALL_STATE(8015)] = 400858,
  [SMALL_STATE(8016)] = 400897,
  [SMALL_STATE(8017)] = 400938,
  [SMALL_STATE(8018)] = 400989,
  [SMALL_STATE(8019)] = 401028,
  [SMALL_STATE(8020)] = 401071,
  [SMALL_STATE(8021)] = 401124,
  [SMALL_STATE(8022)] = 401167,
  [SMALL_STATE(8023)] = 401228,
  [SMALL_STATE(8024)] = 401269,
  [SMALL_STATE(8025)] = 401308,
  [SMALL_STATE(8026)] = 401347,
  [SMALL_STATE(8027)] = 401386,
  [SMALL_STATE(8028)] = 401427,
  [SMALL_STATE(8029)] = 401466,
  [SMALL_STATE(8030)] = 401505,
  [SMALL_STATE(8031)] = 401544,
  [SMALL_STATE(8032)] = 401583,
  [SMALL_STATE(8033)] = 401622,
  [SMALL_STATE(8034)] = 401685,
  [SMALL_STATE(8035)] = 401724,
  [SMALL_STATE(8036)] = 401785,
  [SMALL_STATE(8037)] = 401824,
  [SMALL_STATE(8038)] = 401863,
  [SMALL_STATE(8039)] = 401902,
  [SMALL_STATE(8040)] = 401941,
  [SMALL_STATE(8041)] = 401982,
  [SMALL_STATE(8042)] = 402021,
  [SMALL_STATE(8043)] = 402082,
  [SMALL_STATE(8044)] = 402121,
  [SMALL_STATE(8045)] = 402184,
  [SMALL_STATE(8046)] = 402225,
  [SMALL_STATE(8047)] = 402264,
  [SMALL_STATE(8048)] = 402307,
  [SMALL_STATE(8049)] = 402348,
  [SMALL_STATE(8050)] = 402387,
  [SMALL_STATE(8051)] = 402428,
  [SMALL_STATE(8052)] = 402467,
  [SMALL_STATE(8053)] = 402506,
  [SMALL_STATE(8054)] = 402545,
  [SMALL_STATE(8055)] = 402588,
  [SMALL_STATE(8056)] = 402627,
  [SMALL_STATE(8057)] = 402680,
  [SMALL_STATE(8058)] = 402731,
  [SMALL_STATE(8059)] = 402770,
  [SMALL_STATE(8060)] = 402809,
  [SMALL_STATE(8061)] = 402848,
  [SMALL_STATE(8062)] = 402887,
  [SMALL_STATE(8063)] = 402928,
  [SMALL_STATE(8064)] = 402967,
  [SMALL_STATE(8065)] = 403006,
  [SMALL_STATE(8066)] = 403045,
  [SMALL_STATE(8067)] = 403084,
  [SMALL_STATE(8068)] = 403145,
  [SMALL_STATE(8069)] = 403184,
  [SMALL_STATE(8070)] = 403225,
  [SMALL_STATE(8071)] = 403264,
  [SMALL_STATE(8072)] = 403303,
  [SMALL_STATE(8073)] = 403342,
  [SMALL_STATE(8074)] = 403381,
  [SMALL_STATE(8075)] = 403424,
  [SMALL_STATE(8076)] = 403463,
  [SMALL_STATE(8077)] = 403502,
  [SMALL_STATE(8078)] = 403541,
  [SMALL_STATE(8079)] = 403580,
  [SMALL_STATE(8080)] = 403619,
  [SMALL_STATE(8081)] = 403658,
  [SMALL_STATE(8082)] = 403697,
  [SMALL_STATE(8083)] = 403736,
  [SMALL_STATE(8084)] = 403775,
  [SMALL_STATE(8085)] = 403836,
  [SMALL_STATE(8086)] = 403881,
  [SMALL_STATE(8087)] = 403922,
  [SMALL_STATE(8088)] = 403961,
  [SMALL_STATE(8089)] = 404001,
  [SMALL_STATE(8090)] = 404041,
  [SMALL_STATE(8091)] = 404079,
  [SMALL_STATE(8092)] = 404117,
  [SMALL_STATE(8093)] = 404155,
  [SMALL_STATE(8094)] = 404193,
  [SMALL_STATE(8095)] = 404231,
  [SMALL_STATE(8096)] = 404269,
  [SMALL_STATE(8097)] = 404307,
  [SMALL_STATE(8098)] = 404347,
  [SMALL_STATE(8099)] = 404385,
  [SMALL_STATE(8100)] = 404423,
  [SMALL_STATE(8101)] = 404461,
  [SMALL_STATE(8102)] = 404515,
  [SMALL_STATE(8103)] = 404553,
  [SMALL_STATE(8104)] = 404591,
  [SMALL_STATE(8105)] = 404629,
  [SMALL_STATE(8106)] = 404667,
  [SMALL_STATE(8107)] = 404705,
  [SMALL_STATE(8108)] = 404743,
  [SMALL_STATE(8109)] = 404781,
  [SMALL_STATE(8110)] = 404819,
  [SMALL_STATE(8111)] = 404857,
  [SMALL_STATE(8112)] = 404897,
  [SMALL_STATE(8113)] = 404935,
  [SMALL_STATE(8114)] = 404973,
  [SMALL_STATE(8115)] = 405011,
  [SMALL_STATE(8116)] = 405049,
  [SMALL_STATE(8117)] = 405087,
  [SMALL_STATE(8118)] = 405125,
  [SMALL_STATE(8119)] = 405163,
  [SMALL_STATE(8120)] = 405201,
  [SMALL_STATE(8121)] = 405241,
  [SMALL_STATE(8122)] = 405279,
  [SMALL_STATE(8123)] = 405317,
  [SMALL_STATE(8124)] = 405355,
  [SMALL_STATE(8125)] = 405395,
  [SMALL_STATE(8126)] = 405433,
  [SMALL_STATE(8127)] = 405471,
  [SMALL_STATE(8128)] = 405509,
  [SMALL_STATE(8129)] = 405547,
  [SMALL_STATE(8130)] = 405585,
  [SMALL_STATE(8131)] = 405623,
  [SMALL_STATE(8132)] = 405663,
  [SMALL_STATE(8133)] = 405701,
  [SMALL_STATE(8134)] = 405741,
  [SMALL_STATE(8135)] = 405779,
  [SMALL_STATE(8136)] = 405823,
  [SMALL_STATE(8137)] = 405861,
  [SMALL_STATE(8138)] = 405899,
  [SMALL_STATE(8139)] = 405937,
  [SMALL_STATE(8140)] = 405975,
  [SMALL_STATE(8141)] = 406013,
  [SMALL_STATE(8142)] = 406073,
  [SMALL_STATE(8143)] = 406111,
  [SMALL_STATE(8144)] = 406149,
  [SMALL_STATE(8145)] = 406187,
  [SMALL_STATE(8146)] = 406225,
  [SMALL_STATE(8147)] = 406263,
  [SMALL_STATE(8148)] = 406305,
  [SMALL_STATE(8149)] = 406343,
  [SMALL_STATE(8150)] = 406381,
  [SMALL_STATE(8151)] = 406419,
  [SMALL_STATE(8152)] = 406457,
  [SMALL_STATE(8153)] = 406497,
  [SMALL_STATE(8154)] = 406535,
  [SMALL_STATE(8155)] = 406573,
  [SMALL_STATE(8156)] = 406611,
  [SMALL_STATE(8157)] = 406649,
  [SMALL_STATE(8158)] = 406687,
  [SMALL_STATE(8159)] = 406725,
  [SMALL_STATE(8160)] = 406763,
  [SMALL_STATE(8161)] = 406801,
  [SMALL_STATE(8162)] = 406843,
  [SMALL_STATE(8163)] = 406881,
  [SMALL_STATE(8164)] = 406925,
  [SMALL_STATE(8165)] = 406963,
  [SMALL_STATE(8166)] = 407001,
  [SMALL_STATE(8167)] = 407039,
  [SMALL_STATE(8168)] = 407077,
  [SMALL_STATE(8169)] = 407115,
  [SMALL_STATE(8170)] = 407153,
  [SMALL_STATE(8171)] = 407191,
  [SMALL_STATE(8172)] = 407229,
  [SMALL_STATE(8173)] = 407267,
  [SMALL_STATE(8174)] = 407305,
  [SMALL_STATE(8175)] = 407343,
  [SMALL_STATE(8176)] = 407381,
  [SMALL_STATE(8177)] = 407419,
  [SMALL_STATE(8178)] = 407457,
  [SMALL_STATE(8179)] = 407495,
  [SMALL_STATE(8180)] = 407533,
  [SMALL_STATE(8181)] = 407571,
  [SMALL_STATE(8182)] = 407609,
  [SMALL_STATE(8183)] = 407647,
  [SMALL_STATE(8184)] = 407687,
  [SMALL_STATE(8185)] = 407725,
  [SMALL_STATE(8186)] = 407763,
  [SMALL_STATE(8187)] = 407801,
  [SMALL_STATE(8188)] = 407839,
  [SMALL_STATE(8189)] = 407877,
  [SMALL_STATE(8190)] = 407915,
  [SMALL_STATE(8191)] = 407953,
  [SMALL_STATE(8192)] = 407991,
  [SMALL_STATE(8193)] = 408029,
  [SMALL_STATE(8194)] = 408067,
  [SMALL_STATE(8195)] = 408109,
  [SMALL_STATE(8196)] = 408151,
  [SMALL_STATE(8197)] = 408193,
  [SMALL_STATE(8198)] = 408233,
  [SMALL_STATE(8199)] = 408271,
  [SMALL_STATE(8200)] = 408321,
  [SMALL_STATE(8201)] = 408359,
  [SMALL_STATE(8202)] = 408397,
  [SMALL_STATE(8203)] = 408435,
  [SMALL_STATE(8204)] = 408473,
  [SMALL_STATE(8205)] = 408511,
  [SMALL_STATE(8206)] = 408549,
  [SMALL_STATE(8207)] = 408587,
  [SMALL_STATE(8208)] = 408629,
  [SMALL_STATE(8209)] = 408667,
  [SMALL_STATE(8210)] = 408705,
  [SMALL_STATE(8211)] = 408743,
  [SMALL_STATE(8212)] = 408781,
  [SMALL_STATE(8213)] = 408819,
  [SMALL_STATE(8214)] = 408857,
  [SMALL_STATE(8215)] = 408895,
  [SMALL_STATE(8216)] = 408933,
  [SMALL_STATE(8217)] = 408975,
  [SMALL_STATE(8218)] = 409013,
  [SMALL_STATE(8219)] = 409051,
  [SMALL_STATE(8220)] = 409101,
  [SMALL_STATE(8221)] = 409139,
  [SMALL_STATE(8222)] = 409177,
  [SMALL_STATE(8223)] = 409215,
  [SMALL_STATE(8224)] = 409253,
  [SMALL_STATE(8225)] = 409291,
  [SMALL_STATE(8226)] = 409329,
  [SMALL_STATE(8227)] = 409367,
  [SMALL_STATE(8228)] = 409417,
  [SMALL_STATE(8229)] = 409455,
  [SMALL_STATE(8230)] = 409493,
  [SMALL_STATE(8231)] = 409531,
  [SMALL_STATE(8232)] = 409575,
  [SMALL_STATE(8233)] = 409615,
  [SMALL_STATE(8234)] = 409653,
  [SMALL_STATE(8235)] = 409691,
  [SMALL_STATE(8236)] = 409729,
  [SMALL_STATE(8237)] = 409767,
  [SMALL_STATE(8238)] = 409805,
  [SMALL_STATE(8239)] = 409843,
  [SMALL_STATE(8240)] = 409881,
  [SMALL_STATE(8241)] = 409925,
  [SMALL_STATE(8242)] = 409963,
  [SMALL_STATE(8243)] = 410001,
  [SMALL_STATE(8244)] = 410039,
  [SMALL_STATE(8245)] = 410077,
  [SMALL_STATE(8246)] = 410115,
  [SMALL_STATE(8247)] = 410153,
  [SMALL_STATE(8248)] = 410191,
  [SMALL_STATE(8249)] = 410229,
  [SMALL_STATE(8250)] = 410267,
  [SMALL_STATE(8251)] = 410309,
  [SMALL_STATE(8252)] = 410347,
  [SMALL_STATE(8253)] = 410385,
  [SMALL_STATE(8254)] = 410423,
  [SMALL_STATE(8255)] = 410461,
  [SMALL_STATE(8256)] = 410499,
  [SMALL_STATE(8257)] = 410553,
  [SMALL_STATE(8258)] = 410591,
  [SMALL_STATE(8259)] = 410629,
  [SMALL_STATE(8260)] = 410667,
  [SMALL_STATE(8261)] = 410705,
  [SMALL_STATE(8262)] = 410743,
  [SMALL_STATE(8263)] = 410787,
  [SMALL_STATE(8264)] = 410825,
  [SMALL_STATE(8265)] = 410863,
  [SMALL_STATE(8266)] = 410905,
  [SMALL_STATE(8267)] = 410943,
  [SMALL_STATE(8268)] = 410981,
  [SMALL_STATE(8269)] = 411019,
  [SMALL_STATE(8270)] = 411057,
  [SMALL_STATE(8271)] = 411095,
  [SMALL_STATE(8272)] = 411135,
  [SMALL_STATE(8273)] = 411173,
  [SMALL_STATE(8274)] = 411211,
  [SMALL_STATE(8275)] = 411249,
  [SMALL_STATE(8276)] = 411287,
  [SMALL_STATE(8277)] = 411325,
  [SMALL_STATE(8278)] = 411377,
  [SMALL_STATE(8279)] = 411415,
  [SMALL_STATE(8280)] = 411453,
  [SMALL_STATE(8281)] = 411491,
  [SMALL_STATE(8282)] = 411533,
  [SMALL_STATE(8283)] = 411595,
  [SMALL_STATE(8284)] = 411637,
  [SMALL_STATE(8285)] = 411675,
  [SMALL_STATE(8286)] = 411713,
  [SMALL_STATE(8287)] = 411751,
  [SMALL_STATE(8288)] = 411789,
  [SMALL_STATE(8289)] = 411829,
  [SMALL_STATE(8290)] = 411873,
  [SMALL_STATE(8291)] = 411911,
  [SMALL_STATE(8292)] = 411949,
  [SMALL_STATE(8293)] = 411989,
  [SMALL_STATE(8294)] = 412027,
  [SMALL_STATE(8295)] = 412067,
  [SMALL_STATE(8296)] = 412107,
  [SMALL_STATE(8297)] = 412145,
  [SMALL_STATE(8298)] = 412183,
  [SMALL_STATE(8299)] = 412221,
  [SMALL_STATE(8300)] = 412265,
  [SMALL_STATE(8301)] = 412303,
  [SMALL_STATE(8302)] = 412341,
  [SMALL_STATE(8303)] = 412379,
  [SMALL_STATE(8304)] = 412417,
  [SMALL_STATE(8305)] = 412455,
  [SMALL_STATE(8306)] = 412493,
  [SMALL_STATE(8307)] = 412537,
  [SMALL_STATE(8308)] = 412575,
  [SMALL_STATE(8309)] = 412613,
  [SMALL_STATE(8310)] = 412651,
  [SMALL_STATE(8311)] = 412691,
  [SMALL_STATE(8312)] = 412729,
  [SMALL_STATE(8313)] = 412767,
  [SMALL_STATE(8314)] = 412805,
  [SMALL_STATE(8315)] = 412843,
  [SMALL_STATE(8316)] = 412881,
  [SMALL_STATE(8317)] = 412919,
  [SMALL_STATE(8318)] = 412963,
  [SMALL_STATE(8319)] = 413015,
  [SMALL_STATE(8320)] = 413067,
  [SMALL_STATE(8321)] = 413105,
  [SMALL_STATE(8322)] = 413143,
  [SMALL_STATE(8323)] = 413181,
  [SMALL_STATE(8324)] = 413219,
  [SMALL_STATE(8325)] = 413269,
  [SMALL_STATE(8326)] = 413321,
  [SMALL_STATE(8327)] = 413359,
  [SMALL_STATE(8328)] = 413397,
  [SMALL_STATE(8329)] = 413435,
  [SMALL_STATE(8330)] = 413473,
  [SMALL_STATE(8331)] = 413511,
  [SMALL_STATE(8332)] = 413549,
  [SMALL_STATE(8333)] = 413589,
  [SMALL_STATE(8334)] = 413627,
  [SMALL_STATE(8335)] = 413665,
  [SMALL_STATE(8336)] = 413703,
  [SMALL_STATE(8337)] = 413741,
  [SMALL_STATE(8338)] = 413779,
  [SMALL_STATE(8339)] = 413819,
  [SMALL_STATE(8340)] = 413857,
  [SMALL_STATE(8341)] = 413897,
  [SMALL_STATE(8342)] = 413941,
  [SMALL_STATE(8343)] = 413979,
  [SMALL_STATE(8344)] = 414021,
  [SMALL_STATE(8345)] = 414059,
  [SMALL_STATE(8346)] = 414097,
  [SMALL_STATE(8347)] = 414135,
  [SMALL_STATE(8348)] = 414173,
  [SMALL_STATE(8349)] = 414213,
  [SMALL_STATE(8350)] = 414251,
  [SMALL_STATE(8351)] = 414291,
  [SMALL_STATE(8352)] = 414329,
  [SMALL_STATE(8353)] = 414367,
  [SMALL_STATE(8354)] = 414405,
  [SMALL_STATE(8355)] = 414443,
  [SMALL_STATE(8356)] = 414481,
  [SMALL_STATE(8357)] = 414519,
  [SMALL_STATE(8358)] = 414557,
  [SMALL_STATE(8359)] = 414595,
  [SMALL_STATE(8360)] = 414635,
  [SMALL_STATE(8361)] = 414673,
  [SMALL_STATE(8362)] = 414711,
  [SMALL_STATE(8363)] = 414749,
  [SMALL_STATE(8364)] = 414787,
  [SMALL_STATE(8365)] = 414825,
  [SMALL_STATE(8366)] = 414863,
  [SMALL_STATE(8367)] = 414901,
  [SMALL_STATE(8368)] = 414943,
  [SMALL_STATE(8369)] = 414981,
  [SMALL_STATE(8370)] = 415019,
  [SMALL_STATE(8371)] = 415057,
  [SMALL_STATE(8372)] = 415107,
  [SMALL_STATE(8373)] = 415145,
  [SMALL_STATE(8374)] = 415183,
  [SMALL_STATE(8375)] = 415221,
  [SMALL_STATE(8376)] = 415259,
  [SMALL_STATE(8377)] = 415305,
  [SMALL_STATE(8378)] = 415343,
  [SMALL_STATE(8379)] = 415381,
  [SMALL_STATE(8380)] = 415419,
  [SMALL_STATE(8381)] = 415457,
  [SMALL_STATE(8382)] = 415495,
  [SMALL_STATE(8383)] = 415553,
  [SMALL_STATE(8384)] = 415591,
  [SMALL_STATE(8385)] = 415629,
  [SMALL_STATE(8386)] = 415667,
  [SMALL_STATE(8387)] = 415705,
  [SMALL_STATE(8388)] = 415743,
  [SMALL_STATE(8389)] = 415781,
  [SMALL_STATE(8390)] = 415819,
  [SMALL_STATE(8391)] = 415863,
  [SMALL_STATE(8392)] = 415901,
  [SMALL_STATE(8393)] = 415939,
  [SMALL_STATE(8394)] = 415977,
  [SMALL_STATE(8395)] = 416015,
  [SMALL_STATE(8396)] = 416053,
  [SMALL_STATE(8397)] = 416091,
  [SMALL_STATE(8398)] = 416133,
  [SMALL_STATE(8399)] = 416171,
  [SMALL_STATE(8400)] = 416209,
  [SMALL_STATE(8401)] = 416247,
  [SMALL_STATE(8402)] = 416311,
  [SMALL_STATE(8403)] = 416363,
  [SMALL_STATE(8404)] = 416401,
  [SMALL_STATE(8405)] = 416439,
  [SMALL_STATE(8406)] = 416477,
  [SMALL_STATE(8407)] = 416515,
  [SMALL_STATE(8408)] = 416553,
  [SMALL_STATE(8409)] = 416591,
  [SMALL_STATE(8410)] = 416629,
  [SMALL_STATE(8411)] = 416667,
  [SMALL_STATE(8412)] = 416705,
  [SMALL_STATE(8413)] = 416743,
  [SMALL_STATE(8414)] = 416781,
  [SMALL_STATE(8415)] = 416819,
  [SMALL_STATE(8416)] = 416857,
  [SMALL_STATE(8417)] = 416895,
  [SMALL_STATE(8418)] = 416933,
  [SMALL_STATE(8419)] = 416971,
  [SMALL_STATE(8420)] = 417009,
  [SMALL_STATE(8421)] = 417047,
  [SMALL_STATE(8422)] = 417085,
  [SMALL_STATE(8423)] = 417123,
  [SMALL_STATE(8424)] = 417163,
  [SMALL_STATE(8425)] = 417201,
  [SMALL_STATE(8426)] = 417239,
  [SMALL_STATE(8427)] = 417277,
  [SMALL_STATE(8428)] = 417315,
  [SMALL_STATE(8429)] = 417353,
  [SMALL_STATE(8430)] = 417391,
  [SMALL_STATE(8431)] = 417429,
  [SMALL_STATE(8432)] = 417467,
  [SMALL_STATE(8433)] = 417507,
  [SMALL_STATE(8434)] = 417545,
  [SMALL_STATE(8435)] = 417583,
  [SMALL_STATE(8436)] = 417621,
  [SMALL_STATE(8437)] = 417659,
  [SMALL_STATE(8438)] = 417697,
  [SMALL_STATE(8439)] = 417735,
  [SMALL_STATE(8440)] = 417773,
  [SMALL_STATE(8441)] = 417811,
  [SMALL_STATE(8442)] = 417849,
  [SMALL_STATE(8443)] = 417887,
  [SMALL_STATE(8444)] = 417925,
  [SMALL_STATE(8445)] = 417963,
  [SMALL_STATE(8446)] = 418001,
  [SMALL_STATE(8447)] = 418039,
  [SMALL_STATE(8448)] = 418077,
  [SMALL_STATE(8449)] = 418115,
  [SMALL_STATE(8450)] = 418153,
  [SMALL_STATE(8451)] = 418191,
  [SMALL_STATE(8452)] = 418229,
  [SMALL_STATE(8453)] = 418267,
  [SMALL_STATE(8454)] = 418305,
  [SMALL_STATE(8455)] = 418345,
  [SMALL_STATE(8456)] = 418385,
  [SMALL_STATE(8457)] = 418425,
  [SMALL_STATE(8458)] = 418463,
  [SMALL_STATE(8459)] = 418501,
  [SMALL_STATE(8460)] = 418539,
  [SMALL_STATE(8461)] = 418577,
  [SMALL_STATE(8462)] = 418637,
  [SMALL_STATE(8463)] = 418675,
  [SMALL_STATE(8464)] = 418713,
  [SMALL_STATE(8465)] = 418751,
  [SMALL_STATE(8466)] = 418789,
  [SMALL_STATE(8467)] = 418827,
  [SMALL_STATE(8468)] = 418865,
  [SMALL_STATE(8469)] = 418903,
  [SMALL_STATE(8470)] = 418941,
  [SMALL_STATE(8471)] = 418979,
  [SMALL_STATE(8472)] = 419017,
  [SMALL_STATE(8473)] = 419055,
  [SMALL_STATE(8474)] = 419093,
  [SMALL_STATE(8475)] = 419133,
  [SMALL_STATE(8476)] = 419175,
  [SMALL_STATE(8477)] = 419213,
  [SMALL_STATE(8478)] = 419251,
  [SMALL_STATE(8479)] = 419289,
  [SMALL_STATE(8480)] = 419331,
  [SMALL_STATE(8481)] = 419369,
  [SMALL_STATE(8482)] = 419407,
  [SMALL_STATE(8483)] = 419445,
  [SMALL_STATE(8484)] = 419483,
  [SMALL_STATE(8485)] = 419535,
  [SMALL_STATE(8486)] = 419573,
  [SMALL_STATE(8487)] = 419611,
  [SMALL_STATE(8488)] = 419649,
  [SMALL_STATE(8489)] = 419693,
  [SMALL_STATE(8490)] = 419731,
  [SMALL_STATE(8491)] = 419769,
  [SMALL_STATE(8492)] = 419807,
  [SMALL_STATE(8493)] = 419853,
  [SMALL_STATE(8494)] = 419891,
  [SMALL_STATE(8495)] = 419933,
  [SMALL_STATE(8496)] = 419987,
  [SMALL_STATE(8497)] = 420025,
  [SMALL_STATE(8498)] = 420063,
  [SMALL_STATE(8499)] = 420103,
  [SMALL_STATE(8500)] = 420143,
  [SMALL_STATE(8501)] = 420181,
  [SMALL_STATE(8502)] = 420219,
  [SMALL_STATE(8503)] = 420257,
  [SMALL_STATE(8504)] = 420301,
  [SMALL_STATE(8505)] = 420353,
  [SMALL_STATE(8506)] = 420391,
  [SMALL_STATE(8507)] = 420429,
  [SMALL_STATE(8508)] = 420467,
  [SMALL_STATE(8509)] = 420505,
  [SMALL_STATE(8510)] = 420543,
  [SMALL_STATE(8511)] = 420583,
  [SMALL_STATE(8512)] = 420621,
  [SMALL_STATE(8513)] = 420659,
  [SMALL_STATE(8514)] = 420697,
  [SMALL_STATE(8515)] = 420735,
  [SMALL_STATE(8516)] = 420773,
  [SMALL_STATE(8517)] = 420811,
  [SMALL_STATE(8518)] = 420849,
  [SMALL_STATE(8519)] = 420887,
  [SMALL_STATE(8520)] = 420925,
  [SMALL_STATE(8521)] = 420963,
  [SMALL_STATE(8522)] = 421007,
  [SMALL_STATE(8523)] = 421045,
  [SMALL_STATE(8524)] = 421083,
  [SMALL_STATE(8525)] = 421121,
  [SMALL_STATE(8526)] = 421159,
  [SMALL_STATE(8527)] = 421197,
  [SMALL_STATE(8528)] = 421235,
  [SMALL_STATE(8529)] = 421273,
  [SMALL_STATE(8530)] = 421311,
  [SMALL_STATE(8531)] = 421351,
  [SMALL_STATE(8532)] = 421389,
  [SMALL_STATE(8533)] = 421433,
  [SMALL_STATE(8534)] = 421471,
  [SMALL_STATE(8535)] = 421509,
  [SMALL_STATE(8536)] = 421547,
  [SMALL_STATE(8537)] = 421585,
  [SMALL_STATE(8538)] = 421623,
  [SMALL_STATE(8539)] = 421661,
  [SMALL_STATE(8540)] = 421699,
  [SMALL_STATE(8541)] = 421737,
  [SMALL_STATE(8542)] = 421775,
  [SMALL_STATE(8543)] = 421813,
  [SMALL_STATE(8544)] = 421851,
  [SMALL_STATE(8545)] = 421889,
  [SMALL_STATE(8546)] = 421927,
  [SMALL_STATE(8547)] = 421965,
  [SMALL_STATE(8548)] = 422003,
  [SMALL_STATE(8549)] = 422041,
  [SMALL_STATE(8550)] = 422079,
  [SMALL_STATE(8551)] = 422117,
  [SMALL_STATE(8552)] = 422155,
  [SMALL_STATE(8553)] = 422193,
  [SMALL_STATE(8554)] = 422231,
  [SMALL_STATE(8555)] = 422269,
  [SMALL_STATE(8556)] = 422307,
  [SMALL_STATE(8557)] = 422345,
  [SMALL_STATE(8558)] = 422383,
  [SMALL_STATE(8559)] = 422425,
  [SMALL_STATE(8560)] = 422463,
  [SMALL_STATE(8561)] = 422501,
  [SMALL_STATE(8562)] = 422541,
  [SMALL_STATE(8563)] = 422579,
  [SMALL_STATE(8564)] = 422623,
  [SMALL_STATE(8565)] = 422661,
  [SMALL_STATE(8566)] = 422699,
  [SMALL_STATE(8567)] = 422739,
  [SMALL_STATE(8568)] = 422777,
  [SMALL_STATE(8569)] = 422815,
  [SMALL_STATE(8570)] = 422855,
  [SMALL_STATE(8571)] = 422893,
  [SMALL_STATE(8572)] = 422931,
  [SMALL_STATE(8573)] = 422971,
  [SMALL_STATE(8574)] = 423009,
  [SMALL_STATE(8575)] = 423047,
  [SMALL_STATE(8576)] = 423085,
  [SMALL_STATE(8577)] = 423123,
  [SMALL_STATE(8578)] = 423161,
  [SMALL_STATE(8579)] = 423199,
  [SMALL_STATE(8580)] = 423237,
  [SMALL_STATE(8581)] = 423275,
  [SMALL_STATE(8582)] = 423313,
  [SMALL_STATE(8583)] = 423351,
  [SMALL_STATE(8584)] = 423389,
  [SMALL_STATE(8585)] = 423427,
  [SMALL_STATE(8586)] = 423465,
  [SMALL_STATE(8587)] = 423503,
  [SMALL_STATE(8588)] = 423541,
  [SMALL_STATE(8589)] = 423579,
  [SMALL_STATE(8590)] = 423617,
  [SMALL_STATE(8591)] = 423655,
  [SMALL_STATE(8592)] = 423693,
  [SMALL_STATE(8593)] = 423731,
  [SMALL_STATE(8594)] = 423775,
  [SMALL_STATE(8595)] = 423813,
  [SMALL_STATE(8596)] = 423853,
  [SMALL_STATE(8597)] = 423891,
  [SMALL_STATE(8598)] = 423929,
  [SMALL_STATE(8599)] = 423967,
  [SMALL_STATE(8600)] = 424005,
  [SMALL_STATE(8601)] = 424043,
  [SMALL_STATE(8602)] = 424081,
  [SMALL_STATE(8603)] = 424119,
  [SMALL_STATE(8604)] = 424157,
  [SMALL_STATE(8605)] = 424195,
  [SMALL_STATE(8606)] = 424233,
  [SMALL_STATE(8607)] = 424273,
  [SMALL_STATE(8608)] = 424311,
  [SMALL_STATE(8609)] = 424349,
  [SMALL_STATE(8610)] = 424387,
  [SMALL_STATE(8611)] = 424425,
  [SMALL_STATE(8612)] = 424463,
  [SMALL_STATE(8613)] = 424503,
  [SMALL_STATE(8614)] = 424541,
  [SMALL_STATE(8615)] = 424583,
  [SMALL_STATE(8616)] = 424621,
  [SMALL_STATE(8617)] = 424659,
  [SMALL_STATE(8618)] = 424697,
  [SMALL_STATE(8619)] = 424735,
  [SMALL_STATE(8620)] = 424773,
  [SMALL_STATE(8621)] = 424811,
  [SMALL_STATE(8622)] = 424849,
  [SMALL_STATE(8623)] = 424887,
  [SMALL_STATE(8624)] = 424925,
  [SMALL_STATE(8625)] = 424963,
  [SMALL_STATE(8626)] = 425001,
  [SMALL_STATE(8627)] = 425039,
  [SMALL_STATE(8628)] = 425077,
  [SMALL_STATE(8629)] = 425119,
  [SMALL_STATE(8630)] = 425157,
  [SMALL_STATE(8631)] = 425197,
  [SMALL_STATE(8632)] = 425237,
  [SMALL_STATE(8633)] = 425275,
  [SMALL_STATE(8634)] = 425313,
  [SMALL_STATE(8635)] = 425351,
  [SMALL_STATE(8636)] = 425389,
  [SMALL_STATE(8637)] = 425427,
  [SMALL_STATE(8638)] = 425465,
  [SMALL_STATE(8639)] = 425503,
  [SMALL_STATE(8640)] = 425541,
  [SMALL_STATE(8641)] = 425579,
  [SMALL_STATE(8642)] = 425617,
  [SMALL_STATE(8643)] = 425655,
  [SMALL_STATE(8644)] = 425693,
  [SMALL_STATE(8645)] = 425731,
  [SMALL_STATE(8646)] = 425769,
  [SMALL_STATE(8647)] = 425823,
  [SMALL_STATE(8648)] = 425867,
  [SMALL_STATE(8649)] = 425905,
  [SMALL_STATE(8650)] = 425943,
  [SMALL_STATE(8651)] = 425981,
  [SMALL_STATE(8652)] = 426019,
  [SMALL_STATE(8653)] = 426057,
  [SMALL_STATE(8654)] = 426119,
  [SMALL_STATE(8655)] = 426157,
  [SMALL_STATE(8656)] = 426195,
  [SMALL_STATE(8657)] = 426235,
  [SMALL_STATE(8658)] = 426273,
  [SMALL_STATE(8659)] = 426311,
  [SMALL_STATE(8660)] = 426353,
  [SMALL_STATE(8661)] = 426391,
  [SMALL_STATE(8662)] = 426429,
  [SMALL_STATE(8663)] = 426489,
  [SMALL_STATE(8664)] = 426527,
  [SMALL_STATE(8665)] = 426565,
  [SMALL_STATE(8666)] = 426603,
  [SMALL_STATE(8667)] = 426641,
  [SMALL_STATE(8668)] = 426679,
  [SMALL_STATE(8669)] = 426717,
  [SMALL_STATE(8670)] = 426755,
  [SMALL_STATE(8671)] = 426793,
  [SMALL_STATE(8672)] = 426831,
  [SMALL_STATE(8673)] = 426871,
  [SMALL_STATE(8674)] = 426909,
  [SMALL_STATE(8675)] = 426947,
  [SMALL_STATE(8676)] = 426987,
  [SMALL_STATE(8677)] = 427025,
  [SMALL_STATE(8678)] = 427063,
  [SMALL_STATE(8679)] = 427101,
  [SMALL_STATE(8680)] = 427141,
  [SMALL_STATE(8681)] = 427179,
  [SMALL_STATE(8682)] = 427217,
  [SMALL_STATE(8683)] = 427255,
  [SMALL_STATE(8684)] = 427293,
  [SMALL_STATE(8685)] = 427331,
  [SMALL_STATE(8686)] = 427373,
  [SMALL_STATE(8687)] = 427411,
  [SMALL_STATE(8688)] = 427451,
  [SMALL_STATE(8689)] = 427489,
  [SMALL_STATE(8690)] = 427527,
  [SMALL_STATE(8691)] = 427567,
  [SMALL_STATE(8692)] = 427615,
  [SMALL_STATE(8693)] = 427653,
  [SMALL_STATE(8694)] = 427691,
  [SMALL_STATE(8695)] = 427729,
  [SMALL_STATE(8696)] = 427769,
  [SMALL_STATE(8697)] = 427807,
  [SMALL_STATE(8698)] = 427845,
  [SMALL_STATE(8699)] = 427883,
  [SMALL_STATE(8700)] = 427939,
  [SMALL_STATE(8701)] = 427979,
  [SMALL_STATE(8702)] = 428019,
  [SMALL_STATE(8703)] = 428057,
  [SMALL_STATE(8704)] = 428095,
  [SMALL_STATE(8705)] = 428133,
  [SMALL_STATE(8706)] = 428171,
  [SMALL_STATE(8707)] = 428209,
  [SMALL_STATE(8708)] = 428247,
  [SMALL_STATE(8709)] = 428285,
  [SMALL_STATE(8710)] = 428323,
  [SMALL_STATE(8711)] = 428363,
  [SMALL_STATE(8712)] = 428401,
  [SMALL_STATE(8713)] = 428438,
  [SMALL_STATE(8714)] = 428475,
  [SMALL_STATE(8715)] = 428512,
  [SMALL_STATE(8716)] = 428567,
  [SMALL_STATE(8717)] = 428604,
  [SMALL_STATE(8718)] = 428645,
  [SMALL_STATE(8719)] = 428682,
  [SMALL_STATE(8720)] = 428737,
  [SMALL_STATE(8721)] = 428774,
  [SMALL_STATE(8722)] = 428813,
  [SMALL_STATE(8723)] = 428850,
  [SMALL_STATE(8724)] = 428911,
  [SMALL_STATE(8725)] = 428966,
  [SMALL_STATE(8726)] = 429003,
  [SMALL_STATE(8727)] = 429058,
  [SMALL_STATE(8728)] = 429097,
  [SMALL_STATE(8729)] = 429134,
  [SMALL_STATE(8730)] = 429171,
  [SMALL_STATE(8731)] = 429226,
  [SMALL_STATE(8732)] = 429263,
  [SMALL_STATE(8733)] = 429300,
  [SMALL_STATE(8734)] = 429337,
  [SMALL_STATE(8735)] = 429374,
  [SMALL_STATE(8736)] = 429429,
  [SMALL_STATE(8737)] = 429466,
  [SMALL_STATE(8738)] = 429503,
  [SMALL_STATE(8739)] = 429540,
  [SMALL_STATE(8740)] = 429577,
  [SMALL_STATE(8741)] = 429614,
  [SMALL_STATE(8742)] = 429669,
  [SMALL_STATE(8743)] = 429706,
  [SMALL_STATE(8744)] = 429743,
  [SMALL_STATE(8745)] = 429780,
  [SMALL_STATE(8746)] = 429817,
  [SMALL_STATE(8747)] = 429854,
  [SMALL_STATE(8748)] = 429907,
  [SMALL_STATE(8749)] = 429962,
  [SMALL_STATE(8750)] = 430003,
  [SMALL_STATE(8751)] = 430040,
  [SMALL_STATE(8752)] = 430077,
  [SMALL_STATE(8753)] = 430142,
  [SMALL_STATE(8754)] = 430179,
  [SMALL_STATE(8755)] = 430216,
  [SMALL_STATE(8756)] = 430271,
  [SMALL_STATE(8757)] = 430308,
  [SMALL_STATE(8758)] = 430345,
  [SMALL_STATE(8759)] = 430400,
  [SMALL_STATE(8760)] = 430441,
  [SMALL_STATE(8761)] = 430478,
  [SMALL_STATE(8762)] = 430515,
  [SMALL_STATE(8763)] = 430552,
  [SMALL_STATE(8764)] = 430589,
  [SMALL_STATE(8765)] = 430626,
  [SMALL_STATE(8766)] = 430669,
  [SMALL_STATE(8767)] = 430706,
  [SMALL_STATE(8768)] = 430761,
  [SMALL_STATE(8769)] = 430798,
  [SMALL_STATE(8770)] = 430837,
  [SMALL_STATE(8771)] = 430874,
  [SMALL_STATE(8772)] = 430929,
  [SMALL_STATE(8773)] = 430966,
  [SMALL_STATE(8774)] = 431003,
  [SMALL_STATE(8775)] = 431040,
  [SMALL_STATE(8776)] = 431089,
  [SMALL_STATE(8777)] = 431126,
  [SMALL_STATE(8778)] = 431163,
  [SMALL_STATE(8779)] = 431218,
  [SMALL_STATE(8780)] = 431255,
  [SMALL_STATE(8781)] = 431306,
  [SMALL_STATE(8782)] = 431345,
  [SMALL_STATE(8783)] = 431382,
  [SMALL_STATE(8784)] = 431421,
  [SMALL_STATE(8785)] = 431458,
  [SMALL_STATE(8786)] = 431495,
  [SMALL_STATE(8787)] = 431532,
  [SMALL_STATE(8788)] = 431569,
  [SMALL_STATE(8789)] = 431606,
  [SMALL_STATE(8790)] = 431643,
  [SMALL_STATE(8791)] = 431698,
  [SMALL_STATE(8792)] = 431735,
  [SMALL_STATE(8793)] = 431772,
  [SMALL_STATE(8794)] = 431809,
  [SMALL_STATE(8795)] = 431846,
  [SMALL_STATE(8796)] = 431883,
  [SMALL_STATE(8797)] = 431920,
  [SMALL_STATE(8798)] = 431957,
  [SMALL_STATE(8799)] = 432012,
  [SMALL_STATE(8800)] = 432049,
  [SMALL_STATE(8801)] = 432086,
  [SMALL_STATE(8802)] = 432123,
  [SMALL_STATE(8803)] = 432160,
  [SMALL_STATE(8804)] = 432197,
  [SMALL_STATE(8805)] = 432234,
  [SMALL_STATE(8806)] = 432271,
  [SMALL_STATE(8807)] = 432308,
  [SMALL_STATE(8808)] = 432345,
  [SMALL_STATE(8809)] = 432400,
  [SMALL_STATE(8810)] = 432437,
  [SMALL_STATE(8811)] = 432474,
  [SMALL_STATE(8812)] = 432511,
  [SMALL_STATE(8813)] = 432548,
  [SMALL_STATE(8814)] = 432585,
  [SMALL_STATE(8815)] = 432622,
  [SMALL_STATE(8816)] = 432659,
  [SMALL_STATE(8817)] = 432696,
  [SMALL_STATE(8818)] = 432733,
  [SMALL_STATE(8819)] = 432770,
  [SMALL_STATE(8820)] = 432825,
  [SMALL_STATE(8821)] = 432862,
  [SMALL_STATE(8822)] = 432899,
  [SMALL_STATE(8823)] = 432936,
  [SMALL_STATE(8824)] = 432973,
  [SMALL_STATE(8825)] = 433010,
  [SMALL_STATE(8826)] = 433047,
  [SMALL_STATE(8827)] = 433084,
  [SMALL_STATE(8828)] = 433121,
  [SMALL_STATE(8829)] = 433176,
  [SMALL_STATE(8830)] = 433213,
  [SMALL_STATE(8831)] = 433250,
  [SMALL_STATE(8832)] = 433287,
  [SMALL_STATE(8833)] = 433324,
  [SMALL_STATE(8834)] = 433361,
  [SMALL_STATE(8835)] = 433398,
  [SMALL_STATE(8836)] = 433435,
  [SMALL_STATE(8837)] = 433490,
  [SMALL_STATE(8838)] = 433545,
  [SMALL_STATE(8839)] = 433582,
  [SMALL_STATE(8840)] = 433619,
  [SMALL_STATE(8841)] = 433656,
  [SMALL_STATE(8842)] = 433709,
  [SMALL_STATE(8843)] = 433746,
  [SMALL_STATE(8844)] = 433801,
  [SMALL_STATE(8845)] = 433838,
  [SMALL_STATE(8846)] = 433875,
  [SMALL_STATE(8847)] = 433912,
  [SMALL_STATE(8848)] = 433967,
  [SMALL_STATE(8849)] = 434018,
  [SMALL_STATE(8850)] = 434055,
  [SMALL_STATE(8851)] = 434092,
  [SMALL_STATE(8852)] = 434129,
  [SMALL_STATE(8853)] = 434166,
  [SMALL_STATE(8854)] = 434203,
  [SMALL_STATE(8855)] = 434240,
  [SMALL_STATE(8856)] = 434295,
  [SMALL_STATE(8857)] = 434350,
  [SMALL_STATE(8858)] = 434387,
  [SMALL_STATE(8859)] = 434424,
  [SMALL_STATE(8860)] = 434461,
  [SMALL_STATE(8861)] = 434516,
  [SMALL_STATE(8862)] = 434553,
  [SMALL_STATE(8863)] = 434590,
  [SMALL_STATE(8864)] = 434627,
  [SMALL_STATE(8865)] = 434670,
  [SMALL_STATE(8866)] = 434707,
  [SMALL_STATE(8867)] = 434744,
  [SMALL_STATE(8868)] = 434783,
  [SMALL_STATE(8869)] = 434822,
  [SMALL_STATE(8870)] = 434877,
  [SMALL_STATE(8871)] = 434914,
  [SMALL_STATE(8872)] = 434951,
  [SMALL_STATE(8873)] = 434988,
  [SMALL_STATE(8874)] = 435043,
  [SMALL_STATE(8875)] = 435080,
  [SMALL_STATE(8876)] = 435117,
  [SMALL_STATE(8877)] = 435154,
  [SMALL_STATE(8878)] = 435209,
  [SMALL_STATE(8879)] = 435246,
  [SMALL_STATE(8880)] = 435301,
  [SMALL_STATE(8881)] = 435356,
  [SMALL_STATE(8882)] = 435411,
  [SMALL_STATE(8883)] = 435466,
  [SMALL_STATE(8884)] = 435503,
  [SMALL_STATE(8885)] = 435558,
  [SMALL_STATE(8886)] = 435597,
  [SMALL_STATE(8887)] = 435652,
  [SMALL_STATE(8888)] = 435697,
  [SMALL_STATE(8889)] = 435740,
  [SMALL_STATE(8890)] = 435795,
  [SMALL_STATE(8891)] = 435856,
  [SMALL_STATE(8892)] = 435893,
  [SMALL_STATE(8893)] = 435930,
  [SMALL_STATE(8894)] = 435985,
  [SMALL_STATE(8895)] = 436022,
  [SMALL_STATE(8896)] = 436059,
  [SMALL_STATE(8897)] = 436114,
  [SMALL_STATE(8898)] = 436153,
  [SMALL_STATE(8899)] = 436190,
  [SMALL_STATE(8900)] = 436243,
  [SMALL_STATE(8901)] = 436298,
  [SMALL_STATE(8902)] = 436335,
  [SMALL_STATE(8903)] = 436372,
  [SMALL_STATE(8904)] = 436411,
  [SMALL_STATE(8905)] = 436466,
  [SMALL_STATE(8906)] = 436503,
  [SMALL_STATE(8907)] = 436540,
  [SMALL_STATE(8908)] = 436595,
  [SMALL_STATE(8909)] = 436632,
  [SMALL_STATE(8910)] = 436669,
  [SMALL_STATE(8911)] = 436706,
  [SMALL_STATE(8912)] = 436743,
  [SMALL_STATE(8913)] = 436798,
  [SMALL_STATE(8914)] = 436835,
  [SMALL_STATE(8915)] = 436890,
  [SMALL_STATE(8916)] = 436945,
  [SMALL_STATE(8917)] = 436982,
  [SMALL_STATE(8918)] = 437019,
  [SMALL_STATE(8919)] = 437056,
  [SMALL_STATE(8920)] = 437093,
  [SMALL_STATE(8921)] = 437148,
  [SMALL_STATE(8922)] = 437185,
  [SMALL_STATE(8923)] = 437222,
  [SMALL_STATE(8924)] = 437259,
  [SMALL_STATE(8925)] = 437314,
  [SMALL_STATE(8926)] = 437351,
  [SMALL_STATE(8927)] = 437388,
  [SMALL_STATE(8928)] = 437443,
  [SMALL_STATE(8929)] = 437482,
  [SMALL_STATE(8930)] = 437519,
  [SMALL_STATE(8931)] = 437574,
  [SMALL_STATE(8932)] = 437611,
  [SMALL_STATE(8933)] = 437648,
  [SMALL_STATE(8934)] = 437685,
  [SMALL_STATE(8935)] = 437722,
  [SMALL_STATE(8936)] = 437759,
  [SMALL_STATE(8937)] = 437814,
  [SMALL_STATE(8938)] = 437851,
  [SMALL_STATE(8939)] = 437890,
  [SMALL_STATE(8940)] = 437945,
  [SMALL_STATE(8941)] = 437998,
  [SMALL_STATE(8942)] = 438035,
  [SMALL_STATE(8943)] = 438090,
  [SMALL_STATE(8944)] = 438127,
  [SMALL_STATE(8945)] = 438164,
  [SMALL_STATE(8946)] = 438201,
  [SMALL_STATE(8947)] = 438254,
  [SMALL_STATE(8948)] = 438309,
  [SMALL_STATE(8949)] = 438346,
  [SMALL_STATE(8950)] = 438383,
  [SMALL_STATE(8951)] = 438438,
  [SMALL_STATE(8952)] = 438475,
  [SMALL_STATE(8953)] = 438512,
  [SMALL_STATE(8954)] = 438549,
  [SMALL_STATE(8955)] = 438604,
  [SMALL_STATE(8956)] = 438655,
  [SMALL_STATE(8957)] = 438708,
  [SMALL_STATE(8958)] = 438745,
  [SMALL_STATE(8959)] = 438800,
  [SMALL_STATE(8960)] = 438839,
  [SMALL_STATE(8961)] = 438894,
  [SMALL_STATE(8962)] = 438931,
  [SMALL_STATE(8963)] = 438986,
  [SMALL_STATE(8964)] = 439041,
  [SMALL_STATE(8965)] = 439096,
  [SMALL_STATE(8966)] = 439133,
  [SMALL_STATE(8967)] = 439188,
  [SMALL_STATE(8968)] = 439225,
  [SMALL_STATE(8969)] = 439280,
  [SMALL_STATE(8970)] = 439317,
  [SMALL_STATE(8971)] = 439372,
  [SMALL_STATE(8972)] = 439411,
  [SMALL_STATE(8973)] = 439466,
  [SMALL_STATE(8974)] = 439503,
  [SMALL_STATE(8975)] = 439558,
  [SMALL_STATE(8976)] = 439613,
  [SMALL_STATE(8977)] = 439650,
  [SMALL_STATE(8978)] = 439705,
  [SMALL_STATE(8979)] = 439742,
  [SMALL_STATE(8980)] = 439797,
  [SMALL_STATE(8981)] = 439852,
  [SMALL_STATE(8982)] = 439889,
  [SMALL_STATE(8983)] = 439926,
  [SMALL_STATE(8984)] = 439963,
  [SMALL_STATE(8985)] = 440018,
  [SMALL_STATE(8986)] = 440055,
  [SMALL_STATE(8987)] = 440110,
  [SMALL_STATE(8988)] = 440165,
  [SMALL_STATE(8989)] = 440220,
  [SMALL_STATE(8990)] = 440275,
  [SMALL_STATE(8991)] = 440312,
  [SMALL_STATE(8992)] = 440367,
  [SMALL_STATE(8993)] = 440422,
  [SMALL_STATE(8994)] = 440459,
  [SMALL_STATE(8995)] = 440514,
  [SMALL_STATE(8996)] = 440551,
  [SMALL_STATE(8997)] = 440606,
  [SMALL_STATE(8998)] = 440657,
  [SMALL_STATE(8999)] = 440712,
  [SMALL_STATE(9000)] = 440751,
  [SMALL_STATE(9001)] = 440806,
  [SMALL_STATE(9002)] = 440843,
  [SMALL_STATE(9003)] = 440898,
  [SMALL_STATE(9004)] = 440935,
  [SMALL_STATE(9005)] = 440990,
  [SMALL_STATE(9006)] = 441051,
  [SMALL_STATE(9007)] = 441088,
  [SMALL_STATE(9008)] = 441143,
  [SMALL_STATE(9009)] = 441184,
  [SMALL_STATE(9010)] = 441239,
  [SMALL_STATE(9011)] = 441276,
  [SMALL_STATE(9012)] = 441313,
  [SMALL_STATE(9013)] = 441350,
  [SMALL_STATE(9014)] = 441405,
  [SMALL_STATE(9015)] = 441458,
  [SMALL_STATE(9016)] = 441513,
  [SMALL_STATE(9017)] = 441552,
  [SMALL_STATE(9018)] = 441607,
  [SMALL_STATE(9019)] = 441644,
  [SMALL_STATE(9020)] = 441681,
  [SMALL_STATE(9021)] = 441734,
  [SMALL_STATE(9022)] = 441771,
  [SMALL_STATE(9023)] = 441810,
  [SMALL_STATE(9024)] = 441865,
  [SMALL_STATE(9025)] = 441918,
  [SMALL_STATE(9026)] = 441955,
  [SMALL_STATE(9027)] = 441992,
  [SMALL_STATE(9028)] = 442029,
  [SMALL_STATE(9029)] = 442068,
  [SMALL_STATE(9030)] = 442105,
  [SMALL_STATE(9031)] = 442142,
  [SMALL_STATE(9032)] = 442179,
  [SMALL_STATE(9033)] = 442216,
  [SMALL_STATE(9034)] = 442253,
  [SMALL_STATE(9035)] = 442290,
  [SMALL_STATE(9036)] = 442327,
  [SMALL_STATE(9037)] = 442364,
  [SMALL_STATE(9038)] = 442401,
  [SMALL_STATE(9039)] = 442438,
  [SMALL_STATE(9040)] = 442475,
  [SMALL_STATE(9041)] = 442512,
  [SMALL_STATE(9042)] = 442553,
  [SMALL_STATE(9043)] = 442608,
  [SMALL_STATE(9044)] = 442647,
  [SMALL_STATE(9045)] = 442686,
  [SMALL_STATE(9046)] = 442723,
  [SMALL_STATE(9047)] = 442760,
  [SMALL_STATE(9048)] = 442797,
  [SMALL_STATE(9049)] = 442848,
  [SMALL_STATE(9050)] = 442885,
  [SMALL_STATE(9051)] = 442940,
  [SMALL_STATE(9052)] = 442977,
  [SMALL_STATE(9053)] = 443014,
  [SMALL_STATE(9054)] = 443051,
  [SMALL_STATE(9055)] = 443088,
  [SMALL_STATE(9056)] = 443133,
  [SMALL_STATE(9057)] = 443170,
  [SMALL_STATE(9058)] = 443209,
  [SMALL_STATE(9059)] = 443246,
  [SMALL_STATE(9060)] = 443283,
  [SMALL_STATE(9061)] = 443320,
  [SMALL_STATE(9062)] = 443357,
  [SMALL_STATE(9063)] = 443412,
  [SMALL_STATE(9064)] = 443449,
  [SMALL_STATE(9065)] = 443486,
  [SMALL_STATE(9066)] = 443523,
  [SMALL_STATE(9067)] = 443560,
  [SMALL_STATE(9068)] = 443611,
  [SMALL_STATE(9069)] = 443648,
  [SMALL_STATE(9070)] = 443687,
  [SMALL_STATE(9071)] = 443724,
  [SMALL_STATE(9072)] = 443761,
  [SMALL_STATE(9073)] = 443798,
  [SMALL_STATE(9074)] = 443835,
  [SMALL_STATE(9075)] = 443872,
  [SMALL_STATE(9076)] = 443927,
  [SMALL_STATE(9077)] = 443964,
  [SMALL_STATE(9078)] = 444001,
  [SMALL_STATE(9079)] = 444040,
  [SMALL_STATE(9080)] = 444077,
  [SMALL_STATE(9081)] = 444130,
  [SMALL_STATE(9082)] = 444167,
  [SMALL_STATE(9083)] = 444204,
  [SMALL_STATE(9084)] = 444241,
  [SMALL_STATE(9085)] = 444278,
  [SMALL_STATE(9086)] = 444315,
  [SMALL_STATE(9087)] = 444352,
  [SMALL_STATE(9088)] = 444389,
  [SMALL_STATE(9089)] = 444444,
  [SMALL_STATE(9090)] = 444481,
  [SMALL_STATE(9091)] = 444518,
  [SMALL_STATE(9092)] = 444561,
  [SMALL_STATE(9093)] = 444598,
  [SMALL_STATE(9094)] = 444651,
  [SMALL_STATE(9095)] = 444688,
  [SMALL_STATE(9096)] = 444725,
  [SMALL_STATE(9097)] = 444762,
  [SMALL_STATE(9098)] = 444817,
  [SMALL_STATE(9099)] = 444854,
  [SMALL_STATE(9100)] = 444891,
  [SMALL_STATE(9101)] = 444930,
  [SMALL_STATE(9102)] = 444967,
  [SMALL_STATE(9103)] = 445004,
  [SMALL_STATE(9104)] = 445041,
  [SMALL_STATE(9105)] = 445078,
  [SMALL_STATE(9106)] = 445115,
  [SMALL_STATE(9107)] = 445152,
  [SMALL_STATE(9108)] = 445207,
  [SMALL_STATE(9109)] = 445244,
  [SMALL_STATE(9110)] = 445281,
  [SMALL_STATE(9111)] = 445322,
  [SMALL_STATE(9112)] = 445359,
  [SMALL_STATE(9113)] = 445398,
  [SMALL_STATE(9114)] = 445435,
  [SMALL_STATE(9115)] = 445472,
  [SMALL_STATE(9116)] = 445511,
  [SMALL_STATE(9117)] = 445548,
  [SMALL_STATE(9118)] = 445585,
  [SMALL_STATE(9119)] = 445622,
  [SMALL_STATE(9120)] = 445659,
  [SMALL_STATE(9121)] = 445696,
  [SMALL_STATE(9122)] = 445733,
  [SMALL_STATE(9123)] = 445782,
  [SMALL_STATE(9124)] = 445825,
  [SMALL_STATE(9125)] = 445862,
  [SMALL_STATE(9126)] = 445917,
  [SMALL_STATE(9127)] = 445970,
  [SMALL_STATE(9128)] = 446007,
  [SMALL_STATE(9129)] = 446048,
  [SMALL_STATE(9130)] = 446085,
  [SMALL_STATE(9131)] = 446122,
  [SMALL_STATE(9132)] = 446159,
  [SMALL_STATE(9133)] = 446196,
  [SMALL_STATE(9134)] = 446233,
  [SMALL_STATE(9135)] = 446288,
  [SMALL_STATE(9136)] = 446331,
  [SMALL_STATE(9137)] = 446368,
  [SMALL_STATE(9138)] = 446411,
  [SMALL_STATE(9139)] = 446448,
  [SMALL_STATE(9140)] = 446485,
  [SMALL_STATE(9141)] = 446522,
  [SMALL_STATE(9142)] = 446559,
  [SMALL_STATE(9143)] = 446596,
  [SMALL_STATE(9144)] = 446635,
  [SMALL_STATE(9145)] = 446672,
  [SMALL_STATE(9146)] = 446725,
  [SMALL_STATE(9147)] = 446762,
  [SMALL_STATE(9148)] = 446799,
  [SMALL_STATE(9149)] = 446854,
  [SMALL_STATE(9150)] = 446891,
  [SMALL_STATE(9151)] = 446928,
  [SMALL_STATE(9152)] = 446965,
  [SMALL_STATE(9153)] = 447002,
  [SMALL_STATE(9154)] = 447041,
  [SMALL_STATE(9155)] = 447078,
  [SMALL_STATE(9156)] = 447133,
  [SMALL_STATE(9157)] = 447170,
  [SMALL_STATE(9158)] = 447211,
  [SMALL_STATE(9159)] = 447248,
  [SMALL_STATE(9160)] = 447285,
  [SMALL_STATE(9161)] = 447322,
  [SMALL_STATE(9162)] = 447359,
  [SMALL_STATE(9163)] = 447396,
  [SMALL_STATE(9164)] = 447433,
  [SMALL_STATE(9165)] = 447488,
  [SMALL_STATE(9166)] = 447525,
  [SMALL_STATE(9167)] = 447562,
  [SMALL_STATE(9168)] = 447599,
  [SMALL_STATE(9169)] = 447636,
  [SMALL_STATE(9170)] = 447673,
  [SMALL_STATE(9171)] = 447710,
  [SMALL_STATE(9172)] = 447747,
  [SMALL_STATE(9173)] = 447784,
  [SMALL_STATE(9174)] = 447821,
  [SMALL_STATE(9175)] = 447858,
  [SMALL_STATE(9176)] = 447895,
  [SMALL_STATE(9177)] = 447932,
  [SMALL_STATE(9178)] = 447973,
  [SMALL_STATE(9179)] = 448010,
  [SMALL_STATE(9180)] = 448047,
  [SMALL_STATE(9181)] = 448102,
  [SMALL_STATE(9182)] = 448139,
  [SMALL_STATE(9183)] = 448180,
  [SMALL_STATE(9184)] = 448217,
  [SMALL_STATE(9185)] = 448254,
  [SMALL_STATE(9186)] = 448291,
  [SMALL_STATE(9187)] = 448328,
  [SMALL_STATE(9188)] = 448373,
  [SMALL_STATE(9189)] = 448410,
  [SMALL_STATE(9190)] = 448447,
  [SMALL_STATE(9191)] = 448484,
  [SMALL_STATE(9192)] = 448525,
  [SMALL_STATE(9193)] = 448562,
  [SMALL_STATE(9194)] = 448599,
  [SMALL_STATE(9195)] = 448636,
  [SMALL_STATE(9196)] = 448693,
  [SMALL_STATE(9197)] = 448730,
  [SMALL_STATE(9198)] = 448767,
  [SMALL_STATE(9199)] = 448804,
  [SMALL_STATE(9200)] = 448859,
  [SMALL_STATE(9201)] = 448896,
  [SMALL_STATE(9202)] = 448933,
  [SMALL_STATE(9203)] = 448970,
  [SMALL_STATE(9204)] = 449007,
  [SMALL_STATE(9205)] = 449044,
  [SMALL_STATE(9206)] = 449081,
  [SMALL_STATE(9207)] = 449126,
  [SMALL_STATE(9208)] = 449163,
  [SMALL_STATE(9209)] = 449200,
  [SMALL_STATE(9210)] = 449241,
  [SMALL_STATE(9211)] = 449278,
  [SMALL_STATE(9212)] = 449321,
  [SMALL_STATE(9213)] = 449358,
  [SMALL_STATE(9214)] = 449413,
  [SMALL_STATE(9215)] = 449450,
  [SMALL_STATE(9216)] = 449487,
  [SMALL_STATE(9217)] = 449524,
  [SMALL_STATE(9218)] = 449561,
  [SMALL_STATE(9219)] = 449600,
  [SMALL_STATE(9220)] = 449637,
  [SMALL_STATE(9221)] = 449676,
  [SMALL_STATE(9222)] = 449713,
  [SMALL_STATE(9223)] = 449768,
  [SMALL_STATE(9224)] = 449805,
  [SMALL_STATE(9225)] = 449860,
  [SMALL_STATE(9226)] = 449897,
  [SMALL_STATE(9227)] = 449934,
  [SMALL_STATE(9228)] = 449971,
  [SMALL_STATE(9229)] = 450008,
  [SMALL_STATE(9230)] = 450045,
  [SMALL_STATE(9231)] = 450082,
  [SMALL_STATE(9232)] = 450119,
  [SMALL_STATE(9233)] = 450156,
  [SMALL_STATE(9234)] = 450193,
  [SMALL_STATE(9235)] = 450230,
  [SMALL_STATE(9236)] = 450273,
  [SMALL_STATE(9237)] = 450328,
  [SMALL_STATE(9238)] = 450365,
  [SMALL_STATE(9239)] = 450404,
  [SMALL_STATE(9240)] = 450441,
  [SMALL_STATE(9241)] = 450484,
  [SMALL_STATE(9242)] = 450523,
  [SMALL_STATE(9243)] = 450560,
  [SMALL_STATE(9244)] = 450597,
  [SMALL_STATE(9245)] = 450634,
  [SMALL_STATE(9246)] = 450689,
  [SMALL_STATE(9247)] = 450726,
  [SMALL_STATE(9248)] = 450763,
  [SMALL_STATE(9249)] = 450800,
  [SMALL_STATE(9250)] = 450837,
  [SMALL_STATE(9251)] = 450874,
  [SMALL_STATE(9252)] = 450911,
  [SMALL_STATE(9253)] = 450950,
  [SMALL_STATE(9254)] = 451005,
  [SMALL_STATE(9255)] = 451046,
  [SMALL_STATE(9256)] = 451083,
  [SMALL_STATE(9257)] = 451120,
  [SMALL_STATE(9258)] = 451157,
  [SMALL_STATE(9259)] = 451206,
  [SMALL_STATE(9260)] = 451243,
  [SMALL_STATE(9261)] = 451280,
  [SMALL_STATE(9262)] = 451317,
  [SMALL_STATE(9263)] = 451372,
  [SMALL_STATE(9264)] = 451409,
  [SMALL_STATE(9265)] = 451450,
  [SMALL_STATE(9266)] = 451487,
  [SMALL_STATE(9267)] = 451542,
  [SMALL_STATE(9268)] = 451579,
  [SMALL_STATE(9269)] = 451616,
  [SMALL_STATE(9270)] = 451653,
  [SMALL_STATE(9271)] = 451690,
  [SMALL_STATE(9272)] = 451727,
  [SMALL_STATE(9273)] = 451764,
  [SMALL_STATE(9274)] = 451815,
  [SMALL_STATE(9275)] = 451856,
  [SMALL_STATE(9276)] = 451899,
  [SMALL_STATE(9277)] = 451954,
  [SMALL_STATE(9278)] = 451991,
  [SMALL_STATE(9279)] = 452028,
  [SMALL_STATE(9280)] = 452065,
  [SMALL_STATE(9281)] = 452102,
  [SMALL_STATE(9282)] = 452139,
  [SMALL_STATE(9283)] = 452182,
  [SMALL_STATE(9284)] = 452237,
  [SMALL_STATE(9285)] = 452274,
  [SMALL_STATE(9286)] = 452315,
  [SMALL_STATE(9287)] = 452352,
  [SMALL_STATE(9288)] = 452395,
  [SMALL_STATE(9289)] = 452432,
  [SMALL_STATE(9290)] = 452473,
  [SMALL_STATE(9291)] = 452514,
  [SMALL_STATE(9292)] = 452553,
  [SMALL_STATE(9293)] = 452608,
  [SMALL_STATE(9294)] = 452645,
  [SMALL_STATE(9295)] = 452682,
  [SMALL_STATE(9296)] = 452721,
  [SMALL_STATE(9297)] = 452758,
  [SMALL_STATE(9298)] = 452795,
  [SMALL_STATE(9299)] = 452832,
  [SMALL_STATE(9300)] = 452887,
  [SMALL_STATE(9301)] = 452924,
  [SMALL_STATE(9302)] = 452961,
  [SMALL_STATE(9303)] = 452998,
  [SMALL_STATE(9304)] = 453037,
  [SMALL_STATE(9305)] = 453074,
  [SMALL_STATE(9306)] = 453129,
  [SMALL_STATE(9307)] = 453166,
  [SMALL_STATE(9308)] = 453203,
  [SMALL_STATE(9309)] = 453240,
  [SMALL_STATE(9310)] = 453277,
  [SMALL_STATE(9311)] = 453314,
  [SMALL_STATE(9312)] = 453369,
  [SMALL_STATE(9313)] = 453406,
  [SMALL_STATE(9314)] = 453443,
  [SMALL_STATE(9315)] = 453480,
  [SMALL_STATE(9316)] = 453517,
  [SMALL_STATE(9317)] = 453554,
  [SMALL_STATE(9318)] = 453595,
  [SMALL_STATE(9319)] = 453632,
  [SMALL_STATE(9320)] = 453687,
  [SMALL_STATE(9321)] = 453724,
  [SMALL_STATE(9322)] = 453761,
  [SMALL_STATE(9323)] = 453798,
  [SMALL_STATE(9324)] = 453835,
  [SMALL_STATE(9325)] = 453872,
  [SMALL_STATE(9326)] = 453915,
  [SMALL_STATE(9327)] = 453961,
  [SMALL_STATE(9328)] = 453997,
  [SMALL_STATE(9329)] = 454033,
  [SMALL_STATE(9330)] = 454069,
  [SMALL_STATE(9331)] = 454107,
  [SMALL_STATE(9332)] = 454143,
  [SMALL_STATE(9333)] = 454181,
  [SMALL_STATE(9334)] = 454239,
  [SMALL_STATE(9335)] = 454275,
  [SMALL_STATE(9336)] = 454327,
  [SMALL_STATE(9337)] = 454365,
  [SMALL_STATE(9338)] = 454407,
  [SMALL_STATE(9339)] = 454459,
  [SMALL_STATE(9340)] = 454495,
  [SMALL_STATE(9341)] = 454545,
  [SMALL_STATE(9342)] = 454581,
  [SMALL_STATE(9343)] = 454617,
  [SMALL_STATE(9344)] = 454669,
  [SMALL_STATE(9345)] = 454707,
  [SMALL_STATE(9346)] = 454743,
  [SMALL_STATE(9347)] = 454779,
  [SMALL_STATE(9348)] = 454815,
  [SMALL_STATE(9349)] = 454851,
  [SMALL_STATE(9350)] = 454887,
  [SMALL_STATE(9351)] = 454923,
  [SMALL_STATE(9352)] = 454959,
  [SMALL_STATE(9353)] = 454997,
  [SMALL_STATE(9354)] = 455033,
  [SMALL_STATE(9355)] = 455069,
  [SMALL_STATE(9356)] = 455105,
  [SMALL_STATE(9357)] = 455141,
  [SMALL_STATE(9358)] = 455177,
  [SMALL_STATE(9359)] = 455213,
  [SMALL_STATE(9360)] = 455265,
  [SMALL_STATE(9361)] = 455301,
  [SMALL_STATE(9362)] = 455337,
  [SMALL_STATE(9363)] = 455373,
  [SMALL_STATE(9364)] = 455409,
  [SMALL_STATE(9365)] = 455445,
  [SMALL_STATE(9366)] = 455481,
  [SMALL_STATE(9367)] = 455521,
  [SMALL_STATE(9368)] = 455557,
  [SMALL_STATE(9369)] = 455593,
  [SMALL_STATE(9370)] = 455629,
  [SMALL_STATE(9371)] = 455665,
  [SMALL_STATE(9372)] = 455701,
  [SMALL_STATE(9373)] = 455741,
  [SMALL_STATE(9374)] = 455777,
  [SMALL_STATE(9375)] = 455813,
  [SMALL_STATE(9376)] = 455849,
  [SMALL_STATE(9377)] = 455885,
  [SMALL_STATE(9378)] = 455921,
  [SMALL_STATE(9379)] = 455957,
  [SMALL_STATE(9380)] = 455993,
  [SMALL_STATE(9381)] = 456029,
  [SMALL_STATE(9382)] = 456065,
  [SMALL_STATE(9383)] = 456101,
  [SMALL_STATE(9384)] = 456143,
  [SMALL_STATE(9385)] = 456179,
  [SMALL_STATE(9386)] = 456215,
  [SMALL_STATE(9387)] = 456251,
  [SMALL_STATE(9388)] = 456287,
  [SMALL_STATE(9389)] = 456323,
  [SMALL_STATE(9390)] = 456359,
  [SMALL_STATE(9391)] = 456395,
  [SMALL_STATE(9392)] = 456431,
  [SMALL_STATE(9393)] = 456467,
  [SMALL_STATE(9394)] = 456503,
  [SMALL_STATE(9395)] = 456549,
  [SMALL_STATE(9396)] = 456585,
  [SMALL_STATE(9397)] = 456621,
  [SMALL_STATE(9398)] = 456657,
  [SMALL_STATE(9399)] = 456693,
  [SMALL_STATE(9400)] = 456745,
  [SMALL_STATE(9401)] = 456781,
  [SMALL_STATE(9402)] = 456817,
  [SMALL_STATE(9403)] = 456853,
  [SMALL_STATE(9404)] = 456899,
  [SMALL_STATE(9405)] = 456935,
  [SMALL_STATE(9406)] = 456981,
  [SMALL_STATE(9407)] = 457021,
  [SMALL_STATE(9408)] = 457057,
  [SMALL_STATE(9409)] = 457093,
  [SMALL_STATE(9410)] = 457129,
  [SMALL_STATE(9411)] = 457165,
  [SMALL_STATE(9412)] = 457217,
  [SMALL_STATE(9413)] = 457253,
  [SMALL_STATE(9414)] = 457289,
  [SMALL_STATE(9415)] = 457325,
  [SMALL_STATE(9416)] = 457363,
  [SMALL_STATE(9417)] = 457399,
  [SMALL_STATE(9418)] = 457435,
  [SMALL_STATE(9419)] = 457487,
  [SMALL_STATE(9420)] = 457523,
  [SMALL_STATE(9421)] = 457561,
  [SMALL_STATE(9422)] = 457597,
  [SMALL_STATE(9423)] = 457649,
  [SMALL_STATE(9424)] = 457685,
  [SMALL_STATE(9425)] = 457721,
  [SMALL_STATE(9426)] = 457757,
  [SMALL_STATE(9427)] = 457793,
  [SMALL_STATE(9428)] = 457829,
  [SMALL_STATE(9429)] = 457865,
  [SMALL_STATE(9430)] = 457901,
  [SMALL_STATE(9431)] = 457937,
  [SMALL_STATE(9432)] = 457979,
  [SMALL_STATE(9433)] = 458021,
  [SMALL_STATE(9434)] = 458071,
  [SMALL_STATE(9435)] = 458107,
  [SMALL_STATE(9436)] = 458147,
  [SMALL_STATE(9437)] = 458183,
  [SMALL_STATE(9438)] = 458219,
  [SMALL_STATE(9439)] = 458255,
  [SMALL_STATE(9440)] = 458291,
  [SMALL_STATE(9441)] = 458327,
  [SMALL_STATE(9442)] = 458363,
  [SMALL_STATE(9443)] = 458409,
  [SMALL_STATE(9444)] = 458445,
  [SMALL_STATE(9445)] = 458481,
  [SMALL_STATE(9446)] = 458517,
  [SMALL_STATE(9447)] = 458553,
  [SMALL_STATE(9448)] = 458589,
  [SMALL_STATE(9449)] = 458625,
  [SMALL_STATE(9450)] = 458661,
  [SMALL_STATE(9451)] = 458697,
  [SMALL_STATE(9452)] = 458733,
  [SMALL_STATE(9453)] = 458769,
  [SMALL_STATE(9454)] = 458811,
  [SMALL_STATE(9455)] = 458847,
  [SMALL_STATE(9456)] = 458883,
  [SMALL_STATE(9457)] = 458919,
  [SMALL_STATE(9458)] = 458957,
  [SMALL_STATE(9459)] = 458993,
  [SMALL_STATE(9460)] = 459045,
  [SMALL_STATE(9461)] = 459081,
  [SMALL_STATE(9462)] = 459117,
  [SMALL_STATE(9463)] = 459153,
  [SMALL_STATE(9464)] = 459189,
  [SMALL_STATE(9465)] = 459225,
  [SMALL_STATE(9466)] = 459261,
  [SMALL_STATE(9467)] = 459299,
  [SMALL_STATE(9468)] = 459335,
  [SMALL_STATE(9469)] = 459377,
  [SMALL_STATE(9470)] = 459413,
  [SMALL_STATE(9471)] = 459449,
  [SMALL_STATE(9472)] = 459485,
  [SMALL_STATE(9473)] = 459521,
  [SMALL_STATE(9474)] = 459561,
  [SMALL_STATE(9475)] = 459597,
  [SMALL_STATE(9476)] = 459633,
  [SMALL_STATE(9477)] = 459679,
  [SMALL_STATE(9478)] = 459715,
  [SMALL_STATE(9479)] = 459751,
  [SMALL_STATE(9480)] = 459787,
  [SMALL_STATE(9481)] = 459827,
  [SMALL_STATE(9482)] = 459863,
  [SMALL_STATE(9483)] = 459899,
  [SMALL_STATE(9484)] = 459945,
  [SMALL_STATE(9485)] = 459981,
  [SMALL_STATE(9486)] = 460017,
  [SMALL_STATE(9487)] = 460053,
  [SMALL_STATE(9488)] = 460089,
  [SMALL_STATE(9489)] = 460125,
  [SMALL_STATE(9490)] = 460175,
  [SMALL_STATE(9491)] = 460211,
  [SMALL_STATE(9492)] = 460247,
  [SMALL_STATE(9493)] = 460283,
  [SMALL_STATE(9494)] = 460319,
  [SMALL_STATE(9495)] = 460355,
  [SMALL_STATE(9496)] = 460393,
  [SMALL_STATE(9497)] = 460445,
  [SMALL_STATE(9498)] = 460481,
  [SMALL_STATE(9499)] = 460531,
  [SMALL_STATE(9500)] = 460569,
  [SMALL_STATE(9501)] = 460605,
  [SMALL_STATE(9502)] = 460651,
  [SMALL_STATE(9503)] = 460687,
  [SMALL_STATE(9504)] = 460723,
  [SMALL_STATE(9505)] = 460763,
  [SMALL_STATE(9506)] = 460799,
  [SMALL_STATE(9507)] = 460849,
  [SMALL_STATE(9508)] = 460885,
  [SMALL_STATE(9509)] = 460921,
  [SMALL_STATE(9510)] = 460955,
  [SMALL_STATE(9511)] = 460991,
  [SMALL_STATE(9512)] = 461027,
  [SMALL_STATE(9513)] = 461063,
  [SMALL_STATE(9514)] = 461103,
  [SMALL_STATE(9515)] = 461149,
  [SMALL_STATE(9516)] = 461185,
  [SMALL_STATE(9517)] = 461221,
  [SMALL_STATE(9518)] = 461271,
  [SMALL_STATE(9519)] = 461323,
  [SMALL_STATE(9520)] = 461359,
  [SMALL_STATE(9521)] = 461395,
  [SMALL_STATE(9522)] = 461435,
  [SMALL_STATE(9523)] = 461475,
  [SMALL_STATE(9524)] = 461517,
  [SMALL_STATE(9525)] = 461553,
  [SMALL_STATE(9526)] = 461595,
  [SMALL_STATE(9527)] = 461631,
  [SMALL_STATE(9528)] = 461671,
  [SMALL_STATE(9529)] = 461707,
  [SMALL_STATE(9530)] = 461743,
  [SMALL_STATE(9531)] = 461779,
  [SMALL_STATE(9532)] = 461815,
  [SMALL_STATE(9533)] = 461851,
  [SMALL_STATE(9534)] = 461889,
  [SMALL_STATE(9535)] = 461925,
  [SMALL_STATE(9536)] = 461961,
  [SMALL_STATE(9537)] = 461997,
  [SMALL_STATE(9538)] = 462037,
  [SMALL_STATE(9539)] = 462073,
  [SMALL_STATE(9540)] = 462109,
  [SMALL_STATE(9541)] = 462145,
  [SMALL_STATE(9542)] = 462191,
  [SMALL_STATE(9543)] = 462227,
  [SMALL_STATE(9544)] = 462263,
  [SMALL_STATE(9545)] = 462299,
  [SMALL_STATE(9546)] = 462335,
  [SMALL_STATE(9547)] = 462371,
  [SMALL_STATE(9548)] = 462407,
  [SMALL_STATE(9549)] = 462457,
  [SMALL_STATE(9550)] = 462497,
  [SMALL_STATE(9551)] = 462533,
  [SMALL_STATE(9552)] = 462569,
  [SMALL_STATE(9553)] = 462605,
  [SMALL_STATE(9554)] = 462641,
  [SMALL_STATE(9555)] = 462679,
  [SMALL_STATE(9556)] = 462715,
  [SMALL_STATE(9557)] = 462751,
  [SMALL_STATE(9558)] = 462787,
  [SMALL_STATE(9559)] = 462823,
  [SMALL_STATE(9560)] = 462865,
  [SMALL_STATE(9561)] = 462901,
  [SMALL_STATE(9562)] = 462937,
  [SMALL_STATE(9563)] = 462977,
  [SMALL_STATE(9564)] = 463027,
  [SMALL_STATE(9565)] = 463067,
  [SMALL_STATE(9566)] = 463105,
  [SMALL_STATE(9567)] = 463141,
  [SMALL_STATE(9568)] = 463177,
  [SMALL_STATE(9569)] = 463213,
  [SMALL_STATE(9570)] = 463249,
  [SMALL_STATE(9571)] = 463289,
  [SMALL_STATE(9572)] = 463325,
  [SMALL_STATE(9573)] = 463361,
  [SMALL_STATE(9574)] = 463397,
  [SMALL_STATE(9575)] = 463433,
  [SMALL_STATE(9576)] = 463469,
  [SMALL_STATE(9577)] = 463505,
  [SMALL_STATE(9578)] = 463541,
  [SMALL_STATE(9579)] = 463577,
  [SMALL_STATE(9580)] = 463613,
  [SMALL_STATE(9581)] = 463663,
  [SMALL_STATE(9582)] = 463699,
  [SMALL_STATE(9583)] = 463735,
  [SMALL_STATE(9584)] = 463771,
  [SMALL_STATE(9585)] = 463807,
  [SMALL_STATE(9586)] = 463853,
  [SMALL_STATE(9587)] = 463889,
  [SMALL_STATE(9588)] = 463925,
  [SMALL_STATE(9589)] = 463961,
  [SMALL_STATE(9590)] = 463997,
  [SMALL_STATE(9591)] = 464039,
  [SMALL_STATE(9592)] = 464081,
  [SMALL_STATE(9593)] = 464117,
  [SMALL_STATE(9594)] = 464153,
  [SMALL_STATE(9595)] = 464189,
  [SMALL_STATE(9596)] = 464225,
  [SMALL_STATE(9597)] = 464271,
  [SMALL_STATE(9598)] = 464309,
  [SMALL_STATE(9599)] = 464345,
  [SMALL_STATE(9600)] = 464381,
  [SMALL_STATE(9601)] = 464417,
  [SMALL_STATE(9602)] = 464467,
  [SMALL_STATE(9603)] = 464519,
  [SMALL_STATE(9604)] = 464555,
  [SMALL_STATE(9605)] = 464597,
  [SMALL_STATE(9606)] = 464633,
  [SMALL_STATE(9607)] = 464673,
  [SMALL_STATE(9608)] = 464725,
  [SMALL_STATE(9609)] = 464761,
  [SMALL_STATE(9610)] = 464797,
  [SMALL_STATE(9611)] = 464843,
  [SMALL_STATE(9612)] = 464879,
  [SMALL_STATE(9613)] = 464917,
  [SMALL_STATE(9614)] = 464953,
  [SMALL_STATE(9615)] = 464989,
  [SMALL_STATE(9616)] = 465025,
  [SMALL_STATE(9617)] = 465067,
  [SMALL_STATE(9618)] = 465113,
  [SMALL_STATE(9619)] = 465149,
  [SMALL_STATE(9620)] = 465185,
  [SMALL_STATE(9621)] = 465221,
  [SMALL_STATE(9622)] = 465257,
  [SMALL_STATE(9623)] = 465293,
  [SMALL_STATE(9624)] = 465329,
  [SMALL_STATE(9625)] = 465365,
  [SMALL_STATE(9626)] = 465401,
  [SMALL_STATE(9627)] = 465437,
  [SMALL_STATE(9628)] = 465473,
  [SMALL_STATE(9629)] = 465509,
  [SMALL_STATE(9630)] = 465545,
  [SMALL_STATE(9631)] = 465597,
  [SMALL_STATE(9632)] = 465633,
  [SMALL_STATE(9633)] = 465669,
  [SMALL_STATE(9634)] = 465705,
  [SMALL_STATE(9635)] = 465741,
  [SMALL_STATE(9636)] = 465777,
  [SMALL_STATE(9637)] = 465813,
  [SMALL_STATE(9638)] = 465849,
  [SMALL_STATE(9639)] = 465885,
  [SMALL_STATE(9640)] = 465921,
  [SMALL_STATE(9641)] = 465957,
  [SMALL_STATE(9642)] = 465993,
  [SMALL_STATE(9643)] = 466029,
  [SMALL_STATE(9644)] = 466069,
  [SMALL_STATE(9645)] = 466105,
  [SMALL_STATE(9646)] = 466141,
  [SMALL_STATE(9647)] = 466177,
  [SMALL_STATE(9648)] = 466213,
  [SMALL_STATE(9649)] = 466249,
  [SMALL_STATE(9650)] = 466285,
  [SMALL_STATE(9651)] = 466321,
  [SMALL_STATE(9652)] = 466357,
  [SMALL_STATE(9653)] = 466393,
  [SMALL_STATE(9654)] = 466445,
  [SMALL_STATE(9655)] = 466481,
  [SMALL_STATE(9656)] = 466517,
  [SMALL_STATE(9657)] = 466563,
  [SMALL_STATE(9658)] = 466599,
  [SMALL_STATE(9659)] = 466635,
  [SMALL_STATE(9660)] = 466671,
  [SMALL_STATE(9661)] = 466709,
  [SMALL_STATE(9662)] = 466749,
  [SMALL_STATE(9663)] = 466795,
  [SMALL_STATE(9664)] = 466831,
  [SMALL_STATE(9665)] = 466867,
  [SMALL_STATE(9666)] = 466903,
  [SMALL_STATE(9667)] = 466939,
  [SMALL_STATE(9668)] = 466975,
  [SMALL_STATE(9669)] = 467015,
  [SMALL_STATE(9670)] = 467051,
  [SMALL_STATE(9671)] = 467097,
  [SMALL_STATE(9672)] = 467133,
  [SMALL_STATE(9673)] = 467173,
  [SMALL_STATE(9674)] = 467209,
  [SMALL_STATE(9675)] = 467245,
  [SMALL_STATE(9676)] = 467281,
  [SMALL_STATE(9677)] = 467317,
  [SMALL_STATE(9678)] = 467353,
  [SMALL_STATE(9679)] = 467389,
  [SMALL_STATE(9680)] = 467425,
  [SMALL_STATE(9681)] = 467461,
  [SMALL_STATE(9682)] = 467497,
  [SMALL_STATE(9683)] = 467533,
  [SMALL_STATE(9684)] = 467569,
  [SMALL_STATE(9685)] = 467605,
  [SMALL_STATE(9686)] = 467641,
  [SMALL_STATE(9687)] = 467687,
  [SMALL_STATE(9688)] = 467723,
  [SMALL_STATE(9689)] = 467759,
  [SMALL_STATE(9690)] = 467795,
  [SMALL_STATE(9691)] = 467831,
  [SMALL_STATE(9692)] = 467867,
  [SMALL_STATE(9693)] = 467903,
  [SMALL_STATE(9694)] = 467939,
  [SMALL_STATE(9695)] = 467975,
  [SMALL_STATE(9696)] = 468017,
  [SMALL_STATE(9697)] = 468069,
  [SMALL_STATE(9698)] = 468105,
  [SMALL_STATE(9699)] = 468141,
  [SMALL_STATE(9700)] = 468177,
  [SMALL_STATE(9701)] = 468213,
  [SMALL_STATE(9702)] = 468249,
  [SMALL_STATE(9703)] = 468287,
  [SMALL_STATE(9704)] = 468323,
  [SMALL_STATE(9705)] = 468359,
  [SMALL_STATE(9706)] = 468395,
  [SMALL_STATE(9707)] = 468431,
  [SMALL_STATE(9708)] = 468471,
  [SMALL_STATE(9709)] = 468523,
  [SMALL_STATE(9710)] = 468563,
  [SMALL_STATE(9711)] = 468599,
  [SMALL_STATE(9712)] = 468637,
  [SMALL_STATE(9713)] = 468673,
  [SMALL_STATE(9714)] = 468709,
  [SMALL_STATE(9715)] = 468745,
  [SMALL_STATE(9716)] = 468781,
  [SMALL_STATE(9717)] = 468817,
  [SMALL_STATE(9718)] = 468853,
  [SMALL_STATE(9719)] = 468889,
  [SMALL_STATE(9720)] = 468935,
  [SMALL_STATE(9721)] = 468975,
  [SMALL_STATE(9722)] = 469011,
  [SMALL_STATE(9723)] = 469047,
  [SMALL_STATE(9724)] = 469093,
  [SMALL_STATE(9725)] = 469129,
  [SMALL_STATE(9726)] = 469165,
  [SMALL_STATE(9727)] = 469201,
  [SMALL_STATE(9728)] = 469237,
  [SMALL_STATE(9729)] = 469273,
  [SMALL_STATE(9730)] = 469309,
  [SMALL_STATE(9731)] = 469345,
  [SMALL_STATE(9732)] = 469381,
  [SMALL_STATE(9733)] = 469416,
  [SMALL_STATE(9734)] = 469451,
  [SMALL_STATE(9735)] = 469486,
  [SMALL_STATE(9736)] = 469525,
  [SMALL_STATE(9737)] = 469560,
  [SMALL_STATE(9738)] = 469611,
  [SMALL_STATE(9739)] = 469646,
  [SMALL_STATE(9740)] = 469707,
  [SMALL_STATE(9741)] = 469742,
  [SMALL_STATE(9742)] = 469781,
  [SMALL_STATE(9743)] = 469816,
  [SMALL_STATE(9744)] = 469851,
  [SMALL_STATE(9745)] = 469886,
  [SMALL_STATE(9746)] = 469937,
  [SMALL_STATE(9747)] = 469972,
  [SMALL_STATE(9748)] = 470007,
  [SMALL_STATE(9749)] = 470042,
  [SMALL_STATE(9750)] = 470093,
  [SMALL_STATE(9751)] = 470132,
  [SMALL_STATE(9752)] = 470183,
  [SMALL_STATE(9753)] = 470234,
  [SMALL_STATE(9754)] = 470269,
  [SMALL_STATE(9755)] = 470310,
  [SMALL_STATE(9756)] = 470345,
  [SMALL_STATE(9757)] = 470384,
  [SMALL_STATE(9758)] = 470419,
  [SMALL_STATE(9759)] = 470454,
  [SMALL_STATE(9760)] = 470489,
  [SMALL_STATE(9761)] = 470524,
  [SMALL_STATE(9762)] = 470559,
  [SMALL_STATE(9763)] = 470594,
  [SMALL_STATE(9764)] = 470655,
  [SMALL_STATE(9765)] = 470690,
  [SMALL_STATE(9766)] = 470725,
  [SMALL_STATE(9767)] = 470764,
  [SMALL_STATE(9768)] = 470799,
  [SMALL_STATE(9769)] = 470834,
  [SMALL_STATE(9770)] = 470883,
  [SMALL_STATE(9771)] = 470934,
  [SMALL_STATE(9772)] = 470969,
  [SMALL_STATE(9773)] = 471020,
  [SMALL_STATE(9774)] = 471055,
  [SMALL_STATE(9775)] = 471090,
  [SMALL_STATE(9776)] = 471125,
  [SMALL_STATE(9777)] = 471164,
  [SMALL_STATE(9778)] = 471199,
  [SMALL_STATE(9779)] = 471234,
  [SMALL_STATE(9780)] = 471273,
  [SMALL_STATE(9781)] = 471308,
  [SMALL_STATE(9782)] = 471343,
  [SMALL_STATE(9783)] = 471378,
  [SMALL_STATE(9784)] = 471413,
  [SMALL_STATE(9785)] = 471448,
  [SMALL_STATE(9786)] = 471483,
  [SMALL_STATE(9787)] = 471522,
  [SMALL_STATE(9788)] = 471561,
  [SMALL_STATE(9789)] = 471596,
  [SMALL_STATE(9790)] = 471645,
  [SMALL_STATE(9791)] = 471680,
  [SMALL_STATE(9792)] = 471721,
  [SMALL_STATE(9793)] = 471760,
  [SMALL_STATE(9794)] = 471795,
  [SMALL_STATE(9795)] = 471846,
  [SMALL_STATE(9796)] = 471881,
  [SMALL_STATE(9797)] = 471920,
  [SMALL_STATE(9798)] = 471955,
  [SMALL_STATE(9799)] = 471990,
  [SMALL_STATE(9800)] = 472051,
  [SMALL_STATE(9801)] = 472086,
  [SMALL_STATE(9802)] = 472125,
  [SMALL_STATE(9803)] = 472160,
  [SMALL_STATE(9804)] = 472195,
  [SMALL_STATE(9805)] = 472246,
  [SMALL_STATE(9806)] = 472285,
  [SMALL_STATE(9807)] = 472320,
  [SMALL_STATE(9808)] = 472355,
  [SMALL_STATE(9809)] = 472392,
  [SMALL_STATE(9810)] = 472431,
  [SMALL_STATE(9811)] = 472466,
  [SMALL_STATE(9812)] = 472501,
  [SMALL_STATE(9813)] = 472546,
  [SMALL_STATE(9814)] = 472585,
  [SMALL_STATE(9815)] = 472620,
  [SMALL_STATE(9816)] = 472655,
  [SMALL_STATE(9817)] = 472690,
  [SMALL_STATE(9818)] = 472731,
  [SMALL_STATE(9819)] = 472766,
  [SMALL_STATE(9820)] = 472805,
  [SMALL_STATE(9821)] = 472840,
  [SMALL_STATE(9822)] = 472889,
  [SMALL_STATE(9823)] = 472924,
  [SMALL_STATE(9824)] = 472961,
  [SMALL_STATE(9825)] = 473000,
  [SMALL_STATE(9826)] = 473035,
  [SMALL_STATE(9827)] = 473096,
  [SMALL_STATE(9828)] = 473131,
  [SMALL_STATE(9829)] = 473188,
  [SMALL_STATE(9830)] = 473223,
  [SMALL_STATE(9831)] = 473258,
  [SMALL_STATE(9832)] = 473293,
  [SMALL_STATE(9833)] = 473344,
  [SMALL_STATE(9834)] = 473379,
  [SMALL_STATE(9835)] = 473418,
  [SMALL_STATE(9836)] = 473453,
  [SMALL_STATE(9837)] = 473488,
  [SMALL_STATE(9838)] = 473523,
  [SMALL_STATE(9839)] = 473558,
  [SMALL_STATE(9840)] = 473593,
  [SMALL_STATE(9841)] = 473632,
  [SMALL_STATE(9842)] = 473693,
  [SMALL_STATE(9843)] = 473728,
  [SMALL_STATE(9844)] = 473763,
  [SMALL_STATE(9845)] = 473798,
  [SMALL_STATE(9846)] = 473837,
  [SMALL_STATE(9847)] = 473872,
  [SMALL_STATE(9848)] = 473933,
  [SMALL_STATE(9849)] = 473968,
  [SMALL_STATE(9850)] = 474003,
  [SMALL_STATE(9851)] = 474038,
  [SMALL_STATE(9852)] = 474073,
  [SMALL_STATE(9853)] = 474108,
  [SMALL_STATE(9854)] = 474143,
  [SMALL_STATE(9855)] = 474182,
  [SMALL_STATE(9856)] = 474217,
  [SMALL_STATE(9857)] = 474252,
  [SMALL_STATE(9858)] = 474287,
  [SMALL_STATE(9859)] = 474322,
  [SMALL_STATE(9860)] = 474363,
  [SMALL_STATE(9861)] = 474398,
  [SMALL_STATE(9862)] = 474433,
  [SMALL_STATE(9863)] = 474468,
  [SMALL_STATE(9864)] = 474519,
  [SMALL_STATE(9865)] = 474554,
  [SMALL_STATE(9866)] = 474595,
  [SMALL_STATE(9867)] = 474630,
  [SMALL_STATE(9868)] = 474665,
  [SMALL_STATE(9869)] = 474700,
  [SMALL_STATE(9870)] = 474735,
  [SMALL_STATE(9871)] = 474770,
  [SMALL_STATE(9872)] = 474803,
  [SMALL_STATE(9873)] = 474854,
  [SMALL_STATE(9874)] = 474891,
  [SMALL_STATE(9875)] = 474926,
  [SMALL_STATE(9876)] = 474961,
  [SMALL_STATE(9877)] = 474996,
  [SMALL_STATE(9878)] = 475057,
  [SMALL_STATE(9879)] = 475110,
  [SMALL_STATE(9880)] = 475161,
  [SMALL_STATE(9881)] = 475212,
  [SMALL_STATE(9882)] = 475247,
  [SMALL_STATE(9883)] = 475282,
  [SMALL_STATE(9884)] = 475317,
  [SMALL_STATE(9885)] = 475352,
  [SMALL_STATE(9886)] = 475387,
  [SMALL_STATE(9887)] = 475422,
  [SMALL_STATE(9888)] = 475457,
  [SMALL_STATE(9889)] = 475492,
  [SMALL_STATE(9890)] = 475533,
  [SMALL_STATE(9891)] = 475568,
  [SMALL_STATE(9892)] = 475603,
  [SMALL_STATE(9893)] = 475638,
  [SMALL_STATE(9894)] = 475673,
  [SMALL_STATE(9895)] = 475714,
  [SMALL_STATE(9896)] = 475755,
  [SMALL_STATE(9897)] = 475790,
  [SMALL_STATE(9898)] = 475825,
  [SMALL_STATE(9899)] = 475860,
  [SMALL_STATE(9900)] = 475895,
  [SMALL_STATE(9901)] = 475930,
  [SMALL_STATE(9902)] = 475965,
  [SMALL_STATE(9903)] = 476026,
  [SMALL_STATE(9904)] = 476065,
  [SMALL_STATE(9905)] = 476126,
  [SMALL_STATE(9906)] = 476161,
  [SMALL_STATE(9907)] = 476196,
  [SMALL_STATE(9908)] = 476237,
  [SMALL_STATE(9909)] = 476272,
  [SMALL_STATE(9910)] = 476307,
  [SMALL_STATE(9911)] = 476342,
  [SMALL_STATE(9912)] = 476377,
  [SMALL_STATE(9913)] = 476416,
  [SMALL_STATE(9914)] = 476451,
  [SMALL_STATE(9915)] = 476486,
  [SMALL_STATE(9916)] = 476521,
  [SMALL_STATE(9917)] = 476570,
  [SMALL_STATE(9918)] = 476605,
  [SMALL_STATE(9919)] = 476640,
  [SMALL_STATE(9920)] = 476675,
  [SMALL_STATE(9921)] = 476726,
  [SMALL_STATE(9922)] = 476761,
  [SMALL_STATE(9923)] = 476796,
  [SMALL_STATE(9924)] = 476831,
  [SMALL_STATE(9925)] = 476866,
  [SMALL_STATE(9926)] = 476901,
  [SMALL_STATE(9927)] = 476936,
  [SMALL_STATE(9928)] = 476971,
  [SMALL_STATE(9929)] = 477006,
  [SMALL_STATE(9930)] = 477041,
  [SMALL_STATE(9931)] = 477076,
  [SMALL_STATE(9932)] = 477137,
  [SMALL_STATE(9933)] = 477172,
  [SMALL_STATE(9934)] = 477207,
  [SMALL_STATE(9935)] = 477242,
  [SMALL_STATE(9936)] = 477277,
  [SMALL_STATE(9937)] = 477312,
  [SMALL_STATE(9938)] = 477347,
  [SMALL_STATE(9939)] = 477382,
  [SMALL_STATE(9940)] = 477421,
  [SMALL_STATE(9941)] = 477456,
  [SMALL_STATE(9942)] = 477491,
  [SMALL_STATE(9943)] = 477526,
  [SMALL_STATE(9944)] = 477561,
  [SMALL_STATE(9945)] = 477596,
  [SMALL_STATE(9946)] = 477631,
  [SMALL_STATE(9947)] = 477666,
  [SMALL_STATE(9948)] = 477701,
  [SMALL_STATE(9949)] = 477736,
  [SMALL_STATE(9950)] = 477771,
  [SMALL_STATE(9951)] = 477806,
  [SMALL_STATE(9952)] = 477847,
  [SMALL_STATE(9953)] = 477882,
  [SMALL_STATE(9954)] = 477917,
  [SMALL_STATE(9955)] = 477978,
  [SMALL_STATE(9956)] = 478013,
  [SMALL_STATE(9957)] = 478048,
  [SMALL_STATE(9958)] = 478083,
  [SMALL_STATE(9959)] = 478118,
  [SMALL_STATE(9960)] = 478153,
  [SMALL_STATE(9961)] = 478188,
  [SMALL_STATE(9962)] = 478223,
  [SMALL_STATE(9963)] = 478268,
  [SMALL_STATE(9964)] = 478329,
  [SMALL_STATE(9965)] = 478378,
  [SMALL_STATE(9966)] = 478413,
  [SMALL_STATE(9967)] = 478448,
  [SMALL_STATE(9968)] = 478483,
  [SMALL_STATE(9969)] = 478542,
  [SMALL_STATE(9970)] = 478581,
  [SMALL_STATE(9971)] = 478616,
  [SMALL_STATE(9972)] = 478651,
  [SMALL_STATE(9973)] = 478700,
  [SMALL_STATE(9974)] = 478735,
  [SMALL_STATE(9975)] = 478770,
  [SMALL_STATE(9976)] = 478811,
  [SMALL_STATE(9977)] = 478846,
  [SMALL_STATE(9978)] = 478907,
  [SMALL_STATE(9979)] = 478942,
  [SMALL_STATE(9980)] = 478983,
  [SMALL_STATE(9981)] = 479018,
  [SMALL_STATE(9982)] = 479053,
  [SMALL_STATE(9983)] = 479088,
  [SMALL_STATE(9984)] = 479123,
  [SMALL_STATE(9985)] = 479162,
  [SMALL_STATE(9986)] = 479201,
  [SMALL_STATE(9987)] = 479236,
  [SMALL_STATE(9988)] = 479271,
  [SMALL_STATE(9989)] = 479306,
  [SMALL_STATE(9990)] = 479357,
  [SMALL_STATE(9991)] = 479418,
  [SMALL_STATE(9992)] = 479457,
  [SMALL_STATE(9993)] = 479492,
  [SMALL_STATE(9994)] = 479527,
  [SMALL_STATE(9995)] = 479566,
  [SMALL_STATE(9996)] = 479601,
  [SMALL_STATE(9997)] = 479636,
  [SMALL_STATE(9998)] = 479671,
  [SMALL_STATE(9999)] = 479706,
  [SMALL_STATE(10000)] = 479741,
  [SMALL_STATE(10001)] = 479776,
  [SMALL_STATE(10002)] = 479811,
  [SMALL_STATE(10003)] = 479846,
  [SMALL_STATE(10004)] = 479881,
  [SMALL_STATE(10005)] = 479916,
  [SMALL_STATE(10006)] = 479951,
  [SMALL_STATE(10007)] = 479986,
  [SMALL_STATE(10008)] = 480021,
  [SMALL_STATE(10009)] = 480056,
  [SMALL_STATE(10010)] = 480091,
  [SMALL_STATE(10011)] = 480126,
  [SMALL_STATE(10012)] = 480175,
  [SMALL_STATE(10013)] = 480210,
  [SMALL_STATE(10014)] = 480245,
  [SMALL_STATE(10015)] = 480280,
  [SMALL_STATE(10016)] = 480319,
  [SMALL_STATE(10017)] = 480358,
  [SMALL_STATE(10018)] = 480393,
  [SMALL_STATE(10019)] = 480428,
  [SMALL_STATE(10020)] = 480489,
  [SMALL_STATE(10021)] = 480550,
  [SMALL_STATE(10022)] = 480585,
  [SMALL_STATE(10023)] = 480620,
  [SMALL_STATE(10024)] = 480655,
  [SMALL_STATE(10025)] = 480716,
  [SMALL_STATE(10026)] = 480751,
  [SMALL_STATE(10027)] = 480786,
  [SMALL_STATE(10028)] = 480821,
  [SMALL_STATE(10029)] = 480856,
  [SMALL_STATE(10030)] = 480891,
  [SMALL_STATE(10031)] = 480926,
  [SMALL_STATE(10032)] = 480961,
  [SMALL_STATE(10033)] = 480996,
  [SMALL_STATE(10034)] = 481031,
  [SMALL_STATE(10035)] = 481066,
  [SMALL_STATE(10036)] = 481101,
  [SMALL_STATE(10037)] = 481136,
  [SMALL_STATE(10038)] = 481171,
  [SMALL_STATE(10039)] = 481206,
  [SMALL_STATE(10040)] = 481245,
  [SMALL_STATE(10041)] = 481280,
  [SMALL_STATE(10042)] = 481315,
  [SMALL_STATE(10043)] = 481350,
  [SMALL_STATE(10044)] = 481385,
  [SMALL_STATE(10045)] = 481428,
  [SMALL_STATE(10046)] = 481463,
  [SMALL_STATE(10047)] = 481498,
  [SMALL_STATE(10048)] = 481535,
  [SMALL_STATE(10049)] = 481570,
  [SMALL_STATE(10050)] = 481605,
  [SMALL_STATE(10051)] = 481640,
  [SMALL_STATE(10052)] = 481675,
  [SMALL_STATE(10053)] = 481710,
  [SMALL_STATE(10054)] = 481749,
  [SMALL_STATE(10055)] = 481784,
  [SMALL_STATE(10056)] = 481819,
  [SMALL_STATE(10057)] = 481860,
  [SMALL_STATE(10058)] = 481895,
  [SMALL_STATE(10059)] = 481932,
  [SMALL_STATE(10060)] = 481967,
  [SMALL_STATE(10061)] = 482002,
  [SMALL_STATE(10062)] = 482037,
  [SMALL_STATE(10063)] = 482072,
  [SMALL_STATE(10064)] = 482107,
  [SMALL_STATE(10065)] = 482142,
  [SMALL_STATE(10066)] = 482181,
  [SMALL_STATE(10067)] = 482218,
  [SMALL_STATE(10068)] = 482253,
  [SMALL_STATE(10069)] = 482288,
  [SMALL_STATE(10070)] = 482323,
  [SMALL_STATE(10071)] = 482358,
  [SMALL_STATE(10072)] = 482393,
  [SMALL_STATE(10073)] = 482428,
  [SMALL_STATE(10074)] = 482469,
  [SMALL_STATE(10075)] = 482530,
  [SMALL_STATE(10076)] = 482571,
  [SMALL_STATE(10077)] = 482606,
  [SMALL_STATE(10078)] = 482641,
  [SMALL_STATE(10079)] = 482676,
  [SMALL_STATE(10080)] = 482711,
  [SMALL_STATE(10081)] = 482746,
  [SMALL_STATE(10082)] = 482781,
  [SMALL_STATE(10083)] = 482816,
  [SMALL_STATE(10084)] = 482851,
  [SMALL_STATE(10085)] = 482886,
  [SMALL_STATE(10086)] = 482921,
  [SMALL_STATE(10087)] = 482956,
  [SMALL_STATE(10088)] = 482991,
  [SMALL_STATE(10089)] = 483030,
  [SMALL_STATE(10090)] = 483065,
  [SMALL_STATE(10091)] = 483100,
  [SMALL_STATE(10092)] = 483135,
  [SMALL_STATE(10093)] = 483170,
  [SMALL_STATE(10094)] = 483211,
  [SMALL_STATE(10095)] = 483270,
  [SMALL_STATE(10096)] = 483319,
  [SMALL_STATE(10097)] = 483354,
  [SMALL_STATE(10098)] = 483405,
  [SMALL_STATE(10099)] = 483446,
  [SMALL_STATE(10100)] = 483481,
  [SMALL_STATE(10101)] = 483516,
  [SMALL_STATE(10102)] = 483555,
  [SMALL_STATE(10103)] = 483590,
  [SMALL_STATE(10104)] = 483625,
  [SMALL_STATE(10105)] = 483660,
  [SMALL_STATE(10106)] = 483699,
  [SMALL_STATE(10107)] = 483734,
  [SMALL_STATE(10108)] = 483769,
  [SMALL_STATE(10109)] = 483810,
  [SMALL_STATE(10110)] = 483845,
  [SMALL_STATE(10111)] = 483884,
  [SMALL_STATE(10112)] = 483925,
  [SMALL_STATE(10113)] = 483960,
  [SMALL_STATE(10114)] = 483999,
  [SMALL_STATE(10115)] = 484034,
  [SMALL_STATE(10116)] = 484069,
  [SMALL_STATE(10117)] = 484108,
  [SMALL_STATE(10118)] = 484143,
  [SMALL_STATE(10119)] = 484178,
  [SMALL_STATE(10120)] = 484213,
  [SMALL_STATE(10121)] = 484248,
  [SMALL_STATE(10122)] = 484283,
  [SMALL_STATE(10123)] = 484318,
  [SMALL_STATE(10124)] = 484353,
  [SMALL_STATE(10125)] = 484388,
  [SMALL_STATE(10126)] = 484423,
  [SMALL_STATE(10127)] = 484462,
  [SMALL_STATE(10128)] = 484514,
  [SMALL_STATE(10129)] = 484548,
  [SMALL_STATE(10130)] = 484588,
  [SMALL_STATE(10131)] = 484648,
  [SMALL_STATE(10132)] = 484700,
  [SMALL_STATE(10133)] = 484734,
  [SMALL_STATE(10134)] = 484768,
  [SMALL_STATE(10135)] = 484804,
  [SMALL_STATE(10136)] = 484840,
  [SMALL_STATE(10137)] = 484876,
  [SMALL_STATE(10138)] = 484912,
  [SMALL_STATE(10139)] = 484946,
  [SMALL_STATE(10140)] = 484980,
  [SMALL_STATE(10141)] = 485014,
  [SMALL_STATE(10142)] = 485048,
  [SMALL_STATE(10143)] = 485082,
  [SMALL_STATE(10144)] = 485138,
  [SMALL_STATE(10145)] = 485172,
  [SMALL_STATE(10146)] = 485206,
  [SMALL_STATE(10147)] = 485242,
  [SMALL_STATE(10148)] = 485278,
  [SMALL_STATE(10149)] = 485312,
  [SMALL_STATE(10150)] = 485346,
  [SMALL_STATE(10151)] = 485382,
  [SMALL_STATE(10152)] = 485416,
  [SMALL_STATE(10153)] = 485450,
  [SMALL_STATE(10154)] = 485506,
  [SMALL_STATE(10155)] = 485540,
  [SMALL_STATE(10156)] = 485592,
  [SMALL_STATE(10157)] = 485626,
  [SMALL_STATE(10158)] = 485660,
  [SMALL_STATE(10159)] = 485700,
  [SMALL_STATE(10160)] = 485740,
  [SMALL_STATE(10161)] = 485792,
  [SMALL_STATE(10162)] = 485844,
  [SMALL_STATE(10163)] = 485878,
  [SMALL_STATE(10164)] = 485912,
  [SMALL_STATE(10165)] = 485946,
  [SMALL_STATE(10166)] = 485980,
  [SMALL_STATE(10167)] = 486014,
  [SMALL_STATE(10168)] = 486048,
  [SMALL_STATE(10169)] = 486082,
  [SMALL_STATE(10170)] = 486116,
  [SMALL_STATE(10171)] = 486150,
  [SMALL_STATE(10172)] = 486184,
  [SMALL_STATE(10173)] = 486240,
  [SMALL_STATE(10174)] = 486280,
  [SMALL_STATE(10175)] = 486330,
  [SMALL_STATE(10176)] = 486364,
  [SMALL_STATE(10177)] = 486398,
  [SMALL_STATE(10178)] = 486432,
  [SMALL_STATE(10179)] = 486466,
  [SMALL_STATE(10180)] = 486516,
  [SMALL_STATE(10181)] = 486550,
  [SMALL_STATE(10182)] = 486584,
  [SMALL_STATE(10183)] = 486618,
  [SMALL_STATE(10184)] = 486656,
  [SMALL_STATE(10185)] = 486690,
  [SMALL_STATE(10186)] = 486724,
  [SMALL_STATE(10187)] = 486758,
  [SMALL_STATE(10188)] = 486792,
  [SMALL_STATE(10189)] = 486826,
  [SMALL_STATE(10190)] = 486878,
  [SMALL_STATE(10191)] = 486912,
  [SMALL_STATE(10192)] = 486950,
  [SMALL_STATE(10193)] = 487002,
  [SMALL_STATE(10194)] = 487036,
  [SMALL_STATE(10195)] = 487070,
  [SMALL_STATE(10196)] = 487106,
  [SMALL_STATE(10197)] = 487140,
  [SMALL_STATE(10198)] = 487174,
  [SMALL_STATE(10199)] = 487208,
  [SMALL_STATE(10200)] = 487242,
  [SMALL_STATE(10201)] = 487294,
  [SMALL_STATE(10202)] = 487328,
  [SMALL_STATE(10203)] = 487368,
  [SMALL_STATE(10204)] = 487402,
  [SMALL_STATE(10205)] = 487436,
  [SMALL_STATE(10206)] = 487470,
  [SMALL_STATE(10207)] = 487506,
  [SMALL_STATE(10208)] = 487540,
  [SMALL_STATE(10209)] = 487592,
  [SMALL_STATE(10210)] = 487626,
  [SMALL_STATE(10211)] = 487662,
  [SMALL_STATE(10212)] = 487696,
  [SMALL_STATE(10213)] = 487730,
  [SMALL_STATE(10214)] = 487764,
  [SMALL_STATE(10215)] = 487804,
  [SMALL_STATE(10216)] = 487838,
  [SMALL_STATE(10217)] = 487872,
  [SMALL_STATE(10218)] = 487922,
  [SMALL_STATE(10219)] = 487974,
  [SMALL_STATE(10220)] = 488010,
  [SMALL_STATE(10221)] = 488044,
  [SMALL_STATE(10222)] = 488078,
  [SMALL_STATE(10223)] = 488122,
  [SMALL_STATE(10224)] = 488156,
  [SMALL_STATE(10225)] = 488194,
  [SMALL_STATE(10226)] = 488234,
  [SMALL_STATE(10227)] = 488274,
  [SMALL_STATE(10228)] = 488308,
  [SMALL_STATE(10229)] = 488342,
  [SMALL_STATE(10230)] = 488376,
  [SMALL_STATE(10231)] = 488424,
  [SMALL_STATE(10232)] = 488458,
  [SMALL_STATE(10233)] = 488506,
  [SMALL_STATE(10234)] = 488542,
  [SMALL_STATE(10235)] = 488580,
  [SMALL_STATE(10236)] = 488614,
  [SMALL_STATE(10237)] = 488648,
  [SMALL_STATE(10238)] = 488682,
  [SMALL_STATE(10239)] = 488716,
  [SMALL_STATE(10240)] = 488750,
  [SMALL_STATE(10241)] = 488784,
  [SMALL_STATE(10242)] = 488818,
  [SMALL_STATE(10243)] = 488852,
  [SMALL_STATE(10244)] = 488904,
  [SMALL_STATE(10245)] = 488938,
  [SMALL_STATE(10246)] = 488994,
  [SMALL_STATE(10247)] = 489034,
  [SMALL_STATE(10248)] = 489082,
  [SMALL_STATE(10249)] = 489116,
  [SMALL_STATE(10250)] = 489168,
  [SMALL_STATE(10251)] = 489202,
  [SMALL_STATE(10252)] = 489236,
  [SMALL_STATE(10253)] = 489270,
  [SMALL_STATE(10254)] = 489322,
  [SMALL_STATE(10255)] = 489356,
  [SMALL_STATE(10256)] = 489392,
  [SMALL_STATE(10257)] = 489426,
  [SMALL_STATE(10258)] = 489460,
  [SMALL_STATE(10259)] = 489494,
  [SMALL_STATE(10260)] = 489528,
  [SMALL_STATE(10261)] = 489562,
  [SMALL_STATE(10262)] = 489616,
  [SMALL_STATE(10263)] = 489650,
  [SMALL_STATE(10264)] = 489684,
  [SMALL_STATE(10265)] = 489718,
  [SMALL_STATE(10266)] = 489756,
  [SMALL_STATE(10267)] = 489790,
  [SMALL_STATE(10268)] = 489842,
  [SMALL_STATE(10269)] = 489876,
  [SMALL_STATE(10270)] = 489910,
  [SMALL_STATE(10271)] = 489946,
  [SMALL_STATE(10272)] = 489980,
  [SMALL_STATE(10273)] = 490014,
  [SMALL_STATE(10274)] = 490066,
  [SMALL_STATE(10275)] = 490104,
  [SMALL_STATE(10276)] = 490140,
  [SMALL_STATE(10277)] = 490192,
  [SMALL_STATE(10278)] = 490226,
  [SMALL_STATE(10279)] = 490266,
  [SMALL_STATE(10280)] = 490300,
  [SMALL_STATE(10281)] = 490334,
  [SMALL_STATE(10282)] = 490386,
  [SMALL_STATE(10283)] = 490442,
  [SMALL_STATE(10284)] = 490480,
  [SMALL_STATE(10285)] = 490532,
  [SMALL_STATE(10286)] = 490566,
  [SMALL_STATE(10287)] = 490602,
  [SMALL_STATE(10288)] = 490640,
  [SMALL_STATE(10289)] = 490680,
  [SMALL_STATE(10290)] = 490714,
  [SMALL_STATE(10291)] = 490748,
  [SMALL_STATE(10292)] = 490804,
  [SMALL_STATE(10293)] = 490840,
  [SMALL_STATE(10294)] = 490874,
  [SMALL_STATE(10295)] = 490926,
  [SMALL_STATE(10296)] = 490960,
  [SMALL_STATE(10297)] = 490996,
  [SMALL_STATE(10298)] = 491030,
  [SMALL_STATE(10299)] = 491090,
  [SMALL_STATE(10300)] = 491124,
  [SMALL_STATE(10301)] = 491158,
  [SMALL_STATE(10302)] = 491192,
  [SMALL_STATE(10303)] = 491242,
  [SMALL_STATE(10304)] = 491292,
  [SMALL_STATE(10305)] = 491344,
  [SMALL_STATE(10306)] = 491382,
  [SMALL_STATE(10307)] = 491416,
  [SMALL_STATE(10308)] = 491466,
  [SMALL_STATE(10309)] = 491500,
  [SMALL_STATE(10310)] = 491534,
  [SMALL_STATE(10311)] = 491568,
  [SMALL_STATE(10312)] = 491602,
  [SMALL_STATE(10313)] = 491636,
  [SMALL_STATE(10314)] = 491670,
  [SMALL_STATE(10315)] = 491718,
  [SMALL_STATE(10316)] = 491754,
  [SMALL_STATE(10317)] = 491788,
  [SMALL_STATE(10318)] = 491840,
  [SMALL_STATE(10319)] = 491892,
  [SMALL_STATE(10320)] = 491926,
  [SMALL_STATE(10321)] = 491960,
  [SMALL_STATE(10322)] = 491996,
  [SMALL_STATE(10323)] = 492030,
  [SMALL_STATE(10324)] = 492082,
  [SMALL_STATE(10325)] = 492126,
  [SMALL_STATE(10326)] = 492160,
  [SMALL_STATE(10327)] = 492194,
  [SMALL_STATE(10328)] = 492228,
  [SMALL_STATE(10329)] = 492262,
  [SMALL_STATE(10330)] = 492296,
  [SMALL_STATE(10331)] = 492330,
  [SMALL_STATE(10332)] = 492380,
  [SMALL_STATE(10333)] = 492414,
  [SMALL_STATE(10334)] = 492448,
  [SMALL_STATE(10335)] = 492484,
  [SMALL_STATE(10336)] = 492518,
  [SMALL_STATE(10337)] = 492570,
  [SMALL_STATE(10338)] = 492604,
  [SMALL_STATE(10339)] = 492638,
  [SMALL_STATE(10340)] = 492672,
  [SMALL_STATE(10341)] = 492706,
  [SMALL_STATE(10342)] = 492740,
  [SMALL_STATE(10343)] = 492788,
  [SMALL_STATE(10344)] = 492822,
  [SMALL_STATE(10345)] = 492856,
  [SMALL_STATE(10346)] = 492890,
  [SMALL_STATE(10347)] = 492924,
  [SMALL_STATE(10348)] = 492976,
  [SMALL_STATE(10349)] = 493010,
  [SMALL_STATE(10350)] = 493044,
  [SMALL_STATE(10351)] = 493078,
  [SMALL_STATE(10352)] = 493128,
  [SMALL_STATE(10353)] = 493162,
  [SMALL_STATE(10354)] = 493222,
  [SMALL_STATE(10355)] = 493256,
  [SMALL_STATE(10356)] = 493290,
  [SMALL_STATE(10357)] = 493330,
  [SMALL_STATE(10358)] = 493364,
  [SMALL_STATE(10359)] = 493398,
  [SMALL_STATE(10360)] = 493432,
  [SMALL_STATE(10361)] = 493476,
  [SMALL_STATE(10362)] = 493510,
  [SMALL_STATE(10363)] = 493544,
  [SMALL_STATE(10364)] = 493578,
  [SMALL_STATE(10365)] = 493628,
  [SMALL_STATE(10366)] = 493662,
  [SMALL_STATE(10367)] = 493696,
  [SMALL_STATE(10368)] = 493746,
  [SMALL_STATE(10369)] = 493786,
  [SMALL_STATE(10370)] = 493824,
  [SMALL_STATE(10371)] = 493858,
  [SMALL_STATE(10372)] = 493894,
  [SMALL_STATE(10373)] = 493928,
  [SMALL_STATE(10374)] = 493962,
  [SMALL_STATE(10375)] = 493996,
  [SMALL_STATE(10376)] = 494030,
  [SMALL_STATE(10377)] = 494064,
  [SMALL_STATE(10378)] = 494100,
  [SMALL_STATE(10379)] = 494134,
  [SMALL_STATE(10380)] = 494168,
  [SMALL_STATE(10381)] = 494202,
  [SMALL_STATE(10382)] = 494236,
  [SMALL_STATE(10383)] = 494270,
  [SMALL_STATE(10384)] = 494304,
  [SMALL_STATE(10385)] = 494354,
  [SMALL_STATE(10386)] = 494388,
  [SMALL_STATE(10387)] = 494438,
  [SMALL_STATE(10388)] = 494472,
  [SMALL_STATE(10389)] = 494506,
  [SMALL_STATE(10390)] = 494540,
  [SMALL_STATE(10391)] = 494574,
  [SMALL_STATE(10392)] = 494626,
  [SMALL_STATE(10393)] = 494660,
  [SMALL_STATE(10394)] = 494694,
  [SMALL_STATE(10395)] = 494732,
  [SMALL_STATE(10396)] = 494768,
  [SMALL_STATE(10397)] = 494802,
  [SMALL_STATE(10398)] = 494836,
  [SMALL_STATE(10399)] = 494870,
  [SMALL_STATE(10400)] = 494904,
  [SMALL_STATE(10401)] = 494938,
  [SMALL_STATE(10402)] = 494972,
  [SMALL_STATE(10403)] = 495006,
  [SMALL_STATE(10404)] = 495058,
  [SMALL_STATE(10405)] = 495114,
  [SMALL_STATE(10406)] = 495150,
  [SMALL_STATE(10407)] = 495186,
  [SMALL_STATE(10408)] = 495238,
  [SMALL_STATE(10409)] = 495288,
  [SMALL_STATE(10410)] = 495322,
  [SMALL_STATE(10411)] = 495356,
  [SMALL_STATE(10412)] = 495390,
  [SMALL_STATE(10413)] = 495424,
  [SMALL_STATE(10414)] = 495474,
  [SMALL_STATE(10415)] = 495524,
  [SMALL_STATE(10416)] = 495580,
  [SMALL_STATE(10417)] = 495628,
  [SMALL_STATE(10418)] = 495662,
  [SMALL_STATE(10419)] = 495696,
  [SMALL_STATE(10420)] = 495730,
  [SMALL_STATE(10421)] = 495764,
  [SMALL_STATE(10422)] = 495798,
  [SMALL_STATE(10423)] = 495832,
  [SMALL_STATE(10424)] = 495866,
  [SMALL_STATE(10425)] = 495906,
  [SMALL_STATE(10426)] = 495942,
  [SMALL_STATE(10427)] = 495976,
  [SMALL_STATE(10428)] = 496014,
  [SMALL_STATE(10429)] = 496048,
  [SMALL_STATE(10430)] = 496082,
  [SMALL_STATE(10431)] = 496132,
  [SMALL_STATE(10432)] = 496168,
  [SMALL_STATE(10433)] = 496202,
  [SMALL_STATE(10434)] = 496252,
  [SMALL_STATE(10435)] = 496304,
  [SMALL_STATE(10436)] = 496338,
  [SMALL_STATE(10437)] = 496378,
  [SMALL_STATE(10438)] = 496412,
  [SMALL_STATE(10439)] = 496450,
  [SMALL_STATE(10440)] = 496484,
  [SMALL_STATE(10441)] = 496530,
  [SMALL_STATE(10442)] = 496564,
  [SMALL_STATE(10443)] = 496598,
  [SMALL_STATE(10444)] = 496632,
  [SMALL_STATE(10445)] = 496669,
  [SMALL_STATE(10446)] = 496702,
  [SMALL_STATE(10447)] = 496737,
  [SMALL_STATE(10448)] = 496770,
  [SMALL_STATE(10449)] = 496803,
  [SMALL_STATE(10450)] = 496842,
  [SMALL_STATE(10451)] = 496881,
  [SMALL_STATE(10452)] = 496914,
  [SMALL_STATE(10453)] = 496953,
  [SMALL_STATE(10454)] = 496986,
  [SMALL_STATE(10455)] = 497019,
  [SMALL_STATE(10456)] = 497058,
  [SMALL_STATE(10457)] = 497105,
  [SMALL_STATE(10458)] = 497144,
  [SMALL_STATE(10459)] = 497177,
  [SMALL_STATE(10460)] = 497214,
  [SMALL_STATE(10461)] = 497247,
  [SMALL_STATE(10462)] = 497294,
  [SMALL_STATE(10463)] = 497327,
  [SMALL_STATE(10464)] = 497374,
  [SMALL_STATE(10465)] = 497407,
  [SMALL_STATE(10466)] = 497440,
  [SMALL_STATE(10467)] = 497473,
  [SMALL_STATE(10468)] = 497506,
  [SMALL_STATE(10469)] = 497539,
  [SMALL_STATE(10470)] = 497572,
  [SMALL_STATE(10471)] = 497627,
  [SMALL_STATE(10472)] = 497660,
  [SMALL_STATE(10473)] = 497715,
  [SMALL_STATE(10474)] = 497748,
  [SMALL_STATE(10475)] = 497795,
  [SMALL_STATE(10476)] = 497828,
  [SMALL_STATE(10477)] = 497861,
  [SMALL_STATE(10478)] = 497894,
  [SMALL_STATE(10479)] = 497927,
  [SMALL_STATE(10480)] = 497964,
  [SMALL_STATE(10481)] = 497997,
  [SMALL_STATE(10482)] = 498036,
  [SMALL_STATE(10483)] = 498083,
  [SMALL_STATE(10484)] = 498122,
  [SMALL_STATE(10485)] = 498155,
  [SMALL_STATE(10486)] = 498188,
  [SMALL_STATE(10487)] = 498225,
  [SMALL_STATE(10488)] = 498258,
  [SMALL_STATE(10489)] = 498291,
  [SMALL_STATE(10490)] = 498324,
  [SMALL_STATE(10491)] = 498357,
  [SMALL_STATE(10492)] = 498390,
  [SMALL_STATE(10493)] = 498437,
  [SMALL_STATE(10494)] = 498470,
  [SMALL_STATE(10495)] = 498509,
  [SMALL_STATE(10496)] = 498542,
  [SMALL_STATE(10497)] = 498575,
  [SMALL_STATE(10498)] = 498630,
  [SMALL_STATE(10499)] = 498663,
  [SMALL_STATE(10500)] = 498696,
  [SMALL_STATE(10501)] = 498729,
  [SMALL_STATE(10502)] = 498762,
  [SMALL_STATE(10503)] = 498795,
  [SMALL_STATE(10504)] = 498828,
  [SMALL_STATE(10505)] = 498861,
  [SMALL_STATE(10506)] = 498894,
  [SMALL_STATE(10507)] = 498927,
  [SMALL_STATE(10508)] = 498960,
  [SMALL_STATE(10509)] = 498993,
  [SMALL_STATE(10510)] = 499048,
  [SMALL_STATE(10511)] = 499081,
  [SMALL_STATE(10512)] = 499114,
  [SMALL_STATE(10513)] = 499147,
  [SMALL_STATE(10514)] = 499180,
  [SMALL_STATE(10515)] = 499213,
  [SMALL_STATE(10516)] = 499246,
  [SMALL_STATE(10517)] = 499293,
  [SMALL_STATE(10518)] = 499326,
  [SMALL_STATE(10519)] = 499359,
  [SMALL_STATE(10520)] = 499392,
  [SMALL_STATE(10521)] = 499425,
  [SMALL_STATE(10522)] = 499458,
  [SMALL_STATE(10523)] = 499501,
  [SMALL_STATE(10524)] = 499556,
  [SMALL_STATE(10525)] = 499611,
  [SMALL_STATE(10526)] = 499658,
  [SMALL_STATE(10527)] = 499713,
  [SMALL_STATE(10528)] = 499746,
  [SMALL_STATE(10529)] = 499779,
  [SMALL_STATE(10530)] = 499828,
  [SMALL_STATE(10531)] = 499861,
  [SMALL_STATE(10532)] = 499912,
  [SMALL_STATE(10533)] = 499967,
  [SMALL_STATE(10534)] = 500004,
  [SMALL_STATE(10535)] = 500037,
  [SMALL_STATE(10536)] = 500084,
  [SMALL_STATE(10537)] = 500133,
  [SMALL_STATE(10538)] = 500166,
  [SMALL_STATE(10539)] = 500199,
  [SMALL_STATE(10540)] = 500242,
  [SMALL_STATE(10541)] = 500279,
  [SMALL_STATE(10542)] = 500312,
  [SMALL_STATE(10543)] = 500363,
  [SMALL_STATE(10544)] = 500400,
  [SMALL_STATE(10545)] = 500447,
  [SMALL_STATE(10546)] = 500480,
  [SMALL_STATE(10547)] = 500513,
  [SMALL_STATE(10548)] = 500546,
  [SMALL_STATE(10549)] = 500579,
  [SMALL_STATE(10550)] = 500612,
  [SMALL_STATE(10551)] = 500645,
  [SMALL_STATE(10552)] = 500678,
  [SMALL_STATE(10553)] = 500711,
  [SMALL_STATE(10554)] = 500744,
  [SMALL_STATE(10555)] = 500777,
  [SMALL_STATE(10556)] = 500826,
  [SMALL_STATE(10557)] = 500859,
  [SMALL_STATE(10558)] = 500908,
  [SMALL_STATE(10559)] = 500941,
  [SMALL_STATE(10560)] = 500974,
  [SMALL_STATE(10561)] = 501007,
  [SMALL_STATE(10562)] = 501040,
  [SMALL_STATE(10563)] = 501087,
  [SMALL_STATE(10564)] = 501120,
  [SMALL_STATE(10565)] = 501167,
  [SMALL_STATE(10566)] = 501200,
  [SMALL_STATE(10567)] = 501255,
  [SMALL_STATE(10568)] = 501288,
  [SMALL_STATE(10569)] = 501321,
  [SMALL_STATE(10570)] = 501354,
  [SMALL_STATE(10571)] = 501387,
  [SMALL_STATE(10572)] = 501420,
  [SMALL_STATE(10573)] = 501453,
  [SMALL_STATE(10574)] = 501486,
  [SMALL_STATE(10575)] = 501519,
  [SMALL_STATE(10576)] = 501552,
  [SMALL_STATE(10577)] = 501585,
  [SMALL_STATE(10578)] = 501636,
  [SMALL_STATE(10579)] = 501669,
  [SMALL_STATE(10580)] = 501724,
  [SMALL_STATE(10581)] = 501757,
  [SMALL_STATE(10582)] = 501812,
  [SMALL_STATE(10583)] = 501861,
  [SMALL_STATE(10584)] = 501916,
  [SMALL_STATE(10585)] = 501955,
  [SMALL_STATE(10586)] = 501988,
  [SMALL_STATE(10587)] = 502037,
  [SMALL_STATE(10588)] = 502070,
  [SMALL_STATE(10589)] = 502103,
  [SMALL_STATE(10590)] = 502136,
  [SMALL_STATE(10591)] = 502169,
  [SMALL_STATE(10592)] = 502208,
  [SMALL_STATE(10593)] = 502257,
  [SMALL_STATE(10594)] = 502306,
  [SMALL_STATE(10595)] = 502339,
  [SMALL_STATE(10596)] = 502372,
  [SMALL_STATE(10597)] = 502405,
  [SMALL_STATE(10598)] = 502440,
  [SMALL_STATE(10599)] = 502489,
  [SMALL_STATE(10600)] = 502528,
  [SMALL_STATE(10601)] = 502583,
  [SMALL_STATE(10602)] = 502616,
  [SMALL_STATE(10603)] = 502649,
  [SMALL_STATE(10604)] = 502704,
  [SMALL_STATE(10605)] = 502743,
  [SMALL_STATE(10606)] = 502780,
  [SMALL_STATE(10607)] = 502813,
  [SMALL_STATE(10608)] = 502846,
  [SMALL_STATE(10609)] = 502885,
  [SMALL_STATE(10610)] = 502918,
  [SMALL_STATE(10611)] = 502951,
  [SMALL_STATE(10612)] = 502998,
  [SMALL_STATE(10613)] = 503031,
  [SMALL_STATE(10614)] = 503068,
  [SMALL_STATE(10615)] = 503117,
  [SMALL_STATE(10616)] = 503154,
  [SMALL_STATE(10617)] = 503187,
  [SMALL_STATE(10618)] = 503236,
  [SMALL_STATE(10619)] = 503269,
  [SMALL_STATE(10620)] = 503316,
  [SMALL_STATE(10621)] = 503351,
  [SMALL_STATE(10622)] = 503398,
  [SMALL_STATE(10623)] = 503431,
  [SMALL_STATE(10624)] = 503478,
  [SMALL_STATE(10625)] = 503513,
  [SMALL_STATE(10626)] = 503546,
  [SMALL_STATE(10627)] = 503579,
  [SMALL_STATE(10628)] = 503612,
  [SMALL_STATE(10629)] = 503645,
  [SMALL_STATE(10630)] = 503678,
  [SMALL_STATE(10631)] = 503725,
  [SMALL_STATE(10632)] = 503772,
  [SMALL_STATE(10633)] = 503827,
  [SMALL_STATE(10634)] = 503860,
  [SMALL_STATE(10635)] = 503893,
  [SMALL_STATE(10636)] = 503926,
  [SMALL_STATE(10637)] = 503973,
  [SMALL_STATE(10638)] = 504006,
  [SMALL_STATE(10639)] = 504039,
  [SMALL_STATE(10640)] = 504072,
  [SMALL_STATE(10641)] = 504105,
  [SMALL_STATE(10642)] = 504138,
  [SMALL_STATE(10643)] = 504171,
  [SMALL_STATE(10644)] = 504208,
  [SMALL_STATE(10645)] = 504241,
  [SMALL_STATE(10646)] = 504274,
  [SMALL_STATE(10647)] = 504307,
  [SMALL_STATE(10648)] = 504340,
  [SMALL_STATE(10649)] = 504373,
  [SMALL_STATE(10650)] = 504406,
  [SMALL_STATE(10651)] = 504439,
  [SMALL_STATE(10652)] = 504476,
  [SMALL_STATE(10653)] = 504513,
  [SMALL_STATE(10654)] = 504550,
  [SMALL_STATE(10655)] = 504583,
  [SMALL_STATE(10656)] = 504620,
  [SMALL_STATE(10657)] = 504657,
  [SMALL_STATE(10658)] = 504690,
  [SMALL_STATE(10659)] = 504745,
  [SMALL_STATE(10660)] = 504778,
  [SMALL_STATE(10661)] = 504827,
  [SMALL_STATE(10662)] = 504862,
  [SMALL_STATE(10663)] = 504895,
  [SMALL_STATE(10664)] = 504927,
  [SMALL_STATE(10665)] = 504959,
  [SMALL_STATE(10666)] = 505009,
  [SMALL_STATE(10667)] = 505055,
  [SMALL_STATE(10668)] = 505103,
  [SMALL_STATE(10669)] = 505133,
  [SMALL_STATE(10670)] = 505165,
  [SMALL_STATE(10671)] = 505197,
  [SMALL_STATE(10672)] = 505229,
  [SMALL_STATE(10673)] = 505261,
  [SMALL_STATE(10674)] = 505291,
  [SMALL_STATE(10675)] = 505323,
  [SMALL_STATE(10676)] = 505355,
  [SMALL_STATE(10677)] = 505387,
  [SMALL_STATE(10678)] = 505435,
  [SMALL_STATE(10679)] = 505465,
  [SMALL_STATE(10680)] = 505497,
  [SMALL_STATE(10681)] = 505529,
  [SMALL_STATE(10682)] = 505561,
  [SMALL_STATE(10683)] = 505593,
  [SMALL_STATE(10684)] = 505625,
  [SMALL_STATE(10685)] = 505661,
  [SMALL_STATE(10686)] = 505693,
  [SMALL_STATE(10687)] = 505725,
  [SMALL_STATE(10688)] = 505757,
  [SMALL_STATE(10689)] = 505789,
  [SMALL_STATE(10690)] = 505831,
  [SMALL_STATE(10691)] = 505863,
  [SMALL_STATE(10692)] = 505895,
  [SMALL_STATE(10693)] = 505933,
  [SMALL_STATE(10694)] = 505965,
  [SMALL_STATE(10695)] = 506001,
  [SMALL_STATE(10696)] = 506033,
  [SMALL_STATE(10697)] = 506087,
  [SMALL_STATE(10698)] = 506119,
  [SMALL_STATE(10699)] = 506151,
  [SMALL_STATE(10700)] = 506183,
  [SMALL_STATE(10701)] = 506215,
  [SMALL_STATE(10702)] = 506247,
  [SMALL_STATE(10703)] = 506279,
  [SMALL_STATE(10704)] = 506333,
  [SMALL_STATE(10705)] = 506365,
  [SMALL_STATE(10706)] = 506397,
  [SMALL_STATE(10707)] = 506429,
  [SMALL_STATE(10708)] = 506483,
  [SMALL_STATE(10709)] = 506519,
  [SMALL_STATE(10710)] = 506551,
  [SMALL_STATE(10711)] = 506583,
  [SMALL_STATE(10712)] = 506615,
  [SMALL_STATE(10713)] = 506669,
  [SMALL_STATE(10714)] = 506701,
  [SMALL_STATE(10715)] = 506733,
  [SMALL_STATE(10716)] = 506765,
  [SMALL_STATE(10717)] = 506801,
  [SMALL_STATE(10718)] = 506833,
  [SMALL_STATE(10719)] = 506865,
  [SMALL_STATE(10720)] = 506903,
  [SMALL_STATE(10721)] = 506939,
  [SMALL_STATE(10722)] = 506993,
  [SMALL_STATE(10723)] = 507041,
  [SMALL_STATE(10724)] = 507073,
  [SMALL_STATE(10725)] = 507105,
  [SMALL_STATE(10726)] = 507137,
  [SMALL_STATE(10727)] = 507169,
  [SMALL_STATE(10728)] = 507201,
  [SMALL_STATE(10729)] = 507233,
  [SMALL_STATE(10730)] = 507279,
  [SMALL_STATE(10731)] = 507309,
  [SMALL_STATE(10732)] = 507341,
  [SMALL_STATE(10733)] = 507379,
  [SMALL_STATE(10734)] = 507411,
  [SMALL_STATE(10735)] = 507449,
  [SMALL_STATE(10736)] = 507501,
  [SMALL_STATE(10737)] = 507537,
  [SMALL_STATE(10738)] = 507575,
  [SMALL_STATE(10739)] = 507611,
  [SMALL_STATE(10740)] = 507643,
  [SMALL_STATE(10741)] = 507675,
  [SMALL_STATE(10742)] = 507705,
  [SMALL_STATE(10743)] = 507757,
  [SMALL_STATE(10744)] = 507795,
  [SMALL_STATE(10745)] = 507833,
  [SMALL_STATE(10746)] = 507871,
  [SMALL_STATE(10747)] = 507903,
  [SMALL_STATE(10748)] = 507941,
  [SMALL_STATE(10749)] = 507973,
  [SMALL_STATE(10750)] = 508005,
  [SMALL_STATE(10751)] = 508053,
  [SMALL_STATE(10752)] = 508095,
  [SMALL_STATE(10753)] = 508147,
  [SMALL_STATE(10754)] = 508197,
  [SMALL_STATE(10755)] = 508247,
  [SMALL_STATE(10756)] = 508283,
  [SMALL_STATE(10757)] = 508315,
  [SMALL_STATE(10758)] = 508347,
  [SMALL_STATE(10759)] = 508379,
  [SMALL_STATE(10760)] = 508421,
  [SMALL_STATE(10761)] = 508453,
  [SMALL_STATE(10762)] = 508485,
  [SMALL_STATE(10763)] = 508527,
  [SMALL_STATE(10764)] = 508567,
  [SMALL_STATE(10765)] = 508605,
  [SMALL_STATE(10766)] = 508637,
  [SMALL_STATE(10767)] = 508669,
  [SMALL_STATE(10768)] = 508705,
  [SMALL_STATE(10769)] = 508739,
  [SMALL_STATE(10770)] = 508793,
  [SMALL_STATE(10771)] = 508827,
  [SMALL_STATE(10772)] = 508859,
  [SMALL_STATE(10773)] = 508891,
  [SMALL_STATE(10774)] = 508927,
  [SMALL_STATE(10775)] = 508959,
  [SMALL_STATE(10776)] = 508991,
  [SMALL_STATE(10777)] = 509021,
  [SMALL_STATE(10778)] = 509057,
  [SMALL_STATE(10779)] = 509089,
  [SMALL_STATE(10780)] = 509121,
  [SMALL_STATE(10781)] = 509171,
  [SMALL_STATE(10782)] = 509203,
  [SMALL_STATE(10783)] = 509257,
  [SMALL_STATE(10784)] = 509309,
  [SMALL_STATE(10785)] = 509341,
  [SMALL_STATE(10786)] = 509373,
  [SMALL_STATE(10787)] = 509405,
  [SMALL_STATE(10788)] = 509437,
  [SMALL_STATE(10789)] = 509469,
  [SMALL_STATE(10790)] = 509501,
  [SMALL_STATE(10791)] = 509551,
  [SMALL_STATE(10792)] = 509583,
  [SMALL_STATE(10793)] = 509615,
  [SMALL_STATE(10794)] = 509647,
  [SMALL_STATE(10795)] = 509697,
  [SMALL_STATE(10796)] = 509729,
  [SMALL_STATE(10797)] = 509783,
  [SMALL_STATE(10798)] = 509815,
  [SMALL_STATE(10799)] = 509847,
  [SMALL_STATE(10800)] = 509879,
  [SMALL_STATE(10801)] = 509911,
  [SMALL_STATE(10802)] = 509943,
  [SMALL_STATE(10803)] = 509993,
  [SMALL_STATE(10804)] = 510025,
  [SMALL_STATE(10805)] = 510079,
  [SMALL_STATE(10806)] = 510111,
  [SMALL_STATE(10807)] = 510143,
  [SMALL_STATE(10808)] = 510173,
  [SMALL_STATE(10809)] = 510205,
  [SMALL_STATE(10810)] = 510235,
  [SMALL_STATE(10811)] = 510289,
  [SMALL_STATE(10812)] = 510321,
  [SMALL_STATE(10813)] = 510353,
  [SMALL_STATE(10814)] = 510383,
  [SMALL_STATE(10815)] = 510415,
  [SMALL_STATE(10816)] = 510447,
  [SMALL_STATE(10817)] = 510497,
  [SMALL_STATE(10818)] = 510529,
  [SMALL_STATE(10819)] = 510561,
  [SMALL_STATE(10820)] = 510593,
  [SMALL_STATE(10821)] = 510625,
  [SMALL_STATE(10822)] = 510661,
  [SMALL_STATE(10823)] = 510693,
  [SMALL_STATE(10824)] = 510725,
  [SMALL_STATE(10825)] = 510757,
  [SMALL_STATE(10826)] = 510789,
  [SMALL_STATE(10827)] = 510825,
  [SMALL_STATE(10828)] = 510857,
  [SMALL_STATE(10829)] = 510889,
  [SMALL_STATE(10830)] = 510931,
  [SMALL_STATE(10831)] = 510985,
  [SMALL_STATE(10832)] = 511017,
  [SMALL_STATE(10833)] = 511049,
  [SMALL_STATE(10834)] = 511081,
  [SMALL_STATE(10835)] = 511113,
  [SMALL_STATE(10836)] = 511155,
  [SMALL_STATE(10837)] = 511193,
  [SMALL_STATE(10838)] = 511239,
  [SMALL_STATE(10839)] = 511271,
  [SMALL_STATE(10840)] = 511301,
  [SMALL_STATE(10841)] = 511333,
  [SMALL_STATE(10842)] = 511365,
  [SMALL_STATE(10843)] = 511415,
  [SMALL_STATE(10844)] = 511461,
  [SMALL_STATE(10845)] = 511493,
  [SMALL_STATE(10846)] = 511543,
  [SMALL_STATE(10847)] = 511575,
  [SMALL_STATE(10848)] = 511607,
  [SMALL_STATE(10849)] = 511661,
  [SMALL_STATE(10850)] = 511693,
  [SMALL_STATE(10851)] = 511725,
  [SMALL_STATE(10852)] = 511757,
  [SMALL_STATE(10853)] = 511789,
  [SMALL_STATE(10854)] = 511823,
  [SMALL_STATE(10855)] = 511855,
  [SMALL_STATE(10856)] = 511887,
  [SMALL_STATE(10857)] = 511937,
  [SMALL_STATE(10858)] = 511969,
  [SMALL_STATE(10859)] = 512001,
  [SMALL_STATE(10860)] = 512033,
  [SMALL_STATE(10861)] = 512067,
  [SMALL_STATE(10862)] = 512105,
  [SMALL_STATE(10863)] = 512137,
  [SMALL_STATE(10864)] = 512169,
  [SMALL_STATE(10865)] = 512201,
  [SMALL_STATE(10866)] = 512233,
  [SMALL_STATE(10867)] = 512265,
  [SMALL_STATE(10868)] = 512297,
  [SMALL_STATE(10869)] = 512329,
  [SMALL_STATE(10870)] = 512361,
  [SMALL_STATE(10871)] = 512393,
  [SMALL_STATE(10872)] = 512445,
  [SMALL_STATE(10873)] = 512477,
  [SMALL_STATE(10874)] = 512509,
  [SMALL_STATE(10875)] = 512541,
  [SMALL_STATE(10876)] = 512573,
  [SMALL_STATE(10877)] = 512605,
  [SMALL_STATE(10878)] = 512637,
  [SMALL_STATE(10879)] = 512669,
  [SMALL_STATE(10880)] = 512701,
  [SMALL_STATE(10881)] = 512753,
  [SMALL_STATE(10882)] = 512785,
  [SMALL_STATE(10883)] = 512817,
  [SMALL_STATE(10884)] = 512849,
  [SMALL_STATE(10885)] = 512881,
  [SMALL_STATE(10886)] = 512923,
  [SMALL_STATE(10887)] = 512953,
  [SMALL_STATE(10888)] = 512985,
  [SMALL_STATE(10889)] = 513039,
  [SMALL_STATE(10890)] = 513093,
  [SMALL_STATE(10891)] = 513141,
  [SMALL_STATE(10892)] = 513195,
  [SMALL_STATE(10893)] = 513233,
  [SMALL_STATE(10894)] = 513271,
  [SMALL_STATE(10895)] = 513303,
  [SMALL_STATE(10896)] = 513349,
  [SMALL_STATE(10897)] = 513399,
  [SMALL_STATE(10898)] = 513431,
  [SMALL_STATE(10899)] = 513463,
  [SMALL_STATE(10900)] = 513495,
  [SMALL_STATE(10901)] = 513527,
  [SMALL_STATE(10902)] = 513557,
  [SMALL_STATE(10903)] = 513609,
  [SMALL_STATE(10904)] = 513645,
  [SMALL_STATE(10905)] = 513695,
  [SMALL_STATE(10906)] = 513727,
  [SMALL_STATE(10907)] = 513759,
  [SMALL_STATE(10908)] = 513791,
  [SMALL_STATE(10909)] = 513823,
  [SMALL_STATE(10910)] = 513855,
  [SMALL_STATE(10911)] = 513887,
  [SMALL_STATE(10912)] = 513919,
  [SMALL_STATE(10913)] = 513951,
  [SMALL_STATE(10914)] = 513983,
  [SMALL_STATE(10915)] = 514015,
  [SMALL_STATE(10916)] = 514047,
  [SMALL_STATE(10917)] = 514079,
  [SMALL_STATE(10918)] = 514111,
  [SMALL_STATE(10919)] = 514143,
  [SMALL_STATE(10920)] = 514175,
  [SMALL_STATE(10921)] = 514205,
  [SMALL_STATE(10922)] = 514235,
  [SMALL_STATE(10923)] = 514267,
  [SMALL_STATE(10924)] = 514315,
  [SMALL_STATE(10925)] = 514347,
  [SMALL_STATE(10926)] = 514379,
  [SMALL_STATE(10927)] = 514411,
  [SMALL_STATE(10928)] = 514465,
  [SMALL_STATE(10929)] = 514515,
  [SMALL_STATE(10930)] = 514547,
  [SMALL_STATE(10931)] = 514579,
  [SMALL_STATE(10932)] = 514611,
  [SMALL_STATE(10933)] = 514657,
  [SMALL_STATE(10934)] = 514689,
  [SMALL_STATE(10935)] = 514719,
  [SMALL_STATE(10936)] = 514773,
  [SMALL_STATE(10937)] = 514805,
  [SMALL_STATE(10938)] = 514837,
  [SMALL_STATE(10939)] = 514869,
  [SMALL_STATE(10940)] = 514901,
  [SMALL_STATE(10941)] = 514933,
  [SMALL_STATE(10942)] = 514963,
  [SMALL_STATE(10943)] = 515017,
  [SMALL_STATE(10944)] = 515049,
  [SMALL_STATE(10945)] = 515081,
  [SMALL_STATE(10946)] = 515133,
  [SMALL_STATE(10947)] = 515165,
  [SMALL_STATE(10948)] = 515197,
  [SMALL_STATE(10949)] = 515229,
  [SMALL_STATE(10950)] = 515259,
  [SMALL_STATE(10951)] = 515290,
  [SMALL_STATE(10952)] = 515339,
  [SMALL_STATE(10953)] = 515368,
  [SMALL_STATE(10954)] = 515399,
  [SMALL_STATE(10955)] = 515448,
  [SMALL_STATE(10956)] = 515481,
  [SMALL_STATE(10957)] = 515510,
  [SMALL_STATE(10958)] = 515539,
  [SMALL_STATE(10959)] = 515588,
  [SMALL_STATE(10960)] = 515619,
  [SMALL_STATE(10961)] = 515668,
  [SMALL_STATE(10962)] = 515709,
  [SMALL_STATE(10963)] = 515740,
  [SMALL_STATE(10964)] = 515789,
  [SMALL_STATE(10965)] = 515830,
  [SMALL_STATE(10966)] = 515861,
  [SMALL_STATE(10967)] = 515892,
  [SMALL_STATE(10968)] = 515923,
  [SMALL_STATE(10969)] = 515958,
  [SMALL_STATE(10970)] = 516007,
  [SMALL_STATE(10971)] = 516038,
  [SMALL_STATE(10972)] = 516069,
  [SMALL_STATE(10973)] = 516100,
  [SMALL_STATE(10974)] = 516135,
  [SMALL_STATE(10975)] = 516166,
  [SMALL_STATE(10976)] = 516211,
  [SMALL_STATE(10977)] = 516242,
  [SMALL_STATE(10978)] = 516271,
  [SMALL_STATE(10979)] = 516302,
  [SMALL_STATE(10980)] = 516343,
  [SMALL_STATE(10981)] = 516378,
  [SMALL_STATE(10982)] = 516409,
  [SMALL_STATE(10983)] = 516438,
  [SMALL_STATE(10984)] = 516467,
  [SMALL_STATE(10985)] = 516514,
  [SMALL_STATE(10986)] = 516549,
  [SMALL_STATE(10987)] = 516580,
  [SMALL_STATE(10988)] = 516615,
  [SMALL_STATE(10989)] = 516650,
  [SMALL_STATE(10990)] = 516683,
  [SMALL_STATE(10991)] = 516714,
  [SMALL_STATE(10992)] = 516749,
  [SMALL_STATE(10993)] = 516780,
  [SMALL_STATE(10994)] = 516811,
  [SMALL_STATE(10995)] = 516842,
  [SMALL_STATE(10996)] = 516889,
  [SMALL_STATE(10997)] = 516920,
  [SMALL_STATE(10998)] = 516951,
  [SMALL_STATE(10999)] = 516986,
  [SMALL_STATE(11000)] = 517017,
  [SMALL_STATE(11001)] = 517048,
  [SMALL_STATE(11002)] = 517079,
  [SMALL_STATE(11003)] = 517110,
  [SMALL_STATE(11004)] = 517141,
  [SMALL_STATE(11005)] = 517190,
  [SMALL_STATE(11006)] = 517221,
  [SMALL_STATE(11007)] = 517252,
  [SMALL_STATE(11008)] = 517283,
  [SMALL_STATE(11009)] = 517314,
  [SMALL_STATE(11010)] = 517345,
  [SMALL_STATE(11011)] = 517374,
  [SMALL_STATE(11012)] = 517419,
  [SMALL_STATE(11013)] = 517448,
  [SMALL_STATE(11014)] = 517497,
  [SMALL_STATE(11015)] = 517546,
  [SMALL_STATE(11016)] = 517577,
  [SMALL_STATE(11017)] = 517608,
  [SMALL_STATE(11018)] = 517637,
  [SMALL_STATE(11019)] = 517670,
  [SMALL_STATE(11020)] = 517701,
  [SMALL_STATE(11021)] = 517732,
  [SMALL_STATE(11022)] = 517763,
  [SMALL_STATE(11023)] = 517794,
  [SMALL_STATE(11024)] = 517823,
  [SMALL_STATE(11025)] = 517872,
  [SMALL_STATE(11026)] = 517901,
  [SMALL_STATE(11027)] = 517930,
  [SMALL_STATE(11028)] = 517977,
  [SMALL_STATE(11029)] = 518012,
  [SMALL_STATE(11030)] = 518047,
  [SMALL_STATE(11031)] = 518078,
  [SMALL_STATE(11032)] = 518109,
  [SMALL_STATE(11033)] = 518144,
  [SMALL_STATE(11034)] = 518173,
  [SMALL_STATE(11035)] = 518214,
  [SMALL_STATE(11036)] = 518243,
  [SMALL_STATE(11037)] = 518274,
  [SMALL_STATE(11038)] = 518319,
  [SMALL_STATE(11039)] = 518350,
  [SMALL_STATE(11040)] = 518381,
  [SMALL_STATE(11041)] = 518412,
  [SMALL_STATE(11042)] = 518443,
  [SMALL_STATE(11043)] = 518474,
  [SMALL_STATE(11044)] = 518513,
  [SMALL_STATE(11045)] = 518544,
  [SMALL_STATE(11046)] = 518575,
  [SMALL_STATE(11047)] = 518612,
  [SMALL_STATE(11048)] = 518643,
  [SMALL_STATE(11049)] = 518694,
  [SMALL_STATE(11050)] = 518725,
  [SMALL_STATE(11051)] = 518756,
  [SMALL_STATE(11052)] = 518787,
  [SMALL_STATE(11053)] = 518816,
  [SMALL_STATE(11054)] = 518847,
  [SMALL_STATE(11055)] = 518882,
  [SMALL_STATE(11056)] = 518929,
  [SMALL_STATE(11057)] = 518976,
  [SMALL_STATE(11058)] = 519007,
  [SMALL_STATE(11059)] = 519038,
  [SMALL_STATE(11060)] = 519069,
  [SMALL_STATE(11061)] = 519100,
  [SMALL_STATE(11062)] = 519131,
  [SMALL_STATE(11063)] = 519160,
  [SMALL_STATE(11064)] = 519189,
  [SMALL_STATE(11065)] = 519220,
  [SMALL_STATE(11066)] = 519251,
  [SMALL_STATE(11067)] = 519282,
  [SMALL_STATE(11068)] = 519313,
  [SMALL_STATE(11069)] = 519344,
  [SMALL_STATE(11070)] = 519379,
  [SMALL_STATE(11071)] = 519410,
  [SMALL_STATE(11072)] = 519441,
  [SMALL_STATE(11073)] = 519490,
  [SMALL_STATE(11074)] = 519525,
  [SMALL_STATE(11075)] = 519562,
  [SMALL_STATE(11076)] = 519593,
  [SMALL_STATE(11077)] = 519624,
  [SMALL_STATE(11078)] = 519657,
  [SMALL_STATE(11079)] = 519696,
  [SMALL_STATE(11080)] = 519727,
  [SMALL_STATE(11081)] = 519758,
  [SMALL_STATE(11082)] = 519807,
  [SMALL_STATE(11083)] = 519856,
  [SMALL_STATE(11084)] = 519891,
  [SMALL_STATE(11085)] = 519926,
  [SMALL_STATE(11086)] = 519957,
  [SMALL_STATE(11087)] = 519992,
  [SMALL_STATE(11088)] = 520039,
  [SMALL_STATE(11089)] = 520070,
  [SMALL_STATE(11090)] = 520101,
  [SMALL_STATE(11091)] = 520132,
  [SMALL_STATE(11092)] = 520163,
  [SMALL_STATE(11093)] = 520194,
  [SMALL_STATE(11094)] = 520241,
  [SMALL_STATE(11095)] = 520270,
  [SMALL_STATE(11096)] = 520301,
  [SMALL_STATE(11097)] = 520338,
  [SMALL_STATE(11098)] = 520367,
  [SMALL_STATE(11099)] = 520398,
  [SMALL_STATE(11100)] = 520429,
  [SMALL_STATE(11101)] = 520470,
  [SMALL_STATE(11102)] = 520501,
  [SMALL_STATE(11103)] = 520548,
  [SMALL_STATE(11104)] = 520579,
  [SMALL_STATE(11105)] = 520610,
  [SMALL_STATE(11106)] = 520645,
  [SMALL_STATE(11107)] = 520694,
  [SMALL_STATE(11108)] = 520723,
  [SMALL_STATE(11109)] = 520754,
  [SMALL_STATE(11110)] = 520785,
  [SMALL_STATE(11111)] = 520816,
  [SMALL_STATE(11112)] = 520845,
  [SMALL_STATE(11113)] = 520874,
  [SMALL_STATE(11114)] = 520905,
  [SMALL_STATE(11115)] = 520936,
  [SMALL_STATE(11116)] = 520977,
  [SMALL_STATE(11117)] = 521012,
  [SMALL_STATE(11118)] = 521047,
  [SMALL_STATE(11119)] = 521088,
  [SMALL_STATE(11120)] = 521123,
  [SMALL_STATE(11121)] = 521154,
  [SMALL_STATE(11122)] = 521203,
  [SMALL_STATE(11123)] = 521234,
  [SMALL_STATE(11124)] = 521283,
  [SMALL_STATE(11125)] = 521330,
  [SMALL_STATE(11126)] = 521361,
  [SMALL_STATE(11127)] = 521410,
  [SMALL_STATE(11128)] = 521459,
  [SMALL_STATE(11129)] = 521490,
  [SMALL_STATE(11130)] = 521539,
  [SMALL_STATE(11131)] = 521586,
  [SMALL_STATE(11132)] = 521615,
  [SMALL_STATE(11133)] = 521664,
  [SMALL_STATE(11134)] = 521695,
  [SMALL_STATE(11135)] = 521739,
  [SMALL_STATE(11136)] = 521767,
  [SMALL_STATE(11137)] = 521813,
  [SMALL_STATE(11138)] = 521841,
  [SMALL_STATE(11139)] = 521871,
  [SMALL_STATE(11140)] = 521899,
  [SMALL_STATE(11141)] = 521945,
  [SMALL_STATE(11142)] = 521975,
  [SMALL_STATE(11143)] = 522003,
  [SMALL_STATE(11144)] = 522051,
  [SMALL_STATE(11145)] = 522079,
  [SMALL_STATE(11146)] = 522107,
  [SMALL_STATE(11147)] = 522135,
  [SMALL_STATE(11148)] = 522163,
  [SMALL_STATE(11149)] = 522191,
  [SMALL_STATE(11150)] = 522225,
  [SMALL_STATE(11151)] = 522257,
  [SMALL_STATE(11152)] = 522287,
  [SMALL_STATE(11153)] = 522317,
  [SMALL_STATE(11154)] = 522347,
  [SMALL_STATE(11155)] = 522377,
  [SMALL_STATE(11156)] = 522407,
  [SMALL_STATE(11157)] = 522453,
  [SMALL_STATE(11158)] = 522501,
  [SMALL_STATE(11159)] = 522531,
  [SMALL_STATE(11160)] = 522565,
  [SMALL_STATE(11161)] = 522609,
  [SMALL_STATE(11162)] = 522639,
  [SMALL_STATE(11163)] = 522669,
  [SMALL_STATE(11164)] = 522699,
  [SMALL_STATE(11165)] = 522729,
  [SMALL_STATE(11166)] = 522763,
  [SMALL_STATE(11167)] = 522809,
  [SMALL_STATE(11168)] = 522837,
  [SMALL_STATE(11169)] = 522881,
  [SMALL_STATE(11170)] = 522921,
  [SMALL_STATE(11171)] = 522965,
  [SMALL_STATE(11172)] = 522995,
  [SMALL_STATE(11173)] = 523027,
  [SMALL_STATE(11174)] = 523065,
  [SMALL_STATE(11175)] = 523093,
  [SMALL_STATE(11176)] = 523123,
  [SMALL_STATE(11177)] = 523151,
  [SMALL_STATE(11178)] = 523181,
  [SMALL_STATE(11179)] = 523211,
  [SMALL_STATE(11180)] = 523241,
  [SMALL_STATE(11181)] = 523269,
  [SMALL_STATE(11182)] = 523299,
  [SMALL_STATE(11183)] = 523327,
  [SMALL_STATE(11184)] = 523357,
  [SMALL_STATE(11185)] = 523387,
  [SMALL_STATE(11186)] = 523415,
  [SMALL_STATE(11187)] = 523461,
  [SMALL_STATE(11188)] = 523489,
  [SMALL_STATE(11189)] = 523535,
  [SMALL_STATE(11190)] = 523565,
  [SMALL_STATE(11191)] = 523599,
  [SMALL_STATE(11192)] = 523627,
  [SMALL_STATE(11193)] = 523657,
  [SMALL_STATE(11194)] = 523685,
  [SMALL_STATE(11195)] = 523715,
  [SMALL_STATE(11196)] = 523761,
  [SMALL_STATE(11197)] = 523795,
  [SMALL_STATE(11198)] = 523825,
  [SMALL_STATE(11199)] = 523855,
  [SMALL_STATE(11200)] = 523883,
  [SMALL_STATE(11201)] = 523923,
  [SMALL_STATE(11202)] = 523951,
  [SMALL_STATE(11203)] = 523979,
  [SMALL_STATE(11204)] = 524009,
  [SMALL_STATE(11205)] = 524037,
  [SMALL_STATE(11206)] = 524067,
  [SMALL_STATE(11207)] = 524097,
  [SMALL_STATE(11208)] = 524125,
  [SMALL_STATE(11209)] = 524153,
  [SMALL_STATE(11210)] = 524181,
  [SMALL_STATE(11211)] = 524209,
  [SMALL_STATE(11212)] = 524257,
  [SMALL_STATE(11213)] = 524285,
  [SMALL_STATE(11214)] = 524325,
  [SMALL_STATE(11215)] = 524353,
  [SMALL_STATE(11216)] = 524381,
  [SMALL_STATE(11217)] = 524409,
  [SMALL_STATE(11218)] = 524437,
  [SMALL_STATE(11219)] = 524465,
  [SMALL_STATE(11220)] = 524493,
  [SMALL_STATE(11221)] = 524523,
  [SMALL_STATE(11222)] = 524551,
  [SMALL_STATE(11223)] = 524581,
  [SMALL_STATE(11224)] = 524611,
  [SMALL_STATE(11225)] = 524639,
  [SMALL_STATE(11226)] = 524669,
  [SMALL_STATE(11227)] = 524699,
  [SMALL_STATE(11228)] = 524727,
  [SMALL_STATE(11229)] = 524755,
  [SMALL_STATE(11230)] = 524783,
  [SMALL_STATE(11231)] = 524811,
  [SMALL_STATE(11232)] = 524839,
  [SMALL_STATE(11233)] = 524867,
  [SMALL_STATE(11234)] = 524895,
  [SMALL_STATE(11235)] = 524923,
  [SMALL_STATE(11236)] = 524951,
  [SMALL_STATE(11237)] = 524997,
  [SMALL_STATE(11238)] = 525027,
  [SMALL_STATE(11239)] = 525067,
  [SMALL_STATE(11240)] = 525097,
  [SMALL_STATE(11241)] = 525127,
  [SMALL_STATE(11242)] = 525173,
  [SMALL_STATE(11243)] = 525203,
  [SMALL_STATE(11244)] = 525233,
  [SMALL_STATE(11245)] = 525261,
  [SMALL_STATE(11246)] = 525305,
  [SMALL_STATE(11247)] = 525349,
  [SMALL_STATE(11248)] = 525397,
  [SMALL_STATE(11249)] = 525445,
  [SMALL_STATE(11250)] = 525493,
  [SMALL_STATE(11251)] = 525541,
  [SMALL_STATE(11252)] = 525589,
  [SMALL_STATE(11253)] = 525637,
  [SMALL_STATE(11254)] = 525669,
  [SMALL_STATE(11255)] = 525699,
  [SMALL_STATE(11256)] = 525735,
  [SMALL_STATE(11257)] = 525769,
  [SMALL_STATE(11258)] = 525813,
  [SMALL_STATE(11259)] = 525857,
  [SMALL_STATE(11260)] = 525887,
  [SMALL_STATE(11261)] = 525919,
  [SMALL_STATE(11262)] = 525963,
  [SMALL_STATE(11263)] = 526007,
  [SMALL_STATE(11264)] = 526037,
  [SMALL_STATE(11265)] = 526067,
  [SMALL_STATE(11266)] = 526113,
  [SMALL_STATE(11267)] = 526143,
  [SMALL_STATE(11268)] = 526171,
  [SMALL_STATE(11269)] = 526201,
  [SMALL_STATE(11270)] = 526229,
  [SMALL_STATE(11271)] = 526259,
  [SMALL_STATE(11272)] = 526305,
  [SMALL_STATE(11273)] = 526333,
  [SMALL_STATE(11274)] = 526361,
  [SMALL_STATE(11275)] = 526389,
  [SMALL_STATE(11276)] = 526419,
  [SMALL_STATE(11277)] = 526447,
  [SMALL_STATE(11278)] = 526477,
  [SMALL_STATE(11279)] = 526507,
  [SMALL_STATE(11280)] = 526537,
  [SMALL_STATE(11281)] = 526567,
  [SMALL_STATE(11282)] = 526597,
  [SMALL_STATE(11283)] = 526627,
  [SMALL_STATE(11284)] = 526655,
  [SMALL_STATE(11285)] = 526683,
  [SMALL_STATE(11286)] = 526713,
  [SMALL_STATE(11287)] = 526741,
  [SMALL_STATE(11288)] = 526769,
  [SMALL_STATE(11289)] = 526799,
  [SMALL_STATE(11290)] = 526829,
  [SMALL_STATE(11291)] = 526859,
  [SMALL_STATE(11292)] = 526889,
  [SMALL_STATE(11293)] = 526923,
  [SMALL_STATE(11294)] = 526967,
  [SMALL_STATE(11295)] = 527013,
  [SMALL_STATE(11296)] = 527059,
  [SMALL_STATE(11297)] = 527089,
  [SMALL_STATE(11298)] = 527119,
  [SMALL_STATE(11299)] = 527147,
  [SMALL_STATE(11300)] = 527175,
  [SMALL_STATE(11301)] = 527205,
  [SMALL_STATE(11302)] = 527249,
  [SMALL_STATE(11303)] = 527277,
  [SMALL_STATE(11304)] = 527305,
  [SMALL_STATE(11305)] = 527333,
  [SMALL_STATE(11306)] = 527381,
  [SMALL_STATE(11307)] = 527425,
  [SMALL_STATE(11308)] = 527453,
  [SMALL_STATE(11309)] = 527499,
  [SMALL_STATE(11310)] = 527545,
  [SMALL_STATE(11311)] = 527593,
  [SMALL_STATE(11312)] = 527621,
  [SMALL_STATE(11313)] = 527669,
  [SMALL_STATE(11314)] = 527717,
  [SMALL_STATE(11315)] = 527761,
  [SMALL_STATE(11316)] = 527809,
  [SMALL_STATE(11317)] = 527839,
  [SMALL_STATE(11318)] = 527869,
  [SMALL_STATE(11319)] = 527899,
  [SMALL_STATE(11320)] = 527943,
  [SMALL_STATE(11321)] = 527989,
  [SMALL_STATE(11322)] = 528019,
  [SMALL_STATE(11323)] = 528051,
  [SMALL_STATE(11324)] = 528081,
  [SMALL_STATE(11325)] = 528127,
  [SMALL_STATE(11326)] = 528173,
  [SMALL_STATE(11327)] = 528201,
  [SMALL_STATE(11328)] = 528245,
  [SMALL_STATE(11329)] = 528289,
  [SMALL_STATE(11330)] = 528333,
  [SMALL_STATE(11331)] = 528377,
  [SMALL_STATE(11332)] = 528421,
  [SMALL_STATE(11333)] = 528465,
  [SMALL_STATE(11334)] = 528509,
  [SMALL_STATE(11335)] = 528553,
  [SMALL_STATE(11336)] = 528597,
  [SMALL_STATE(11337)] = 528641,
  [SMALL_STATE(11338)] = 528685,
  [SMALL_STATE(11339)] = 528729,
  [SMALL_STATE(11340)] = 528773,
  [SMALL_STATE(11341)] = 528817,
  [SMALL_STATE(11342)] = 528861,
  [SMALL_STATE(11343)] = 528905,
  [SMALL_STATE(11344)] = 528949,
  [SMALL_STATE(11345)] = 528993,
  [SMALL_STATE(11346)] = 529037,
  [SMALL_STATE(11347)] = 529081,
  [SMALL_STATE(11348)] = 529109,
  [SMALL_STATE(11349)] = 529153,
  [SMALL_STATE(11350)] = 529197,
  [SMALL_STATE(11351)] = 529241,
  [SMALL_STATE(11352)] = 529285,
  [SMALL_STATE(11353)] = 529329,
  [SMALL_STATE(11354)] = 529373,
  [SMALL_STATE(11355)] = 529417,
  [SMALL_STATE(11356)] = 529461,
  [SMALL_STATE(11357)] = 529505,
  [SMALL_STATE(11358)] = 529549,
  [SMALL_STATE(11359)] = 529577,
  [SMALL_STATE(11360)] = 529621,
  [SMALL_STATE(11361)] = 529665,
  [SMALL_STATE(11362)] = 529709,
  [SMALL_STATE(11363)] = 529753,
  [SMALL_STATE(11364)] = 529797,
  [SMALL_STATE(11365)] = 529841,
  [SMALL_STATE(11366)] = 529885,
  [SMALL_STATE(11367)] = 529929,
  [SMALL_STATE(11368)] = 529957,
  [SMALL_STATE(11369)] = 530001,
  [SMALL_STATE(11370)] = 530045,
  [SMALL_STATE(11371)] = 530089,
  [SMALL_STATE(11372)] = 530133,
  [SMALL_STATE(11373)] = 530177,
  [SMALL_STATE(11374)] = 530221,
  [SMALL_STATE(11375)] = 530265,
  [SMALL_STATE(11376)] = 530309,
  [SMALL_STATE(11377)] = 530353,
  [SMALL_STATE(11378)] = 530397,
  [SMALL_STATE(11379)] = 530441,
  [SMALL_STATE(11380)] = 530485,
  [SMALL_STATE(11381)] = 530529,
  [SMALL_STATE(11382)] = 530573,
  [SMALL_STATE(11383)] = 530617,
  [SMALL_STATE(11384)] = 530661,
  [SMALL_STATE(11385)] = 530705,
  [SMALL_STATE(11386)] = 530749,
  [SMALL_STATE(11387)] = 530793,
  [SMALL_STATE(11388)] = 530837,
  [SMALL_STATE(11389)] = 530881,
  [SMALL_STATE(11390)] = 530925,
  [SMALL_STATE(11391)] = 530969,
  [SMALL_STATE(11392)] = 531013,
  [SMALL_STATE(11393)] = 531057,
  [SMALL_STATE(11394)] = 531101,
  [SMALL_STATE(11395)] = 531145,
  [SMALL_STATE(11396)] = 531189,
  [SMALL_STATE(11397)] = 531233,
  [SMALL_STATE(11398)] = 531277,
  [SMALL_STATE(11399)] = 531321,
  [SMALL_STATE(11400)] = 531365,
  [SMALL_STATE(11401)] = 531409,
  [SMALL_STATE(11402)] = 531453,
  [SMALL_STATE(11403)] = 531497,
  [SMALL_STATE(11404)] = 531541,
  [SMALL_STATE(11405)] = 531585,
  [SMALL_STATE(11406)] = 531629,
  [SMALL_STATE(11407)] = 531673,
  [SMALL_STATE(11408)] = 531717,
  [SMALL_STATE(11409)] = 531761,
  [SMALL_STATE(11410)] = 531805,
  [SMALL_STATE(11411)] = 531849,
  [SMALL_STATE(11412)] = 531893,
  [SMALL_STATE(11413)] = 531937,
  [SMALL_STATE(11414)] = 531981,
  [SMALL_STATE(11415)] = 532025,
  [SMALL_STATE(11416)] = 532069,
  [SMALL_STATE(11417)] = 532113,
  [SMALL_STATE(11418)] = 532157,
  [SMALL_STATE(11419)] = 532201,
  [SMALL_STATE(11420)] = 532245,
  [SMALL_STATE(11421)] = 532289,
  [SMALL_STATE(11422)] = 532333,
  [SMALL_STATE(11423)] = 532377,
  [SMALL_STATE(11424)] = 532421,
  [SMALL_STATE(11425)] = 532465,
  [SMALL_STATE(11426)] = 532509,
  [SMALL_STATE(11427)] = 532553,
  [SMALL_STATE(11428)] = 532597,
  [SMALL_STATE(11429)] = 532641,
  [SMALL_STATE(11430)] = 532685,
  [SMALL_STATE(11431)] = 532729,
  [SMALL_STATE(11432)] = 532773,
  [SMALL_STATE(11433)] = 532817,
  [SMALL_STATE(11434)] = 532861,
  [SMALL_STATE(11435)] = 532905,
  [SMALL_STATE(11436)] = 532949,
  [SMALL_STATE(11437)] = 532993,
  [SMALL_STATE(11438)] = 533037,
  [SMALL_STATE(11439)] = 533081,
  [SMALL_STATE(11440)] = 533125,
  [SMALL_STATE(11441)] = 533169,
  [SMALL_STATE(11442)] = 533213,
  [SMALL_STATE(11443)] = 533257,
  [SMALL_STATE(11444)] = 533301,
  [SMALL_STATE(11445)] = 533345,
  [SMALL_STATE(11446)] = 533389,
  [SMALL_STATE(11447)] = 533433,
  [SMALL_STATE(11448)] = 533477,
  [SMALL_STATE(11449)] = 533521,
  [SMALL_STATE(11450)] = 533565,
  [SMALL_STATE(11451)] = 533609,
  [SMALL_STATE(11452)] = 533653,
  [SMALL_STATE(11453)] = 533697,
  [SMALL_STATE(11454)] = 533741,
  [SMALL_STATE(11455)] = 533785,
  [SMALL_STATE(11456)] = 533829,
  [SMALL_STATE(11457)] = 533873,
  [SMALL_STATE(11458)] = 533917,
  [SMALL_STATE(11459)] = 533965,
  [SMALL_STATE(11460)] = 533992,
  [SMALL_STATE(11461)] = 534033,
  [SMALL_STATE(11462)] = 534062,
  [SMALL_STATE(11463)] = 534109,
  [SMALL_STATE(11464)] = 534138,
  [SMALL_STATE(11465)] = 534167,
  [SMALL_STATE(11466)] = 534194,
  [SMALL_STATE(11467)] = 534221,
  [SMALL_STATE(11468)] = 534248,
  [SMALL_STATE(11469)] = 534277,
  [SMALL_STATE(11470)] = 534322,
  [SMALL_STATE(11471)] = 534349,
  [SMALL_STATE(11472)] = 534390,
  [SMALL_STATE(11473)] = 534437,
  [SMALL_STATE(11474)] = 534484,
  [SMALL_STATE(11475)] = 534531,
  [SMALL_STATE(11476)] = 534564,
  [SMALL_STATE(11477)] = 534597,
  [SMALL_STATE(11478)] = 534624,
  [SMALL_STATE(11479)] = 534651,
  [SMALL_STATE(11480)] = 534690,
  [SMALL_STATE(11481)] = 534717,
  [SMALL_STATE(11482)] = 534744,
  [SMALL_STATE(11483)] = 534773,
  [SMALL_STATE(11484)] = 534804,
  [SMALL_STATE(11485)] = 534831,
  [SMALL_STATE(11486)] = 534860,
  [SMALL_STATE(11487)] = 534887,
  [SMALL_STATE(11488)] = 534914,
  [SMALL_STATE(11489)] = 534941,
  [SMALL_STATE(11490)] = 534968,
  [SMALL_STATE(11491)] = 534995,
  [SMALL_STATE(11492)] = 535022,
  [SMALL_STATE(11493)] = 535049,
  [SMALL_STATE(11494)] = 535076,
  [SMALL_STATE(11495)] = 535109,
  [SMALL_STATE(11496)] = 535138,
  [SMALL_STATE(11497)] = 535167,
  [SMALL_STATE(11498)] = 535194,
  [SMALL_STATE(11499)] = 535225,
  [SMALL_STATE(11500)] = 535254,
  [SMALL_STATE(11501)] = 535283,
  [SMALL_STATE(11502)] = 535310,
  [SMALL_STATE(11503)] = 535339,
  [SMALL_STATE(11504)] = 535368,
  [SMALL_STATE(11505)] = 535415,
  [SMALL_STATE(11506)] = 535442,
  [SMALL_STATE(11507)] = 535469,
  [SMALL_STATE(11508)] = 535496,
  [SMALL_STATE(11509)] = 535523,
  [SMALL_STATE(11510)] = 535552,
  [SMALL_STATE(11511)] = 535579,
  [SMALL_STATE(11512)] = 535618,
  [SMALL_STATE(11513)] = 535651,
  [SMALL_STATE(11514)] = 535678,
  [SMALL_STATE(11515)] = 535725,
  [SMALL_STATE(11516)] = 535752,
  [SMALL_STATE(11517)] = 535781,
  [SMALL_STATE(11518)] = 535810,
  [SMALL_STATE(11519)] = 535837,
  [SMALL_STATE(11520)] = 535864,
  [SMALL_STATE(11521)] = 535893,
  [SMALL_STATE(11522)] = 535920,
  [SMALL_STATE(11523)] = 535947,
  [SMALL_STATE(11524)] = 535974,
  [SMALL_STATE(11525)] = 536001,
  [SMALL_STATE(11526)] = 536028,
  [SMALL_STATE(11527)] = 536057,
  [SMALL_STATE(11528)] = 536086,
  [SMALL_STATE(11529)] = 536113,
  [SMALL_STATE(11530)] = 536142,
  [SMALL_STATE(11531)] = 536171,
  [SMALL_STATE(11532)] = 536200,
  [SMALL_STATE(11533)] = 536229,
  [SMALL_STATE(11534)] = 536256,
  [SMALL_STATE(11535)] = 536283,
  [SMALL_STATE(11536)] = 536312,
  [SMALL_STATE(11537)] = 536339,
  [SMALL_STATE(11538)] = 536366,
  [SMALL_STATE(11539)] = 536393,
  [SMALL_STATE(11540)] = 536422,
  [SMALL_STATE(11541)] = 536451,
  [SMALL_STATE(11542)] = 536480,
  [SMALL_STATE(11543)] = 536507,
  [SMALL_STATE(11544)] = 536548,
  [SMALL_STATE(11545)] = 536577,
  [SMALL_STATE(11546)] = 536606,
  [SMALL_STATE(11547)] = 536635,
  [SMALL_STATE(11548)] = 536662,
  [SMALL_STATE(11549)] = 536689,
  [SMALL_STATE(11550)] = 536720,
  [SMALL_STATE(11551)] = 536747,
  [SMALL_STATE(11552)] = 536774,
  [SMALL_STATE(11553)] = 536801,
  [SMALL_STATE(11554)] = 536828,
  [SMALL_STATE(11555)] = 536867,
  [SMALL_STATE(11556)] = 536894,
  [SMALL_STATE(11557)] = 536941,
  [SMALL_STATE(11558)] = 536968,
  [SMALL_STATE(11559)] = 537015,
  [SMALL_STATE(11560)] = 537042,
  [SMALL_STATE(11561)] = 537069,
  [SMALL_STATE(11562)] = 537096,
  [SMALL_STATE(11563)] = 537123,
  [SMALL_STATE(11564)] = 537150,
  [SMALL_STATE(11565)] = 537177,
  [SMALL_STATE(11566)] = 537206,
  [SMALL_STATE(11567)] = 537233,
  [SMALL_STATE(11568)] = 537260,
  [SMALL_STATE(11569)] = 537287,
  [SMALL_STATE(11570)] = 537318,
  [SMALL_STATE(11571)] = 537365,
  [SMALL_STATE(11572)] = 537400,
  [SMALL_STATE(11573)] = 537427,
  [SMALL_STATE(11574)] = 537454,
  [SMALL_STATE(11575)] = 537493,
  [SMALL_STATE(11576)] = 537520,
  [SMALL_STATE(11577)] = 537549,
  [SMALL_STATE(11578)] = 537580,
  [SMALL_STATE(11579)] = 537609,
  [SMALL_STATE(11580)] = 537652,
  [SMALL_STATE(11581)] = 537679,
  [SMALL_STATE(11582)] = 537706,
  [SMALL_STATE(11583)] = 537735,
  [SMALL_STATE(11584)] = 537776,
  [SMALL_STATE(11585)] = 537817,
  [SMALL_STATE(11586)] = 537844,
  [SMALL_STATE(11587)] = 537871,
  [SMALL_STATE(11588)] = 537900,
  [SMALL_STATE(11589)] = 537933,
  [SMALL_STATE(11590)] = 537960,
  [SMALL_STATE(11591)] = 537987,
  [SMALL_STATE(11592)] = 538014,
  [SMALL_STATE(11593)] = 538043,
  [SMALL_STATE(11594)] = 538070,
  [SMALL_STATE(11595)] = 538099,
  [SMALL_STATE(11596)] = 538146,
  [SMALL_STATE(11597)] = 538193,
  [SMALL_STATE(11598)] = 538220,
  [SMALL_STATE(11599)] = 538249,
  [SMALL_STATE(11600)] = 538276,
  [SMALL_STATE(11601)] = 538305,
  [SMALL_STATE(11602)] = 538332,
  [SMALL_STATE(11603)] = 538373,
  [SMALL_STATE(11604)] = 538400,
  [SMALL_STATE(11605)] = 538447,
  [SMALL_STATE(11606)] = 538474,
  [SMALL_STATE(11607)] = 538503,
  [SMALL_STATE(11608)] = 538532,
  [SMALL_STATE(11609)] = 538561,
  [SMALL_STATE(11610)] = 538590,
  [SMALL_STATE(11611)] = 538619,
  [SMALL_STATE(11612)] = 538666,
  [SMALL_STATE(11613)] = 538713,
  [SMALL_STATE(11614)] = 538760,
  [SMALL_STATE(11615)] = 538801,
  [SMALL_STATE(11616)] = 538842,
  [SMALL_STATE(11617)] = 538889,
  [SMALL_STATE(11618)] = 538916,
  [SMALL_STATE(11619)] = 538945,
  [SMALL_STATE(11620)] = 538972,
  [SMALL_STATE(11621)] = 539003,
  [SMALL_STATE(11622)] = 539036,
  [SMALL_STATE(11623)] = 539067,
  [SMALL_STATE(11624)] = 539098,
  [SMALL_STATE(11625)] = 539131,
  [SMALL_STATE(11626)] = 539162,
  [SMALL_STATE(11627)] = 539193,
  [SMALL_STATE(11628)] = 539224,
  [SMALL_STATE(11629)] = 539267,
  [SMALL_STATE(11630)] = 539296,
  [SMALL_STATE(11631)] = 539323,
  [SMALL_STATE(11632)] = 539350,
  [SMALL_STATE(11633)] = 539377,
  [SMALL_STATE(11634)] = 539410,
  [SMALL_STATE(11635)] = 539439,
  [SMALL_STATE(11636)] = 539482,
  [SMALL_STATE(11637)] = 539513,
  [SMALL_STATE(11638)] = 539540,
  [SMALL_STATE(11639)] = 539581,
  [SMALL_STATE(11640)] = 539622,
  [SMALL_STATE(11641)] = 539649,
  [SMALL_STATE(11642)] = 539676,
  [SMALL_STATE(11643)] = 539703,
  [SMALL_STATE(11644)] = 539730,
  [SMALL_STATE(11645)] = 539757,
  [SMALL_STATE(11646)] = 539786,
  [SMALL_STATE(11647)] = 539813,
  [SMALL_STATE(11648)] = 539840,
  [SMALL_STATE(11649)] = 539867,
  [SMALL_STATE(11650)] = 539894,
  [SMALL_STATE(11651)] = 539933,
  [SMALL_STATE(11652)] = 539960,
  [SMALL_STATE(11653)] = 539987,
  [SMALL_STATE(11654)] = 540034,
  [SMALL_STATE(11655)] = 540061,
  [SMALL_STATE(11656)] = 540088,
  [SMALL_STATE(11657)] = 540117,
  [SMALL_STATE(11658)] = 540146,
  [SMALL_STATE(11659)] = 540173,
  [SMALL_STATE(11660)] = 540202,
  [SMALL_STATE(11661)] = 540243,
  [SMALL_STATE(11662)] = 540284,
  [SMALL_STATE(11663)] = 540325,
  [SMALL_STATE(11664)] = 540376,
  [SMALL_STATE(11665)] = 540403,
  [SMALL_STATE(11666)] = 540432,
  [SMALL_STATE(11667)] = 540473,
  [SMALL_STATE(11668)] = 540514,
  [SMALL_STATE(11669)] = 540545,
  [SMALL_STATE(11670)] = 540586,
  [SMALL_STATE(11671)] = 540613,
  [SMALL_STATE(11672)] = 540640,
  [SMALL_STATE(11673)] = 540679,
  [SMALL_STATE(11674)] = 540708,
  [SMALL_STATE(11675)] = 540739,
  [SMALL_STATE(11676)] = 540766,
  [SMALL_STATE(11677)] = 540799,
  [SMALL_STATE(11678)] = 540826,
  [SMALL_STATE(11679)] = 540853,
  [SMALL_STATE(11680)] = 540880,
  [SMALL_STATE(11681)] = 540907,
  [SMALL_STATE(11682)] = 540946,
  [SMALL_STATE(11683)] = 540973,
  [SMALL_STATE(11684)] = 541000,
  [SMALL_STATE(11685)] = 541027,
  [SMALL_STATE(11686)] = 541054,
  [SMALL_STATE(11687)] = 541081,
  [SMALL_STATE(11688)] = 541108,
  [SMALL_STATE(11689)] = 541135,
  [SMALL_STATE(11690)] = 541162,
  [SMALL_STATE(11691)] = 541189,
  [SMALL_STATE(11692)] = 541218,
  [SMALL_STATE(11693)] = 541247,
  [SMALL_STATE(11694)] = 541276,
  [SMALL_STATE(11695)] = 541307,
  [SMALL_STATE(11696)] = 541334,
  [SMALL_STATE(11697)] = 541363,
  [SMALL_STATE(11698)] = 541396,
  [SMALL_STATE(11699)] = 541423,
  [SMALL_STATE(11700)] = 541452,
  [SMALL_STATE(11701)] = 541479,
  [SMALL_STATE(11702)] = 541506,
  [SMALL_STATE(11703)] = 541533,
  [SMALL_STATE(11704)] = 541560,
  [SMALL_STATE(11705)] = 541589,
  [SMALL_STATE(11706)] = 541630,
  [SMALL_STATE(11707)] = 541659,
  [SMALL_STATE(11708)] = 541686,
  [SMALL_STATE(11709)] = 541715,
  [SMALL_STATE(11710)] = 541744,
  [SMALL_STATE(11711)] = 541773,
  [SMALL_STATE(11712)] = 541800,
  [SMALL_STATE(11713)] = 541841,
  [SMALL_STATE(11714)] = 541888,
  [SMALL_STATE(11715)] = 541917,
  [SMALL_STATE(11716)] = 541944,
  [SMALL_STATE(11717)] = 541971,
  [SMALL_STATE(11718)] = 541998,
  [SMALL_STATE(11719)] = 542037,
  [SMALL_STATE(11720)] = 542084,
  [SMALL_STATE(11721)] = 542125,
  [SMALL_STATE(11722)] = 542166,
  [SMALL_STATE(11723)] = 542207,
  [SMALL_STATE(11724)] = 542248,
  [SMALL_STATE(11725)] = 542289,
  [SMALL_STATE(11726)] = 542330,
  [SMALL_STATE(11727)] = 542371,
  [SMALL_STATE(11728)] = 542412,
  [SMALL_STATE(11729)] = 542453,
  [SMALL_STATE(11730)] = 542494,
  [SMALL_STATE(11731)] = 542535,
  [SMALL_STATE(11732)] = 542576,
  [SMALL_STATE(11733)] = 542617,
  [SMALL_STATE(11734)] = 542658,
  [SMALL_STATE(11735)] = 542699,
  [SMALL_STATE(11736)] = 542740,
  [SMALL_STATE(11737)] = 542781,
  [SMALL_STATE(11738)] = 542822,
  [SMALL_STATE(11739)] = 542863,
  [SMALL_STATE(11740)] = 542904,
  [SMALL_STATE(11741)] = 542945,
  [SMALL_STATE(11742)] = 542986,
  [SMALL_STATE(11743)] = 543027,
  [SMALL_STATE(11744)] = 543068,
  [SMALL_STATE(11745)] = 543109,
  [SMALL_STATE(11746)] = 543150,
  [SMALL_STATE(11747)] = 543191,
  [SMALL_STATE(11748)] = 543232,
  [SMALL_STATE(11749)] = 543273,
  [SMALL_STATE(11750)] = 543314,
  [SMALL_STATE(11751)] = 543355,
  [SMALL_STATE(11752)] = 543396,
  [SMALL_STATE(11753)] = 543437,
  [SMALL_STATE(11754)] = 543478,
  [SMALL_STATE(11755)] = 543519,
  [SMALL_STATE(11756)] = 543560,
  [SMALL_STATE(11757)] = 543601,
  [SMALL_STATE(11758)] = 543642,
  [SMALL_STATE(11759)] = 543683,
  [SMALL_STATE(11760)] = 543724,
  [SMALL_STATE(11761)] = 543765,
  [SMALL_STATE(11762)] = 543806,
  [SMALL_STATE(11763)] = 543847,
  [SMALL_STATE(11764)] = 543888,
  [SMALL_STATE(11765)] = 543929,
  [SMALL_STATE(11766)] = 543970,
  [SMALL_STATE(11767)] = 544011,
  [SMALL_STATE(11768)] = 544052,
  [SMALL_STATE(11769)] = 544093,
  [SMALL_STATE(11770)] = 544134,
  [SMALL_STATE(11771)] = 544175,
  [SMALL_STATE(11772)] = 544216,
  [SMALL_STATE(11773)] = 544257,
  [SMALL_STATE(11774)] = 544298,
  [SMALL_STATE(11775)] = 544339,
  [SMALL_STATE(11776)] = 544380,
  [SMALL_STATE(11777)] = 544421,
  [SMALL_STATE(11778)] = 544462,
  [SMALL_STATE(11779)] = 544503,
  [SMALL_STATE(11780)] = 544544,
  [SMALL_STATE(11781)] = 544585,
  [SMALL_STATE(11782)] = 544626,
  [SMALL_STATE(11783)] = 544667,
  [SMALL_STATE(11784)] = 544708,
  [SMALL_STATE(11785)] = 544735,
  [SMALL_STATE(11786)] = 544761,
  [SMALL_STATE(11787)] = 544801,
  [SMALL_STATE(11788)] = 544827,
  [SMALL_STATE(11789)] = 544865,
  [SMALL_STATE(11790)] = 544905,
  [SMALL_STATE(11791)] = 544937,
  [SMALL_STATE(11792)] = 544963,
  [SMALL_STATE(11793)] = 544991,
  [SMALL_STATE(11794)] = 545017,
  [SMALL_STATE(11795)] = 545043,
  [SMALL_STATE(11796)] = 545071,
  [SMALL_STATE(11797)] = 545097,
  [SMALL_STATE(11798)] = 545123,
  [SMALL_STATE(11799)] = 545149,
  [SMALL_STATE(11800)] = 545177,
  [SMALL_STATE(11801)] = 545205,
  [SMALL_STATE(11802)] = 545231,
  [SMALL_STATE(11803)] = 545271,
  [SMALL_STATE(11804)] = 545311,
  [SMALL_STATE(11805)] = 545337,
  [SMALL_STATE(11806)] = 545377,
  [SMALL_STATE(11807)] = 545403,
  [SMALL_STATE(11808)] = 545433,
  [SMALL_STATE(11809)] = 545459,
  [SMALL_STATE(11810)] = 545501,
  [SMALL_STATE(11811)] = 545527,
  [SMALL_STATE(11812)] = 545553,
  [SMALL_STATE(11813)] = 545593,
  [SMALL_STATE(11814)] = 545621,
  [SMALL_STATE(11815)] = 545647,
  [SMALL_STATE(11816)] = 545675,
  [SMALL_STATE(11817)] = 545701,
  [SMALL_STATE(11818)] = 545727,
  [SMALL_STATE(11819)] = 545753,
  [SMALL_STATE(11820)] = 545779,
  [SMALL_STATE(11821)] = 545819,
  [SMALL_STATE(11822)] = 545845,
  [SMALL_STATE(11823)] = 545885,
  [SMALL_STATE(11824)] = 545925,
  [SMALL_STATE(11825)] = 545951,
  [SMALL_STATE(11826)] = 545977,
  [SMALL_STATE(11827)] = 546003,
  [SMALL_STATE(11828)] = 546029,
  [SMALL_STATE(11829)] = 546069,
  [SMALL_STATE(11830)] = 546109,
  [SMALL_STATE(11831)] = 546135,
  [SMALL_STATE(11832)] = 546175,
  [SMALL_STATE(11833)] = 546215,
  [SMALL_STATE(11834)] = 546247,
  [SMALL_STATE(11835)] = 546287,
  [SMALL_STATE(11836)] = 546327,
  [SMALL_STATE(11837)] = 546367,
  [SMALL_STATE(11838)] = 546393,
  [SMALL_STATE(11839)] = 546421,
  [SMALL_STATE(11840)] = 546461,
  [SMALL_STATE(11841)] = 546501,
  [SMALL_STATE(11842)] = 546527,
  [SMALL_STATE(11843)] = 546553,
  [SMALL_STATE(11844)] = 546583,
  [SMALL_STATE(11845)] = 546613,
  [SMALL_STATE(11846)] = 546653,
  [SMALL_STATE(11847)] = 546693,
  [SMALL_STATE(11848)] = 546733,
  [SMALL_STATE(11849)] = 546759,
  [SMALL_STATE(11850)] = 546799,
  [SMALL_STATE(11851)] = 546825,
  [SMALL_STATE(11852)] = 546851,
  [SMALL_STATE(11853)] = 546877,
  [SMALL_STATE(11854)] = 546917,
  [SMALL_STATE(11855)] = 546943,
  [SMALL_STATE(11856)] = 546969,
  [SMALL_STATE(11857)] = 546995,
  [SMALL_STATE(11858)] = 547027,
  [SMALL_STATE(11859)] = 547055,
  [SMALL_STATE(11860)] = 547093,
  [SMALL_STATE(11861)] = 547125,
  [SMALL_STATE(11862)] = 547155,
  [SMALL_STATE(11863)] = 547185,
  [SMALL_STATE(11864)] = 547217,
  [SMALL_STATE(11865)] = 547243,
  [SMALL_STATE(11866)] = 547273,
  [SMALL_STATE(11867)] = 547313,
  [SMALL_STATE(11868)] = 547343,
  [SMALL_STATE(11869)] = 547369,
  [SMALL_STATE(11870)] = 547399,
  [SMALL_STATE(11871)] = 547429,
  [SMALL_STATE(11872)] = 547469,
  [SMALL_STATE(11873)] = 547495,
  [SMALL_STATE(11874)] = 547537,
  [SMALL_STATE(11875)] = 547567,
  [SMALL_STATE(11876)] = 547593,
  [SMALL_STATE(11877)] = 547633,
  [SMALL_STATE(11878)] = 547659,
  [SMALL_STATE(11879)] = 547685,
  [SMALL_STATE(11880)] = 547725,
  [SMALL_STATE(11881)] = 547765,
  [SMALL_STATE(11882)] = 547805,
  [SMALL_STATE(11883)] = 547831,
  [SMALL_STATE(11884)] = 547859,
  [SMALL_STATE(11885)] = 547899,
  [SMALL_STATE(11886)] = 547925,
  [SMALL_STATE(11887)] = 547965,
  [SMALL_STATE(11888)] = 548005,
  [SMALL_STATE(11889)] = 548045,
  [SMALL_STATE(11890)] = 548085,
  [SMALL_STATE(11891)] = 548111,
  [SMALL_STATE(11892)] = 548143,
  [SMALL_STATE(11893)] = 548173,
  [SMALL_STATE(11894)] = 548203,
  [SMALL_STATE(11895)] = 548235,
  [SMALL_STATE(11896)] = 548265,
  [SMALL_STATE(11897)] = 548295,
  [SMALL_STATE(11898)] = 548321,
  [SMALL_STATE(11899)] = 548347,
  [SMALL_STATE(11900)] = 548373,
  [SMALL_STATE(11901)] = 548399,
  [SMALL_STATE(11902)] = 548427,
  [SMALL_STATE(11903)] = 548467,
  [SMALL_STATE(11904)] = 548507,
  [SMALL_STATE(11905)] = 548533,
  [SMALL_STATE(11906)] = 548559,
  [SMALL_STATE(11907)] = 548585,
  [SMALL_STATE(11908)] = 548611,
  [SMALL_STATE(11909)] = 548639,
  [SMALL_STATE(11910)] = 548665,
  [SMALL_STATE(11911)] = 548705,
  [SMALL_STATE(11912)] = 548745,
  [SMALL_STATE(11913)] = 548785,
  [SMALL_STATE(11914)] = 548825,
  [SMALL_STATE(11915)] = 548851,
  [SMALL_STATE(11916)] = 548891,
  [SMALL_STATE(11917)] = 548917,
  [SMALL_STATE(11918)] = 548957,
  [SMALL_STATE(11919)] = 548997,
  [SMALL_STATE(11920)] = 549023,
  [SMALL_STATE(11921)] = 549049,
  [SMALL_STATE(11922)] = 549089,
  [SMALL_STATE(11923)] = 549129,
  [SMALL_STATE(11924)] = 549169,
  [SMALL_STATE(11925)] = 549209,
  [SMALL_STATE(11926)] = 549239,
  [SMALL_STATE(11927)] = 549269,
  [SMALL_STATE(11928)] = 549309,
  [SMALL_STATE(11929)] = 549339,
  [SMALL_STATE(11930)] = 549365,
  [SMALL_STATE(11931)] = 549391,
  [SMALL_STATE(11932)] = 549419,
  [SMALL_STATE(11933)] = 549459,
  [SMALL_STATE(11934)] = 549485,
  [SMALL_STATE(11935)] = 549523,
  [SMALL_STATE(11936)] = 549549,
  [SMALL_STATE(11937)] = 549575,
  [SMALL_STATE(11938)] = 549601,
  [SMALL_STATE(11939)] = 549641,
  [SMALL_STATE(11940)] = 549667,
  [SMALL_STATE(11941)] = 549693,
  [SMALL_STATE(11942)] = 549721,
  [SMALL_STATE(11943)] = 549747,
  [SMALL_STATE(11944)] = 549787,
  [SMALL_STATE(11945)] = 549825,
  [SMALL_STATE(11946)] = 549855,
  [SMALL_STATE(11947)] = 549895,
  [SMALL_STATE(11948)] = 549935,
  [SMALL_STATE(11949)] = 549961,
  [SMALL_STATE(11950)] = 549987,
  [SMALL_STATE(11951)] = 550013,
  [SMALL_STATE(11952)] = 550039,
  [SMALL_STATE(11953)] = 550073,
  [SMALL_STATE(11954)] = 550099,
  [SMALL_STATE(11955)] = 550129,
  [SMALL_STATE(11956)] = 550169,
  [SMALL_STATE(11957)] = 550195,
  [SMALL_STATE(11958)] = 550221,
  [SMALL_STATE(11959)] = 550247,
  [SMALL_STATE(11960)] = 550287,
  [SMALL_STATE(11961)] = 550327,
  [SMALL_STATE(11962)] = 550357,
  [SMALL_STATE(11963)] = 550383,
  [SMALL_STATE(11964)] = 550423,
  [SMALL_STATE(11965)] = 550463,
  [SMALL_STATE(11966)] = 550503,
  [SMALL_STATE(11967)] = 550529,
  [SMALL_STATE(11968)] = 550555,
  [SMALL_STATE(11969)] = 550595,
  [SMALL_STATE(11970)] = 550625,
  [SMALL_STATE(11971)] = 550655,
  [SMALL_STATE(11972)] = 550695,
  [SMALL_STATE(11973)] = 550721,
  [SMALL_STATE(11974)] = 550761,
  [SMALL_STATE(11975)] = 550801,
  [SMALL_STATE(11976)] = 550841,
  [SMALL_STATE(11977)] = 550879,
  [SMALL_STATE(11978)] = 550911,
  [SMALL_STATE(11979)] = 550937,
  [SMALL_STATE(11980)] = 550963,
  [SMALL_STATE(11981)] = 550989,
  [SMALL_STATE(11982)] = 551029,
  [SMALL_STATE(11983)] = 551059,
  [SMALL_STATE(11984)] = 551085,
  [SMALL_STATE(11985)] = 551111,
  [SMALL_STATE(11986)] = 551137,
  [SMALL_STATE(11987)] = 551163,
  [SMALL_STATE(11988)] = 551189,
  [SMALL_STATE(11989)] = 551227,
  [SMALL_STATE(11990)] = 551253,
  [SMALL_STATE(11991)] = 551293,
  [SMALL_STATE(11992)] = 551319,
  [SMALL_STATE(11993)] = 551349,
  [SMALL_STATE(11994)] = 551379,
  [SMALL_STATE(11995)] = 551405,
  [SMALL_STATE(11996)] = 551431,
  [SMALL_STATE(11997)] = 551457,
  [SMALL_STATE(11998)] = 551497,
  [SMALL_STATE(11999)] = 551523,
  [SMALL_STATE(12000)] = 551549,
  [SMALL_STATE(12001)] = 551577,
  [SMALL_STATE(12002)] = 551615,
  [SMALL_STATE(12003)] = 551641,
  [SMALL_STATE(12004)] = 551667,
  [SMALL_STATE(12005)] = 551695,
  [SMALL_STATE(12006)] = 551727,
  [SMALL_STATE(12007)] = 551753,
  [SMALL_STATE(12008)] = 551779,
  [SMALL_STATE(12009)] = 551805,
  [SMALL_STATE(12010)] = 551831,
  [SMALL_STATE(12011)] = 551857,
  [SMALL_STATE(12012)] = 551897,
  [SMALL_STATE(12013)] = 551923,
  [SMALL_STATE(12014)] = 551949,
  [SMALL_STATE(12015)] = 551975,
  [SMALL_STATE(12016)] = 552001,
  [SMALL_STATE(12017)] = 552041,
  [SMALL_STATE(12018)] = 552081,
  [SMALL_STATE(12019)] = 552121,
  [SMALL_STATE(12020)] = 552147,
  [SMALL_STATE(12021)] = 552173,
  [SMALL_STATE(12022)] = 552213,
  [SMALL_STATE(12023)] = 552241,
  [SMALL_STATE(12024)] = 552271,
  [SMALL_STATE(12025)] = 552311,
  [SMALL_STATE(12026)] = 552351,
  [SMALL_STATE(12027)] = 552377,
  [SMALL_STATE(12028)] = 552417,
  [SMALL_STATE(12029)] = 552443,
  [SMALL_STATE(12030)] = 552469,
  [SMALL_STATE(12031)] = 552507,
  [SMALL_STATE(12032)] = 552535,
  [SMALL_STATE(12033)] = 552575,
  [SMALL_STATE(12034)] = 552601,
  [SMALL_STATE(12035)] = 552641,
  [SMALL_STATE(12036)] = 552669,
  [SMALL_STATE(12037)] = 552709,
  [SMALL_STATE(12038)] = 552735,
  [SMALL_STATE(12039)] = 552763,
  [SMALL_STATE(12040)] = 552803,
  [SMALL_STATE(12041)] = 552833,
  [SMALL_STATE(12042)] = 552859,
  [SMALL_STATE(12043)] = 552899,
  [SMALL_STATE(12044)] = 552939,
  [SMALL_STATE(12045)] = 552979,
  [SMALL_STATE(12046)] = 553019,
  [SMALL_STATE(12047)] = 553059,
  [SMALL_STATE(12048)] = 553087,
  [SMALL_STATE(12049)] = 553117,
  [SMALL_STATE(12050)] = 553149,
  [SMALL_STATE(12051)] = 553189,
  [SMALL_STATE(12052)] = 553215,
  [SMALL_STATE(12053)] = 553241,
  [SMALL_STATE(12054)] = 553281,
  [SMALL_STATE(12055)] = 553321,
  [SMALL_STATE(12056)] = 553361,
  [SMALL_STATE(12057)] = 553389,
  [SMALL_STATE(12058)] = 553429,
  [SMALL_STATE(12059)] = 553455,
  [SMALL_STATE(12060)] = 553481,
  [SMALL_STATE(12061)] = 553507,
  [SMALL_STATE(12062)] = 553533,
  [SMALL_STATE(12063)] = 553559,
  [SMALL_STATE(12064)] = 553599,
  [SMALL_STATE(12065)] = 553639,
  [SMALL_STATE(12066)] = 553665,
  [SMALL_STATE(12067)] = 553693,
  [SMALL_STATE(12068)] = 553719,
  [SMALL_STATE(12069)] = 553759,
  [SMALL_STATE(12070)] = 553797,
  [SMALL_STATE(12071)] = 553837,
  [SMALL_STATE(12072)] = 553863,
  [SMALL_STATE(12073)] = 553889,
  [SMALL_STATE(12074)] = 553931,
  [SMALL_STATE(12075)] = 553971,
  [SMALL_STATE(12076)] = 554011,
  [SMALL_STATE(12077)] = 554051,
  [SMALL_STATE(12078)] = 554091,
  [SMALL_STATE(12079)] = 554117,
  [SMALL_STATE(12080)] = 554157,
  [SMALL_STATE(12081)] = 554183,
  [SMALL_STATE(12082)] = 554209,
  [SMALL_STATE(12083)] = 554249,
  [SMALL_STATE(12084)] = 554289,
  [SMALL_STATE(12085)] = 554321,
  [SMALL_STATE(12086)] = 554347,
  [SMALL_STATE(12087)] = 554373,
  [SMALL_STATE(12088)] = 554399,
  [SMALL_STATE(12089)] = 554425,
  [SMALL_STATE(12090)] = 554465,
  [SMALL_STATE(12091)] = 554491,
  [SMALL_STATE(12092)] = 554531,
  [SMALL_STATE(12093)] = 554557,
  [SMALL_STATE(12094)] = 554583,
  [SMALL_STATE(12095)] = 554609,
  [SMALL_STATE(12096)] = 554635,
  [SMALL_STATE(12097)] = 554675,
  [SMALL_STATE(12098)] = 554715,
  [SMALL_STATE(12099)] = 554741,
  [SMALL_STATE(12100)] = 554781,
  [SMALL_STATE(12101)] = 554807,
  [SMALL_STATE(12102)] = 554847,
  [SMALL_STATE(12103)] = 554873,
  [SMALL_STATE(12104)] = 554913,
  [SMALL_STATE(12105)] = 554953,
  [SMALL_STATE(12106)] = 554993,
  [SMALL_STATE(12107)] = 555033,
  [SMALL_STATE(12108)] = 555073,
  [SMALL_STATE(12109)] = 555099,
  [SMALL_STATE(12110)] = 555125,
  [SMALL_STATE(12111)] = 555165,
  [SMALL_STATE(12112)] = 555205,
  [SMALL_STATE(12113)] = 555247,
  [SMALL_STATE(12114)] = 555287,
  [SMALL_STATE(12115)] = 555315,
  [SMALL_STATE(12116)] = 555345,
  [SMALL_STATE(12117)] = 555385,
  [SMALL_STATE(12118)] = 555425,
  [SMALL_STATE(12119)] = 555465,
  [SMALL_STATE(12120)] = 555491,
  [SMALL_STATE(12121)] = 555531,
  [SMALL_STATE(12122)] = 555571,
  [SMALL_STATE(12123)] = 555611,
  [SMALL_STATE(12124)] = 555651,
  [SMALL_STATE(12125)] = 555691,
  [SMALL_STATE(12126)] = 555717,
  [SMALL_STATE(12127)] = 555757,
  [SMALL_STATE(12128)] = 555797,
  [SMALL_STATE(12129)] = 555837,
  [SMALL_STATE(12130)] = 555863,
  [SMALL_STATE(12131)] = 555903,
  [SMALL_STATE(12132)] = 555943,
  [SMALL_STATE(12133)] = 555969,
  [SMALL_STATE(12134)] = 555995,
  [SMALL_STATE(12135)] = 556035,
  [SMALL_STATE(12136)] = 556061,
  [SMALL_STATE(12137)] = 556101,
  [SMALL_STATE(12138)] = 556141,
  [SMALL_STATE(12139)] = 556181,
  [SMALL_STATE(12140)] = 556209,
  [SMALL_STATE(12141)] = 556249,
  [SMALL_STATE(12142)] = 556289,
  [SMALL_STATE(12143)] = 556315,
  [SMALL_STATE(12144)] = 556353,
  [SMALL_STATE(12145)] = 556393,
  [SMALL_STATE(12146)] = 556433,
  [SMALL_STATE(12147)] = 556473,
  [SMALL_STATE(12148)] = 556513,
  [SMALL_STATE(12149)] = 556553,
  [SMALL_STATE(12150)] = 556581,
  [SMALL_STATE(12151)] = 556609,
  [SMALL_STATE(12152)] = 556637,
  [SMALL_STATE(12153)] = 556665,
  [SMALL_STATE(12154)] = 556693,
  [SMALL_STATE(12155)] = 556731,
  [SMALL_STATE(12156)] = 556771,
  [SMALL_STATE(12157)] = 556797,
  [SMALL_STATE(12158)] = 556823,
  [SMALL_STATE(12159)] = 556863,
  [SMALL_STATE(12160)] = 556903,
  [SMALL_STATE(12161)] = 556929,
  [SMALL_STATE(12162)] = 556955,
  [SMALL_STATE(12163)] = 556981,
  [SMALL_STATE(12164)] = 557007,
  [SMALL_STATE(12165)] = 557033,
  [SMALL_STATE(12166)] = 557061,
  [SMALL_STATE(12167)] = 557087,
  [SMALL_STATE(12168)] = 557115,
  [SMALL_STATE(12169)] = 557155,
  [SMALL_STATE(12170)] = 557195,
  [SMALL_STATE(12171)] = 557221,
  [SMALL_STATE(12172)] = 557247,
  [SMALL_STATE(12173)] = 557273,
  [SMALL_STATE(12174)] = 557299,
  [SMALL_STATE(12175)] = 557332,
  [SMALL_STATE(12176)] = 557357,
  [SMALL_STATE(12177)] = 557382,
  [SMALL_STATE(12178)] = 557407,
  [SMALL_STATE(12179)] = 557444,
  [SMALL_STATE(12180)] = 557469,
  [SMALL_STATE(12181)] = 557494,
  [SMALL_STATE(12182)] = 557531,
  [SMALL_STATE(12183)] = 557564,
  [SMALL_STATE(12184)] = 557601,
  [SMALL_STATE(12185)] = 557638,
  [SMALL_STATE(12186)] = 557675,
  [SMALL_STATE(12187)] = 557712,
  [SMALL_STATE(12188)] = 557749,
  [SMALL_STATE(12189)] = 557780,
  [SMALL_STATE(12190)] = 557817,
  [SMALL_STATE(12191)] = 557854,
  [SMALL_STATE(12192)] = 557891,
  [SMALL_STATE(12193)] = 557928,
  [SMALL_STATE(12194)] = 557955,
  [SMALL_STATE(12195)] = 557984,
  [SMALL_STATE(12196)] = 558021,
  [SMALL_STATE(12197)] = 558058,
  [SMALL_STATE(12198)] = 558095,
  [SMALL_STATE(12199)] = 558122,
  [SMALL_STATE(12200)] = 558159,
  [SMALL_STATE(12201)] = 558196,
  [SMALL_STATE(12202)] = 558233,
  [SMALL_STATE(12203)] = 558270,
  [SMALL_STATE(12204)] = 558307,
  [SMALL_STATE(12205)] = 558332,
  [SMALL_STATE(12206)] = 558359,
  [SMALL_STATE(12207)] = 558396,
  [SMALL_STATE(12208)] = 558433,
  [SMALL_STATE(12209)] = 558470,
  [SMALL_STATE(12210)] = 558507,
  [SMALL_STATE(12211)] = 558540,
  [SMALL_STATE(12212)] = 558577,
  [SMALL_STATE(12213)] = 558610,
  [SMALL_STATE(12214)] = 558647,
  [SMALL_STATE(12215)] = 558684,
  [SMALL_STATE(12216)] = 558709,
  [SMALL_STATE(12217)] = 558746,
  [SMALL_STATE(12218)] = 558783,
  [SMALL_STATE(12219)] = 558822,
  [SMALL_STATE(12220)] = 558859,
  [SMALL_STATE(12221)] = 558896,
  [SMALL_STATE(12222)] = 558933,
  [SMALL_STATE(12223)] = 558970,
  [SMALL_STATE(12224)] = 559007,
  [SMALL_STATE(12225)] = 559044,
  [SMALL_STATE(12226)] = 559081,
  [SMALL_STATE(12227)] = 559118,
  [SMALL_STATE(12228)] = 559145,
  [SMALL_STATE(12229)] = 559182,
  [SMALL_STATE(12230)] = 559219,
  [SMALL_STATE(12231)] = 559244,
  [SMALL_STATE(12232)] = 559281,
  [SMALL_STATE(12233)] = 559306,
  [SMALL_STATE(12234)] = 559331,
  [SMALL_STATE(12235)] = 559368,
  [SMALL_STATE(12236)] = 559393,
  [SMALL_STATE(12237)] = 559430,
  [SMALL_STATE(12238)] = 559455,
  [SMALL_STATE(12239)] = 559492,
  [SMALL_STATE(12240)] = 559517,
  [SMALL_STATE(12241)] = 559554,
  [SMALL_STATE(12242)] = 559579,
  [SMALL_STATE(12243)] = 559616,
  [SMALL_STATE(12244)] = 559653,
  [SMALL_STATE(12245)] = 559690,
  [SMALL_STATE(12246)] = 559727,
  [SMALL_STATE(12247)] = 559764,
  [SMALL_STATE(12248)] = 559801,
  [SMALL_STATE(12249)] = 559838,
  [SMALL_STATE(12250)] = 559875,
  [SMALL_STATE(12251)] = 559912,
  [SMALL_STATE(12252)] = 559953,
  [SMALL_STATE(12253)] = 559990,
  [SMALL_STATE(12254)] = 560027,
  [SMALL_STATE(12255)] = 560064,
  [SMALL_STATE(12256)] = 560101,
  [SMALL_STATE(12257)] = 560138,
  [SMALL_STATE(12258)] = 560175,
  [SMALL_STATE(12259)] = 560212,
  [SMALL_STATE(12260)] = 560237,
  [SMALL_STATE(12261)] = 560264,
  [SMALL_STATE(12262)] = 560301,
  [SMALL_STATE(12263)] = 560338,
  [SMALL_STATE(12264)] = 560375,
  [SMALL_STATE(12265)] = 560412,
  [SMALL_STATE(12266)] = 560449,
  [SMALL_STATE(12267)] = 560486,
  [SMALL_STATE(12268)] = 560511,
  [SMALL_STATE(12269)] = 560548,
  [SMALL_STATE(12270)] = 560579,
  [SMALL_STATE(12271)] = 560616,
  [SMALL_STATE(12272)] = 560645,
  [SMALL_STATE(12273)] = 560682,
  [SMALL_STATE(12274)] = 560719,
  [SMALL_STATE(12275)] = 560750,
  [SMALL_STATE(12276)] = 560787,
  [SMALL_STATE(12277)] = 560824,
  [SMALL_STATE(12278)] = 560861,
  [SMALL_STATE(12279)] = 560898,
  [SMALL_STATE(12280)] = 560935,
  [SMALL_STATE(12281)] = 560972,
  [SMALL_STATE(12282)] = 561009,
  [SMALL_STATE(12283)] = 561046,
  [SMALL_STATE(12284)] = 561083,
  [SMALL_STATE(12285)] = 561120,
  [SMALL_STATE(12286)] = 561145,
  [SMALL_STATE(12287)] = 561182,
  [SMALL_STATE(12288)] = 561219,
  [SMALL_STATE(12289)] = 561256,
  [SMALL_STATE(12290)] = 561293,
  [SMALL_STATE(12291)] = 561318,
  [SMALL_STATE(12292)] = 561355,
  [SMALL_STATE(12293)] = 561392,
  [SMALL_STATE(12294)] = 561429,
  [SMALL_STATE(12295)] = 561462,
  [SMALL_STATE(12296)] = 561495,
  [SMALL_STATE(12297)] = 561528,
  [SMALL_STATE(12298)] = 561561,
  [SMALL_STATE(12299)] = 561598,
  [SMALL_STATE(12300)] = 561635,
  [SMALL_STATE(12301)] = 561662,
  [SMALL_STATE(12302)] = 561703,
  [SMALL_STATE(12303)] = 561740,
  [SMALL_STATE(12304)] = 561765,
  [SMALL_STATE(12305)] = 561790,
  [SMALL_STATE(12306)] = 561815,
  [SMALL_STATE(12307)] = 561840,
  [SMALL_STATE(12308)] = 561865,
  [SMALL_STATE(12309)] = 561890,
  [SMALL_STATE(12310)] = 561915,
  [SMALL_STATE(12311)] = 561940,
  [SMALL_STATE(12312)] = 561977,
  [SMALL_STATE(12313)] = 562014,
  [SMALL_STATE(12314)] = 562051,
  [SMALL_STATE(12315)] = 562084,
  [SMALL_STATE(12316)] = 562121,
  [SMALL_STATE(12317)] = 562158,
  [SMALL_STATE(12318)] = 562195,
  [SMALL_STATE(12319)] = 562232,
  [SMALL_STATE(12320)] = 562269,
  [SMALL_STATE(12321)] = 562296,
  [SMALL_STATE(12322)] = 562333,
  [SMALL_STATE(12323)] = 562370,
  [SMALL_STATE(12324)] = 562407,
  [SMALL_STATE(12325)] = 562444,
  [SMALL_STATE(12326)] = 562481,
  [SMALL_STATE(12327)] = 562518,
  [SMALL_STATE(12328)] = 562555,
  [SMALL_STATE(12329)] = 562592,
  [SMALL_STATE(12330)] = 562627,
  [SMALL_STATE(12331)] = 562658,
  [SMALL_STATE(12332)] = 562695,
  [SMALL_STATE(12333)] = 562732,
  [SMALL_STATE(12334)] = 562757,
  [SMALL_STATE(12335)] = 562794,
  [SMALL_STATE(12336)] = 562821,
  [SMALL_STATE(12337)] = 562858,
  [SMALL_STATE(12338)] = 562883,
  [SMALL_STATE(12339)] = 562920,
  [SMALL_STATE(12340)] = 562947,
  [SMALL_STATE(12341)] = 562984,
  [SMALL_STATE(12342)] = 563009,
  [SMALL_STATE(12343)] = 563046,
  [SMALL_STATE(12344)] = 563091,
  [SMALL_STATE(12345)] = 563124,
  [SMALL_STATE(12346)] = 563149,
  [SMALL_STATE(12347)] = 563186,
  [SMALL_STATE(12348)] = 563223,
  [SMALL_STATE(12349)] = 563260,
  [SMALL_STATE(12350)] = 563297,
  [SMALL_STATE(12351)] = 563334,
  [SMALL_STATE(12352)] = 563365,
  [SMALL_STATE(12353)] = 563402,
  [SMALL_STATE(12354)] = 563439,
  [SMALL_STATE(12355)] = 563476,
  [SMALL_STATE(12356)] = 563513,
  [SMALL_STATE(12357)] = 563544,
  [SMALL_STATE(12358)] = 563581,
  [SMALL_STATE(12359)] = 563618,
  [SMALL_STATE(12360)] = 563651,
  [SMALL_STATE(12361)] = 563680,
  [SMALL_STATE(12362)] = 563713,
  [SMALL_STATE(12363)] = 563746,
  [SMALL_STATE(12364)] = 563787,
  [SMALL_STATE(12365)] = 563812,
  [SMALL_STATE(12366)] = 563837,
  [SMALL_STATE(12367)] = 563862,
  [SMALL_STATE(12368)] = 563899,
  [SMALL_STATE(12369)] = 563936,
  [SMALL_STATE(12370)] = 563961,
  [SMALL_STATE(12371)] = 563998,
  [SMALL_STATE(12372)] = 564023,
  [SMALL_STATE(12373)] = 564048,
  [SMALL_STATE(12374)] = 564085,
  [SMALL_STATE(12375)] = 564112,
  [SMALL_STATE(12376)] = 564149,
  [SMALL_STATE(12377)] = 564186,
  [SMALL_STATE(12378)] = 564211,
  [SMALL_STATE(12379)] = 564236,
  [SMALL_STATE(12380)] = 564273,
  [SMALL_STATE(12381)] = 564298,
  [SMALL_STATE(12382)] = 564335,
  [SMALL_STATE(12383)] = 564360,
  [SMALL_STATE(12384)] = 564385,
  [SMALL_STATE(12385)] = 564410,
  [SMALL_STATE(12386)] = 564435,
  [SMALL_STATE(12387)] = 564472,
  [SMALL_STATE(12388)] = 564497,
  [SMALL_STATE(12389)] = 564522,
  [SMALL_STATE(12390)] = 564559,
  [SMALL_STATE(12391)] = 564584,
  [SMALL_STATE(12392)] = 564621,
  [SMALL_STATE(12393)] = 564646,
  [SMALL_STATE(12394)] = 564683,
  [SMALL_STATE(12395)] = 564708,
  [SMALL_STATE(12396)] = 564739,
  [SMALL_STATE(12397)] = 564764,
  [SMALL_STATE(12398)] = 564801,
  [SMALL_STATE(12399)] = 564838,
  [SMALL_STATE(12400)] = 564863,
  [SMALL_STATE(12401)] = 564888,
  [SMALL_STATE(12402)] = 564921,
  [SMALL_STATE(12403)] = 564958,
  [SMALL_STATE(12404)] = 564983,
  [SMALL_STATE(12405)] = 565020,
  [SMALL_STATE(12406)] = 565057,
  [SMALL_STATE(12407)] = 565094,
  [SMALL_STATE(12408)] = 565119,
  [SMALL_STATE(12409)] = 565152,
  [SMALL_STATE(12410)] = 565189,
  [SMALL_STATE(12411)] = 565214,
  [SMALL_STATE(12412)] = 565251,
  [SMALL_STATE(12413)] = 565276,
  [SMALL_STATE(12414)] = 565301,
  [SMALL_STATE(12415)] = 565338,
  [SMALL_STATE(12416)] = 565375,
  [SMALL_STATE(12417)] = 565412,
  [SMALL_STATE(12418)] = 565449,
  [SMALL_STATE(12419)] = 565474,
  [SMALL_STATE(12420)] = 565499,
  [SMALL_STATE(12421)] = 565536,
  [SMALL_STATE(12422)] = 565573,
  [SMALL_STATE(12423)] = 565610,
  [SMALL_STATE(12424)] = 565639,
  [SMALL_STATE(12425)] = 565676,
  [SMALL_STATE(12426)] = 565713,
  [SMALL_STATE(12427)] = 565750,
  [SMALL_STATE(12428)] = 565775,
  [SMALL_STATE(12429)] = 565812,
  [SMALL_STATE(12430)] = 565849,
  [SMALL_STATE(12431)] = 565886,
  [SMALL_STATE(12432)] = 565919,
  [SMALL_STATE(12433)] = 565956,
  [SMALL_STATE(12434)] = 565993,
  [SMALL_STATE(12435)] = 566018,
  [SMALL_STATE(12436)] = 566043,
  [SMALL_STATE(12437)] = 566080,
  [SMALL_STATE(12438)] = 566117,
  [SMALL_STATE(12439)] = 566154,
  [SMALL_STATE(12440)] = 566191,
  [SMALL_STATE(12441)] = 566216,
  [SMALL_STATE(12442)] = 566253,
  [SMALL_STATE(12443)] = 566278,
  [SMALL_STATE(12444)] = 566303,
  [SMALL_STATE(12445)] = 566328,
  [SMALL_STATE(12446)] = 566365,
  [SMALL_STATE(12447)] = 566390,
  [SMALL_STATE(12448)] = 566415,
  [SMALL_STATE(12449)] = 566452,
  [SMALL_STATE(12450)] = 566477,
  [SMALL_STATE(12451)] = 566514,
  [SMALL_STATE(12452)] = 566551,
  [SMALL_STATE(12453)] = 566588,
  [SMALL_STATE(12454)] = 566613,
  [SMALL_STATE(12455)] = 566640,
  [SMALL_STATE(12456)] = 566677,
  [SMALL_STATE(12457)] = 566702,
  [SMALL_STATE(12458)] = 566739,
  [SMALL_STATE(12459)] = 566776,
  [SMALL_STATE(12460)] = 566801,
  [SMALL_STATE(12461)] = 566838,
  [SMALL_STATE(12462)] = 566863,
  [SMALL_STATE(12463)] = 566900,
  [SMALL_STATE(12464)] = 566937,
  [SMALL_STATE(12465)] = 566962,
  [SMALL_STATE(12466)] = 566987,
  [SMALL_STATE(12467)] = 567024,
  [SMALL_STATE(12468)] = 567061,
  [SMALL_STATE(12469)] = 567098,
  [SMALL_STATE(12470)] = 567135,
  [SMALL_STATE(12471)] = 567172,
  [SMALL_STATE(12472)] = 567201,
  [SMALL_STATE(12473)] = 567226,
  [SMALL_STATE(12474)] = 567263,
  [SMALL_STATE(12475)] = 567288,
  [SMALL_STATE(12476)] = 567317,
  [SMALL_STATE(12477)] = 567344,
  [SMALL_STATE(12478)] = 567371,
  [SMALL_STATE(12479)] = 567408,
  [SMALL_STATE(12480)] = 567435,
  [SMALL_STATE(12481)] = 567472,
  [SMALL_STATE(12482)] = 567509,
  [SMALL_STATE(12483)] = 567534,
  [SMALL_STATE(12484)] = 567571,
  [SMALL_STATE(12485)] = 567608,
  [SMALL_STATE(12486)] = 567645,
  [SMALL_STATE(12487)] = 567676,
  [SMALL_STATE(12488)] = 567703,
  [SMALL_STATE(12489)] = 567740,
  [SMALL_STATE(12490)] = 567777,
  [SMALL_STATE(12491)] = 567806,
  [SMALL_STATE(12492)] = 567835,
  [SMALL_STATE(12493)] = 567866,
  [SMALL_STATE(12494)] = 567895,
  [SMALL_STATE(12495)] = 567924,
  [SMALL_STATE(12496)] = 567961,
  [SMALL_STATE(12497)] = 567998,
  [SMALL_STATE(12498)] = 568035,
  [SMALL_STATE(12499)] = 568066,
  [SMALL_STATE(12500)] = 568091,
  [SMALL_STATE(12501)] = 568128,
  [SMALL_STATE(12502)] = 568157,
  [SMALL_STATE(12503)] = 568186,
  [SMALL_STATE(12504)] = 568217,
  [SMALL_STATE(12505)] = 568246,
  [SMALL_STATE(12506)] = 568275,
  [SMALL_STATE(12507)] = 568312,
  [SMALL_STATE(12508)] = 568341,
  [SMALL_STATE(12509)] = 568370,
  [SMALL_STATE(12510)] = 568395,
  [SMALL_STATE(12511)] = 568432,
  [SMALL_STATE(12512)] = 568469,
  [SMALL_STATE(12513)] = 568506,
  [SMALL_STATE(12514)] = 568543,
  [SMALL_STATE(12515)] = 568580,
  [SMALL_STATE(12516)] = 568605,
  [SMALL_STATE(12517)] = 568642,
  [SMALL_STATE(12518)] = 568669,
  [SMALL_STATE(12519)] = 568706,
  [SMALL_STATE(12520)] = 568743,
  [SMALL_STATE(12521)] = 568780,
  [SMALL_STATE(12522)] = 568817,
  [SMALL_STATE(12523)] = 568854,
  [SMALL_STATE(12524)] = 568885,
  [SMALL_STATE(12525)] = 568922,
  [SMALL_STATE(12526)] = 568947,
  [SMALL_STATE(12527)] = 568984,
  [SMALL_STATE(12528)] = 569021,
  [SMALL_STATE(12529)] = 569058,
  [SMALL_STATE(12530)] = 569095,
  [SMALL_STATE(12531)] = 569132,
  [SMALL_STATE(12532)] = 569169,
  [SMALL_STATE(12533)] = 569198,
  [SMALL_STATE(12534)] = 569235,
  [SMALL_STATE(12535)] = 569260,
  [SMALL_STATE(12536)] = 569297,
  [SMALL_STATE(12537)] = 569324,
  [SMALL_STATE(12538)] = 569361,
  [SMALL_STATE(12539)] = 569398,
  [SMALL_STATE(12540)] = 569435,
  [SMALL_STATE(12541)] = 569472,
  [SMALL_STATE(12542)] = 569507,
  [SMALL_STATE(12543)] = 569544,
  [SMALL_STATE(12544)] = 569581,
  [SMALL_STATE(12545)] = 569618,
  [SMALL_STATE(12546)] = 569655,
  [SMALL_STATE(12547)] = 569692,
  [SMALL_STATE(12548)] = 569729,
  [SMALL_STATE(12549)] = 569766,
  [SMALL_STATE(12550)] = 569803,
  [SMALL_STATE(12551)] = 569840,
  [SMALL_STATE(12552)] = 569865,
  [SMALL_STATE(12553)] = 569890,
  [SMALL_STATE(12554)] = 569915,
  [SMALL_STATE(12555)] = 569952,
  [SMALL_STATE(12556)] = 569977,
  [SMALL_STATE(12557)] = 570006,
  [SMALL_STATE(12558)] = 570033,
  [SMALL_STATE(12559)] = 570058,
  [SMALL_STATE(12560)] = 570093,
  [SMALL_STATE(12561)] = 570128,
  [SMALL_STATE(12562)] = 570165,
  [SMALL_STATE(12563)] = 570202,
  [SMALL_STATE(12564)] = 570239,
  [SMALL_STATE(12565)] = 570276,
  [SMALL_STATE(12566)] = 570313,
  [SMALL_STATE(12567)] = 570350,
  [SMALL_STATE(12568)] = 570387,
  [SMALL_STATE(12569)] = 570424,
  [SMALL_STATE(12570)] = 570461,
  [SMALL_STATE(12571)] = 570498,
  [SMALL_STATE(12572)] = 570535,
  [SMALL_STATE(12573)] = 570572,
  [SMALL_STATE(12574)] = 570609,
  [SMALL_STATE(12575)] = 570646,
  [SMALL_STATE(12576)] = 570683,
  [SMALL_STATE(12577)] = 570720,
  [SMALL_STATE(12578)] = 570745,
  [SMALL_STATE(12579)] = 570782,
  [SMALL_STATE(12580)] = 570807,
  [SMALL_STATE(12581)] = 570832,
  [SMALL_STATE(12582)] = 570857,
  [SMALL_STATE(12583)] = 570894,
  [SMALL_STATE(12584)] = 570919,
  [SMALL_STATE(12585)] = 570950,
  [SMALL_STATE(12586)] = 570983,
  [SMALL_STATE(12587)] = 571020,
  [SMALL_STATE(12588)] = 571045,
  [SMALL_STATE(12589)] = 571074,
  [SMALL_STATE(12590)] = 571111,
  [SMALL_STATE(12591)] = 571148,
  [SMALL_STATE(12592)] = 571177,
  [SMALL_STATE(12593)] = 571214,
  [SMALL_STATE(12594)] = 571251,
  [SMALL_STATE(12595)] = 571276,
  [SMALL_STATE(12596)] = 571301,
  [SMALL_STATE(12597)] = 571326,
  [SMALL_STATE(12598)] = 571363,
  [SMALL_STATE(12599)] = 571390,
  [SMALL_STATE(12600)] = 571415,
  [SMALL_STATE(12601)] = 571440,
  [SMALL_STATE(12602)] = 571467,
  [SMALL_STATE(12603)] = 571494,
  [SMALL_STATE(12604)] = 571519,
  [SMALL_STATE(12605)] = 571556,
  [SMALL_STATE(12606)] = 571593,
  [SMALL_STATE(12607)] = 571618,
  [SMALL_STATE(12608)] = 571655,
  [SMALL_STATE(12609)] = 571692,
  [SMALL_STATE(12610)] = 571719,
  [SMALL_STATE(12611)] = 571744,
  [SMALL_STATE(12612)] = 571769,
  [SMALL_STATE(12613)] = 571794,
  [SMALL_STATE(12614)] = 571819,
  [SMALL_STATE(12615)] = 571856,
  [SMALL_STATE(12616)] = 571893,
  [SMALL_STATE(12617)] = 571930,
  [SMALL_STATE(12618)] = 571955,
  [SMALL_STATE(12619)] = 571992,
  [SMALL_STATE(12620)] = 572021,
  [SMALL_STATE(12621)] = 572046,
  [SMALL_STATE(12622)] = 572079,
  [SMALL_STATE(12623)] = 572116,
  [SMALL_STATE(12624)] = 572141,
  [SMALL_STATE(12625)] = 572166,
  [SMALL_STATE(12626)] = 572203,
  [SMALL_STATE(12627)] = 572230,
  [SMALL_STATE(12628)] = 572267,
  [SMALL_STATE(12629)] = 572304,
  [SMALL_STATE(12630)] = 572341,
  [SMALL_STATE(12631)] = 572366,
  [SMALL_STATE(12632)] = 572393,
  [SMALL_STATE(12633)] = 572430,
  [SMALL_STATE(12634)] = 572467,
  [SMALL_STATE(12635)] = 572504,
  [SMALL_STATE(12636)] = 572541,
  [SMALL_STATE(12637)] = 572578,
  [SMALL_STATE(12638)] = 572615,
  [SMALL_STATE(12639)] = 572652,
  [SMALL_STATE(12640)] = 572689,
  [SMALL_STATE(12641)] = 572717,
  [SMALL_STATE(12642)] = 572741,
  [SMALL_STATE(12643)] = 572773,
  [SMALL_STATE(12644)] = 572797,
  [SMALL_STATE(12645)] = 572821,
  [SMALL_STATE(12646)] = 572845,
  [SMALL_STATE(12647)] = 572869,
  [SMALL_STATE(12648)] = 572903,
  [SMALL_STATE(12649)] = 572927,
  [SMALL_STATE(12650)] = 572951,
  [SMALL_STATE(12651)] = 572975,
  [SMALL_STATE(12652)] = 573009,
  [SMALL_STATE(12653)] = 573033,
  [SMALL_STATE(12654)] = 573065,
  [SMALL_STATE(12655)] = 573099,
  [SMALL_STATE(12656)] = 573123,
  [SMALL_STATE(12657)] = 573157,
  [SMALL_STATE(12658)] = 573181,
  [SMALL_STATE(12659)] = 573205,
  [SMALL_STATE(12660)] = 573229,
  [SMALL_STATE(12661)] = 573257,
  [SMALL_STATE(12662)] = 573291,
  [SMALL_STATE(12663)] = 573325,
  [SMALL_STATE(12664)] = 573353,
  [SMALL_STATE(12665)] = 573387,
  [SMALL_STATE(12666)] = 573421,
  [SMALL_STATE(12667)] = 573449,
  [SMALL_STATE(12668)] = 573483,
  [SMALL_STATE(12669)] = 573511,
  [SMALL_STATE(12670)] = 573543,
  [SMALL_STATE(12671)] = 573567,
  [SMALL_STATE(12672)] = 573591,
  [SMALL_STATE(12673)] = 573615,
  [SMALL_STATE(12674)] = 573639,
  [SMALL_STATE(12675)] = 573663,
  [SMALL_STATE(12676)] = 573697,
  [SMALL_STATE(12677)] = 573733,
  [SMALL_STATE(12678)] = 573761,
  [SMALL_STATE(12679)] = 573793,
  [SMALL_STATE(12680)] = 573827,
  [SMALL_STATE(12681)] = 573851,
  [SMALL_STATE(12682)] = 573875,
  [SMALL_STATE(12683)] = 573899,
  [SMALL_STATE(12684)] = 573933,
  [SMALL_STATE(12685)] = 573957,
  [SMALL_STATE(12686)] = 573989,
  [SMALL_STATE(12687)] = 574013,
  [SMALL_STATE(12688)] = 574037,
  [SMALL_STATE(12689)] = 574071,
  [SMALL_STATE(12690)] = 574099,
  [SMALL_STATE(12691)] = 574123,
  [SMALL_STATE(12692)] = 574149,
  [SMALL_STATE(12693)] = 574183,
  [SMALL_STATE(12694)] = 574207,
  [SMALL_STATE(12695)] = 574231,
  [SMALL_STATE(12696)] = 574255,
  [SMALL_STATE(12697)] = 574279,
  [SMALL_STATE(12698)] = 574303,
  [SMALL_STATE(12699)] = 574337,
  [SMALL_STATE(12700)] = 574371,
  [SMALL_STATE(12701)] = 574405,
  [SMALL_STATE(12702)] = 574437,
  [SMALL_STATE(12703)] = 574461,
  [SMALL_STATE(12704)] = 574487,
  [SMALL_STATE(12705)] = 574511,
  [SMALL_STATE(12706)] = 574539,
  [SMALL_STATE(12707)] = 574573,
  [SMALL_STATE(12708)] = 574601,
  [SMALL_STATE(12709)] = 574633,
  [SMALL_STATE(12710)] = 574657,
  [SMALL_STATE(12711)] = 574681,
  [SMALL_STATE(12712)] = 574705,
  [SMALL_STATE(12713)] = 574739,
  [SMALL_STATE(12714)] = 574763,
  [SMALL_STATE(12715)] = 574797,
  [SMALL_STATE(12716)] = 574831,
  [SMALL_STATE(12717)] = 574865,
  [SMALL_STATE(12718)] = 574897,
  [SMALL_STATE(12719)] = 574921,
  [SMALL_STATE(12720)] = 574945,
  [SMALL_STATE(12721)] = 574969,
  [SMALL_STATE(12722)] = 574993,
  [SMALL_STATE(12723)] = 575029,
  [SMALL_STATE(12724)] = 575053,
  [SMALL_STATE(12725)] = 575087,
  [SMALL_STATE(12726)] = 575113,
  [SMALL_STATE(12727)] = 575137,
  [SMALL_STATE(12728)] = 575171,
  [SMALL_STATE(12729)] = 575195,
  [SMALL_STATE(12730)] = 575219,
  [SMALL_STATE(12731)] = 575253,
  [SMALL_STATE(12732)] = 575277,
  [SMALL_STATE(12733)] = 575301,
  [SMALL_STATE(12734)] = 575325,
  [SMALL_STATE(12735)] = 575359,
  [SMALL_STATE(12736)] = 575383,
  [SMALL_STATE(12737)] = 575407,
  [SMALL_STATE(12738)] = 575441,
  [SMALL_STATE(12739)] = 575475,
  [SMALL_STATE(12740)] = 575499,
  [SMALL_STATE(12741)] = 575523,
  [SMALL_STATE(12742)] = 575547,
  [SMALL_STATE(12743)] = 575571,
  [SMALL_STATE(12744)] = 575605,
  [SMALL_STATE(12745)] = 575629,
  [SMALL_STATE(12746)] = 575653,
  [SMALL_STATE(12747)] = 575677,
  [SMALL_STATE(12748)] = 575701,
  [SMALL_STATE(12749)] = 575733,
  [SMALL_STATE(12750)] = 575757,
  [SMALL_STATE(12751)] = 575791,
  [SMALL_STATE(12752)] = 575815,
  [SMALL_STATE(12753)] = 575839,
  [SMALL_STATE(12754)] = 575863,
  [SMALL_STATE(12755)] = 575887,
  [SMALL_STATE(12756)] = 575921,
  [SMALL_STATE(12757)] = 575953,
  [SMALL_STATE(12758)] = 575977,
  [SMALL_STATE(12759)] = 576007,
  [SMALL_STATE(12760)] = 576033,
  [SMALL_STATE(12761)] = 576067,
  [SMALL_STATE(12762)] = 576091,
  [SMALL_STATE(12763)] = 576125,
  [SMALL_STATE(12764)] = 576159,
  [SMALL_STATE(12765)] = 576203,
  [SMALL_STATE(12766)] = 576239,
  [SMALL_STATE(12767)] = 576267,
  [SMALL_STATE(12768)] = 576301,
  [SMALL_STATE(12769)] = 576333,
  [SMALL_STATE(12770)] = 576357,
  [SMALL_STATE(12771)] = 576387,
  [SMALL_STATE(12772)] = 576421,
  [SMALL_STATE(12773)] = 576451,
  [SMALL_STATE(12774)] = 576487,
  [SMALL_STATE(12775)] = 576515,
  [SMALL_STATE(12776)] = 576549,
  [SMALL_STATE(12777)] = 576577,
  [SMALL_STATE(12778)] = 576601,
  [SMALL_STATE(12779)] = 576627,
  [SMALL_STATE(12780)] = 576661,
  [SMALL_STATE(12781)] = 576695,
  [SMALL_STATE(12782)] = 576739,
  [SMALL_STATE(12783)] = 576773,
  [SMALL_STATE(12784)] = 576807,
  [SMALL_STATE(12785)] = 576841,
  [SMALL_STATE(12786)] = 576871,
  [SMALL_STATE(12787)] = 576901,
  [SMALL_STATE(12788)] = 576935,
  [SMALL_STATE(12789)] = 576969,
  [SMALL_STATE(12790)] = 576993,
  [SMALL_STATE(12791)] = 577021,
  [SMALL_STATE(12792)] = 577049,
  [SMALL_STATE(12793)] = 577083,
  [SMALL_STATE(12794)] = 577107,
  [SMALL_STATE(12795)] = 577131,
  [SMALL_STATE(12796)] = 577155,
  [SMALL_STATE(12797)] = 577179,
  [SMALL_STATE(12798)] = 577203,
  [SMALL_STATE(12799)] = 577237,
  [SMALL_STATE(12800)] = 577263,
  [SMALL_STATE(12801)] = 577287,
  [SMALL_STATE(12802)] = 577315,
  [SMALL_STATE(12803)] = 577349,
  [SMALL_STATE(12804)] = 577383,
  [SMALL_STATE(12805)] = 577417,
  [SMALL_STATE(12806)] = 577441,
  [SMALL_STATE(12807)] = 577475,
  [SMALL_STATE(12808)] = 577509,
  [SMALL_STATE(12809)] = 577533,
  [SMALL_STATE(12810)] = 577557,
  [SMALL_STATE(12811)] = 577591,
  [SMALL_STATE(12812)] = 577615,
  [SMALL_STATE(12813)] = 577639,
  [SMALL_STATE(12814)] = 577673,
  [SMALL_STATE(12815)] = 577697,
  [SMALL_STATE(12816)] = 577723,
  [SMALL_STATE(12817)] = 577749,
  [SMALL_STATE(12818)] = 577783,
  [SMALL_STATE(12819)] = 577813,
  [SMALL_STATE(12820)] = 577837,
  [SMALL_STATE(12821)] = 577871,
  [SMALL_STATE(12822)] = 577899,
  [SMALL_STATE(12823)] = 577943,
  [SMALL_STATE(12824)] = 577977,
  [SMALL_STATE(12825)] = 578011,
  [SMALL_STATE(12826)] = 578035,
  [SMALL_STATE(12827)] = 578069,
  [SMALL_STATE(12828)] = 578103,
  [SMALL_STATE(12829)] = 578133,
  [SMALL_STATE(12830)] = 578161,
  [SMALL_STATE(12831)] = 578195,
  [SMALL_STATE(12832)] = 578231,
  [SMALL_STATE(12833)] = 578265,
  [SMALL_STATE(12834)] = 578289,
  [SMALL_STATE(12835)] = 578323,
  [SMALL_STATE(12836)] = 578347,
  [SMALL_STATE(12837)] = 578375,
  [SMALL_STATE(12838)] = 578399,
  [SMALL_STATE(12839)] = 578435,
  [SMALL_STATE(12840)] = 578469,
  [SMALL_STATE(12841)] = 578493,
  [SMALL_STATE(12842)] = 578517,
  [SMALL_STATE(12843)] = 578543,
  [SMALL_STATE(12844)] = 578571,
  [SMALL_STATE(12845)] = 578605,
  [SMALL_STATE(12846)] = 578629,
  [SMALL_STATE(12847)] = 578653,
  [SMALL_STATE(12848)] = 578687,
  [SMALL_STATE(12849)] = 578719,
  [SMALL_STATE(12850)] = 578753,
  [SMALL_STATE(12851)] = 578783,
  [SMALL_STATE(12852)] = 578817,
  [SMALL_STATE(12853)] = 578845,
  [SMALL_STATE(12854)] = 578877,
  [SMALL_STATE(12855)] = 578911,
  [SMALL_STATE(12856)] = 578935,
  [SMALL_STATE(12857)] = 578959,
  [SMALL_STATE(12858)] = 578983,
  [SMALL_STATE(12859)] = 579017,
  [SMALL_STATE(12860)] = 579051,
  [SMALL_STATE(12861)] = 579075,
  [SMALL_STATE(12862)] = 579101,
  [SMALL_STATE(12863)] = 579125,
  [SMALL_STATE(12864)] = 579159,
  [SMALL_STATE(12865)] = 579183,
  [SMALL_STATE(12866)] = 579217,
  [SMALL_STATE(12867)] = 579241,
  [SMALL_STATE(12868)] = 579265,
  [SMALL_STATE(12869)] = 579289,
  [SMALL_STATE(12870)] = 579323,
  [SMALL_STATE(12871)] = 579347,
  [SMALL_STATE(12872)] = 579381,
  [SMALL_STATE(12873)] = 579405,
  [SMALL_STATE(12874)] = 579429,
  [SMALL_STATE(12875)] = 579459,
  [SMALL_STATE(12876)] = 579493,
  [SMALL_STATE(12877)] = 579527,
  [SMALL_STATE(12878)] = 579561,
  [SMALL_STATE(12879)] = 579585,
  [SMALL_STATE(12880)] = 579613,
  [SMALL_STATE(12881)] = 579647,
  [SMALL_STATE(12882)] = 579671,
  [SMALL_STATE(12883)] = 579699,
  [SMALL_STATE(12884)] = 579733,
  [SMALL_STATE(12885)] = 579757,
  [SMALL_STATE(12886)] = 579791,
  [SMALL_STATE(12887)] = 579815,
  [SMALL_STATE(12888)] = 579841,
  [SMALL_STATE(12889)] = 579873,
  [SMALL_STATE(12890)] = 579907,
  [SMALL_STATE(12891)] = 579931,
  [SMALL_STATE(12892)] = 579965,
  [SMALL_STATE(12893)] = 579989,
  [SMALL_STATE(12894)] = 580013,
  [SMALL_STATE(12895)] = 580037,
  [SMALL_STATE(12896)] = 580071,
  [SMALL_STATE(12897)] = 580101,
  [SMALL_STATE(12898)] = 580125,
  [SMALL_STATE(12899)] = 580149,
  [SMALL_STATE(12900)] = 580173,
  [SMALL_STATE(12901)] = 580207,
  [SMALL_STATE(12902)] = 580241,
  [SMALL_STATE(12903)] = 580265,
  [SMALL_STATE(12904)] = 580293,
  [SMALL_STATE(12905)] = 580327,
  [SMALL_STATE(12906)] = 580361,
  [SMALL_STATE(12907)] = 580385,
  [SMALL_STATE(12908)] = 580409,
  [SMALL_STATE(12909)] = 580433,
  [SMALL_STATE(12910)] = 580457,
  [SMALL_STATE(12911)] = 580481,
  [SMALL_STATE(12912)] = 580511,
  [SMALL_STATE(12913)] = 580535,
  [SMALL_STATE(12914)] = 580559,
  [SMALL_STATE(12915)] = 580583,
  [SMALL_STATE(12916)] = 580607,
  [SMALL_STATE(12917)] = 580633,
  [SMALL_STATE(12918)] = 580657,
  [SMALL_STATE(12919)] = 580681,
  [SMALL_STATE(12920)] = 580705,
  [SMALL_STATE(12921)] = 580729,
  [SMALL_STATE(12922)] = 580753,
  [SMALL_STATE(12923)] = 580777,
  [SMALL_STATE(12924)] = 580801,
  [SMALL_STATE(12925)] = 580825,
  [SMALL_STATE(12926)] = 580849,
  [SMALL_STATE(12927)] = 580875,
  [SMALL_STATE(12928)] = 580899,
  [SMALL_STATE(12929)] = 580923,
  [SMALL_STATE(12930)] = 580947,
  [SMALL_STATE(12931)] = 580971,
  [SMALL_STATE(12932)] = 580995,
  [SMALL_STATE(12933)] = 581019,
  [SMALL_STATE(12934)] = 581043,
  [SMALL_STATE(12935)] = 581075,
  [SMALL_STATE(12936)] = 581099,
  [SMALL_STATE(12937)] = 581123,
  [SMALL_STATE(12938)] = 581147,
  [SMALL_STATE(12939)] = 581177,
  [SMALL_STATE(12940)] = 581201,
  [SMALL_STATE(12941)] = 581225,
  [SMALL_STATE(12942)] = 581255,
  [SMALL_STATE(12943)] = 581281,
  [SMALL_STATE(12944)] = 581305,
  [SMALL_STATE(12945)] = 581339,
  [SMALL_STATE(12946)] = 581371,
  [SMALL_STATE(12947)] = 581397,
  [SMALL_STATE(12948)] = 581429,
  [SMALL_STATE(12949)] = 581453,
  [SMALL_STATE(12950)] = 581477,
  [SMALL_STATE(12951)] = 581501,
  [SMALL_STATE(12952)] = 581533,
  [SMALL_STATE(12953)] = 581559,
  [SMALL_STATE(12954)] = 581589,
  [SMALL_STATE(12955)] = 581613,
  [SMALL_STATE(12956)] = 581641,
  [SMALL_STATE(12957)] = 581667,
  [SMALL_STATE(12958)] = 581695,
  [SMALL_STATE(12959)] = 581719,
  [SMALL_STATE(12960)] = 581745,
  [SMALL_STATE(12961)] = 581779,
  [SMALL_STATE(12962)] = 581803,
  [SMALL_STATE(12963)] = 581827,
  [SMALL_STATE(12964)] = 581861,
  [SMALL_STATE(12965)] = 581887,
  [SMALL_STATE(12966)] = 581931,
  [SMALL_STATE(12967)] = 581975,
  [SMALL_STATE(12968)] = 582019,
  [SMALL_STATE(12969)] = 582063,
  [SMALL_STATE(12970)] = 582097,
  [SMALL_STATE(12971)] = 582121,
  [SMALL_STATE(12972)] = 582145,
  [SMALL_STATE(12973)] = 582169,
  [SMALL_STATE(12974)] = 582201,
  [SMALL_STATE(12975)] = 582233,
  [SMALL_STATE(12976)] = 582265,
  [SMALL_STATE(12977)] = 582309,
  [SMALL_STATE(12978)] = 582341,
  [SMALL_STATE(12979)] = 582375,
  [SMALL_STATE(12980)] = 582407,
  [SMALL_STATE(12981)] = 582439,
  [SMALL_STATE(12982)] = 582473,
  [SMALL_STATE(12983)] = 582505,
  [SMALL_STATE(12984)] = 582529,
  [SMALL_STATE(12985)] = 582553,
  [SMALL_STATE(12986)] = 582577,
  [SMALL_STATE(12987)] = 582601,
  [SMALL_STATE(12988)] = 582625,
  [SMALL_STATE(12989)] = 582657,
  [SMALL_STATE(12990)] = 582681,
  [SMALL_STATE(12991)] = 582713,
  [SMALL_STATE(12992)] = 582747,
  [SMALL_STATE(12993)] = 582771,
  [SMALL_STATE(12994)] = 582803,
  [SMALL_STATE(12995)] = 582827,
  [SMALL_STATE(12996)] = 582861,
  [SMALL_STATE(12997)] = 582905,
  [SMALL_STATE(12998)] = 582929,
  [SMALL_STATE(12999)] = 582963,
  [SMALL_STATE(13000)] = 582987,
  [SMALL_STATE(13001)] = 583011,
  [SMALL_STATE(13002)] = 583045,
  [SMALL_STATE(13003)] = 583069,
  [SMALL_STATE(13004)] = 583093,
  [SMALL_STATE(13005)] = 583119,
  [SMALL_STATE(13006)] = 583145,
  [SMALL_STATE(13007)] = 583169,
  [SMALL_STATE(13008)] = 583201,
  [SMALL_STATE(13009)] = 583235,
  [SMALL_STATE(13010)] = 583269,
  [SMALL_STATE(13011)] = 583301,
  [SMALL_STATE(13012)] = 583327,
  [SMALL_STATE(13013)] = 583355,
  [SMALL_STATE(13014)] = 583389,
  [SMALL_STATE(13015)] = 583433,
  [SMALL_STATE(13016)] = 583461,
  [SMALL_STATE(13017)] = 583495,
  [SMALL_STATE(13018)] = 583519,
  [SMALL_STATE(13019)] = 583553,
  [SMALL_STATE(13020)] = 583577,
  [SMALL_STATE(13021)] = 583601,
  [SMALL_STATE(13022)] = 583625,
  [SMALL_STATE(13023)] = 583649,
  [SMALL_STATE(13024)] = 583673,
  [SMALL_STATE(13025)] = 583697,
  [SMALL_STATE(13026)] = 583720,
  [SMALL_STATE(13027)] = 583747,
  [SMALL_STATE(13028)] = 583774,
  [SMALL_STATE(13029)] = 583797,
  [SMALL_STATE(13030)] = 583820,
  [SMALL_STATE(13031)] = 583845,
  [SMALL_STATE(13032)] = 583868,
  [SMALL_STATE(13033)] = 583891,
  [SMALL_STATE(13034)] = 583914,
  [SMALL_STATE(13035)] = 583937,
  [SMALL_STATE(13036)] = 583964,
  [SMALL_STATE(13037)] = 583987,
  [SMALL_STATE(13038)] = 584010,
  [SMALL_STATE(13039)] = 584033,
  [SMALL_STATE(13040)] = 584056,
  [SMALL_STATE(13041)] = 584079,
  [SMALL_STATE(13042)] = 584102,
  [SMALL_STATE(13043)] = 584141,
  [SMALL_STATE(13044)] = 584164,
  [SMALL_STATE(13045)] = 584189,
  [SMALL_STATE(13046)] = 584212,
  [SMALL_STATE(13047)] = 584235,
  [SMALL_STATE(13048)] = 584258,
  [SMALL_STATE(13049)] = 584281,
  [SMALL_STATE(13050)] = 584306,
  [SMALL_STATE(13051)] = 584329,
  [SMALL_STATE(13052)] = 584352,
  [SMALL_STATE(13053)] = 584375,
  [SMALL_STATE(13054)] = 584398,
  [SMALL_STATE(13055)] = 584421,
  [SMALL_STATE(13056)] = 584444,
  [SMALL_STATE(13057)] = 584467,
  [SMALL_STATE(13058)] = 584490,
  [SMALL_STATE(13059)] = 584515,
  [SMALL_STATE(13060)] = 584538,
  [SMALL_STATE(13061)] = 584567,
  [SMALL_STATE(13062)] = 584594,
  [SMALL_STATE(13063)] = 584617,
  [SMALL_STATE(13064)] = 584648,
  [SMALL_STATE(13065)] = 584671,
  [SMALL_STATE(13066)] = 584694,
  [SMALL_STATE(13067)] = 584717,
  [SMALL_STATE(13068)] = 584744,
  [SMALL_STATE(13069)] = 584771,
  [SMALL_STATE(13070)] = 584794,
  [SMALL_STATE(13071)] = 584817,
  [SMALL_STATE(13072)] = 584844,
  [SMALL_STATE(13073)] = 584871,
  [SMALL_STATE(13074)] = 584894,
  [SMALL_STATE(13075)] = 584919,
  [SMALL_STATE(13076)] = 584944,
  [SMALL_STATE(13077)] = 584973,
  [SMALL_STATE(13078)] = 584996,
  [SMALL_STATE(13079)] = 585031,
  [SMALL_STATE(13080)] = 585056,
  [SMALL_STATE(13081)] = 585079,
  [SMALL_STATE(13082)] = 585118,
  [SMALL_STATE(13083)] = 585141,
  [SMALL_STATE(13084)] = 585164,
  [SMALL_STATE(13085)] = 585187,
  [SMALL_STATE(13086)] = 585210,
  [SMALL_STATE(13087)] = 585233,
  [SMALL_STATE(13088)] = 585256,
  [SMALL_STATE(13089)] = 585279,
  [SMALL_STATE(13090)] = 585302,
  [SMALL_STATE(13091)] = 585329,
  [SMALL_STATE(13092)] = 585352,
  [SMALL_STATE(13093)] = 585377,
  [SMALL_STATE(13094)] = 585400,
  [SMALL_STATE(13095)] = 585423,
  [SMALL_STATE(13096)] = 585446,
  [SMALL_STATE(13097)] = 585469,
  [SMALL_STATE(13098)] = 585492,
  [SMALL_STATE(13099)] = 585519,
  [SMALL_STATE(13100)] = 585542,
  [SMALL_STATE(13101)] = 585565,
  [SMALL_STATE(13102)] = 585588,
  [SMALL_STATE(13103)] = 585619,
  [SMALL_STATE(13104)] = 585648,
  [SMALL_STATE(13105)] = 585671,
  [SMALL_STATE(13106)] = 585706,
  [SMALL_STATE(13107)] = 585737,
  [SMALL_STATE(13108)] = 585760,
  [SMALL_STATE(13109)] = 585785,
  [SMALL_STATE(13110)] = 585810,
  [SMALL_STATE(13111)] = 585833,
  [SMALL_STATE(13112)] = 585856,
  [SMALL_STATE(13113)] = 585879,
  [SMALL_STATE(13114)] = 585902,
  [SMALL_STATE(13115)] = 585929,
  [SMALL_STATE(13116)] = 585952,
  [SMALL_STATE(13117)] = 585975,
  [SMALL_STATE(13118)] = 585998,
  [SMALL_STATE(13119)] = 586033,
  [SMALL_STATE(13120)] = 586060,
  [SMALL_STATE(13121)] = 586083,
  [SMALL_STATE(13122)] = 586114,
  [SMALL_STATE(13123)] = 586137,
  [SMALL_STATE(13124)] = 586160,
  [SMALL_STATE(13125)] = 586183,
  [SMALL_STATE(13126)] = 586206,
  [SMALL_STATE(13127)] = 586239,
  [SMALL_STATE(13128)] = 586262,
  [SMALL_STATE(13129)] = 586285,
  [SMALL_STATE(13130)] = 586308,
  [SMALL_STATE(13131)] = 586331,
  [SMALL_STATE(13132)] = 586356,
  [SMALL_STATE(13133)] = 586383,
  [SMALL_STATE(13134)] = 586406,
  [SMALL_STATE(13135)] = 586429,
  [SMALL_STATE(13136)] = 586454,
  [SMALL_STATE(13137)] = 586477,
  [SMALL_STATE(13138)] = 586500,
  [SMALL_STATE(13139)] = 586523,
  [SMALL_STATE(13140)] = 586546,
  [SMALL_STATE(13141)] = 586575,
  [SMALL_STATE(13142)] = 586600,
  [SMALL_STATE(13143)] = 586623,
  [SMALL_STATE(13144)] = 586646,
  [SMALL_STATE(13145)] = 586669,
  [SMALL_STATE(13146)] = 586692,
  [SMALL_STATE(13147)] = 586715,
  [SMALL_STATE(13148)] = 586742,
  [SMALL_STATE(13149)] = 586765,
  [SMALL_STATE(13150)] = 586788,
  [SMALL_STATE(13151)] = 586811,
  [SMALL_STATE(13152)] = 586840,
  [SMALL_STATE(13153)] = 586867,
  [SMALL_STATE(13154)] = 586890,
  [SMALL_STATE(13155)] = 586913,
  [SMALL_STATE(13156)] = 586936,
  [SMALL_STATE(13157)] = 586959,
  [SMALL_STATE(13158)] = 586982,
  [SMALL_STATE(13159)] = 587005,
  [SMALL_STATE(13160)] = 587028,
  [SMALL_STATE(13161)] = 587055,
  [SMALL_STATE(13162)] = 587078,
  [SMALL_STATE(13163)] = 587101,
  [SMALL_STATE(13164)] = 587132,
  [SMALL_STATE(13165)] = 587159,
  [SMALL_STATE(13166)] = 587188,
  [SMALL_STATE(13167)] = 587219,
  [SMALL_STATE(13168)] = 587242,
  [SMALL_STATE(13169)] = 587265,
  [SMALL_STATE(13170)] = 587288,
  [SMALL_STATE(13171)] = 587315,
  [SMALL_STATE(13172)] = 587342,
  [SMALL_STATE(13173)] = 587371,
  [SMALL_STATE(13174)] = 587394,
  [SMALL_STATE(13175)] = 587423,
  [SMALL_STATE(13176)] = 587446,
  [SMALL_STATE(13177)] = 587473,
  [SMALL_STATE(13178)] = 587500,
  [SMALL_STATE(13179)] = 587523,
  [SMALL_STATE(13180)] = 587546,
  [SMALL_STATE(13181)] = 587569,
  [SMALL_STATE(13182)] = 587600,
  [SMALL_STATE(13183)] = 587623,
  [SMALL_STATE(13184)] = 587646,
  [SMALL_STATE(13185)] = 587669,
  [SMALL_STATE(13186)] = 587692,
  [SMALL_STATE(13187)] = 587715,
  [SMALL_STATE(13188)] = 587744,
  [SMALL_STATE(13189)] = 587767,
  [SMALL_STATE(13190)] = 587790,
  [SMALL_STATE(13191)] = 587813,
  [SMALL_STATE(13192)] = 587836,
  [SMALL_STATE(13193)] = 587859,
  [SMALL_STATE(13194)] = 587886,
  [SMALL_STATE(13195)] = 587913,
  [SMALL_STATE(13196)] = 587948,
  [SMALL_STATE(13197)] = 587973,
  [SMALL_STATE(13198)] = 587996,
  [SMALL_STATE(13199)] = 588019,
  [SMALL_STATE(13200)] = 588042,
  [SMALL_STATE(13201)] = 588065,
  [SMALL_STATE(13202)] = 588088,
  [SMALL_STATE(13203)] = 588117,
  [SMALL_STATE(13204)] = 588148,
  [SMALL_STATE(13205)] = 588171,
  [SMALL_STATE(13206)] = 588194,
  [SMALL_STATE(13207)] = 588217,
  [SMALL_STATE(13208)] = 588240,
  [SMALL_STATE(13209)] = 588263,
  [SMALL_STATE(13210)] = 588286,
  [SMALL_STATE(13211)] = 588309,
  [SMALL_STATE(13212)] = 588332,
  [SMALL_STATE(13213)] = 588355,
  [SMALL_STATE(13214)] = 588378,
  [SMALL_STATE(13215)] = 588409,
  [SMALL_STATE(13216)] = 588432,
  [SMALL_STATE(13217)] = 588459,
  [SMALL_STATE(13218)] = 588486,
  [SMALL_STATE(13219)] = 588509,
  [SMALL_STATE(13220)] = 588532,
  [SMALL_STATE(13221)] = 588555,
  [SMALL_STATE(13222)] = 588580,
  [SMALL_STATE(13223)] = 588603,
  [SMALL_STATE(13224)] = 588626,
  [SMALL_STATE(13225)] = 588649,
  [SMALL_STATE(13226)] = 588680,
  [SMALL_STATE(13227)] = 588703,
  [SMALL_STATE(13228)] = 588726,
  [SMALL_STATE(13229)] = 588749,
  [SMALL_STATE(13230)] = 588780,
  [SMALL_STATE(13231)] = 588813,
  [SMALL_STATE(13232)] = 588840,
  [SMALL_STATE(13233)] = 588863,
  [SMALL_STATE(13234)] = 588892,
  [SMALL_STATE(13235)] = 588919,
  [SMALL_STATE(13236)] = 588942,
  [SMALL_STATE(13237)] = 588971,
  [SMALL_STATE(13238)] = 588998,
  [SMALL_STATE(13239)] = 589021,
  [SMALL_STATE(13240)] = 589046,
  [SMALL_STATE(13241)] = 589069,
  [SMALL_STATE(13242)] = 589092,
  [SMALL_STATE(13243)] = 589115,
  [SMALL_STATE(13244)] = 589138,
  [SMALL_STATE(13245)] = 589161,
  [SMALL_STATE(13246)] = 589188,
  [SMALL_STATE(13247)] = 589211,
  [SMALL_STATE(13248)] = 589240,
  [SMALL_STATE(13249)] = 589267,
  [SMALL_STATE(13250)] = 589290,
  [SMALL_STATE(13251)] = 589317,
  [SMALL_STATE(13252)] = 589340,
  [SMALL_STATE(13253)] = 589365,
  [SMALL_STATE(13254)] = 589392,
  [SMALL_STATE(13255)] = 589419,
  [SMALL_STATE(13256)] = 589442,
  [SMALL_STATE(13257)] = 589465,
  [SMALL_STATE(13258)] = 589488,
  [SMALL_STATE(13259)] = 589519,
  [SMALL_STATE(13260)] = 589548,
  [SMALL_STATE(13261)] = 589575,
  [SMALL_STATE(13262)] = 589604,
  [SMALL_STATE(13263)] = 589627,
  [SMALL_STATE(13264)] = 589656,
  [SMALL_STATE(13265)] = 589681,
  [SMALL_STATE(13266)] = 589704,
  [SMALL_STATE(13267)] = 589727,
  [SMALL_STATE(13268)] = 589750,
  [SMALL_STATE(13269)] = 589773,
  [SMALL_STATE(13270)] = 589796,
  [SMALL_STATE(13271)] = 589819,
  [SMALL_STATE(13272)] = 589842,
  [SMALL_STATE(13273)] = 589865,
  [SMALL_STATE(13274)] = 589888,
  [SMALL_STATE(13275)] = 589911,
  [SMALL_STATE(13276)] = 589942,
  [SMALL_STATE(13277)] = 589965,
  [SMALL_STATE(13278)] = 589988,
  [SMALL_STATE(13279)] = 590011,
  [SMALL_STATE(13280)] = 590040,
  [SMALL_STATE(13281)] = 590063,
  [SMALL_STATE(13282)] = 590090,
  [SMALL_STATE(13283)] = 590113,
  [SMALL_STATE(13284)] = 590136,
  [SMALL_STATE(13285)] = 590159,
  [SMALL_STATE(13286)] = 590182,
  [SMALL_STATE(13287)] = 590209,
  [SMALL_STATE(13288)] = 590232,
  [SMALL_STATE(13289)] = 590255,
  [SMALL_STATE(13290)] = 590278,
  [SMALL_STATE(13291)] = 590305,
  [SMALL_STATE(13292)] = 590332,
  [SMALL_STATE(13293)] = 590355,
  [SMALL_STATE(13294)] = 590378,
  [SMALL_STATE(13295)] = 590405,
  [SMALL_STATE(13296)] = 590428,
  [SMALL_STATE(13297)] = 590451,
  [SMALL_STATE(13298)] = 590474,
  [SMALL_STATE(13299)] = 590501,
  [SMALL_STATE(13300)] = 590524,
  [SMALL_STATE(13301)] = 590547,
  [SMALL_STATE(13302)] = 590570,
  [SMALL_STATE(13303)] = 590593,
  [SMALL_STATE(13304)] = 590622,
  [SMALL_STATE(13305)] = 590645,
  [SMALL_STATE(13306)] = 590668,
  [SMALL_STATE(13307)] = 590691,
  [SMALL_STATE(13308)] = 590714,
  [SMALL_STATE(13309)] = 590741,
  [SMALL_STATE(13310)] = 590764,
  [SMALL_STATE(13311)] = 590789,
  [SMALL_STATE(13312)] = 590812,
  [SMALL_STATE(13313)] = 590835,
  [SMALL_STATE(13314)] = 590858,
  [SMALL_STATE(13315)] = 590881,
  [SMALL_STATE(13316)] = 590904,
  [SMALL_STATE(13317)] = 590927,
  [SMALL_STATE(13318)] = 590952,
  [SMALL_STATE(13319)] = 590975,
  [SMALL_STATE(13320)] = 591000,
  [SMALL_STATE(13321)] = 591035,
  [SMALL_STATE(13322)] = 591057,
  [SMALL_STATE(13323)] = 591079,
  [SMALL_STATE(13324)] = 591101,
  [SMALL_STATE(13325)] = 591127,
  [SMALL_STATE(13326)] = 591153,
  [SMALL_STATE(13327)] = 591175,
  [SMALL_STATE(13328)] = 591205,
  [SMALL_STATE(13329)] = 591229,
  [SMALL_STATE(13330)] = 591257,
  [SMALL_STATE(13331)] = 591279,
  [SMALL_STATE(13332)] = 591301,
  [SMALL_STATE(13333)] = 591331,
  [SMALL_STATE(13334)] = 591353,
  [SMALL_STATE(13335)] = 591375,
  [SMALL_STATE(13336)] = 591401,
  [SMALL_STATE(13337)] = 591427,
  [SMALL_STATE(13338)] = 591451,
  [SMALL_STATE(13339)] = 591479,
  [SMALL_STATE(13340)] = 591501,
  [SMALL_STATE(13341)] = 591525,
  [SMALL_STATE(13342)] = 591551,
  [SMALL_STATE(13343)] = 591579,
  [SMALL_STATE(13344)] = 591605,
  [SMALL_STATE(13345)] = 591631,
  [SMALL_STATE(13346)] = 591657,
  [SMALL_STATE(13347)] = 591685,
  [SMALL_STATE(13348)] = 591711,
  [SMALL_STATE(13349)] = 591733,
  [SMALL_STATE(13350)] = 591757,
  [SMALL_STATE(13351)] = 591781,
  [SMALL_STATE(13352)] = 591807,
  [SMALL_STATE(13353)] = 591829,
  [SMALL_STATE(13354)] = 591851,
  [SMALL_STATE(13355)] = 591873,
  [SMALL_STATE(13356)] = 591895,
  [SMALL_STATE(13357)] = 591921,
  [SMALL_STATE(13358)] = 591945,
  [SMALL_STATE(13359)] = 591967,
  [SMALL_STATE(13360)] = 591995,
  [SMALL_STATE(13361)] = 592021,
  [SMALL_STATE(13362)] = 592049,
  [SMALL_STATE(13363)] = 592071,
  [SMALL_STATE(13364)] = 592093,
  [SMALL_STATE(13365)] = 592115,
  [SMALL_STATE(13366)] = 592137,
  [SMALL_STATE(13367)] = 592165,
  [SMALL_STATE(13368)] = 592187,
  [SMALL_STATE(13369)] = 592213,
  [SMALL_STATE(13370)] = 592235,
  [SMALL_STATE(13371)] = 592259,
  [SMALL_STATE(13372)] = 592287,
  [SMALL_STATE(13373)] = 592309,
  [SMALL_STATE(13374)] = 592331,
  [SMALL_STATE(13375)] = 592361,
  [SMALL_STATE(13376)] = 592383,
  [SMALL_STATE(13377)] = 592413,
  [SMALL_STATE(13378)] = 592439,
  [SMALL_STATE(13379)] = 592461,
  [SMALL_STATE(13380)] = 592487,
  [SMALL_STATE(13381)] = 592509,
  [SMALL_STATE(13382)] = 592535,
  [SMALL_STATE(13383)] = 592557,
  [SMALL_STATE(13384)] = 592585,
  [SMALL_STATE(13385)] = 592607,
  [SMALL_STATE(13386)] = 592629,
  [SMALL_STATE(13387)] = 592657,
  [SMALL_STATE(13388)] = 592679,
  [SMALL_STATE(13389)] = 592701,
  [SMALL_STATE(13390)] = 592723,
  [SMALL_STATE(13391)] = 592749,
  [SMALL_STATE(13392)] = 592771,
  [SMALL_STATE(13393)] = 592793,
  [SMALL_STATE(13394)] = 592815,
  [SMALL_STATE(13395)] = 592841,
  [SMALL_STATE(13396)] = 592863,
  [SMALL_STATE(13397)] = 592885,
  [SMALL_STATE(13398)] = 592907,
  [SMALL_STATE(13399)] = 592931,
  [SMALL_STATE(13400)] = 592953,
  [SMALL_STATE(13401)] = 592979,
  [SMALL_STATE(13402)] = 593005,
  [SMALL_STATE(13403)] = 593027,
  [SMALL_STATE(13404)] = 593049,
  [SMALL_STATE(13405)] = 593071,
  [SMALL_STATE(13406)] = 593095,
  [SMALL_STATE(13407)] = 593117,
  [SMALL_STATE(13408)] = 593139,
  [SMALL_STATE(13409)] = 593161,
  [SMALL_STATE(13410)] = 593189,
  [SMALL_STATE(13411)] = 593211,
  [SMALL_STATE(13412)] = 593233,
  [SMALL_STATE(13413)] = 593255,
  [SMALL_STATE(13414)] = 593277,
  [SMALL_STATE(13415)] = 593299,
  [SMALL_STATE(13416)] = 593321,
  [SMALL_STATE(13417)] = 593343,
  [SMALL_STATE(13418)] = 593365,
  [SMALL_STATE(13419)] = 593391,
  [SMALL_STATE(13420)] = 593417,
  [SMALL_STATE(13421)] = 593443,
  [SMALL_STATE(13422)] = 593471,
  [SMALL_STATE(13423)] = 593495,
  [SMALL_STATE(13424)] = 593523,
  [SMALL_STATE(13425)] = 593545,
  [SMALL_STATE(13426)] = 593567,
  [SMALL_STATE(13427)] = 593589,
  [SMALL_STATE(13428)] = 593611,
  [SMALL_STATE(13429)] = 593633,
  [SMALL_STATE(13430)] = 593655,
  [SMALL_STATE(13431)] = 593677,
  [SMALL_STATE(13432)] = 593699,
  [SMALL_STATE(13433)] = 593721,
  [SMALL_STATE(13434)] = 593743,
  [SMALL_STATE(13435)] = 593765,
  [SMALL_STATE(13436)] = 593791,
  [SMALL_STATE(13437)] = 593813,
  [SMALL_STATE(13438)] = 593835,
  [SMALL_STATE(13439)] = 593857,
  [SMALL_STATE(13440)] = 593883,
  [SMALL_STATE(13441)] = 593905,
  [SMALL_STATE(13442)] = 593931,
  [SMALL_STATE(13443)] = 593953,
  [SMALL_STATE(13444)] = 593975,
  [SMALL_STATE(13445)] = 593997,
  [SMALL_STATE(13446)] = 594019,
  [SMALL_STATE(13447)] = 594041,
  [SMALL_STATE(13448)] = 594065,
  [SMALL_STATE(13449)] = 594091,
  [SMALL_STATE(13450)] = 594121,
  [SMALL_STATE(13451)] = 594145,
  [SMALL_STATE(13452)] = 594167,
  [SMALL_STATE(13453)] = 594189,
  [SMALL_STATE(13454)] = 594211,
  [SMALL_STATE(13455)] = 594233,
  [SMALL_STATE(13456)] = 594255,
  [SMALL_STATE(13457)] = 594277,
  [SMALL_STATE(13458)] = 594299,
  [SMALL_STATE(13459)] = 594321,
  [SMALL_STATE(13460)] = 594343,
  [SMALL_STATE(13461)] = 594369,
  [SMALL_STATE(13462)] = 594395,
  [SMALL_STATE(13463)] = 594417,
  [SMALL_STATE(13464)] = 594447,
  [SMALL_STATE(13465)] = 594469,
  [SMALL_STATE(13466)] = 594491,
  [SMALL_STATE(13467)] = 594513,
  [SMALL_STATE(13468)] = 594535,
  [SMALL_STATE(13469)] = 594561,
  [SMALL_STATE(13470)] = 594585,
  [SMALL_STATE(13471)] = 594607,
  [SMALL_STATE(13472)] = 594633,
  [SMALL_STATE(13473)] = 594655,
  [SMALL_STATE(13474)] = 594677,
  [SMALL_STATE(13475)] = 594703,
  [SMALL_STATE(13476)] = 594725,
  [SMALL_STATE(13477)] = 594751,
  [SMALL_STATE(13478)] = 594773,
  [SMALL_STATE(13479)] = 594803,
  [SMALL_STATE(13480)] = 594833,
  [SMALL_STATE(13481)] = 594857,
  [SMALL_STATE(13482)] = 594879,
  [SMALL_STATE(13483)] = 594909,
  [SMALL_STATE(13484)] = 594931,
  [SMALL_STATE(13485)] = 594953,
  [SMALL_STATE(13486)] = 594983,
  [SMALL_STATE(13487)] = 595005,
  [SMALL_STATE(13488)] = 595027,
  [SMALL_STATE(13489)] = 595049,
  [SMALL_STATE(13490)] = 595071,
  [SMALL_STATE(13491)] = 595093,
  [SMALL_STATE(13492)] = 595115,
  [SMALL_STATE(13493)] = 595137,
  [SMALL_STATE(13494)] = 595159,
  [SMALL_STATE(13495)] = 595181,
  [SMALL_STATE(13496)] = 595203,
  [SMALL_STATE(13497)] = 595229,
  [SMALL_STATE(13498)] = 595253,
  [SMALL_STATE(13499)] = 595281,
  [SMALL_STATE(13500)] = 595303,
  [SMALL_STATE(13501)] = 595325,
  [SMALL_STATE(13502)] = 595347,
  [SMALL_STATE(13503)] = 595373,
  [SMALL_STATE(13504)] = 595399,
  [SMALL_STATE(13505)] = 595421,
  [SMALL_STATE(13506)] = 595449,
  [SMALL_STATE(13507)] = 595475,
  [SMALL_STATE(13508)] = 595503,
  [SMALL_STATE(13509)] = 595531,
  [SMALL_STATE(13510)] = 595553,
  [SMALL_STATE(13511)] = 595579,
  [SMALL_STATE(13512)] = 595601,
  [SMALL_STATE(13513)] = 595623,
  [SMALL_STATE(13514)] = 595645,
  [SMALL_STATE(13515)] = 595667,
  [SMALL_STATE(13516)] = 595689,
  [SMALL_STATE(13517)] = 595715,
  [SMALL_STATE(13518)] = 595737,
  [SMALL_STATE(13519)] = 595759,
  [SMALL_STATE(13520)] = 595781,
  [SMALL_STATE(13521)] = 595815,
  [SMALL_STATE(13522)] = 595837,
  [SMALL_STATE(13523)] = 595861,
  [SMALL_STATE(13524)] = 595883,
  [SMALL_STATE(13525)] = 595905,
  [SMALL_STATE(13526)] = 595927,
  [SMALL_STATE(13527)] = 595949,
  [SMALL_STATE(13528)] = 595971,
  [SMALL_STATE(13529)] = 595993,
  [SMALL_STATE(13530)] = 596021,
  [SMALL_STATE(13531)] = 596043,
  [SMALL_STATE(13532)] = 596065,
  [SMALL_STATE(13533)] = 596089,
  [SMALL_STATE(13534)] = 596111,
  [SMALL_STATE(13535)] = 596133,
  [SMALL_STATE(13536)] = 596155,
  [SMALL_STATE(13537)] = 596177,
  [SMALL_STATE(13538)] = 596203,
  [SMALL_STATE(13539)] = 596227,
  [SMALL_STATE(13540)] = 596251,
  [SMALL_STATE(13541)] = 596273,
  [SMALL_STATE(13542)] = 596299,
  [SMALL_STATE(13543)] = 596325,
  [SMALL_STATE(13544)] = 596347,
  [SMALL_STATE(13545)] = 596369,
  [SMALL_STATE(13546)] = 596393,
  [SMALL_STATE(13547)] = 596415,
  [SMALL_STATE(13548)] = 596437,
  [SMALL_STATE(13549)] = 596459,
  [SMALL_STATE(13550)] = 596483,
  [SMALL_STATE(13551)] = 596505,
  [SMALL_STATE(13552)] = 596527,
  [SMALL_STATE(13553)] = 596549,
  [SMALL_STATE(13554)] = 596575,
  [SMALL_STATE(13555)] = 596597,
  [SMALL_STATE(13556)] = 596619,
  [SMALL_STATE(13557)] = 596645,
  [SMALL_STATE(13558)] = 596667,
  [SMALL_STATE(13559)] = 596693,
  [SMALL_STATE(13560)] = 596715,
  [SMALL_STATE(13561)] = 596737,
  [SMALL_STATE(13562)] = 596759,
  [SMALL_STATE(13563)] = 596781,
  [SMALL_STATE(13564)] = 596803,
  [SMALL_STATE(13565)] = 596825,
  [SMALL_STATE(13566)] = 596847,
  [SMALL_STATE(13567)] = 596871,
  [SMALL_STATE(13568)] = 596893,
  [SMALL_STATE(13569)] = 596923,
  [SMALL_STATE(13570)] = 596945,
  [SMALL_STATE(13571)] = 596967,
  [SMALL_STATE(13572)] = 596989,
  [SMALL_STATE(13573)] = 597011,
  [SMALL_STATE(13574)] = 597041,
  [SMALL_STATE(13575)] = 597067,
  [SMALL_STATE(13576)] = 597089,
  [SMALL_STATE(13577)] = 597115,
  [SMALL_STATE(13578)] = 597143,
  [SMALL_STATE(13579)] = 597169,
  [SMALL_STATE(13580)] = 597191,
  [SMALL_STATE(13581)] = 597213,
  [SMALL_STATE(13582)] = 597235,
  [SMALL_STATE(13583)] = 597257,
  [SMALL_STATE(13584)] = 597279,
  [SMALL_STATE(13585)] = 597301,
  [SMALL_STATE(13586)] = 597331,
  [SMALL_STATE(13587)] = 597359,
  [SMALL_STATE(13588)] = 597381,
  [SMALL_STATE(13589)] = 597403,
  [SMALL_STATE(13590)] = 597425,
  [SMALL_STATE(13591)] = 597447,
  [SMALL_STATE(13592)] = 597473,
  [SMALL_STATE(13593)] = 597495,
  [SMALL_STATE(13594)] = 597519,
  [SMALL_STATE(13595)] = 597541,
  [SMALL_STATE(13596)] = 597563,
  [SMALL_STATE(13597)] = 597585,
  [SMALL_STATE(13598)] = 597607,
  [SMALL_STATE(13599)] = 597635,
  [SMALL_STATE(13600)] = 597665,
  [SMALL_STATE(13601)] = 597687,
  [SMALL_STATE(13602)] = 597709,
  [SMALL_STATE(13603)] = 597731,
  [SMALL_STATE(13604)] = 597753,
  [SMALL_STATE(13605)] = 597783,
  [SMALL_STATE(13606)] = 597813,
  [SMALL_STATE(13607)] = 597839,
  [SMALL_STATE(13608)] = 597867,
  [SMALL_STATE(13609)] = 597893,
  [SMALL_STATE(13610)] = 597915,
  [SMALL_STATE(13611)] = 597937,
  [SMALL_STATE(13612)] = 597965,
  [SMALL_STATE(13613)] = 597987,
  [SMALL_STATE(13614)] = 598009,
  [SMALL_STATE(13615)] = 598031,
  [SMALL_STATE(13616)] = 598053,
  [SMALL_STATE(13617)] = 598075,
  [SMALL_STATE(13618)] = 598097,
  [SMALL_STATE(13619)] = 598119,
  [SMALL_STATE(13620)] = 598141,
  [SMALL_STATE(13621)] = 598163,
  [SMALL_STATE(13622)] = 598189,
  [SMALL_STATE(13623)] = 598211,
  [SMALL_STATE(13624)] = 598233,
  [SMALL_STATE(13625)] = 598255,
  [SMALL_STATE(13626)] = 598281,
  [SMALL_STATE(13627)] = 598303,
  [SMALL_STATE(13628)] = 598329,
  [SMALL_STATE(13629)] = 598351,
  [SMALL_STATE(13630)] = 598373,
  [SMALL_STATE(13631)] = 598399,
  [SMALL_STATE(13632)] = 598421,
  [SMALL_STATE(13633)] = 598446,
  [SMALL_STATE(13634)] = 598469,
  [SMALL_STATE(13635)] = 598490,
  [SMALL_STATE(13636)] = 598511,
  [SMALL_STATE(13637)] = 598532,
  [SMALL_STATE(13638)] = 598553,
  [SMALL_STATE(13639)] = 598578,
  [SMALL_STATE(13640)] = 598605,
  [SMALL_STATE(13641)] = 598630,
  [SMALL_STATE(13642)] = 598653,
  [SMALL_STATE(13643)] = 598682,
  [SMALL_STATE(13644)] = 598703,
  [SMALL_STATE(13645)] = 598736,
  [SMALL_STATE(13646)] = 598757,
  [SMALL_STATE(13647)] = 598790,
  [SMALL_STATE(13648)] = 598823,
  [SMALL_STATE(13649)] = 598850,
  [SMALL_STATE(13650)] = 598883,
  [SMALL_STATE(13651)] = 598904,
  [SMALL_STATE(13652)] = 598929,
  [SMALL_STATE(13653)] = 598950,
  [SMALL_STATE(13654)] = 598977,
  [SMALL_STATE(13655)] = 599002,
  [SMALL_STATE(13656)] = 599027,
  [SMALL_STATE(13657)] = 599052,
  [SMALL_STATE(13658)] = 599079,
  [SMALL_STATE(13659)] = 599108,
  [SMALL_STATE(13660)] = 599129,
  [SMALL_STATE(13661)] = 599156,
  [SMALL_STATE(13662)] = 599177,
  [SMALL_STATE(13663)] = 599198,
  [SMALL_STATE(13664)] = 599225,
  [SMALL_STATE(13665)] = 599252,
  [SMALL_STATE(13666)] = 599273,
  [SMALL_STATE(13667)] = 599294,
  [SMALL_STATE(13668)] = 599323,
  [SMALL_STATE(13669)] = 599352,
  [SMALL_STATE(13670)] = 599381,
  [SMALL_STATE(13671)] = 599410,
  [SMALL_STATE(13672)] = 599435,
  [SMALL_STATE(13673)] = 599462,
  [SMALL_STATE(13674)] = 599487,
  [SMALL_STATE(13675)] = 599516,
  [SMALL_STATE(13676)] = 599539,
  [SMALL_STATE(13677)] = 599564,
  [SMALL_STATE(13678)] = 599589,
  [SMALL_STATE(13679)] = 599610,
  [SMALL_STATE(13680)] = 599631,
  [SMALL_STATE(13681)] = 599652,
  [SMALL_STATE(13682)] = 599681,
  [SMALL_STATE(13683)] = 599704,
  [SMALL_STATE(13684)] = 599729,
  [SMALL_STATE(13685)] = 599752,
  [SMALL_STATE(13686)] = 599773,
  [SMALL_STATE(13687)] = 599794,
  [SMALL_STATE(13688)] = 599817,
  [SMALL_STATE(13689)] = 599838,
  [SMALL_STATE(13690)] = 599859,
  [SMALL_STATE(13691)] = 599880,
  [SMALL_STATE(13692)] = 599901,
  [SMALL_STATE(13693)] = 599932,
  [SMALL_STATE(13694)] = 599957,
  [SMALL_STATE(13695)] = 599978,
  [SMALL_STATE(13696)] = 599999,
  [SMALL_STATE(13697)] = 600020,
  [SMALL_STATE(13698)] = 600041,
  [SMALL_STATE(13699)] = 600068,
  [SMALL_STATE(13700)] = 600091,
  [SMALL_STATE(13701)] = 600116,
  [SMALL_STATE(13702)] = 600137,
  [SMALL_STATE(13703)] = 600158,
  [SMALL_STATE(13704)] = 600191,
  [SMALL_STATE(13705)] = 600212,
  [SMALL_STATE(13706)] = 600245,
  [SMALL_STATE(13707)] = 600266,
  [SMALL_STATE(13708)] = 600291,
  [SMALL_STATE(13709)] = 600312,
  [SMALL_STATE(13710)] = 600333,
  [SMALL_STATE(13711)] = 600360,
  [SMALL_STATE(13712)] = 600385,
  [SMALL_STATE(13713)] = 600406,
  [SMALL_STATE(13714)] = 600429,
  [SMALL_STATE(13715)] = 600450,
  [SMALL_STATE(13716)] = 600471,
  [SMALL_STATE(13717)] = 600492,
  [SMALL_STATE(13718)] = 600513,
  [SMALL_STATE(13719)] = 600534,
  [SMALL_STATE(13720)] = 600555,
  [SMALL_STATE(13721)] = 600578,
  [SMALL_STATE(13722)] = 600601,
  [SMALL_STATE(13723)] = 600622,
  [SMALL_STATE(13724)] = 600647,
  [SMALL_STATE(13725)] = 600668,
  [SMALL_STATE(13726)] = 600693,
  [SMALL_STATE(13727)] = 600722,
  [SMALL_STATE(13728)] = 600751,
  [SMALL_STATE(13729)] = 600776,
  [SMALL_STATE(13730)] = 600807,
  [SMALL_STATE(13731)] = 600832,
  [SMALL_STATE(13732)] = 600853,
  [SMALL_STATE(13733)] = 600876,
  [SMALL_STATE(13734)] = 600905,
  [SMALL_STATE(13735)] = 600930,
  [SMALL_STATE(13736)] = 600957,
  [SMALL_STATE(13737)] = 600978,
  [SMALL_STATE(13738)] = 601011,
  [SMALL_STATE(13739)] = 601042,
  [SMALL_STATE(13740)] = 601067,
  [SMALL_STATE(13741)] = 601092,
  [SMALL_STATE(13742)] = 601119,
  [SMALL_STATE(13743)] = 601152,
  [SMALL_STATE(13744)] = 601181,
  [SMALL_STATE(13745)] = 601214,
  [SMALL_STATE(13746)] = 601239,
  [SMALL_STATE(13747)] = 601266,
  [SMALL_STATE(13748)] = 601291,
  [SMALL_STATE(13749)] = 601320,
  [SMALL_STATE(13750)] = 601349,
  [SMALL_STATE(13751)] = 601370,
  [SMALL_STATE(13752)] = 601391,
  [SMALL_STATE(13753)] = 601416,
  [SMALL_STATE(13754)] = 601449,
  [SMALL_STATE(13755)] = 601480,
  [SMALL_STATE(13756)] = 601501,
  [SMALL_STATE(13757)] = 601534,
  [SMALL_STATE(13758)] = 601555,
  [SMALL_STATE(13759)] = 601588,
  [SMALL_STATE(13760)] = 601609,
  [SMALL_STATE(13761)] = 601630,
  [SMALL_STATE(13762)] = 601663,
  [SMALL_STATE(13763)] = 601684,
  [SMALL_STATE(13764)] = 601711,
  [SMALL_STATE(13765)] = 601732,
  [SMALL_STATE(13766)] = 601757,
  [SMALL_STATE(13767)] = 601778,
  [SMALL_STATE(13768)] = 601803,
  [SMALL_STATE(13769)] = 601830,
  [SMALL_STATE(13770)] = 601851,
  [SMALL_STATE(13771)] = 601876,
  [SMALL_STATE(13772)] = 601903,
  [SMALL_STATE(13773)] = 601928,
  [SMALL_STATE(13774)] = 601955,
  [SMALL_STATE(13775)] = 601980,
  [SMALL_STATE(13776)] = 602005,
  [SMALL_STATE(13777)] = 602032,
  [SMALL_STATE(13778)] = 602055,
  [SMALL_STATE(13779)] = 602080,
  [SMALL_STATE(13780)] = 602103,
  [SMALL_STATE(13781)] = 602130,
  [SMALL_STATE(13782)] = 602151,
  [SMALL_STATE(13783)] = 602172,
  [SMALL_STATE(13784)] = 602197,
  [SMALL_STATE(13785)] = 602218,
  [SMALL_STATE(13786)] = 602243,
  [SMALL_STATE(13787)] = 602264,
  [SMALL_STATE(13788)] = 602285,
  [SMALL_STATE(13789)] = 602308,
  [SMALL_STATE(13790)] = 602329,
  [SMALL_STATE(13791)] = 602350,
  [SMALL_STATE(13792)] = 602375,
  [SMALL_STATE(13793)] = 602400,
  [SMALL_STATE(13794)] = 602421,
  [SMALL_STATE(13795)] = 602442,
  [SMALL_STATE(13796)] = 602463,
  [SMALL_STATE(13797)] = 602484,
  [SMALL_STATE(13798)] = 602505,
  [SMALL_STATE(13799)] = 602526,
  [SMALL_STATE(13800)] = 602551,
  [SMALL_STATE(13801)] = 602578,
  [SMALL_STATE(13802)] = 602599,
  [SMALL_STATE(13803)] = 602620,
  [SMALL_STATE(13804)] = 602645,
  [SMALL_STATE(13805)] = 602672,
  [SMALL_STATE(13806)] = 602693,
  [SMALL_STATE(13807)] = 602714,
  [SMALL_STATE(13808)] = 602737,
  [SMALL_STATE(13809)] = 602762,
  [SMALL_STATE(13810)] = 602787,
  [SMALL_STATE(13811)] = 602814,
  [SMALL_STATE(13812)] = 602839,
  [SMALL_STATE(13813)] = 602862,
  [SMALL_STATE(13814)] = 602883,
  [SMALL_STATE(13815)] = 602908,
  [SMALL_STATE(13816)] = 602933,
  [SMALL_STATE(13817)] = 602954,
  [SMALL_STATE(13818)] = 602975,
  [SMALL_STATE(13819)] = 602998,
  [SMALL_STATE(13820)] = 603023,
  [SMALL_STATE(13821)] = 603044,
  [SMALL_STATE(13822)] = 603069,
  [SMALL_STATE(13823)] = 603094,
  [SMALL_STATE(13824)] = 603115,
  [SMALL_STATE(13825)] = 603142,
  [SMALL_STATE(13826)] = 603165,
  [SMALL_STATE(13827)] = 603186,
  [SMALL_STATE(13828)] = 603219,
  [SMALL_STATE(13829)] = 603242,
  [SMALL_STATE(13830)] = 603269,
  [SMALL_STATE(13831)] = 603290,
  [SMALL_STATE(13832)] = 603319,
  [SMALL_STATE(13833)] = 603340,
  [SMALL_STATE(13834)] = 603365,
  [SMALL_STATE(13835)] = 603393,
  [SMALL_STATE(13836)] = 603417,
  [SMALL_STATE(13837)] = 603437,
  [SMALL_STATE(13838)] = 603457,
  [SMALL_STATE(13839)] = 603477,
  [SMALL_STATE(13840)] = 603499,
  [SMALL_STATE(13841)] = 603519,
  [SMALL_STATE(13842)] = 603543,
  [SMALL_STATE(13843)] = 603567,
  [SMALL_STATE(13844)] = 603587,
  [SMALL_STATE(13845)] = 603607,
  [SMALL_STATE(13846)] = 603631,
  [SMALL_STATE(13847)] = 603651,
  [SMALL_STATE(13848)] = 603671,
  [SMALL_STATE(13849)] = 603691,
  [SMALL_STATE(13850)] = 603711,
  [SMALL_STATE(13851)] = 603737,
  [SMALL_STATE(13852)] = 603759,
  [SMALL_STATE(13853)] = 603779,
  [SMALL_STATE(13854)] = 603801,
  [SMALL_STATE(13855)] = 603821,
  [SMALL_STATE(13856)] = 603843,
  [SMALL_STATE(13857)] = 603867,
  [SMALL_STATE(13858)] = 603887,
  [SMALL_STATE(13859)] = 603911,
  [SMALL_STATE(13860)] = 603935,
  [SMALL_STATE(13861)] = 603955,
  [SMALL_STATE(13862)] = 603975,
  [SMALL_STATE(13863)] = 603999,
  [SMALL_STATE(13864)] = 604027,
  [SMALL_STATE(13865)] = 604051,
  [SMALL_STATE(13866)] = 604075,
  [SMALL_STATE(13867)] = 604103,
  [SMALL_STATE(13868)] = 604123,
  [SMALL_STATE(13869)] = 604147,
  [SMALL_STATE(13870)] = 604171,
  [SMALL_STATE(13871)] = 604197,
  [SMALL_STATE(13872)] = 604217,
  [SMALL_STATE(13873)] = 604241,
  [SMALL_STATE(13874)] = 604265,
  [SMALL_STATE(13875)] = 604289,
  [SMALL_STATE(13876)] = 604315,
  [SMALL_STATE(13877)] = 604339,
  [SMALL_STATE(13878)] = 604371,
  [SMALL_STATE(13879)] = 604403,
  [SMALL_STATE(13880)] = 604425,
  [SMALL_STATE(13881)] = 604445,
  [SMALL_STATE(13882)] = 604467,
  [SMALL_STATE(13883)] = 604499,
  [SMALL_STATE(13884)] = 604519,
  [SMALL_STATE(13885)] = 604541,
  [SMALL_STATE(13886)] = 604565,
  [SMALL_STATE(13887)] = 604597,
  [SMALL_STATE(13888)] = 604623,
  [SMALL_STATE(13889)] = 604643,
  [SMALL_STATE(13890)] = 604665,
  [SMALL_STATE(13891)] = 604685,
  [SMALL_STATE(13892)] = 604707,
  [SMALL_STATE(13893)] = 604731,
  [SMALL_STATE(13894)] = 604751,
  [SMALL_STATE(13895)] = 604771,
  [SMALL_STATE(13896)] = 604795,
  [SMALL_STATE(13897)] = 604819,
  [SMALL_STATE(13898)] = 604839,
  [SMALL_STATE(13899)] = 604859,
  [SMALL_STATE(13900)] = 604887,
  [SMALL_STATE(13901)] = 604911,
  [SMALL_STATE(13902)] = 604933,
  [SMALL_STATE(13903)] = 604957,
  [SMALL_STATE(13904)] = 604977,
  [SMALL_STATE(13905)] = 604999,
  [SMALL_STATE(13906)] = 605019,
  [SMALL_STATE(13907)] = 605045,
  [SMALL_STATE(13908)] = 605069,
  [SMALL_STATE(13909)] = 605093,
  [SMALL_STATE(13910)] = 605119,
  [SMALL_STATE(13911)] = 605143,
  [SMALL_STATE(13912)] = 605169,
  [SMALL_STATE(13913)] = 605193,
  [SMALL_STATE(13914)] = 605219,
  [SMALL_STATE(13915)] = 605241,
  [SMALL_STATE(13916)] = 605261,
  [SMALL_STATE(13917)] = 605287,
  [SMALL_STATE(13918)] = 605307,
  [SMALL_STATE(13919)] = 605331,
  [SMALL_STATE(13920)] = 605351,
  [SMALL_STATE(13921)] = 605375,
  [SMALL_STATE(13922)] = 605401,
  [SMALL_STATE(13923)] = 605425,
  [SMALL_STATE(13924)] = 605451,
  [SMALL_STATE(13925)] = 605471,
  [SMALL_STATE(13926)] = 605491,
  [SMALL_STATE(13927)] = 605515,
  [SMALL_STATE(13928)] = 605535,
  [SMALL_STATE(13929)] = 605557,
  [SMALL_STATE(13930)] = 605583,
  [SMALL_STATE(13931)] = 605603,
  [SMALL_STATE(13932)] = 605629,
  [SMALL_STATE(13933)] = 605649,
  [SMALL_STATE(13934)] = 605671,
  [SMALL_STATE(13935)] = 605701,
  [SMALL_STATE(13936)] = 605721,
  [SMALL_STATE(13937)] = 605747,
  [SMALL_STATE(13938)] = 605773,
  [SMALL_STATE(13939)] = 605797,
  [SMALL_STATE(13940)] = 605821,
  [SMALL_STATE(13941)] = 605845,
  [SMALL_STATE(13942)] = 605865,
  [SMALL_STATE(13943)] = 605893,
  [SMALL_STATE(13944)] = 605913,
  [SMALL_STATE(13945)] = 605939,
  [SMALL_STATE(13946)] = 605959,
  [SMALL_STATE(13947)] = 605983,
  [SMALL_STATE(13948)] = 606007,
  [SMALL_STATE(13949)] = 606031,
  [SMALL_STATE(13950)] = 606055,
  [SMALL_STATE(13951)] = 606075,
  [SMALL_STATE(13952)] = 606099,
  [SMALL_STATE(13953)] = 606129,
  [SMALL_STATE(13954)] = 606155,
  [SMALL_STATE(13955)] = 606179,
  [SMALL_STATE(13956)] = 606199,
  [SMALL_STATE(13957)] = 606225,
  [SMALL_STATE(13958)] = 606253,
  [SMALL_STATE(13959)] = 606273,
  [SMALL_STATE(13960)] = 606293,
  [SMALL_STATE(13961)] = 606313,
  [SMALL_STATE(13962)] = 606333,
  [SMALL_STATE(13963)] = 606353,
  [SMALL_STATE(13964)] = 606377,
  [SMALL_STATE(13965)] = 606403,
  [SMALL_STATE(13966)] = 606423,
  [SMALL_STATE(13967)] = 606447,
  [SMALL_STATE(13968)] = 606473,
  [SMALL_STATE(13969)] = 606497,
  [SMALL_STATE(13970)] = 606521,
  [SMALL_STATE(13971)] = 606551,
  [SMALL_STATE(13972)] = 606577,
  [SMALL_STATE(13973)] = 606601,
  [SMALL_STATE(13974)] = 606627,
  [SMALL_STATE(13975)] = 606647,
  [SMALL_STATE(13976)] = 606667,
  [SMALL_STATE(13977)] = 606691,
  [SMALL_STATE(13978)] = 606711,
  [SMALL_STATE(13979)] = 606735,
  [SMALL_STATE(13980)] = 606757,
  [SMALL_STATE(13981)] = 606779,
  [SMALL_STATE(13982)] = 606799,
  [SMALL_STATE(13983)] = 606823,
  [SMALL_STATE(13984)] = 606843,
  [SMALL_STATE(13985)] = 606863,
  [SMALL_STATE(13986)] = 606889,
  [SMALL_STATE(13987)] = 606909,
  [SMALL_STATE(13988)] = 606933,
  [SMALL_STATE(13989)] = 606953,
  [SMALL_STATE(13990)] = 606973,
  [SMALL_STATE(13991)] = 606993,
  [SMALL_STATE(13992)] = 607013,
  [SMALL_STATE(13993)] = 607035,
  [SMALL_STATE(13994)] = 607061,
  [SMALL_STATE(13995)] = 607081,
  [SMALL_STATE(13996)] = 607105,
  [SMALL_STATE(13997)] = 607127,
  [SMALL_STATE(13998)] = 607147,
  [SMALL_STATE(13999)] = 607167,
  [SMALL_STATE(14000)] = 607187,
  [SMALL_STATE(14001)] = 607209,
  [SMALL_STATE(14002)] = 607231,
  [SMALL_STATE(14003)] = 607253,
  [SMALL_STATE(14004)] = 607275,
  [SMALL_STATE(14005)] = 607305,
  [SMALL_STATE(14006)] = 607331,
  [SMALL_STATE(14007)] = 607351,
  [SMALL_STATE(14008)] = 607377,
  [SMALL_STATE(14009)] = 607399,
  [SMALL_STATE(14010)] = 607422,
  [SMALL_STATE(14011)] = 607441,
  [SMALL_STATE(14012)] = 607466,
  [SMALL_STATE(14013)] = 607491,
  [SMALL_STATE(14014)] = 607510,
  [SMALL_STATE(14015)] = 607533,
  [SMALL_STATE(14016)] = 607562,
  [SMALL_STATE(14017)] = 607587,
  [SMALL_STATE(14018)] = 607606,
  [SMALL_STATE(14019)] = 607629,
  [SMALL_STATE(14020)] = 607654,
  [SMALL_STATE(14021)] = 607673,
  [SMALL_STATE(14022)] = 607694,
  [SMALL_STATE(14023)] = 607717,
  [SMALL_STATE(14024)] = 607738,
  [SMALL_STATE(14025)] = 607757,
  [SMALL_STATE(14026)] = 607780,
  [SMALL_STATE(14027)] = 607799,
  [SMALL_STATE(14028)] = 607828,
  [SMALL_STATE(14029)] = 607851,
  [SMALL_STATE(14030)] = 607874,
  [SMALL_STATE(14031)] = 607893,
  [SMALL_STATE(14032)] = 607912,
  [SMALL_STATE(14033)] = 607931,
  [SMALL_STATE(14034)] = 607950,
  [SMALL_STATE(14035)] = 607979,
  [SMALL_STATE(14036)] = 608008,
  [SMALL_STATE(14037)] = 608037,
  [SMALL_STATE(14038)] = 608056,
  [SMALL_STATE(14039)] = 608079,
  [SMALL_STATE(14040)] = 608098,
  [SMALL_STATE(14041)] = 608119,
  [SMALL_STATE(14042)] = 608144,
  [SMALL_STATE(14043)] = 608165,
  [SMALL_STATE(14044)] = 608184,
  [SMALL_STATE(14045)] = 608203,
  [SMALL_STATE(14046)] = 608226,
  [SMALL_STATE(14047)] = 608249,
  [SMALL_STATE(14048)] = 608268,
  [SMALL_STATE(14049)] = 608287,
  [SMALL_STATE(14050)] = 608316,
  [SMALL_STATE(14051)] = 608335,
  [SMALL_STATE(14052)] = 608354,
  [SMALL_STATE(14053)] = 608373,
  [SMALL_STATE(14054)] = 608402,
  [SMALL_STATE(14055)] = 608421,
  [SMALL_STATE(14056)] = 608446,
  [SMALL_STATE(14057)] = 608471,
  [SMALL_STATE(14058)] = 608490,
  [SMALL_STATE(14059)] = 608511,
  [SMALL_STATE(14060)] = 608530,
  [SMALL_STATE(14061)] = 608549,
  [SMALL_STATE(14062)] = 608568,
  [SMALL_STATE(14063)] = 608597,
  [SMALL_STATE(14064)] = 608616,
  [SMALL_STATE(14065)] = 608639,
  [SMALL_STATE(14066)] = 608662,
  [SMALL_STATE(14067)] = 608681,
  [SMALL_STATE(14068)] = 608704,
  [SMALL_STATE(14069)] = 608723,
  [SMALL_STATE(14070)] = 608752,
  [SMALL_STATE(14071)] = 608773,
  [SMALL_STATE(14072)] = 608802,
  [SMALL_STATE(14073)] = 608821,
  [SMALL_STATE(14074)] = 608850,
  [SMALL_STATE(14075)] = 608879,
  [SMALL_STATE(14076)] = 608908,
  [SMALL_STATE(14077)] = 608933,
  [SMALL_STATE(14078)] = 608952,
  [SMALL_STATE(14079)] = 608971,
  [SMALL_STATE(14080)] = 608994,
  [SMALL_STATE(14081)] = 609019,
  [SMALL_STATE(14082)] = 609038,
  [SMALL_STATE(14083)] = 609057,
  [SMALL_STATE(14084)] = 609082,
  [SMALL_STATE(14085)] = 609101,
  [SMALL_STATE(14086)] = 609120,
  [SMALL_STATE(14087)] = 609149,
  [SMALL_STATE(14088)] = 609170,
  [SMALL_STATE(14089)] = 609199,
  [SMALL_STATE(14090)] = 609228,
  [SMALL_STATE(14091)] = 609247,
  [SMALL_STATE(14092)] = 609270,
  [SMALL_STATE(14093)] = 609289,
  [SMALL_STATE(14094)] = 609314,
  [SMALL_STATE(14095)] = 609337,
  [SMALL_STATE(14096)] = 609362,
  [SMALL_STATE(14097)] = 609381,
  [SMALL_STATE(14098)] = 609400,
  [SMALL_STATE(14099)] = 609429,
  [SMALL_STATE(14100)] = 609448,
  [SMALL_STATE(14101)] = 609471,
  [SMALL_STATE(14102)] = 609500,
  [SMALL_STATE(14103)] = 609519,
  [SMALL_STATE(14104)] = 609548,
  [SMALL_STATE(14105)] = 609567,
  [SMALL_STATE(14106)] = 609592,
  [SMALL_STATE(14107)] = 609611,
  [SMALL_STATE(14108)] = 609636,
  [SMALL_STATE(14109)] = 609665,
  [SMALL_STATE(14110)] = 609694,
  [SMALL_STATE(14111)] = 609713,
  [SMALL_STATE(14112)] = 609742,
  [SMALL_STATE(14113)] = 609761,
  [SMALL_STATE(14114)] = 609782,
  [SMALL_STATE(14115)] = 609805,
  [SMALL_STATE(14116)] = 609826,
  [SMALL_STATE(14117)] = 609845,
  [SMALL_STATE(14118)] = 609868,
  [SMALL_STATE(14119)] = 609897,
  [SMALL_STATE(14120)] = 609926,
  [SMALL_STATE(14121)] = 609945,
  [SMALL_STATE(14122)] = 609970,
  [SMALL_STATE(14123)] = 609989,
  [SMALL_STATE(14124)] = 610012,
  [SMALL_STATE(14125)] = 610031,
  [SMALL_STATE(14126)] = 610060,
  [SMALL_STATE(14127)] = 610089,
  [SMALL_STATE(14128)] = 610108,
  [SMALL_STATE(14129)] = 610127,
  [SMALL_STATE(14130)] = 610156,
  [SMALL_STATE(14131)] = 610175,
  [SMALL_STATE(14132)] = 610194,
  [SMALL_STATE(14133)] = 610223,
  [SMALL_STATE(14134)] = 610242,
  [SMALL_STATE(14135)] = 610263,
  [SMALL_STATE(14136)] = 610284,
  [SMALL_STATE(14137)] = 610307,
  [SMALL_STATE(14138)] = 610326,
  [SMALL_STATE(14139)] = 610355,
  [SMALL_STATE(14140)] = 610374,
  [SMALL_STATE(14141)] = 610393,
  [SMALL_STATE(14142)] = 610412,
  [SMALL_STATE(14143)] = 610435,
  [SMALL_STATE(14144)] = 610464,
  [SMALL_STATE(14145)] = 610487,
  [SMALL_STATE(14146)] = 610516,
  [SMALL_STATE(14147)] = 610541,
  [SMALL_STATE(14148)] = 610564,
  [SMALL_STATE(14149)] = 610589,
  [SMALL_STATE(14150)] = 610618,
  [SMALL_STATE(14151)] = 610647,
  [SMALL_STATE(14152)] = 610670,
  [SMALL_STATE(14153)] = 610693,
  [SMALL_STATE(14154)] = 610718,
  [SMALL_STATE(14155)] = 610737,
  [SMALL_STATE(14156)] = 610760,
  [SMALL_STATE(14157)] = 610779,
  [SMALL_STATE(14158)] = 610802,
  [SMALL_STATE(14159)] = 610821,
  [SMALL_STATE(14160)] = 610850,
  [SMALL_STATE(14161)] = 610869,
  [SMALL_STATE(14162)] = 610888,
  [SMALL_STATE(14163)] = 610911,
  [SMALL_STATE(14164)] = 610934,
  [SMALL_STATE(14165)] = 610959,
  [SMALL_STATE(14166)] = 610977,
  [SMALL_STATE(14167)] = 611003,
  [SMALL_STATE(14168)] = 611021,
  [SMALL_STATE(14169)] = 611047,
  [SMALL_STATE(14170)] = 611071,
  [SMALL_STATE(14171)] = 611089,
  [SMALL_STATE(14172)] = 611111,
  [SMALL_STATE(14173)] = 611137,
  [SMALL_STATE(14174)] = 611155,
  [SMALL_STATE(14175)] = 611179,
  [SMALL_STATE(14176)] = 611205,
  [SMALL_STATE(14177)] = 611223,
  [SMALL_STATE(14178)] = 611249,
  [SMALL_STATE(14179)] = 611267,
  [SMALL_STATE(14180)] = 611285,
  [SMALL_STATE(14181)] = 611311,
  [SMALL_STATE(14182)] = 611329,
  [SMALL_STATE(14183)] = 611347,
  [SMALL_STATE(14184)] = 611373,
  [SMALL_STATE(14185)] = 611391,
  [SMALL_STATE(14186)] = 611409,
  [SMALL_STATE(14187)] = 611435,
  [SMALL_STATE(14188)] = 611453,
  [SMALL_STATE(14189)] = 611471,
  [SMALL_STATE(14190)] = 611495,
  [SMALL_STATE(14191)] = 611517,
  [SMALL_STATE(14192)] = 611541,
  [SMALL_STATE(14193)] = 611567,
  [SMALL_STATE(14194)] = 611585,
  [SMALL_STATE(14195)] = 611603,
  [SMALL_STATE(14196)] = 611621,
  [SMALL_STATE(14197)] = 611639,
  [SMALL_STATE(14198)] = 611663,
  [SMALL_STATE(14199)] = 611689,
  [SMALL_STATE(14200)] = 611707,
  [SMALL_STATE(14201)] = 611733,
  [SMALL_STATE(14202)] = 611759,
  [SMALL_STATE(14203)] = 611781,
  [SMALL_STATE(14204)] = 611801,
  [SMALL_STATE(14205)] = 611827,
  [SMALL_STATE(14206)] = 611853,
  [SMALL_STATE(14207)] = 611875,
  [SMALL_STATE(14208)] = 611895,
  [SMALL_STATE(14209)] = 611921,
  [SMALL_STATE(14210)] = 611943,
  [SMALL_STATE(14211)] = 611963,
  [SMALL_STATE(14212)] = 611989,
  [SMALL_STATE(14213)] = 612007,
  [SMALL_STATE(14214)] = 612025,
  [SMALL_STATE(14215)] = 612047,
  [SMALL_STATE(14216)] = 612073,
  [SMALL_STATE(14217)] = 612091,
  [SMALL_STATE(14218)] = 612117,
  [SMALL_STATE(14219)] = 612139,
  [SMALL_STATE(14220)] = 612163,
  [SMALL_STATE(14221)] = 612181,
  [SMALL_STATE(14222)] = 612207,
  [SMALL_STATE(14223)] = 612229,
  [SMALL_STATE(14224)] = 612255,
  [SMALL_STATE(14225)] = 612275,
  [SMALL_STATE(14226)] = 612293,
  [SMALL_STATE(14227)] = 612311,
  [SMALL_STATE(14228)] = 612337,
  [SMALL_STATE(14229)] = 612363,
  [SMALL_STATE(14230)] = 612385,
  [SMALL_STATE(14231)] = 612403,
  [SMALL_STATE(14232)] = 612421,
  [SMALL_STATE(14233)] = 612439,
  [SMALL_STATE(14234)] = 612465,
  [SMALL_STATE(14235)] = 612487,
  [SMALL_STATE(14236)] = 612513,
  [SMALL_STATE(14237)] = 612531,
  [SMALL_STATE(14238)] = 612549,
  [SMALL_STATE(14239)] = 612569,
  [SMALL_STATE(14240)] = 612587,
  [SMALL_STATE(14241)] = 612613,
  [SMALL_STATE(14242)] = 612631,
  [SMALL_STATE(14243)] = 612651,
  [SMALL_STATE(14244)] = 612677,
  [SMALL_STATE(14245)] = 612703,
  [SMALL_STATE(14246)] = 612721,
  [SMALL_STATE(14247)] = 612747,
  [SMALL_STATE(14248)] = 612765,
  [SMALL_STATE(14249)] = 612783,
  [SMALL_STATE(14250)] = 612803,
  [SMALL_STATE(14251)] = 612823,
  [SMALL_STATE(14252)] = 612841,
  [SMALL_STATE(14253)] = 612859,
  [SMALL_STATE(14254)] = 612877,
  [SMALL_STATE(14255)] = 612901,
  [SMALL_STATE(14256)] = 612923,
  [SMALL_STATE(14257)] = 612945,
  [SMALL_STATE(14258)] = 612969,
  [SMALL_STATE(14259)] = 612987,
  [SMALL_STATE(14260)] = 613009,
  [SMALL_STATE(14261)] = 613031,
  [SMALL_STATE(14262)] = 613049,
  [SMALL_STATE(14263)] = 613073,
  [SMALL_STATE(14264)] = 613091,
  [SMALL_STATE(14265)] = 613117,
  [SMALL_STATE(14266)] = 613135,
  [SMALL_STATE(14267)] = 613159,
  [SMALL_STATE(14268)] = 613177,
  [SMALL_STATE(14269)] = 613195,
  [SMALL_STATE(14270)] = 613217,
  [SMALL_STATE(14271)] = 613239,
  [SMALL_STATE(14272)] = 613259,
  [SMALL_STATE(14273)] = 613277,
  [SMALL_STATE(14274)] = 613299,
  [SMALL_STATE(14275)] = 613317,
  [SMALL_STATE(14276)] = 613335,
  [SMALL_STATE(14277)] = 613353,
  [SMALL_STATE(14278)] = 613371,
  [SMALL_STATE(14279)] = 613389,
  [SMALL_STATE(14280)] = 613415,
  [SMALL_STATE(14281)] = 613441,
  [SMALL_STATE(14282)] = 613459,
  [SMALL_STATE(14283)] = 613485,
  [SMALL_STATE(14284)] = 613503,
  [SMALL_STATE(14285)] = 613525,
  [SMALL_STATE(14286)] = 613549,
  [SMALL_STATE(14287)] = 613573,
  [SMALL_STATE(14288)] = 613591,
  [SMALL_STATE(14289)] = 613617,
  [SMALL_STATE(14290)] = 613635,
  [SMALL_STATE(14291)] = 613661,
  [SMALL_STATE(14292)] = 613679,
  [SMALL_STATE(14293)] = 613705,
  [SMALL_STATE(14294)] = 613723,
  [SMALL_STATE(14295)] = 613741,
  [SMALL_STATE(14296)] = 613759,
  [SMALL_STATE(14297)] = 613777,
  [SMALL_STATE(14298)] = 613801,
  [SMALL_STATE(14299)] = 613819,
  [SMALL_STATE(14300)] = 613845,
  [SMALL_STATE(14301)] = 613863,
  [SMALL_STATE(14302)] = 613881,
  [SMALL_STATE(14303)] = 613899,
  [SMALL_STATE(14304)] = 613917,
  [SMALL_STATE(14305)] = 613943,
  [SMALL_STATE(14306)] = 613969,
  [SMALL_STATE(14307)] = 613995,
  [SMALL_STATE(14308)] = 614021,
  [SMALL_STATE(14309)] = 614039,
  [SMALL_STATE(14310)] = 614057,
  [SMALL_STATE(14311)] = 614081,
  [SMALL_STATE(14312)] = 614099,
  [SMALL_STATE(14313)] = 614123,
  [SMALL_STATE(14314)] = 614141,
  [SMALL_STATE(14315)] = 614165,
  [SMALL_STATE(14316)] = 614189,
  [SMALL_STATE(14317)] = 614215,
  [SMALL_STATE(14318)] = 614241,
  [SMALL_STATE(14319)] = 614267,
  [SMALL_STATE(14320)] = 614291,
  [SMALL_STATE(14321)] = 614311,
  [SMALL_STATE(14322)] = 614329,
  [SMALL_STATE(14323)] = 614349,
  [SMALL_STATE(14324)] = 614369,
  [SMALL_STATE(14325)] = 614395,
  [SMALL_STATE(14326)] = 614413,
  [SMALL_STATE(14327)] = 614431,
  [SMALL_STATE(14328)] = 614449,
  [SMALL_STATE(14329)] = 614467,
  [SMALL_STATE(14330)] = 614485,
  [SMALL_STATE(14331)] = 614503,
  [SMALL_STATE(14332)] = 614521,
  [SMALL_STATE(14333)] = 614539,
  [SMALL_STATE(14334)] = 614559,
  [SMALL_STATE(14335)] = 614577,
  [SMALL_STATE(14336)] = 614603,
  [SMALL_STATE(14337)] = 614623,
  [SMALL_STATE(14338)] = 614645,
  [SMALL_STATE(14339)] = 614669,
  [SMALL_STATE(14340)] = 614687,
  [SMALL_STATE(14341)] = 614705,
  [SMALL_STATE(14342)] = 614723,
  [SMALL_STATE(14343)] = 614749,
  [SMALL_STATE(14344)] = 614767,
  [SMALL_STATE(14345)] = 614791,
  [SMALL_STATE(14346)] = 614815,
  [SMALL_STATE(14347)] = 614837,
  [SMALL_STATE(14348)] = 614861,
  [SMALL_STATE(14349)] = 614879,
  [SMALL_STATE(14350)] = 614905,
  [SMALL_STATE(14351)] = 614923,
  [SMALL_STATE(14352)] = 614949,
  [SMALL_STATE(14353)] = 614967,
  [SMALL_STATE(14354)] = 614985,
  [SMALL_STATE(14355)] = 615003,
  [SMALL_STATE(14356)] = 615029,
  [SMALL_STATE(14357)] = 615047,
  [SMALL_STATE(14358)] = 615073,
  [SMALL_STATE(14359)] = 615091,
  [SMALL_STATE(14360)] = 615109,
  [SMALL_STATE(14361)] = 615133,
  [SMALL_STATE(14362)] = 615151,
  [SMALL_STATE(14363)] = 615177,
  [SMALL_STATE(14364)] = 615195,
  [SMALL_STATE(14365)] = 615213,
  [SMALL_STATE(14366)] = 615231,
  [SMALL_STATE(14367)] = 615249,
  [SMALL_STATE(14368)] = 615267,
  [SMALL_STATE(14369)] = 615285,
  [SMALL_STATE(14370)] = 615311,
  [SMALL_STATE(14371)] = 615337,
  [SMALL_STATE(14372)] = 615363,
  [SMALL_STATE(14373)] = 615387,
  [SMALL_STATE(14374)] = 615405,
  [SMALL_STATE(14375)] = 615423,
  [SMALL_STATE(14376)] = 615441,
  [SMALL_STATE(14377)] = 615459,
  [SMALL_STATE(14378)] = 615477,
  [SMALL_STATE(14379)] = 615501,
  [SMALL_STATE(14380)] = 615519,
  [SMALL_STATE(14381)] = 615537,
  [SMALL_STATE(14382)] = 615555,
  [SMALL_STATE(14383)] = 615581,
  [SMALL_STATE(14384)] = 615599,
  [SMALL_STATE(14385)] = 615617,
  [SMALL_STATE(14386)] = 615635,
  [SMALL_STATE(14387)] = 615661,
  [SMALL_STATE(14388)] = 615687,
  [SMALL_STATE(14389)] = 615713,
  [SMALL_STATE(14390)] = 615737,
  [SMALL_STATE(14391)] = 615755,
  [SMALL_STATE(14392)] = 615773,
  [SMALL_STATE(14393)] = 615791,
  [SMALL_STATE(14394)] = 615809,
  [SMALL_STATE(14395)] = 615835,
  [SMALL_STATE(14396)] = 615853,
  [SMALL_STATE(14397)] = 615877,
  [SMALL_STATE(14398)] = 615895,
  [SMALL_STATE(14399)] = 615921,
  [SMALL_STATE(14400)] = 615947,
  [SMALL_STATE(14401)] = 615965,
  [SMALL_STATE(14402)] = 615983,
  [SMALL_STATE(14403)] = 616001,
  [SMALL_STATE(14404)] = 616019,
  [SMALL_STATE(14405)] = 616039,
  [SMALL_STATE(14406)] = 616057,
  [SMALL_STATE(14407)] = 616075,
  [SMALL_STATE(14408)] = 616101,
  [SMALL_STATE(14409)] = 616123,
  [SMALL_STATE(14410)] = 616143,
  [SMALL_STATE(14411)] = 616165,
  [SMALL_STATE(14412)] = 616189,
  [SMALL_STATE(14413)] = 616215,
  [SMALL_STATE(14414)] = 616241,
  [SMALL_STATE(14415)] = 616259,
  [SMALL_STATE(14416)] = 616283,
  [SMALL_STATE(14417)] = 616307,
  [SMALL_STATE(14418)] = 616333,
  [SMALL_STATE(14419)] = 616354,
  [SMALL_STATE(14420)] = 616375,
  [SMALL_STATE(14421)] = 616392,
  [SMALL_STATE(14422)] = 616415,
  [SMALL_STATE(14423)] = 616438,
  [SMALL_STATE(14424)] = 616459,
  [SMALL_STATE(14425)] = 616476,
  [SMALL_STATE(14426)] = 616499,
  [SMALL_STATE(14427)] = 616520,
  [SMALL_STATE(14428)] = 616543,
  [SMALL_STATE(14429)] = 616566,
  [SMALL_STATE(14430)] = 616583,
  [SMALL_STATE(14431)] = 616604,
  [SMALL_STATE(14432)] = 616621,
  [SMALL_STATE(14433)] = 616644,
  [SMALL_STATE(14434)] = 616665,
  [SMALL_STATE(14435)] = 616686,
  [SMALL_STATE(14436)] = 616709,
  [SMALL_STATE(14437)] = 616732,
  [SMALL_STATE(14438)] = 616753,
  [SMALL_STATE(14439)] = 616770,
  [SMALL_STATE(14440)] = 616793,
  [SMALL_STATE(14441)] = 616814,
  [SMALL_STATE(14442)] = 616837,
  [SMALL_STATE(14443)] = 616854,
  [SMALL_STATE(14444)] = 616871,
  [SMALL_STATE(14445)] = 616888,
  [SMALL_STATE(14446)] = 616911,
  [SMALL_STATE(14447)] = 616934,
  [SMALL_STATE(14448)] = 616951,
  [SMALL_STATE(14449)] = 616968,
  [SMALL_STATE(14450)] = 616991,
  [SMALL_STATE(14451)] = 617014,
  [SMALL_STATE(14452)] = 617035,
  [SMALL_STATE(14453)] = 617058,
  [SMALL_STATE(14454)] = 617079,
  [SMALL_STATE(14455)] = 617098,
  [SMALL_STATE(14456)] = 617115,
  [SMALL_STATE(14457)] = 617132,
  [SMALL_STATE(14458)] = 617155,
  [SMALL_STATE(14459)] = 617172,
  [SMALL_STATE(14460)] = 617189,
  [SMALL_STATE(14461)] = 617212,
  [SMALL_STATE(14462)] = 617235,
  [SMALL_STATE(14463)] = 617258,
  [SMALL_STATE(14464)] = 617277,
  [SMALL_STATE(14465)] = 617300,
  [SMALL_STATE(14466)] = 617323,
  [SMALL_STATE(14467)] = 617346,
  [SMALL_STATE(14468)] = 617369,
  [SMALL_STATE(14469)] = 617392,
  [SMALL_STATE(14470)] = 617415,
  [SMALL_STATE(14471)] = 617432,
  [SMALL_STATE(14472)] = 617451,
  [SMALL_STATE(14473)] = 617474,
  [SMALL_STATE(14474)] = 617491,
  [SMALL_STATE(14475)] = 617514,
  [SMALL_STATE(14476)] = 617535,
  [SMALL_STATE(14477)] = 617556,
  [SMALL_STATE(14478)] = 617579,
  [SMALL_STATE(14479)] = 617596,
  [SMALL_STATE(14480)] = 617619,
  [SMALL_STATE(14481)] = 617636,
  [SMALL_STATE(14482)] = 617659,
  [SMALL_STATE(14483)] = 617680,
  [SMALL_STATE(14484)] = 617701,
  [SMALL_STATE(14485)] = 617724,
  [SMALL_STATE(14486)] = 617747,
  [SMALL_STATE(14487)] = 617768,
  [SMALL_STATE(14488)] = 617785,
  [SMALL_STATE(14489)] = 617806,
  [SMALL_STATE(14490)] = 617827,
  [SMALL_STATE(14491)] = 617846,
  [SMALL_STATE(14492)] = 617867,
  [SMALL_STATE(14493)] = 617884,
  [SMALL_STATE(14494)] = 617907,
  [SMALL_STATE(14495)] = 617926,
  [SMALL_STATE(14496)] = 617947,
  [SMALL_STATE(14497)] = 617964,
  [SMALL_STATE(14498)] = 617987,
  [SMALL_STATE(14499)] = 618010,
  [SMALL_STATE(14500)] = 618027,
  [SMALL_STATE(14501)] = 618050,
  [SMALL_STATE(14502)] = 618071,
  [SMALL_STATE(14503)] = 618088,
  [SMALL_STATE(14504)] = 618105,
  [SMALL_STATE(14505)] = 618122,
  [SMALL_STATE(14506)] = 618139,
  [SMALL_STATE(14507)] = 618160,
  [SMALL_STATE(14508)] = 618183,
  [SMALL_STATE(14509)] = 618204,
  [SMALL_STATE(14510)] = 618225,
  [SMALL_STATE(14511)] = 618246,
  [SMALL_STATE(14512)] = 618263,
  [SMALL_STATE(14513)] = 618280,
  [SMALL_STATE(14514)] = 618303,
  [SMALL_STATE(14515)] = 618324,
  [SMALL_STATE(14516)] = 618343,
  [SMALL_STATE(14517)] = 618364,
  [SMALL_STATE(14518)] = 618381,
  [SMALL_STATE(14519)] = 618398,
  [SMALL_STATE(14520)] = 618421,
  [SMALL_STATE(14521)] = 618438,
  [SMALL_STATE(14522)] = 618461,
  [SMALL_STATE(14523)] = 618484,
  [SMALL_STATE(14524)] = 618507,
  [SMALL_STATE(14525)] = 618526,
  [SMALL_STATE(14526)] = 618547,
  [SMALL_STATE(14527)] = 618568,
  [SMALL_STATE(14528)] = 618591,
  [SMALL_STATE(14529)] = 618608,
  [SMALL_STATE(14530)] = 618631,
  [SMALL_STATE(14531)] = 618654,
  [SMALL_STATE(14532)] = 618675,
  [SMALL_STATE(14533)] = 618698,
  [SMALL_STATE(14534)] = 618715,
  [SMALL_STATE(14535)] = 618738,
  [SMALL_STATE(14536)] = 618759,
  [SMALL_STATE(14537)] = 618782,
  [SMALL_STATE(14538)] = 618805,
  [SMALL_STATE(14539)] = 618828,
  [SMALL_STATE(14540)] = 618851,
  [SMALL_STATE(14541)] = 618874,
  [SMALL_STATE(14542)] = 618897,
  [SMALL_STATE(14543)] = 618914,
  [SMALL_STATE(14544)] = 618935,
  [SMALL_STATE(14545)] = 618954,
  [SMALL_STATE(14546)] = 618971,
  [SMALL_STATE(14547)] = 618994,
  [SMALL_STATE(14548)] = 619017,
  [SMALL_STATE(14549)] = 619038,
  [SMALL_STATE(14550)] = 619055,
  [SMALL_STATE(14551)] = 619078,
  [SMALL_STATE(14552)] = 619099,
  [SMALL_STATE(14553)] = 619122,
  [SMALL_STATE(14554)] = 619139,
  [SMALL_STATE(14555)] = 619162,
  [SMALL_STATE(14556)] = 619179,
  [SMALL_STATE(14557)] = 619202,
  [SMALL_STATE(14558)] = 619225,
  [SMALL_STATE(14559)] = 619242,
  [SMALL_STATE(14560)] = 619263,
  [SMALL_STATE(14561)] = 619286,
  [SMALL_STATE(14562)] = 619309,
  [SMALL_STATE(14563)] = 619328,
  [SMALL_STATE(14564)] = 619345,
  [SMALL_STATE(14565)] = 619366,
  [SMALL_STATE(14566)] = 619389,
  [SMALL_STATE(14567)] = 619412,
  [SMALL_STATE(14568)] = 619435,
  [SMALL_STATE(14569)] = 619452,
  [SMALL_STATE(14570)] = 619475,
  [SMALL_STATE(14571)] = 619498,
  [SMALL_STATE(14572)] = 619521,
  [SMALL_STATE(14573)] = 619544,
  [SMALL_STATE(14574)] = 619567,
  [SMALL_STATE(14575)] = 619590,
  [SMALL_STATE(14576)] = 619613,
  [SMALL_STATE(14577)] = 619632,
  [SMALL_STATE(14578)] = 619653,
  [SMALL_STATE(14579)] = 619676,
  [SMALL_STATE(14580)] = 619693,
  [SMALL_STATE(14581)] = 619714,
  [SMALL_STATE(14582)] = 619737,
  [SMALL_STATE(14583)] = 619760,
  [SMALL_STATE(14584)] = 619783,
  [SMALL_STATE(14585)] = 619806,
  [SMALL_STATE(14586)] = 619827,
  [SMALL_STATE(14587)] = 619850,
  [SMALL_STATE(14588)] = 619873,
  [SMALL_STATE(14589)] = 619896,
  [SMALL_STATE(14590)] = 619919,
  [SMALL_STATE(14591)] = 619936,
  [SMALL_STATE(14592)] = 619959,
  [SMALL_STATE(14593)] = 619982,
  [SMALL_STATE(14594)] = 620005,
  [SMALL_STATE(14595)] = 620022,
  [SMALL_STATE(14596)] = 620043,
  [SMALL_STATE(14597)] = 620064,
  [SMALL_STATE(14598)] = 620081,
  [SMALL_STATE(14599)] = 620098,
  [SMALL_STATE(14600)] = 620115,
  [SMALL_STATE(14601)] = 620132,
  [SMALL_STATE(14602)] = 620151,
  [SMALL_STATE(14603)] = 620168,
  [SMALL_STATE(14604)] = 620191,
  [SMALL_STATE(14605)] = 620208,
  [SMALL_STATE(14606)] = 620231,
  [SMALL_STATE(14607)] = 620254,
  [SMALL_STATE(14608)] = 620277,
  [SMALL_STATE(14609)] = 620294,
  [SMALL_STATE(14610)] = 620317,
  [SMALL_STATE(14611)] = 620334,
  [SMALL_STATE(14612)] = 620351,
  [SMALL_STATE(14613)] = 620368,
  [SMALL_STATE(14614)] = 620391,
  [SMALL_STATE(14615)] = 620412,
  [SMALL_STATE(14616)] = 620433,
  [SMALL_STATE(14617)] = 620456,
  [SMALL_STATE(14618)] = 620475,
  [SMALL_STATE(14619)] = 620496,
  [SMALL_STATE(14620)] = 620513,
  [SMALL_STATE(14621)] = 620530,
  [SMALL_STATE(14622)] = 620549,
  [SMALL_STATE(14623)] = 620566,
  [SMALL_STATE(14624)] = 620587,
  [SMALL_STATE(14625)] = 620608,
  [SMALL_STATE(14626)] = 620625,
  [SMALL_STATE(14627)] = 620648,
  [SMALL_STATE(14628)] = 620671,
  [SMALL_STATE(14629)] = 620688,
  [SMALL_STATE(14630)] = 620705,
  [SMALL_STATE(14631)] = 620726,
  [SMALL_STATE(14632)] = 620747,
  [SMALL_STATE(14633)] = 620770,
  [SMALL_STATE(14634)] = 620793,
  [SMALL_STATE(14635)] = 620816,
  [SMALL_STATE(14636)] = 620833,
  [SMALL_STATE(14637)] = 620856,
  [SMALL_STATE(14638)] = 620879,
  [SMALL_STATE(14639)] = 620896,
  [SMALL_STATE(14640)] = 620919,
  [SMALL_STATE(14641)] = 620942,
  [SMALL_STATE(14642)] = 620959,
  [SMALL_STATE(14643)] = 620982,
  [SMALL_STATE(14644)] = 621005,
  [SMALL_STATE(14645)] = 621028,
  [SMALL_STATE(14646)] = 621051,
  [SMALL_STATE(14647)] = 621074,
  [SMALL_STATE(14648)] = 621095,
  [SMALL_STATE(14649)] = 621118,
  [SMALL_STATE(14650)] = 621135,
  [SMALL_STATE(14651)] = 621156,
  [SMALL_STATE(14652)] = 621177,
  [SMALL_STATE(14653)] = 621200,
  [SMALL_STATE(14654)] = 621223,
  [SMALL_STATE(14655)] = 621240,
  [SMALL_STATE(14656)] = 621261,
  [SMALL_STATE(14657)] = 621284,
  [SMALL_STATE(14658)] = 621307,
  [SMALL_STATE(14659)] = 621330,
  [SMALL_STATE(14660)] = 621351,
  [SMALL_STATE(14661)] = 621374,
  [SMALL_STATE(14662)] = 621397,
  [SMALL_STATE(14663)] = 621420,
  [SMALL_STATE(14664)] = 621443,
  [SMALL_STATE(14665)] = 621460,
  [SMALL_STATE(14666)] = 621481,
  [SMALL_STATE(14667)] = 621502,
  [SMALL_STATE(14668)] = 621525,
  [SMALL_STATE(14669)] = 621546,
  [SMALL_STATE(14670)] = 621569,
  [SMALL_STATE(14671)] = 621592,
  [SMALL_STATE(14672)] = 621609,
  [SMALL_STATE(14673)] = 621632,
  [SMALL_STATE(14674)] = 621649,
  [SMALL_STATE(14675)] = 621670,
  [SMALL_STATE(14676)] = 621693,
  [SMALL_STATE(14677)] = 621710,
  [SMALL_STATE(14678)] = 621731,
  [SMALL_STATE(14679)] = 621748,
  [SMALL_STATE(14680)] = 621765,
  [SMALL_STATE(14681)] = 621782,
  [SMALL_STATE(14682)] = 621805,
  [SMALL_STATE(14683)] = 621828,
  [SMALL_STATE(14684)] = 621849,
  [SMALL_STATE(14685)] = 621872,
  [SMALL_STATE(14686)] = 621889,
  [SMALL_STATE(14687)] = 621912,
  [SMALL_STATE(14688)] = 621935,
  [SMALL_STATE(14689)] = 621958,
  [SMALL_STATE(14690)] = 621979,
  [SMALL_STATE(14691)] = 622002,
  [SMALL_STATE(14692)] = 622025,
  [SMALL_STATE(14693)] = 622042,
  [SMALL_STATE(14694)] = 622065,
  [SMALL_STATE(14695)] = 622082,
  [SMALL_STATE(14696)] = 622105,
  [SMALL_STATE(14697)] = 622126,
  [SMALL_STATE(14698)] = 622143,
  [SMALL_STATE(14699)] = 622160,
  [SMALL_STATE(14700)] = 622177,
  [SMALL_STATE(14701)] = 622200,
  [SMALL_STATE(14702)] = 622223,
  [SMALL_STATE(14703)] = 622240,
  [SMALL_STATE(14704)] = 622261,
  [SMALL_STATE(14705)] = 622278,
  [SMALL_STATE(14706)] = 622301,
  [SMALL_STATE(14707)] = 622324,
  [SMALL_STATE(14708)] = 622347,
  [SMALL_STATE(14709)] = 622368,
  [SMALL_STATE(14710)] = 622391,
  [SMALL_STATE(14711)] = 622412,
  [SMALL_STATE(14712)] = 622435,
  [SMALL_STATE(14713)] = 622458,
  [SMALL_STATE(14714)] = 622479,
  [SMALL_STATE(14715)] = 622496,
  [SMALL_STATE(14716)] = 622517,
  [SMALL_STATE(14717)] = 622534,
  [SMALL_STATE(14718)] = 622557,
  [SMALL_STATE(14719)] = 622574,
  [SMALL_STATE(14720)] = 622597,
  [SMALL_STATE(14721)] = 622620,
  [SMALL_STATE(14722)] = 622643,
  [SMALL_STATE(14723)] = 622660,
  [SMALL_STATE(14724)] = 622683,
  [SMALL_STATE(14725)] = 622700,
  [SMALL_STATE(14726)] = 622717,
  [SMALL_STATE(14727)] = 622740,
  [SMALL_STATE(14728)] = 622757,
  [SMALL_STATE(14729)] = 622780,
  [SMALL_STATE(14730)] = 622799,
  [SMALL_STATE(14731)] = 622822,
  [SMALL_STATE(14732)] = 622839,
  [SMALL_STATE(14733)] = 622859,
  [SMALL_STATE(14734)] = 622879,
  [SMALL_STATE(14735)] = 622899,
  [SMALL_STATE(14736)] = 622919,
  [SMALL_STATE(14737)] = 622939,
  [SMALL_STATE(14738)] = 622959,
  [SMALL_STATE(14739)] = 622979,
  [SMALL_STATE(14740)] = 622999,
  [SMALL_STATE(14741)] = 623019,
  [SMALL_STATE(14742)] = 623039,
  [SMALL_STATE(14743)] = 623059,
  [SMALL_STATE(14744)] = 623079,
  [SMALL_STATE(14745)] = 623099,
  [SMALL_STATE(14746)] = 623119,
  [SMALL_STATE(14747)] = 623139,
  [SMALL_STATE(14748)] = 623159,
  [SMALL_STATE(14749)] = 623179,
  [SMALL_STATE(14750)] = 623199,
  [SMALL_STATE(14751)] = 623219,
  [SMALL_STATE(14752)] = 623239,
  [SMALL_STATE(14753)] = 623259,
  [SMALL_STATE(14754)] = 623279,
  [SMALL_STATE(14755)] = 623297,
  [SMALL_STATE(14756)] = 623317,
  [SMALL_STATE(14757)] = 623337,
  [SMALL_STATE(14758)] = 623357,
  [SMALL_STATE(14759)] = 623377,
  [SMALL_STATE(14760)] = 623397,
  [SMALL_STATE(14761)] = 623417,
  [SMALL_STATE(14762)] = 623437,
  [SMALL_STATE(14763)] = 623457,
  [SMALL_STATE(14764)] = 623477,
  [SMALL_STATE(14765)] = 623497,
  [SMALL_STATE(14766)] = 623517,
  [SMALL_STATE(14767)] = 623537,
  [SMALL_STATE(14768)] = 623557,
  [SMALL_STATE(14769)] = 623577,
  [SMALL_STATE(14770)] = 623597,
  [SMALL_STATE(14771)] = 623617,
  [SMALL_STATE(14772)] = 623637,
  [SMALL_STATE(14773)] = 623657,
  [SMALL_STATE(14774)] = 623677,
  [SMALL_STATE(14775)] = 623697,
  [SMALL_STATE(14776)] = 623717,
  [SMALL_STATE(14777)] = 623737,
  [SMALL_STATE(14778)] = 623757,
  [SMALL_STATE(14779)] = 623777,
  [SMALL_STATE(14780)] = 623797,
  [SMALL_STATE(14781)] = 623817,
  [SMALL_STATE(14782)] = 623837,
  [SMALL_STATE(14783)] = 623857,
  [SMALL_STATE(14784)] = 623877,
  [SMALL_STATE(14785)] = 623897,
  [SMALL_STATE(14786)] = 623917,
  [SMALL_STATE(14787)] = 623937,
  [SMALL_STATE(14788)] = 623955,
  [SMALL_STATE(14789)] = 623975,
  [SMALL_STATE(14790)] = 623995,
  [SMALL_STATE(14791)] = 624015,
  [SMALL_STATE(14792)] = 624035,
  [SMALL_STATE(14793)] = 624055,
  [SMALL_STATE(14794)] = 624075,
  [SMALL_STATE(14795)] = 624095,
  [SMALL_STATE(14796)] = 624115,
  [SMALL_STATE(14797)] = 624135,
  [SMALL_STATE(14798)] = 624155,
  [SMALL_STATE(14799)] = 624175,
  [SMALL_STATE(14800)] = 624195,
  [SMALL_STATE(14801)] = 624213,
  [SMALL_STATE(14802)] = 624233,
  [SMALL_STATE(14803)] = 624253,
  [SMALL_STATE(14804)] = 624273,
  [SMALL_STATE(14805)] = 624293,
  [SMALL_STATE(14806)] = 624313,
  [SMALL_STATE(14807)] = 624333,
  [SMALL_STATE(14808)] = 624353,
  [SMALL_STATE(14809)] = 624373,
  [SMALL_STATE(14810)] = 624393,
  [SMALL_STATE(14811)] = 624413,
  [SMALL_STATE(14812)] = 624433,
  [SMALL_STATE(14813)] = 624453,
  [SMALL_STATE(14814)] = 624473,
  [SMALL_STATE(14815)] = 624493,
  [SMALL_STATE(14816)] = 624513,
  [SMALL_STATE(14817)] = 624533,
  [SMALL_STATE(14818)] = 624553,
  [SMALL_STATE(14819)] = 624573,
  [SMALL_STATE(14820)] = 624593,
  [SMALL_STATE(14821)] = 624613,
  [SMALL_STATE(14822)] = 624633,
  [SMALL_STATE(14823)] = 624653,
  [SMALL_STATE(14824)] = 624673,
  [SMALL_STATE(14825)] = 624693,
  [SMALL_STATE(14826)] = 624713,
  [SMALL_STATE(14827)] = 624733,
  [SMALL_STATE(14828)] = 624753,
  [SMALL_STATE(14829)] = 624773,
  [SMALL_STATE(14830)] = 624791,
  [SMALL_STATE(14831)] = 624811,
  [SMALL_STATE(14832)] = 624831,
  [SMALL_STATE(14833)] = 624851,
  [SMALL_STATE(14834)] = 624871,
  [SMALL_STATE(14835)] = 624891,
  [SMALL_STATE(14836)] = 624911,
  [SMALL_STATE(14837)] = 624931,
  [SMALL_STATE(14838)] = 624947,
  [SMALL_STATE(14839)] = 624967,
  [SMALL_STATE(14840)] = 624987,
  [SMALL_STATE(14841)] = 625007,
  [SMALL_STATE(14842)] = 625027,
  [SMALL_STATE(14843)] = 625047,
  [SMALL_STATE(14844)] = 625067,
  [SMALL_STATE(14845)] = 625087,
  [SMALL_STATE(14846)] = 625107,
  [SMALL_STATE(14847)] = 625127,
  [SMALL_STATE(14848)] = 625147,
  [SMALL_STATE(14849)] = 625165,
  [SMALL_STATE(14850)] = 625185,
  [SMALL_STATE(14851)] = 625205,
  [SMALL_STATE(14852)] = 625223,
  [SMALL_STATE(14853)] = 625243,
  [SMALL_STATE(14854)] = 625263,
  [SMALL_STATE(14855)] = 625283,
  [SMALL_STATE(14856)] = 625303,
  [SMALL_STATE(14857)] = 625323,
  [SMALL_STATE(14858)] = 625343,
  [SMALL_STATE(14859)] = 625363,
  [SMALL_STATE(14860)] = 625383,
  [SMALL_STATE(14861)] = 625403,
  [SMALL_STATE(14862)] = 625421,
  [SMALL_STATE(14863)] = 625441,
  [SMALL_STATE(14864)] = 625461,
  [SMALL_STATE(14865)] = 625481,
  [SMALL_STATE(14866)] = 625499,
  [SMALL_STATE(14867)] = 625519,
  [SMALL_STATE(14868)] = 625539,
  [SMALL_STATE(14869)] = 625559,
  [SMALL_STATE(14870)] = 625579,
  [SMALL_STATE(14871)] = 625597,
  [SMALL_STATE(14872)] = 625617,
  [SMALL_STATE(14873)] = 625637,
  [SMALL_STATE(14874)] = 625657,
  [SMALL_STATE(14875)] = 625677,
  [SMALL_STATE(14876)] = 625697,
  [SMALL_STATE(14877)] = 625717,
  [SMALL_STATE(14878)] = 625737,
  [SMALL_STATE(14879)] = 625757,
  [SMALL_STATE(14880)] = 625777,
  [SMALL_STATE(14881)] = 625793,
  [SMALL_STATE(14882)] = 625813,
  [SMALL_STATE(14883)] = 625833,
  [SMALL_STATE(14884)] = 625853,
  [SMALL_STATE(14885)] = 625873,
  [SMALL_STATE(14886)] = 625893,
  [SMALL_STATE(14887)] = 625913,
  [SMALL_STATE(14888)] = 625931,
  [SMALL_STATE(14889)] = 625951,
  [SMALL_STATE(14890)] = 625971,
  [SMALL_STATE(14891)] = 625991,
  [SMALL_STATE(14892)] = 626011,
  [SMALL_STATE(14893)] = 626031,
  [SMALL_STATE(14894)] = 626051,
  [SMALL_STATE(14895)] = 626071,
  [SMALL_STATE(14896)] = 626091,
  [SMALL_STATE(14897)] = 626111,
  [SMALL_STATE(14898)] = 626131,
  [SMALL_STATE(14899)] = 626151,
  [SMALL_STATE(14900)] = 626171,
  [SMALL_STATE(14901)] = 626191,
  [SMALL_STATE(14902)] = 626211,
  [SMALL_STATE(14903)] = 626231,
  [SMALL_STATE(14904)] = 626251,
  [SMALL_STATE(14905)] = 626271,
  [SMALL_STATE(14906)] = 626291,
  [SMALL_STATE(14907)] = 626311,
  [SMALL_STATE(14908)] = 626331,
  [SMALL_STATE(14909)] = 626351,
  [SMALL_STATE(14910)] = 626371,
  [SMALL_STATE(14911)] = 626391,
  [SMALL_STATE(14912)] = 626411,
  [SMALL_STATE(14913)] = 626431,
  [SMALL_STATE(14914)] = 626451,
  [SMALL_STATE(14915)] = 626471,
  [SMALL_STATE(14916)] = 626489,
  [SMALL_STATE(14917)] = 626509,
  [SMALL_STATE(14918)] = 626529,
  [SMALL_STATE(14919)] = 626549,
  [SMALL_STATE(14920)] = 626569,
  [SMALL_STATE(14921)] = 626589,
  [SMALL_STATE(14922)] = 626609,
  [SMALL_STATE(14923)] = 626629,
  [SMALL_STATE(14924)] = 626649,
  [SMALL_STATE(14925)] = 626669,
  [SMALL_STATE(14926)] = 626689,
  [SMALL_STATE(14927)] = 626709,
  [SMALL_STATE(14928)] = 626729,
  [SMALL_STATE(14929)] = 626749,
  [SMALL_STATE(14930)] = 626769,
  [SMALL_STATE(14931)] = 626789,
  [SMALL_STATE(14932)] = 626809,
  [SMALL_STATE(14933)] = 626829,
  [SMALL_STATE(14934)] = 626849,
  [SMALL_STATE(14935)] = 626869,
  [SMALL_STATE(14936)] = 626889,
  [SMALL_STATE(14937)] = 626909,
  [SMALL_STATE(14938)] = 626929,
  [SMALL_STATE(14939)] = 626949,
  [SMALL_STATE(14940)] = 626969,
  [SMALL_STATE(14941)] = 626989,
  [SMALL_STATE(14942)] = 627009,
  [SMALL_STATE(14943)] = 627029,
  [SMALL_STATE(14944)] = 627049,
  [SMALL_STATE(14945)] = 627069,
  [SMALL_STATE(14946)] = 627089,
  [SMALL_STATE(14947)] = 627109,
  [SMALL_STATE(14948)] = 627129,
  [SMALL_STATE(14949)] = 627149,
  [SMALL_STATE(14950)] = 627169,
  [SMALL_STATE(14951)] = 627189,
  [SMALL_STATE(14952)] = 627207,
  [SMALL_STATE(14953)] = 627227,
  [SMALL_STATE(14954)] = 627247,
  [SMALL_STATE(14955)] = 627267,
  [SMALL_STATE(14956)] = 627287,
  [SMALL_STATE(14957)] = 627307,
  [SMALL_STATE(14958)] = 627327,
  [SMALL_STATE(14959)] = 627347,
  [SMALL_STATE(14960)] = 627367,
  [SMALL_STATE(14961)] = 627387,
  [SMALL_STATE(14962)] = 627407,
  [SMALL_STATE(14963)] = 627427,
  [SMALL_STATE(14964)] = 627447,
  [SMALL_STATE(14965)] = 627467,
  [SMALL_STATE(14966)] = 627487,
  [SMALL_STATE(14967)] = 627507,
  [SMALL_STATE(14968)] = 627527,
  [SMALL_STATE(14969)] = 627547,
  [SMALL_STATE(14970)] = 627567,
  [SMALL_STATE(14971)] = 627587,
  [SMALL_STATE(14972)] = 627607,
  [SMALL_STATE(14973)] = 627627,
  [SMALL_STATE(14974)] = 627647,
  [SMALL_STATE(14975)] = 627667,
  [SMALL_STATE(14976)] = 627687,
  [SMALL_STATE(14977)] = 627707,
  [SMALL_STATE(14978)] = 627725,
  [SMALL_STATE(14979)] = 627745,
  [SMALL_STATE(14980)] = 627765,
  [SMALL_STATE(14981)] = 627785,
  [SMALL_STATE(14982)] = 627805,
  [SMALL_STATE(14983)] = 627825,
  [SMALL_STATE(14984)] = 627845,
  [SMALL_STATE(14985)] = 627865,
  [SMALL_STATE(14986)] = 627885,
  [SMALL_STATE(14987)] = 627905,
  [SMALL_STATE(14988)] = 627923,
  [SMALL_STATE(14989)] = 627943,
  [SMALL_STATE(14990)] = 627963,
  [SMALL_STATE(14991)] = 627983,
  [SMALL_STATE(14992)] = 628001,
  [SMALL_STATE(14993)] = 628021,
  [SMALL_STATE(14994)] = 628041,
  [SMALL_STATE(14995)] = 628061,
  [SMALL_STATE(14996)] = 628081,
  [SMALL_STATE(14997)] = 628101,
  [SMALL_STATE(14998)] = 628121,
  [SMALL_STATE(14999)] = 628141,
  [SMALL_STATE(15000)] = 628161,
  [SMALL_STATE(15001)] = 628181,
  [SMALL_STATE(15002)] = 628201,
  [SMALL_STATE(15003)] = 628221,
  [SMALL_STATE(15004)] = 628241,
  [SMALL_STATE(15005)] = 628261,
  [SMALL_STATE(15006)] = 628281,
  [SMALL_STATE(15007)] = 628301,
  [SMALL_STATE(15008)] = 628321,
  [SMALL_STATE(15009)] = 628341,
  [SMALL_STATE(15010)] = 628359,
  [SMALL_STATE(15011)] = 628379,
  [SMALL_STATE(15012)] = 628399,
  [SMALL_STATE(15013)] = 628417,
  [SMALL_STATE(15014)] = 628435,
  [SMALL_STATE(15015)] = 628455,
  [SMALL_STATE(15016)] = 628475,
  [SMALL_STATE(15017)] = 628493,
  [SMALL_STATE(15018)] = 628513,
  [SMALL_STATE(15019)] = 628531,
  [SMALL_STATE(15020)] = 628549,
  [SMALL_STATE(15021)] = 628567,
  [SMALL_STATE(15022)] = 628585,
  [SMALL_STATE(15023)] = 628603,
  [SMALL_STATE(15024)] = 628621,
  [SMALL_STATE(15025)] = 628639,
  [SMALL_STATE(15026)] = 628657,
  [SMALL_STATE(15027)] = 628675,
  [SMALL_STATE(15028)] = 628693,
  [SMALL_STATE(15029)] = 628711,
  [SMALL_STATE(15030)] = 628729,
  [SMALL_STATE(15031)] = 628747,
  [SMALL_STATE(15032)] = 628765,
  [SMALL_STATE(15033)] = 628783,
  [SMALL_STATE(15034)] = 628801,
  [SMALL_STATE(15035)] = 628819,
  [SMALL_STATE(15036)] = 628839,
  [SMALL_STATE(15037)] = 628859,
  [SMALL_STATE(15038)] = 628879,
  [SMALL_STATE(15039)] = 628899,
  [SMALL_STATE(15040)] = 628919,
  [SMALL_STATE(15041)] = 628939,
  [SMALL_STATE(15042)] = 628959,
  [SMALL_STATE(15043)] = 628979,
  [SMALL_STATE(15044)] = 628999,
  [SMALL_STATE(15045)] = 629019,
  [SMALL_STATE(15046)] = 629039,
  [SMALL_STATE(15047)] = 629059,
  [SMALL_STATE(15048)] = 629077,
  [SMALL_STATE(15049)] = 629093,
  [SMALL_STATE(15050)] = 629113,
  [SMALL_STATE(15051)] = 629133,
  [SMALL_STATE(15052)] = 629153,
  [SMALL_STATE(15053)] = 629173,
  [SMALL_STATE(15054)] = 629193,
  [SMALL_STATE(15055)] = 629213,
  [SMALL_STATE(15056)] = 629233,
  [SMALL_STATE(15057)] = 629253,
  [SMALL_STATE(15058)] = 629271,
  [SMALL_STATE(15059)] = 629289,
  [SMALL_STATE(15060)] = 629307,
  [SMALL_STATE(15061)] = 629325,
  [SMALL_STATE(15062)] = 629343,
  [SMALL_STATE(15063)] = 629361,
  [SMALL_STATE(15064)] = 629379,
  [SMALL_STATE(15065)] = 629397,
  [SMALL_STATE(15066)] = 629417,
  [SMALL_STATE(15067)] = 629433,
  [SMALL_STATE(15068)] = 629453,
  [SMALL_STATE(15069)] = 629473,
  [SMALL_STATE(15070)] = 629493,
  [SMALL_STATE(15071)] = 629513,
  [SMALL_STATE(15072)] = 629533,
  [SMALL_STATE(15073)] = 629553,
  [SMALL_STATE(15074)] = 629573,
  [SMALL_STATE(15075)] = 629593,
  [SMALL_STATE(15076)] = 629613,
  [SMALL_STATE(15077)] = 629633,
  [SMALL_STATE(15078)] = 629653,
  [SMALL_STATE(15079)] = 629673,
  [SMALL_STATE(15080)] = 629693,
  [SMALL_STATE(15081)] = 629713,
  [SMALL_STATE(15082)] = 629733,
  [SMALL_STATE(15083)] = 629753,
  [SMALL_STATE(15084)] = 629771,
  [SMALL_STATE(15085)] = 629789,
  [SMALL_STATE(15086)] = 629807,
  [SMALL_STATE(15087)] = 629825,
  [SMALL_STATE(15088)] = 629843,
  [SMALL_STATE(15089)] = 629861,
  [SMALL_STATE(15090)] = 629879,
  [SMALL_STATE(15091)] = 629897,
  [SMALL_STATE(15092)] = 629915,
  [SMALL_STATE(15093)] = 629935,
  [SMALL_STATE(15094)] = 629955,
  [SMALL_STATE(15095)] = 629975,
  [SMALL_STATE(15096)] = 629993,
  [SMALL_STATE(15097)] = 630013,
  [SMALL_STATE(15098)] = 630033,
  [SMALL_STATE(15099)] = 630053,
  [SMALL_STATE(15100)] = 630073,
  [SMALL_STATE(15101)] = 630093,
  [SMALL_STATE(15102)] = 630113,
  [SMALL_STATE(15103)] = 630133,
  [SMALL_STATE(15104)] = 630153,
  [SMALL_STATE(15105)] = 630171,
  [SMALL_STATE(15106)] = 630191,
  [SMALL_STATE(15107)] = 630211,
  [SMALL_STATE(15108)] = 630229,
  [SMALL_STATE(15109)] = 630247,
  [SMALL_STATE(15110)] = 630265,
  [SMALL_STATE(15111)] = 630285,
  [SMALL_STATE(15112)] = 630305,
  [SMALL_STATE(15113)] = 630325,
  [SMALL_STATE(15114)] = 630341,
  [SMALL_STATE(15115)] = 630361,
  [SMALL_STATE(15116)] = 630381,
  [SMALL_STATE(15117)] = 630401,
  [SMALL_STATE(15118)] = 630419,
  [SMALL_STATE(15119)] = 630437,
  [SMALL_STATE(15120)] = 630457,
  [SMALL_STATE(15121)] = 630477,
  [SMALL_STATE(15122)] = 630497,
  [SMALL_STATE(15123)] = 630517,
  [SMALL_STATE(15124)] = 630535,
  [SMALL_STATE(15125)] = 630555,
  [SMALL_STATE(15126)] = 630575,
  [SMALL_STATE(15127)] = 630595,
  [SMALL_STATE(15128)] = 630615,
  [SMALL_STATE(15129)] = 630635,
  [SMALL_STATE(15130)] = 630655,
  [SMALL_STATE(15131)] = 630675,
  [SMALL_STATE(15132)] = 630695,
  [SMALL_STATE(15133)] = 630715,
  [SMALL_STATE(15134)] = 630733,
  [SMALL_STATE(15135)] = 630753,
  [SMALL_STATE(15136)] = 630773,
  [SMALL_STATE(15137)] = 630791,
  [SMALL_STATE(15138)] = 630811,
  [SMALL_STATE(15139)] = 630831,
  [SMALL_STATE(15140)] = 630849,
  [SMALL_STATE(15141)] = 630867,
  [SMALL_STATE(15142)] = 630887,
  [SMALL_STATE(15143)] = 630907,
  [SMALL_STATE(15144)] = 630927,
  [SMALL_STATE(15145)] = 630947,
  [SMALL_STATE(15146)] = 630967,
  [SMALL_STATE(15147)] = 630987,
  [SMALL_STATE(15148)] = 631007,
  [SMALL_STATE(15149)] = 631027,
  [SMALL_STATE(15150)] = 631047,
  [SMALL_STATE(15151)] = 631067,
  [SMALL_STATE(15152)] = 631087,
  [SMALL_STATE(15153)] = 631107,
  [SMALL_STATE(15154)] = 631127,
  [SMALL_STATE(15155)] = 631147,
  [SMALL_STATE(15156)] = 631167,
  [SMALL_STATE(15157)] = 631187,
  [SMALL_STATE(15158)] = 631207,
  [SMALL_STATE(15159)] = 631227,
  [SMALL_STATE(15160)] = 631247,
  [SMALL_STATE(15161)] = 631265,
  [SMALL_STATE(15162)] = 631285,
  [SMALL_STATE(15163)] = 631305,
  [SMALL_STATE(15164)] = 631325,
  [SMALL_STATE(15165)] = 631343,
  [SMALL_STATE(15166)] = 631363,
  [SMALL_STATE(15167)] = 631383,
  [SMALL_STATE(15168)] = 631399,
  [SMALL_STATE(15169)] = 631419,
  [SMALL_STATE(15170)] = 631439,
  [SMALL_STATE(15171)] = 631459,
  [SMALL_STATE(15172)] = 631479,
  [SMALL_STATE(15173)] = 631499,
  [SMALL_STATE(15174)] = 631519,
  [SMALL_STATE(15175)] = 631539,
  [SMALL_STATE(15176)] = 631559,
  [SMALL_STATE(15177)] = 631579,
  [SMALL_STATE(15178)] = 631599,
  [SMALL_STATE(15179)] = 631617,
  [SMALL_STATE(15180)] = 631637,
  [SMALL_STATE(15181)] = 631657,
  [SMALL_STATE(15182)] = 631673,
  [SMALL_STATE(15183)] = 631693,
  [SMALL_STATE(15184)] = 631713,
  [SMALL_STATE(15185)] = 631733,
  [SMALL_STATE(15186)] = 631753,
  [SMALL_STATE(15187)] = 631773,
  [SMALL_STATE(15188)] = 631793,
  [SMALL_STATE(15189)] = 631813,
  [SMALL_STATE(15190)] = 631833,
  [SMALL_STATE(15191)] = 631853,
  [SMALL_STATE(15192)] = 631873,
  [SMALL_STATE(15193)] = 631893,
  [SMALL_STATE(15194)] = 631913,
  [SMALL_STATE(15195)] = 631933,
  [SMALL_STATE(15196)] = 631953,
  [SMALL_STATE(15197)] = 631971,
  [SMALL_STATE(15198)] = 631991,
  [SMALL_STATE(15199)] = 632011,
  [SMALL_STATE(15200)] = 632031,
  [SMALL_STATE(15201)] = 632051,
  [SMALL_STATE(15202)] = 632071,
  [SMALL_STATE(15203)] = 632091,
  [SMALL_STATE(15204)] = 632111,
  [SMALL_STATE(15205)] = 632131,
  [SMALL_STATE(15206)] = 632151,
  [SMALL_STATE(15207)] = 632171,
  [SMALL_STATE(15208)] = 632191,
  [SMALL_STATE(15209)] = 632211,
  [SMALL_STATE(15210)] = 632231,
  [SMALL_STATE(15211)] = 632251,
  [SMALL_STATE(15212)] = 632271,
  [SMALL_STATE(15213)] = 632291,
  [SMALL_STATE(15214)] = 632311,
  [SMALL_STATE(15215)] = 632331,
  [SMALL_STATE(15216)] = 632351,
  [SMALL_STATE(15217)] = 632371,
  [SMALL_STATE(15218)] = 632391,
  [SMALL_STATE(15219)] = 632411,
  [SMALL_STATE(15220)] = 632429,
  [SMALL_STATE(15221)] = 632449,
  [SMALL_STATE(15222)] = 632469,
  [SMALL_STATE(15223)] = 632489,
  [SMALL_STATE(15224)] = 632509,
  [SMALL_STATE(15225)] = 632529,
  [SMALL_STATE(15226)] = 632549,
  [SMALL_STATE(15227)] = 632569,
  [SMALL_STATE(15228)] = 632589,
  [SMALL_STATE(15229)] = 632609,
  [SMALL_STATE(15230)] = 632629,
  [SMALL_STATE(15231)] = 632649,
  [SMALL_STATE(15232)] = 632667,
  [SMALL_STATE(15233)] = 632687,
  [SMALL_STATE(15234)] = 632707,
  [SMALL_STATE(15235)] = 632727,
  [SMALL_STATE(15236)] = 632747,
  [SMALL_STATE(15237)] = 632763,
  [SMALL_STATE(15238)] = 632783,
  [SMALL_STATE(15239)] = 632803,
  [SMALL_STATE(15240)] = 632823,
  [SMALL_STATE(15241)] = 632841,
  [SMALL_STATE(15242)] = 632861,
  [SMALL_STATE(15243)] = 632881,
  [SMALL_STATE(15244)] = 632901,
  [SMALL_STATE(15245)] = 632921,
  [SMALL_STATE(15246)] = 632941,
  [SMALL_STATE(15247)] = 632961,
  [SMALL_STATE(15248)] = 632979,
  [SMALL_STATE(15249)] = 632999,
  [SMALL_STATE(15250)] = 633019,
  [SMALL_STATE(15251)] = 633039,
  [SMALL_STATE(15252)] = 633059,
  [SMALL_STATE(15253)] = 633079,
  [SMALL_STATE(15254)] = 633099,
  [SMALL_STATE(15255)] = 633119,
  [SMALL_STATE(15256)] = 633139,
  [SMALL_STATE(15257)] = 633157,
  [SMALL_STATE(15258)] = 633177,
  [SMALL_STATE(15259)] = 633197,
  [SMALL_STATE(15260)] = 633217,
  [SMALL_STATE(15261)] = 633237,
  [SMALL_STATE(15262)] = 633253,
  [SMALL_STATE(15263)] = 633273,
  [SMALL_STATE(15264)] = 633293,
  [SMALL_STATE(15265)] = 633313,
  [SMALL_STATE(15266)] = 633333,
  [SMALL_STATE(15267)] = 633353,
  [SMALL_STATE(15268)] = 633373,
  [SMALL_STATE(15269)] = 633393,
  [SMALL_STATE(15270)] = 633413,
  [SMALL_STATE(15271)] = 633433,
  [SMALL_STATE(15272)] = 633453,
  [SMALL_STATE(15273)] = 633473,
  [SMALL_STATE(15274)] = 633493,
  [SMALL_STATE(15275)] = 633513,
  [SMALL_STATE(15276)] = 633531,
  [SMALL_STATE(15277)] = 633551,
  [SMALL_STATE(15278)] = 633567,
  [SMALL_STATE(15279)] = 633587,
  [SMALL_STATE(15280)] = 633607,
  [SMALL_STATE(15281)] = 633627,
  [SMALL_STATE(15282)] = 633647,
  [SMALL_STATE(15283)] = 633667,
  [SMALL_STATE(15284)] = 633687,
  [SMALL_STATE(15285)] = 633707,
  [SMALL_STATE(15286)] = 633727,
  [SMALL_STATE(15287)] = 633747,
  [SMALL_STATE(15288)] = 633767,
  [SMALL_STATE(15289)] = 633787,
  [SMALL_STATE(15290)] = 633807,
  [SMALL_STATE(15291)] = 633827,
  [SMALL_STATE(15292)] = 633845,
  [SMALL_STATE(15293)] = 633865,
  [SMALL_STATE(15294)] = 633885,
  [SMALL_STATE(15295)] = 633905,
  [SMALL_STATE(15296)] = 633925,
  [SMALL_STATE(15297)] = 633945,
  [SMALL_STATE(15298)] = 633961,
  [SMALL_STATE(15299)] = 633981,
  [SMALL_STATE(15300)] = 633999,
  [SMALL_STATE(15301)] = 634017,
  [SMALL_STATE(15302)] = 634037,
  [SMALL_STATE(15303)] = 634057,
  [SMALL_STATE(15304)] = 634077,
  [SMALL_STATE(15305)] = 634097,
  [SMALL_STATE(15306)] = 634117,
  [SMALL_STATE(15307)] = 634137,
  [SMALL_STATE(15308)] = 634157,
  [SMALL_STATE(15309)] = 634173,
  [SMALL_STATE(15310)] = 634193,
  [SMALL_STATE(15311)] = 634213,
  [SMALL_STATE(15312)] = 634233,
  [SMALL_STATE(15313)] = 634249,
  [SMALL_STATE(15314)] = 634267,
  [SMALL_STATE(15315)] = 634287,
  [SMALL_STATE(15316)] = 634307,
  [SMALL_STATE(15317)] = 634327,
  [SMALL_STATE(15318)] = 634347,
  [SMALL_STATE(15319)] = 634367,
  [SMALL_STATE(15320)] = 634385,
  [SMALL_STATE(15321)] = 634405,
  [SMALL_STATE(15322)] = 634425,
  [SMALL_STATE(15323)] = 634445,
  [SMALL_STATE(15324)] = 634465,
  [SMALL_STATE(15325)] = 634485,
  [SMALL_STATE(15326)] = 634505,
  [SMALL_STATE(15327)] = 634525,
  [SMALL_STATE(15328)] = 634545,
  [SMALL_STATE(15329)] = 634565,
  [SMALL_STATE(15330)] = 634581,
  [SMALL_STATE(15331)] = 634601,
  [SMALL_STATE(15332)] = 634621,
  [SMALL_STATE(15333)] = 634641,
  [SMALL_STATE(15334)] = 634661,
  [SMALL_STATE(15335)] = 634681,
  [SMALL_STATE(15336)] = 634701,
  [SMALL_STATE(15337)] = 634721,
  [SMALL_STATE(15338)] = 634741,
  [SMALL_STATE(15339)] = 634761,
  [SMALL_STATE(15340)] = 634779,
  [SMALL_STATE(15341)] = 634799,
  [SMALL_STATE(15342)] = 634819,
  [SMALL_STATE(15343)] = 634839,
  [SMALL_STATE(15344)] = 634859,
  [SMALL_STATE(15345)] = 634879,
  [SMALL_STATE(15346)] = 634899,
  [SMALL_STATE(15347)] = 634919,
  [SMALL_STATE(15348)] = 634935,
  [SMALL_STATE(15349)] = 634955,
  [SMALL_STATE(15350)] = 634975,
  [SMALL_STATE(15351)] = 634995,
  [SMALL_STATE(15352)] = 635015,
  [SMALL_STATE(15353)] = 635035,
  [SMALL_STATE(15354)] = 635055,
  [SMALL_STATE(15355)] = 635075,
  [SMALL_STATE(15356)] = 635095,
  [SMALL_STATE(15357)] = 635115,
  [SMALL_STATE(15358)] = 635135,
  [SMALL_STATE(15359)] = 635155,
  [SMALL_STATE(15360)] = 635175,
  [SMALL_STATE(15361)] = 635195,
  [SMALL_STATE(15362)] = 635215,
  [SMALL_STATE(15363)] = 635231,
  [SMALL_STATE(15364)] = 635251,
  [SMALL_STATE(15365)] = 635271,
  [SMALL_STATE(15366)] = 635291,
  [SMALL_STATE(15367)] = 635311,
  [SMALL_STATE(15368)] = 635331,
  [SMALL_STATE(15369)] = 635351,
  [SMALL_STATE(15370)] = 635371,
  [SMALL_STATE(15371)] = 635391,
  [SMALL_STATE(15372)] = 635411,
  [SMALL_STATE(15373)] = 635431,
  [SMALL_STATE(15374)] = 635451,
  [SMALL_STATE(15375)] = 635471,
  [SMALL_STATE(15376)] = 635489,
  [SMALL_STATE(15377)] = 635509,
  [SMALL_STATE(15378)] = 635529,
  [SMALL_STATE(15379)] = 635549,
  [SMALL_STATE(15380)] = 635569,
  [SMALL_STATE(15381)] = 635589,
  [SMALL_STATE(15382)] = 635609,
  [SMALL_STATE(15383)] = 635629,
  [SMALL_STATE(15384)] = 635649,
  [SMALL_STATE(15385)] = 635669,
  [SMALL_STATE(15386)] = 635689,
  [SMALL_STATE(15387)] = 635709,
  [SMALL_STATE(15388)] = 635729,
  [SMALL_STATE(15389)] = 635749,
  [SMALL_STATE(15390)] = 635769,
  [SMALL_STATE(15391)] = 635787,
  [SMALL_STATE(15392)] = 635807,
  [SMALL_STATE(15393)] = 635825,
  [SMALL_STATE(15394)] = 635845,
  [SMALL_STATE(15395)] = 635865,
  [SMALL_STATE(15396)] = 635885,
  [SMALL_STATE(15397)] = 635905,
  [SMALL_STATE(15398)] = 635925,
  [SMALL_STATE(15399)] = 635941,
  [SMALL_STATE(15400)] = 635961,
  [SMALL_STATE(15401)] = 635981,
  [SMALL_STATE(15402)] = 636001,
  [SMALL_STATE(15403)] = 636021,
  [SMALL_STATE(15404)] = 636039,
  [SMALL_STATE(15405)] = 636059,
  [SMALL_STATE(15406)] = 636079,
  [SMALL_STATE(15407)] = 636099,
  [SMALL_STATE(15408)] = 636119,
  [SMALL_STATE(15409)] = 636139,
  [SMALL_STATE(15410)] = 636159,
  [SMALL_STATE(15411)] = 636179,
  [SMALL_STATE(15412)] = 636199,
  [SMALL_STATE(15413)] = 636219,
  [SMALL_STATE(15414)] = 636239,
  [SMALL_STATE(15415)] = 636259,
  [SMALL_STATE(15416)] = 636279,
  [SMALL_STATE(15417)] = 636299,
  [SMALL_STATE(15418)] = 636319,
  [SMALL_STATE(15419)] = 636339,
  [SMALL_STATE(15420)] = 636355,
  [SMALL_STATE(15421)] = 636375,
  [SMALL_STATE(15422)] = 636395,
  [SMALL_STATE(15423)] = 636415,
  [SMALL_STATE(15424)] = 636435,
  [SMALL_STATE(15425)] = 636455,
  [SMALL_STATE(15426)] = 636471,
  [SMALL_STATE(15427)] = 636491,
  [SMALL_STATE(15428)] = 636511,
  [SMALL_STATE(15429)] = 636529,
  [SMALL_STATE(15430)] = 636549,
  [SMALL_STATE(15431)] = 636569,
  [SMALL_STATE(15432)] = 636589,
  [SMALL_STATE(15433)] = 636609,
  [SMALL_STATE(15434)] = 636627,
  [SMALL_STATE(15435)] = 636645,
  [SMALL_STATE(15436)] = 636665,
  [SMALL_STATE(15437)] = 636685,
  [SMALL_STATE(15438)] = 636705,
  [SMALL_STATE(15439)] = 636725,
  [SMALL_STATE(15440)] = 636745,
  [SMALL_STATE(15441)] = 636765,
  [SMALL_STATE(15442)] = 636785,
  [SMALL_STATE(15443)] = 636805,
  [SMALL_STATE(15444)] = 636825,
  [SMALL_STATE(15445)] = 636845,
  [SMALL_STATE(15446)] = 636865,
  [SMALL_STATE(15447)] = 636885,
  [SMALL_STATE(15448)] = 636905,
  [SMALL_STATE(15449)] = 636925,
  [SMALL_STATE(15450)] = 636945,
  [SMALL_STATE(15451)] = 636961,
  [SMALL_STATE(15452)] = 636981,
  [SMALL_STATE(15453)] = 637001,
  [SMALL_STATE(15454)] = 637021,
  [SMALL_STATE(15455)] = 637041,
  [SMALL_STATE(15456)] = 637059,
  [SMALL_STATE(15457)] = 637079,
  [SMALL_STATE(15458)] = 637099,
  [SMALL_STATE(15459)] = 637119,
  [SMALL_STATE(15460)] = 637137,
  [SMALL_STATE(15461)] = 637157,
  [SMALL_STATE(15462)] = 637177,
  [SMALL_STATE(15463)] = 637197,
  [SMALL_STATE(15464)] = 637217,
  [SMALL_STATE(15465)] = 637237,
  [SMALL_STATE(15466)] = 637255,
  [SMALL_STATE(15467)] = 637275,
  [SMALL_STATE(15468)] = 637295,
  [SMALL_STATE(15469)] = 637315,
  [SMALL_STATE(15470)] = 637335,
  [SMALL_STATE(15471)] = 637355,
  [SMALL_STATE(15472)] = 637375,
  [SMALL_STATE(15473)] = 637395,
  [SMALL_STATE(15474)] = 637415,
  [SMALL_STATE(15475)] = 637431,
  [SMALL_STATE(15476)] = 637451,
  [SMALL_STATE(15477)] = 637471,
  [SMALL_STATE(15478)] = 637491,
  [SMALL_STATE(15479)] = 637511,
  [SMALL_STATE(15480)] = 637527,
  [SMALL_STATE(15481)] = 637547,
  [SMALL_STATE(15482)] = 637565,
  [SMALL_STATE(15483)] = 637585,
  [SMALL_STATE(15484)] = 637605,
  [SMALL_STATE(15485)] = 637625,
  [SMALL_STATE(15486)] = 637645,
  [SMALL_STATE(15487)] = 637661,
  [SMALL_STATE(15488)] = 637681,
  [SMALL_STATE(15489)] = 637701,
  [SMALL_STATE(15490)] = 637721,
  [SMALL_STATE(15491)] = 637741,
  [SMALL_STATE(15492)] = 637759,
  [SMALL_STATE(15493)] = 637779,
  [SMALL_STATE(15494)] = 637797,
  [SMALL_STATE(15495)] = 637817,
  [SMALL_STATE(15496)] = 637837,
  [SMALL_STATE(15497)] = 637855,
  [SMALL_STATE(15498)] = 637875,
  [SMALL_STATE(15499)] = 637891,
  [SMALL_STATE(15500)] = 637911,
  [SMALL_STATE(15501)] = 637931,
  [SMALL_STATE(15502)] = 637951,
  [SMALL_STATE(15503)] = 637971,
  [SMALL_STATE(15504)] = 637991,
  [SMALL_STATE(15505)] = 638011,
  [SMALL_STATE(15506)] = 638031,
  [SMALL_STATE(15507)] = 638051,
  [SMALL_STATE(15508)] = 638071,
  [SMALL_STATE(15509)] = 638091,
  [SMALL_STATE(15510)] = 638111,
  [SMALL_STATE(15511)] = 638129,
  [SMALL_STATE(15512)] = 638147,
  [SMALL_STATE(15513)] = 638167,
  [SMALL_STATE(15514)] = 638187,
  [SMALL_STATE(15515)] = 638207,
  [SMALL_STATE(15516)] = 638225,
  [SMALL_STATE(15517)] = 638245,
  [SMALL_STATE(15518)] = 638265,
  [SMALL_STATE(15519)] = 638285,
  [SMALL_STATE(15520)] = 638305,
  [SMALL_STATE(15521)] = 638325,
  [SMALL_STATE(15522)] = 638345,
  [SMALL_STATE(15523)] = 638365,
  [SMALL_STATE(15524)] = 638385,
  [SMALL_STATE(15525)] = 638405,
  [SMALL_STATE(15526)] = 638425,
  [SMALL_STATE(15527)] = 638445,
  [SMALL_STATE(15528)] = 638465,
  [SMALL_STATE(15529)] = 638485,
  [SMALL_STATE(15530)] = 638505,
  [SMALL_STATE(15531)] = 638525,
  [SMALL_STATE(15532)] = 638545,
  [SMALL_STATE(15533)] = 638565,
  [SMALL_STATE(15534)] = 638585,
  [SMALL_STATE(15535)] = 638603,
  [SMALL_STATE(15536)] = 638623,
  [SMALL_STATE(15537)] = 638643,
  [SMALL_STATE(15538)] = 638663,
  [SMALL_STATE(15539)] = 638683,
  [SMALL_STATE(15540)] = 638703,
  [SMALL_STATE(15541)] = 638723,
  [SMALL_STATE(15542)] = 638743,
  [SMALL_STATE(15543)] = 638763,
  [SMALL_STATE(15544)] = 638783,
  [SMALL_STATE(15545)] = 638801,
  [SMALL_STATE(15546)] = 638821,
  [SMALL_STATE(15547)] = 638841,
  [SMALL_STATE(15548)] = 638861,
  [SMALL_STATE(15549)] = 638881,
  [SMALL_STATE(15550)] = 638901,
  [SMALL_STATE(15551)] = 638921,
  [SMALL_STATE(15552)] = 638941,
  [SMALL_STATE(15553)] = 638961,
  [SMALL_STATE(15554)] = 638981,
  [SMALL_STATE(15555)] = 639001,
  [SMALL_STATE(15556)] = 639021,
  [SMALL_STATE(15557)] = 639041,
  [SMALL_STATE(15558)] = 639061,
  [SMALL_STATE(15559)] = 639081,
  [SMALL_STATE(15560)] = 639101,
  [SMALL_STATE(15561)] = 639121,
  [SMALL_STATE(15562)] = 639141,
  [SMALL_STATE(15563)] = 639161,
  [SMALL_STATE(15564)] = 639181,
  [SMALL_STATE(15565)] = 639199,
  [SMALL_STATE(15566)] = 639219,
  [SMALL_STATE(15567)] = 639239,
  [SMALL_STATE(15568)] = 639259,
  [SMALL_STATE(15569)] = 639279,
  [SMALL_STATE(15570)] = 639299,
  [SMALL_STATE(15571)] = 639317,
  [SMALL_STATE(15572)] = 639337,
  [SMALL_STATE(15573)] = 639357,
  [SMALL_STATE(15574)] = 639377,
  [SMALL_STATE(15575)] = 639395,
  [SMALL_STATE(15576)] = 639415,
  [SMALL_STATE(15577)] = 639435,
  [SMALL_STATE(15578)] = 639455,
  [SMALL_STATE(15579)] = 639475,
  [SMALL_STATE(15580)] = 639495,
  [SMALL_STATE(15581)] = 639513,
  [SMALL_STATE(15582)] = 639533,
  [SMALL_STATE(15583)] = 639551,
  [SMALL_STATE(15584)] = 639571,
  [SMALL_STATE(15585)] = 639591,
  [SMALL_STATE(15586)] = 639609,
  [SMALL_STATE(15587)] = 639629,
  [SMALL_STATE(15588)] = 639649,
  [SMALL_STATE(15589)] = 639667,
  [SMALL_STATE(15590)] = 639687,
  [SMALL_STATE(15591)] = 639705,
  [SMALL_STATE(15592)] = 639725,
  [SMALL_STATE(15593)] = 639743,
  [SMALL_STATE(15594)] = 639763,
  [SMALL_STATE(15595)] = 639783,
  [SMALL_STATE(15596)] = 639803,
  [SMALL_STATE(15597)] = 639823,
  [SMALL_STATE(15598)] = 639843,
  [SMALL_STATE(15599)] = 639863,
  [SMALL_STATE(15600)] = 639883,
  [SMALL_STATE(15601)] = 639903,
  [SMALL_STATE(15602)] = 639923,
  [SMALL_STATE(15603)] = 639943,
  [SMALL_STATE(15604)] = 639963,
  [SMALL_STATE(15605)] = 639979,
  [SMALL_STATE(15606)] = 639999,
  [SMALL_STATE(15607)] = 640017,
  [SMALL_STATE(15608)] = 640037,
  [SMALL_STATE(15609)] = 640057,
  [SMALL_STATE(15610)] = 640077,
  [SMALL_STATE(15611)] = 640095,
  [SMALL_STATE(15612)] = 640115,
  [SMALL_STATE(15613)] = 640135,
  [SMALL_STATE(15614)] = 640155,
  [SMALL_STATE(15615)] = 640175,
  [SMALL_STATE(15616)] = 640193,
  [SMALL_STATE(15617)] = 640213,
  [SMALL_STATE(15618)] = 640233,
  [SMALL_STATE(15619)] = 640253,
  [SMALL_STATE(15620)] = 640273,
  [SMALL_STATE(15621)] = 640293,
  [SMALL_STATE(15622)] = 640313,
  [SMALL_STATE(15623)] = 640331,
  [SMALL_STATE(15624)] = 640351,
  [SMALL_STATE(15625)] = 640371,
  [SMALL_STATE(15626)] = 640391,
  [SMALL_STATE(15627)] = 640411,
  [SMALL_STATE(15628)] = 640431,
  [SMALL_STATE(15629)] = 640451,
  [SMALL_STATE(15630)] = 640471,
  [SMALL_STATE(15631)] = 640491,
  [SMALL_STATE(15632)] = 640509,
  [SMALL_STATE(15633)] = 640529,
  [SMALL_STATE(15634)] = 640549,
  [SMALL_STATE(15635)] = 640569,
  [SMALL_STATE(15636)] = 640589,
  [SMALL_STATE(15637)] = 640609,
  [SMALL_STATE(15638)] = 640629,
  [SMALL_STATE(15639)] = 640649,
  [SMALL_STATE(15640)] = 640669,
  [SMALL_STATE(15641)] = 640689,
  [SMALL_STATE(15642)] = 640709,
  [SMALL_STATE(15643)] = 640727,
  [SMALL_STATE(15644)] = 640745,
  [SMALL_STATE(15645)] = 640765,
  [SMALL_STATE(15646)] = 640785,
  [SMALL_STATE(15647)] = 640805,
  [SMALL_STATE(15648)] = 640825,
  [SMALL_STATE(15649)] = 640845,
  [SMALL_STATE(15650)] = 640865,
  [SMALL_STATE(15651)] = 640885,
  [SMALL_STATE(15652)] = 640905,
  [SMALL_STATE(15653)] = 640925,
  [SMALL_STATE(15654)] = 640945,
  [SMALL_STATE(15655)] = 640965,
  [SMALL_STATE(15656)] = 640985,
  [SMALL_STATE(15657)] = 641005,
  [SMALL_STATE(15658)] = 641025,
  [SMALL_STATE(15659)] = 641045,
  [SMALL_STATE(15660)] = 641065,
  [SMALL_STATE(15661)] = 641085,
  [SMALL_STATE(15662)] = 641105,
  [SMALL_STATE(15663)] = 641125,
  [SMALL_STATE(15664)] = 641145,
  [SMALL_STATE(15665)] = 641165,
  [SMALL_STATE(15666)] = 641185,
  [SMALL_STATE(15667)] = 641205,
  [SMALL_STATE(15668)] = 641225,
  [SMALL_STATE(15669)] = 641245,
  [SMALL_STATE(15670)] = 641265,
  [SMALL_STATE(15671)] = 641285,
  [SMALL_STATE(15672)] = 641305,
  [SMALL_STATE(15673)] = 641325,
  [SMALL_STATE(15674)] = 641345,
  [SMALL_STATE(15675)] = 641365,
  [SMALL_STATE(15676)] = 641385,
  [SMALL_STATE(15677)] = 641405,
  [SMALL_STATE(15678)] = 641425,
  [SMALL_STATE(15679)] = 641445,
  [SMALL_STATE(15680)] = 641465,
  [SMALL_STATE(15681)] = 641485,
  [SMALL_STATE(15682)] = 641505,
  [SMALL_STATE(15683)] = 641525,
  [SMALL_STATE(15684)] = 641545,
  [SMALL_STATE(15685)] = 641565,
  [SMALL_STATE(15686)] = 641585,
  [SMALL_STATE(15687)] = 641605,
  [SMALL_STATE(15688)] = 641625,
  [SMALL_STATE(15689)] = 641645,
  [SMALL_STATE(15690)] = 641665,
  [SMALL_STATE(15691)] = 641685,
  [SMALL_STATE(15692)] = 641705,
  [SMALL_STATE(15693)] = 641725,
  [SMALL_STATE(15694)] = 641745,
  [SMALL_STATE(15695)] = 641765,
  [SMALL_STATE(15696)] = 641785,
  [SMALL_STATE(15697)] = 641805,
  [SMALL_STATE(15698)] = 641825,
  [SMALL_STATE(15699)] = 641845,
  [SMALL_STATE(15700)] = 641865,
  [SMALL_STATE(15701)] = 641885,
  [SMALL_STATE(15702)] = 641905,
  [SMALL_STATE(15703)] = 641925,
  [SMALL_STATE(15704)] = 641945,
  [SMALL_STATE(15705)] = 641965,
  [SMALL_STATE(15706)] = 641985,
  [SMALL_STATE(15707)] = 642005,
  [SMALL_STATE(15708)] = 642025,
  [SMALL_STATE(15709)] = 642045,
  [SMALL_STATE(15710)] = 642065,
  [SMALL_STATE(15711)] = 642085,
  [SMALL_STATE(15712)] = 642105,
  [SMALL_STATE(15713)] = 642125,
  [SMALL_STATE(15714)] = 642145,
  [SMALL_STATE(15715)] = 642165,
  [SMALL_STATE(15716)] = 642185,
  [SMALL_STATE(15717)] = 642205,
  [SMALL_STATE(15718)] = 642225,
  [SMALL_STATE(15719)] = 642243,
  [SMALL_STATE(15720)] = 642263,
  [SMALL_STATE(15721)] = 642283,
  [SMALL_STATE(15722)] = 642303,
  [SMALL_STATE(15723)] = 642323,
  [SMALL_STATE(15724)] = 642343,
  [SMALL_STATE(15725)] = 642363,
  [SMALL_STATE(15726)] = 642383,
  [SMALL_STATE(15727)] = 642403,
  [SMALL_STATE(15728)] = 642423,
  [SMALL_STATE(15729)] = 642443,
  [SMALL_STATE(15730)] = 642463,
  [SMALL_STATE(15731)] = 642483,
  [SMALL_STATE(15732)] = 642503,
  [SMALL_STATE(15733)] = 642523,
  [SMALL_STATE(15734)] = 642543,
  [SMALL_STATE(15735)] = 642563,
  [SMALL_STATE(15736)] = 642583,
  [SMALL_STATE(15737)] = 642603,
  [SMALL_STATE(15738)] = 642623,
  [SMALL_STATE(15739)] = 642643,
  [SMALL_STATE(15740)] = 642663,
  [SMALL_STATE(15741)] = 642683,
  [SMALL_STATE(15742)] = 642703,
  [SMALL_STATE(15743)] = 642723,
  [SMALL_STATE(15744)] = 642743,
  [SMALL_STATE(15745)] = 642763,
  [SMALL_STATE(15746)] = 642783,
  [SMALL_STATE(15747)] = 642803,
  [SMALL_STATE(15748)] = 642823,
  [SMALL_STATE(15749)] = 642843,
  [SMALL_STATE(15750)] = 642863,
  [SMALL_STATE(15751)] = 642883,
  [SMALL_STATE(15752)] = 642903,
  [SMALL_STATE(15753)] = 642923,
  [SMALL_STATE(15754)] = 642943,
  [SMALL_STATE(15755)] = 642963,
  [SMALL_STATE(15756)] = 642983,
  [SMALL_STATE(15757)] = 643003,
  [SMALL_STATE(15758)] = 643023,
  [SMALL_STATE(15759)] = 643043,
  [SMALL_STATE(15760)] = 643063,
  [SMALL_STATE(15761)] = 643083,
  [SMALL_STATE(15762)] = 643103,
  [SMALL_STATE(15763)] = 643123,
  [SMALL_STATE(15764)] = 643143,
  [SMALL_STATE(15765)] = 643163,
  [SMALL_STATE(15766)] = 643183,
  [SMALL_STATE(15767)] = 643203,
  [SMALL_STATE(15768)] = 643223,
  [SMALL_STATE(15769)] = 643243,
  [SMALL_STATE(15770)] = 643263,
  [SMALL_STATE(15771)] = 643283,
  [SMALL_STATE(15772)] = 643303,
  [SMALL_STATE(15773)] = 643323,
  [SMALL_STATE(15774)] = 643343,
  [SMALL_STATE(15775)] = 643363,
  [SMALL_STATE(15776)] = 643383,
  [SMALL_STATE(15777)] = 643403,
  [SMALL_STATE(15778)] = 643419,
  [SMALL_STATE(15779)] = 643439,
  [SMALL_STATE(15780)] = 643459,
  [SMALL_STATE(15781)] = 643479,
  [SMALL_STATE(15782)] = 643499,
  [SMALL_STATE(15783)] = 643519,
  [SMALL_STATE(15784)] = 643539,
  [SMALL_STATE(15785)] = 643559,
  [SMALL_STATE(15786)] = 643579,
  [SMALL_STATE(15787)] = 643599,
  [SMALL_STATE(15788)] = 643619,
  [SMALL_STATE(15789)] = 643639,
  [SMALL_STATE(15790)] = 643657,
  [SMALL_STATE(15791)] = 643677,
  [SMALL_STATE(15792)] = 643697,
  [SMALL_STATE(15793)] = 643717,
  [SMALL_STATE(15794)] = 643737,
  [SMALL_STATE(15795)] = 643757,
  [SMALL_STATE(15796)] = 643775,
  [SMALL_STATE(15797)] = 643795,
  [SMALL_STATE(15798)] = 643815,
  [SMALL_STATE(15799)] = 643835,
  [SMALL_STATE(15800)] = 643855,
  [SMALL_STATE(15801)] = 643875,
  [SMALL_STATE(15802)] = 643895,
  [SMALL_STATE(15803)] = 643915,
  [SMALL_STATE(15804)] = 643935,
  [SMALL_STATE(15805)] = 643955,
  [SMALL_STATE(15806)] = 643975,
  [SMALL_STATE(15807)] = 643995,
  [SMALL_STATE(15808)] = 644015,
  [SMALL_STATE(15809)] = 644035,
  [SMALL_STATE(15810)] = 644055,
  [SMALL_STATE(15811)] = 644075,
  [SMALL_STATE(15812)] = 644095,
  [SMALL_STATE(15813)] = 644115,
  [SMALL_STATE(15814)] = 644135,
  [SMALL_STATE(15815)] = 644155,
  [SMALL_STATE(15816)] = 644175,
  [SMALL_STATE(15817)] = 644195,
  [SMALL_STATE(15818)] = 644215,
  [SMALL_STATE(15819)] = 644235,
  [SMALL_STATE(15820)] = 644255,
  [SMALL_STATE(15821)] = 644275,
  [SMALL_STATE(15822)] = 644295,
  [SMALL_STATE(15823)] = 644315,
  [SMALL_STATE(15824)] = 644335,
  [SMALL_STATE(15825)] = 644355,
  [SMALL_STATE(15826)] = 644375,
  [SMALL_STATE(15827)] = 644395,
  [SMALL_STATE(15828)] = 644415,
  [SMALL_STATE(15829)] = 644435,
  [SMALL_STATE(15830)] = 644455,
  [SMALL_STATE(15831)] = 644475,
  [SMALL_STATE(15832)] = 644495,
  [SMALL_STATE(15833)] = 644515,
  [SMALL_STATE(15834)] = 644535,
  [SMALL_STATE(15835)] = 644555,
  [SMALL_STATE(15836)] = 644575,
  [SMALL_STATE(15837)] = 644595,
  [SMALL_STATE(15838)] = 644613,
  [SMALL_STATE(15839)] = 644633,
  [SMALL_STATE(15840)] = 644653,
  [SMALL_STATE(15841)] = 644673,
  [SMALL_STATE(15842)] = 644693,
  [SMALL_STATE(15843)] = 644713,
  [SMALL_STATE(15844)] = 644731,
  [SMALL_STATE(15845)] = 644751,
  [SMALL_STATE(15846)] = 644771,
  [SMALL_STATE(15847)] = 644791,
  [SMALL_STATE(15848)] = 644811,
  [SMALL_STATE(15849)] = 644831,
  [SMALL_STATE(15850)] = 644849,
  [SMALL_STATE(15851)] = 644864,
  [SMALL_STATE(15852)] = 644879,
  [SMALL_STATE(15853)] = 644894,
  [SMALL_STATE(15854)] = 644909,
  [SMALL_STATE(15855)] = 644924,
  [SMALL_STATE(15856)] = 644939,
  [SMALL_STATE(15857)] = 644954,
  [SMALL_STATE(15858)] = 644969,
  [SMALL_STATE(15859)] = 644986,
  [SMALL_STATE(15860)] = 645001,
  [SMALL_STATE(15861)] = 645016,
  [SMALL_STATE(15862)] = 645031,
  [SMALL_STATE(15863)] = 645046,
  [SMALL_STATE(15864)] = 645063,
  [SMALL_STATE(15865)] = 645078,
  [SMALL_STATE(15866)] = 645095,
  [SMALL_STATE(15867)] = 645110,
  [SMALL_STATE(15868)] = 645125,
  [SMALL_STATE(15869)] = 645140,
  [SMALL_STATE(15870)] = 645157,
  [SMALL_STATE(15871)] = 645172,
  [SMALL_STATE(15872)] = 645187,
  [SMALL_STATE(15873)] = 645202,
  [SMALL_STATE(15874)] = 645217,
  [SMALL_STATE(15875)] = 645232,
  [SMALL_STATE(15876)] = 645247,
  [SMALL_STATE(15877)] = 645264,
  [SMALL_STATE(15878)] = 645281,
  [SMALL_STATE(15879)] = 645296,
  [SMALL_STATE(15880)] = 645313,
  [SMALL_STATE(15881)] = 645328,
  [SMALL_STATE(15882)] = 645345,
  [SMALL_STATE(15883)] = 645360,
  [SMALL_STATE(15884)] = 645377,
  [SMALL_STATE(15885)] = 645392,
  [SMALL_STATE(15886)] = 645407,
  [SMALL_STATE(15887)] = 645422,
  [SMALL_STATE(15888)] = 645439,
  [SMALL_STATE(15889)] = 645456,
  [SMALL_STATE(15890)] = 645471,
  [SMALL_STATE(15891)] = 645486,
  [SMALL_STATE(15892)] = 645501,
  [SMALL_STATE(15893)] = 645516,
  [SMALL_STATE(15894)] = 645531,
  [SMALL_STATE(15895)] = 645546,
  [SMALL_STATE(15896)] = 645561,
  [SMALL_STATE(15897)] = 645576,
  [SMALL_STATE(15898)] = 645591,
  [SMALL_STATE(15899)] = 645606,
  [SMALL_STATE(15900)] = 645621,
  [SMALL_STATE(15901)] = 645636,
  [SMALL_STATE(15902)] = 645651,
  [SMALL_STATE(15903)] = 645666,
  [SMALL_STATE(15904)] = 645681,
  [SMALL_STATE(15905)] = 645696,
  [SMALL_STATE(15906)] = 645713,
  [SMALL_STATE(15907)] = 645728,
  [SMALL_STATE(15908)] = 645743,
  [SMALL_STATE(15909)] = 645760,
  [SMALL_STATE(15910)] = 645775,
  [SMALL_STATE(15911)] = 645790,
  [SMALL_STATE(15912)] = 645805,
  [SMALL_STATE(15913)] = 645820,
  [SMALL_STATE(15914)] = 645837,
  [SMALL_STATE(15915)] = 645852,
  [SMALL_STATE(15916)] = 645869,
  [SMALL_STATE(15917)] = 645884,
  [SMALL_STATE(15918)] = 645899,
  [SMALL_STATE(15919)] = 645914,
  [SMALL_STATE(15920)] = 645929,
  [SMALL_STATE(15921)] = 645944,
  [SMALL_STATE(15922)] = 645959,
  [SMALL_STATE(15923)] = 645974,
  [SMALL_STATE(15924)] = 645989,
  [SMALL_STATE(15925)] = 646004,
  [SMALL_STATE(15926)] = 646019,
  [SMALL_STATE(15927)] = 646034,
  [SMALL_STATE(15928)] = 646051,
  [SMALL_STATE(15929)] = 646068,
  [SMALL_STATE(15930)] = 646083,
  [SMALL_STATE(15931)] = 646098,
  [SMALL_STATE(15932)] = 646113,
  [SMALL_STATE(15933)] = 646128,
  [SMALL_STATE(15934)] = 646143,
  [SMALL_STATE(15935)] = 646158,
  [SMALL_STATE(15936)] = 646173,
  [SMALL_STATE(15937)] = 646190,
  [SMALL_STATE(15938)] = 646205,
  [SMALL_STATE(15939)] = 646220,
  [SMALL_STATE(15940)] = 646235,
  [SMALL_STATE(15941)] = 646250,
  [SMALL_STATE(15942)] = 646267,
  [SMALL_STATE(15943)] = 646282,
  [SMALL_STATE(15944)] = 646297,
  [SMALL_STATE(15945)] = 646312,
  [SMALL_STATE(15946)] = 646327,
  [SMALL_STATE(15947)] = 646344,
  [SMALL_STATE(15948)] = 646359,
  [SMALL_STATE(15949)] = 646374,
  [SMALL_STATE(15950)] = 646389,
  [SMALL_STATE(15951)] = 646406,
  [SMALL_STATE(15952)] = 646421,
  [SMALL_STATE(15953)] = 646436,
  [SMALL_STATE(15954)] = 646453,
  [SMALL_STATE(15955)] = 646470,
  [SMALL_STATE(15956)] = 646487,
  [SMALL_STATE(15957)] = 646502,
  [SMALL_STATE(15958)] = 646517,
  [SMALL_STATE(15959)] = 646532,
  [SMALL_STATE(15960)] = 646547,
  [SMALL_STATE(15961)] = 646562,
  [SMALL_STATE(15962)] = 646577,
  [SMALL_STATE(15963)] = 646592,
  [SMALL_STATE(15964)] = 646607,
  [SMALL_STATE(15965)] = 646622,
  [SMALL_STATE(15966)] = 646637,
  [SMALL_STATE(15967)] = 646652,
  [SMALL_STATE(15968)] = 646667,
  [SMALL_STATE(15969)] = 646682,
  [SMALL_STATE(15970)] = 646697,
  [SMALL_STATE(15971)] = 646714,
  [SMALL_STATE(15972)] = 646731,
  [SMALL_STATE(15973)] = 646746,
  [SMALL_STATE(15974)] = 646761,
  [SMALL_STATE(15975)] = 646776,
  [SMALL_STATE(15976)] = 646793,
  [SMALL_STATE(15977)] = 646810,
  [SMALL_STATE(15978)] = 646827,
  [SMALL_STATE(15979)] = 646842,
  [SMALL_STATE(15980)] = 646857,
  [SMALL_STATE(15981)] = 646874,
  [SMALL_STATE(15982)] = 646889,
  [SMALL_STATE(15983)] = 646904,
  [SMALL_STATE(15984)] = 646919,
  [SMALL_STATE(15985)] = 646934,
  [SMALL_STATE(15986)] = 646949,
  [SMALL_STATE(15987)] = 646964,
  [SMALL_STATE(15988)] = 646979,
  [SMALL_STATE(15989)] = 646996,
  [SMALL_STATE(15990)] = 647013,
  [SMALL_STATE(15991)] = 647028,
  [SMALL_STATE(15992)] = 647043,
  [SMALL_STATE(15993)] = 647058,
  [SMALL_STATE(15994)] = 647075,
  [SMALL_STATE(15995)] = 647090,
  [SMALL_STATE(15996)] = 647105,
  [SMALL_STATE(15997)] = 647120,
  [SMALL_STATE(15998)] = 647135,
  [SMALL_STATE(15999)] = 647152,
  [SMALL_STATE(16000)] = 647167,
  [SMALL_STATE(16001)] = 647182,
  [SMALL_STATE(16002)] = 647197,
  [SMALL_STATE(16003)] = 647214,
  [SMALL_STATE(16004)] = 647231,
  [SMALL_STATE(16005)] = 647246,
  [SMALL_STATE(16006)] = 647263,
  [SMALL_STATE(16007)] = 647278,
  [SMALL_STATE(16008)] = 647295,
  [SMALL_STATE(16009)] = 647312,
  [SMALL_STATE(16010)] = 647327,
  [SMALL_STATE(16011)] = 647342,
  [SMALL_STATE(16012)] = 647357,
  [SMALL_STATE(16013)] = 647374,
  [SMALL_STATE(16014)] = 647389,
  [SMALL_STATE(16015)] = 647404,
  [SMALL_STATE(16016)] = 647419,
  [SMALL_STATE(16017)] = 647436,
  [SMALL_STATE(16018)] = 647451,
  [SMALL_STATE(16019)] = 647466,
  [SMALL_STATE(16020)] = 647483,
  [SMALL_STATE(16021)] = 647498,
  [SMALL_STATE(16022)] = 647513,
  [SMALL_STATE(16023)] = 647528,
  [SMALL_STATE(16024)] = 647543,
  [SMALL_STATE(16025)] = 647558,
  [SMALL_STATE(16026)] = 647573,
  [SMALL_STATE(16027)] = 647590,
  [SMALL_STATE(16028)] = 647605,
  [SMALL_STATE(16029)] = 647622,
  [SMALL_STATE(16030)] = 647639,
  [SMALL_STATE(16031)] = 647654,
  [SMALL_STATE(16032)] = 647669,
  [SMALL_STATE(16033)] = 647684,
  [SMALL_STATE(16034)] = 647699,
  [SMALL_STATE(16035)] = 647716,
  [SMALL_STATE(16036)] = 647731,
  [SMALL_STATE(16037)] = 647748,
  [SMALL_STATE(16038)] = 647765,
  [SMALL_STATE(16039)] = 647780,
  [SMALL_STATE(16040)] = 647795,
  [SMALL_STATE(16041)] = 647810,
  [SMALL_STATE(16042)] = 647825,
  [SMALL_STATE(16043)] = 647840,
  [SMALL_STATE(16044)] = 647855,
  [SMALL_STATE(16045)] = 647870,
  [SMALL_STATE(16046)] = 647885,
  [SMALL_STATE(16047)] = 647900,
  [SMALL_STATE(16048)] = 647917,
  [SMALL_STATE(16049)] = 647932,
  [SMALL_STATE(16050)] = 647947,
  [SMALL_STATE(16051)] = 647964,
  [SMALL_STATE(16052)] = 647979,
  [SMALL_STATE(16053)] = 647994,
  [SMALL_STATE(16054)] = 648009,
  [SMALL_STATE(16055)] = 648024,
  [SMALL_STATE(16056)] = 648039,
  [SMALL_STATE(16057)] = 648054,
  [SMALL_STATE(16058)] = 648071,
  [SMALL_STATE(16059)] = 648088,
  [SMALL_STATE(16060)] = 648103,
  [SMALL_STATE(16061)] = 648118,
  [SMALL_STATE(16062)] = 648133,
  [SMALL_STATE(16063)] = 648148,
  [SMALL_STATE(16064)] = 648163,
  [SMALL_STATE(16065)] = 648178,
  [SMALL_STATE(16066)] = 648193,
  [SMALL_STATE(16067)] = 648208,
  [SMALL_STATE(16068)] = 648223,
  [SMALL_STATE(16069)] = 648238,
  [SMALL_STATE(16070)] = 648253,
  [SMALL_STATE(16071)] = 648270,
  [SMALL_STATE(16072)] = 648285,
  [SMALL_STATE(16073)] = 648300,
  [SMALL_STATE(16074)] = 648315,
  [SMALL_STATE(16075)] = 648332,
  [SMALL_STATE(16076)] = 648347,
  [SMALL_STATE(16077)] = 648362,
  [SMALL_STATE(16078)] = 648377,
  [SMALL_STATE(16079)] = 648392,
  [SMALL_STATE(16080)] = 648407,
  [SMALL_STATE(16081)] = 648422,
  [SMALL_STATE(16082)] = 648437,
  [SMALL_STATE(16083)] = 648454,
  [SMALL_STATE(16084)] = 648471,
  [SMALL_STATE(16085)] = 648486,
  [SMALL_STATE(16086)] = 648501,
  [SMALL_STATE(16087)] = 648516,
  [SMALL_STATE(16088)] = 648531,
  [SMALL_STATE(16089)] = 648546,
  [SMALL_STATE(16090)] = 648563,
  [SMALL_STATE(16091)] = 648578,
  [SMALL_STATE(16092)] = 648593,
  [SMALL_STATE(16093)] = 648608,
  [SMALL_STATE(16094)] = 648623,
  [SMALL_STATE(16095)] = 648638,
  [SMALL_STATE(16096)] = 648651,
  [SMALL_STATE(16097)] = 648666,
  [SMALL_STATE(16098)] = 648681,
  [SMALL_STATE(16099)] = 648696,
  [SMALL_STATE(16100)] = 648711,
  [SMALL_STATE(16101)] = 648726,
  [SMALL_STATE(16102)] = 648741,
  [SMALL_STATE(16103)] = 648756,
  [SMALL_STATE(16104)] = 648771,
  [SMALL_STATE(16105)] = 648786,
  [SMALL_STATE(16106)] = 648801,
  [SMALL_STATE(16107)] = 648816,
  [SMALL_STATE(16108)] = 648831,
  [SMALL_STATE(16109)] = 648846,
  [SMALL_STATE(16110)] = 648861,
  [SMALL_STATE(16111)] = 648876,
  [SMALL_STATE(16112)] = 648891,
  [SMALL_STATE(16113)] = 648906,
  [SMALL_STATE(16114)] = 648921,
  [SMALL_STATE(16115)] = 648936,
  [SMALL_STATE(16116)] = 648951,
  [SMALL_STATE(16117)] = 648966,
  [SMALL_STATE(16118)] = 648981,
  [SMALL_STATE(16119)] = 648996,
  [SMALL_STATE(16120)] = 649013,
  [SMALL_STATE(16121)] = 649028,
  [SMALL_STATE(16122)] = 649043,
  [SMALL_STATE(16123)] = 649058,
  [SMALL_STATE(16124)] = 649073,
  [SMALL_STATE(16125)] = 649090,
  [SMALL_STATE(16126)] = 649105,
  [SMALL_STATE(16127)] = 649120,
  [SMALL_STATE(16128)] = 649137,
  [SMALL_STATE(16129)] = 649152,
  [SMALL_STATE(16130)] = 649167,
  [SMALL_STATE(16131)] = 649184,
  [SMALL_STATE(16132)] = 649201,
  [SMALL_STATE(16133)] = 649218,
  [SMALL_STATE(16134)] = 649233,
  [SMALL_STATE(16135)] = 649250,
  [SMALL_STATE(16136)] = 649265,
  [SMALL_STATE(16137)] = 649280,
  [SMALL_STATE(16138)] = 649295,
  [SMALL_STATE(16139)] = 649310,
  [SMALL_STATE(16140)] = 649325,
  [SMALL_STATE(16141)] = 649340,
  [SMALL_STATE(16142)] = 649355,
  [SMALL_STATE(16143)] = 649370,
  [SMALL_STATE(16144)] = 649385,
  [SMALL_STATE(16145)] = 649400,
  [SMALL_STATE(16146)] = 649415,
  [SMALL_STATE(16147)] = 649430,
  [SMALL_STATE(16148)] = 649445,
  [SMALL_STATE(16149)] = 649459,
  [SMALL_STATE(16150)] = 649473,
  [SMALL_STATE(16151)] = 649487,
  [SMALL_STATE(16152)] = 649501,
  [SMALL_STATE(16153)] = 649515,
  [SMALL_STATE(16154)] = 649529,
  [SMALL_STATE(16155)] = 649543,
  [SMALL_STATE(16156)] = 649557,
  [SMALL_STATE(16157)] = 649571,
  [SMALL_STATE(16158)] = 649585,
  [SMALL_STATE(16159)] = 649599,
  [SMALL_STATE(16160)] = 649613,
  [SMALL_STATE(16161)] = 649627,
  [SMALL_STATE(16162)] = 649641,
  [SMALL_STATE(16163)] = 649655,
  [SMALL_STATE(16164)] = 649669,
  [SMALL_STATE(16165)] = 649683,
  [SMALL_STATE(16166)] = 649697,
  [SMALL_STATE(16167)] = 649711,
  [SMALL_STATE(16168)] = 649725,
  [SMALL_STATE(16169)] = 649739,
  [SMALL_STATE(16170)] = 649753,
  [SMALL_STATE(16171)] = 649767,
  [SMALL_STATE(16172)] = 649781,
  [SMALL_STATE(16173)] = 649795,
  [SMALL_STATE(16174)] = 649809,
  [SMALL_STATE(16175)] = 649823,
  [SMALL_STATE(16176)] = 649837,
  [SMALL_STATE(16177)] = 649851,
  [SMALL_STATE(16178)] = 649865,
  [SMALL_STATE(16179)] = 649879,
  [SMALL_STATE(16180)] = 649893,
  [SMALL_STATE(16181)] = 649907,
  [SMALL_STATE(16182)] = 649921,
  [SMALL_STATE(16183)] = 649935,
  [SMALL_STATE(16184)] = 649949,
  [SMALL_STATE(16185)] = 649963,
  [SMALL_STATE(16186)] = 649977,
  [SMALL_STATE(16187)] = 649991,
  [SMALL_STATE(16188)] = 650005,
  [SMALL_STATE(16189)] = 650019,
  [SMALL_STATE(16190)] = 650033,
  [SMALL_STATE(16191)] = 650047,
  [SMALL_STATE(16192)] = 650061,
  [SMALL_STATE(16193)] = 650075,
  [SMALL_STATE(16194)] = 650089,
  [SMALL_STATE(16195)] = 650103,
  [SMALL_STATE(16196)] = 650117,
  [SMALL_STATE(16197)] = 650131,
  [SMALL_STATE(16198)] = 650145,
  [SMALL_STATE(16199)] = 650159,
  [SMALL_STATE(16200)] = 650173,
  [SMALL_STATE(16201)] = 650187,
  [SMALL_STATE(16202)] = 650201,
  [SMALL_STATE(16203)] = 650215,
  [SMALL_STATE(16204)] = 650229,
  [SMALL_STATE(16205)] = 650243,
  [SMALL_STATE(16206)] = 650257,
  [SMALL_STATE(16207)] = 650271,
  [SMALL_STATE(16208)] = 650285,
  [SMALL_STATE(16209)] = 650299,
  [SMALL_STATE(16210)] = 650313,
  [SMALL_STATE(16211)] = 650327,
  [SMALL_STATE(16212)] = 650341,
  [SMALL_STATE(16213)] = 650355,
  [SMALL_STATE(16214)] = 650369,
  [SMALL_STATE(16215)] = 650383,
  [SMALL_STATE(16216)] = 650397,
  [SMALL_STATE(16217)] = 650411,
  [SMALL_STATE(16218)] = 650425,
  [SMALL_STATE(16219)] = 650439,
  [SMALL_STATE(16220)] = 650453,
  [SMALL_STATE(16221)] = 650467,
  [SMALL_STATE(16222)] = 650481,
  [SMALL_STATE(16223)] = 650495,
  [SMALL_STATE(16224)] = 650509,
  [SMALL_STATE(16225)] = 650523,
  [SMALL_STATE(16226)] = 650537,
  [SMALL_STATE(16227)] = 650551,
  [SMALL_STATE(16228)] = 650565,
  [SMALL_STATE(16229)] = 650579,
  [SMALL_STATE(16230)] = 650593,
  [SMALL_STATE(16231)] = 650607,
  [SMALL_STATE(16232)] = 650621,
  [SMALL_STATE(16233)] = 650635,
  [SMALL_STATE(16234)] = 650649,
  [SMALL_STATE(16235)] = 650663,
  [SMALL_STATE(16236)] = 650677,
  [SMALL_STATE(16237)] = 650691,
  [SMALL_STATE(16238)] = 650705,
  [SMALL_STATE(16239)] = 650719,
  [SMALL_STATE(16240)] = 650733,
  [SMALL_STATE(16241)] = 650747,
  [SMALL_STATE(16242)] = 650761,
  [SMALL_STATE(16243)] = 650775,
  [SMALL_STATE(16244)] = 650789,
  [SMALL_STATE(16245)] = 650803,
  [SMALL_STATE(16246)] = 650817,
  [SMALL_STATE(16247)] = 650831,
  [SMALL_STATE(16248)] = 650845,
  [SMALL_STATE(16249)] = 650859,
  [SMALL_STATE(16250)] = 650873,
  [SMALL_STATE(16251)] = 650887,
  [SMALL_STATE(16252)] = 650901,
  [SMALL_STATE(16253)] = 650915,
  [SMALL_STATE(16254)] = 650929,
  [SMALL_STATE(16255)] = 650943,
  [SMALL_STATE(16256)] = 650957,
  [SMALL_STATE(16257)] = 650971,
  [SMALL_STATE(16258)] = 650985,
  [SMALL_STATE(16259)] = 650999,
  [SMALL_STATE(16260)] = 651013,
  [SMALL_STATE(16261)] = 651027,
  [SMALL_STATE(16262)] = 651041,
  [SMALL_STATE(16263)] = 651055,
  [SMALL_STATE(16264)] = 651069,
  [SMALL_STATE(16265)] = 651083,
  [SMALL_STATE(16266)] = 651097,
  [SMALL_STATE(16267)] = 651111,
  [SMALL_STATE(16268)] = 651125,
  [SMALL_STATE(16269)] = 651139,
  [SMALL_STATE(16270)] = 651153,
  [SMALL_STATE(16271)] = 651167,
  [SMALL_STATE(16272)] = 651181,
  [SMALL_STATE(16273)] = 651195,
  [SMALL_STATE(16274)] = 651209,
  [SMALL_STATE(16275)] = 651223,
  [SMALL_STATE(16276)] = 651237,
  [SMALL_STATE(16277)] = 651251,
  [SMALL_STATE(16278)] = 651265,
  [SMALL_STATE(16279)] = 651279,
  [SMALL_STATE(16280)] = 651293,
  [SMALL_STATE(16281)] = 651307,
  [SMALL_STATE(16282)] = 651321,
  [SMALL_STATE(16283)] = 651335,
  [SMALL_STATE(16284)] = 651349,
  [SMALL_STATE(16285)] = 651363,
  [SMALL_STATE(16286)] = 651377,
  [SMALL_STATE(16287)] = 651391,
  [SMALL_STATE(16288)] = 651405,
  [SMALL_STATE(16289)] = 651419,
  [SMALL_STATE(16290)] = 651433,
  [SMALL_STATE(16291)] = 651447,
  [SMALL_STATE(16292)] = 651461,
  [SMALL_STATE(16293)] = 651475,
  [SMALL_STATE(16294)] = 651489,
  [SMALL_STATE(16295)] = 651503,
  [SMALL_STATE(16296)] = 651517,
  [SMALL_STATE(16297)] = 651531,
  [SMALL_STATE(16298)] = 651545,
  [SMALL_STATE(16299)] = 651559,
  [SMALL_STATE(16300)] = 651573,
  [SMALL_STATE(16301)] = 651587,
  [SMALL_STATE(16302)] = 651601,
  [SMALL_STATE(16303)] = 651615,
  [SMALL_STATE(16304)] = 651629,
  [SMALL_STATE(16305)] = 651643,
  [SMALL_STATE(16306)] = 651657,
  [SMALL_STATE(16307)] = 651671,
  [SMALL_STATE(16308)] = 651685,
  [SMALL_STATE(16309)] = 651699,
  [SMALL_STATE(16310)] = 651713,
  [SMALL_STATE(16311)] = 651727,
  [SMALL_STATE(16312)] = 651741,
  [SMALL_STATE(16313)] = 651755,
  [SMALL_STATE(16314)] = 651769,
  [SMALL_STATE(16315)] = 651783,
  [SMALL_STATE(16316)] = 651797,
  [SMALL_STATE(16317)] = 651811,
  [SMALL_STATE(16318)] = 651825,
  [SMALL_STATE(16319)] = 651839,
  [SMALL_STATE(16320)] = 651853,
  [SMALL_STATE(16321)] = 651867,
  [SMALL_STATE(16322)] = 651881,
  [SMALL_STATE(16323)] = 651895,
  [SMALL_STATE(16324)] = 651909,
  [SMALL_STATE(16325)] = 651923,
  [SMALL_STATE(16326)] = 651937,
  [SMALL_STATE(16327)] = 651951,
  [SMALL_STATE(16328)] = 651965,
  [SMALL_STATE(16329)] = 651979,
  [SMALL_STATE(16330)] = 651993,
  [SMALL_STATE(16331)] = 652007,
  [SMALL_STATE(16332)] = 652021,
  [SMALL_STATE(16333)] = 652035,
  [SMALL_STATE(16334)] = 652049,
  [SMALL_STATE(16335)] = 652063,
  [SMALL_STATE(16336)] = 652077,
  [SMALL_STATE(16337)] = 652091,
  [SMALL_STATE(16338)] = 652105,
  [SMALL_STATE(16339)] = 652119,
  [SMALL_STATE(16340)] = 652133,
  [SMALL_STATE(16341)] = 652147,
  [SMALL_STATE(16342)] = 652161,
  [SMALL_STATE(16343)] = 652175,
  [SMALL_STATE(16344)] = 652189,
  [SMALL_STATE(16345)] = 652203,
  [SMALL_STATE(16346)] = 652217,
  [SMALL_STATE(16347)] = 652231,
  [SMALL_STATE(16348)] = 652245,
  [SMALL_STATE(16349)] = 652259,
  [SMALL_STATE(16350)] = 652273,
  [SMALL_STATE(16351)] = 652287,
  [SMALL_STATE(16352)] = 652301,
  [SMALL_STATE(16353)] = 652315,
  [SMALL_STATE(16354)] = 652329,
  [SMALL_STATE(16355)] = 652343,
  [SMALL_STATE(16356)] = 652357,
  [SMALL_STATE(16357)] = 652371,
  [SMALL_STATE(16358)] = 652385,
  [SMALL_STATE(16359)] = 652399,
  [SMALL_STATE(16360)] = 652413,
  [SMALL_STATE(16361)] = 652427,
  [SMALL_STATE(16362)] = 652441,
  [SMALL_STATE(16363)] = 652455,
  [SMALL_STATE(16364)] = 652469,
  [SMALL_STATE(16365)] = 652483,
  [SMALL_STATE(16366)] = 652497,
  [SMALL_STATE(16367)] = 652511,
  [SMALL_STATE(16368)] = 652525,
  [SMALL_STATE(16369)] = 652539,
  [SMALL_STATE(16370)] = 652553,
  [SMALL_STATE(16371)] = 652567,
  [SMALL_STATE(16372)] = 652581,
  [SMALL_STATE(16373)] = 652595,
  [SMALL_STATE(16374)] = 652609,
  [SMALL_STATE(16375)] = 652623,
  [SMALL_STATE(16376)] = 652637,
  [SMALL_STATE(16377)] = 652651,
  [SMALL_STATE(16378)] = 652665,
  [SMALL_STATE(16379)] = 652679,
  [SMALL_STATE(16380)] = 652693,
  [SMALL_STATE(16381)] = 652707,
  [SMALL_STATE(16382)] = 652721,
  [SMALL_STATE(16383)] = 652735,
  [SMALL_STATE(16384)] = 652749,
  [SMALL_STATE(16385)] = 652763,
  [SMALL_STATE(16386)] = 652777,
  [SMALL_STATE(16387)] = 652791,
  [SMALL_STATE(16388)] = 652805,
  [SMALL_STATE(16389)] = 652819,
  [SMALL_STATE(16390)] = 652833,
  [SMALL_STATE(16391)] = 652847,
  [SMALL_STATE(16392)] = 652861,
  [SMALL_STATE(16393)] = 652875,
  [SMALL_STATE(16394)] = 652889,
  [SMALL_STATE(16395)] = 652903,
  [SMALL_STATE(16396)] = 652917,
  [SMALL_STATE(16397)] = 652931,
  [SMALL_STATE(16398)] = 652945,
  [SMALL_STATE(16399)] = 652959,
  [SMALL_STATE(16400)] = 652973,
  [SMALL_STATE(16401)] = 652987,
  [SMALL_STATE(16402)] = 653001,
  [SMALL_STATE(16403)] = 653015,
  [SMALL_STATE(16404)] = 653029,
  [SMALL_STATE(16405)] = 653043,
  [SMALL_STATE(16406)] = 653057,
  [SMALL_STATE(16407)] = 653071,
  [SMALL_STATE(16408)] = 653085,
  [SMALL_STATE(16409)] = 653099,
  [SMALL_STATE(16410)] = 653113,
  [SMALL_STATE(16411)] = 653127,
  [SMALL_STATE(16412)] = 653141,
  [SMALL_STATE(16413)] = 653155,
  [SMALL_STATE(16414)] = 653169,
  [SMALL_STATE(16415)] = 653183,
  [SMALL_STATE(16416)] = 653197,
  [SMALL_STATE(16417)] = 653211,
  [SMALL_STATE(16418)] = 653225,
  [SMALL_STATE(16419)] = 653239,
  [SMALL_STATE(16420)] = 653253,
  [SMALL_STATE(16421)] = 653267,
  [SMALL_STATE(16422)] = 653281,
  [SMALL_STATE(16423)] = 653295,
  [SMALL_STATE(16424)] = 653309,
  [SMALL_STATE(16425)] = 653323,
  [SMALL_STATE(16426)] = 653337,
  [SMALL_STATE(16427)] = 653351,
  [SMALL_STATE(16428)] = 653365,
  [SMALL_STATE(16429)] = 653379,
  [SMALL_STATE(16430)] = 653393,
  [SMALL_STATE(16431)] = 653407,
  [SMALL_STATE(16432)] = 653421,
  [SMALL_STATE(16433)] = 653435,
  [SMALL_STATE(16434)] = 653449,
  [SMALL_STATE(16435)] = 653463,
  [SMALL_STATE(16436)] = 653477,
  [SMALL_STATE(16437)] = 653491,
  [SMALL_STATE(16438)] = 653505,
  [SMALL_STATE(16439)] = 653519,
  [SMALL_STATE(16440)] = 653533,
  [SMALL_STATE(16441)] = 653547,
  [SMALL_STATE(16442)] = 653561,
  [SMALL_STATE(16443)] = 653575,
  [SMALL_STATE(16444)] = 653589,
  [SMALL_STATE(16445)] = 653603,
  [SMALL_STATE(16446)] = 653617,
  [SMALL_STATE(16447)] = 653631,
  [SMALL_STATE(16448)] = 653645,
  [SMALL_STATE(16449)] = 653659,
  [SMALL_STATE(16450)] = 653673,
  [SMALL_STATE(16451)] = 653687,
  [SMALL_STATE(16452)] = 653701,
  [SMALL_STATE(16453)] = 653715,
  [SMALL_STATE(16454)] = 653729,
  [SMALL_STATE(16455)] = 653743,
  [SMALL_STATE(16456)] = 653757,
  [SMALL_STATE(16457)] = 653771,
  [SMALL_STATE(16458)] = 653785,
  [SMALL_STATE(16459)] = 653799,
  [SMALL_STATE(16460)] = 653813,
  [SMALL_STATE(16461)] = 653827,
  [SMALL_STATE(16462)] = 653841,
  [SMALL_STATE(16463)] = 653855,
  [SMALL_STATE(16464)] = 653869,
  [SMALL_STATE(16465)] = 653883,
  [SMALL_STATE(16466)] = 653897,
  [SMALL_STATE(16467)] = 653911,
  [SMALL_STATE(16468)] = 653925,
  [SMALL_STATE(16469)] = 653939,
  [SMALL_STATE(16470)] = 653953,
  [SMALL_STATE(16471)] = 653967,
  [SMALL_STATE(16472)] = 653981,
  [SMALL_STATE(16473)] = 653995,
  [SMALL_STATE(16474)] = 654009,
  [SMALL_STATE(16475)] = 654023,
  [SMALL_STATE(16476)] = 654037,
  [SMALL_STATE(16477)] = 654051,
  [SMALL_STATE(16478)] = 654065,
  [SMALL_STATE(16479)] = 654079,
  [SMALL_STATE(16480)] = 654093,
  [SMALL_STATE(16481)] = 654107,
  [SMALL_STATE(16482)] = 654121,
  [SMALL_STATE(16483)] = 654135,
  [SMALL_STATE(16484)] = 654149,
  [SMALL_STATE(16485)] = 654163,
  [SMALL_STATE(16486)] = 654177,
  [SMALL_STATE(16487)] = 654191,
  [SMALL_STATE(16488)] = 654205,
  [SMALL_STATE(16489)] = 654219,
  [SMALL_STATE(16490)] = 654233,
  [SMALL_STATE(16491)] = 654247,
  [SMALL_STATE(16492)] = 654261,
  [SMALL_STATE(16493)] = 654275,
  [SMALL_STATE(16494)] = 654289,
  [SMALL_STATE(16495)] = 654303,
  [SMALL_STATE(16496)] = 654317,
  [SMALL_STATE(16497)] = 654331,
  [SMALL_STATE(16498)] = 654345,
  [SMALL_STATE(16499)] = 654359,
  [SMALL_STATE(16500)] = 654373,
  [SMALL_STATE(16501)] = 654387,
  [SMALL_STATE(16502)] = 654401,
  [SMALL_STATE(16503)] = 654415,
  [SMALL_STATE(16504)] = 654429,
  [SMALL_STATE(16505)] = 654443,
  [SMALL_STATE(16506)] = 654457,
  [SMALL_STATE(16507)] = 654471,
  [SMALL_STATE(16508)] = 654485,
  [SMALL_STATE(16509)] = 654499,
  [SMALL_STATE(16510)] = 654513,
  [SMALL_STATE(16511)] = 654527,
  [SMALL_STATE(16512)] = 654541,
  [SMALL_STATE(16513)] = 654555,
  [SMALL_STATE(16514)] = 654569,
  [SMALL_STATE(16515)] = 654583,
  [SMALL_STATE(16516)] = 654597,
  [SMALL_STATE(16517)] = 654611,
  [SMALL_STATE(16518)] = 654625,
  [SMALL_STATE(16519)] = 654639,
  [SMALL_STATE(16520)] = 654653,
  [SMALL_STATE(16521)] = 654667,
  [SMALL_STATE(16522)] = 654681,
  [SMALL_STATE(16523)] = 654695,
  [SMALL_STATE(16524)] = 654709,
  [SMALL_STATE(16525)] = 654723,
  [SMALL_STATE(16526)] = 654737,
  [SMALL_STATE(16527)] = 654751,
  [SMALL_STATE(16528)] = 654765,
  [SMALL_STATE(16529)] = 654779,
  [SMALL_STATE(16530)] = 654793,
  [SMALL_STATE(16531)] = 654807,
  [SMALL_STATE(16532)] = 654821,
  [SMALL_STATE(16533)] = 654835,
  [SMALL_STATE(16534)] = 654849,
  [SMALL_STATE(16535)] = 654863,
  [SMALL_STATE(16536)] = 654877,
  [SMALL_STATE(16537)] = 654891,
  [SMALL_STATE(16538)] = 654905,
  [SMALL_STATE(16539)] = 654919,
  [SMALL_STATE(16540)] = 654933,
  [SMALL_STATE(16541)] = 654947,
  [SMALL_STATE(16542)] = 654961,
  [SMALL_STATE(16543)] = 654975,
  [SMALL_STATE(16544)] = 654989,
  [SMALL_STATE(16545)] = 655003,
  [SMALL_STATE(16546)] = 655017,
  [SMALL_STATE(16547)] = 655031,
  [SMALL_STATE(16548)] = 655045,
  [SMALL_STATE(16549)] = 655059,
  [SMALL_STATE(16550)] = 655073,
  [SMALL_STATE(16551)] = 655087,
  [SMALL_STATE(16552)] = 655101,
  [SMALL_STATE(16553)] = 655115,
  [SMALL_STATE(16554)] = 655129,
  [SMALL_STATE(16555)] = 655143,
  [SMALL_STATE(16556)] = 655157,
  [SMALL_STATE(16557)] = 655171,
  [SMALL_STATE(16558)] = 655185,
  [SMALL_STATE(16559)] = 655199,
  [SMALL_STATE(16560)] = 655213,
  [SMALL_STATE(16561)] = 655227,
  [SMALL_STATE(16562)] = 655241,
  [SMALL_STATE(16563)] = 655255,
  [SMALL_STATE(16564)] = 655269,
  [SMALL_STATE(16565)] = 655283,
  [SMALL_STATE(16566)] = 655297,
  [SMALL_STATE(16567)] = 655311,
  [SMALL_STATE(16568)] = 655325,
  [SMALL_STATE(16569)] = 655339,
  [SMALL_STATE(16570)] = 655353,
  [SMALL_STATE(16571)] = 655367,
  [SMALL_STATE(16572)] = 655381,
  [SMALL_STATE(16573)] = 655395,
  [SMALL_STATE(16574)] = 655409,
  [SMALL_STATE(16575)] = 655423,
  [SMALL_STATE(16576)] = 655437,
  [SMALL_STATE(16577)] = 655451,
  [SMALL_STATE(16578)] = 655465,
  [SMALL_STATE(16579)] = 655479,
  [SMALL_STATE(16580)] = 655493,
  [SMALL_STATE(16581)] = 655507,
  [SMALL_STATE(16582)] = 655521,
  [SMALL_STATE(16583)] = 655535,
  [SMALL_STATE(16584)] = 655549,
  [SMALL_STATE(16585)] = 655563,
  [SMALL_STATE(16586)] = 655577,
  [SMALL_STATE(16587)] = 655591,
  [SMALL_STATE(16588)] = 655605,
  [SMALL_STATE(16589)] = 655619,
  [SMALL_STATE(16590)] = 655633,
  [SMALL_STATE(16591)] = 655647,
  [SMALL_STATE(16592)] = 655661,
  [SMALL_STATE(16593)] = 655675,
  [SMALL_STATE(16594)] = 655689,
  [SMALL_STATE(16595)] = 655703,
  [SMALL_STATE(16596)] = 655717,
  [SMALL_STATE(16597)] = 655731,
  [SMALL_STATE(16598)] = 655745,
  [SMALL_STATE(16599)] = 655759,
  [SMALL_STATE(16600)] = 655773,
  [SMALL_STATE(16601)] = 655787,
  [SMALL_STATE(16602)] = 655801,
  [SMALL_STATE(16603)] = 655815,
  [SMALL_STATE(16604)] = 655829,
  [SMALL_STATE(16605)] = 655843,
  [SMALL_STATE(16606)] = 655857,
  [SMALL_STATE(16607)] = 655871,
  [SMALL_STATE(16608)] = 655885,
  [SMALL_STATE(16609)] = 655899,
  [SMALL_STATE(16610)] = 655913,
  [SMALL_STATE(16611)] = 655927,
  [SMALL_STATE(16612)] = 655941,
  [SMALL_STATE(16613)] = 655955,
  [SMALL_STATE(16614)] = 655969,
  [SMALL_STATE(16615)] = 655983,
  [SMALL_STATE(16616)] = 655997,
  [SMALL_STATE(16617)] = 656011,
  [SMALL_STATE(16618)] = 656025,
  [SMALL_STATE(16619)] = 656039,
  [SMALL_STATE(16620)] = 656053,
  [SMALL_STATE(16621)] = 656067,
  [SMALL_STATE(16622)] = 656081,
  [SMALL_STATE(16623)] = 656095,
  [SMALL_STATE(16624)] = 656109,
  [SMALL_STATE(16625)] = 656123,
  [SMALL_STATE(16626)] = 656137,
  [SMALL_STATE(16627)] = 656151,
  [SMALL_STATE(16628)] = 656165,
  [SMALL_STATE(16629)] = 656179,
  [SMALL_STATE(16630)] = 656193,
  [SMALL_STATE(16631)] = 656207,
  [SMALL_STATE(16632)] = 656221,
  [SMALL_STATE(16633)] = 656235,
  [SMALL_STATE(16634)] = 656249,
  [SMALL_STATE(16635)] = 656263,
  [SMALL_STATE(16636)] = 656277,
  [SMALL_STATE(16637)] = 656291,
  [SMALL_STATE(16638)] = 656305,
  [SMALL_STATE(16639)] = 656319,
  [SMALL_STATE(16640)] = 656333,
  [SMALL_STATE(16641)] = 656347,
  [SMALL_STATE(16642)] = 656361,
  [SMALL_STATE(16643)] = 656375,
  [SMALL_STATE(16644)] = 656389,
  [SMALL_STATE(16645)] = 656403,
  [SMALL_STATE(16646)] = 656417,
  [SMALL_STATE(16647)] = 656431,
  [SMALL_STATE(16648)] = 656445,
  [SMALL_STATE(16649)] = 656459,
  [SMALL_STATE(16650)] = 656473,
  [SMALL_STATE(16651)] = 656487,
  [SMALL_STATE(16652)] = 656501,
  [SMALL_STATE(16653)] = 656515,
  [SMALL_STATE(16654)] = 656529,
  [SMALL_STATE(16655)] = 656543,
  [SMALL_STATE(16656)] = 656557,
  [SMALL_STATE(16657)] = 656571,
  [SMALL_STATE(16658)] = 656585,
  [SMALL_STATE(16659)] = 656599,
  [SMALL_STATE(16660)] = 656613,
  [SMALL_STATE(16661)] = 656627,
  [SMALL_STATE(16662)] = 656641,
  [SMALL_STATE(16663)] = 656655,
  [SMALL_STATE(16664)] = 656669,
  [SMALL_STATE(16665)] = 656683,
  [SMALL_STATE(16666)] = 656697,
  [SMALL_STATE(16667)] = 656711,
  [SMALL_STATE(16668)] = 656725,
  [SMALL_STATE(16669)] = 656739,
  [SMALL_STATE(16670)] = 656753,
  [SMALL_STATE(16671)] = 656767,
  [SMALL_STATE(16672)] = 656781,
  [SMALL_STATE(16673)] = 656795,
  [SMALL_STATE(16674)] = 656809,
  [SMALL_STATE(16675)] = 656823,
  [SMALL_STATE(16676)] = 656837,
  [SMALL_STATE(16677)] = 656851,
  [SMALL_STATE(16678)] = 656865,
  [SMALL_STATE(16679)] = 656879,
  [SMALL_STATE(16680)] = 656893,
  [SMALL_STATE(16681)] = 656907,
  [SMALL_STATE(16682)] = 656921,
  [SMALL_STATE(16683)] = 656935,
  [SMALL_STATE(16684)] = 656949,
  [SMALL_STATE(16685)] = 656963,
  [SMALL_STATE(16686)] = 656977,
  [SMALL_STATE(16687)] = 656991,
  [SMALL_STATE(16688)] = 657005,
  [SMALL_STATE(16689)] = 657019,
  [SMALL_STATE(16690)] = 657033,
  [SMALL_STATE(16691)] = 657047,
  [SMALL_STATE(16692)] = 657061,
  [SMALL_STATE(16693)] = 657075,
  [SMALL_STATE(16694)] = 657089,
  [SMALL_STATE(16695)] = 657103,
  [SMALL_STATE(16696)] = 657117,
  [SMALL_STATE(16697)] = 657131,
  [SMALL_STATE(16698)] = 657145,
  [SMALL_STATE(16699)] = 657159,
  [SMALL_STATE(16700)] = 657173,
  [SMALL_STATE(16701)] = 657187,
  [SMALL_STATE(16702)] = 657201,
  [SMALL_STATE(16703)] = 657215,
  [SMALL_STATE(16704)] = 657229,
  [SMALL_STATE(16705)] = 657243,
  [SMALL_STATE(16706)] = 657257,
  [SMALL_STATE(16707)] = 657271,
  [SMALL_STATE(16708)] = 657285,
  [SMALL_STATE(16709)] = 657299,
  [SMALL_STATE(16710)] = 657313,
  [SMALL_STATE(16711)] = 657327,
  [SMALL_STATE(16712)] = 657341,
  [SMALL_STATE(16713)] = 657355,
  [SMALL_STATE(16714)] = 657369,
  [SMALL_STATE(16715)] = 657383,
  [SMALL_STATE(16716)] = 657397,
  [SMALL_STATE(16717)] = 657411,
  [SMALL_STATE(16718)] = 657425,
  [SMALL_STATE(16719)] = 657439,
  [SMALL_STATE(16720)] = 657453,
  [SMALL_STATE(16721)] = 657467,
  [SMALL_STATE(16722)] = 657481,
  [SMALL_STATE(16723)] = 657495,
  [SMALL_STATE(16724)] = 657509,
  [SMALL_STATE(16725)] = 657523,
  [SMALL_STATE(16726)] = 657537,
  [SMALL_STATE(16727)] = 657551,
  [SMALL_STATE(16728)] = 657565,
  [SMALL_STATE(16729)] = 657579,
  [SMALL_STATE(16730)] = 657593,
  [SMALL_STATE(16731)] = 657607,
  [SMALL_STATE(16732)] = 657621,
  [SMALL_STATE(16733)] = 657635,
  [SMALL_STATE(16734)] = 657649,
  [SMALL_STATE(16735)] = 657663,
  [SMALL_STATE(16736)] = 657677,
  [SMALL_STATE(16737)] = 657691,
  [SMALL_STATE(16738)] = 657705,
  [SMALL_STATE(16739)] = 657719,
  [SMALL_STATE(16740)] = 657733,
  [SMALL_STATE(16741)] = 657747,
  [SMALL_STATE(16742)] = 657761,
  [SMALL_STATE(16743)] = 657775,
  [SMALL_STATE(16744)] = 657789,
  [SMALL_STATE(16745)] = 657803,
  [SMALL_STATE(16746)] = 657817,
  [SMALL_STATE(16747)] = 657831,
  [SMALL_STATE(16748)] = 657845,
  [SMALL_STATE(16749)] = 657859,
  [SMALL_STATE(16750)] = 657873,
  [SMALL_STATE(16751)] = 657887,
  [SMALL_STATE(16752)] = 657901,
  [SMALL_STATE(16753)] = 657915,
  [SMALL_STATE(16754)] = 657929,
  [SMALL_STATE(16755)] = 657943,
  [SMALL_STATE(16756)] = 657957,
  [SMALL_STATE(16757)] = 657971,
  [SMALL_STATE(16758)] = 657985,
  [SMALL_STATE(16759)] = 657999,
  [SMALL_STATE(16760)] = 658013,
  [SMALL_STATE(16761)] = 658027,
  [SMALL_STATE(16762)] = 658041,
  [SMALL_STATE(16763)] = 658055,
  [SMALL_STATE(16764)] = 658069,
  [SMALL_STATE(16765)] = 658083,
  [SMALL_STATE(16766)] = 658097,
  [SMALL_STATE(16767)] = 658111,
  [SMALL_STATE(16768)] = 658125,
  [SMALL_STATE(16769)] = 658139,
  [SMALL_STATE(16770)] = 658153,
  [SMALL_STATE(16771)] = 658167,
  [SMALL_STATE(16772)] = 658181,
  [SMALL_STATE(16773)] = 658195,
  [SMALL_STATE(16774)] = 658209,
  [SMALL_STATE(16775)] = 658223,
  [SMALL_STATE(16776)] = 658237,
  [SMALL_STATE(16777)] = 658251,
  [SMALL_STATE(16778)] = 658265,
  [SMALL_STATE(16779)] = 658279,
  [SMALL_STATE(16780)] = 658293,
  [SMALL_STATE(16781)] = 658307,
  [SMALL_STATE(16782)] = 658321,
  [SMALL_STATE(16783)] = 658335,
  [SMALL_STATE(16784)] = 658349,
  [SMALL_STATE(16785)] = 658363,
  [SMALL_STATE(16786)] = 658377,
  [SMALL_STATE(16787)] = 658391,
  [SMALL_STATE(16788)] = 658405,
  [SMALL_STATE(16789)] = 658419,
  [SMALL_STATE(16790)] = 658433,
  [SMALL_STATE(16791)] = 658447,
  [SMALL_STATE(16792)] = 658461,
  [SMALL_STATE(16793)] = 658475,
  [SMALL_STATE(16794)] = 658489,
  [SMALL_STATE(16795)] = 658503,
  [SMALL_STATE(16796)] = 658517,
  [SMALL_STATE(16797)] = 658531,
  [SMALL_STATE(16798)] = 658545,
  [SMALL_STATE(16799)] = 658559,
  [SMALL_STATE(16800)] = 658573,
  [SMALL_STATE(16801)] = 658587,
  [SMALL_STATE(16802)] = 658601,
  [SMALL_STATE(16803)] = 658615,
  [SMALL_STATE(16804)] = 658629,
  [SMALL_STATE(16805)] = 658643,
  [SMALL_STATE(16806)] = 658657,
  [SMALL_STATE(16807)] = 658671,
  [SMALL_STATE(16808)] = 658685,
  [SMALL_STATE(16809)] = 658699,
  [SMALL_STATE(16810)] = 658713,
  [SMALL_STATE(16811)] = 658727,
  [SMALL_STATE(16812)] = 658741,
  [SMALL_STATE(16813)] = 658755,
  [SMALL_STATE(16814)] = 658769,
  [SMALL_STATE(16815)] = 658783,
  [SMALL_STATE(16816)] = 658797,
  [SMALL_STATE(16817)] = 658811,
  [SMALL_STATE(16818)] = 658825,
  [SMALL_STATE(16819)] = 658839,
  [SMALL_STATE(16820)] = 658853,
  [SMALL_STATE(16821)] = 658867,
  [SMALL_STATE(16822)] = 658881,
  [SMALL_STATE(16823)] = 658895,
  [SMALL_STATE(16824)] = 658909,
  [SMALL_STATE(16825)] = 658923,
  [SMALL_STATE(16826)] = 658937,
  [SMALL_STATE(16827)] = 658951,
  [SMALL_STATE(16828)] = 658965,
  [SMALL_STATE(16829)] = 658979,
  [SMALL_STATE(16830)] = 658993,
  [SMALL_STATE(16831)] = 659007,
  [SMALL_STATE(16832)] = 659021,
  [SMALL_STATE(16833)] = 659035,
  [SMALL_STATE(16834)] = 659049,
  [SMALL_STATE(16835)] = 659063,
  [SMALL_STATE(16836)] = 659077,
  [SMALL_STATE(16837)] = 659091,
  [SMALL_STATE(16838)] = 659105,
  [SMALL_STATE(16839)] = 659119,
  [SMALL_STATE(16840)] = 659133,
  [SMALL_STATE(16841)] = 659147,
  [SMALL_STATE(16842)] = 659161,
  [SMALL_STATE(16843)] = 659175,
  [SMALL_STATE(16844)] = 659189,
  [SMALL_STATE(16845)] = 659203,
  [SMALL_STATE(16846)] = 659217,
  [SMALL_STATE(16847)] = 659231,
  [SMALL_STATE(16848)] = 659245,
  [SMALL_STATE(16849)] = 659259,
  [SMALL_STATE(16850)] = 659273,
  [SMALL_STATE(16851)] = 659287,
  [SMALL_STATE(16852)] = 659301,
  [SMALL_STATE(16853)] = 659315,
  [SMALL_STATE(16854)] = 659329,
  [SMALL_STATE(16855)] = 659343,
  [SMALL_STATE(16856)] = 659357,
  [SMALL_STATE(16857)] = 659371,
  [SMALL_STATE(16858)] = 659385,
  [SMALL_STATE(16859)] = 659399,
  [SMALL_STATE(16860)] = 659413,
  [SMALL_STATE(16861)] = 659427,
  [SMALL_STATE(16862)] = 659441,
  [SMALL_STATE(16863)] = 659455,
  [SMALL_STATE(16864)] = 659469,
  [SMALL_STATE(16865)] = 659483,
  [SMALL_STATE(16866)] = 659497,
  [SMALL_STATE(16867)] = 659511,
  [SMALL_STATE(16868)] = 659525,
  [SMALL_STATE(16869)] = 659539,
  [SMALL_STATE(16870)] = 659553,
  [SMALL_STATE(16871)] = 659567,
  [SMALL_STATE(16872)] = 659581,
  [SMALL_STATE(16873)] = 659595,
  [SMALL_STATE(16874)] = 659609,
  [SMALL_STATE(16875)] = 659623,
  [SMALL_STATE(16876)] = 659637,
  [SMALL_STATE(16877)] = 659651,
  [SMALL_STATE(16878)] = 659665,
  [SMALL_STATE(16879)] = 659679,
  [SMALL_STATE(16880)] = 659693,
  [SMALL_STATE(16881)] = 659707,
  [SMALL_STATE(16882)] = 659721,
  [SMALL_STATE(16883)] = 659735,
  [SMALL_STATE(16884)] = 659749,
  [SMALL_STATE(16885)] = 659763,
  [SMALL_STATE(16886)] = 659777,
  [SMALL_STATE(16887)] = 659791,
  [SMALL_STATE(16888)] = 659805,
  [SMALL_STATE(16889)] = 659819,
  [SMALL_STATE(16890)] = 659833,
  [SMALL_STATE(16891)] = 659847,
  [SMALL_STATE(16892)] = 659861,
  [SMALL_STATE(16893)] = 659875,
  [SMALL_STATE(16894)] = 659889,
  [SMALL_STATE(16895)] = 659903,
  [SMALL_STATE(16896)] = 659917,
  [SMALL_STATE(16897)] = 659931,
  [SMALL_STATE(16898)] = 659945,
  [SMALL_STATE(16899)] = 659959,
  [SMALL_STATE(16900)] = 659973,
  [SMALL_STATE(16901)] = 659987,
  [SMALL_STATE(16902)] = 660001,
  [SMALL_STATE(16903)] = 660015,
  [SMALL_STATE(16904)] = 660029,
  [SMALL_STATE(16905)] = 660043,
  [SMALL_STATE(16906)] = 660057,
  [SMALL_STATE(16907)] = 660071,
  [SMALL_STATE(16908)] = 660085,
  [SMALL_STATE(16909)] = 660099,
  [SMALL_STATE(16910)] = 660113,
  [SMALL_STATE(16911)] = 660127,
  [SMALL_STATE(16912)] = 660141,
  [SMALL_STATE(16913)] = 660155,
  [SMALL_STATE(16914)] = 660169,
  [SMALL_STATE(16915)] = 660183,
  [SMALL_STATE(16916)] = 660197,
  [SMALL_STATE(16917)] = 660211,
  [SMALL_STATE(16918)] = 660225,
  [SMALL_STATE(16919)] = 660239,
  [SMALL_STATE(16920)] = 660253,
  [SMALL_STATE(16921)] = 660267,
  [SMALL_STATE(16922)] = 660281,
  [SMALL_STATE(16923)] = 660295,
  [SMALL_STATE(16924)] = 660309,
  [SMALL_STATE(16925)] = 660323,
  [SMALL_STATE(16926)] = 660337,
  [SMALL_STATE(16927)] = 660351,
  [SMALL_STATE(16928)] = 660365,
  [SMALL_STATE(16929)] = 660379,
  [SMALL_STATE(16930)] = 660393,
  [SMALL_STATE(16931)] = 660407,
  [SMALL_STATE(16932)] = 660421,
  [SMALL_STATE(16933)] = 660435,
  [SMALL_STATE(16934)] = 660449,
  [SMALL_STATE(16935)] = 660463,
  [SMALL_STATE(16936)] = 660477,
  [SMALL_STATE(16937)] = 660491,
  [SMALL_STATE(16938)] = 660505,
  [SMALL_STATE(16939)] = 660519,
  [SMALL_STATE(16940)] = 660533,
  [SMALL_STATE(16941)] = 660547,
  [SMALL_STATE(16942)] = 660561,
  [SMALL_STATE(16943)] = 660575,
  [SMALL_STATE(16944)] = 660589,
  [SMALL_STATE(16945)] = 660603,
  [SMALL_STATE(16946)] = 660617,
  [SMALL_STATE(16947)] = 660631,
  [SMALL_STATE(16948)] = 660645,
  [SMALL_STATE(16949)] = 660659,
  [SMALL_STATE(16950)] = 660673,
  [SMALL_STATE(16951)] = 660687,
  [SMALL_STATE(16952)] = 660701,
  [SMALL_STATE(16953)] = 660715,
  [SMALL_STATE(16954)] = 660729,
  [SMALL_STATE(16955)] = 660743,
  [SMALL_STATE(16956)] = 660757,
  [SMALL_STATE(16957)] = 660771,
  [SMALL_STATE(16958)] = 660785,
  [SMALL_STATE(16959)] = 660799,
  [SMALL_STATE(16960)] = 660813,
  [SMALL_STATE(16961)] = 660827,
  [SMALL_STATE(16962)] = 660841,
  [SMALL_STATE(16963)] = 660855,
  [SMALL_STATE(16964)] = 660869,
  [SMALL_STATE(16965)] = 660883,
  [SMALL_STATE(16966)] = 660897,
  [SMALL_STATE(16967)] = 660911,
  [SMALL_STATE(16968)] = 660925,
  [SMALL_STATE(16969)] = 660939,
  [SMALL_STATE(16970)] = 660953,
  [SMALL_STATE(16971)] = 660967,
  [SMALL_STATE(16972)] = 660981,
  [SMALL_STATE(16973)] = 660995,
  [SMALL_STATE(16974)] = 661009,
  [SMALL_STATE(16975)] = 661023,
  [SMALL_STATE(16976)] = 661037,
  [SMALL_STATE(16977)] = 661051,
  [SMALL_STATE(16978)] = 661065,
  [SMALL_STATE(16979)] = 661079,
  [SMALL_STATE(16980)] = 661093,
  [SMALL_STATE(16981)] = 661107,
  [SMALL_STATE(16982)] = 661121,
  [SMALL_STATE(16983)] = 661135,
  [SMALL_STATE(16984)] = 661149,
  [SMALL_STATE(16985)] = 661163,
  [SMALL_STATE(16986)] = 661177,
  [SMALL_STATE(16987)] = 661191,
  [SMALL_STATE(16988)] = 661205,
  [SMALL_STATE(16989)] = 661219,
  [SMALL_STATE(16990)] = 661233,
  [SMALL_STATE(16991)] = 661247,
  [SMALL_STATE(16992)] = 661261,
  [SMALL_STATE(16993)] = 661275,
  [SMALL_STATE(16994)] = 661289,
  [SMALL_STATE(16995)] = 661303,
  [SMALL_STATE(16996)] = 661317,
  [SMALL_STATE(16997)] = 661331,
  [SMALL_STATE(16998)] = 661345,
  [SMALL_STATE(16999)] = 661359,
  [SMALL_STATE(17000)] = 661373,
  [SMALL_STATE(17001)] = 661387,
  [SMALL_STATE(17002)] = 661401,
  [SMALL_STATE(17003)] = 661415,
  [SMALL_STATE(17004)] = 661429,
  [SMALL_STATE(17005)] = 661443,
  [SMALL_STATE(17006)] = 661457,
  [SMALL_STATE(17007)] = 661471,
  [SMALL_STATE(17008)] = 661485,
  [SMALL_STATE(17009)] = 661499,
  [SMALL_STATE(17010)] = 661513,
  [SMALL_STATE(17011)] = 661527,
  [SMALL_STATE(17012)] = 661541,
  [SMALL_STATE(17013)] = 661555,
  [SMALL_STATE(17014)] = 661569,
  [SMALL_STATE(17015)] = 661583,
  [SMALL_STATE(17016)] = 661597,
  [SMALL_STATE(17017)] = 661611,
  [SMALL_STATE(17018)] = 661625,
  [SMALL_STATE(17019)] = 661639,
  [SMALL_STATE(17020)] = 661653,
  [SMALL_STATE(17021)] = 661667,
  [SMALL_STATE(17022)] = 661681,
  [SMALL_STATE(17023)] = 661695,
  [SMALL_STATE(17024)] = 661709,
  [SMALL_STATE(17025)] = 661723,
  [SMALL_STATE(17026)] = 661737,
  [SMALL_STATE(17027)] = 661751,
  [SMALL_STATE(17028)] = 661765,
  [SMALL_STATE(17029)] = 661779,
  [SMALL_STATE(17030)] = 661793,
  [SMALL_STATE(17031)] = 661807,
  [SMALL_STATE(17032)] = 661821,
  [SMALL_STATE(17033)] = 661835,
  [SMALL_STATE(17034)] = 661849,
  [SMALL_STATE(17035)] = 661863,
  [SMALL_STATE(17036)] = 661877,
  [SMALL_STATE(17037)] = 661891,
  [SMALL_STATE(17038)] = 661905,
  [SMALL_STATE(17039)] = 661919,
  [SMALL_STATE(17040)] = 661933,
  [SMALL_STATE(17041)] = 661947,
  [SMALL_STATE(17042)] = 661961,
  [SMALL_STATE(17043)] = 661975,
  [SMALL_STATE(17044)] = 661989,
  [SMALL_STATE(17045)] = 662003,
  [SMALL_STATE(17046)] = 662017,
  [SMALL_STATE(17047)] = 662031,
  [SMALL_STATE(17048)] = 662045,
  [SMALL_STATE(17049)] = 662059,
  [SMALL_STATE(17050)] = 662073,
  [SMALL_STATE(17051)] = 662087,
  [SMALL_STATE(17052)] = 662101,
  [SMALL_STATE(17053)] = 662115,
  [SMALL_STATE(17054)] = 662129,
  [SMALL_STATE(17055)] = 662143,
  [SMALL_STATE(17056)] = 662157,
  [SMALL_STATE(17057)] = 662171,
  [SMALL_STATE(17058)] = 662185,
  [SMALL_STATE(17059)] = 662199,
  [SMALL_STATE(17060)] = 662213,
  [SMALL_STATE(17061)] = 662227,
  [SMALL_STATE(17062)] = 662241,
  [SMALL_STATE(17063)] = 662255,
  [SMALL_STATE(17064)] = 662269,
  [SMALL_STATE(17065)] = 662283,
  [SMALL_STATE(17066)] = 662297,
  [SMALL_STATE(17067)] = 662311,
  [SMALL_STATE(17068)] = 662325,
  [SMALL_STATE(17069)] = 662339,
  [SMALL_STATE(17070)] = 662353,
  [SMALL_STATE(17071)] = 662367,
  [SMALL_STATE(17072)] = 662381,
  [SMALL_STATE(17073)] = 662395,
  [SMALL_STATE(17074)] = 662409,
  [SMALL_STATE(17075)] = 662423,
  [SMALL_STATE(17076)] = 662437,
  [SMALL_STATE(17077)] = 662451,
  [SMALL_STATE(17078)] = 662465,
  [SMALL_STATE(17079)] = 662479,
  [SMALL_STATE(17080)] = 662493,
  [SMALL_STATE(17081)] = 662507,
  [SMALL_STATE(17082)] = 662521,
  [SMALL_STATE(17083)] = 662535,
  [SMALL_STATE(17084)] = 662549,
  [SMALL_STATE(17085)] = 662563,
  [SMALL_STATE(17086)] = 662577,
  [SMALL_STATE(17087)] = 662591,
  [SMALL_STATE(17088)] = 662605,
  [SMALL_STATE(17089)] = 662619,
  [SMALL_STATE(17090)] = 662633,
  [SMALL_STATE(17091)] = 662647,
  [SMALL_STATE(17092)] = 662661,
  [SMALL_STATE(17093)] = 662675,
  [SMALL_STATE(17094)] = 662689,
  [SMALL_STATE(17095)] = 662703,
  [SMALL_STATE(17096)] = 662717,
  [SMALL_STATE(17097)] = 662731,
  [SMALL_STATE(17098)] = 662745,
  [SMALL_STATE(17099)] = 662759,
  [SMALL_STATE(17100)] = 662773,
  [SMALL_STATE(17101)] = 662787,
  [SMALL_STATE(17102)] = 662801,
  [SMALL_STATE(17103)] = 662815,
  [SMALL_STATE(17104)] = 662829,
  [SMALL_STATE(17105)] = 662843,
  [SMALL_STATE(17106)] = 662857,
  [SMALL_STATE(17107)] = 662871,
  [SMALL_STATE(17108)] = 662885,
  [SMALL_STATE(17109)] = 662899,
  [SMALL_STATE(17110)] = 662913,
  [SMALL_STATE(17111)] = 662927,
  [SMALL_STATE(17112)] = 662941,
  [SMALL_STATE(17113)] = 662955,
  [SMALL_STATE(17114)] = 662969,
  [SMALL_STATE(17115)] = 662983,
  [SMALL_STATE(17116)] = 662997,
  [SMALL_STATE(17117)] = 663011,
  [SMALL_STATE(17118)] = 663025,
  [SMALL_STATE(17119)] = 663039,
  [SMALL_STATE(17120)] = 663053,
  [SMALL_STATE(17121)] = 663067,
  [SMALL_STATE(17122)] = 663081,
  [SMALL_STATE(17123)] = 663095,
  [SMALL_STATE(17124)] = 663109,
  [SMALL_STATE(17125)] = 663123,
  [SMALL_STATE(17126)] = 663137,
  [SMALL_STATE(17127)] = 663151,
  [SMALL_STATE(17128)] = 663165,
  [SMALL_STATE(17129)] = 663179,
  [SMALL_STATE(17130)] = 663193,
  [SMALL_STATE(17131)] = 663207,
  [SMALL_STATE(17132)] = 663221,
  [SMALL_STATE(17133)] = 663235,
  [SMALL_STATE(17134)] = 663249,
  [SMALL_STATE(17135)] = 663263,
  [SMALL_STATE(17136)] = 663277,
  [SMALL_STATE(17137)] = 663291,
  [SMALL_STATE(17138)] = 663305,
  [SMALL_STATE(17139)] = 663319,
  [SMALL_STATE(17140)] = 663333,
  [SMALL_STATE(17141)] = 663347,
  [SMALL_STATE(17142)] = 663361,
  [SMALL_STATE(17143)] = 663375,
  [SMALL_STATE(17144)] = 663389,
  [SMALL_STATE(17145)] = 663403,
  [SMALL_STATE(17146)] = 663417,
  [SMALL_STATE(17147)] = 663431,
  [SMALL_STATE(17148)] = 663445,
  [SMALL_STATE(17149)] = 663459,
  [SMALL_STATE(17150)] = 663473,
  [SMALL_STATE(17151)] = 663487,
  [SMALL_STATE(17152)] = 663501,
  [SMALL_STATE(17153)] = 663515,
  [SMALL_STATE(17154)] = 663529,
  [SMALL_STATE(17155)] = 663543,
  [SMALL_STATE(17156)] = 663557,
  [SMALL_STATE(17157)] = 663571,
  [SMALL_STATE(17158)] = 663585,
  [SMALL_STATE(17159)] = 663599,
  [SMALL_STATE(17160)] = 663613,
  [SMALL_STATE(17161)] = 663627,
  [SMALL_STATE(17162)] = 663641,
  [SMALL_STATE(17163)] = 663655,
  [SMALL_STATE(17164)] = 663669,
  [SMALL_STATE(17165)] = 663683,
  [SMALL_STATE(17166)] = 663697,
  [SMALL_STATE(17167)] = 663711,
  [SMALL_STATE(17168)] = 663725,
  [SMALL_STATE(17169)] = 663739,
  [SMALL_STATE(17170)] = 663753,
  [SMALL_STATE(17171)] = 663767,
  [SMALL_STATE(17172)] = 663781,
  [SMALL_STATE(17173)] = 663795,
  [SMALL_STATE(17174)] = 663809,
  [SMALL_STATE(17175)] = 663823,
  [SMALL_STATE(17176)] = 663837,
  [SMALL_STATE(17177)] = 663851,
  [SMALL_STATE(17178)] = 663865,
  [SMALL_STATE(17179)] = 663879,
  [SMALL_STATE(17180)] = 663893,
  [SMALL_STATE(17181)] = 663907,
  [SMALL_STATE(17182)] = 663921,
  [SMALL_STATE(17183)] = 663935,
  [SMALL_STATE(17184)] = 663949,
  [SMALL_STATE(17185)] = 663963,
  [SMALL_STATE(17186)] = 663977,
  [SMALL_STATE(17187)] = 663991,
  [SMALL_STATE(17188)] = 664005,
  [SMALL_STATE(17189)] = 664019,
  [SMALL_STATE(17190)] = 664033,
  [SMALL_STATE(17191)] = 664047,
  [SMALL_STATE(17192)] = 664061,
  [SMALL_STATE(17193)] = 664075,
  [SMALL_STATE(17194)] = 664089,
  [SMALL_STATE(17195)] = 664103,
  [SMALL_STATE(17196)] = 664117,
  [SMALL_STATE(17197)] = 664131,
  [SMALL_STATE(17198)] = 664145,
  [SMALL_STATE(17199)] = 664159,
  [SMALL_STATE(17200)] = 664173,
  [SMALL_STATE(17201)] = 664187,
  [SMALL_STATE(17202)] = 664201,
  [SMALL_STATE(17203)] = 664215,
  [SMALL_STATE(17204)] = 664229,
  [SMALL_STATE(17205)] = 664243,
  [SMALL_STATE(17206)] = 664257,
  [SMALL_STATE(17207)] = 664271,
  [SMALL_STATE(17208)] = 664285,
  [SMALL_STATE(17209)] = 664299,
  [SMALL_STATE(17210)] = 664313,
  [SMALL_STATE(17211)] = 664327,
  [SMALL_STATE(17212)] = 664341,
  [SMALL_STATE(17213)] = 664355,
  [SMALL_STATE(17214)] = 664369,
  [SMALL_STATE(17215)] = 664383,
  [SMALL_STATE(17216)] = 664397,
  [SMALL_STATE(17217)] = 664411,
  [SMALL_STATE(17218)] = 664425,
  [SMALL_STATE(17219)] = 664439,
  [SMALL_STATE(17220)] = 664453,
  [SMALL_STATE(17221)] = 664467,
  [SMALL_STATE(17222)] = 664481,
  [SMALL_STATE(17223)] = 664495,
  [SMALL_STATE(17224)] = 664509,
  [SMALL_STATE(17225)] = 664523,
  [SMALL_STATE(17226)] = 664537,
  [SMALL_STATE(17227)] = 664551,
  [SMALL_STATE(17228)] = 664565,
  [SMALL_STATE(17229)] = 664579,
  [SMALL_STATE(17230)] = 664593,
  [SMALL_STATE(17231)] = 664607,
  [SMALL_STATE(17232)] = 664621,
  [SMALL_STATE(17233)] = 664635,
  [SMALL_STATE(17234)] = 664649,
  [SMALL_STATE(17235)] = 664663,
  [SMALL_STATE(17236)] = 664677,
  [SMALL_STATE(17237)] = 664691,
  [SMALL_STATE(17238)] = 664705,
  [SMALL_STATE(17239)] = 664719,
  [SMALL_STATE(17240)] = 664733,
  [SMALL_STATE(17241)] = 664747,
  [SMALL_STATE(17242)] = 664761,
  [SMALL_STATE(17243)] = 664775,
  [SMALL_STATE(17244)] = 664789,
  [SMALL_STATE(17245)] = 664803,
  [SMALL_STATE(17246)] = 664817,
  [SMALL_STATE(17247)] = 664831,
  [SMALL_STATE(17248)] = 664845,
  [SMALL_STATE(17249)] = 664859,
  [SMALL_STATE(17250)] = 664873,
  [SMALL_STATE(17251)] = 664887,
  [SMALL_STATE(17252)] = 664901,
  [SMALL_STATE(17253)] = 664915,
  [SMALL_STATE(17254)] = 664929,
  [SMALL_STATE(17255)] = 664943,
  [SMALL_STATE(17256)] = 664957,
  [SMALL_STATE(17257)] = 664971,
  [SMALL_STATE(17258)] = 664985,
  [SMALL_STATE(17259)] = 664999,
  [SMALL_STATE(17260)] = 665013,
  [SMALL_STATE(17261)] = 665027,
  [SMALL_STATE(17262)] = 665041,
  [SMALL_STATE(17263)] = 665055,
  [SMALL_STATE(17264)] = 665069,
  [SMALL_STATE(17265)] = 665083,
  [SMALL_STATE(17266)] = 665097,
  [SMALL_STATE(17267)] = 665111,
  [SMALL_STATE(17268)] = 665125,
  [SMALL_STATE(17269)] = 665139,
  [SMALL_STATE(17270)] = 665153,
  [SMALL_STATE(17271)] = 665167,
  [SMALL_STATE(17272)] = 665181,
  [SMALL_STATE(17273)] = 665195,
  [SMALL_STATE(17274)] = 665209,
  [SMALL_STATE(17275)] = 665223,
  [SMALL_STATE(17276)] = 665237,
  [SMALL_STATE(17277)] = 665251,
  [SMALL_STATE(17278)] = 665265,
  [SMALL_STATE(17279)] = 665279,
  [SMALL_STATE(17280)] = 665293,
  [SMALL_STATE(17281)] = 665307,
  [SMALL_STATE(17282)] = 665321,
  [SMALL_STATE(17283)] = 665335,
  [SMALL_STATE(17284)] = 665349,
  [SMALL_STATE(17285)] = 665363,
  [SMALL_STATE(17286)] = 665377,
  [SMALL_STATE(17287)] = 665391,
  [SMALL_STATE(17288)] = 665405,
  [SMALL_STATE(17289)] = 665419,
  [SMALL_STATE(17290)] = 665433,
  [SMALL_STATE(17291)] = 665447,
  [SMALL_STATE(17292)] = 665461,
  [SMALL_STATE(17293)] = 665475,
  [SMALL_STATE(17294)] = 665489,
  [SMALL_STATE(17295)] = 665503,
  [SMALL_STATE(17296)] = 665517,
  [SMALL_STATE(17297)] = 665531,
  [SMALL_STATE(17298)] = 665545,
  [SMALL_STATE(17299)] = 665559,
  [SMALL_STATE(17300)] = 665573,
  [SMALL_STATE(17301)] = 665587,
  [SMALL_STATE(17302)] = 665601,
  [SMALL_STATE(17303)] = 665615,
  [SMALL_STATE(17304)] = 665629,
  [SMALL_STATE(17305)] = 665643,
  [SMALL_STATE(17306)] = 665657,
  [SMALL_STATE(17307)] = 665671,
  [SMALL_STATE(17308)] = 665685,
  [SMALL_STATE(17309)] = 665699,
  [SMALL_STATE(17310)] = 665713,
  [SMALL_STATE(17311)] = 665727,
  [SMALL_STATE(17312)] = 665741,
  [SMALL_STATE(17313)] = 665755,
  [SMALL_STATE(17314)] = 665769,
  [SMALL_STATE(17315)] = 665783,
  [SMALL_STATE(17316)] = 665797,
  [SMALL_STATE(17317)] = 665811,
  [SMALL_STATE(17318)] = 665825,
  [SMALL_STATE(17319)] = 665839,
  [SMALL_STATE(17320)] = 665853,
  [SMALL_STATE(17321)] = 665867,
  [SMALL_STATE(17322)] = 665881,
  [SMALL_STATE(17323)] = 665895,
  [SMALL_STATE(17324)] = 665909,
  [SMALL_STATE(17325)] = 665923,
  [SMALL_STATE(17326)] = 665937,
  [SMALL_STATE(17327)] = 665951,
  [SMALL_STATE(17328)] = 665965,
  [SMALL_STATE(17329)] = 665979,
  [SMALL_STATE(17330)] = 665993,
  [SMALL_STATE(17331)] = 666007,
  [SMALL_STATE(17332)] = 666021,
  [SMALL_STATE(17333)] = 666035,
  [SMALL_STATE(17334)] = 666049,
  [SMALL_STATE(17335)] = 666063,
  [SMALL_STATE(17336)] = 666077,
  [SMALL_STATE(17337)] = 666091,
  [SMALL_STATE(17338)] = 666105,
  [SMALL_STATE(17339)] = 666119,
  [SMALL_STATE(17340)] = 666133,
  [SMALL_STATE(17341)] = 666147,
  [SMALL_STATE(17342)] = 666161,
  [SMALL_STATE(17343)] = 666175,
  [SMALL_STATE(17344)] = 666189,
  [SMALL_STATE(17345)] = 666203,
  [SMALL_STATE(17346)] = 666217,
  [SMALL_STATE(17347)] = 666231,
  [SMALL_STATE(17348)] = 666245,
  [SMALL_STATE(17349)] = 666259,
  [SMALL_STATE(17350)] = 666273,
  [SMALL_STATE(17351)] = 666287,
  [SMALL_STATE(17352)] = 666301,
  [SMALL_STATE(17353)] = 666315,
  [SMALL_STATE(17354)] = 666329,
  [SMALL_STATE(17355)] = 666343,
  [SMALL_STATE(17356)] = 666357,
  [SMALL_STATE(17357)] = 666371,
  [SMALL_STATE(17358)] = 666385,
  [SMALL_STATE(17359)] = 666399,
  [SMALL_STATE(17360)] = 666413,
  [SMALL_STATE(17361)] = 666427,
  [SMALL_STATE(17362)] = 666441,
  [SMALL_STATE(17363)] = 666455,
  [SMALL_STATE(17364)] = 666469,
  [SMALL_STATE(17365)] = 666483,
  [SMALL_STATE(17366)] = 666497,
  [SMALL_STATE(17367)] = 666511,
  [SMALL_STATE(17368)] = 666525,
  [SMALL_STATE(17369)] = 666539,
  [SMALL_STATE(17370)] = 666553,
  [SMALL_STATE(17371)] = 666567,
  [SMALL_STATE(17372)] = 666581,
  [SMALL_STATE(17373)] = 666595,
  [SMALL_STATE(17374)] = 666609,
  [SMALL_STATE(17375)] = 666623,
  [SMALL_STATE(17376)] = 666637,
  [SMALL_STATE(17377)] = 666651,
  [SMALL_STATE(17378)] = 666665,
  [SMALL_STATE(17379)] = 666679,
  [SMALL_STATE(17380)] = 666693,
  [SMALL_STATE(17381)] = 666707,
  [SMALL_STATE(17382)] = 666721,
  [SMALL_STATE(17383)] = 666735,
  [SMALL_STATE(17384)] = 666749,
  [SMALL_STATE(17385)] = 666763,
  [SMALL_STATE(17386)] = 666777,
  [SMALL_STATE(17387)] = 666791,
  [SMALL_STATE(17388)] = 666805,
  [SMALL_STATE(17389)] = 666819,
  [SMALL_STATE(17390)] = 666833,
  [SMALL_STATE(17391)] = 666847,
  [SMALL_STATE(17392)] = 666861,
  [SMALL_STATE(17393)] = 666875,
  [SMALL_STATE(17394)] = 666889,
  [SMALL_STATE(17395)] = 666903,
  [SMALL_STATE(17396)] = 666917,
  [SMALL_STATE(17397)] = 666931,
  [SMALL_STATE(17398)] = 666945,
  [SMALL_STATE(17399)] = 666959,
  [SMALL_STATE(17400)] = 666973,
  [SMALL_STATE(17401)] = 666987,
  [SMALL_STATE(17402)] = 667001,
  [SMALL_STATE(17403)] = 667015,
  [SMALL_STATE(17404)] = 667029,
  [SMALL_STATE(17405)] = 667043,
  [SMALL_STATE(17406)] = 667057,
  [SMALL_STATE(17407)] = 667071,
  [SMALL_STATE(17408)] = 667085,
  [SMALL_STATE(17409)] = 667099,
  [SMALL_STATE(17410)] = 667113,
  [SMALL_STATE(17411)] = 667127,
  [SMALL_STATE(17412)] = 667141,
  [SMALL_STATE(17413)] = 667155,
  [SMALL_STATE(17414)] = 667169,
  [SMALL_STATE(17415)] = 667183,
  [SMALL_STATE(17416)] = 667197,
  [SMALL_STATE(17417)] = 667211,
  [SMALL_STATE(17418)] = 667225,
  [SMALL_STATE(17419)] = 667239,
  [SMALL_STATE(17420)] = 667253,
  [SMALL_STATE(17421)] = 667267,
  [SMALL_STATE(17422)] = 667281,
  [SMALL_STATE(17423)] = 667295,
  [SMALL_STATE(17424)] = 667309,
  [SMALL_STATE(17425)] = 667323,
  [SMALL_STATE(17426)] = 667337,
  [SMALL_STATE(17427)] = 667351,
  [SMALL_STATE(17428)] = 667365,
  [SMALL_STATE(17429)] = 667379,
  [SMALL_STATE(17430)] = 667393,
  [SMALL_STATE(17431)] = 667407,
  [SMALL_STATE(17432)] = 667421,
  [SMALL_STATE(17433)] = 667435,
  [SMALL_STATE(17434)] = 667449,
  [SMALL_STATE(17435)] = 667463,
  [SMALL_STATE(17436)] = 667477,
  [SMALL_STATE(17437)] = 667491,
  [SMALL_STATE(17438)] = 667505,
  [SMALL_STATE(17439)] = 667519,
  [SMALL_STATE(17440)] = 667533,
  [SMALL_STATE(17441)] = 667547,
  [SMALL_STATE(17442)] = 667561,
  [SMALL_STATE(17443)] = 667575,
  [SMALL_STATE(17444)] = 667589,
  [SMALL_STATE(17445)] = 667603,
  [SMALL_STATE(17446)] = 667617,
  [SMALL_STATE(17447)] = 667631,
  [SMALL_STATE(17448)] = 667645,
  [SMALL_STATE(17449)] = 667659,
  [SMALL_STATE(17450)] = 667673,
  [SMALL_STATE(17451)] = 667687,
  [SMALL_STATE(17452)] = 667701,
  [SMALL_STATE(17453)] = 667715,
  [SMALL_STATE(17454)] = 667729,
  [SMALL_STATE(17455)] = 667743,
  [SMALL_STATE(17456)] = 667757,
  [SMALL_STATE(17457)] = 667771,
  [SMALL_STATE(17458)] = 667785,
  [SMALL_STATE(17459)] = 667799,
  [SMALL_STATE(17460)] = 667813,
  [SMALL_STATE(17461)] = 667827,
  [SMALL_STATE(17462)] = 667841,
  [SMALL_STATE(17463)] = 667855,
  [SMALL_STATE(17464)] = 667869,
  [SMALL_STATE(17465)] = 667883,
  [SMALL_STATE(17466)] = 667897,
  [SMALL_STATE(17467)] = 667911,
  [SMALL_STATE(17468)] = 667925,
  [SMALL_STATE(17469)] = 667939,
  [SMALL_STATE(17470)] = 667953,
  [SMALL_STATE(17471)] = 667967,
  [SMALL_STATE(17472)] = 667981,
  [SMALL_STATE(17473)] = 667995,
  [SMALL_STATE(17474)] = 668009,
  [SMALL_STATE(17475)] = 668023,
  [SMALL_STATE(17476)] = 668037,
  [SMALL_STATE(17477)] = 668051,
  [SMALL_STATE(17478)] = 668065,
  [SMALL_STATE(17479)] = 668079,
  [SMALL_STATE(17480)] = 668093,
  [SMALL_STATE(17481)] = 668107,
  [SMALL_STATE(17482)] = 668121,
  [SMALL_STATE(17483)] = 668135,
  [SMALL_STATE(17484)] = 668149,
  [SMALL_STATE(17485)] = 668163,
  [SMALL_STATE(17486)] = 668177,
  [SMALL_STATE(17487)] = 668191,
  [SMALL_STATE(17488)] = 668205,
  [SMALL_STATE(17489)] = 668219,
  [SMALL_STATE(17490)] = 668233,
  [SMALL_STATE(17491)] = 668247,
  [SMALL_STATE(17492)] = 668261,
  [SMALL_STATE(17493)] = 668275,
  [SMALL_STATE(17494)] = 668289,
  [SMALL_STATE(17495)] = 668303,
  [SMALL_STATE(17496)] = 668317,
  [SMALL_STATE(17497)] = 668331,
  [SMALL_STATE(17498)] = 668345,
  [SMALL_STATE(17499)] = 668359,
  [SMALL_STATE(17500)] = 668373,
  [SMALL_STATE(17501)] = 668387,
  [SMALL_STATE(17502)] = 668401,
  [SMALL_STATE(17503)] = 668415,
  [SMALL_STATE(17504)] = 668429,
  [SMALL_STATE(17505)] = 668443,
  [SMALL_STATE(17506)] = 668457,
  [SMALL_STATE(17507)] = 668471,
  [SMALL_STATE(17508)] = 668485,
  [SMALL_STATE(17509)] = 668499,
  [SMALL_STATE(17510)] = 668513,
  [SMALL_STATE(17511)] = 668527,
  [SMALL_STATE(17512)] = 668541,
  [SMALL_STATE(17513)] = 668555,
  [SMALL_STATE(17514)] = 668569,
  [SMALL_STATE(17515)] = 668583,
  [SMALL_STATE(17516)] = 668597,
  [SMALL_STATE(17517)] = 668611,
  [SMALL_STATE(17518)] = 668625,
  [SMALL_STATE(17519)] = 668639,
  [SMALL_STATE(17520)] = 668653,
  [SMALL_STATE(17521)] = 668667,
  [SMALL_STATE(17522)] = 668681,
  [SMALL_STATE(17523)] = 668695,
  [SMALL_STATE(17524)] = 668709,
  [SMALL_STATE(17525)] = 668723,
  [SMALL_STATE(17526)] = 668737,
  [SMALL_STATE(17527)] = 668751,
  [SMALL_STATE(17528)] = 668765,
  [SMALL_STATE(17529)] = 668779,
  [SMALL_STATE(17530)] = 668793,
  [SMALL_STATE(17531)] = 668807,
  [SMALL_STATE(17532)] = 668821,
  [SMALL_STATE(17533)] = 668835,
  [SMALL_STATE(17534)] = 668849,
  [SMALL_STATE(17535)] = 668863,
  [SMALL_STATE(17536)] = 668877,
  [SMALL_STATE(17537)] = 668891,
  [SMALL_STATE(17538)] = 668905,
  [SMALL_STATE(17539)] = 668919,
  [SMALL_STATE(17540)] = 668933,
  [SMALL_STATE(17541)] = 668947,
  [SMALL_STATE(17542)] = 668961,
  [SMALL_STATE(17543)] = 668975,
  [SMALL_STATE(17544)] = 668989,
  [SMALL_STATE(17545)] = 669003,
  [SMALL_STATE(17546)] = 669017,
  [SMALL_STATE(17547)] = 669031,
  [SMALL_STATE(17548)] = 669045,
  [SMALL_STATE(17549)] = 669059,
  [SMALL_STATE(17550)] = 669073,
  [SMALL_STATE(17551)] = 669087,
  [SMALL_STATE(17552)] = 669101,
  [SMALL_STATE(17553)] = 669115,
  [SMALL_STATE(17554)] = 669129,
  [SMALL_STATE(17555)] = 669143,
  [SMALL_STATE(17556)] = 669157,
  [SMALL_STATE(17557)] = 669171,
  [SMALL_STATE(17558)] = 669185,
  [SMALL_STATE(17559)] = 669199,
  [SMALL_STATE(17560)] = 669213,
  [SMALL_STATE(17561)] = 669227,
  [SMALL_STATE(17562)] = 669241,
  [SMALL_STATE(17563)] = 669255,
  [SMALL_STATE(17564)] = 669269,
  [SMALL_STATE(17565)] = 669283,
  [SMALL_STATE(17566)] = 669297,
  [SMALL_STATE(17567)] = 669311,
  [SMALL_STATE(17568)] = 669325,
  [SMALL_STATE(17569)] = 669339,
  [SMALL_STATE(17570)] = 669353,
  [SMALL_STATE(17571)] = 669367,
  [SMALL_STATE(17572)] = 669381,
  [SMALL_STATE(17573)] = 669395,
  [SMALL_STATE(17574)] = 669409,
  [SMALL_STATE(17575)] = 669423,
  [SMALL_STATE(17576)] = 669437,
  [SMALL_STATE(17577)] = 669451,
  [SMALL_STATE(17578)] = 669465,
  [SMALL_STATE(17579)] = 669479,
  [SMALL_STATE(17580)] = 669493,
  [SMALL_STATE(17581)] = 669507,
  [SMALL_STATE(17582)] = 669521,
  [SMALL_STATE(17583)] = 669535,
  [SMALL_STATE(17584)] = 669549,
  [SMALL_STATE(17585)] = 669563,
  [SMALL_STATE(17586)] = 669577,
  [SMALL_STATE(17587)] = 669591,
  [SMALL_STATE(17588)] = 669605,
  [SMALL_STATE(17589)] = 669619,
  [SMALL_STATE(17590)] = 669633,
  [SMALL_STATE(17591)] = 669647,
  [SMALL_STATE(17592)] = 669661,
  [SMALL_STATE(17593)] = 669675,
  [SMALL_STATE(17594)] = 669689,
  [SMALL_STATE(17595)] = 669703,
  [SMALL_STATE(17596)] = 669717,
  [SMALL_STATE(17597)] = 669731,
  [SMALL_STATE(17598)] = 669745,
  [SMALL_STATE(17599)] = 669759,
  [SMALL_STATE(17600)] = 669773,
  [SMALL_STATE(17601)] = 669787,
  [SMALL_STATE(17602)] = 669801,
  [SMALL_STATE(17603)] = 669815,
  [SMALL_STATE(17604)] = 669829,
  [SMALL_STATE(17605)] = 669843,
  [SMALL_STATE(17606)] = 669857,
  [SMALL_STATE(17607)] = 669871,
  [SMALL_STATE(17608)] = 669885,
  [SMALL_STATE(17609)] = 669899,
  [SMALL_STATE(17610)] = 669913,
  [SMALL_STATE(17611)] = 669927,
  [SMALL_STATE(17612)] = 669941,
  [SMALL_STATE(17613)] = 669955,
  [SMALL_STATE(17614)] = 669969,
  [SMALL_STATE(17615)] = 669983,
  [SMALL_STATE(17616)] = 669997,
  [SMALL_STATE(17617)] = 670011,
  [SMALL_STATE(17618)] = 670025,
  [SMALL_STATE(17619)] = 670039,
  [SMALL_STATE(17620)] = 670053,
  [SMALL_STATE(17621)] = 670067,
  [SMALL_STATE(17622)] = 670081,
  [SMALL_STATE(17623)] = 670095,
  [SMALL_STATE(17624)] = 670109,
  [SMALL_STATE(17625)] = 670123,
  [SMALL_STATE(17626)] = 670137,
  [SMALL_STATE(17627)] = 670151,
  [SMALL_STATE(17628)] = 670165,
  [SMALL_STATE(17629)] = 670179,
  [SMALL_STATE(17630)] = 670193,
  [SMALL_STATE(17631)] = 670207,
  [SMALL_STATE(17632)] = 670221,
  [SMALL_STATE(17633)] = 670235,
  [SMALL_STATE(17634)] = 670249,
  [SMALL_STATE(17635)] = 670263,
  [SMALL_STATE(17636)] = 670277,
  [SMALL_STATE(17637)] = 670291,
  [SMALL_STATE(17638)] = 670305,
  [SMALL_STATE(17639)] = 670319,
  [SMALL_STATE(17640)] = 670333,
  [SMALL_STATE(17641)] = 670347,
  [SMALL_STATE(17642)] = 670361,
  [SMALL_STATE(17643)] = 670375,
  [SMALL_STATE(17644)] = 670389,
  [SMALL_STATE(17645)] = 670403,
  [SMALL_STATE(17646)] = 670417,
  [SMALL_STATE(17647)] = 670431,
  [SMALL_STATE(17648)] = 670445,
  [SMALL_STATE(17649)] = 670459,
  [SMALL_STATE(17650)] = 670473,
  [SMALL_STATE(17651)] = 670487,
  [SMALL_STATE(17652)] = 670501,
  [SMALL_STATE(17653)] = 670515,
  [SMALL_STATE(17654)] = 670529,
  [SMALL_STATE(17655)] = 670543,
  [SMALL_STATE(17656)] = 670557,
  [SMALL_STATE(17657)] = 670571,
  [SMALL_STATE(17658)] = 670585,
  [SMALL_STATE(17659)] = 670599,
  [SMALL_STATE(17660)] = 670613,
  [SMALL_STATE(17661)] = 670627,
  [SMALL_STATE(17662)] = 670641,
  [SMALL_STATE(17663)] = 670655,
  [SMALL_STATE(17664)] = 670669,
  [SMALL_STATE(17665)] = 670683,
  [SMALL_STATE(17666)] = 670697,
  [SMALL_STATE(17667)] = 670711,
  [SMALL_STATE(17668)] = 670725,
  [SMALL_STATE(17669)] = 670739,
  [SMALL_STATE(17670)] = 670753,
  [SMALL_STATE(17671)] = 670767,
  [SMALL_STATE(17672)] = 670781,
  [SMALL_STATE(17673)] = 670795,
  [SMALL_STATE(17674)] = 670809,
  [SMALL_STATE(17675)] = 670823,
  [SMALL_STATE(17676)] = 670837,
  [SMALL_STATE(17677)] = 670851,
  [SMALL_STATE(17678)] = 670865,
  [SMALL_STATE(17679)] = 670879,
  [SMALL_STATE(17680)] = 670893,
  [SMALL_STATE(17681)] = 670907,
  [SMALL_STATE(17682)] = 670921,
  [SMALL_STATE(17683)] = 670935,
  [SMALL_STATE(17684)] = 670949,
  [SMALL_STATE(17685)] = 670963,
  [SMALL_STATE(17686)] = 670977,
  [SMALL_STATE(17687)] = 670991,
  [SMALL_STATE(17688)] = 671005,
  [SMALL_STATE(17689)] = 671019,
  [SMALL_STATE(17690)] = 671033,
  [SMALL_STATE(17691)] = 671047,
  [SMALL_STATE(17692)] = 671061,
  [SMALL_STATE(17693)] = 671075,
  [SMALL_STATE(17694)] = 671089,
  [SMALL_STATE(17695)] = 671103,
  [SMALL_STATE(17696)] = 671117,
  [SMALL_STATE(17697)] = 671131,
  [SMALL_STATE(17698)] = 671145,
  [SMALL_STATE(17699)] = 671159,
  [SMALL_STATE(17700)] = 671173,
  [SMALL_STATE(17701)] = 671187,
  [SMALL_STATE(17702)] = 671201,
  [SMALL_STATE(17703)] = 671215,
  [SMALL_STATE(17704)] = 671229,
  [SMALL_STATE(17705)] = 671243,
  [SMALL_STATE(17706)] = 671257,
  [SMALL_STATE(17707)] = 671271,
  [SMALL_STATE(17708)] = 671285,
  [SMALL_STATE(17709)] = 671299,
  [SMALL_STATE(17710)] = 671313,
  [SMALL_STATE(17711)] = 671327,
  [SMALL_STATE(17712)] = 671341,
  [SMALL_STATE(17713)] = 671355,
  [SMALL_STATE(17714)] = 671369,
  [SMALL_STATE(17715)] = 671383,
  [SMALL_STATE(17716)] = 671397,
  [SMALL_STATE(17717)] = 671411,
  [SMALL_STATE(17718)] = 671425,
  [SMALL_STATE(17719)] = 671439,
  [SMALL_STATE(17720)] = 671453,
  [SMALL_STATE(17721)] = 671467,
  [SMALL_STATE(17722)] = 671481,
  [SMALL_STATE(17723)] = 671495,
  [SMALL_STATE(17724)] = 671509,
  [SMALL_STATE(17725)] = 671523,
  [SMALL_STATE(17726)] = 671537,
  [SMALL_STATE(17727)] = 671551,
  [SMALL_STATE(17728)] = 671565,
  [SMALL_STATE(17729)] = 671579,
  [SMALL_STATE(17730)] = 671593,
  [SMALL_STATE(17731)] = 671607,
  [SMALL_STATE(17732)] = 671621,
  [SMALL_STATE(17733)] = 671635,
  [SMALL_STATE(17734)] = 671649,
  [SMALL_STATE(17735)] = 671663,
  [SMALL_STATE(17736)] = 671677,
  [SMALL_STATE(17737)] = 671691,
  [SMALL_STATE(17738)] = 671705,
  [SMALL_STATE(17739)] = 671719,
  [SMALL_STATE(17740)] = 671733,
  [SMALL_STATE(17741)] = 671747,
  [SMALL_STATE(17742)] = 671761,
  [SMALL_STATE(17743)] = 671775,
  [SMALL_STATE(17744)] = 671789,
  [SMALL_STATE(17745)] = 671803,
  [SMALL_STATE(17746)] = 671817,
  [SMALL_STATE(17747)] = 671831,
  [SMALL_STATE(17748)] = 671845,
  [SMALL_STATE(17749)] = 671859,
  [SMALL_STATE(17750)] = 671873,
  [SMALL_STATE(17751)] = 671887,
  [SMALL_STATE(17752)] = 671901,
  [SMALL_STATE(17753)] = 671915,
  [SMALL_STATE(17754)] = 671929,
  [SMALL_STATE(17755)] = 671943,
  [SMALL_STATE(17756)] = 671957,
  [SMALL_STATE(17757)] = 671971,
  [SMALL_STATE(17758)] = 671985,
  [SMALL_STATE(17759)] = 671999,
  [SMALL_STATE(17760)] = 672013,
  [SMALL_STATE(17761)] = 672027,
  [SMALL_STATE(17762)] = 672041,
  [SMALL_STATE(17763)] = 672055,
  [SMALL_STATE(17764)] = 672069,
  [SMALL_STATE(17765)] = 672083,
  [SMALL_STATE(17766)] = 672097,
  [SMALL_STATE(17767)] = 672111,
  [SMALL_STATE(17768)] = 672125,
  [SMALL_STATE(17769)] = 672139,
  [SMALL_STATE(17770)] = 672153,
  [SMALL_STATE(17771)] = 672167,
  [SMALL_STATE(17772)] = 672181,
  [SMALL_STATE(17773)] = 672195,
  [SMALL_STATE(17774)] = 672209,
  [SMALL_STATE(17775)] = 672223,
  [SMALL_STATE(17776)] = 672237,
  [SMALL_STATE(17777)] = 672251,
  [SMALL_STATE(17778)] = 672265,
  [SMALL_STATE(17779)] = 672279,
  [SMALL_STATE(17780)] = 672293,
  [SMALL_STATE(17781)] = 672307,
  [SMALL_STATE(17782)] = 672321,
  [SMALL_STATE(17783)] = 672335,
  [SMALL_STATE(17784)] = 672349,
  [SMALL_STATE(17785)] = 672363,
  [SMALL_STATE(17786)] = 672377,
  [SMALL_STATE(17787)] = 672391,
  [SMALL_STATE(17788)] = 672405,
  [SMALL_STATE(17789)] = 672419,
  [SMALL_STATE(17790)] = 672433,
  [SMALL_STATE(17791)] = 672447,
  [SMALL_STATE(17792)] = 672461,
  [SMALL_STATE(17793)] = 672475,
  [SMALL_STATE(17794)] = 672489,
  [SMALL_STATE(17795)] = 672503,
  [SMALL_STATE(17796)] = 672517,
  [SMALL_STATE(17797)] = 672531,
  [SMALL_STATE(17798)] = 672545,
  [SMALL_STATE(17799)] = 672559,
  [SMALL_STATE(17800)] = 672573,
  [SMALL_STATE(17801)] = 672587,
  [SMALL_STATE(17802)] = 672601,
  [SMALL_STATE(17803)] = 672615,
  [SMALL_STATE(17804)] = 672629,
  [SMALL_STATE(17805)] = 672643,
  [SMALL_STATE(17806)] = 672657,
  [SMALL_STATE(17807)] = 672671,
  [SMALL_STATE(17808)] = 672685,
  [SMALL_STATE(17809)] = 672699,
  [SMALL_STATE(17810)] = 672713,
  [SMALL_STATE(17811)] = 672727,
  [SMALL_STATE(17812)] = 672741,
  [SMALL_STATE(17813)] = 672755,
  [SMALL_STATE(17814)] = 672769,
  [SMALL_STATE(17815)] = 672783,
  [SMALL_STATE(17816)] = 672797,
  [SMALL_STATE(17817)] = 672811,
  [SMALL_STATE(17818)] = 672825,
  [SMALL_STATE(17819)] = 672839,
  [SMALL_STATE(17820)] = 672853,
  [SMALL_STATE(17821)] = 672867,
  [SMALL_STATE(17822)] = 672881,
  [SMALL_STATE(17823)] = 672895,
  [SMALL_STATE(17824)] = 672909,
  [SMALL_STATE(17825)] = 672923,
  [SMALL_STATE(17826)] = 672937,
  [SMALL_STATE(17827)] = 672951,
  [SMALL_STATE(17828)] = 672965,
  [SMALL_STATE(17829)] = 672979,
  [SMALL_STATE(17830)] = 672993,
  [SMALL_STATE(17831)] = 673007,
  [SMALL_STATE(17832)] = 673021,
  [SMALL_STATE(17833)] = 673035,
  [SMALL_STATE(17834)] = 673049,
  [SMALL_STATE(17835)] = 673063,
  [SMALL_STATE(17836)] = 673077,
  [SMALL_STATE(17837)] = 673091,
  [SMALL_STATE(17838)] = 673105,
  [SMALL_STATE(17839)] = 673119,
  [SMALL_STATE(17840)] = 673133,
  [SMALL_STATE(17841)] = 673147,
  [SMALL_STATE(17842)] = 673161,
  [SMALL_STATE(17843)] = 673175,
  [SMALL_STATE(17844)] = 673189,
  [SMALL_STATE(17845)] = 673203,
  [SMALL_STATE(17846)] = 673217,
  [SMALL_STATE(17847)] = 673231,
  [SMALL_STATE(17848)] = 673245,
  [SMALL_STATE(17849)] = 673259,
  [SMALL_STATE(17850)] = 673273,
  [SMALL_STATE(17851)] = 673287,
  [SMALL_STATE(17852)] = 673301,
  [SMALL_STATE(17853)] = 673315,
  [SMALL_STATE(17854)] = 673329,
  [SMALL_STATE(17855)] = 673343,
  [SMALL_STATE(17856)] = 673357,
  [SMALL_STATE(17857)] = 673371,
  [SMALL_STATE(17858)] = 673385,
  [SMALL_STATE(17859)] = 673399,
  [SMALL_STATE(17860)] = 673413,
  [SMALL_STATE(17861)] = 673427,
  [SMALL_STATE(17862)] = 673441,
  [SMALL_STATE(17863)] = 673455,
  [SMALL_STATE(17864)] = 673469,
  [SMALL_STATE(17865)] = 673483,
  [SMALL_STATE(17866)] = 673497,
  [SMALL_STATE(17867)] = 673511,
  [SMALL_STATE(17868)] = 673525,
  [SMALL_STATE(17869)] = 673539,
  [SMALL_STATE(17870)] = 673553,
  [SMALL_STATE(17871)] = 673567,
  [SMALL_STATE(17872)] = 673581,
  [SMALL_STATE(17873)] = 673595,
  [SMALL_STATE(17874)] = 673609,
  [SMALL_STATE(17875)] = 673623,
  [SMALL_STATE(17876)] = 673637,
  [SMALL_STATE(17877)] = 673641,
  [SMALL_STATE(17878)] = 673645,
  [SMALL_STATE(17879)] = 673649,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14736),
  [5] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14865),
  [7] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compilation_unit, 0, 0, 0),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4512),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12576),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15936),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11903),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12520),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12521),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12355),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7897),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4171),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12036),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12054),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2256),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4263),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(666),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1327),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3853),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1386),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4459),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4246),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9625),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9224),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9658),
  [55] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11840),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12518),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7765),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6358),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5388),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5399),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2350),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4141),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4158),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4177),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1803),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2253),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12223),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12331),
  [83] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4512),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9352),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10271),
  [89] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10271),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10257),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10212),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(648),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2267),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2268),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2402),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10263),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5337),
  [107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13207),
  [111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6079),
  [113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4138),
  [115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2148),
  [117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4253),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(668),
  [121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(875),
  [123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3891),
  [125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1650),
  [127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4400),
  [129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4251),
  [131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11974),
  [133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12312),
  [135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6691),
  [137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5365),
  [139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2348),
  [141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4156),
  [143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4146),
  [145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4162),
  [147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1818),
  [149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14677),
  [151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2162),
  [153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12421),
  [155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12422),
  [157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5337),
  [159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9187),
  [161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7802),
  [163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7802),
  [165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7806),
  [167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7873),
  [169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(697),
  [171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2164),
  [173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7466),
  [177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9891),
  [179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6498),
  [181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7643),
  [183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8339),
  [185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11002),
  [187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5988),
  [189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11239),
  [191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11185),
  [193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14102),
  [195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11527),
  [197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6539),
  [199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12659),
  [201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11978),
  [203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9248),
  [205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8529),
  [207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9130),
  [209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6473),
  [211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10300),
  [213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11470),
  [215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10333),
  [217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11019),
  [219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10912),
  [221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6889),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10679),
  [225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8807),
  [227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16799),
  [229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10081),
  [231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8585),
  [233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13094),
  [235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8217),
  [237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13000),
  [239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5354),
  [241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12170),
  [243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6293),
  [245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10215),
  [247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10478),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10676),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10393),
  [253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14258),
  [255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10879),
  [257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5872),
  [259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7229),
  [261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7911),
  [263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8393),
  [265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10541),
  [267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10022),
  [269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13045),
  [271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10950),
  [273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10917),
  [275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7328),
  [277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9296),
  [279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9718),
  [281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16128),
  [283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8800),
  [285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13297),
  [287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10700),
  [289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10196),
  [291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11217),
  [293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10489),
  [295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11916),
  [297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10469),
  [299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14139),
  [301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8351),
  [303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8309),
  [305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12388),
  [307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9427),
  [309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13321),
  [311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9941),
  [313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7479),
  [315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13440),
  [317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8782),
  [319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9627),
  [321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9852),
  [323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10560),
  [325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9921),
  [327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5575),
  [329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9810),
  [331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10686),
  [333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10538),
  [335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14077),
  [337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6026),
  [339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6943),
  [341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8788),
  [343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8517),
  [345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7645),
  [347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8368),
  [349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9802),
  [351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9917),
  [353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13581),
  [355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12870),
  [357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9816),
  [359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13397),
  [361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9934),
  [363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11680),
  [365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10248),
  [367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10834),
  [369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7700),
  [371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8740),
  [373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11706),
  [375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12950),
  [377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8822),
  [379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10423),
  [381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8263),
  [383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8921),
  [385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10216),
  [387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10119),
  [389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10228),
  [391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7960),
  [393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9030),
  [395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13293),
  [397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9471),
  [399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10309),
  [401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10476),
  [403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8279),
  [405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9558),
  [407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9581),
  [409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13200),
  [411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compilation_unit, 4, 0, 0),
  [413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8844),
  [415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4065),
  [417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9457),
  [419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7972),
  [421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7478),
  [423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8418),
  [425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8898),
  [427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6613),
  [429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9361),
  [431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8273),
  [433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6192),
  [435] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compilation_unit, 2, 0, 0),
  [437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7651),
  [439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9159),
  [441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8427),
  [443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compilation_unit, 1, 0, 0),
  [445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8666),
  [447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9965),
  [449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9353),
  [451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10760),
  [453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9345),
  [455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5677),
  [457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10256),
  [459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6877),
  [461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9815),
  [463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6913),
  [465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9595),
  [467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8789),
  [469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6678),
  [471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compilation_unit, 3, 0, 0),
  [473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5776),
  [475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12311),
  [477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4067),
  [481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12414),
  [483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12415),
  [485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12416),
  [487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7866),
  [489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4155),
  [491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11802),
  [493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11803),
  [495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2105),
  [497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4247),
  [499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(685),
  [501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(937),
  [503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3855),
  [505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(924),
  [507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4421),
  [509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4250),
  [511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11805),
  [513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12420),
  [515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7003),
  [517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5368),
  [519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2349),
  [521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4168),
  [523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4145),
  [525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4166),
  [527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1802),
  [529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14630),
  [531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2085),
  [533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12566),
  [535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12637),
  [537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5776),
  [539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9711),
  [541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9490),
  [543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9490),
  [545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9491),
  [547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9416),
  [549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(661),
  [551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2175),
  [553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2281),
  [555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9488),
  [557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16089),
  [559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8887),
  [561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16338),
  [563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9206),
  [565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14241),
  [567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14511),
  [569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14598),
  [571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14340),
  [575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15874),
  [577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17757),
  [579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15862),
  [581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 2, 0, 25),
  [583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_clause, 2, 0, 25),
  [585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4165),
  [587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2078),
  [589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(696),
  [591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(964),
  [593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3858),
  [595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1278),
  [597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4248),
  [599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5371),
  [601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14206),
  [603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2125),
  [605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8999),
  [607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(614),
  [609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2244),
  [611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4160),
  [613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2199),
  [615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(728),
  [617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1048),
  [619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3893),
  [621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1017),
  [623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4252),
  [625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5373),
  [627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14256),
  [629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2184),
  [631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8903),
  [633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(586),
  [635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2201),
  [637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__block, 3, 0, 0),
  [639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14517),
  [641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14448),
  [643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11236),
  [645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5295),
  [647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__block, 2, 0, 0),
  [649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14478),
  [651] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__block, 2, 0, 0),
  [653] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__block, 3, 0, 0),
  [655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14239),
  [657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11241),
  [659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5607),
  [661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__enum_block, 2, 0, 0),
  [663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__enum_block, 3, 0, 0),
  [665] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(5776),
  [668] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0),
  [670] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(139),
  [673] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(7866),
  [676] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(2105),
  [679] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(5607),
  [682] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(685),
  [685] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(937),
  [688] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(3855),
  [691] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(924),
  [694] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(4421),
  [697] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(12730),
  [700] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(2349),
  [703] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(1802),
  [706] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_self_type, 2, 1, 0),
  [708] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(2085),
  [711] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(12566),
  [714] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(12637),
  [717] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(5776),
  [720] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(9711),
  [723] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(9490),
  [726] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(9490),
  [729] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(9491),
  [732] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(9416),
  [735] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(661),
  [738] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(2175),
  [741] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(2281),
  [744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [746] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(9488),
  [749] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(5337),
  [752] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(122),
  [755] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(6079),
  [758] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(2148),
  [761] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(5295),
  [764] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(668),
  [767] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(875),
  [770] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(3891),
  [773] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(1650),
  [776] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(4400),
  [779] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(12675),
  [782] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(2348),
  [785] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(1818),
  [788] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(2162),
  [791] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(12421),
  [794] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(12422),
  [797] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(5337),
  [800] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(9457),
  [803] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(7802),
  [806] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(7802),
  [809] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(7806),
  [812] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(7873),
  [815] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(697),
  [818] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(2164),
  [821] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(2268),
  [824] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(155),
  [827] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, 1, 0), SHIFT(7466),
  [830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5706),
  [832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [834] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 1, 0, 0),
  [836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7821),
  [838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2237),
  [840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5969),
  [842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(730),
  [844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(897),
  [846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3901),
  [848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(898),
  [850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4405),
  [852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1815),
  [854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2247),
  [856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12530),
  [858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12531),
  [860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5706),
  [862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8097),
  [864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8137),
  [866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8137),
  [868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8158),
  [870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9331),
  [872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(640),
  [874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2249),
  [876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2275),
  [878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8502),
  [880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(698),
  [882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(729),
  [884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(670),
  [886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(686),
  [888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4530),
  [890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10294),
  [892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [894] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_postfix_expression, 2, 0, 0),
  [896] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_postfix_expression, 2, 0, 0),
  [898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4794),
  [900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2169),
  [902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4526),
  [904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(671),
  [906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4431),
  [908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12771),
  [910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2464),
  [912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1820),
  [914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12430),
  [916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12592),
  [918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4530),
  [920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4967),
  [922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5805),
  [924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5805),
  [926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5806),
  [928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5465),
  [930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5803),
  [932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4633),
  [934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10284),
  [936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5253),
  [940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2084),
  [942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4634),
  [944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4417),
  [946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2574),
  [948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1825),
  [950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12605),
  [952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12370),
  [954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4633),
  [956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5254),
  [958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6215),
  [960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6215),
  [962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6352),
  [964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6602),
  [966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6129),
  [968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4594),
  [970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10276),
  [972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5090),
  [976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2235),
  [978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4582),
  [980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4443),
  [982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2571),
  [984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1816),
  [986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12247),
  [988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12291),
  [990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4594),
  [992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5051),
  [994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6247),
  [996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6247),
  [998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6287),
  [1000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6188),
  [1002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6225),
  [1004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4922),
  [1006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10407),
  [1008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [1010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5543),
  [1012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2183),
  [1014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4891),
  [1016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4433),
  [1018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2579),
  [1020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1819),
  [1022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12567),
  [1024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12184),
  [1026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4922),
  [1028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5883),
  [1030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7223),
  [1032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7223),
  [1034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7224),
  [1036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6910),
  [1038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7220),
  [1040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4997),
  [1042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10336),
  [1044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [1046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5804),
  [1048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2121),
  [1050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4993),
  [1052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4423),
  [1054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2576),
  [1056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1806),
  [1058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12451),
  [1060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12327),
  [1062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4997),
  [1064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5753),
  [1066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6808),
  [1068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6808),
  [1070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6809),
  [1072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6675),
  [1074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6804),
  [1076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4809),
  [1078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10347),
  [1080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [1082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5533),
  [1084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2178),
  [1086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4764),
  [1088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4432),
  [1090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2577),
  [1092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1801),
  [1094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12511),
  [1096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12628),
  [1098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4809),
  [1100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5866),
  [1102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7105),
  [1104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7105),
  [1106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7106),
  [1108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6874),
  [1110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7103),
  [1112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5173),
  [1114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10189),
  [1116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [1118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6524),
  [1120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2213),
  [1122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5169),
  [1124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4438),
  [1126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2575),
  [1128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1827),
  [1130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12183),
  [1132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12248),
  [1134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5173),
  [1136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6622),
  [1138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7452),
  [1140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7452),
  [1142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7473),
  [1144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7476),
  [1146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7411),
  [1148] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_expression, 1, 0, 0),
  [1150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(806),
  [1152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1036),
  [1154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3882),
  [1156] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_expression, 1, 0, 0),
  [1158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1004),
  [1160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12784),
  [1162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2170),
  [1164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7074),
  [1166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(536),
  [1168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2171),
  [1170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2293),
  [1172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1186),
  [1174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3898),
  [1176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1162),
  [1178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12880),
  [1180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2152),
  [1182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6108),
  [1184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(537),
  [1186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2269),
  [1188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2289),
  [1190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5821),
  [1192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10317),
  [1194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [1196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7273),
  [1198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2141),
  [1200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5832),
  [1202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4425),
  [1204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2965),
  [1206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1812),
  [1208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12252),
  [1210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12393),
  [1212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5821),
  [1214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7141),
  [1216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8608),
  [1218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8608),
  [1220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8609),
  [1222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8472),
  [1224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8600),
  [1226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4411),
  [1228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10155),
  [1230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [1232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7973),
  [1234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2151),
  [1236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4406),
  [1238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4466),
  [1240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2992),
  [1242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1813),
  [1244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12322),
  [1246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12432),
  [1248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4411),
  [1250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7789),
  [1252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8784),
  [1254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8784),
  [1256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8785),
  [1258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9158),
  [1260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8779),
  [1262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(719),
  [1264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1022),
  [1266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3872),
  [1268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(998),
  [1270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12775),
  [1272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7006),
  [1274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(540),
  [1276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2135),
  [1278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5185),
  [1280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10304),
  [1282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [1284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6277),
  [1286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2239),
  [1288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5184),
  [1290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4444),
  [1292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2896),
  [1294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1800),
  [1296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12263),
  [1298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12299),
  [1300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5185),
  [1302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6070),
  [1304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7829),
  [1306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7829),
  [1308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7842),
  [1310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7648),
  [1312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7799),
  [1314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(749),
  [1316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1100),
  [1318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3861),
  [1320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1072),
  [1322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12823),
  [1324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2200),
  [1326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7275),
  [1328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(542),
  [1330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2067),
  [1332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2299),
  [1334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5530),
  [1336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10323),
  [1338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [1340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7161),
  [1342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2246),
  [1344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5529),
  [1346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4446),
  [1348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2926),
  [1350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1805),
  [1352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12278),
  [1354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12313),
  [1356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5530),
  [1358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6693),
  [1360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8206),
  [1362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8206),
  [1364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8211),
  [1366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8399),
  [1368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8200),
  [1370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5569),
  [1372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10200),
  [1374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [1376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7221),
  [1378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2131),
  [1380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5567),
  [1382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4424),
  [1384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3590),
  [1386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1824),
  [1388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12636),
  [1390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12352),
  [1392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5569),
  [1394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7050),
  [1396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8445),
  [1398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8445),
  [1400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8448),
  [1402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8380),
  [1404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8433),
  [1406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4473),
  [1408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10391),
  [1410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [1412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8352),
  [1414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2049),
  [1416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4484),
  [1418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4410),
  [1420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3184),
  [1422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1822),
  [1424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12564),
  [1426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12607),
  [1428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4473),
  [1430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8120),
  [1432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9688),
  [1434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9688),
  [1436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9689),
  [1438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9584),
  [1440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9684),
  [1442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(707),
  [1444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(991),
  [1446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3897),
  [1448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(972),
  [1450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12738),
  [1452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2132),
  [1454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8027),
  [1456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(546),
  [1458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2057),
  [1460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(680),
  [1462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(923),
  [1464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3856),
  [1466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1268),
  [1468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12667),
  [1470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2081),
  [1472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8013),
  [1474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(547),
  [1476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2127),
  [1478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2277),
  [1480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5752),
  [1482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10403),
  [1484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [1486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6821),
  [1488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2096),
  [1490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5755),
  [1492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4420),
  [1494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3835),
  [1496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1814),
  [1498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12411),
  [1500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12458),
  [1502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5752),
  [1504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6807),
  [1506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8229),
  [1508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8229),
  [1510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8326),
  [1512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8222),
  [1514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8553),
  [1516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1202),
  [1518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3847),
  [1520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1182),
  [1522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12900),
  [1524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2222),
  [1526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6688),
  [1528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(549),
  [1530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2063),
  [1532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2303),
  [1534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1156),
  [1536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3885),
  [1538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1133),
  [1540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12859),
  [1542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6010),
  [1544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(550),
  [1546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2208),
  [1548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(705),
  [1550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(984),
  [1552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3886),
  [1554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(965),
  [1556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12724),
  [1558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2122),
  [1560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7867),
  [1562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(551),
  [1564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2040),
  [1566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2287),
  [1568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6091),
  [1570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10160),
  [1572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [1574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7434),
  [1576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2206),
  [1578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6623),
  [1580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4436),
  [1582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3124),
  [1584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1821),
  [1586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12627),
  [1588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12226),
  [1590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6091),
  [1592] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7932),
  [1594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9231),
  [1596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9231),
  [1598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9232),
  [1600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8838),
  [1602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9230),
  [1604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10434),
  [1606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6629),
  [1608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1122),
  [1610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3871),
  [1612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1096),
  [1614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12834),
  [1616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6680),
  [1618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(554),
  [1620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2115),
  [1622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(763),
  [1624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1132),
  [1626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3875),
  [1628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1107),
  [1630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12844),
  [1632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7989),
  [1634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(555),
  [1636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2144),
  [1638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4471),
  [1640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10243),
  [1642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [1644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8247),
  [1646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2227),
  [1648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4470),
  [1650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4442),
  [1652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3390),
  [1654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1809),
  [1656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12224),
  [1658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12279),
  [1660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4471),
  [1662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8690),
  [1664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9685),
  [1666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9685),
  [1668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9687),
  [1670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9357),
  [1672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9641),
  [1674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(765),
  [1676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1137),
  [1678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3846),
  [1680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1113),
  [1682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12847),
  [1684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2228),
  [1686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8016),
  [1688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(557),
  [1690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2156),
  [1692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2305),
  [1694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6117),
  [1696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10218),
  [1698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [1700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7903),
  [1702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2221),
  [1704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6094),
  [1706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4441),
  [1708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3328),
  [1710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1804),
  [1712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12199),
  [1714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12265),
  [1716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6117),
  [1718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8069),
  [1720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9082),
  [1722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9082),
  [1724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9083),
  [1726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8894),
  [1728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9053),
  [1730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(780),
  [1732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1171),
  [1734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3892),
  [1736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1148),
  [1738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12869),
  [1740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2236),
  [1742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7425),
  [1744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(559),
  [1746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2240),
  [1748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2307),
  [1750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1176),
  [1752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3894),
  [1754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1153),
  [1756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12871),
  [1758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7382),
  [1760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(560),
  [1762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2251),
  [1764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(721),
  [1766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1029),
  [1768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3877),
  [1770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1284),
  [1772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12780),
  [1774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2161),
  [1776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8338),
  [1778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(561),
  [1780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2154),
  [1782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2291),
  [1784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(683),
  [1786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(930),
  [1788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3884),
  [1790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(919),
  [1792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12679),
  [1794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2107),
  [1796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8710),
  [1798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(562),
  [1800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2153),
  [1802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2279),
  [1804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6619),
  [1806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10131),
  [1808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [1810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7822),
  [1812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2191),
  [1814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6532),
  [1816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4434),
  [1818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3845),
  [1820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1810),
  [1822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12590),
  [1824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12200),
  [1826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6619),
  [1828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7902),
  [1830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9185),
  [1832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9185),
  [1834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9186),
  [1836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8786),
  [1838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9183),
  [1840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10318),
  [1842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3844),
  [1844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8672),
  [1846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4597),
  [1848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10208),
  [1850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [1852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9277),
  [1854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2160),
  [1856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4580),
  [1858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4429),
  [1860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3841),
  [1862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1828),
  [1864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12349),
  [1866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12512),
  [1868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4597),
  [1870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9112),
  [1872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9797),
  [1874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9797),
  [1876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9800),
  [1878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9961),
  [1880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9784),
  [1882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1194),
  [1884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3902),
  [1886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1172),
  [1888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12891),
  [1890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7385),
  [1892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(566),
  [1894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2045),
  [1896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1083),
  [1898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3854),
  [1900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1055),
  [1902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12810),
  [1904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7349),
  [1906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(567),
  [1908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2331),
  [1910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1198),
  [1912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3874),
  [1914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1177),
  [1916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12895),
  [1918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8086),
  [1920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(568),
  [1922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2053),
  [1924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(752),
  [1926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1106),
  [1928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3864),
  [1930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1078),
  [1932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12826),
  [1934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2207),
  [1936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8474),
  [1938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(569),
  [1940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2072),
  [1942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2301),
  [1944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(699),
  [1946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(971),
  [1948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3870),
  [1950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(951),
  [1952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12706),
  [1954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2106),
  [1956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8348),
  [1958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(570),
  [1960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2259),
  [1962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2283),
  [1964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(754),
  [1966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1112),
  [1968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3867),
  [1970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1084),
  [1972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12830),
  [1974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2214),
  [1976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8510),
  [1978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(571),
  [1980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2086),
  [1982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(731),
  [1984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1054),
  [1986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3899),
  [1988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1023),
  [1990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12792),
  [1992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2192),
  [1994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8572),
  [1996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(572),
  [1998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2216),
  [2000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2297),
  [2002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1117),
  [2004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3869),
  [2006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1090),
  [2008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12832),
  [2010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8048),
  [2012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(573),
  [2014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2099),
  [2016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4685),
  [2018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10161),
  [2020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [2022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8743),
  [2024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2113),
  [2026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4670),
  [2028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4422),
  [2030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3843),
  [2032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1823),
  [2034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12358),
  [2036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12256),
  [2038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4685),
  [2040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8721),
  [2042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9825),
  [2044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9825),
  [2046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9827),
  [2048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10014),
  [2050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9822),
  [2052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3842),
  [2054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(701),
  [2056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(978),
  [2058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3878),
  [2060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(958),
  [2062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12715),
  [2064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2114),
  [2066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8271),
  [2068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(576),
  [2070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2272),
  [2072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2285),
  [2074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(676),
  [2076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(913),
  [2078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3880),
  [2080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1258),
  [2082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12647),
  [2084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2050),
  [2086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8088),
  [2088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(577),
  [2090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2087),
  [2092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1152),
  [2094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3883),
  [2096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1128),
  [2098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12858),
  [2100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7796),
  [2102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(578),
  [2104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2195),
  [2106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1190),
  [2108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3900),
  [2110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1167),
  [2112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12883),
  [2114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7890),
  [2116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(579),
  [2118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2035),
  [2120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4085),
  [2122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(734),
  [2124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1059),
  [2126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3903),
  [2128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1030),
  [2130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12798),
  [2132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8679),
  [2134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(620),
  [2136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2229),
  [2138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [2140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4117),
  [2142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(692),
  [2144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(957),
  [2146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3868),
  [2148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(945),
  [2150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12700),
  [2152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9415),
  [2154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1221),
  [2156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2225),
  [2158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [2160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4108),
  [2162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(793),
  [2164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [2166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4132),
  [2168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(756),
  [2170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [2172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(687),
  [2174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(944),
  [2176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3904),
  [2178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(931),
  [2180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12683),
  [2182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2097),
  [2184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8781),
  [2186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(584),
  [2188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2193),
  [2190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4126),
  [2192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [2194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12820),
  [2196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4106),
  [2198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(736),
  [2200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1065),
  [2202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3863),
  [2204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1037),
  [2206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12802),
  [2208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2179),
  [2210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9808),
  [2212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1721),
  [2214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2241),
  [2216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2295),
  [2218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [2220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(745),
  [2222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3857),
  [2224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1060),
  [2226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12813),
  [2228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8350),
  [2230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(588),
  [2232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2042),
  [2234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4120),
  [2236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(743),
  [2238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [2240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4099),
  [2242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [2244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4102),
  [2246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(758),
  [2248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4124),
  [2250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(782),
  [2252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [2254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4104),
  [2256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4119),
  [2258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(776),
  [2260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1161),
  [2262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3888),
  [2264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1138),
  [2266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12863),
  [2268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8062),
  [2270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(622),
  [2272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2223),
  [2274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4101),
  [2276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4112),
  [2278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(714),
  [2280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1009),
  [2282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3860),
  [2284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1272),
  [2286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12755),
  [2288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2142),
  [2290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8783),
  [2292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(615),
  [2294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2098),
  [2296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4114),
  [2298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [2300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4118),
  [2302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(690),
  [2304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(950),
  [2306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3889),
  [2308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(938),
  [2310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12692),
  [2312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9330),
  [2314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1210),
  [2316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2210),
  [2318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4136),
  [2320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4122),
  [2322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(747),
  [2324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1095),
  [2326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3859),
  [2328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1066),
  [2330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12817),
  [2332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9873),
  [2334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1758),
  [2336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2055),
  [2338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1181),
  [2340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3896),
  [2342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1157),
  [2344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12877),
  [2346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8701),
  [2348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(602),
  [2350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2260),
  [2352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10267),
  [2354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8233),
  [2356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9533),
  [2358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4098),
  [2360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(767),
  [2362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1142),
  [2364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3879),
  [2366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1118),
  [2368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12851),
  [2370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8959),
  [2372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(636),
  [2374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2172),
  [2376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [2378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4095),
  [2380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(784),
  [2382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [2384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1127),
  [2386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3873),
  [2388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1101),
  [2390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12839),
  [2392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8040),
  [2394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(606),
  [2396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2126),
  [2398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4087),
  [2400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(795),
  [2402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4088),
  [2404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4109),
  [2406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(789),
  [2408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4086),
  [2410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(778),
  [2412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1166),
  [2414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3890),
  [2416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1143),
  [2418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12865),
  [2420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9022),
  [2422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(644),
  [2424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2231),
  [2426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10127),
  [2428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3851),
  [2430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4131),
  [2432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4094),
  [2434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(791),
  [2436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12767),
  [2438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4128),
  [2440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4134),
  [2442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(726),
  [2444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1042),
  [2446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3887),
  [2448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1010),
  [2450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12788),
  [2452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9043),
  [2454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(625),
  [2456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2187),
  [2458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4127),
  [2460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1147),
  [2462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3881),
  [2464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1123),
  [2466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12854),
  [2468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8687),
  [2470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(619),
  [2472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2185),
  [2474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4092),
  [2476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4115),
  [2478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4081),
  [2480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4093),
  [2482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4107),
  [2484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(774),
  [2486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1077),
  [2488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3848),
  [2490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1049),
  [2492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12807),
  [2494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8124),
  [2496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(628),
  [2498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2264),
  [2500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4135),
  [2502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1089),
  [2504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4083),
  [2506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(786),
  [2508] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4685),
  [2511] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0),
  [2513] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(143),
  [2516] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0),
  [2518] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4670),
  [2521] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(3843),
  [2524] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1823),
  [2527] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4685),
  [2530] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8781),
  [2533] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2283),
  [2536] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4633),
  [2539] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(126),
  [2542] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4634),
  [2545] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2574),
  [2548] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1825),
  [2551] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4633),
  [2554] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(6680),
  [2557] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2277),
  [2560] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4997),
  [2563] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(147),
  [2566] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4993),
  [2569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(760),
  [2571] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2576),
  [2574] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1806),
  [2577] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4997),
  [2580] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8040),
  [2583] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4594),
  [2586] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(129),
  [2589] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4582),
  [2592] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2571),
  [2595] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1816),
  [2598] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4594),
  [2601] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(7989),
  [2604] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2303),
  [2607] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5185),
  [2610] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(131),
  [2613] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5184),
  [2616] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2896),
  [2619] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1800),
  [2622] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5185),
  [2625] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8016),
  [2628] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2305),
  [2631] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8959),
  [2634] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(6091),
  [2637] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(121),
  [2640] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(6623),
  [2643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(769),
  [2645] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(3124),
  [2648] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1821),
  [2651] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(6091),
  [2654] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8687),
  [2657] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2297),
  [2660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(771),
  [2662] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(7796),
  [2665] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5706),
  [2668] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(137),
  [2671] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5969),
  [2674] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(3851),
  [2677] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1815),
  [2680] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5706),
  [2683] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8097),
  [2686] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2275),
  [2689] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4530),
  [2692] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(140),
  [2695] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4526),
  [2698] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2464),
  [2701] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1820),
  [2704] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4530),
  [2707] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(6010),
  [2710] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2289),
  [2713] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4809),
  [2716] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(142),
  [2719] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4764),
  [2722] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2577),
  [2725] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1801),
  [2728] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4809),
  [2731] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8062),
  [2734] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2291),
  [2737] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(9022),
  [2740] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5530),
  [2743] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(133),
  [2746] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5529),
  [2749] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2926),
  [2752] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1805),
  [2755] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5530),
  [2758] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(7425),
  [2761] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2307),
  [2764] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5173),
  [2767] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(123),
  [2770] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5169),
  [2773] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2575),
  [2776] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1827),
  [2779] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5173),
  [2782] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(7382),
  [2785] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2299),
  [2788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12656),
  [2790] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(6117),
  [2793] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(125),
  [2796] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(6094),
  [2799] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(3328),
  [2802] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1804),
  [2805] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(6117),
  [2808] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8701),
  [2811] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2301),
  [2814] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(6108),
  [2817] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(7890),
  [2820] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(7385),
  [2823] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8086),
  [2826] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(6688),
  [2829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(673),
  [2831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(905),
  [2833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3876),
  [2835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(906),
  [2837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12981),
  [2839] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(10406),
  [2842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1826),
  [2844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2051),
  [2846] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4473),
  [2849] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(145),
  [2852] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4484),
  [2855] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(3184),
  [2858] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1822),
  [2861] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4473),
  [2864] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8088),
  [2867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(678),
  [2869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(918),
  [2871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3865),
  [2873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(914),
  [2875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12661),
  [2877] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(10206),
  [2880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1817),
  [2882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2108),
  [2884] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4512),
  [2887] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(141),
  [2890] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8233),
  [2893] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2350),
  [2896] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1803),
  [2899] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4512),
  [2902] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(9352),
  [2905] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2268),
  [2908] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8013),
  [2911] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5752),
  [2914] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(135),
  [2917] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5755),
  [2920] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(3835),
  [2923] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1814),
  [2926] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5752),
  [2929] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8710),
  [2932] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2279),
  [2935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12730),
  [2937] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5776),
  [2940] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(139),
  [2943] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5607),
  [2946] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2349),
  [2949] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1802),
  [2952] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5776),
  [2955] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(9711),
  [2958] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2281),
  [2961] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(9330),
  [2964] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(9415),
  [2967] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5337),
  [2970] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(122),
  [2973] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5295),
  [2976] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(3842),
  [2979] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1818),
  [2982] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5337),
  [2985] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8999),
  [2988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1808),
  [2990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [2992] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8348),
  [2995] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5569),
  [2998] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(124),
  [3001] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5567),
  [3004] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(3590),
  [3007] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1824),
  [3010] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5569),
  [3013] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8271),
  [3016] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2285),
  [3019] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5821),
  [3022] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(128),
  [3025] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5832),
  [3028] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2965),
  [3031] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1812),
  [3034] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(5821),
  [3037] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(7867),
  [3040] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2287),
  [3043] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4411),
  [3046] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(132),
  [3049] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4406),
  [3052] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2992),
  [3055] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1813),
  [3058] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4411),
  [3061] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8027),
  [3064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(709),
  [3066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(997),
  [3068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3862),
  [3070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(979),
  [3072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12743),
  [3074] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(9336),
  [3077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1316),
  [3079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2069),
  [3081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1003),
  [3083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3849),
  [3085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(985),
  [3087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12750),
  [3089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8197),
  [3091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(694),
  [3093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2080),
  [3095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(712),
  [3097] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2348),
  [3100] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8197),
  [3103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12675),
  [3105] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(9457),
  [3108] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4597),
  [3111] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(136),
  [3114] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4580),
  [3117] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(3841),
  [3120] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1828),
  [3123] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4597),
  [3126] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8783),
  [3129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(716),
  [3131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1016),
  [3133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3866),
  [3135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(992),
  [3137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12760),
  [3139] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(9420),
  [3142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1369),
  [3144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2117),
  [3146] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(7006),
  [3149] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8048),
  [3152] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8338),
  [3155] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4922),
  [3158] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(144),
  [3161] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4891),
  [3164] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2579),
  [3167] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1819),
  [3170] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4922),
  [3173] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(7074),
  [3176] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2293),
  [3179] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(6619),
  [3182] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(146),
  [3185] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(6532),
  [3188] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(3845),
  [3191] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1810),
  [3194] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(6619),
  [3197] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(9043),
  [3200] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2295),
  [3203] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(3844),
  [3206] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8903),
  [3209] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8572),
  [3212] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8679),
  [3215] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(9808),
  [3218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1071),
  [3220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3895),
  [3222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1043),
  [3224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12804),
  [3226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9016),
  [3228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(797),
  [3230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2255),
  [3232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(738),
  [3234] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(9016),
  [3237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(740),
  [3239] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8124),
  [3242] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(7349),
  [3245] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8350),
  [3248] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(9873),
  [3251] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(7275),
  [3254] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8474),
  [3257] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4471),
  [3260] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(127),
  [3263] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4470),
  [3266] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(3390),
  [3269] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1809),
  [3272] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(4471),
  [3275] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(8510),
  [3278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [3280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [3282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1811),
  [3284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10406),
  [3286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [3288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9336),
  [3290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9420),
  [3292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [3294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10206),
  [3296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10249),
  [3298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [3300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2079),
  [3302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4430),
  [3304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1807),
  [3306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12391),
  [3308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12571),
  [3310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10486),
  [3312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10820),
  [3314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10820),
  [3316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10823),
  [3318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10748),
  [3320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10793),
  [3322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1836),
  [3324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4965),
  [3326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1962),
  [3328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6771),
  [3330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1965),
  [3332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8412),
  [3334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1918),
  [3336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12345),
  [3338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1968),
  [3340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7675),
  [3342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1971),
  [3344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8932),
  [3346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1829),
  [3348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5829),
  [3350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1974),
  [3352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5108),
  [3354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1928),
  [3356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13382),
  [3358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1977),
  [3360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4792),
  [3362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1980),
  [3364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5643),
  [3366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1983),
  [3368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6549),
  [3370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1986),
  [3372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5670),
  [3374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1989),
  [3376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7420),
  [3378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1992),
  [3380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5775),
  [3382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1995),
  [3384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7484),
  [3386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1998),
  [3388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7004),
  [3390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1940),
  [3392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12657),
  [3394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2001),
  [3396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7554),
  [3398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2004),
  [3400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4841),
  [3402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2007),
  [3404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10211),
  [3406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1960),
  [3408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7135),
  [3410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2010),
  [3412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5859),
  [3414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2013),
  [3416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7059),
  [3418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2016),
  [3420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6476),
  [3422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2019),
  [3424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7673),
  [3426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1957),
  [3428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12733),
  [3430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2022),
  [3432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8363),
  [3434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2024),
  [3436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5157),
  [3438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2025),
  [3440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6418),
  [3442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2026),
  [3444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6637),
  [3446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2027),
  [3448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7142),
  [3450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1934),
  [3452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11178),
  [3454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1936),
  [3456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4464),
  [3458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1877),
  [3460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6342),
  [3462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1969),
  [3464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12789),
  [3466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1849),
  [3468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12534),
  [3470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2030),
  [3472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6534),
  [3474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1985),
  [3476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8052),
  [3478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1958),
  [3480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7163),
  [3482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1997),
  [3484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9321),
  [3486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1948),
  [3488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12587),
  [3490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2018),
  [3492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9124),
  [3494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2006),
  [3496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8579),
  [3498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1830),
  [3500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7811),
  [3502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1862),
  [3504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14391),
  [3506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2020),
  [3508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5500),
  [3510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1895),
  [3512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6291),
  [3514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1856),
  [3516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9136),
  [3518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1961),
  [3520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8660),
  [3522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1941),
  [3524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8872),
  [3526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1901),
  [3528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8694),
  [3530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1834),
  [3532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7893),
  [3534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1867),
  [3536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8586),
  [3538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1978),
  [3540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8508),
  [3542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1870),
  [3544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8725),
  [3546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1943),
  [3548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8098),
  [3550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1966),
  [3552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5902),
  [3554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1874),
  [3556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13861),
  [3558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1916),
  [3560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8926),
  [3562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1994),
  [3564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8253),
  [3566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1939),
  [3568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8605),
  [3570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1993),
  [3572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5338),
  [3574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2002),
  [3576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6016),
  [3578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2032),
  [3580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8114),
  [3582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1831),
  [3584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5864),
  [3586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1959),
  [3588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7394),
  [3590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1842),
  [3592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8416),
  [3594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1845),
  [3596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7518),
  [3598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1927),
  [3600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9169),
  [3602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1848),
  [3604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10096),
  [3606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1888),
  [3608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6836),
  [3610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1851),
  [3612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9341),
  [3614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2008),
  [3616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6168),
  [3618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1854),
  [3620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7724),
  [3622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1973),
  [3624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9045),
  [3626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1857),
  [3628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6854),
  [3630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1860),
  [3632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6377),
  [3634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1863),
  [3636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7021),
  [3638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1866),
  [3640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7688),
  [3642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1869),
  [3644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7808),
  [3646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1872),
  [3648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8344),
  [3650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1838),
  [3652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5426),
  [3654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1875),
  [3656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8929),
  [3658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1878),
  [3660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8618),
  [3662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1881),
  [3664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10188),
  [3666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1884),
  [3668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5014),
  [3670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1887),
  [3672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5221),
  [3674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1890),
  [3676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5600),
  [3678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1893),
  [3680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5258),
  [3682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2021),
  [3684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9412),
  [3686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1896),
  [3688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5658),
  [3690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1864),
  [3692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5914),
  [3694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1899),
  [3696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6595),
  [3698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1902),
  [3700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7986),
  [3702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1905),
  [3704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6951),
  [3706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1908),
  [3708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8316),
  [3710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1903),
  [3712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13059),
  [3714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1911),
  [3716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7601),
  [3718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2000),
  [3720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6848),
  [3722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1914),
  [3724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6340),
  [3726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1876),
  [3728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7164),
  [3730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1917),
  [3732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7711),
  [3734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1920),
  [3736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8591),
  [3738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1923),
  [3740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7817),
  [3742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1926),
  [3744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7209),
  [3746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1929),
  [3748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9084),
  [3750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1970),
  [3752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6554),
  [3754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1932),
  [3756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8369),
  [3758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1886),
  [3760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10925),
  [3762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1935),
  [3764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4577),
  [3766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1892),
  [3768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14402),
  [3770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1938),
  [3772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5626),
  [3774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2033),
  [3776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5055),
  [3778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1944),
  [3780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5059),
  [3782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1947),
  [3784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6666),
  [3786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1835),
  [3788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6286),
  [3790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1950),
  [3792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6685),
  [3794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1953),
  [3796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6545),
  [3798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1909),
  [3800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7283),
  [3802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1956),
  [3804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6741),
  [3806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1839),
  [3808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5583),
  [3810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6246),
  [3812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9895),
  [3814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5707),
  [3816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8695),
  [3818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9597),
  [3820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7530),
  [3822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7111),
  [3824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5592),
  [3826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10597),
  [3828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8656),
  [3830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8455),
  [3832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7417),
  [3834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6763),
  [3836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7590),
  [3838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7180),
  [3840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5353),
  [3842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6403),
  [3844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5719),
  [3846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4854),
  [3848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7453),
  [3850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8295),
  [3852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8867),
  [3854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6747),
  [3856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5457),
  [3858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6115),
  [3860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9220),
  [3862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1102),
  [3864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1545),
  [3866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1542),
  [3868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8941),
  [3870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6935),
  [3872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1026),
  [3874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7519),
  [3876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9552),
  [3878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1330),
  [3880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1061),
  [3882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1244),
  [3884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1163),
  [3886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7439),
  [3888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1555),
  [3890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1207),
  [3892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10383),
  [3894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8154),
  [3896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1342),
  [3898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1312),
  [3900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1477),
  [3902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1568),
  [3904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(871),
  [3906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9667),
  [3908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1347),
  [3910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1276),
  [3912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9385),
  [3914] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__exprs_in_parens, 3, 0, 0),
  [3916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9635),
  [3918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10854),
  [3920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1310),
  [3922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1580),
  [3924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8831),
  [3926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10068),
  [3928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1526),
  [3930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1271),
  [3932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1418),
  [3934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6737),
  [3936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1255),
  [3938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1005),
  [3940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1591),
  [3942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1218),
  [3944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8559),
  [3946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1365),
  [3948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1521),
  [3950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8373),
  [3952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(811),
  [3954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(954),
  [3956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1602),
  [3958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1377),
  [3960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1498),
  [3962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1497),
  [3964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1442),
  [3966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(996),
  [3968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6906),
  [3970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6224),
  [3972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1614),
  [3974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10021),
  [3976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1382),
  [3978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9207),
  [3980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1450),
  [3982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1294),
  [3984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1415),
  [3986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8874),
  [3988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5697),
  [3990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1625),
  [3992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1231),
  [3994] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__exprs_in_parens, 2, 0, 0),
  [3996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1183),
  [3998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(859),
  [4000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1456),
  [4002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1436),
  [4004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8125),
  [4006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1636),
  [4008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1401),
  [4010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(823),
  [4012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(847),
  [4014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7696),
  [4016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(835),
  [4018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6019),
  [4020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1469),
  [4022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(896),
  [4024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1648),
  [4026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1519),
  [4028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(796),
  [4030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(672),
  [4032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(675),
  [4034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(677),
  [4036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(679),
  [4038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(682),
  [4040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(684),
  [4042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(689),
  [4044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(691),
  [4046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(693),
  [4048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(700),
  [4050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(703),
  [4052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(706),
  [4054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(708),
  [4056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(711),
  [4058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(713),
  [4060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(715),
  [4062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(718),
  [4064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(720),
  [4066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(722),
  [4068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(725),
  [4070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(727),
  [4072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(733),
  [4074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(735),
  [4076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(737),
  [4078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(739),
  [4080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(742),
  [4082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(744),
  [4084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(746),
  [4086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(748),
  [4088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(750),
  [4090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(753),
  [4092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(755),
  [4094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(757),
  [4096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(759),
  [4098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(761),
  [4100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(764),
  [4102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(766),
  [4104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(768),
  [4106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(770),
  [4108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(772),
  [4110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(775),
  [4112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(777),
  [4114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(779),
  [4116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(781),
  [4118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(783),
  [4120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(785),
  [4122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(787),
  [4124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(790),
  [4126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(792),
  [4128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(794),
  [4130] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline_modifier, 1, 0, 0),
  [4132] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__soft_identifier, 1, 0, 0),
  [4134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline_modifier, 1, 0, 0),
  [4136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__soft_identifier, 1, 0, 0),
  [4138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6041),
  [4140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17554),
  [4142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [4144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7116),
  [4146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3476),
  [4148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11741),
  [4150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6517),
  [4152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9283),
  [4154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2434),
  [4156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6041),
  [4158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6850),
  [4160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10717),
  [4162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10717),
  [4164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10718),
  [4166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [4168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10713),
  [4170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5675),
  [4172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17441),
  [4174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [4176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6389),
  [4178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3718),
  [4180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11725),
  [4182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5984),
  [4184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9305),
  [4186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2429),
  [4188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5675),
  [4190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9805),
  [4192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10627),
  [4194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10627),
  [4196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10629),
  [4198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [4200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10625),
  [4202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7344),
  [4204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [4206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9809),
  [4208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [4210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6658),
  [4212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17482),
  [4214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [4216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7357),
  [4218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3229),
  [4220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11726),
  [4222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6451),
  [4224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9134),
  [4226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2430),
  [4228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6658),
  [4230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7270),
  [4232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10825),
  [4234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10825),
  [4236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10832),
  [4238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [4240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10765),
  [4242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9776),
  [4244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [4246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9813),
  [4248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [4250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9787),
  [4252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [4254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4941),
  [4256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17782),
  [4258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [4260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5174),
  [4262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3418),
  [4264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11771),
  [4266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4940),
  [4268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8950),
  [4270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2423),
  [4272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4941),
  [4274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5333),
  [4276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9742),
  [4278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9742),
  [4280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9744),
  [4282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [4284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9738),
  [4286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4467),
  [4288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4687),
  [4290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3705),
  [4292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11730),
  [4294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4555),
  [4296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2431),
  [4298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4467),
  [4300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4684),
  [4302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9064),
  [4304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9064),
  [4306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9065),
  [4308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [4310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9063),
  [4312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5532),
  [4314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17784),
  [4316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [4318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6116),
  [4320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3451),
  [4322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11773),
  [4324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5531),
  [4326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8960),
  [4328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2424),
  [4330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5532),
  [4332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6121),
  [4334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10503),
  [4336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10503),
  [4338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10508),
  [4340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [4342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10493),
  [4344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6290),
  [4346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17786),
  [4348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [4350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7187),
  [4352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3485),
  [4354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11774),
  [4356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6268),
  [4358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8966),
  [4360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2425),
  [4362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6290),
  [4364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7016),
  [4366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10795),
  [4368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10795),
  [4370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10797),
  [4372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [4374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10792),
  [4376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5049),
  [4378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17542),
  [4380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [4382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5800),
  [4384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3309),
  [4386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11740),
  [4388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5445),
  [4390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9253),
  [4392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2433),
  [4394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5049),
  [4396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5812),
  [4398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10144),
  [4400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10144),
  [4402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10145),
  [4404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [4406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10141),
  [4408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4476),
  [4410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4756),
  [4412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3517),
  [4414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11775),
  [4416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4475),
  [4418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2412),
  [4420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4476),
  [4422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4664),
  [4424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8772),
  [4426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8772),
  [4428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8773),
  [4430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [4432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8770),
  [4434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4948),
  [4436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17792),
  [4438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [4440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5180),
  [4442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3557),
  [4444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11777),
  [4446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4946),
  [4448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8979),
  [4450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2427),
  [4452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4948),
  [4454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5355),
  [4456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9862),
  [4458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9862),
  [4460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9868),
  [4462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [4464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9846),
  [4466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9819),
  [4468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6759),
  [4470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17566),
  [4472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [4474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7940),
  [4476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3632),
  [4478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11742),
  [4480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6725),
  [4482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9299),
  [4484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2435),
  [4486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6759),
  [4488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8019),
  [4490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11090),
  [4492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11090),
  [4494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11091),
  [4496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [4498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11080),
  [4500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9824),
  [4502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9834),
  [4504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9994),
  [4506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10101),
  [4508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [4510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4572),
  [4512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4783),
  [4514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3824),
  [4516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11744),
  [4518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4734),
  [4520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2413),
  [4522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4572),
  [4524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4786),
  [4526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9713),
  [4528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9713),
  [4530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9714),
  [4532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [4534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9712),
  [4536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9845),
  [4538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10053),
  [4540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5155),
  [4542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17673),
  [4544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [4546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5789),
  [4548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3115),
  [4550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11746),
  [4552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5147),
  [4554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8767),
  [4556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2414),
  [4558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5155),
  [4560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5619),
  [4562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10280),
  [4564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10280),
  [4566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10355),
  [4568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [4570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10242),
  [4572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5025),
  [4574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17406),
  [4576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [4578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5375),
  [4580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3335),
  [4582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11724),
  [4584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5020),
  [4586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9062),
  [4588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2426),
  [4590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5025),
  [4592] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5310),
  [4594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10030),
  [4596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10030),
  [4598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10031),
  [4600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10028),
  [4602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5195),
  [4604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17802),
  [4606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [4608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5515),
  [4610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3588),
  [4612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11783),
  [4614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5194),
  [4616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9000),
  [4618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2428),
  [4620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5195),
  [4622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5816),
  [4624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10251),
  [4626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10251),
  [4628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10252),
  [4630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [4632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10240),
  [4634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10088),
  [4636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9854),
  [4638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10113),
  [4640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7872),
  [4642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8705),
  [4644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3532),
  [4646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11722),
  [4648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7845),
  [4650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2432),
  [4652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7872),
  [4654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8265),
  [4656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11317),
  [4658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11317),
  [4660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11318),
  [4662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11316),
  [4664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5176),
  [4666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17703),
  [4668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [4670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5959),
  [4672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3152),
  [4674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11748),
  [4676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5175),
  [4678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8790),
  [4680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2415),
  [4682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5176),
  [4684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5633),
  [4686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10326),
  [4688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10326),
  [4690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10223),
  [4692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [4694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10128),
  [4696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9735),
  [4698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5498),
  [4700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17718),
  [4702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [4704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6373),
  [4706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3185),
  [4708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11754),
  [4710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5493),
  [4712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8819),
  [4714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2416),
  [4716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5498),
  [4718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6488),
  [4720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10515),
  [4722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10515),
  [4724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10521),
  [4726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10475),
  [4728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9792),
  [4730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [4732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7205),
  [4734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17728),
  [4736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [4738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7423),
  [4740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3220),
  [4742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11756),
  [4744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7203),
  [4746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8843),
  [4748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2417),
  [4750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7205),
  [4752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7732),
  [4754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11068),
  [4756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11068),
  [4758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11098),
  [4760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [4762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10992),
  [4764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9741),
  [4766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [4768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9750),
  [4770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4399),
  [4772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4508),
  [4774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3253),
  [4776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11757),
  [4778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4398),
  [4780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2418),
  [4782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4399),
  [4784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4509),
  [4786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8127),
  [4788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8127),
  [4790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8334),
  [4792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8616),
  [4794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4605),
  [4796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4784),
  [4798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3289),
  [4800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11759),
  [4802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4604),
  [4804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2419),
  [4806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4605),
  [4808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4859),
  [4810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9443),
  [4812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9443),
  [4814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9448),
  [4816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9429),
  [4818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9756),
  [4820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4608),
  [4822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17753),
  [4824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [4826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4799),
  [4828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3324),
  [4830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11760),
  [4832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4606),
  [4834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8880),
  [4836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2420),
  [4838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4608),
  [4840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4865),
  [4842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9588),
  [4844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9588),
  [4846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9593),
  [4848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [4850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9573),
  [4852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5519),
  [4854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17759),
  [4856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [4858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6656),
  [4860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3356),
  [4862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11762),
  [4864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5517),
  [4866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8884),
  [4868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2421),
  [4870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5519),
  [4872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6049),
  [4874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10505),
  [4876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10505),
  [4878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10513),
  [4880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10500),
  [4882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5522),
  [4884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17762),
  [4886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [4888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6198),
  [4890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3388),
  [4892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11763),
  [4894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5521),
  [4896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8896),
  [4898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2422),
  [4900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5522),
  [4902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6071),
  [4904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10448),
  [4906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10448),
  [4908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10596),
  [4910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10601),
  [4912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9766),
  [4914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9779),
  [4916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9796),
  [4918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9840),
  [4920] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__case_pattern, 3, 0, 52),
  [4922] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__case_pattern, 3, 0, 52),
  [4924] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__case_pattern, 2, 0, 52),
  [4926] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__case_pattern, 2, 0, 52),
  [4928] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_self_type, 3, 1, 0),
  [4930] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_self_type, 3, 1, 0),
  [4932] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__shebang, 1, 0, 0),
  [4934] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__shebang, 1, 0, 0),
  [4936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9023),
  [4938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9157),
  [4940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2492),
  [4942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9209),
  [4944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5329),
  [4946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17367),
  [4948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [4950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5653),
  [4952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11660),
  [4954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5331),
  [4956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10891),
  [4958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9564),
  [4960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2482),
  [4962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2410),
  [4964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13467),
  [4966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5329),
  [4968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9668),
  [4970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15879),
  [4972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9123),
  [4974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8742),
  [4976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5704),
  [4978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8065),
  [4980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16009),
  [4982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5439),
  [4984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5908),
  [4986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4808),
  [4988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7818),
  [4990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9265),
  [4992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4730),
  [4994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7948),
  [4996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5652),
  [4998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4775),
  [5000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6000),
  [5002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15897),
  [5004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7215),
  [5006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9256),
  [5008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13794),
  [5010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13562),
  [5012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7764),
  [5014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5509),
  [5016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7322),
  [5018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6844),
  [5020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15885),
  [5022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7901),
  [5024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8276),
  [5026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9493),
  [5028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6736),
  [5030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13595),
  [5032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5436),
  [5034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7898),
  [5036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7886),
  [5038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9142),
  [5040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6054),
  [5042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13832),
  [5044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4964),
  [5046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7186),
  [5048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7306),
  [5050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7438),
  [5052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7470),
  [5054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10741),
  [5056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10006),
  [5058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7340),
  [5060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8242),
  [5062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5612),
  [5064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8671),
  [5066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10813),
  [5068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7399),
  [5070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5343),
  [5072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6486),
  [5074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5550),
  [5076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7589),
  [5078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5351),
  [5080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8178),
  [5082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6228),
  [5084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5132),
  [5086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7354),
  [5088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7101),
  [5090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5905),
  [5092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6311),
  [5094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6445),
  [5096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7761),
  [5098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6259),
  [5100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8982),
  [5102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7787),
  [5104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5589),
  [5106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7172),
  [5108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7113),
  [5110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8311),
  [5112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3529),
  [5114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_wildcard, 1, 0, 0),
  [5116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5196),
  [5118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5415),
  [5120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5178),
  [5122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5179),
  [5124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6444),
  [5126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6455),
  [5128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5495),
  [5130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5496),
  [5132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12365),
  [5134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12366),
  [5136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7201),
  [5138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7202),
  [5140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13244),
  [5142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13246),
  [5144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7848),
  [5146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7849),
  [5148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11273),
  [5150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11274),
  [5152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4919),
  [5154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4920),
  [5156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5505),
  [5158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5506),
  [5160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12378),
  [5162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12380),
  [5164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5511),
  [5166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5512),
  [5168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6084),
  [5170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6085),
  [5172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12720),
  [5174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12721),
  [5176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9061),
  [5178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9229),
  [5180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7559),
  [5182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4546),
  [5184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5965),
  [5186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7899),
  [5188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5968),
  [5190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9249),
  [5192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11524),
  [5194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5288),
  [5196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7874),
  [5198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7261),
  [5200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9297),
  [5202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11810),
  [5204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7321),
  [5206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7262),
  [5208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7264),
  [5210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5952),
  [5212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9228),
  [5214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4821),
  [5216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7277),
  [5218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7325),
  [5220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5311),
  [5222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10952),
  [5224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8323),
  [5226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11647),
  [5228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7279),
  [5230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4871),
  [5232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11848),
  [5234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6343),
  [5236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4294),
  [5238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8525),
  [5240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7233),
  [5242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8580),
  [5244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4295),
  [5246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6359),
  [5248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6191),
  [5250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13399),
  [5252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6601),
  [5254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11689),
  [5256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8584),
  [5258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13415),
  [5260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6297),
  [5262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9675),
  [5264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6944),
  [5266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8034),
  [5268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4989),
  [5270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9679),
  [5272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6181),
  [5274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13410),
  [5276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6027),
  [5278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4601),
  [5280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7355),
  [5282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8037),
  [5284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6056),
  [5286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6031),
  [5288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7975),
  [5290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6461),
  [5292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6065),
  [5294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12239),
  [5296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8275),
  [5298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13369),
  [5300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7372),
  [5302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5074),
  [5304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8285),
  [5306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5417),
  [5308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7373),
  [5310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7374),
  [5312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10343),
  [5314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11637),
  [5316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12098),
  [5318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6404),
  [5320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11702),
  [5322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5472),
  [5324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11703),
  [5326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4832),
  [5328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8076),
  [5330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5610),
  [5332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11819),
  [5334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13148),
  [5336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6740),
  [5338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7961),
  [5340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12100),
  [5342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5611),
  [5344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5085),
  [5346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8004),
  [5348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6407),
  [5350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7098),
  [5352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10900),
  [5354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11854),
  [5356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8388),
  [5358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6521),
  [5360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6024),
  [5362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12094),
  [5364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10924),
  [5366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6025),
  [5368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11652),
  [5370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8554),
  [5372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11948),
  [5374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5548),
  [5376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7327),
  [5378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5621),
  [5380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11234),
  [5382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8254),
  [5384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4502),
  [5386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5623),
  [5388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6778),
  [5390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4503),
  [5392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7657),
  [5394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5568),
  [5396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11507),
  [5398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6023),
  [5400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7260),
  [5402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7759),
  [5404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5094),
  [5406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13223),
  [5408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5427),
  [5410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11021),
  [5412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5095),
  [5414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8466),
  [5416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8520),
  [5418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11210),
  [5420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8156),
  [5422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4780),
  [5424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11649),
  [5426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5452),
  [5428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5103),
  [5430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8210),
  [5432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4781),
  [5434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4599),
  [5436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7805),
  [5438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6833),
  [5440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7807),
  [5442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7757),
  [5444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5073),
  [5446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7157),
  [5448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4787),
  [5450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13285),
  [5452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7370),
  [5454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4788),
  [5456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5941),
  [5458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8622),
  [5460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10046),
  [5462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6668),
  [5464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9624),
  [5466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12309),
  [5468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6420),
  [5470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6428),
  [5472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13580),
  [5474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6435),
  [5476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9626),
  [5478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5084),
  [5480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12856),
  [5482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6871),
  [5484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7241),
  [5486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12754),
  [5488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8469),
  [5490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9674),
  [5492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6776),
  [5494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13854),
  [5496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6573),
  [5498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4723),
  [5500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6581),
  [5502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7760),
  [5504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7143),
  [5506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4834),
  [5508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4719),
  [5510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7766),
  [5512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5102),
  [5514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4667),
  [5516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5678),
  [5518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4671),
  [5520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9451),
  [5522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4674),
  [5524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5682),
  [5526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5953),
  [5528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12020),
  [5530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6412),
  [5532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6127),
  [5534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6832),
  [5536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6095),
  [5538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10086),
  [5540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5129),
  [5542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5312),
  [5544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6113),
  [5546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10090),
  [5548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9680),
  [5550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7193),
  [5552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5230),
  [5554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6413),
  [5556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6977),
  [5558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6193),
  [5560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4774),
  [5562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6981),
  [5564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5237),
  [5566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6867),
  [5568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11936),
  [5570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6266),
  [5572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8327),
  [5574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5820),
  [5576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6870),
  [5578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6275),
  [5580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11655),
  [5582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8471),
  [5584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7237),
  [5586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6872),
  [5588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4721),
  [5590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6721),
  [5592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12684),
  [5594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12241),
  [5596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12693),
  [5598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5289),
  [5600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6753),
  [5602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11690),
  [5604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7775),
  [5606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9449),
  [5608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7607),
  [5610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7577),
  [5612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7034),
  [5614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8015),
  [5616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7587),
  [5618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11133),
  [5620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6487),
  [5622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8018),
  [5624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9831),
  [5626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6135),
  [5628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12164),
  [5630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5128),
  [5632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7044),
  [5634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4936),
  [5636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13157),
  [5638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7046),
  [5640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6270),
  [5642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8594),
  [5644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8811),
  [5646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8203),
  [5648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7190),
  [5650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12648),
  [5652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11026),
  [5654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6936),
  [5656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7617),
  [5658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8370),
  [5660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11052),
  [5662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4722),
  [5664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6939),
  [5666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8177),
  [5668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9223),
  [5670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12162),
  [5672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12736),
  [5674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5814),
  [5676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8126),
  [5678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5433),
  [5680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11235),
  [5682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9089),
  [5684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8128),
  [5686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6522),
  [5688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7032),
  [5690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11994),
  [5692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11522),
  [5694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7456),
  [5696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8234),
  [5698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4862),
  [5700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11523),
  [5702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6080),
  [5704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7191),
  [5706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8259),
  [5708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7615),
  [5710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4868),
  [5712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8460),
  [5714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5915),
  [5716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8148),
  [5718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4869),
  [5720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7669),
  [5722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4861),
  [5724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4683),
  [5726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5396),
  [5728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5740),
  [5730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11487),
  [5732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12310),
  [5734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4688),
  [5736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13857),
  [5738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8186),
  [5740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11488),
  [5742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5906),
  [5744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8876),
  [5746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5154),
  [5748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5987),
  [5750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7477),
  [5752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5048),
  [5754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12933),
  [5756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7333),
  [5758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10035),
  [5760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9510),
  [5762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5983),
  [5764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5716),
  [5766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5473),
  [5768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7350),
  [5770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13442),
  [5772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6028),
  [5774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5474),
  [5776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6130),
  [5778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7359),
  [5780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5852),
  [5782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13615),
  [5784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5603),
  [5786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5950),
  [5788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6618),
  [5790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6485),
  [5792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5165),
  [5794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6560),
  [5796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7024),
  [5798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12649),
  [5800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11951),
  [5802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5166),
  [5804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7026),
  [5806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6507),
  [5808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6509),
  [5810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6078),
  [5812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5850),
  [5814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4277),
  [5816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8978),
  [5818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6599),
  [5820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9698),
  [5822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4903),
  [5824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12065),
  [5826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7614),
  [5828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12739),
  [5830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4904),
  [5832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8985),
  [5834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7138),
  [5836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5642),
  [5838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12067),
  [5840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7148),
  [5842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11818),
  [5844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5656),
  [5846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7369),
  [5848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7150),
  [5850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5360),
  [5852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13144),
  [5854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8221),
  [5856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7926),
  [5858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5362),
  [5860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13153),
  [5862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12845),
  [5864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9133),
  [5866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6563),
  [5868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8103),
  [5870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11851),
  [5872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6875),
  [5874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11601),
  [5876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8107),
  [5878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7102),
  [5880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9150),
  [5882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11605),
  [5884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7429),
  [5886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10037),
  [5888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7353),
  [5890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5171),
  [5892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6437),
  [5894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8150),
  [5896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11101),
  [5898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5172),
  [5900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8567),
  [5902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7169),
  [5904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11049),
  [5906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7173),
  [5908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6954),
  [5910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11580),
  [5912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4663),
  [5914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6449),
  [5916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11209),
  [5918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8650),
  [5920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13088),
  [5922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7762),
  [5924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6494),
  [5926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8661),
  [5928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7889),
  [5930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7064),
  [5932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13096),
  [5934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9060),
  [5936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6733),
  [5938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6347),
  [5940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6099),
  [5942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7158),
  [5944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5483),
  [5946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6350),
  [5948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7072),
  [5950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6414),
  [5952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6103),
  [5954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10956),
  [5956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8362),
  [5958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13846),
  [5960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12855),
  [5962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12015),
  [5964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7112),
  [5966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13919),
  [5968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7182),
  [5970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7114),
  [5972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7115),
  [5974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7931),
  [5976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5398),
  [5978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7780),
  [5980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7835),
  [5982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7199),
  [5984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7840),
  [5986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7183),
  [5988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11687),
  [5990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8403),
  [5992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6467),
  [5994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8409),
  [5996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4745),
  [5998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4751),
  [6000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7391),
  [6002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7977),
  [6004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13373),
  [6006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7978),
  [6008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8181),
  [6010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4986),
  [6012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11358),
  [6014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6029),
  [6016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11367),
  [6018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5286),
  [6020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4770),
  [6022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10060),
  [6024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8680),
  [6026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10064),
  [6028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5423),
  [6030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4928),
  [6032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4693),
  [6034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11658),
  [6036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4696),
  [6038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5470),
  [6040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4760),
  [6042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7462),
  [6044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4762),
  [6046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9407),
  [6048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12092),
  [6050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5270),
  [6052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4551),
  [6054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5274),
  [6056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5534),
  [6058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4803),
  [6060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5290),
  [6062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4805),
  [6064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9226),
  [6066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13220),
  [6068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5316),
  [6070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4822),
  [6072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5318),
  [6074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6354),
  [6076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5754),
  [6078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4872),
  [6080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5759),
  [6082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9413),
  [6084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13283),
  [6086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6963),
  [6088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6194),
  [6090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6967),
  [6092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5765),
  [6094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6258),
  [6096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12949),
  [6098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6262),
  [6100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10428),
  [6102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4372),
  [6104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7110),
  [6106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12985),
  [6108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6298),
  [6110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12992),
  [6112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9073),
  [6114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5193),
  [6116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17777),
  [6118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [6120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5507),
  [6122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11782),
  [6124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5192),
  [6126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2523),
  [6128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5193),
  [6130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5135),
  [6132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6415),
  [6134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17420),
  [6136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [6138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6982),
  [6140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11723),
  [6142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6393),
  [6144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2476),
  [6146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6415),
  [6148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6122),
  [6150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11205),
  [6152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11205),
  [6154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11206),
  [6156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11203),
  [6158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17399),
  [6160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [6162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11721),
  [6164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11015),
  [6166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11015),
  [6168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10978),
  [6170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11099),
  [6172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11729),
  [6174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2534),
  [6176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5163),
  [6178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6240),
  [6180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7280),
  [6182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11752),
  [6184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6119),
  [6186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2444),
  [6188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6240),
  [6190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6538),
  [6192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5516),
  [6194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17536),
  [6196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [6198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6503),
  [6200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11761),
  [6202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5514),
  [6204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2469),
  [6206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5516),
  [6208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5503),
  [6210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7856),
  [6212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17401),
  [6214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [6216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8673),
  [6218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11666),
  [6220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7650),
  [6222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2508),
  [6224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7856),
  [6226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7527),
  [6228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5538),
  [6230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17795),
  [6232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [6234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6092),
  [6236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11460),
  [6238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5537),
  [6240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2532),
  [6242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5538),
  [6244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5956),
  [6246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2458),
  [6248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6312),
  [6250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11750),
  [6252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5492),
  [6254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17708),
  [6256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [6258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6443),
  [6260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11753),
  [6262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5489),
  [6264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2451),
  [6266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5492),
  [6268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5705),
  [6270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10635),
  [6272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10635),
  [6274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10573),
  [6276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10588),
  [6278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5525),
  [6280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17548),
  [6282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [6284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6303),
  [6286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11764),
  [6288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5523),
  [6290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2473),
  [6292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5525),
  [6294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5572),
  [6296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2512),
  [6298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5597),
  [6300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7680),
  [6302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8633),
  [6304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11739),
  [6306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7526),
  [6308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2449),
  [6310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7680),
  [6312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7825),
  [6314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11153),
  [6316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11153),
  [6318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11154),
  [6320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11151),
  [6322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7267),
  [6324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7792),
  [6326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11727),
  [6328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7123),
  [6330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2528),
  [6332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7267),
  [6334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7031),
  [6336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11222),
  [6338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11222),
  [6340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11223),
  [6342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11220),
  [6344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6141),
  [6346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17560),
  [6348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [6350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7051),
  [6352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11765),
  [6354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6136),
  [6356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2477),
  [6358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6141),
  [6360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6576),
  [6362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2516),
  [6364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5657),
  [6366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2498),
  [6368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5876),
  [6370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5485),
  [6372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17455),
  [6374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [6376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6308),
  [6378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11747),
  [6380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5481),
  [6382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2441),
  [6384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5485),
  [6386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5665),
  [6388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6548),
  [6390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17494),
  [6392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [6394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6883),
  [6396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11728),
  [6398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6179),
  [6400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2548),
  [6402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6548),
  [6404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6195),
  [6406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10710),
  [6408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10710),
  [6410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10740),
  [6412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10675),
  [6414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17462),
  [6416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [6418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11749),
  [6420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7913),
  [6422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17572),
  [6424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [6426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8215),
  [6428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11766),
  [6430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7912),
  [6432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2481),
  [6434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7913),
  [6436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7465),
  [6438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6834),
  [6440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17392),
  [6442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [6444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8072),
  [6446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11743),
  [6448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6798),
  [6450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2460),
  [6452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6834),
  [6454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7296),
  [6456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6313),
  [6458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17385),
  [6460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [6462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6940),
  [6464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11720),
  [6466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6281),
  [6468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2450),
  [6470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6313),
  [6472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6003),
  [6474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10847),
  [6476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10847),
  [6478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10857),
  [6480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10818),
  [6482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6416),
  [6484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7315),
  [6486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11751),
  [6488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6210),
  [6490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2448),
  [6492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6416),
  [6494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6020),
  [6496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11110),
  [6498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11110),
  [6500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11059),
  [6502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11125),
  [6504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4474),
  [6506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4736),
  [6508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11767),
  [6510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4472),
  [6512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2483),
  [6514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4474),
  [6516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4498),
  [6518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7843),
  [6520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17469),
  [6522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [6524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8562),
  [6526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11755),
  [6528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7838),
  [6530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2454),
  [6532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7843),
  [6534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7649),
  [6536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2465),
  [6538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4504),
  [6540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11669),
  [6542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2497),
  [6544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5067),
  [6546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4937),
  [6548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5162),
  [6550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11768),
  [6552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4935),
  [6554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2487),
  [6556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4937),
  [6558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4934),
  [6560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4874),
  [6562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5291),
  [6564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11731),
  [6566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4811),
  [6568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2559),
  [6570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4874),
  [6572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4943),
  [6574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11732),
  [6576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11734),
  [6578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6199),
  [6580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6862),
  [6582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11733),
  [6584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6002),
  [6586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2561),
  [6588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6199),
  [6590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6337),
  [6592] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11005),
  [6594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11005),
  [6596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11076),
  [6598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11108),
  [6600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5817),
  [6602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17512),
  [6604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [6606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6516),
  [6608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11735),
  [6610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5764),
  [6612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2452),
  [6614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5817),
  [6616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5848),
  [6618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10517),
  [6620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10517),
  [6622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10518),
  [6624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10514),
  [6626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4939),
  [6628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17667),
  [6630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [6632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5168),
  [6634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11769),
  [6636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4938),
  [6638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2489),
  [6640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4939),
  [6642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4959),
  [6644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11667),
  [6646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2500),
  [6648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6727),
  [6650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6233),
  [6652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17679),
  [6654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [6656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7156),
  [6658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11770),
  [6660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6230),
  [6662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2493),
  [6664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6233),
  [6666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6112),
  [6668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6257),
  [6670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17697),
  [6672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [6674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7175),
  [6676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11772),
  [6678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6252),
  [6680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2495),
  [6682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6257),
  [6684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6018),
  [6686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2499),
  [6688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7995),
  [6690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5191),
  [6692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17761),
  [6694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [6696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5497),
  [6698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11778),
  [6700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5190),
  [6702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2514),
  [6704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5191),
  [6706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5112),
  [6708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2562),
  [6710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4395),
  [6712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6378),
  [6714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17763),
  [6716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [6718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7204),
  [6720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11779),
  [6722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6371),
  [6724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2518),
  [6726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6378),
  [6728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6583),
  [6730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2525),
  [6732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4846),
  [6734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17524),
  [6736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [6738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11736),
  [6740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7274),
  [6742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17768),
  [6744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [6746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7850),
  [6748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11780),
  [6750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7272),
  [6752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2520),
  [6754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7274),
  [6756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6959),
  [6758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11737),
  [6760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4925),
  [6762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5104),
  [6764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11758),
  [6766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4916),
  [6768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2462),
  [6770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4925),
  [6772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4900),
  [6774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4626),
  [6776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4924),
  [6778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11781),
  [6780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4625),
  [6782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2522),
  [6784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4626),
  [6786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4574),
  [6788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2526),
  [6790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5857),
  [6792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8149),
  [6794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9251),
  [6796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11738),
  [6798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8637),
  [6800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2439),
  [6802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8149),
  [6804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8152),
  [6806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11463),
  [6808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11463),
  [6810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11495),
  [6812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11461),
  [6814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2527),
  [6816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6431),
  [6818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2530),
  [6820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4469),
  [6822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2471),
  [6824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5197),
  [6826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2505),
  [6828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4610),
  [6830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8809),
  [6832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17791),
  [6834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [6836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9440),
  [6838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11776),
  [6840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8803),
  [6842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2507),
  [6844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8809),
  [6846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8868),
  [6848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12601),
  [6850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12601),
  [6852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12602),
  [6854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12598),
  [6856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2474),
  [6858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6244),
  [6860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2531),
  [6862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4870),
  [6864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2478),
  [6866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6938),
  [6868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4620),
  [6870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4824),
  [6872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11745),
  [6874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4618),
  [6876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2551),
  [6878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4620),
  [6880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4757),
  [6882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2486),
  [6884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4611),
  [6886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2510),
  [6888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4630),
  [6890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2491),
  [6892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5050),
  [6894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2438),
  [6896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5024),
  [6898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9463),
  [6900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3957),
  [6902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4143),
  [6904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10808),
  [6906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3430),
  [6908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9408),
  [6910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2217),
  [6912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3958),
  [6914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12565),
  [6916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9463),
  [6918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10415),
  [6920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11124),
  [6922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4042),
  [6924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3907),
  [6926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3910),
  [6928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4001),
  [6930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4003),
  [6932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4022),
  [6934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3906),
  [6936] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_identifier, 1, 0, 0),
  [6938] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identifier, 1, 0, 0),
  [6940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3979),
  [6942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3996),
  [6944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3908),
  [6946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3909),
  [6948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3911),
  [6950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3914),
  [6952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3924),
  [6954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3926),
  [6956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3912),
  [6958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3913),
  [6960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3919),
  [6962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3920),
  [6964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3915),
  [6966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3916),
  [6968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3917),
  [6970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3918),
  [6972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3921),
  [6974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3922),
  [6976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3940),
  [6978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3944),
  [6980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3929),
  [6982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3935),
  [6984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3927),
  [6986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3928),
  [6988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3939),
  [6990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3950),
  [6992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3930),
  [6994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3934),
  [6996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3931),
  [6998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3933),
  [7000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4024),
  [7002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3975),
  [7004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3936),
  [7006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3937),
  [7008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3943),
  [7010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3945),
  [7012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3941),
  [7014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3942),
  [7016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3946),
  [7018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3947),
  [7020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3948),
  [7022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3949),
  [7024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3923),
  [7026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3925),
  [7028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3953),
  [7030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3954),
  [7032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3938),
  [7034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3991),
  [7036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3959),
  [7038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3905),
  [7040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3964),
  [7042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3965),
  [7044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3962),
  [7046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3963),
  [7048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4002),
  [7050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4017),
  [7052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3968),
  [7054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3969),
  [7056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3971),
  [7058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3972),
  [7060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3973),
  [7062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3974),
  [7064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3990),
  [7066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3994),
  [7068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3977),
  [7070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3978),
  [7072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3984),
  [7074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3985),
  [7076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3982),
  [7078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3983),
  [7080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3980),
  [7082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3981),
  [7084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3988),
  [7086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3989),
  [7088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3986),
  [7090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3987),
  [7092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3995),
  [7094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4005),
  [7096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3992),
  [7098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3993),
  [7100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3999),
  [7102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4000),
  [7104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3997),
  [7106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3998),
  [7108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3967),
  [7110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3970),
  [7112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4004),
  [7114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4006),
  [7116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4007),
  [7118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4011),
  [7120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4009),
  [7122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4010),
  [7124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4013),
  [7126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4014),
  [7128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4015),
  [7130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4016),
  [7132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4018),
  [7134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4019),
  [7136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4023),
  [7138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3966),
  [7140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3956),
  [7142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3961),
  [7144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3952),
  [7146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3955),
  [7148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4151),
  [7150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4169),
  [7152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8752),
  [7154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10172),
  [7156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10245),
  [7158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11027),
  [7160] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enumerators, 3, 0, 0),
  [7162] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enumerators, 2, 0, 0),
  [7164] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerators, 2, 0, 0),
  [7166] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerators, 3, 0, 0),
  [7168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4148),
  [7170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2071),
  [7172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10404),
  [7174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11056),
  [7176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14579),
  [7178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14549),
  [7180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10258),
  [7182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12195),
  [7184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11275),
  [7186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3086),
  [7188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11888),
  [7190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10163),
  [7192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4154),
  [7194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12574),
  [7196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10258),
  [7198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9826),
  [7200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10735),
  [7202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12625),
  [7204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12101),
  [7206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9877),
  [7208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10880),
  [7210] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), REDUCE(sym__if_condition, 1, 4, 0),
  [7213] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), REDUCE(sym__if_condition, 1, 4, 0),
  [7216] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__if_condition, 1, 4, 0),
  [7218] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__if_condition, 1, 4, 0),
  [7220] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [7222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [7224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9899),
  [7226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10966),
  [7228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3198),
  [7230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9836),
  [7232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4153),
  [7234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12425),
  [7236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9899),
  [7238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9990),
  [7240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11309),
  [7242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9904),
  [7244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11325),
  [7246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11259),
  [7248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9963),
  [7250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10902),
  [7252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11535),
  [7254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10291),
  [7256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10995),
  [7258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10020),
  [7260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11265),
  [7262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11297),
  [7264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10971),
  [7266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9841),
  [7268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11294),
  [7270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9847),
  [7272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11295),
  [7274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10024),
  [7276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11136),
  [7278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9902),
  [7280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11324),
  [7282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11699),
  [7284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9739),
  [7286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10752),
  [7288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11042),
  [7290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9977),
  [7292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10742),
  [7294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9763),
  [7296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11195),
  [7298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11516),
  [7300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11020),
  [7302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11300),
  [7304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9954),
  [7306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11308),
  [7308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9799),
  [7310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11188),
  [7312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11167),
  [7314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11674),
  [7316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [7318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11631),
  [7320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7450),
  [7322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11307),
  [7324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2407),
  [7326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11167),
  [7328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10660),
  [7330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14730),
  [7332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9962),
  [7334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10708),
  [7336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10222),
  [7338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10973),
  [7340] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_modifier, 1, 0, 0),
  [7342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10324),
  [7344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10985),
  [7346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10143),
  [7348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11055),
  [7350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10261),
  [7352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10975),
  [7354] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_open_modifier, 1, 0, 0),
  [7356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9403),
  [7358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10459),
  [7360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10153),
  [7362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11130),
  [7364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11518),
  [7366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12166),
  [7368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11519),
  [7370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2409),
  [7372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11518),
  [7374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10890),
  [7376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10282),
  [7378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11102),
  [7380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9719),
  [7382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10656),
  [7384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10019),
  [7386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10783),
  [7388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9931),
  [7390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10945),
  [7392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9828),
  [7394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10667),
  [7396] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_transparent_modifier, 1, 0, 0),
  [7398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10074),
  [7400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10871),
  [7402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9333),
  [7404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10592),
  [7406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9812),
  [7408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10684),
  [7410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_wildcard, 1, 0, 0),
  [7412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3731),
  [7414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9693),
  [7416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9693),
  [7418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9694),
  [7420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9692),
  [7422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3716),
  [7424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7714),
  [7426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7714),
  [7428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7715),
  [7430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7712),
  [7432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3370),
  [7434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9210),
  [7436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9210),
  [7438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9233),
  [7440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8736),
  [7442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3723),
  [7444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9271),
  [7446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9271),
  [7448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9272),
  [7450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9269),
  [7452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3301),
  [7454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10311),
  [7456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10311),
  [7458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10312),
  [7460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10308),
  [7462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3467),
  [7464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7729),
  [7466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7729),
  [7468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7730),
  [7470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7723),
  [7472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3340),
  [7474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10866),
  [7476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10866),
  [7478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10867),
  [7480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10864),
  [7482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3598),
  [7484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9918),
  [7486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9918),
  [7488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9919),
  [7490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9915),
  [7492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3445),
  [7494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10545),
  [7496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10545),
  [7498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10580),
  [7500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10534),
  [7502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3586),
  [7504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9893),
  [7506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9893),
  [7508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9898),
  [7510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9890),
  [7512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3697),
  [7514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9161),
  [7516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9161),
  [7518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9162),
  [7520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9160),
  [7522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3478),
  [7524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10499),
  [7526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10499),
  [7528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10570),
  [7530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10528),
  [7532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3248),
  [7534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9146),
  [7536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9146),
  [7538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9147),
  [7540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9144),
  [7542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3670),
  [7544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10363),
  [7546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10363),
  [7548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10366),
  [7550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10354),
  [7552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3375),
  [7554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9973),
  [7556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9973),
  [7558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10059),
  [7560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10045),
  [7562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3736),
  [7564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10380),
  [7566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10380),
  [7568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10381),
  [7570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10376),
  [7572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3473),
  [7574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8252),
  [7576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8252),
  [7578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8257),
  [7580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8230),
  [7582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3549),
  [7584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10559),
  [7586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10559),
  [7588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10568),
  [7590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10628),
  [7592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3558),
  [7594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10649),
  [7596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10649),
  [7598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10453),
  [7600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10626),
  [7602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3706),
  [7604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9953),
  [7606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9953),
  [7608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9956),
  [7610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9950),
  [7612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3622),
  [7614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6760),
  [7616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6760),
  [7618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6761),
  [7620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6758),
  [7622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3711),
  [7624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10177),
  [7626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10177),
  [7628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10178),
  [7630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10170),
  [7632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3498),
  [7634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10702),
  [7636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10702),
  [7638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10704),
  [7640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10697),
  [7642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3758),
  [7644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9922),
  [7646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9922),
  [7648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9947),
  [7650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9911),
  [7652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3749),
  [7654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9724),
  [7656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9724),
  [7658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9725),
  [7660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9722),
  [7662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3746),
  [7664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8109),
  [7666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8109),
  [7668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8110),
  [7670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8108),
  [7672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3694),
  [7674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10186),
  [7676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10186),
  [7678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10190),
  [7680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10181),
  [7682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3567),
  [7684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8153),
  [7686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8153),
  [7688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8155),
  [7690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8134),
  [7692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3332),
  [7694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10337),
  [7696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10337),
  [7698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10338),
  [7700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10335),
  [7702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3626),
  [7704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8862),
  [7706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8862),
  [7708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8863),
  [7710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8858),
  [7712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3690),
  [7714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9119),
  [7716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9119),
  [7718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9120),
  [7720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9117),
  [7722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3678),
  [7724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7509),
  [7726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7509),
  [7728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7511),
  [7730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7508),
  [7732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3682),
  [7734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9095),
  [7736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9095),
  [7738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9096),
  [7740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9094),
  [7742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3614),
  [7744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10778),
  [7746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10778),
  [7748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10803),
  [7750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10705),
  [7752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3508),
  [7754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9678),
  [7756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9678),
  [7758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9683),
  [7760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9673),
  [7762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3719),
  [7764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11540),
  [7766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11540),
  [7768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11541),
  [7770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11539),
  [7772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3701),
  [7774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10411),
  [7776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10411),
  [7778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10412),
  [7780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10397),
  [7782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3595),
  [7784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9575),
  [7786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9575),
  [7788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9578),
  [7790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9572),
  [7792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3604),
  [7794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10004),
  [7796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10004),
  [7798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10005),
  [7800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10003),
  [7802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3569),
  [7804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8329),
  [7806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8329),
  [7808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8331),
  [7810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8312),
  [7812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3484),
  [7814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10000),
  [7816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10000),
  [7818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10027),
  [7820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9945),
  [7822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3577),
  [7824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9389),
  [7826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9389),
  [7828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9390),
  [7830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9386),
  [7832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3754),
  [7834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9539),
  [7836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9539),
  [7838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9555),
  [7840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9461),
  [7842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3638),
  [7844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9788),
  [7846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9788),
  [7848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9793),
  [7850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9781),
  [7852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3619),
  [7854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10607),
  [7856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10607),
  [7858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10610),
  [7860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10527),
  [7862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3453),
  [7864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10899),
  [7866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10899),
  [7868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10914),
  [7870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10758),
  [7872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3437),
  [7874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10277),
  [7876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10277),
  [7878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10297),
  [7880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10421),
  [7882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3634),
  [7884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8248),
  [7886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8248),
  [7888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8261),
  [7890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8236),
  [7892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3490),
  [7894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11008),
  [7896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11008),
  [7898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11009),
  [7900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10962),
  [7902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3629),
  [7904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8172),
  [7906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8172),
  [7908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8189),
  [7910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8692),
  [7912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3662),
  [7914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10025),
  [7916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10025),
  [7918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10026),
  [7920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10009),
  [7922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3674),
  [7924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10873),
  [7926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10873),
  [7928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10877),
  [7930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10859),
  [7932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3609),
  [7934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10114),
  [7936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10114),
  [7938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10115),
  [7940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10112),
  [7942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3533),
  [7944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10328),
  [7946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10328),
  [7948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10361),
  [7950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10316),
  [7952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3741),
  [7954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10639),
  [7956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10639),
  [7958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10640),
  [7960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10637),
  [7962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3642),
  [7964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9869),
  [7966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9869),
  [7968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9870),
  [7970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9864),
  [7972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3653),
  [7974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9930),
  [7976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9930),
  [7978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9932),
  [7980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9926),
  [7982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3461),
  [7984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10269),
  [7986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10269),
  [7988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10443),
  [7990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10418),
  [7992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3601),
  [7994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10511),
  [7996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10511),
  [7998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10512),
  [8000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10501),
  [8002] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__if_condition, 2, 4, 0),
  [8004] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__if_condition, 2, 4, 0),
  [8006] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_identifier, 1, 0, 7),
  [8008] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stable_identifier, 3, 0, 0),
  [8010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [8012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7671),
  [8014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9224),
  [8016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12518),
  [8018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6358),
  [8020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5399),
  [8022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6062),
  [8024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6139),
  [8026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6646),
  [8028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6030),
  [8030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10298),
  [8032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [8034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9545),
  [8036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9546),
  [8038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12312),
  [8040] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stable_type_identifier, 3, 0, 0),
  [8042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [8044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12420),
  [8046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [8048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7107),
  [8050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9509),
  [8052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7120),
  [8054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14725),
  [8056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14722),
  [8058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12698),
  [8060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4280),
  [8062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8343),
  [8064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8194),
  [8066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8195),
  [8068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8196),
  [8070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4281),
  [8072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13136),
  [8074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14725),
  [8076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14659),
  [8078] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__annotated_type, 1, 0, 0),
  [8080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__annotated_type, 1, 0, 0),
  [8082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3570),
  [8084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8860),
  [8086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1657),
  [8088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12513),
  [8090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12318),
  [8092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15888),
  [8094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12625),
  [8096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4172),
  [8098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12101),
  [8100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12077),
  [8102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9613),
  [8104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9623),
  [8106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12024),
  [8108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12202),
  [8110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16552),
  [8112] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__constructor_application, 1, 0, 0),
  [8114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_application, 1, 0, 0),
  [8116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8009),
  [8118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4340),
  [8120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4341),
  [8122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14283),
  [8124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4323),
  [8126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4324),
  [8128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14381),
  [8130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4310),
  [8132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4311),
  [8134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14237),
  [8136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12321),
  [8138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16036),
  [8140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12195),
  [8142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4170),
  [8144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11888),
  [8146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11923),
  [8148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11822),
  [8150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12317),
  [8152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4149),
  [8154] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation, 2, 0, 3),
  [8156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation, 2, 0, 3),
  [8158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3666),
  [8160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1786),
  [8162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12178),
  [8164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11156),
  [8166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4137),
  [8168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11271),
  [8170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1447),
  [8172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15933),
  [8174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15984),
  [8176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11918),
  [8178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4336),
  [8180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4337),
  [8182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14196),
  [8184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4327),
  [8186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4328),
  [8188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13489),
  [8190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4304),
  [8192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4305),
  [8194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13425),
  [8196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4374),
  [8198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4375),
  [8200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13304),
  [8202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4350),
  [8204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4351),
  [8206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13031),
  [8208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4307),
  [8210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4308),
  [8212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13488),
  [8214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4163),
  [8216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12034),
  [8218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12191),
  [8220] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 5, 0, 0),
  [8222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8924),
  [8224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13128),
  [8226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13038),
  [8228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7390),
  [8230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13064),
  [8232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3284),
  [8234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9180),
  [8236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1692),
  [8238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12336),
  [8240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1756),
  [8242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13183),
  [8244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13184),
  [8246] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_type, 2, 0, 42),
  [8248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17774),
  [8250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [8252] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_type, 2, 0, 42),
  [8254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7468),
  [8256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 3, 0, 0),
  [8258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3747),
  [8260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1660),
  [8262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12222),
  [8264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3784),
  [8266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1672),
  [8268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12258),
  [8270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 4, 0, 0),
  [8272] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 5, 0, 0),
  [8274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17376),
  [8276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3266),
  [8278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11545),
  [8280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11176),
  [8282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17434),
  [8284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [8286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11648),
  [8288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11174),
  [8290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3160),
  [8292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11176),
  [8294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11152),
  [8296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13198),
  [8298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13378),
  [8300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13393),
  [8302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14281),
  [8304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13354),
  [8306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13403),
  [8308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13622),
  [8310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13624),
  [8312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13365),
  [8314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14300),
  [8316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11550),
  [8318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17691),
  [8320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [8322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11872),
  [8324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11547),
  [8326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3403),
  [8328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11550),
  [8330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11509),
  [8332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13206),
  [8334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14165),
  [8336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14414),
  [8338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13462),
  [8340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17738),
  [8342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [8344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3085),
  [8346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11161),
  [8348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14341),
  [8350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14170),
  [8352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14173),
  [8354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14179),
  [8356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17772),
  [8358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [8360] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_type, 1, 0, 0),
  [8362] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_type, 2, 0, 43),
  [8364] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 3, 0, 0),
  [8366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_singleton_type, 3, 0, 0),
  [8368] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_projected_type, 3, 0, 85),
  [8370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3742),
  [8372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8972),
  [8374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1726),
  [8376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12221),
  [8378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13178),
  [8380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17413),
  [8382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [8384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13424),
  [8386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13123),
  [8388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3137),
  [8390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13178),
  [8392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13074),
  [8394] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 4, 0, 0),
  [8396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13107),
  [8398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7532),
  [8400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3469),
  [8402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1651),
  [8404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12315),
  [8406] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__infix_type_choice, 1, 0, 0),
  [8408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__infix_type_choice, 1, 0, 0),
  [8410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type, 1, 0, 0),
  [8412] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type, 1, 0, 0),
  [8414] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_types, 1, 0, 0),
  [8416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17789),
  [8418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [8420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7533),
  [8422] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_identifier, 1, 0, 7),
  [8424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8991),
  [8426] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation, 3, 0, 55),
  [8428] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation, 3, 0, 55),
  [8430] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0),
  [8432] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0),
  [8434] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1786),
  [8437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3675),
  [8439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1790),
  [8441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12185),
  [8443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3683),
  [8445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1791),
  [8447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12187),
  [8449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17800),
  [8451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [8453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7555),
  [8455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11921),
  [8457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1658),
  [8459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3795),
  [8461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1682),
  [8463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12280),
  [8465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5699),
  [8467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17345),
  [8469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [8471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5637),
  [8473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5702),
  [8475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3825),
  [8477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5699),
  [8479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5780),
  [8481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 1, 0, 0),
  [8483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17649),
  [8485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [8487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7616),
  [8489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7946),
  [8491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7566),
  [8493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3100),
  [8495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7616),
  [8497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8045),
  [8499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17781),
  [8501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [8503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7788),
  [8505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7440),
  [8507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7767),
  [8509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3117),
  [8511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7788),
  [8513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7804),
  [8515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3572),
  [8517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1757),
  [8519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12527),
  [8521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3578),
  [8523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1761),
  [8525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12562),
  [8527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5008),
  [8529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17427),
  [8531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [8533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4932),
  [8535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4999),
  [8537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3149),
  [8539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5008),
  [8541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4810),
  [8543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6081),
  [8545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6469),
  [8547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6216),
  [8549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3197),
  [8551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6081),
  [8553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6060),
  [8555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7612),
  [8557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7955),
  [8559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7627),
  [8561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3208),
  [8563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7612),
  [8565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7451),
  [8567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8201),
  [8569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8545),
  [8571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8575),
  [8573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3221),
  [8575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8201),
  [8577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8332),
  [8579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5231),
  [8581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17506),
  [8583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [8585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5114),
  [8587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5213),
  [8589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3236),
  [8591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5231),
  [8593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5372),
  [8595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6470),
  [8597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6162),
  [8599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6368),
  [8601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3258),
  [8603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6470),
  [8605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6423),
  [8607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6383),
  [8609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6120),
  [8611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6239),
  [8613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3278),
  [8615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6383),
  [8617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6474),
  [8619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7731),
  [8621] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 4, 0, 0),
  [8623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 4, 0, 0),
  [8625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8303),
  [8627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8523),
  [8629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8578),
  [8631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3312),
  [8633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8303),
  [8635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8432),
  [8637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9867),
  [8639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17608),
  [8641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [8643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9785),
  [8645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10051),
  [8647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3347),
  [8649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9867),
  [8651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10066),
  [8653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4727),
  [8655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17613),
  [8657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [8659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4701),
  [8661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4726),
  [8663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3355),
  [8665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4727),
  [8667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4750),
  [8669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5137),
  [8671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17619),
  [8673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [8675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5292),
  [8677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5133),
  [8679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3362),
  [8681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5137),
  [8683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5462),
  [8685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5145),
  [8687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5335),
  [8689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5141),
  [8691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3383),
  [8693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5145),
  [8695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5245),
  [8697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7122),
  [8699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7005),
  [8701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7093),
  [8703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3389),
  [8705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7122),
  [8707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7069),
  [8709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17625),
  [8711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [8713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7755),
  [8715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7174),
  [8717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7213),
  [8719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7159),
  [8721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3417),
  [8723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7174),
  [8725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6897),
  [8727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3455),
  [8729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8724),
  [8731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1736),
  [8733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12302),
  [8735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5520),
  [8737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5762),
  [8739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5518),
  [8741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3515),
  [8743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5520),
  [8745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5547),
  [8747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8726),
  [8749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7238),
  [8751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7000),
  [8753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7235),
  [8755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3521),
  [8757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7238),
  [8759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7068),
  [8761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7907),
  [8763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7604),
  [8765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7904),
  [8767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3538),
  [8769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7907),
  [8771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7705),
  [8773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4931),
  [8775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17773),
  [8777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [8779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4882),
  [8781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4930),
  [8783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3563),
  [8785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4931),
  [8787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4893),
  [8789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5528),
  [8791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5480),
  [8793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5527),
  [8795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3571),
  [8797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5528),
  [8799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5927),
  [8801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4076),
  [8803] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__postfix_expression_choice, 1, 0, 0),
  [8805] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_body, 2, 0, 0),
  [8807] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_body, 2, 0, 0),
  [8809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12787),
  [8811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4078),
  [8813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2250),
  [8815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4076),
  [8817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1769),
  [8819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6351),
  [8821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6579),
  [8823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6321),
  [8825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3645),
  [8827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6351),
  [8829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6229),
  [8831] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_prefix_expression, 2, 0, 0),
  [8833] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_prefix_expression, 2, 0, 0),
  [8835] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_expression, 3, 0, 66),
  [8837] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_expression, 3, 0, 66),
  [8839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1750),
  [8841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8042),
  [8843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3575),
  [8845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8873),
  [8847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1674),
  [8849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12554),
  [8851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3583),
  [8853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8879),
  [8855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1694),
  [8857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12568),
  [8859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8084),
  [8861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8974),
  [8863] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 2, 0, 0),
  [8865] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(6358),
  [8868] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(5399),
  [8871] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(6062),
  [8874] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(6139),
  [8877] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(6646),
  [8880] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(6030),
  [8883] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_modifiers_repeat1, 2, 0, 0),
  [8885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8990),
  [8887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9308),
  [8889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8840),
  [8891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3501),
  [8893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8990),
  [8895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8971),
  [8897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17602),
  [8899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [8901] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 2, 0, 0),
  [8903] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 2, 0, 0),
  [8905] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 3, 0, 0),
  [8907] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 3, 0, 0),
  [8909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6699),
  [8911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7208),
  [8913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7386),
  [8915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3291),
  [8917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6699),
  [8919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7258),
  [8921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3787),
  [8923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1675),
  [8925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12262),
  [8927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11820),
  [8929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8930),
  [8931] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0),
  [8933] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0),
  [8935] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8860),
  [8938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8936),
  [8940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17743),
  [8942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [8944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8022),
  [8946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1423),
  [8948] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1756),
  [8951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(816),
  [8953] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 3, 0, 0),
  [8955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1759),
  [8957] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotated_type, 2, 0, 0),
  [8959] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotated_type, 2, 0, 0),
  [8961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1763),
  [8963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9009),
  [8965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7962),
  [8967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17748),
  [8969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [8971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8067),
  [8973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12126),
  [8975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3671),
  [8977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1788),
  [8979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12181),
  [8981] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 3, 0, 0),
  [8983] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 4, 0, 0),
  [8985] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 5, 0, 0),
  [8987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11968),
  [8989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12889),
  [8991] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1660),
  [8994] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_wildcard, 1, 0, 0),
  [8996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14861),
  [8998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3750),
  [9000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1661),
  [9002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12225),
  [9004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12654),
  [9006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14559),
  [9008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3295),
  [9010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1764),
  [9012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12367),
  [9014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3759),
  [9016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1664),
  [9018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12234),
  [9020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17806),
  [9022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [9024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7582),
  [9026] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8924),
  [9029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3775),
  [9031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1666),
  [9033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12245),
  [9035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3154),
  [9037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9075),
  [9039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1701),
  [9041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12569),
  [9043] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1672),
  [9046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12714),
  [9048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17776),
  [9050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [9052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7475),
  [9054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17778),
  [9056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [9058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7482),
  [9060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3698),
  [9062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8947),
  [9064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1693),
  [9066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12201),
  [9068] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_stable_type_identifier, 3, 0, 0),
  [9070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7499),
  [9072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8869),
  [9074] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_type, 1, 0, 0),
  [9076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3755),
  [9078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8977),
  [9080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1739),
  [9082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12229),
  [9084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8877),
  [9086] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generic_type, 2, 0, 43),
  [9088] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_singleton_type, 3, 0, 0),
  [9090] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_projected_type, 3, 0, 85),
  [9092] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 4, 0, 0),
  [9094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7539),
  [9096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1729),
  [9098] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 5, 0, 0),
  [9100] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1651),
  [9103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3475),
  [9105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1799),
  [9107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12328),
  [9109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1667),
  [9111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1710),
  [9113] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9180),
  [9116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17793),
  [9118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [9120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7540),
  [9122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3164),
  [9124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1706),
  [9126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12231),
  [9128] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1757),
  [9131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12944),
  [9133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1676),
  [9135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11884),
  [9137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3133),
  [9139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1773),
  [9141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12543),
  [9143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17801),
  [9145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [9147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7561),
  [9149] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8991),
  [9152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1761),
  [9155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17796),
  [9157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [9159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7546),
  [9161] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8972),
  [9164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8994),
  [9166] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8974),
  [9169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7869),
  [9171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17518),
  [9173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [9175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7414),
  [9177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11971),
  [9179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12076),
  [9181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7914),
  [9183] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1658),
  [9186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3523),
  [9188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1742),
  [9190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12397),
  [9192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3789),
  [9194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1678),
  [9196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12266),
  [9198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17631),
  [9200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [9202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7777),
  [9204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3509),
  [9206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8758),
  [9208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1708),
  [9210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12376),
  [9212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12016),
  [9214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3534),
  [9216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8778),
  [9218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1715),
  [9220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12406),
  [9222] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15),
  [9224] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17613),
  [9227] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(43),
  [9230] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15),
  [9232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12876),
  [9234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1777),
  [9236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8730),
  [9238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1663),
  [9240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12963),
  [9242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1784),
  [9244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3587),
  [9246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1765),
  [9248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12573),
  [9250] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1682),
  [9253] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1750),
  [9256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7514),
  [9258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1689),
  [9260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1389),
  [9262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15009),
  [9264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1796),
  [9266] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1790),
  [9269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1424),
  [9271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8975),
  [9273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8927),
  [9275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17775),
  [9277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [9279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7471),
  [9281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8980),
  [9283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15428),
  [9285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17790),
  [9287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [9289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7536),
  [9291] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_annotation_repeat1, 1, 0, 0),
  [9293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3796),
  [9295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1684),
  [9297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12283),
  [9299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1573),
  [9301] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8726),
  [9304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3623),
  [9306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1774),
  [9308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12608),
  [9310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1527),
  [9312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(840),
  [9314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3788),
  [9316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8996),
  [9318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1770),
  [9320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12264),
  [9322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7565),
  [9324] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1791),
  [9327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1607),
  [9329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3798),
  [9331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1685),
  [9333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12286),
  [9335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8986),
  [9337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3357),
  [9339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9245),
  [9341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1714),
  [9343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12633),
  [9345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1110),
  [9347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12070),
  [9349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(864),
  [9351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9199),
  [9353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12091),
  [9355] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17427),
  [9358] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(13),
  [9361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3852),
  [9363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0),
  [9365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3850),
  [9367] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0),
  [9369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2271),
  [9371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3852),
  [9373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(529),
  [9375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(828),
  [9377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17803),
  [9379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [9381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7568),
  [9383] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1661),
  [9386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14848),
  [9388] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1664),
  [9391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12779),
  [9393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17807),
  [9395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [9397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7584),
  [9399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12168),
  [9401] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1666),
  [9404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17808),
  [9406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [9408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7588),
  [9410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3781),
  [9412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1669),
  [9414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12254),
  [9416] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84),
  [9418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84),
  [9420] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7468),
  [9423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3635),
  [9425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1779),
  [9427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12618),
  [9429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7943),
  [9431] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1675),
  [9434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1677),
  [9436] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1759),
  [9439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12148),
  [9441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1283),
  [9443] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unit, 2, 0, 0),
  [9445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unit, 2, 0, 0),
  [9447] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bindings, 2, 0, 0),
  [9449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15104),
  [9451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3544),
  [9453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8808),
  [9455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1725),
  [9457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12433),
  [9459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15313),
  [9461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1301),
  [9463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11829),
  [9465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3646),
  [9467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1780),
  [9469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12629),
  [9471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17758),
  [9473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [9475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7395),
  [9477] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1764),
  [9480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12664),
  [9482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1662),
  [9484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1506),
  [9486] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8873),
  [9489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3336),
  [9491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1775),
  [9493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12575),
  [9495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8771),
  [9497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17685),
  [9499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [9501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7885),
  [9503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3799),
  [9505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1686),
  [9507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12288),
  [9509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12123),
  [9511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3592),
  [9513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8882),
  [9515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1699),
  [9517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12578),
  [9519] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 1, 0, 0),
  [9521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_definition_repeat1, 1, 0, 0),
  [9523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7401),
  [9525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1797),
  [9527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11963),
  [9529] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17773),
  [9532] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(83),
  [9535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12782),
  [9537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1722),
  [9539] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1763),
  [9542] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1788),
  [9545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3615),
  [9547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8893),
  [9549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1707),
  [9551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12597),
  [9553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7418),
  [9555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1390),
  [9557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12130),
  [9559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3707),
  [9561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8958),
  [9563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1696),
  [9565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12207),
  [9567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11975),
  [9569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7510),
  [9571] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8724),
  [9574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3687),
  [9576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1792),
  [9578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12190),
  [9580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9002),
  [9582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12138),
  [9584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3695),
  [9586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1795),
  [9588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12196),
  [9590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17764),
  [9592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [9594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7424),
  [9596] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8930),
  [9599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1744),
  [9601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3596),
  [9603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1768),
  [9605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12582),
  [9607] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8936),
  [9610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3702),
  [9612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1798),
  [9614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12203),
  [9616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8881),
  [9618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1572),
  [9620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1641),
  [9622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17448),
  [9624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [9626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7515),
  [9628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2209),
  [9630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3712),
  [9632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1652),
  [9634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12209),
  [9636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8900),
  [9638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1452),
  [9640] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1729),
  [9643] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8869),
  [9646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(852),
  [9648] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1799),
  [9651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9088),
  [9653] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8879),
  [9656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11866),
  [9658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1114),
  [9660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3486),
  [9662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1733),
  [9664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12338),
  [9666] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(8009),
  [9669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9013),
  [9671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1285),
  [9673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1038),
  [9675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9015),
  [9677] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8877),
  [9680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1741),
  [9682] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9009),
  [9685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12103),
  [9687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1731),
  [9689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17798),
  [9691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [9693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7550),
  [9695] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8994),
  [9698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11946),
  [9700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8963),
  [9702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17785),
  [9704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [9706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7516),
  [9708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3724),
  [9710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1655),
  [9712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12214),
  [9714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9017),
  [9716] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1663),
  [9719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17530),
  [9721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [9723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7472),
  [9725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11835),
  [9727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3766),
  [9729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1665),
  [9731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12240),
  [9733] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 83),
  [9735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 83),
  [9737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3777),
  [9739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1668),
  [9741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12249),
  [9743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3539),
  [9745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1746),
  [9747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12426),
  [9749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17809),
  [9751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [9753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7592),
  [9755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3783),
  [9757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1671),
  [9759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12255),
  [9761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11902),
  [9763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17780),
  [9765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [9767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7495),
  [9769] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1678),
  [9772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3791),
  [9774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1679),
  [9776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12272),
  [9778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17769),
  [9780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [9782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7445),
  [9784] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1684),
  [9787] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1685),
  [9790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11913),
  [9792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1075),
  [9794] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1742),
  [9797] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1765),
  [9800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1767),
  [9802] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8927),
  [9805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12074),
  [9807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12032),
  [9809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12712),
  [9811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1748),
  [9813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3932),
  [9815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4021),
  [9817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2203),
  [9819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3932),
  [9821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(530),
  [9823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4031),
  [9825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4033),
  [9827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2254),
  [9829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4031),
  [9831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(535),
  [9833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1507),
  [9835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3976),
  [9837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4020),
  [9839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2047),
  [9841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3976),
  [9843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(531),
  [9845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1353),
  [9847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1594),
  [9849] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1689),
  [9852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1772),
  [9854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4043),
  [9856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__postfix_expression_choice, 1, 0, 0),
  [9858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4044),
  [9860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4043),
  [9862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(553),
  [9864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2116),
  [9866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1584),
  [9868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2066),
  [9870] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17506),
  [9873] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(25),
  [9876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7541),
  [9878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1703),
  [9880] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8947),
  [9883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17779),
  [9885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [9887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7487),
  [9889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1337),
  [9891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1560),
  [9893] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indented_cases, 3, 0, 0),
  [9895] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indented_cases, 3, 0, 0),
  [9897] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1706),
  [9900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indented_block, 4, 0, 0),
  [9902] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indented_block, 4, 0, 0),
  [9904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12097),
  [9906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1248),
  [9908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12716),
  [9910] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__end_marker, 2, 0, 0),
  [9912] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__end_marker, 2, 0, 0),
  [9914] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__end_marker, 2, 0, 13),
  [9916] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__end_marker, 2, 0, 13),
  [9918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1712),
  [9920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3377),
  [9922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9276),
  [9924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1740),
  [9926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12208),
  [9928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12763),
  [9930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3214),
  [9932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1717),
  [9934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12189),
  [9936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1745),
  [9938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17783),
  [9940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [9942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7506),
  [9944] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1774),
  [9947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1789),
  [9949] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7390),
  [9952] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9075),
  [9955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1261),
  [9957] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_block, 3, 0, 0),
  [9959] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_block, 3, 0, 0),
  [9961] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1796),
  [9964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9222),
  [9966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3234),
  [9968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1728),
  [9970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12572),
  [9972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3630),
  [9974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1778),
  [9976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12616),
  [9978] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modifiers, 1, 0, 0),
  [9980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15849),
  [9982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8939),
  [9984] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9199),
  [9987] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17619),
  [9990] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(44),
  [9993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2137),
  [9995] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17667),
  [9998] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(52),
  [10001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8741),
  [10003] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7532),
  [10006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4034),
  [10008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4029),
  [10010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2174),
  [10012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4034),
  [10014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(532),
  [10016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14787),
  [10018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8988),
  [10020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2068),
  [10022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1408),
  [10024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7449),
  [10026] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7533),
  [10029] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_body, 1, 0, 0),
  [10031] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_body, 1, 0, 0),
  [10033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__braced_template_body, 2, 0, 0),
  [10035] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__braced_template_body, 2, 0, 0),
  [10037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15083),
  [10039] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__braced_template_body, 3, 0, 0),
  [10041] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__braced_template_body, 3, 0, 0),
  [10043] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7755),
  [10046] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__indented_template_body, 4, 0, 0),
  [10048] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__indented_template_body, 4, 0, 0),
  [10050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__indented_template_body, 5, 0, 0),
  [10052] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__indented_template_body, 5, 0, 0),
  [10054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12827),
  [10056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1695),
  [10058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4056),
  [10060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4062),
  [10062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4056),
  [10064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15868),
  [10066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16001),
  [10068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15853),
  [10070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11960),
  [10072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16108),
  [10074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1484),
  [10076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3720),
  [10078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8964),
  [10080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1705),
  [10082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12213),
  [10084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17760),
  [10086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [10088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7409),
  [10090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7522),
  [10092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16069),
  [10094] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8730),
  [10097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8942),
  [10099] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_access_modifier, 1, 0, 0),
  [10101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12875),
  [10103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_access_modifier, 1, 0, 0),
  [10105] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8975),
  [10108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3405),
  [10110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1713),
  [10112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12253),
  [10114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(977),
  [10116] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8977),
  [10119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3192),
  [10121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9097),
  [10123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1688),
  [10125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12244),
  [10127] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indented_block, 3, 0, 0),
  [10129] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indented_block, 3, 0, 0),
  [10131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7831),
  [10133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3425),
  [10135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1724),
  [10137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12292),
  [10139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8886),
  [10141] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8980),
  [10144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1618),
  [10146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1629),
  [10148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3480),
  [10150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1732),
  [10152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12332),
  [10154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8954),
  [10156] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8986),
  [10159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8912),
  [10161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8914),
  [10163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3227),
  [10165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9125),
  [10167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1718),
  [10169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12375),
  [10171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12082),
  [10173] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7555),
  [10176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3627),
  [10178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1776),
  [10180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12614),
  [10182] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7582),
  [10185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17804),
  [10187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [10189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7574),
  [10191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3559),
  [10193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1753),
  [10195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12470),
  [10197] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1686),
  [10200] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7482),
  [10203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12018),
  [10205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17799),
  [10207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [10209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7552),
  [10211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1187),
  [10213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17578),
  [10215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [10217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7620),
  [10219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9311),
  [10221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12079),
  [10223] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9013),
  [10226] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(3661),
  [10229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(521),
  [10231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1119),
  [10233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1464),
  [10235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4027),
  [10237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4026),
  [10239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2128),
  [10241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4027),
  [10243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(533),
  [10245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4045),
  [10247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4037),
  [10249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2101),
  [10251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4045),
  [10253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(538),
  [10255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4030),
  [10257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4028),
  [10259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2224),
  [10261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4030),
  [10263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(534),
  [10265] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1768),
  [10268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4041),
  [10270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4038),
  [10272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2056),
  [10274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4041),
  [10276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(543),
  [10278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17797),
  [10280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [10282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7548),
  [10284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17765),
  [10286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [10288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7432),
  [10290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1323),
  [10292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12105),
  [10294] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9015),
  [10297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1236),
  [10299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1547),
  [10301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2196),
  [10303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2038),
  [10305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1481),
  [10307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9516),
  [10309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3230),
  [10311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4167),
  [10313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12298),
  [10315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11051),
  [10317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9497),
  [10319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4152),
  [10321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2091),
  [10323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11036),
  [10325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4173),
  [10327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9516),
  [10329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4147),
  [10331] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9088),
  [10334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12063),
  [10336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8984),
  [10338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8968),
  [10340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7594),
  [10342] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8881),
  [10345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1711),
  [10347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15160),
  [10349] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17345),
  [10352] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(5),
  [10355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15390),
  [10357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2044),
  [10359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3391),
  [10361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9292),
  [10363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1794),
  [10365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12236),
  [10367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13018),
  [10369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1723),
  [10371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1754),
  [10373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8719),
  [10375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(523),
  [10377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9107),
  [10379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4048),
  [10381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4035),
  [10383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2060),
  [10385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4048),
  [10387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(539),
  [10389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12089),
  [10391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11959),
  [10393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3550),
  [10395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1749),
  [10397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12439),
  [10399] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1652),
  [10402] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 2, 0, 0),
  [10404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2, 0, 0),
  [10406] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 0),
  [10408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 0),
  [10410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7957),
  [10412] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_splice_expression, 2, 0, 0),
  [10414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_splice_expression, 2, 0, 0),
  [10416] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generic_function, 2, 0, 19),
  [10418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_function, 2, 0, 19),
  [10420] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 2, 0, 20),
  [10422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 2, 0, 20),
  [10424] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3, 0, 0),
  [10426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3, 0, 0),
  [10428] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instance_expression, 3, 0, 15),
  [10430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_expression, 3, 0, 15),
  [10432] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_expression, 3, 0, 64),
  [10434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 3, 0, 64),
  [10436] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_colon_argument, 1, 0, 0),
  [10438] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_colon_argument, 1, 0, 0),
  [10440] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 3, 0, 67),
  [10442] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 3, 0, 67),
  [10444] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_expression, 4, 0, 0),
  [10446] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_expression, 4, 0, 0),
  [10448] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_splice_expression, 4, 0, 0),
  [10450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_splice_expression, 4, 0, 0),
  [10452] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_expression, 5, 0, 0),
  [10454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_expression, 5, 0, 0),
  [10456] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_colon_argument, 3, 0, 138),
  [10458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_colon_argument, 3, 0, 138),
  [10460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12134),
  [10462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12042),
  [10464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8735),
  [10466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8987),
  [10468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [10470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7810),
  [10472] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8900),
  [10475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3555),
  [10477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8836),
  [10479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1738),
  [10481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12455),
  [10483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12995),
  [10485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1793),
  [10487] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type, 1, 0, 0), SHIFT(17643),
  [10490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1354),
  [10492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13013),
  [10494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1743),
  [10496] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quote_expression, 2, 0, 0),
  [10498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quote_expression, 2, 0, 0),
  [10500] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolated_string_expression, 2, 0, 21),
  [10502] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolated_string_expression, 2, 0, 21),
  [10504] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolated_string, 2, 0, 0),
  [10506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolated_string, 2, 0, 0),
  [10508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quote_expression, 4, 0, 0),
  [10510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quote_expression, 4, 0, 0),
  [10512] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolated_string, 3, 0, 0),
  [10514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolated_string, 3, 0, 0),
  [10516] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1669),
  [10519] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9245),
  [10522] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__constructor_application, 2, 0, 41),
  [10524] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_application, 2, 0, 41),
  [10526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1653),
  [10528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17794),
  [10530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [10532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7543),
  [10534] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17761),
  [10537] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(71),
  [10540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12665),
  [10542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1683),
  [10544] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1775),
  [10547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8798),
  [10549] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8996),
  [10552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17713),
  [10554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [10556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7935),
  [10558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11955),
  [10560] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7731),
  [10563] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1797),
  [10566] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1780),
  [10569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8989),
  [10571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9148),
  [10573] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 1, 0, 0),
  [10575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 1, 0, 0),
  [10577] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__non_null_literal, 1, 0, 0),
  [10579] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__non_null_literal, 1, 0, 0),
  [10581] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean_literal, 1, 0, 0),
  [10583] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_literal, 1, 0, 0),
  [10585] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17777),
  [10588] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(87),
  [10591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15139),
  [10593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15164),
  [10595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3658),
  [10597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1783),
  [10599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12638),
  [10601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17787),
  [10603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [10605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7524),
  [10607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2147),
  [10609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1444),
  [10611] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1773),
  [10614] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1798),
  [10617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4039),
  [10619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4036),
  [10621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2163),
  [10623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4039),
  [10625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(541),
  [10627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1700),
  [10629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2242),
  [10631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [10633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7441),
  [10635] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1744),
  [10638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11990),
  [10640] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1677),
  [10643] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(8084),
  [10646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11786),
  [10648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12122),
  [10650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3419),
  [10652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1720),
  [10654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12282),
  [10656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3793),
  [10658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1681),
  [10660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12275),
  [10662] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_type, 3, 0, 66),
  [10664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_type, 3, 0, 66),
  [10666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(522),
  [10668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1372),
  [10670] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8758),
  [10673] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type, 1, 0, 0), SHIFT(17767),
  [10676] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9002),
  [10679] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8771),
  [10682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12136),
  [10684] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8778),
  [10687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8904),
  [10689] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1792),
  [10692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8907),
  [10694] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7475),
  [10697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11917),
  [10699] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1795),
  [10702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2133),
  [10704] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__refinement, 1, 0, 39),
  [10706] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__refinement, 1, 0, 39),
  [10708] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_type, 2, 0, 40),
  [10710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_type, 2, 0, 40),
  [10712] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_type, 3, 0, 42),
  [10714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_type, 3, 0, 42),
  [10716] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(8022),
  [10719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9004),
  [10721] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(8042),
  [10724] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(8067),
  [10727] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1741),
  [10730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1211),
  [10732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11973),
  [10734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1319),
  [10736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2232),
  [10738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4049),
  [10740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4057),
  [10742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2186),
  [10744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4049),
  [10746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(552),
  [10748] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8893),
  [10751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4050),
  [10753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4053),
  [10755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2262),
  [10757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4050),
  [10759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(558),
  [10761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12158),
  [10763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12017),
  [10765] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_transparent_modifier, 1, 0, 0),
  [10767] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8939),
  [10770] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17455),
  [10773] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17),
  [10776] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9222),
  [10779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15496),
  [10781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2155),
  [10783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12159),
  [10785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [10787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7686),
  [10789] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1779),
  [10792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15789),
  [10794] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1655),
  [10797] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8942),
  [10800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2083),
  [10802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17771),
  [10804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [10806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7461),
  [10808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8920),
  [10810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1223),
  [10812] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1748),
  [10815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1371),
  [10817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2046),
  [10819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12141),
  [10821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14870),
  [10823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12044),
  [10825] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1772),
  [10828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4051),
  [10830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4052),
  [10832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2157),
  [10834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4051),
  [10836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(548),
  [10838] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_capture_pattern, 3, 0, 91),
  [10840] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_capture_pattern, 3, 0, 91),
  [10842] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7561),
  [10845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2218),
  [10847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13009),
  [10849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1698),
  [10851] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_modifier, 1, 0, 0),
  [10853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13016),
  [10855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12904),
  [10857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [10859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7709),
  [10861] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9017),
  [10864] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1671),
  [10867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17723),
  [10869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [10871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7947),
  [10873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(611),
  [10875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2265),
  [10877] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alternative_pattern, 3, 0, 0),
  [10879] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alternative_pattern, 3, 0, 0),
  [10881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2075),
  [10883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11943),
  [10885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9007),
  [10887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8828),
  [10889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3651),
  [10891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1781),
  [10893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12632),
  [10895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17733),
  [10897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [10899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7976),
  [10901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11832),
  [10903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17805),
  [10905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [10907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7579),
  [10909] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8988),
  [10912] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1746),
  [10915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4055),
  [10917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4054),
  [10919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2088),
  [10921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4055),
  [10923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(556),
  [10925] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_pattern, 3, 0, 66),
  [10927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_pattern, 3, 0, 66),
  [10929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12043),
  [10931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2261),
  [10933] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7536),
  [10936] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7777),
  [10939] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17536),
  [10942] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(30),
  [10945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3732),
  [10947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1656),
  [10949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12217),
  [10951] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1731),
  [10954] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8954),
  [10957] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7539),
  [10960] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17795),
  [10963] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(105),
  [10966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8847),
  [10968] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_access_qualifier, 3, 0, 0),
  [10970] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_access_qualifier, 3, 0, 0),
  [10972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3123),
  [10974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9050),
  [10976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1782),
  [10978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12436),
  [10980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11912),
  [10982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17637),
  [10984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [10986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7800),
  [10988] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8914),
  [10991] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7962),
  [10994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1751),
  [10996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17766),
  [10998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [11000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7436),
  [11002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11981),
  [11004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4058),
  [11006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4061),
  [11008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2273),
  [11010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4058),
  [11012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(544),
  [11014] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8886),
  [11017] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9224),
  [11020] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7540),
  [11023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1709),
  [11025] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_modifiers_repeat1, 1, 0, 0),
  [11027] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17548),
  [11030] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(32),
  [11033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [11035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7918),
  [11037] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7471),
  [11040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(879),
  [11042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8715),
  [11044] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1713),
  [11047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4059),
  [11049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12960),
  [11051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4060),
  [11053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2089),
  [11055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4059),
  [11057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(545),
  [11059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12021),
  [11061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3411),
  [11063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1716),
  [11065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12268),
  [11067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11812),
  [11069] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_access_modifier, 2, 0, 0),
  [11071] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_access_modifier, 2, 0, 0),
  [11073] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1679),
  [11076] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1767),
  [11079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3326),
  [11081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12526),
  [11083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1747),
  [11085] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7546),
  [11088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12039),
  [11090] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type, 1, 0, 0), SHIFT(17596),
  [11093] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1665),
  [11096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15511),
  [11098] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7414),
  [11101] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type, 1, 0, 0), SHIFT(17476),
  [11104] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8958),
  [11107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7710),
  [11109] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7499),
  [11112] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1776),
  [11115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11964),
  [11117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12116),
  [11119] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8963),
  [11122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11846),
  [11124] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8808),
  [11127] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8882),
  [11130] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1733),
  [11133] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1668),
  [11136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3500),
  [11138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1737),
  [11140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12354),
  [11142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3241),
  [11144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1734),
  [11146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12197),
  [11148] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_open_modifier, 1, 0, 0),
  [11150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3171),
  [11152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13001),
  [11154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12438),
  [11156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11226),
  [11158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4139),
  [11160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(862),
  [11162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4157),
  [11164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4174),
  [11166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3173),
  [11168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(874),
  [11170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17584),
  [11172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [11174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7646),
  [11176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3136),
  [11178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4179),
  [11180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12135),
  [11182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11661),
  [11184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11662),
  [11186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8962),
  [11188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11663),
  [11190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4123),
  [11192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11503),
  [11194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11817),
  [11196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4071),
  [11198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4072),
  [11200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2257),
  [11202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4071),
  [11204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(600),
  [11206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1595),
  [11208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2233),
  [11210] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1653),
  [11213] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_opaque_modifier, 1, 0, 0),
  [11215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3380),
  [11217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(936),
  [11219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3392),
  [11221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(939),
  [11223] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7424),
  [11226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14061),
  [11228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14112),
  [11230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17500),
  [11232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [11234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7968),
  [11236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3821),
  [11238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(887),
  [11240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3822),
  [11242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(888),
  [11244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12440),
  [11246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12482),
  [11248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11887),
  [11250] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9004),
  [11253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13268),
  [11255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17590),
  [11257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [11259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7687),
  [11261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13288),
  [11263] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7584),
  [11266] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modifiers, 1, 0, 0),
  [11268] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9125),
  [11271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9319),
  [11273] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1711),
  [11276] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7588),
  [11279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11254),
  [11281] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8904),
  [11284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1727),
  [11286] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1717),
  [11289] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2572),
  [11292] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), REDUCE(sym_binding, 1, 10, 2),
  [11295] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17560),
  [11298] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(34),
  [11301] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1723),
  [11304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12688),
  [11306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1760),
  [11308] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1749),
  [11311] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7395),
  [11314] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1728),
  [11317] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8912),
  [11320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4063),
  [11322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4064),
  [11324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2102),
  [11326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4063),
  [11328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(565),
  [11330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15299),
  [11332] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1778),
  [11335] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7514),
  [11338] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8964),
  [11341] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type, 1, 0, 0), SHIFT(46),
  [11344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11911),
  [11346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8970),
  [11348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12046),
  [11350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3458),
  [11352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1425),
  [11354] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8968),
  [11357] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17679),
  [11360] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(53),
  [11363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3489),
  [11365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1548),
  [11367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11853),
  [11369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12878),
  [11371] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17697),
  [11374] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(56),
  [11377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8755),
  [11379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17788),
  [11381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [11383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7528),
  [11385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4068),
  [11387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4070),
  [11389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2188),
  [11391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4068),
  [11393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(563),
  [11395] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17763),
  [11398] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(73),
  [11401] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9276),
  [11404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14951),
  [11406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11938),
  [11408] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1783),
  [11411] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9311),
  [11414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12096),
  [11416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12107),
  [11418] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1681),
  [11421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17770),
  [11423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [11425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7455),
  [11427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4125),
  [11429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11122),
  [11431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1762),
  [11433] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1700),
  [11436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3257),
  [11438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12545),
  [11440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11657),
  [11442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2403),
  [11444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2090),
  [11446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4140),
  [11448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4144),
  [11450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4142),
  [11452] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7869),
  [11455] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7885),
  [11458] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8984),
  [11461] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8741),
  [11464] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7914),
  [11467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9155),
  [11469] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type, 1, 0, 0), SHIFT(75),
  [11472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12681),
  [11474] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8987),
  [11477] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1724),
  [11480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12045),
  [11482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15642),
  [11484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4066),
  [11486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12699),
  [11488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4074),
  [11490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2194),
  [11492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4066),
  [11494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(574),
  [11496] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8989),
  [11499] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7515),
  [11502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3310),
  [11504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1504),
  [11506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3311),
  [11508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1530),
  [11510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12053),
  [11512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2400),
  [11514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1752),
  [11516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11517),
  [11518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10886),
  [11520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4091),
  [11522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11289),
  [11524] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9097),
  [11527] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1753),
  [11530] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8798),
  [11533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10920),
  [11535] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1732),
  [11538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2248),
  [11540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(575),
  [11542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1730),
  [11544] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7565),
  [11547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3492),
  [11549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1735),
  [11551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12347),
  [11553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15544),
  [11555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2347),
  [11557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(564),
  [11559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1702),
  [11561] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_type, 1, 0, 0),
  [11563] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_type, 1, 0, 0),
  [11565] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7568),
  [11568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1529),
  [11570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8915),
  [11572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2173),
  [11574] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type, 1, 0, 0), SHIFT(17488),
  [11577] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1656),
  [11580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3568),
  [11582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8855),
  [11584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1785),
  [11586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12496),
  [11588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8748),
  [11590] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1751),
  [11593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11876),
  [11595] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9148),
  [11598] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type, 1, 0, 0), SHIFT(38),
  [11601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12120),
  [11603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [11605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7853),
  [11607] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1781),
  [11610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12762),
  [11612] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7592),
  [11615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3786),
  [11617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1673),
  [11619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12261),
  [11621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11932),
  [11623] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type, 1, 0, 0), SHIFT(17661),
  [11626] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7510),
  [11629] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17768),
  [11632] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(78),
  [11635] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9107),
  [11638] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9292),
  [11641] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17367),
  [11644] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(6),
  [11647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1766),
  [11649] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7516),
  [11652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12144),
  [11654] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8907),
  [11657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1007),
  [11659] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8920),
  [11662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2073),
  [11664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2074),
  [11666] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7418),
  [11669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12113),
  [11671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2092),
  [11673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15795),
  [11675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2037),
  [11677] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8719),
  [11680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2230),
  [11682] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1709),
  [11685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12099),
  [11687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2118),
  [11689] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7487),
  [11692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12011),
  [11694] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8735),
  [11697] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7472),
  [11700] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7550),
  [11703] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1716),
  [11706] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17392),
  [11709] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(8),
  [11712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12111),
  [11714] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7401),
  [11717] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1720),
  [11720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2166),
  [11722] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7943),
  [11725] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7495),
  [11728] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1734),
  [11731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2165),
  [11733] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17462),
  [11736] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(18),
  [11739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4075),
  [11741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4077),
  [11743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2061),
  [11745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4075),
  [11747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(603),
  [11749] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7445),
  [11752] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7409),
  [11755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_case_class_pattern_repeat1, 2, 0, 0),
  [11757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11831),
  [11759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2180),
  [11761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(917),
  [11763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15392),
  [11765] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8828),
  [11768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2215),
  [11770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13643),
  [11772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13888),
  [11774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13637),
  [11776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3188),
  [11778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13643),
  [11780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13807),
  [11782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2070),
  [11784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11924),
  [11786] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8836),
  [11789] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7506),
  [11792] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9007),
  [11795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7987),
  [11797] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8847),
  [11800] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7432),
  [11803] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8970),
  [11806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11997),
  [11808] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7548),
  [11811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [11813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7832),
  [11815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1755),
  [11817] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7522),
  [11820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15375),
  [11822] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8915),
  [11825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2059),
  [11827] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9319),
  [11830] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7574),
  [11833] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7552),
  [11836] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7935),
  [11839] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_lambda, 5, 0, 168),
  [11841] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_lambda, 5, 0, 168),
  [11843] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(1447),
  [11846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11889),
  [11848] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7449),
  [11851] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1762),
  [11854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8992),
  [11856] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17572),
  [11859] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(36),
  [11862] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type, 1, 0, 0), SHIFT(17655),
  [11865] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_expression, 4, 0, 115),
  [11867] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_expression, 4, 0, 115),
  [11869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12050),
  [11871] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_type, 3, 0, 0),
  [11873] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_type, 3, 0, 0),
  [11875] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__indented_type_cases, 3, 0, 0),
  [11877] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__indented_type_cases, 3, 0, 0),
  [11879] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__arrow_then_type, 2, 0, 10),
  [11881] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__arrow_then_type, 2, 0, 10),
  [11883] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1688),
  [11886] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17469),
  [11889] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(19),
  [11892] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8715),
  [11895] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7543),
  [11898] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__structural_type, 1, 0, 8),
  [11900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__structural_type, 1, 0, 8),
  [11902] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_lambda, 6, 0, 179),
  [11904] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_lambda, 6, 0, 179),
  [11906] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7541),
  [11909] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7441),
  [11912] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_lambda, 6, 0, 180),
  [11914] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_lambda, 6, 0, 180),
  [11916] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7620),
  [11919] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9155),
  [11922] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_type, 2, 0, 79),
  [11924] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_type, 2, 0, 79),
  [11926] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7810),
  [11929] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7524),
  [11932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2243),
  [11934] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1737),
  [11937] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_lambda, 7, 0, 186),
  [11939] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_lambda, 7, 0, 186),
  [11941] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7831),
  [11944] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9050),
  [11947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4164),
  [11949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12737),
  [11951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4161),
  [11953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4164),
  [11955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1391),
  [11957] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7579),
  [11960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12387),
  [11962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12711),
  [11964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12385),
  [11966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3504),
  [11968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12387),
  [11970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12557),
  [11972] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7594),
  [11975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7558),
  [11977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12392),
  [11979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12728),
  [11981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12390),
  [11983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3528),
  [11985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12392),
  [11987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12198),
  [11989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10934),
  [11991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11025),
  [11993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10839),
  [11995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3543),
  [11997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10934),
  [11999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10814),
  [12001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11062),
  [12003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11528),
  [12005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11097),
  [12007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3130),
  [12009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11062),
  [12011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11285),
  [12013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11287),
  [12015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11525),
  [12017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11286),
  [12019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3554),
  [12021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11287),
  [12023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11162),
  [12025] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type, 1, 0, 0), SHIFT(17448),
  [12028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11823),
  [12030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11591),
  [12032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12078),
  [12034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11590),
  [12036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3574),
  [12038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11591),
  [12040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11659),
  [12042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12741),
  [12044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13309),
  [12046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12740),
  [12048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3582),
  [12050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12741),
  [12052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12703),
  [12054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2034),
  [12056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12744),
  [12058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13113),
  [12060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12742),
  [12062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3591),
  [12064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12744),
  [12066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12778),
  [12068] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7918),
  [12071] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7709),
  [12074] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7461),
  [12077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11793),
  [12079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12371),
  [12081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11791),
  [12083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3650),
  [12085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11793),
  [12087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12139),
  [12089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12752),
  [12091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13277),
  [12093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12751),
  [12095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3657),
  [12097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12752),
  [12099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12691),
  [12101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10865),
  [12103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11050),
  [12105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10833),
  [12107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3168),
  [12109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10865),
  [12111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10770),
  [12113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11035),
  [12115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11276),
  [12117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11012),
  [12119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3665),
  [12121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11035),
  [12123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11075),
  [12125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11828),
  [12127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11798),
  [12129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12382),
  [12131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11797),
  [12133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3686),
  [12135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11798),
  [12137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11799),
  [12139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12413),
  [12141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12723),
  [12143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12412),
  [12145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3726),
  [12147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12413),
  [12149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12320),
  [12151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2110),
  [12153] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9023),
  [12156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8068),
  [12158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8145),
  [12160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8041),
  [12162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3177),
  [12164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8068),
  [12166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7882),
  [12168] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7686),
  [12171] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7436),
  [12174] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17401),
  [12177] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(4),
  [12180] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7800),
  [12183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9871),
  [12185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12033),
  [12187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3231),
  [12189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9871),
  [12191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11587),
  [12193] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type_identifier, 1, 0, 7), SHIFT(2572),
  [12196] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type_identifier, 1, 0, 7), REDUCE(sym_binding, 1, 10, 2),
  [12199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10957),
  [12201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11137),
  [12203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11017),
  [12205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3323),
  [12207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10957),
  [12209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11113),
  [12211] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8755),
  [12214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2567),
  [12216] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7947),
  [12219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3802),
  [12221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4268),
  [12223] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7957),
  [12226] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7976),
  [12229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12341),
  [12231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13021),
  [12233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12337),
  [12235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3396),
  [12237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12341),
  [12239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12227),
  [12241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11224),
  [12243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11909),
  [12245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11214),
  [12247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3409),
  [12249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11224),
  [12251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11520),
  [12253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11063),
  [12255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13385),
  [12257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11111),
  [12259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3840),
  [12261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11063),
  [12263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13049),
  [12265] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1735),
  [12268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11269),
  [12270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11711),
  [12272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11267),
  [12274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3431),
  [12276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11269),
  [12278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11296),
  [12280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9369),
  [12282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9370),
  [12284] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__start_var, 3, 0, 0),
  [12286] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__start_var, 3, 0, 0),
  [12288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8627),
  [12290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8632),
  [12292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8708),
  [12294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8709),
  [12296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6541),
  [12298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6561),
  [12300] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7968),
  [12303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8480),
  [12305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8482),
  [12307] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7455),
  [12310] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7710),
  [12313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8533),
  [12315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8542),
  [12317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5248),
  [12319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5249),
  [12321] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1755),
  [12324] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1673),
  [12327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6355),
  [12329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6356),
  [12331] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_type, 1, 0, 0), SHIFT(2568),
  [12334] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_type, 1, 0, 0), REDUCE(sym_binding, 1, 10, 0),
  [12337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6811),
  [12339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6812),
  [12341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9259),
  [12343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9260),
  [12345] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8748),
  [12348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9301),
  [12350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9302),
  [12352] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7646),
  [12355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__start_val, 2, 0, 0),
  [12357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__start_val, 2, 0, 0),
  [12359] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__start_var, 2, 0, 0),
  [12361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__start_var, 2, 0, 0),
  [12363] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__start_val, 1, 0, 0),
  [12365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__start_val, 1, 0, 0),
  [12367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5879),
  [12369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5881),
  [12371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__start_var, 1, 0, 0),
  [12373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__start_var, 1, 0, 0),
  [12375] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7528),
  [12378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8049),
  [12380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8051),
  [12382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8793),
  [12384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8794),
  [12386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5743),
  [12388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5744),
  [12390] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7687),
  [12393] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__start_val, 3, 0, 0),
  [12395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__start_val, 3, 0, 0),
  [12397] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8855),
  [12400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7572),
  [12402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7573),
  [12404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14977),
  [12406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12998),
  [12408] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7853),
  [12411] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1, 0, 0), SHIFT(2568),
  [12414] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1, 0, 0), REDUCE(sym_binding, 1, 10, 0),
  [12417] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8992),
  [12420] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(17608),
  [12423] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, 0, 15), SHIFT(42),
  [12426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12064),
  [12428] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_extension_definition_repeat1, 2, 0, 0),
  [12430] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_extension_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(10298),
  [12433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11140),
  [12435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16390),
  [12437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10712),
  [12439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2406),
  [12441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13798),
  [12443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17375),
  [12445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17692),
  [12447] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7832),
  [12450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17320),
  [12452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17745),
  [12454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17038),
  [12456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17853),
  [12458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 1, 0, 2),
  [12460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7697),
  [12462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8837),
  [12464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12591),
  [12466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4273),
  [12468] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 1, 0, 2), SHIFT(15053),
  [12471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17186),
  [12473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17386),
  [12475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16165),
  [12477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16195),
  [12479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17453),
  [12481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16804),
  [12483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16225),
  [12485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16719),
  [12487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17513),
  [12489] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7987),
  [12492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10942),
  [12494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2411),
  [12496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10776),
  [12498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14275),
  [12500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15924),
  [12502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2578),
  [12504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14713),
  [12506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16255),
  [12508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17255),
  [12510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16921),
  [12512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16282),
  [12514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14287),
  [12516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17109),
  [12518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17573),
  [12520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3727),
  [12522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12216),
  [12524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16555),
  [12526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16824),
  [12528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17633),
  [12530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14154),
  [12532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14120),
  [12534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17726),
  [12536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3317),
  [12538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1687),
  [12540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12467),
  [12542] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7558),
  [12545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14243),
  [12547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10544),
  [12549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14128),
  [12551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13687),
  [12553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10456),
  [12555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14401),
  [12557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13979),
  [12559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3564),
  [12561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12484),
  [12563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3794),
  [12565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12276),
  [12567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7721),
  [12569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9266),
  [12571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12879),
  [12573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4271),
  [12575] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 1, 0, 2), SHIFT(15307),
  [12578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14387),
  [12580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3305),
  [12582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9213),
  [12584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1654),
  [12586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12404),
  [12588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1771),
  [12590] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type_identifier, 1, 0, 7), SHIFT(12056),
  [12593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12068),
  [12595] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type_identifier, 1, 0, 7), SHIFT(7450),
  [12598] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type_identifier, 1, 0, 7), SHIFT(10353),
  [12601] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type_identifier, 1, 0, 7), SHIFT(14603),
  [12604] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_stable_identifier, 3, 0, 0),
  [12606] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 4, 0, 126),
  [12608] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 1, 0, 0),
  [12610] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__using_parameters_clause, 4, 0, 0),
  [12612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7443),
  [12614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10730),
  [12616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13686),
  [12618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13635),
  [12620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13582),
  [12622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3829),
  [12624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9042),
  [12626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12615),
  [12628] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 5, 0, 0),
  [12630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__using_parameters_clause, 5, 0, 0),
  [12632] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typed_pattern, 3, 0, 90),
  [12634] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_val_declaration, 4, 0, 105),
  [12636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(891),
  [12638] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_val_declaration, 4, 0, 105),
  [12640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_pattern, 3, 0, 90),
  [12642] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_declaration, 4, 0, 105),
  [12644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(892),
  [12646] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_declaration, 4, 0, 105),
  [12648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3654),
  [12650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12635),
  [12652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3737),
  [12654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12219),
  [12656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10949),
  [12658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12075),
  [12660] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 2, 0, 0),
  [12662] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1687),
  [12665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13494),
  [12667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10809),
  [12669] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 6, 0, 0),
  [12671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13790),
  [12673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__using_parameters_clause, 6, 0, 0),
  [12675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12117),
  [12677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3254),
  [12679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1691),
  [12681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12246),
  [12683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 2, 0, 22),
  [12685] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 2, 0, 22), SHIFT(15053),
  [12688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3602),
  [12690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8889),
  [12692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1659),
  [12694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12589),
  [12696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13492),
  [12698] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1725),
  [12701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1697),
  [12703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 4, 0, 16),
  [12705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11789),
  [12707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13453),
  [12709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(956),
  [12711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(959),
  [12713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1670),
  [12715] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 3, 0, 16),
  [12717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 5, 0, 126),
  [12719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 3, 0, 0),
  [12721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13830),
  [12723] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_extension_definition_repeat1, 1, 0, 0),
  [12725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10921),
  [12727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 4, 0, 0),
  [12729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3831),
  [12731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3093),
  [12733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9514),
  [12735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3111),
  [12737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3466),
  [12739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7413),
  [12741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3812),
  [12743] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_class_pattern, 6, 0, 173),
  [12745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_class_pattern, 6, 0, 173),
  [12747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(899),
  [12749] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1718),
  [12752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1583),
  [12754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3109),
  [12756] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 2, 0, 22), SHIFT(15307),
  [12759] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1705),
  [12762] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_class_pattern, 5, 0, 156),
  [12764] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_class_pattern, 5, 0, 156),
  [12766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3833),
  [12768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3763),
  [12770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12238),
  [12772] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_pattern, 3, 0, 0),
  [12774] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pattern, 3, 0, 0),
  [12776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3364),
  [12778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9262),
  [12780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12186),
  [12782] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_class_pattern, 3, 0, 92),
  [12784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_class_pattern, 3, 0, 92),
  [12786] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_repeat_pattern, 2, 0, 52),
  [12788] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeat_pattern, 2, 0, 52),
  [12790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1191),
  [12792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3810),
  [12794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1505),
  [12796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11880),
  [12798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(901),
  [12800] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_pattern, 4, 0, 0),
  [12802] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pattern, 4, 0, 0),
  [12804] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_given_pattern, 2, 0, 50),
  [12806] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_pattern, 2, 0, 50),
  [12808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3433),
  [12810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12563),
  [12812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3091),
  [12814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12057),
  [12816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1680),
  [12818] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8962),
  [12821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1224),
  [12823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3605),
  [12825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1690),
  [12827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12593),
  [12829] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_class_pattern, 4, 0, 132),
  [12831] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_class_pattern, 4, 0, 132),
  [12833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3495),
  [12835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16604),
  [12837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16152),
  [12839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15582),
  [12841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15053),
  [12843] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1794),
  [12846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12025),
  [12848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13994),
  [12850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12634),
  [12852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12155),
  [12854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13974),
  [12856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13994),
  [12858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12301),
  [12860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17384),
  [12862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16402),
  [12864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12121),
  [12866] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_definition, 1, 0, 2),
  [12868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17401),
  [12870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4300),
  [12872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11602),
  [12874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3790),
  [12876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12270),
  [12878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17852),
  [12880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16102),
  [12882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3797),
  [12884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12284),
  [12886] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_definition, 1, 0, 12),
  [12888] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_definition, 1, 0, 12), SHIFT(14310),
  [12891] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 2, 0, 2),
  [12893] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 2, 0, 2), SHIFT(15053),
  [12896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 3, 0, 22),
  [12898] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 3, 0, 22), SHIFT(15053),
  [12901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13840),
  [12903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13988),
  [12905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13840),
  [12907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12363),
  [12909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16499),
  [12911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16527),
  [12913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17376),
  [12915] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 2, 0, 10),
  [12917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(886),
  [12919] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 3, 0, 38),
  [12921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(889),
  [12923] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 3, 0, 61),
  [12925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [12927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 4, 0, 111),
  [12929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [12931] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 4, 0, 118),
  [12933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [12935] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 5, 0, 144),
  [12937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(895),
  [12939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9656),
  [12941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17121),
  [12943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17134),
  [12945] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1738),
  [12948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17440),
  [12950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17467),
  [12952] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ascription_expression, 3, 4, 0),
  [12954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11568),
  [12956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12277),
  [12958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11871),
  [12960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12137),
  [12962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11834),
  [12964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [12966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [12968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [12970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [12972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17017),
  [12974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [12976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15864),
  [12978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9686),
  [12980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16151),
  [12982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16156),
  [12984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16423),
  [12986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16431),
  [12988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16580),
  [12990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16591),
  [12992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16734),
  [12994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16736),
  [12996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16839),
  [12998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16845),
  [13000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16933),
  [13002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16942),
  [13004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17049),
  [13006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17051),
  [13008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17124),
  [13010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17132),
  [13012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17192),
  [13014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17194),
  [13016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17266),
  [13018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17270),
  [13020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17330),
  [13022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17336),
  [13024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17393),
  [13026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17396),
  [13028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17465),
  [13030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17468),
  [13032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17523),
  [13034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17526),
  [13036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17582),
  [13038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17585),
  [13040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17644),
  [13042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17646),
  [13044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17700),
  [13046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17704),
  [13048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17754),
  [13050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17756),
  [13052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17860),
  [13054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17863),
  [13056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16170),
  [13058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16172),
  [13060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16200),
  [13062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16202),
  [13064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16230),
  [13066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16232),
  [13068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16260),
  [13070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16262),
  [13072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16287),
  [13074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16289),
  [13076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16311),
  [13078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16313),
  [13080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16334),
  [13082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16336),
  [13084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16357),
  [13086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16359),
  [13088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16377),
  [13090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16379),
  [13092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16398),
  [13094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16400),
  [13096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16419),
  [13098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16421),
  [13100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16440),
  [13102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16442),
  [13104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16461),
  [13106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16463),
  [13108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16482),
  [13110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16484),
  [13112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16503),
  [13114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16505),
  [13116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16524),
  [13118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16526),
  [13120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16544),
  [13122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16546),
  [13124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16564),
  [13126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16566),
  [13128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16584),
  [13130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16586),
  [13132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16606),
  [13134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16624),
  [13136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16626),
  [13138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16644),
  [13140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16646),
  [13142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16664),
  [13144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16666),
  [13146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16683),
  [13148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16685),
  [13150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16702),
  [13152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16704),
  [13154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16721),
  [13156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16723),
  [13158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16740),
  [13160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16742),
  [13162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16759),
  [13164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16761),
  [13166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16777),
  [13168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16779),
  [13170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16795),
  [13172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16797),
  [13174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16813),
  [13176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16815),
  [13178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16831),
  [13180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16833),
  [13182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16848),
  [13184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16850),
  [13186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16866),
  [13188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16868),
  [13190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16884),
  [13192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16886),
  [13194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16902),
  [13196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16904),
  [13198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16914),
  [13200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16916),
  [13202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16926),
  [13204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16928),
  [13206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16938),
  [13208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16940),
  [13210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16949),
  [13212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16951),
  [13214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16960),
  [13216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16962),
  [13218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16971),
  [13220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16973),
  [13222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16982),
  [13224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16984),
  [13226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16993),
  [13228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16995),
  [13230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17004),
  [13232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17006),
  [13234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17015),
  [13236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [13238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_expression, 4, 0, 93),
  [13240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [13242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17462),
  [13244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4320),
  [13246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11639),
  [13248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13818),
  [13250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1606),
  [13252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [13254] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_definition, 1, 0, 12), SHIFT(14219),
  [13257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3717),
  [13259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12211),
  [13261] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1654),
  [13264] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1782),
  [13267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [13269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12118),
  [13271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__indentable_expression, 1, 0, 0),
  [13273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3800),
  [13275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12289),
  [13277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [13279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11836),
  [13281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14729),
  [13283] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1691),
  [13286] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_expression, 3, 0, 14),
  [13288] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 3, 0, 44),
  [13290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_expression, 3, 0, 63),
  [13292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3599),
  [13294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12586),
  [13296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [13298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_expression, 4, 0, 89),
  [13300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [13302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 2, 0, 0),
  [13304] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 2, 0, 94),
  [13306] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_finally_clause, 2, 0, 0),
  [13308] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_expression, 4, 0, 14),
  [13310] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 4, 0, 101),
  [13312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_while_expression, 4, 0, 104),
  [13314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_expression, 4, 0, 114),
  [13316] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_match_expression, 3, 0, 63), REDUCE(sym_match_expression, 4, 0, 114),
  [13319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_block, 2, 0, 0),
  [13321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lazy_parameter_type, 2, 0, 50),
  [13323] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeated_parameter_type, 2, 0, 92),
  [13325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9541),
  [13327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(907),
  [13329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 5, 0, 130),
  [13331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 6, 0, 154),
  [13333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_expression, 6, 0, 155),
  [13335] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9042),
  [13338] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 6, 0, 160),
  [13340] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 5, 0, 130), REDUCE(sym_if_expression, 6, 0, 160),
  [13343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7464),
  [13345] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 7, 0, 174),
  [13347] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 6, 0, 154), REDUCE(sym_if_expression, 7, 0, 174),
  [13350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17772),
  [13352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13350),
  [13354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11947),
  [13356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1440),
  [13358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [13360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1561),
  [13362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1605),
  [13364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1073),
  [13366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1289),
  [13368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17738),
  [13370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1355),
  [13372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9442),
  [13374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3447),
  [13376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14510),
  [13378] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_expression, 2, 0, 0),
  [13380] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_expression, 2, 0, 0),
  [13382] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_expression, 3, 0, 49),
  [13384] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 3, 0, 65),
  [13386] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_expression, 5, 0, 131),
  [13388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expr_case_clause, 3, 0, 74),
  [13390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7531),
  [13392] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1694),
  [13395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_constructor, 1, 0, 2),
  [13397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10353),
  [13399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12874),
  [13401] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 2, 0, 2), SHIFT(15307),
  [13404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1299),
  [13406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12140),
  [13408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3693),
  [13410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 1, 0, 2),
  [13412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7713),
  [13414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3685),
  [13416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3165),
  [13418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3714),
  [13420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12108),
  [13422] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9213),
  [13425] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 3, 0, 22), SHIFT(15307),
  [13428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12012),
  [13430] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 1, 0, 0),
  [13432] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 1, 0, 0),
  [13434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [13436] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1697),
  [13439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3722),
  [13441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4192),
  [13443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1234),
  [13445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3691),
  [13447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12192),
  [13449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1260),
  [13451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6366),
  [13453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5671),
  [13455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11914),
  [13457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11618),
  [13459] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 3, 0, 22),
  [13461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 3, 0, 22),
  [13463] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 3, 0, 57),
  [13465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 3, 0, 57),
  [13467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11910),
  [13469] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 3, 0, 36),
  [13471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 3, 0, 36),
  [13473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10542),
  [13475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12555),
  [13477] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1680),
  [13480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_definition, 2, 0, 46),
  [13482] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_definition, 2, 0, 46), SHIFT(14310),
  [13485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6863),
  [13487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6044),
  [13489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12461),
  [13491] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 3, 0, 80),
  [13493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 3, 0, 80),
  [13495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4700),
  [13497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4548),
  [13499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10977),
  [13501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9444),
  [13503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9078),
  [13505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9320),
  [13507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9069),
  [13509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5126),
  [13511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4833),
  [13513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8620),
  [13515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7734),
  [13517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6151),
  [13519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6335),
  [13521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11548),
  [13523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11155),
  [13525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5802),
  [13527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5140),
  [13529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11841),
  [13531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11645),
  [13533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12235),
  [13535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11838),
  [13537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7027),
  [13539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6397),
  [13541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13137),
  [13543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12861),
  [13545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7611),
  [13547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7077),
  [13549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3142),
  [13551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14514),
  [13553] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 3, 0, 44),
  [13555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 3, 0, 44),
  [13557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14321),
  [13559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5307),
  [13561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4875),
  [13563] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1690),
  [13566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3262),
  [13568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9164),
  [13570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1704),
  [13572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12281),
  [13574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3663),
  [13576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7599),
  [13578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7750),
  [13580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11232),
  [13582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11001),
  [13584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12731),
  [13586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12479),
  [13588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4856),
  [13590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4702),
  [13592] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8061),
  [13594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6853),
  [13596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10192),
  [13598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8170),
  [13600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8089),
  [13602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14564),
  [13604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5898),
  [13606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5158),
  [13608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12243),
  [13610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13968),
  [13612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12307),
  [13614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12047),
  [13616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6924),
  [13618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7252),
  [13620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7091),
  [13622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6365),
  [13624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5978),
  [13626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5167),
  [13628] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_definition, 2, 0, 31),
  [13630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6059),
  [13632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5484),
  [13634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4368),
  [13636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4245),
  [13638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4544),
  [13640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4384),
  [13642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12643),
  [13644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12339),
  [13646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8055),
  [13648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7782),
  [13650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9585),
  [13652] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 2, 0, 0),
  [13654] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 2, 0, 0),
  [13656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8543),
  [13658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7812),
  [13660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7749),
  [13662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7194),
  [13664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7154),
  [13666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6438),
  [13668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3770),
  [13670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12242),
  [13672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5944),
  [13674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5201),
  [13676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12051),
  [13678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10875),
  [13680] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_applications, 1, 0, 70),
  [13682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4402),
  [13684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4403),
  [13686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5926),
  [13688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5793),
  [13690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6178),
  [13692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5667),
  [13694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5393),
  [13696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5422),
  [13698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5285),
  [13700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4880),
  [13702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7095),
  [13704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6007),
  [13706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7727),
  [13708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10130),
  [13710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13303),
  [13712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4717),
  [13714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4549),
  [13716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4818),
  [13718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4738),
  [13720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6858),
  [13722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6302),
  [13724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5412),
  [13726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5005),
  [13728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16118),
  [13730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7232),
  [13732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6536),
  [13734] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1693),
  [13737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3779),
  [13739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12250),
  [13741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6482),
  [13743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5938),
  [13745] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1670),
  [13748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9217),
  [13750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8530),
  [13752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12613),
  [13754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8450),
  [13756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8005),
  [13758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4849),
  [13760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4623),
  [13762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7178),
  [13764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6064),
  [13766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6160),
  [13768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5845),
  [13770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6555),
  [13772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6614),
  [13774] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1739),
  [13777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11642),
  [13779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11194),
  [13781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12890),
  [13783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12193),
  [13785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3792),
  [13787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12273),
  [13789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5947),
  [13791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5458),
  [13793] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 5, 0, 99),
  [13795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 5, 0, 99),
  [13797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5994),
  [13799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6654),
  [13801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9483),
  [13803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6381),
  [13805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5587),
  [13807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7348),
  [13809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6152),
  [13811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6660),
  [13813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6491),
  [13815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7365),
  [13817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6814),
  [13819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8080),
  [13821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6845),
  [13823] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8889),
  [13826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8489),
  [13828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8359),
  [13830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7695),
  [13832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6831),
  [13834] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 2, 0, 2),
  [13836] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 2, 0, 2),
  [13838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11207),
  [13840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11022),
  [13842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6276),
  [13844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5889),
  [13846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9935),
  [13848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10047),
  [13850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11589),
  [13852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11290),
  [13854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14043),
  [13856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4654),
  [13858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4711),
  [13860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1719),
  [13862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5663),
  [13864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5204),
  [13866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11030),
  [13868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10860),
  [13870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4765),
  [13872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4720),
  [13874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5844),
  [13876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5916),
  [13878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5275),
  [13880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5456),
  [13882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6399),
  [13884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5939),
  [13886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4906),
  [13888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4731),
  [13890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7130),
  [13892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7228),
  [13894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5404),
  [13896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5086),
  [13898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8024),
  [13900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7486),
  [13902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5976),
  [13904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5101),
  [13906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6508),
  [13908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5985),
  [13910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13358),
  [13912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11908),
  [13914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7285),
  [13916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6818),
  [13918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12825),
  [13920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12335),
  [13922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8478),
  [13924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7544),
  [13926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7876),
  [13928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7970),
  [13930] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 2, 0, 36),
  [13932] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 2, 0, 36),
  [13934] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9262),
  [13937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7255),
  [13939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6075),
  [13941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11131),
  [13943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10756),
  [13945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11801),
  [13947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11629),
  [13949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8501),
  [13951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7699),
  [13953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11684),
  [13955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11177),
  [13957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6006),
  [13959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5602),
  [13961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4983),
  [13963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5034),
  [13965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4596),
  [13967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4499),
  [13969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5070),
  [13971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5040),
  [13973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6073),
  [13975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5783),
  [13977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5981),
  [13979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5536),
  [13981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11640),
  [13983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11163),
  [13985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5082),
  [13987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4771),
  [13989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11845),
  [13991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12088),
  [13993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11464),
  [13995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6772),
  [13997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6214),
  [13999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12978),
  [14001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14596),
  [14003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8463),
  [14005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7600),
  [14007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13215),
  [14009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13004),
  [14011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13387),
  [14013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13141),
  [14015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13848),
  [14017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13713),
  [14019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5099),
  [14021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4793),
  [14023] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 4, 0, 22),
  [14025] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 4, 0, 22),
  [14027] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 4, 0, 99),
  [14029] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 4, 0, 99),
  [14031] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 4, 0, 57),
  [14033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 4, 0, 57),
  [14035] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 4, 0, 80),
  [14037] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 4, 0, 80),
  [14039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16049),
  [14041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6827),
  [14043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6480),
  [14045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6123),
  [14047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6261),
  [14049] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 3, 0, 2),
  [14051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 3, 0, 2),
  [14053] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 2, 0, 44),
  [14055] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 2, 0, 44),
  [14057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4827),
  [14059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4866),
  [14061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13278),
  [14063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12916),
  [14065] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_expression, 2, 0, 14),
  [14067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(630),
  [14069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [14071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4542),
  [14073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5281),
  [14075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__function_constructor_repeat1, 2, 0, 0),
  [14077] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__function_constructor_repeat1, 2, 0, 0), SHIFT_REPEAT(10353),
  [14080] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__function_constructor_repeat1, 2, 0, 0), SHIFT_REPEAT(15416),
  [14083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7888),
  [14085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [14087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3260),
  [14089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7883),
  [14091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7888),
  [14093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7085),
  [14095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [14097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3261),
  [14099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7057),
  [14101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7085),
  [14103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4814),
  [14105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12109),
  [14107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4835),
  [14109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6697),
  [14111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6137),
  [14113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11638),
  [14115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12860),
  [14117] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1715),
  [14120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11166),
  [14122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6269),
  [14124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8546),
  [14126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12110),
  [14128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8766),
  [14130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [14132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3268),
  [14134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8763),
  [14136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8766),
  [14138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9270),
  [14140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [14142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3269),
  [14144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9244),
  [14146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9270),
  [14148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5837),
  [14150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11965),
  [14152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6390),
  [14154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12837),
  [14156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15954),
  [14158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7121),
  [14160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7659),
  [14162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6495),
  [14164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12795),
  [14166] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 2, 0, 23),
  [14168] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 2, 0, 23), SHIFT(15053),
  [14171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7865),
  [14173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7250),
  [14175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11023),
  [14177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8452),
  [14179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11679),
  [14181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13835),
  [14183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4980),
  [14185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4593),
  [14187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10279),
  [14189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [14191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3655),
  [14193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10168),
  [14195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10279),
  [14197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9349),
  [14199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [14201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3280),
  [14203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9346),
  [14205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9349),
  [14207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5068),
  [14209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8722),
  [14211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [14213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3282),
  [14215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8713),
  [14217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8722),
  [14219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11881),
  [14221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5884),
  [14223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5554),
  [14225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5080),
  [14227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8481),
  [14229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12081),
  [14231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6765),
  [14233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13205),
  [14235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7966),
  [14237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5097),
  [14239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11466),
  [14241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6150),
  [14243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [14245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3292),
  [14247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6146),
  [14249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6150),
  [14251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [14253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3293),
  [14255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6823),
  [14257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13273),
  [14259] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_definition, 2, 0, 46), SHIFT(14219),
  [14262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8610),
  [14264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [14266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3169),
  [14268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8440),
  [14270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8610),
  [14272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7129),
  [14274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6334),
  [14276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6859),
  [14278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9910),
  [14280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [14282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3170),
  [14284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9837),
  [14286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9910),
  [14288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4662),
  [14290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9437),
  [14292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5123),
  [14294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7925),
  [14296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [14298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3303),
  [14300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7924),
  [14302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7925),
  [14304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6144),
  [14306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [14308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3304),
  [14310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5798),
  [14312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8677),
  [14314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12232),
  [14316] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1770),
  [14319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7017),
  [14321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13111),
  [14323] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__class_constructor_repeat1, 2, 0, 0),
  [14325] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__class_constructor_repeat1, 2, 0, 0), SHIFT_REPEAT(4273),
  [14328] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__class_constructor_repeat1, 2, 0, 0), SHIFT_REPEAT(15053),
  [14331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7608),
  [14333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11230),
  [14335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11469),
  [14337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8411),
  [14339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [14341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3314),
  [14343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8408),
  [14345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8411),
  [14347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [14349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3316),
  [14351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4852),
  [14353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13589),
  [14355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7791),
  [14357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5894),
  [14359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12305),
  [14361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5960),
  [14363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6032),
  [14365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13023),
  [14367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [14369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3325),
  [14371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7176),
  [14373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 3, 0, 68),
  [14375] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 3, 0, 68), SHIFT(15053),
  [14378] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 3, 0, 2),
  [14380] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 3, 0, 2), SHIFT(15053),
  [14383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 3, 0, 69),
  [14385] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 3, 0, 69), SHIFT(15053),
  [14388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10661),
  [14390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [14392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3334),
  [14394] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7443),
  [14397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_simple_enum_case, 1, 0, 2),
  [14399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4334),
  [14401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4259),
  [14403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5403),
  [14405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11143),
  [14407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [14409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3342),
  [14411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [14413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(843),
  [14415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4725),
  [14417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4184),
  [14419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11922),
  [14421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8754),
  [14423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [14425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3179),
  [14427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8714),
  [14429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8754),
  [14431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14151),
  [14433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8006),
  [14435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6767),
  [14437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [14439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3181),
  [14441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6683),
  [14443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6767),
  [14445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5420),
  [14447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [14449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3668),
  [14451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7243),
  [14453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16007),
  [14455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4211),
  [14457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4853),
  [14459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6501),
  [14461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16034),
  [14463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4186),
  [14465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15887),
  [14467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 2, 0, 22),
  [14469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [14471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(867),
  [14473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4182),
  [14475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9234),
  [14477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16083),
  [14479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4194),
  [14481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10042),
  [14483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [14485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3189),
  [14487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9955),
  [14489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10042),
  [14491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15993),
  [14493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4230),
  [14495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8205),
  [14497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [14499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3190),
  [14501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8538),
  [14503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8205),
  [14505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8483),
  [14507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13725),
  [14509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4203),
  [14511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [14513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3139),
  [14515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 4, 0, 22),
  [14517] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 4, 0, 22), SHIFT(15053),
  [14520] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1714),
  [14523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 4, 0, 120),
  [14525] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 4, 0, 120), SHIFT(15053),
  [14528] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 4, 0, 121),
  [14530] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 4, 0, 121), SHIFT(15053),
  [14533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4345),
  [14535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4269),
  [14537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5321),
  [14539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4229),
  [14541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6544),
  [14543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [14545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3141),
  [14547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6523),
  [14549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6544),
  [14551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4188),
  [14553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7954),
  [14555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6569),
  [14557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16134),
  [14559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4242),
  [14561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4185),
  [14563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10878),
  [14565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [14567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3199),
  [14569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10874),
  [14571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10878),
  [14573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [14575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3200),
  [14577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3505),
  [14579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14618),
  [14581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5957),
  [14583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4196),
  [14585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1403),
  [14587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4191),
  [14589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11695),
  [14591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4208),
  [14593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6604),
  [14595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(839),
  [14597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15975),
  [14599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4224),
  [14601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8182),
  [14603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [14605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3119),
  [14607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8144),
  [14609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8182),
  [14611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15915),
  [14613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8026),
  [14615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [14617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3804),
  [14619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8038),
  [14621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8026),
  [14623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [14625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3807),
  [14627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9662),
  [14629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4215),
  [14631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [14633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3121),
  [14635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7361),
  [14637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4232),
  [14639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4202),
  [14641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5790),
  [14643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [14645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3210),
  [14647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5694),
  [14649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5790),
  [14651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 5, 0, 148),
  [14653] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 5, 0, 148), SHIFT(15053),
  [14656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [14658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3212),
  [14660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7376),
  [14662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9165),
  [14664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16019),
  [14666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4238),
  [14668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10768),
  [14670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7875),
  [14672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15970),
  [14674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4197),
  [14676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4198),
  [14678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4209),
  [14680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4223),
  [14682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [14684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3151),
  [14686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16029),
  [14688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4225),
  [14690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8597),
  [14692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15977),
  [14694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4189),
  [14696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [14698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3153),
  [14700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16047),
  [14702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4221),
  [14704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4237),
  [14706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4243),
  [14708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4187),
  [14710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11058),
  [14712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14114),
  [14714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15988),
  [14716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4222),
  [14718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7636),
  [14720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3463),
  [14722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16124),
  [14724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4236),
  [14726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4217),
  [14728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16131),
  [14730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4228),
  [14732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4200),
  [14734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4212),
  [14736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11212),
  [14738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4233),
  [14740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3271),
  [14742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14585),
  [14744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15946),
  [14746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4231),
  [14748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4227),
  [14750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16012),
  [14752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4240),
  [14754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9946),
  [14756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16127),
  [14758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4241),
  [14760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14506),
  [14762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4234),
  [14764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4193),
  [14766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4235),
  [14768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7047),
  [14770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [14772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3223),
  [14774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7012),
  [14776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7047),
  [14778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [14780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3225),
  [14782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4675),
  [14784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4214),
  [14786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4216),
  [14788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4213),
  [14790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4207),
  [14792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16008),
  [14794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4190),
  [14796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8449),
  [14798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4790),
  [14800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4220),
  [14802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9428),
  [14804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [14806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3826),
  [14808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9395),
  [14810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9428),
  [14812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [14814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3827),
  [14816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15881),
  [14818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4199),
  [14820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15998),
  [14822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4201),
  [14824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12931),
  [14826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4181),
  [14828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16037),
  [14830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4219),
  [14832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16028),
  [14834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4183),
  [14836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4180),
  [14838] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_constructor, 2, 0, 22),
  [14840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12938),
  [14842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4195),
  [14844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4381),
  [14846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4239),
  [14848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11077),
  [14850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4206),
  [14852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4205),
  [14854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15869),
  [14856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4226),
  [14858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4204),
  [14860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5300),
  [14862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12027),
  [14864] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_constructor, 3, 0, 99),
  [14866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12770),
  [14868] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_constructor, 2, 0, 57),
  [14870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12941),
  [14872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3639),
  [14874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12622),
  [14876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4944),
  [14878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9551),
  [14880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [14882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3087),
  [14884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9536),
  [14886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9551),
  [14888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [14890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3088),
  [14892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9328),
  [14894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [14896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3082),
  [14898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9507),
  [14900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9328),
  [14902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [14904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3232),
  [14906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5441),
  [14908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5570),
  [14910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [14912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3233),
  [14914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6762),
  [14916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5488),
  [14918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [14920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3132),
  [14922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6114),
  [14924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6661),
  [14926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6653),
  [14928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4407),
  [14930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4408),
  [14932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12746),
  [14934] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1708),
  [14937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11830),
  [14939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [14941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3238),
  [14943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12991),
  [14945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [14947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3240),
  [14949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11855),
  [14951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6984),
  [14953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13905),
  [14955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [14957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3102),
  [14959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [14961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3104),
  [14963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5491),
  [14965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7128),
  [14967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11481),
  [14969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7217),
  [14971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6497),
  [14973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9723),
  [14975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [14977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1433),
  [14979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [14981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3250),
  [14983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [14985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3252),
  [14987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6600),
  [14989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8202),
  [14991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6159),
  [14993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11716),
  [14995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [14997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3162),
  [14999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [15001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3163),
  [15003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7936),
  [15005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4218),
  [15007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3610),
  [15009] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 5, 0, 148), SHIFT(15307),
  [15012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15895),
  [15014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16998),
  [15016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [15018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1341),
  [15020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3679),
  [15022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16033),
  [15024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13103),
  [15026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9394),
  [15028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7502),
  [15030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8919),
  [15032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15987),
  [15034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9405),
  [15036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [15038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1245),
  [15040] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_constructor, 1, 0, 2),
  [15042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3506),
  [15044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3379),
  [15046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9501),
  [15048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [15050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1298),
  [15052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16052),
  [15054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15900),
  [15056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(609),
  [15058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(831),
  [15060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9997),
  [15062] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1707),
  [15065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11849),
  [15067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15850),
  [15069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10100),
  [15071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15893),
  [15073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [15075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1576),
  [15077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12145),
  [15079] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_applications, 2, 0, 122),
  [15081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16146),
  [15083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [15085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1532),
  [15087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8157),
  [15089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6209),
  [15091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15918),
  [15093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8568),
  [15095] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__function_constructor_repeat1, 2, 0, 0), SHIFT_REPEAT(10130),
  [15098] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__function_constructor_repeat1, 2, 0, 0), SHIFT_REPEAT(15360),
  [15101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15926),
  [15103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerator, 4, 0, 0),
  [15105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3808),
  [15107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2217),
  [15109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14615),
  [15111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16991),
  [15113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10817),
  [15115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15896),
  [15117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16115),
  [15119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16113),
  [15121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15985),
  [15123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [15125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1352),
  [15127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16030),
  [15129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10244),
  [15131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8278),
  [15133] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1696),
  [15136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [15138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(855),
  [15140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_constructor, 4, 0, 99),
  [15142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15972),
  [15144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14475),
  [15146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3300),
  [15148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3308),
  [15150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15916),
  [15152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12169),
  [15154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7801),
  [15156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15886),
  [15158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15989),
  [15160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12277),
  [15162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4176),
  [15164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11871),
  [15166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11927),
  [15168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9703),
  [15170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9388),
  [15172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11886),
  [15174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12293),
  [15176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7678),
  [15178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14097),
  [15180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15909),
  [15182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14715),
  [15184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5691),
  [15186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15931),
  [15188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15943),
  [15190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16043),
  [15192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16014),
  [15194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13236),
  [15196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15937),
  [15198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13261),
  [15200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16024),
  [15202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16101),
  [15204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15872),
  [15206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat1, 2, 0, 122),
  [15208] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat1, 2, 0, 122), SHIFT_REPEAT(4402),
  [15211] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat2, 2, 0, 122),
  [15213] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat2, 2, 0, 122), SHIFT_REPEAT(4403),
  [15216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15902),
  [15218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15940),
  [15220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13571),
  [15222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15983),
  [15224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8526),
  [15226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16042),
  [15228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_definition, 2, 0, 47),
  [15230] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_definition, 2, 0, 47), SHIFT(14310),
  [15233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16094),
  [15235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15860),
  [15237] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_definition, 3, 0, 87),
  [15239] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_definition, 3, 0, 87), SHIFT(14310),
  [15242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15919),
  [15244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13101),
  [15246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15968),
  [15248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16023),
  [15250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1251),
  [15252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16075),
  [15254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [15256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1610),
  [15258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16121),
  [15260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16142),
  [15262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16056),
  [15264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16035),
  [15266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16045),
  [15268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16064),
  [15270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15973),
  [15272] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_constructor, 2, 0, 2),
  [15274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17473),
  [15276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6894),
  [15278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15997),
  [15280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12651),
  [15282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16110),
  [15284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16136),
  [15286] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerator, 3, 0, 0),
  [15288] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7413),
  [15291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1564),
  [15293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6533),
  [15295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15920),
  [15297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15992),
  [15299] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__class_constructor_repeat1, 2, 0, 0), SHIFT_REPEAT(4271),
  [15302] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__class_constructor_repeat1, 2, 0, 0), SHIFT_REPEAT(15307),
  [15305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15974),
  [15307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9476),
  [15309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9465),
  [15311] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_definition, 2, 0, 32),
  [15313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [15315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1491),
  [15317] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_constructor, 3, 0, 22),
  [15319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_constructor, 3, 0, 57),
  [15321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6720),
  [15323] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 2, 0, 23), SHIFT(15307),
  [15326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1364),
  [15328] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1699),
  [15331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9633),
  [15333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6926),
  [15335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13276),
  [15337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4150),
  [15339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15913),
  [15341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12634),
  [15343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4175),
  [15345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12155),
  [15347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12128),
  [15349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11839),
  [15351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12325),
  [15353] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 4, 0, 22), SHIFT(15307),
  [15356] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 3, 0, 68), SHIFT(15307),
  [15359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 3, 0, 2), SHIFT(15307),
  [15362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14696),
  [15364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 4, 0, 120), SHIFT(15307),
  [15367] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 3, 0, 69), SHIFT(15307),
  [15370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15855),
  [15372] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 4, 0, 121), SHIFT(15307),
  [15375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [15377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1395),
  [15379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [15381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1429),
  [15383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16283),
  [15385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1512),
  [15387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8816),
  [15389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4159),
  [15391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15857),
  [15393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1266),
  [15395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_definition, 3, 0, 76),
  [15397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9375),
  [15399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1460),
  [15401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8861),
  [15403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4178),
  [15405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11879),
  [15407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12228),
  [15409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9503),
  [15411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9188),
  [15413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3372),
  [15415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat1, 2, 0, 15),
  [15417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat2, 2, 0, 15),
  [15419] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat2, 2, 0, 122), SHIFT_REPEAT(4408),
  [15422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameters, 2, 0, 0),
  [15424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3348),
  [15426] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_class_parameters, 4, 0, 0), REDUCE(sym_class_parameters, 5, 0, 0),
  [15429] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 2, 0, 56),
  [15431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12106),
  [15433] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat1, 2, 0, 122), SHIFT_REPEAT(4407),
  [15436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14526),
  [15438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3172),
  [15440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [15442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1288),
  [15444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameters, 5, 0, 0),
  [15446] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__class_constructor_repeat1, 1, 0, 0),
  [15448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9670),
  [15450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12146),
  [15452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14703),
  [15454] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_definition, 2, 0, 47), SHIFT(14219),
  [15457] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 3, 0, 97),
  [15459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(621),
  [15461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1203),
  [15463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3333),
  [15465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3361),
  [15467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [15469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1644),
  [15471] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_class_parameters, 3, 0, 0), REDUCE(sym_class_parameters, 4, 0, 0),
  [15474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13592),
  [15476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13428),
  [15478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3343),
  [15480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9236),
  [15482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12604),
  [15484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [15486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1240),
  [15488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameters, 4, 0, 0),
  [15490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9596),
  [15492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameters, 3, 0, 0),
  [15494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14623),
  [15496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extends_clause, 2, 0, 71),
  [15498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3773),
  [15500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(623),
  [15502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1470),
  [15504] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48),
  [15506] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16594),
  [15509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1578),
  [15511] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), REDUCE(sym_if_expression, 4, 0, 113),
  [15514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113),
  [15516] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16607),
  [15519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1581),
  [15521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [15523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1306),
  [15525] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17564),
  [15528] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1437),
  [15531] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16210),
  [15534] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1443),
  [15537] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1740),
  [15540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [15542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1046),
  [15544] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_class_parameters, 5, 0, 0), REDUCE(sym_class_parameters, 6, 0, 0),
  [15547] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameters, 6, 0, 0),
  [15549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14595),
  [15551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1787),
  [15553] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_class_parameters, 6, 0, 0), REDUCE(sym_class_parameters, 7, 0, 0),
  [15556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(605),
  [15558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1640),
  [15560] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameters, 7, 0, 0),
  [15562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13509),
  [15564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1412),
  [15566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1551),
  [15568] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17349),
  [15571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1393),
  [15573] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17361),
  [15576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1476),
  [15578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9610),
  [15580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13375),
  [15582] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16898),
  [15585] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(821),
  [15588] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17369),
  [15591] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(824),
  [15594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1621),
  [15596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1632),
  [15598] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_class_parameters, 2, 0, 0), REDUCE(sym_class_parameters, 3, 0, 0),
  [15601] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_definition, 3, 0, 87), SHIFT(14219),
  [15604] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1719),
  [15607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1482),
  [15609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3385),
  [15611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [15613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1376),
  [15615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3620),
  [15617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13704),
  [15619] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17400),
  [15622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1463),
  [15624] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16452),
  [15627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1472),
  [15629] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16521),
  [15632] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(845),
  [15635] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16806),
  [15638] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(848),
  [15641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13786),
  [15643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12287),
  [15645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3530),
  [15647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14624),
  [15649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16587),
  [15652] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1536),
  [15655] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16753),
  [15658] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1546),
  [15661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14710),
  [15663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerator, 1, 0, 0),
  [15665] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_constructor, 2, 0, 22),
  [15667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [15669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1303),
  [15671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3516),
  [15673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_derives_clause, 2, 0, 50),
  [15675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11584),
  [15677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16635),
  [15679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [15681] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16860),
  [15684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1296),
  [15686] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17628),
  [15689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1052),
  [15691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__function_constructor_repeat1, 1, 0, 0),
  [15693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14453),
  [15695] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16692),
  [15698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1063),
  [15700] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16558),
  [15703] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1432),
  [15706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [15708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(838),
  [15710] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7531),
  [15713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [15715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1087),
  [15717] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16694),
  [15720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1291),
  [15722] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16862),
  [15725] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1612),
  [15728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9326),
  [15730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1449),
  [15732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [15734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1334),
  [15736] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_derives_clause_repeat1, 2, 0, 151),
  [15738] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_derives_clause_repeat1, 2, 0, 151), SHIFT_REPEAT(11584),
  [15741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(593),
  [15743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(986),
  [15745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [15747] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17296),
  [15750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [15752] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17599),
  [15755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(836),
  [15757] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16190),
  [15760] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(869),
  [15763] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16220),
  [15766] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(872),
  [15769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13661),
  [15771] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16887),
  [15774] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1615),
  [15777] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enumerator_repeat1, 2, 0, 0),
  [15779] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enumerator_repeat1, 2, 0, 0), SHIFT_REPEAT(2217),
  [15782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16405),
  [15784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1093),
  [15786] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9164),
  [15789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9617),
  [15791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_package_identifier_repeat1, 2, 0, 0),
  [15793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1139),
  [15795] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17241),
  [15798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1646),
  [15800] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16655),
  [15803] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1438),
  [15806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1359),
  [15808] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17252),
  [15811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1649),
  [15813] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(7464),
  [15816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [15818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1587),
  [15820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [15822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1514),
  [15824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1487),
  [15826] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17219),
  [15829] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1398),
  [15832] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17307),
  [15835] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1402),
  [15838] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_derives_clause, 3, 0, 123),
  [15840] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17605),
  [15843] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1516),
  [15846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17147),
  [15848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1457),
  [15850] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16459),
  [15853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1566),
  [15855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4414),
  [15857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4415),
  [15859] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 3, 0, 98),
  [15861] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17736),
  [15864] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1522),
  [15867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3643),
  [15869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3106),
  [15871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3090),
  [15873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3183),
  [15875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14437),
  [15877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4418),
  [15879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4419),
  [15881] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17825),
  [15884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [15886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14495),
  [15888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4461),
  [15890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4463),
  [15892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13709),
  [15894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11471),
  [15896] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17000),
  [15899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1623),
  [15901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_clause, 2, 0, 3),
  [15903] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_package_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(12824),
  [15906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2357),
  [15908] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_guard, 2, 0, 51),
  [15910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12069),
  [15912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2071),
  [15914] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17029),
  [15917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1626),
  [15919] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16166),
  [15922] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1309),
  [15925] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16315),
  [15928] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1313),
  [15931] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extends_clause, 3, 0, 71),
  [15933] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__namespace_expression, 1, 0, 5),
  [15935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10463),
  [15937] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__full_enum_def, 1, 0, 150),
  [15939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4346),
  [15941] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__full_enum_def, 1, 0, 150), SHIFT(17744),
  [15944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__block, 1, 0, 0),
  [15946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [15948] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16495),
  [15951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1569),
  [15953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4347),
  [15955] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__full_enum_def, 1, 0, 150), SHIFT(16556),
  [15958] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 5, 0, 169),
  [15960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_derives_clause_repeat1, 2, 0, 50),
  [15962] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 4, 0, 133),
  [15964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [15966] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 4, 0, 153),
  [15968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__full_enum_def, 2, 0, 166),
  [15970] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__full_enum_def, 2, 0, 166), SHIFT(16556),
  [15973] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17854),
  [15976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1414),
  [15978] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16193),
  [15981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1419),
  [15983] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17224),
  [15986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [15988] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17328),
  [15991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [15993] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17544),
  [15996] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1257),
  [15999] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17559),
  [16002] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1275),
  [16005] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17495),
  [16008] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(857),
  [16011] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17555),
  [16014] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(860),
  [16017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13984),
  [16019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__namespace_expression, 2, 0, 33),
  [16021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10492),
  [16023] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_derives_clause_repeat1, 2, 0, 151), SHIFT_REPEAT(11471),
  [16026] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17446),
  [16029] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(863),
  [16032] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17464),
  [16035] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1033),
  [16038] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17428),
  [16041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(990),
  [16043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12147),
  [16045] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17636),
  [16048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1344),
  [16050] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17816),
  [16053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1349),
  [16055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17086),
  [16057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1453),
  [16059] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17639),
  [16062] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1302),
  [16065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12257),
  [16067] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16286),
  [16070] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1407),
  [16073] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16572),
  [16076] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1417),
  [16079] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__full_enum_def, 2, 0, 166), SHIFT(17744),
  [16082] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17654),
  [16085] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1314),
  [16088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [16090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1227),
  [16092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10482),
  [16094] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat2, 2, 0, 122), SHIFT_REPEAT(4415),
  [16097] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17533),
  [16100] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1494),
  [16103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_constructor, 3, 0, 97),
  [16105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17112),
  [16107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [16109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3688),
  [16111] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declaration, 2, 0, 17),
  [16113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3096),
  [16115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declaration, 4, 0, 119),
  [16117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3202),
  [16119] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17183),
  [16122] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1273),
  [16125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [16127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1537),
  [16129] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 2, 0, 6),
  [16131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12547),
  [16133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [16135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1214),
  [16137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3398),
  [16139] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16320),
  [16142] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1277),
  [16145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10636),
  [16147] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17450),
  [16150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1362),
  [16152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17348),
  [16154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [16156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4371),
  [16158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11614),
  [16160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17491),
  [16162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [16164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3302),
  [16166] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(8006),
  [16169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3426),
  [16171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declaration, 3, 0, 62),
  [16173] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17144),
  [16176] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1634),
  [16179] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17828),
  [16182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1366),
  [16184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3499),
  [16186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17062),
  [16188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [16190] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_declaration, 2, 0, 6),
  [16192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [16194] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__full_enum_def_repeat1, 2, 0, 0),
  [16196] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__full_enum_def_repeat1, 2, 0, 0), SHIFT_REPEAT(4269),
  [16199] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__full_enum_def_repeat1, 2, 0, 0), SHIFT_REPEAT(16556),
  [16202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16417),
  [16204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1216),
  [16206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16515),
  [16208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1219),
  [16210] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17301),
  [16213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1473),
  [16215] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17352),
  [16218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1479),
  [16220] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16490),
  [16223] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1253),
  [16226] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16507),
  [16229] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1256),
  [16232] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17158),
  [16235] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1637),
  [16238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_constructor, 2, 0, 56),
  [16240] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17735),
  [16243] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1517),
  [16246] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17811),
  [16249] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1524),
  [16252] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17843),
  [16255] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1370),
  [16258] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17850),
  [16261] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1380),
  [16264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3131),
  [16266] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17563),
  [16269] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1500),
  [16272] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__enum_block, 1, 0, 0),
  [16274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [16276] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enumerator_repeat1, 1, 0, 0),
  [16278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [16280] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 1, 0, 1),
  [16282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [16284] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(9236),
  [16287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_identifier, 2, 0, 0),
  [16289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12901),
  [16291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [16293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1598),
  [16295] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17615),
  [16298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1242),
  [16300] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2, 0, 0), SHIFT_REPEAT(1787),
  [16303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 3, 0, 34),
  [16305] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_declaration, 3, 0, 34),
  [16307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [16309] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17737),
  [16312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [16314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lower_bound, 2, 0, 50),
  [16316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [16318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declaration, 4, 0, 100),
  [16320] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declaration, 5, 0, 137),
  [16322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16911),
  [16324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1229),
  [16326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17011),
  [16328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1232),
  [16330] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16323),
  [16333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1553),
  [16335] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16364),
  [16338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1556),
  [16340] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_identifier, 1, 0, 0),
  [16342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [16344] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0),
  [16346] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16686),
  [16349] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1589),
  [16352] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16705),
  [16355] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1592),
  [16358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11859),
  [16360] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declaration, 6, 0, 163),
  [16362] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_package_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(12901),
  [16365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [16367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [16369] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat2, 2, 0, 122), SHIFT_REPEAT(4419),
  [16372] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_package_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(12783),
  [16375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_import_declaration_repeat1, 2, 0, 78),
  [16377] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_import_declaration_repeat1, 2, 0, 78), SHIFT_REPEAT(12547),
  [16380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [16382] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__full_enum_def_repeat1, 2, 0, 0), SHIFT_REPEAT(4259),
  [16385] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__full_enum_def_repeat1, 2, 0, 0), SHIFT_REPEAT(17744),
  [16388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16771),
  [16390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1600),
  [16392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3728),
  [16394] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_constructor, 4, 0, 133),
  [16396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12220),
  [16398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2202),
  [16400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7793),
  [16402] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__top_level_definition, 1, 0, 0),
  [16404] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17742),
  [16407] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1336),
  [16410] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17810),
  [16413] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1345),
  [16416] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat1, 2, 0, 122), SHIFT_REPEAT(4461),
  [16419] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16989),
  [16422] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1205),
  [16425] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat2, 2, 0, 122), SHIFT_REPEAT(4463),
  [16428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9460),
  [16430] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16380),
  [16433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1571),
  [16435] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_selectors, 3, 0, 0),
  [16437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6301),
  [16439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4073),
  [16441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8883),
  [16443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3330),
  [16445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__enum_block_repeat1, 2, 0, 0),
  [16447] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat1, 2, 0, 122), SHIFT_REPEAT(4414),
  [16450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_as_renamed_identifier, 3, 0, 152),
  [16452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__type_parameter_repeat1, 2, 0, 0),
  [16454] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__type_parameter_repeat1, 2, 0, 0), SHIFT_REPEAT(3714),
  [16457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6531),
  [16459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enumerators_repeat1, 2, 0, 0),
  [16461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7597),
  [16463] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16474),
  [16466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1282),
  [16468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [16470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16071),
  [16472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16079),
  [16474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_upper_bound, 2, 0, 50),
  [16476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8706),
  [16478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_constructor, 3, 0, 98),
  [16480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerator, 5, 0, 0),
  [16482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5636),
  [16484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3640),
  [16486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9500),
  [16488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5306),
  [16490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10669),
  [16492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11792),
  [16494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14633),
  [16496] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17423),
  [16499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1237),
  [16501] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enumerator_repeat1, 2, 0, 0), SHIFT_REPEAT(2071),
  [16504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [16506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16066),
  [16508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16078),
  [16510] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(17175),
  [16513] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1208),
  [16516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8583),
  [16518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6973),
  [16520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1988),
  [16522] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__exprs_in_parens, 1, 0, 0),
  [16524] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16657),
  [16527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [16529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16222),
  [16531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1543),
  [16533] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16532),
  [16536] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1492),
  [16539] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16716),
  [16542] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1499),
  [16545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9010),
  [16547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6283),
  [16549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6769),
  [16551] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16160),
  [16554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1168),
  [16556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4090),
  [16558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6953),
  [16560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8552),
  [16562] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_import_declaration_repeat1, 2, 0, 78), SHIFT_REPEAT(12220),
  [16565] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16575),
  [16568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [16570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11795),
  [16572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14695),
  [16574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12114),
  [16576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14546),
  [16578] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_selectors, 5, 0, 0),
  [16580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1503),
  [16582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5998),
  [16584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12151),
  [16586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14723),
  [16588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12167),
  [16590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14552),
  [16592] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__namespace_expression, 3, 0, 5),
  [16594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8918),
  [16596] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat1, 2, 0, 122), SHIFT_REPEAT(4418),
  [16599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3363),
  [16601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__namespace_expression, 4, 0, 33),
  [16603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11815),
  [16605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14465),
  [16607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_import_declaration_repeat1, 2, 0, 6),
  [16609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5815),
  [16611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8166),
  [16613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1387),
  [16615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6705),
  [16617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7747),
  [16619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1263),
  [16621] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_selectors, 4, 0, 0),
  [16623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5723),
  [16625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16194),
  [16627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1540),
  [16629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16788),
  [16631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1603),
  [16633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2549),
  [16635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6307),
  [16637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 5, 0, 143),
  [16639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2556),
  [16641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5711),
  [16643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12468),
  [16645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_case_definitions, 2, 0, 0),
  [16647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2457),
  [16649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6496),
  [16651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2552),
  [16653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7758),
  [16655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2496),
  [16657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7852),
  [16659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2542),
  [16661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8123),
  [16663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_definition, 2, 0, 4),
  [16665] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_definition, 4, 0, 129),
  [16667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2524),
  [16669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8198),
  [16671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2555),
  [16673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7785),
  [16675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_definition, 2, 0, 45),
  [16677] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 3, 0, 146),
  [16679] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__type_parameter_repeat2, 2, 0, 0), SHIFT_REPEAT(3693),
  [16682] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__type_parameter_repeat2, 2, 0, 0),
  [16684] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 6, 0, 181),
  [16686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2544),
  [16688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5130),
  [16690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_template_body, 4, 0, 0),
  [16692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 4, 0, 0),
  [16694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 6, 0, 182),
  [16696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2557),
  [16698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7167),
  [16700] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__full_enum_def_repeat1, 1, 0, 0),
  [16702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2550),
  [16704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6426),
  [16706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2533),
  [16708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8640),
  [16710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_case_definitions, 3, 0, 0),
  [16712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12323),
  [16714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2380),
  [16716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2475),
  [16718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6842),
  [16720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2480),
  [16722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7744),
  [16724] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 2, 0, 16),
  [16726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3298),
  [16728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2560),
  [16730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8255),
  [16732] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 5, 0, 145),
  [16734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3692),
  [16736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2509),
  [16738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7185),
  [16740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2436),
  [16742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8738),
  [16744] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extension_definition, 2, 0, 14),
  [16746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [16748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2553),
  [16750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6634),
  [16752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2502),
  [16754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9140),
  [16756] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 3, 0, 59),
  [16758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3421),
  [16760] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 7, 0, 175),
  [16762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 2, 0, 11),
  [16764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2558),
  [16766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7109),
  [16768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2506),
  [16770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4956),
  [16772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2515),
  [16774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7419),
  [16776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2443),
  [16778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4807),
  [16780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 2, 0, 18),
  [16782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 4, 0, 112),
  [16784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3493),
  [16786] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 2, 0, 0),
  [16788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3776),
  [16790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14245),
  [16792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10303),
  [16794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11976),
  [16796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12154),
  [16798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2484),
  [16800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8269),
  [16802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2537),
  [16804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5341),
  [16806] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__structural_instance, 3, 0, 81),
  [16808] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 4, 0, 82),
  [16810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3560),
  [16812] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_type_repeat1, 2, 0, 84), SHIFT_REPEAT(8035),
  [16815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 6, 0, 182),
  [16817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [16819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17343),
  [16821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [16823] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 3, 0, 37),
  [16825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17419),
  [16827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [16829] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 7, 0, 176),
  [16831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2447),
  [16833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4729),
  [16835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_definition, 3, 0, 86),
  [16837] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_val_declaration, 5, 0, 134),
  [16839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_definition, 4, 0, 116),
  [16841] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_case_definitions_repeat1, 2, 0, 0), SHIFT_REPEAT(12468),
  [16844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_case_definitions_repeat1, 2, 0, 0),
  [16846] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_definition, 3, 0, 88),
  [16848] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_case_definitions, 4, 0, 0),
  [16850] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_definition, 4, 0, 72),
  [16852] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_definition, 3, 0, 24),
  [16854] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 3, 0, 58),
  [16856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2461),
  [16858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7075),
  [16860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2547),
  [16862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5901),
  [16864] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(16856),
  [16867] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1326),
  [16870] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16979),
  [16873] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1331),
  [16876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4040),
  [16878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3951),
  [16880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2541),
  [16882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5350),
  [16884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_declaration, 5, 0, 134),
  [16886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2494),
  [16888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5435),
  [16890] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 5, 0, 135),
  [16892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 3, 0, 60),
  [16894] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 5, 0, 136),
  [16896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trait_definition, 3, 0, 27),
  [16898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 6, 0, 185),
  [16900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_definition, 4, 0, 73),
  [16902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2519),
  [16904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9982),
  [16906] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 5, 0, 128),
  [16908] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_definition, 3, 0, 26),
  [16910] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 3, 0, 27),
  [16912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2440),
  [16914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5438),
  [16916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2455),
  [16918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5650),
  [16920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2503),
  [16922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6053),
  [16924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2453),
  [16926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8046),
  [16928] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_definition, 2, 0, 29),
  [16930] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 7, 0, 187),
  [16932] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__definition_body, 1, 0, 30),
  [16934] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 5, 0, 171),
  [16936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4046),
  [16938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4012),
  [16940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2511),
  [16942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7302),
  [16944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2554),
  [16946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8969),
  [16948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2543),
  [16950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6222),
  [16952] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 7, 0, 187),
  [16954] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(511),
  [16957] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enumerators_repeat1, 2, 0, 0), SHIFT_REPEAT(4040),
  [16960] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enumerators_repeat1, 2, 0, 0), SHIFT_REPEAT(4046),
  [16963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2445),
  [16965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7797),
  [16967] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 3, 0, 0),
  [16969] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__definition_body, 2, 0, 14),
  [16971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_template_body, 3, 0, 0),
  [16973] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_definition, 3, 0, 75),
  [16975] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__extension_template_body, 3, 0, 0),
  [16977] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extension_definition, 4, 0, 95),
  [16979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 4, 0, 96),
  [16981] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(509),
  [16984] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_definition, 3, 0, 77),
  [16986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2472),
  [16988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7320),
  [16990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3684),
  [16992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17442),
  [16994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1020),
  [16996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17240),
  [16998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1028),
  [17000] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_definition, 5, 0, 139),
  [17002] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__extension_template_body, 2, 0, 0),
  [17004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2529),
  [17006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5606),
  [17008] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trait_definition, 2, 0, 11),
  [17010] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 8, 0, 188),
  [17012] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0),
  [17014] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(17865),
  [17017] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 48), SHIFT(1379),
  [17020] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(16244),
  [17023] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 113), SHIFT(1384),
  [17026] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_definition, 5, 0, 124),
  [17028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2485),
  [17030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9618),
  [17032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2538),
  [17034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6221),
  [17036] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 4, 0, 117),
  [17038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2521),
  [17040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7337),
  [17042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2488),
  [17044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6712),
  [17046] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trait_definition, 4, 0, 109),
  [17048] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_val_definition, 6, 0, 157),
  [17050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerators, 1, 0, 0),
  [17052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3960),
  [17054] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_definition, 4, 0, 125),
  [17056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2546),
  [17058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7097),
  [17060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_definition, 6, 0, 157),
  [17062] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_val_definition, 4, 0, 106),
  [17064] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 6, 0, 158),
  [17066] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_definition, 4, 0, 106),
  [17068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2545),
  [17070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7352),
  [17072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2446),
  [17074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8712),
  [17076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2513),
  [17078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7435),
  [17080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4008),
  [17082] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 6, 0, 159),
  [17084] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extension_definition, 3, 0, 53),
  [17086] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_definition, 6, 0, 161),
  [17088] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_definition, 4, 0, 108),
  [17090] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 5, 0, 171),
  [17092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 6, 0, 162),
  [17094] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_definition, 5, 0, 140),
  [17096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2437),
  [17098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8059),
  [17100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extension_definition, 3, 0, 54),
  [17102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2540),
  [17104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7562),
  [17106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14030),
  [17108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10408),
  [17110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2463),
  [17112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9324),
  [17114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 4, 0, 164),
  [17116] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_definition, 5, 0, 141),
  [17118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2468),
  [17120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7748),
  [17122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 5, 0, 142),
  [17124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 4, 0, 109),
  [17126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2456),
  [17128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4945),
  [17130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2536),
  [17132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7389),
  [17134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 2, 0, 9),
  [17136] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_case_definitions_repeat1, 2, 0, 0), SHIFT_REPEAT(12323),
  [17139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 4, 0, 110),
  [17141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2539),
  [17143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5542),
  [17145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3204),
  [17147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 5, 0, 170),
  [17149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2442),
  [17151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5868),
  [17153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2501),
  [17155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7746),
  [17157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 5, 0, 177),
  [17159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2470),
  [17161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5499),
  [17163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14523),
  [17165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15302),
  [17167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identifiers, 4, 0, 0),
  [17169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13214),
  [17171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4210),
  [17173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11897),
  [17175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4096),
  [17177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6900),
  [17179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11543),
  [17181] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_simple_enum_case, 2, 0, 31),
  [17183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15941),
  [17185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [17187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5778),
  [17189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4097),
  [17191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5750),
  [17193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11566),
  [17195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14460),
  [17197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15134),
  [17199] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__indented_type_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(4210),
  [17202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__indented_type_cases_repeat1, 2, 0, 0),
  [17204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5276),
  [17206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12909),
  [17208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14640),
  [17210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15076),
  [17212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11534),
  [17214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14446),
  [17216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15230),
  [17218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7018),
  [17220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13146),
  [17222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12006),
  [17224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7632),
  [17226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9398),
  [17228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6997),
  [17230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14493),
  [17232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15180),
  [17234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3346),
  [17236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9631),
  [17238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13402),
  [17240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9279),
  [17242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7397),
  [17244] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__enum_block_repeat1, 2, 0, 0), SHIFT_REPEAT(520),
  [17247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6422),
  [17249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12153),
  [17251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13554),
  [17253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13548),
  [17255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8518),
  [17257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2467),
  [17259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13388),
  [17261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3114),
  [17263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6799),
  [17265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16002),
  [17267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14648),
  [17269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15206),
  [17271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [17273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15971),
  [17275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8854),
  [17277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4047),
  [17279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4032),
  [17281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [17283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [17285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6203),
  [17287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16050),
  [17289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14497),
  [17291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15243),
  [17293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [17295] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(512),
  [17298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_indented_cases_repeat1, 2, 0, 0),
  [17300] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_indented_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(4097),
  [17303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13645),
  [17305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3782),
  [17307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14550),
  [17309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15342),
  [17311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13097),
  [17313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9424),
  [17315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6888),
  [17317] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 4, 0, 105),
  [17319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2134),
  [17321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14662),
  [17323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15162),
  [17325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15950),
  [17327] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 3, 0, 102),
  [17329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2109),
  [17331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 5, 0, 172),
  [17333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2143),
  [17335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14432),
  [17337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15147),
  [17339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7603),
  [17341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14532),
  [17343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14997),
  [17345] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_derives_clause_repeat1, 2, 0, 151), SHIFT_REPEAT(11543),
  [17348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [17350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8621),
  [17352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13299),
  [17354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16026),
  [17356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12917),
  [17358] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(518),
  [17361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14709),
  [17363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15119),
  [17365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5700),
  [17367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12008),
  [17369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5688),
  [17371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11957),
  [17373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8913),
  [17375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14536),
  [17377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15171),
  [17379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12927),
  [17381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8555),
  [17383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2466),
  [17385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13706),
  [17387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8443),
  [17389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4025),
  [17391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14480),
  [17393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 3, 0, 102),
  [17395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2123),
  [17397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3329),
  [17399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11800),
  [17401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16003),
  [17403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerators, 5, 0, 0),
  [17405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13852),
  [17407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11858),
  [17409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11299),
  [17411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6710),
  [17413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9727),
  [17415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2566),
  [17417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 2, 0, 3),
  [17419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2100),
  [17421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13432),
  [17423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11490),
  [17425] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__enum_block_repeat1, 2, 0, 0), SHIFT_REPEAT(519),
  [17428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6305),
  [17430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11933),
  [17432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5241),
  [17434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7192),
  [17436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7667),
  [17438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2517),
  [17440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10678),
  [17442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8437),
  [17444] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_type_repeat1, 2, 0, 0), SHIFT_REPEAT(3520),
  [17447] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tuple_type_repeat1, 2, 0, 0),
  [17449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14584),
  [17451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15220),
  [17453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11040),
  [17455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerators, 4, 0, 0),
  [17457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7493),
  [17459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6528),
  [17461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8806),
  [17463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13701),
  [17465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14661),
  [17467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15103),
  [17469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15953),
  [17471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11145),
  [17473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16005),
  [17475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5766),
  [17477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8187),
  [17479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14616),
  [17481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15250),
  [17483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2563),
  [17485] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 3, 0, 147),
  [17487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2124),
  [17489] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enumerators_repeat1, 2, 0, 0), SHIFT_REPEAT(4047),
  [17492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12165),
  [17494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8824),
  [17496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15927),
  [17498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7507),
  [17500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15877),
  [17502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5895),
  [17504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13500),
  [17506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_identifiers_repeat1, 2, 0, 0),
  [17508] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(13214),
  [17511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0),
  [17513] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(168),
  [17516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14632),
  [17518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15050),
  [17520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14670),
  [17522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15192),
  [17524] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_val_declaration_repeat1, 2, 0, 3), REDUCE(sym_identifiers, 3, 0, 0),
  [17527] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_val_declaration_repeat1, 2, 0, 3), SHIFT(13214),
  [17530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identifiers, 3, 0, 0),
  [17532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6543),
  [17534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13513),
  [17536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12150),
  [17538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16556),
  [17540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10685),
  [17542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8204),
  [17544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13981),
  [17546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13051),
  [17548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11278),
  [17550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8613),
  [17552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16057),
  [17554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13267),
  [17556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 6, 0, 184),
  [17558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2146),
  [17560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16137),
  [17562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16074),
  [17564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_view_bound, 2, 0, 50),
  [17566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9242),
  [17568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11607),
  [17570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12690),
  [17572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2564),
  [17574] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 1, 0, 2),
  [17576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2064),
  [17578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12610),
  [17580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12456),
  [17582] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 4, 0, 105),
  [17584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2136),
  [17586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10939),
  [17588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13781),
  [17590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17098),
  [17592] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 5, 0, 172),
  [17594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2145),
  [17596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12176),
  [17598] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__type_parameter_repeat1, 1, 0, 0),
  [17600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10779),
  [17602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8496),
  [17604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [17606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16130),
  [17608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12908),
  [17610] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_indented_cases_repeat1, 2, 0, 0), SHIFT_REPEAT(4096),
  [17613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6527),
  [17615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12152),
  [17617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2570),
  [17619] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 4, 0, 165),
  [17621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2138),
  [17623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15905),
  [17625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6651),
  [17627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16082),
  [17629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6921),
  [17631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13583),
  [17633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13287),
  [17635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17744),
  [17637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_namespace_selectors_repeat1, 2, 0, 0),
  [17639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6264),
  [17641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15865),
  [17643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16119),
  [17645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12038),
  [17647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10791),
  [17649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12570),
  [17651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11931),
  [17653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2017),
  [17655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6050),
  [17657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2688),
  [17659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13124),
  [17661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2690),
  [17663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7952),
  [17665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2693),
  [17667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14736),
  [17669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17876),
  [17671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16958),
  [17673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14865),
  [17675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2694),
  [17677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1913),
  [17679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6730),
  [17681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2700),
  [17683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6466),
  [17685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2701),
  [17687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6022),
  [17689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2702),
  [17691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2704),
  [17693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2711),
  [17695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11187),
  [17697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2713),
  [17699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4501),
  [17701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2715),
  [17703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2716),
  [17705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2900),
  [17707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7313),
  [17709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15515),
  [17711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6999),
  [17713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15534),
  [17715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2721),
  [17717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6786),
  [17719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2904),
  [17721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5993),
  [17723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2723),
  [17725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5093),
  [17727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3354),
  [17729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2724),
  [17731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2727),
  [17733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2729),
  [17735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8342),
  [17737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2686),
  [17739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5608),
  [17741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2732),
  [17743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4779),
  [17745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2735),
  [17747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2737),
  [17749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2906),
  [17751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1844),
  [17753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7512),
  [17755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2738),
  [17757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4646),
  [17759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2739),
  [17761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7803),
  [17763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2740),
  [17765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2741),
  [17767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2907),
  [17769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13567),
  [17771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2743),
  [17773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5109),
  [17775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7002),
  [17777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2745),
  [17779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4785),
  [17781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2746),
  [17783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2911),
  [17785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2748),
  [17787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2797),
  [17789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5224),
  [17791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2910),
  [17793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2754),
  [17795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12630),
  [17797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2809),
  [17799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6868),
  [17801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2755),
  [17803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6398),
  [17805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4377),
  [17807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2756),
  [17809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2758),
  [17811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8235),
  [17813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2913),
  [17815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2760),
  [17817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5116),
  [17819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2761),
  [17821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13022),
  [17823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2762),
  [17825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2764),
  [17827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10402),
  [17829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2767),
  [17831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6891),
  [17833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2787),
  [17835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6596),
  [17837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8718),
  [17839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2769),
  [17841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6562),
  [17843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2770),
  [17845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2771),
  [17847] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_class_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(4167),
  [17850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10721),
  [17852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2777),
  [17854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5121),
  [17856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2689),
  [17858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2779),
  [17860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5674),
  [17862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2781),
  [17864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2783),
  [17866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2811),
  [17868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4100),
  [17870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2788),
  [17872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6948),
  [17874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2789),
  [17876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6083),
  [17878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2791),
  [17880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2915),
  [17882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5487),
  [17884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2793),
  [17886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11170),
  [17888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16519),
  [17890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2798),
  [17892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6149),
  [17894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2799),
  [17896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6974),
  [17898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2800),
  [17900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2802),
  [17902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2917),
  [17904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6167),
  [17906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2804),
  [17908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6986),
  [17910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8925),
  [17912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2806),
  [17914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6250),
  [17916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2808),
  [17918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2801),
  [17920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2810),
  [17922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2919),
  [17924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6142),
  [17926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3836),
  [17928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2815),
  [17930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4621),
  [17932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2925),
  [17934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2692),
  [17936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2817),
  [17938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12680),
  [17940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2818),
  [17942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2819),
  [17944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2792),
  [17946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2824),
  [17948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9543),
  [17950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2826),
  [17952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7567),
  [17954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2827),
  [17956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2927),
  [17958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2829),
  [17960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1840),
  [17962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8931),
  [17964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2836),
  [17966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5139),
  [17968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2837),
  [17970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7042),
  [17972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2839),
  [17974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2840),
  [17976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2920),
  [17978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7019),
  [17980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3636),
  [17982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8937),
  [17984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2846),
  [17986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12794),
  [17988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2847),
  [17990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11010),
  [17992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2849),
  [17994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2851),
  [17996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2803),
  [17998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2922),
  [18000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2814),
  [18002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2858),
  [18004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5861),
  [18006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2859),
  [18008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8112),
  [18010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2861),
  [18012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16095),
  [18014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17877),
  [18016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2863),
  [18018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2616),
  [18020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9111),
  [18022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2924),
  [18024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2865),
  [18026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7062),
  [18028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2867),
  [18030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11521),
  [18032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2870),
  [18034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2871),
  [18036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2875),
  [18038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7647),
  [18040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2876),
  [18042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4864),
  [18044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2878),
  [18046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2880),
  [18048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2929),
  [18050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5579),
  [18052] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_context_bound, 2, 0, 50),
  [18054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1891),
  [18056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2882),
  [18058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4873),
  [18060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2883),
  [18062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4678),
  [18064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2887),
  [18066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2888),
  [18068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2931),
  [18070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8957),
  [18072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3089),
  [18074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2892),
  [18076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5975),
  [18078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11198),
  [18080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2894),
  [18082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5153),
  [18084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2895),
  [18086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2898),
  [18088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2937),
  [18090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2903),
  [18092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5469),
  [18094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2905),
  [18096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5471),
  [18098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2908),
  [18100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2643),
  [18102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2909),
  [18104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2939),
  [18106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6735),
  [18108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13269),
  [18110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2916),
  [18112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6479),
  [18114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2918),
  [18116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5164),
  [18118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2921),
  [18120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2923),
  [18122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2935),
  [18124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12059),
  [18126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4282),
  [18128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2942),
  [18130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8976),
  [18132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2943),
  [18134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7144),
  [18136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2932),
  [18138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6172),
  [18140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2947),
  [18142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3175),
  [18144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2619),
  [18146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2949),
  [18148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13133),
  [18150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2953),
  [18152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2957),
  [18154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8099),
  [18156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2961),
  [18158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2794),
  [18160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1889),
  [18162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9381),
  [18164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2969),
  [18166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5170),
  [18168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4321),
  [18170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2973),
  [18172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2975),
  [18174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7165),
  [18176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2977),
  [18178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2984),
  [18180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13087),
  [18182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2990),
  [18184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2934),
  [18186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4902),
  [18188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2995),
  [18190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6097),
  [18192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3001),
  [18194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8983),
  [18196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3009),
  [18198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7181),
  [18200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3018),
  [18202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3023),
  [18204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4742),
  [18206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2936),
  [18208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3024),
  [18210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3048),
  [18212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9402),
  [18214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3066),
  [18216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2581),
  [18218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5177),
  [18220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2582),
  [18222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9715),
  [18224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2583),
  [18226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6427),
  [18228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2584),
  [18230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2938),
  [18232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2585),
  [18234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5494),
  [18236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2586),
  [18238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2587),
  [18240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12364),
  [18242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2588),
  [18244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2589),
  [18246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7200),
  [18248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2590),
  [18250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2591),
  [18252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13240),
  [18254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2592),
  [18256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2593),
  [18258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7847),
  [18260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2594),
  [18262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2940),
  [18264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6817),
  [18266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2595),
  [18268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11272),
  [18270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2596),
  [18272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2597),
  [18274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4917),
  [18276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2598),
  [18278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2599),
  [18280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5504),
  [18282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2600),
  [18284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2601),
  [18286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12377),
  [18288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2602),
  [18290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2603),
  [18292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5510),
  [18294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2941),
  [18296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5632),
  [18298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2604),
  [18300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2605),
  [18302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6077),
  [18304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2606),
  [18306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2607),
  [18308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12719),
  [18310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2608),
  [18312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2944),
  [18314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2945),
  [18316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7635),
  [18318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2946),
  [18320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7060),
  [18322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3206),
  [18324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3625),
  [18326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2813),
  [18328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6679),
  [18330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14548),
  [18332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3345),
  [18334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1955),
  [18336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6218),
  [18338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9967),
  [18340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2948),
  [18342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5358),
  [18344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2954),
  [18346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12805),
  [18348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7641),
  [18350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2950),
  [18352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11245),
  [18354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16449),
  [18356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9526),
  [18358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2955),
  [18360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9114),
  [18362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11246),
  [18364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16501),
  [18366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2825),
  [18368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7997),
  [18370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2952),
  [18372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2958),
  [18374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2705),
  [18376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11599),
  [18378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3201),
  [18380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3778),
  [18382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2963),
  [18384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2621),
  [18386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3806),
  [18388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2816),
  [18390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6707),
  [18392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3235),
  [18394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3267),
  [18396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3424),
  [18398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3242),
  [18400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3725),
  [18402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3143),
  [18404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3237),
  [18406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3422),
  [18408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3607),
  [18410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3420),
  [18412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3441),
  [18414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3507),
  [18416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3689),
  [18418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3721),
  [18420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3606),
  [18422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3828),
  [18424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3120),
  [18426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3203),
  [18428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1954),
  [18430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6902),
  [18432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2968),
  [18434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6923),
  [18436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1931),
  [18438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8678),
  [18440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2970),
  [18442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6386),
  [18444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9034),
  [18446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14531),
  [18448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2775),
  [18450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4653),
  [18452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2959),
  [18454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7090),
  [18456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3477),
  [18458] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_comment_repeat1, 2, 0, 0), SHIFT_REPEAT(16095),
  [18461] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_block_comment_repeat1, 2, 0, 0),
  [18463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2978),
  [18465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11160),
  [18467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16731),
  [18469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11257),
  [18471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17096),
  [18473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4272),
  [18475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17587),
  [18477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11258),
  [18479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17123),
  [18481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2014),
  [18483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7689),
  [18485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3167),
  [18487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3503),
  [18489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3696),
  [18491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3744),
  [18493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3259),
  [18495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3273),
  [18497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3319),
  [18499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3752),
  [18501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2981),
  [18503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2960),
  [18505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11597),
  [18507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2820),
  [18509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2828),
  [18511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8007),
  [18513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9764),
  [18515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14631),
  [18517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9038),
  [18519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2962),
  [18521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2988),
  [18523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7560),
  [18525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11261),
  [18527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17398),
  [18529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2821),
  [18531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11262),
  [18533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17447),
  [18535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2964),
  [18537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3306),
  [18539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3536),
  [18541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3756),
  [18543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3239),
  [18545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3511),
  [18547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3350),
  [18549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3387),
  [18551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3809),
  [18553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2830),
  [18555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2989),
  [18557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7053),
  [18559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2997),
  [18561] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_parameters_repeat1, 2, 0, 127), SHIFT_REPEAT(7529),
  [18564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_parameters_repeat1, 2, 0, 127),
  [18566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2999),
  [18568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2710),
  [18570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5620),
  [18572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14525),
  [18574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6648),
  [18576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1897),
  [18578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10840),
  [18580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2832),
  [18582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3002),
  [18584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11112),
  [18586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3341),
  [18588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3573),
  [18590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3440),
  [18592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9534),
  [18594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2658),
  [18596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13458),
  [18598] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__type_parameter_repeat2, 1, 0, 0),
  [18600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3007),
  [18602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7100),
  [18604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14647),
  [18606] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interpolated_string_repeat2, 2, 0, 0), SHIFT_REPEAT(15534),
  [18609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_interpolated_string_repeat2, 2, 0, 0),
  [18611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3465),
  [18613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3010),
  [18615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10848),
  [18617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3373),
  [18619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3205),
  [18621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3011),
  [18623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2712),
  [18625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9474),
  [18627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2747),
  [18629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7324),
  [18631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14708),
  [18633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2971),
  [18635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8540),
  [18637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7248),
  [18639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12897),
  [18641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3535),
  [18643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3228),
  [18645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2778),
  [18647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4661),
  [18649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3402),
  [18651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2479),
  [18653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1924),
  [18655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8549),
  [18657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10782),
  [18659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14433),
  [18661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3014),
  [18663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7809),
  [18665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6722),
  [18667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12444),
  [18669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2972),
  [18671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11000),
  [18673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9482),
  [18675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3015),
  [18677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7824),
  [18679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2974),
  [18681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3016),
  [18683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2714),
  [18685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2752),
  [18687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14666),
  [18689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2976),
  [18691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3017),
  [18693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4284),
  [18695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14651),
  [18697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1906),
  [18699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9883),
  [18701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2914),
  [18703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3019),
  [18705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11651),
  [18707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6329),
  [18709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2982),
  [18711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11311),
  [18713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3020),
  [18715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8379),
  [18717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3576),
  [18719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14535),
  [18721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__full_enum_def, 3, 0, 178),
  [18723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3021),
  [18725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2983),
  [18727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8638),
  [18729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6331),
  [18731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2985),
  [18733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3022),
  [18735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14488),
  [18737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2987),
  [18739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2459),
  [18741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16067),
  [18743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10889),
  [18745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3743),
  [18747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2831),
  [18749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6021),
  [18751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2780),
  [18753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4287),
  [18755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3025),
  [18757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7964),
  [18759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14668),
  [18761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10888),
  [18763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1861),
  [18765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10346),
  [18767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3026),
  [18769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7974),
  [18771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10799),
  [18773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3027),
  [18775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8087),
  [18777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14580),
  [18779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2822),
  [18781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2993),
  [18783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7153),
  [18785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3722),
  [18787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4288),
  [18789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2834),
  [18791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6048),
  [18793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3028),
  [18795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2994),
  [18797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6344),
  [18799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7784),
  [18801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14577),
  [18803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2844),
  [18805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8386),
  [18807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3274),
  [18809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2996),
  [18811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2663),
  [18813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6035),
  [18815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2838),
  [18817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3030),
  [18819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4981),
  [18821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2998),
  [18823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14440),
  [18825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3031),
  [18827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11347),
  [18829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3032),
  [18831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1841),
  [18833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6932),
  [18835] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_parameters_repeat1, 2, 0, 0), SHIFT_REPEAT(4392),
  [18838] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_parameters_repeat1, 2, 0, 0),
  [18840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3033),
  [18842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14486),
  [18844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2841),
  [18846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8129),
  [18848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3003),
  [18850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8130),
  [18852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3652),
  [18854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9446),
  [18856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9874),
  [18858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3035),
  [18860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5015),
  [18862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14614),
  [18864] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_full_enum_case, 2, 0, 149),
  [18866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3036),
  [18868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10050),
  [18870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3004),
  [18872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13917),
  [18874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8138),
  [18876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3006),
  [18878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3037),
  [18880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2848),
  [18882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6934),
  [18884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2726),
  [18886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10999),
  [18888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3008),
  [18890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3038),
  [18892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3434),
  [18894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6040),
  [18896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10680),
  [18898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11320),
  [18900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2850),
  [18902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3040),
  [18904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5028),
  [18906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2782),
  [18908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3041),
  [18910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4692),
  [18912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2833),
  [18914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9848),
  [18916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2490),
  [18918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3095),
  [18920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3042),
  [18922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3043),
  [18924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2854),
  [18926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8171),
  [18928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2677),
  [18930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10390),
  [18932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3013),
  [18934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3029),
  [18936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7860),
  [18938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1865),
  [18940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8565),
  [18942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4274),
  [18944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16392),
  [18946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2853),
  [18948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3044),
  [18950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5601),
  [18952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3045),
  [18954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5042),
  [18956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7308),
  [18958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10901),
  [18960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10769),
  [18962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2843),
  [18964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9316),
  [18966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3191),
  [18968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3046),
  [18970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3047),
  [18972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11186),
  [18974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16044),
  [18976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2980),
  [18978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4716),
  [18980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2731),
  [18982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8603),
  [18984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1855),
  [18986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8031),
  [18988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2665),
  [18990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9884),
  [18992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2786),
  [18994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6406),
  [18996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3394),
  [18998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3399),
  [19000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3401),
  [19002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3404),
  [19004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2852),
  [19006] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2, 0, 0), SHIFT_REPEAT(11048),
  [19009] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2, 0, 0),
  [19011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10413),
  [19013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2868),
  [19015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7403),
  [19017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3049),
  [19019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11966),
  [19021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3000),
  [19023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7410),
  [19025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3050),
  [19027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5264),
  [19029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4309),
  [19031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7317),
  [19033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10668),
  [19035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10696),
  [19037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10703),
  [19039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3051),
  [19041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2893),
  [19043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3052),
  [19045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11288),
  [19047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2855),
  [19049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9035),
  [19051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2733),
  [19053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2897),
  [19055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2003),
  [19057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8683),
  [19059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3053),
  [19061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5659),
  [19063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3034),
  [19065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5411),
  [19067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2790),
  [19069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10077),
  [19071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3054),
  [19073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4802),
  [19075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4312),
  [19077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4313),
  [19079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2707),
  [19081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11904),
  [19083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3055),
  [19085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10796),
  [19087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2667),
  [19089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2674),
  [19091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10804),
  [19093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2736),
  [19095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2535),
  [19097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2785),
  [19099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3056),
  [19101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4129),
  [19103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4314),
  [19105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2933),
  [19107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4315),
  [19109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10331),
  [19111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3058),
  [19113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13222),
  [19115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3081),
  [19117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9049),
  [19119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3059),
  [19121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5314),
  [19123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4330),
  [19125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4316),
  [19127] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_lambda_repeat1, 2, 0, 127), SHIFT_REPEAT(11705),
  [19130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_lambda_repeat1, 2, 0, 127),
  [19132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3060),
  [19134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4317),
  [19136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3061),
  [19138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2631),
  [19140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5421),
  [19142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2979),
  [19144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11586),
  [19146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3062),
  [19148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6045),
  [19150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3063),
  [19152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5735),
  [19154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2751),
  [19156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3064),
  [19158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2633),
  [19160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8314),
  [19162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3065),
  [19164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2860),
  [19166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2763),
  [19168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2807),
  [19170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3067),
  [19172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13162),
  [19174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2862),
  [19176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3068),
  [19178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6956),
  [19180] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__full_enum_def, 2, 0, 167),
  [19182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14418),
  [19184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3069),
  [19186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5734),
  [19188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3070),
  [19190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2866),
  [19192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11885),
  [19194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3830),
  [19196] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__using_parameters_clause_repeat1, 2, 0, 0), REDUCE(aux_sym_tuple_type_repeat1, 2, 0, 0),
  [19199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3071),
  [19201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5810),
  [19203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2928),
  [19205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6481),
  [19207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3072),
  [19209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6255),
  [19211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2951),
  [19213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7919),
  [19215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3073),
  [19217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3074),
  [19219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2986),
  [19221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3012),
  [19223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1904),
  [19225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8825),
  [19227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3077),
  [19229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7048),
  [19231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3078),
  [19233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12983),
  [19235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6795),
  [19237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3079),
  [19239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3039),
  [19241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5434),
  [19243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2750),
  [19245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8192),
  [19247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3470),
  [19249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3080),
  [19251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2869),
  [19253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8665),
  [19255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3057),
  [19257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9221),
  [19259] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__using_parameters_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(2573),
  [19262] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__using_parameters_clause_repeat1, 2, 0, 0),
  [19264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2627),
  [19266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2796),
  [19268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7080),
  [19270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5737),
  [19272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2610),
  [19274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2856),
  [19276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12160),
  [19278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2912),
  [19280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2835),
  [19282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1972),
  [19284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9200),
  [19286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8191),
  [19288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11088),
  [19290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2872),
  [19292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2666),
  [19294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6396),
  [19296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2709),
  [19298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7284),
  [19300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2753),
  [19302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9622),
  [19304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2687),
  [19306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11816),
  [19308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2695),
  [19310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2728),
  [19312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8457),
  [19314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2765),
  [19316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6802),
  [19318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_object, 3, 0, 26),
  [19320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2698),
  [19322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2812),
  [19324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2874),
  [19326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2757),
  [19328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2720),
  [19330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6459),
  [19332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2742),
  [19334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7745),
  [19336] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_clause, 3, 0, 28),
  [19338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11192),
  [19340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2773),
  [19342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2823),
  [19344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9486),
  [19346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2857),
  [19348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12970),
  [19350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6670),
  [19352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12163),
  [19354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2759),
  [19356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10707),
  [19358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3076),
  [19360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4367),
  [19362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3407),
  [19364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2901),
  [19366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10032),
  [19368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2956),
  [19370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2842),
  [19372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8174),
  [19374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14080),
  [19376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1846),
  [19378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9529),
  [19380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2967),
  [19382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2845),
  [19384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7189),
  [19386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3751),
  [19388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3771),
  [19390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3772),
  [19392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3774),
  [19394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2719),
  [19396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11467),
  [19398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2864),
  [19400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2877),
  [19402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8360),
  [19404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9544),
  [19406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2873),
  [19408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4326),
  [19410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6674),
  [19412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12171),
  [19414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10810),
  [19416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10142),
  [19418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10830),
  [19420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14056),
  [19422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2930),
  [19424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8228),
  [19426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11502),
  [19428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9322),
  [19430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11496),
  [19432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2966),
  [19434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7855),
  [19436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2617),
  [19438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2622),
  [19440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11983),
  [19442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4329),
  [19444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6719),
  [19446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12407),
  [19448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10927),
  [19450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10935),
  [19452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2504),
  [19454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6732),
  [19456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13224),
  [19458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2991),
  [19460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9058),
  [19462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4084),
  [19464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3005),
  [19466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2623),
  [19468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7319),
  [19470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2609),
  [19472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2879),
  [19474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8587),
  [19476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2611),
  [19478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8043),
  [19480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4331),
  [19482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3134),
  [19484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2626),
  [19486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2634),
  [19488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11497),
  [19490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2612),
  [19492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4490),
  [19494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2630),
  [19496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2613),
  [19498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5963),
  [19500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3369),
  [19502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2614),
  [19504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2615),
  [19506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binding, 3, 10, 102),
  [19508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2885),
  [19510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2618),
  [19512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5461),
  [19514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2620),
  [19516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7259),
  [19518] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(2202),
  [19521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2637),
  [19523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12026),
  [19525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2572),
  [19527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binding, 1, 10, 2),
  [19529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2624),
  [19531] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interpolated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(15515),
  [19534] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_interpolated_string_repeat1, 2, 0, 0),
  [19536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2625),
  [19538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2642),
  [19540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8574),
  [19542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2568),
  [19544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binding, 1, 10, 0),
  [19546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3439),
  [19548] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_bindings_repeat1, 2, 0, 0), SHIFT_REPEAT(11628),
  [19551] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_bindings_repeat1, 2, 0, 0),
  [19553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2628),
  [19555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4969),
  [19557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binding, 3, 10, 103),
  [19559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6976),
  [19561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2647),
  [19563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2629),
  [19565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7271),
  [19567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2649),
  [19569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2632),
  [19571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2635),
  [19573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2580),
  [19575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5214),
  [19577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2890),
  [19579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2884),
  [19581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5334),
  [19583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3195),
  [19585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2636),
  [19587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4974),
  [19589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2638),
  [19591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6314),
  [19593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2653),
  [19595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7347),
  [19597] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_val_declaration_repeat1, 2, 0, 107),
  [19599] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_val_declaration_repeat1, 2, 0, 107), SHIFT_REPEAT(12998),
  [19602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11003),
  [19604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6702),
  [19606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14085),
  [19608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2749),
  [19610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5921),
  [19612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3556),
  [19614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2640),
  [19616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2805),
  [19618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11919),
  [19620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2644),
  [19622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1882),
  [19624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9657),
  [19626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2654),
  [19628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8030),
  [19630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2766),
  [19632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9663),
  [19634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3667),
  [19636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10993),
  [19638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4339),
  [19640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6708),
  [19642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14072),
  [19644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2784),
  [19646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2661),
  [19648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2645),
  [19650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6068),
  [19652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11327),
  [19654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17857),
  [19656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17878),
  [19658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11328),
  [19660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16154),
  [19662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2662),
  [19664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8573),
  [19666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2646),
  [19668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13623),
  [19670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6960),
  [19672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12673),
  [19674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2795),
  [19676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11329),
  [19678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16415),
  [19680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11330),
  [19682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16430),
  [19684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2768),
  [19686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13880),
  [19688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3603),
  [19690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11331),
  [19692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16573),
  [19694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11332),
  [19696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16588),
  [19698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4342),
  [19700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2648),
  [19702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11333),
  [19704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16730),
  [19706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11334),
  [19708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16735),
  [19710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2650),
  [19712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11335),
  [19714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16834),
  [19716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11336),
  [19718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16840),
  [19720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11337),
  [19722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16930),
  [19724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11338),
  [19726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16934),
  [19728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11339),
  [19730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17046),
  [19732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11340),
  [19734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17050),
  [19736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2670),
  [19738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13572),
  [19740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1981),
  [19742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8870),
  [19744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11341),
  [19746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17120),
  [19748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11342),
  [19750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17130),
  [19752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11343),
  [19754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17189),
  [19756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11344),
  [19758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17193),
  [19760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11345),
  [19762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17264),
  [19764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2671),
  [19766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7368),
  [19768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11346),
  [19770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17267),
  [19772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11348),
  [19774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17326),
  [19776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11349),
  [19778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17333),
  [19780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2675),
  [19782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4343),
  [19784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11350),
  [19786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17389),
  [19788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11351),
  [19790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17395),
  [19792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11352),
  [19794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17458),
  [19796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11353),
  [19798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17466),
  [19800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2676),
  [19802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2651),
  [19804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6110),
  [19806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11354),
  [19808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17519),
  [19810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11355),
  [19812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17525),
  [19814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11356),
  [19816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17580),
  [19818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11357),
  [19820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17583),
  [19822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2886),
  [19824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11484),
  [19826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1894),
  [19828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9632),
  [19830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11359),
  [19832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17640),
  [19834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1964),
  [19836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10007),
  [19838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11360),
  [19840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17645),
  [19842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2652),
  [19844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9671),
  [19846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4344),
  [19848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11361),
  [19850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17695),
  [19852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11362),
  [19854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17701),
  [19856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11363),
  [19858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17749),
  [19860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11364),
  [19862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17755),
  [19864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11365),
  [19866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17858),
  [19868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4303),
  [19870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11366),
  [19872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17861),
  [19874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2655),
  [19876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11368),
  [19878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16168),
  [19880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11369),
  [19882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16171),
  [19884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11370),
  [19886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16198),
  [19888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11371),
  [19890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16201),
  [19892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11372),
  [19894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16228),
  [19896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2678),
  [19898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11715),
  [19900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11373),
  [19902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16231),
  [19904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2656),
  [19906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11374),
  [19908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16258),
  [19910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2772),
  [19912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7740),
  [19914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11375),
  [19916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16261),
  [19918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11376),
  [19920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16285),
  [19922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11377),
  [19924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16288),
  [19926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6980),
  [19928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11378),
  [19930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16309),
  [19932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2679),
  [19934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12095),
  [19936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11379),
  [19938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16312),
  [19940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11380),
  [19942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16333),
  [19944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11381),
  [19946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16335),
  [19948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2685),
  [19950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11382),
  [19952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16356),
  [19954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11383),
  [19956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16358),
  [19958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11384),
  [19960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16376),
  [19962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11385),
  [19964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16378),
  [19966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2691),
  [19968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11386),
  [19970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16397),
  [19972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11387),
  [19974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16399),
  [19976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2657),
  [19978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6468),
  [19980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11388),
  [19982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16418),
  [19984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11389),
  [19986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16420),
  [19988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11390),
  [19990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16439),
  [19992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11391),
  [19994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16441),
  [19996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2889),
  [19998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2659),
  [20000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6603),
  [20002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11392),
  [20004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16460),
  [20006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8607),
  [20008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11393),
  [20010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16462),
  [20012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11394),
  [20014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16481),
  [20016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11395),
  [20018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16483),
  [20020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11396),
  [20022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16502),
  [20024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11397),
  [20026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16504),
  [20028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2660),
  [20030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11398),
  [20032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16523),
  [20034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11399),
  [20036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16525),
  [20038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2774),
  [20040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11400),
  [20042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16543),
  [20044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11401),
  [20046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16545),
  [20048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11402),
  [20050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16563),
  [20052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2664),
  [20054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11403),
  [20056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16565),
  [20058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2696),
  [20060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6792),
  [20062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11404),
  [20064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16583),
  [20066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11405),
  [20068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16585),
  [20070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11134),
  [20072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16603),
  [20074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11406),
  [20076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16605),
  [20078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11407),
  [20080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16623),
  [20082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11408),
  [20084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16625),
  [20086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2697),
  [20088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10828),
  [20090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11409),
  [20092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16643),
  [20094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11410),
  [20096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16645),
  [20098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11411),
  [20100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16663),
  [20102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11412),
  [20104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16665),
  [20106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11413),
  [20108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16682),
  [20110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2699),
  [20112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11414),
  [20114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16684),
  [20116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11415),
  [20118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16701),
  [20120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11416),
  [20122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16703),
  [20124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2668),
  [20126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12464),
  [20128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11417),
  [20130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16720),
  [20132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2703),
  [20134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11418),
  [20136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16722),
  [20138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11419),
  [20140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16739),
  [20142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11420),
  [20144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16741),
  [20146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11421),
  [20148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16758),
  [20150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11422),
  [20152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16760),
  [20154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2891),
  [20156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11423),
  [20158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16776),
  [20160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2669),
  [20162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8531),
  [20164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11424),
  [20166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16778),
  [20168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11425),
  [20170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16794),
  [20172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11426),
  [20174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16796),
  [20176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2776),
  [20178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11427),
  [20180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16812),
  [20182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11428),
  [20184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16814),
  [20186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11429),
  [20188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16830),
  [20190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11430),
  [20192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16832),
  [20194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2672),
  [20196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11431),
  [20198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16847),
  [20200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11432),
  [20202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16849),
  [20204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11433),
  [20206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16865),
  [20208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11434),
  [20210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16867),
  [20212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11435),
  [20214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16883),
  [20216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11436),
  [20218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16885),
  [20220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2706),
  [20222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8168),
  [20224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11437),
  [20226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16901),
  [20228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11438),
  [20230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16903),
  [20232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2673),
  [20234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11439),
  [20236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16913),
  [20238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11440),
  [20240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16915),
  [20242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11441),
  [20244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16925),
  [20246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11442),
  [20248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16927),
  [20250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11443),
  [20252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16937),
  [20254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11444),
  [20256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16939),
  [20258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2708),
  [20260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5524),
  [20262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11445),
  [20264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16948),
  [20266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11446),
  [20268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16950),
  [20270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11447),
  [20272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16959),
  [20274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11448),
  [20276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16961),
  [20278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11449),
  [20280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16970),
  [20282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2717),
  [20284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11450),
  [20286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16972),
  [20288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11451),
  [20290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16981),
  [20292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2639),
  [20294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4291),
  [20296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11452),
  [20298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16983),
  [20300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11453),
  [20302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16992),
  [20304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11454),
  [20306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16994),
  [20308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2718),
  [20310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11455),
  [20312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17003),
  [20314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11456),
  [20316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17005),
  [20318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11457),
  [20320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17014),
  [20322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11314),
  [20324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17016),
  [20326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1982),
  [20328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5695),
  [20330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8670),
  [20332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2680),
  [20334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6620),
  [20336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2681),
  [20338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11701),
  [20340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11500),
  [20342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2722),
  [20344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7837),
  [20346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2725),
  [20348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5386),
  [20350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2682),
  [20352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2730),
  [20354] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_namespace_selectors_repeat1, 2, 0, 0), SHIFT_REPEAT(10611),
  [20357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2684),
  [20359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4789),
  [20361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2683),
  [20363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2734),
  [20365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2881),
  [20367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7741),
  [20369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2641),
  [20371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3272),
  [20373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2902),
  [20375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9644),
  [20377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2899),
  [20379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12670),
  [20381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3075),
  [20383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2744),
  [20385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7242),
  [20387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1215),
  [20389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [20391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1465),
  [20393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1241),
  [20395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [20397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [20399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1408),
  [20401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_val_declaration_repeat1, 2, 0, 3),
  [20403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3092),
  [20405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [20407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1320),
  [20409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1388),
  [20411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 3, 0, 74),
  [20413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3094),
  [20415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [20417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bindings, 5, 0, 0),
  [20419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2139),
  [20421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1584),
  [20423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(842),
  [20425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1486),
  [20427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15336),
  [20429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1394),
  [20431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1586),
  [20433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1588),
  [20435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1038),
  [20437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3811),
  [20439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1504),
  [20441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2103),
  [20443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bindings, 2, 0, 0),
  [20445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_types, 2, 1, 0),
  [20447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1223),
  [20449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15301),
  [20451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variant_type_parameter, 1, 0, 35),
  [20453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3813),
  [20455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1530),
  [20457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1410),
  [20459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_types, 5, 1, 0),
  [20461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1413),
  [20463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15081),
  [20465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1424),
  [20467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_parameters_repeat1, 2, 0, 16),
  [20469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1199),
  [20471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1226),
  [20473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1228),
  [20475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1305),
  [20477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [20479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1307),
  [20481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_types, 4, 1, 0),
  [20483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1595),
  [20485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1444),
  [20487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1204),
  [20489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1597),
  [20491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1599),
  [20493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1287),
  [20495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1527),
  [20497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2219),
  [20499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1134),
  [20501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1428),
  [20503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3112),
  [20505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [20507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1431),
  [20509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_case_clause, 3, 0, 183),
  [20511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1572),
  [20513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1044),
  [20515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12381),
  [20517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12104),
  [20519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1265),
  [20521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15165),
  [20523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1396),
  [20525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [20527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1267),
  [20529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(851),
  [20531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(844),
  [20533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__namespace_given_by_type, 2, 0, 0),
  [20535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1448),
  [20537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1484),
  [20539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1290),
  [20541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2167),
  [20543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [20545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1547),
  [20547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1451),
  [20549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__interpolated_string_start, 1, 0, 0),
  [20551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1550),
  [20553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1607),
  [20555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1552),
  [20557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1489),
  [20559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1609),
  [20561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1611),
  [20563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2176),
  [20565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1452),
  [20567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1493),
  [20569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [20571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15266),
  [20573] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_indented_cases_repeat1, 1, 0, 0),
  [20575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [20577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2076),
  [20579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [20581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_covariant_type_parameter, 2, 0, 16),
  [20583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2204),
  [20585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15370),
  [20587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3110),
  [20589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(887),
  [20591] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_contravariant_type_parameter, 2, 0, 16),
  [20593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variant_type_parameter, 2, 0, 0),
  [20595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1447),
  [20597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1114),
  [20599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1594),
  [20601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1211),
  [20603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [20605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1531),
  [20607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1235),
  [20609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1371),
  [20611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1247),
  [20613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [20615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15194),
  [20617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2181),
  [20619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(850),
  [20621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1535),
  [20623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [20625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15150),
  [20627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3832),
  [20629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [20631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15172),
  [20633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1618),
  [20635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1357),
  [20637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3834),
  [20639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [20641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [20643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1620),
  [20645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1622),
  [20647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__interpolated_multiline_string_start, 1, 0, 0),
  [20649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1360),
  [20651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variant_type_parameter, 2, 0, 16),
  [20653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1050),
  [20655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15234),
  [20657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12353),
  [20659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12127),
  [20661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [20663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1354),
  [20665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [20667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15121),
  [20669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1187),
  [20671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1628),
  [20673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [20675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(808),
  [20677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15314),
  [20679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1458),
  [20681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1144),
  [20683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2149),
  [20685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2197),
  [20687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1213),
  [20689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2094),
  [20691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1506),
  [20693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15005),
  [20695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15293),
  [20697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1375),
  [20699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15274),
  [20701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [20703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1538),
  [20705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3471),
  [20707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1425),
  [20709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1560),
  [20711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15182),
  [20713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1261),
  [20715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1295),
  [20717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1563),
  [20719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1300),
  [20721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1565),
  [20723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2189),
  [20725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1485),
  [20727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15328),
  [20729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15208),
  [20731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1378),
  [20733] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__indented_type_cases_repeat1, 1, 0, 0),
  [20735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1507),
  [20737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [20739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15055),
  [20741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1462),
  [20743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15322),
  [20745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [20747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1511),
  [20749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1629),
  [20751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1631),
  [20753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1633),
  [20755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1515),
  [20757] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bindings, 3, 0, 0),
  [20759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1490),
  [20761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1430),
  [20763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15222),
  [20765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1481),
  [20767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2158),
  [20769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variant_type_parameter, 1, 0, 0),
  [20771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [20773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1423),
  [20775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_lambda_repeat1, 2, 0, 16),
  [20777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [20779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1434),
  [20781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2211),
  [20783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [20785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [20787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [20789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1509),
  [20791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1513),
  [20793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1323),
  [20795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__dollar_escape, 2, 0, 0),
  [20797] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_types, 3, 1, 0),
  [20799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1405),
  [20801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3496),
  [20803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1548),
  [20805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1333),
  [20807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2111),
  [20809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1335),
  [20811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1319),
  [20813] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__aliased_interpolation_identifier, 1, 0, 0),
  [20815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolation, 2, 0, 0),
  [20817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2129),
  [20819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15105),
  [20821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [20823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1119),
  [20825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1641),
  [20827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1337),
  [20829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1573),
  [20831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1389),
  [20833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1643),
  [20835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1645),
  [20837] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_block_comment_repeat1, 1, 0, 0),
  [20839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1464),
  [20841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1575),
  [20843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1124),
  [20845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1577),
  [20847] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bindings, 4, 0, 0),
  [20849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [20851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [20853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1468),
  [20855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1471),
  [20857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1301),
  [20859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(820),
  [20861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1340),
  [20863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1322),
  [20865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [20867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1325),
  [20869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1283),
  [20871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1353),
  [20873] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arrow_renamed_identifier, 3, 0, 152),
  [20875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2041),
  [20877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1361),
  [20879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1367),
  [20881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(830),
  [20883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1372),
  [20885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15244),
  [20887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [20889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15285),
  [20891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1529),
  [20893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2119),
  [20895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15254),
  [20897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2387),
  [20899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1239),
  [20901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15138),
  [20903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [20905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [20907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1390),
  [20909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [20911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1399),
  [20913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1406),
  [20915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1534),
  [20917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1250),
  [20919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1252),
  [20921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1285),
  [20923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7915),
  [20925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14141),
  [20927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3435),
  [20929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1461),
  [20931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3436),
  [20933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7054),
  [20935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3438),
  [20937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8619),
  [20939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13251),
  [20941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10872),
  [20943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1173),
  [20945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9425),
  [20947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1922),
  [20949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9875),
  [20951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14870),
  [20953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1311),
  [20955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3580),
  [20957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9743),
  [20959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3581),
  [20961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3584),
  [20963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3585),
  [20965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9056),
  [20967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6908),
  [20969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11529),
  [20971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9565),
  [20973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2389),
  [20975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1837),
  [20977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7066),
  [20979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8395),
  [20981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10036),
  [20983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2023),
  [20985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5342),
  [20987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9127),
  [20989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13122),
  [20991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13561),
  [20993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1946),
  [20995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(870),
  [20997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6731),
  [20999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8064),
  [21001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1421),
  [21003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1541),
  [21005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14951),
  [21007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7430),
  [21009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9771),
  [21011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3613),
  [21013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10994),
  [21015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3616),
  [21017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3617),
  [21019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3618),
  [21021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4977),
  [21023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13046),
  [21025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9129),
  [21027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2390),
  [21029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13307),
  [21031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1445),
  [21033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7408),
  [21035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8668),
  [21037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10955),
  [21039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10907),
  [21041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7433),
  [21043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10029),
  [21045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1859),
  [21047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12394),
  [21049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9777),
  [21051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(873),
  [21053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11181),
  [21055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1544),
  [21057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5061),
  [21059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8577),
  [21061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15009),
  [21063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13132),
  [21065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(841),
  [21067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3644),
  [21069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9855),
  [21071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3647),
  [21073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3648),
  [21075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3649),
  [21077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8436),
  [21079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7707),
  [21081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14325),
  [21083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12399),
  [21085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2391),
  [21087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6652),
  [21089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10370),
  [21091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9882),
  [21093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8885),
  [21095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1385),
  [21097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7416),
  [21099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10919),
  [21101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5786),
  [21103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6505),
  [21105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10169),
  [21107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11253),
  [21109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13117),
  [21111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12040),
  [21113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1528),
  [21115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15083),
  [21117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8716),
  [21119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1907),
  [21121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3676),
  [21123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13213),
  [21125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3677),
  [21127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3680),
  [21129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3681),
  [21131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1549),
  [21133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2392),
  [21135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16058),
  [21137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5787),
  [21139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7717),
  [21141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10176),
  [21143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12400),
  [21145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8266),
  [21147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8184),
  [21149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5526),
  [21151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14610),
  [21153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14612),
  [21155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12553),
  [21157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10620),
  [21159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15164),
  [21161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13034),
  [21163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7197),
  [21165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3708),
  [21167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1411),
  [21169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3709),
  [21171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3710),
  [21173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3713),
  [21175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8053),
  [21177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2393),
  [21179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1858),
  [21181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8066),
  [21183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9434),
  [21185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1976),
  [21187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2371),
  [21189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7070),
  [21191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9139),
  [21193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8290),
  [21195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8686),
  [21197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7981),
  [21199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1426),
  [21201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3735),
  [21203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10831),
  [21205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3738),
  [21207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3739),
  [21209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3740),
  [21211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7880),
  [21213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1315),
  [21215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2394),
  [21217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4113),
  [21219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1280),
  [21221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6903),
  [21223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1554),
  [21225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5062),
  [21227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9746),
  [21229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16073),
  [21231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9447),
  [21233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7494),
  [21235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8036),
  [21237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7404),
  [21239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10552),
  [21241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5595),
  [21243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3764),
  [21245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3765),
  [21247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3767),
  [21249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3768),
  [21251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10788),
  [21253] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__braced_template_body2, 2, 0, 0),
  [21255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2395),
  [21257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9141),
  [21259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17630),
  [21261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12131),
  [21263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8321),
  [21265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1011),
  [21267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11060),
  [21269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2012),
  [21271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14594),
  [21273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2405),
  [21275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6057),
  [21277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7827),
  [21279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2408),
  [21281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9462),
  [21283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [21285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3785),
  [21287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3801),
  [21289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3803),
  [21291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3805),
  [21293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10670),
  [21295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2356),
  [21297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1557),
  [21299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9857),
  [21301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7503),
  [21303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8684),
  [21305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8060),
  [21307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6046),
  [21309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1952),
  [21311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7330),
  [21313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2401),
  [21315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7836),
  [21317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3196),
  [21319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3265),
  [21321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3358),
  [21323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3359),
  [21325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1639),
  [21327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9470),
  [21329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2396),
  [21331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__braced_template_body1, 2, 0, 0),
  [21333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__braced_template_body2, 4, 0, 0),
  [21335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6061),
  [21337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12423),
  [21339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13226),
  [21341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15544),
  [21343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6775),
  [21345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4270),
  [21347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1562),
  [21349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1505),
  [21351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9032),
  [21353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3526),
  [21355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3527),
  [21357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3715),
  [21359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3745),
  [21361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1583),
  [21363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3083),
  [21365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1098),
  [21367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5687),
  [21369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6125),
  [21371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12644),
  [21373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8063),
  [21375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7457),
  [21377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1925),
  [21379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13616),
  [21381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1999),
  [21383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3243),
  [21385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5834),
  [21387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1217),
  [21389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3368),
  [21391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3406),
  [21393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3413),
  [21395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3423),
  [21397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7007),
  [21399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3263),
  [21401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2358),
  [21403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5414),
  [21405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1879),
  [21407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3264),
  [21409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3270),
  [21411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1915),
  [21413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9036),
  [21415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14499),
  [21417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7690),
  [21419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8381),
  [21421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8707),
  [21423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12655),
  [21425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3135),
  [21427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3156),
  [21429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3166),
  [21431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3174),
  [21433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13526),
  [21435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2385),
  [21437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1833),
  [21439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6093),
  [21441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3522),
  [21443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5683),
  [21445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13408),
  [21447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1474),
  [21449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6777),
  [21451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7008),
  [21453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9040),
  [21455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7427),
  [21457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5628),
  [21459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13530),
  [21461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1567),
  [21463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3275),
  [21465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3315),
  [21467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3327),
  [21469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3344),
  [21471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12558),
  [21473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14635),
  [21475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2397),
  [21477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9037),
  [21479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5609),
  [21481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8090),
  [21483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8406),
  [21485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10148),
  [21487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12658),
  [21489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1351),
  [21491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13528),
  [21493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2353),
  [21495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6063),
  [21497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10549),
  [21499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3531),
  [21501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3579),
  [21503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3600),
  [21505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3612),
  [21507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10701),
  [21509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2352),
  [21511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8280),
  [21513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1254),
  [21515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13073),
  [21517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9721),
  [21519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6587),
  [21521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11201),
  [21523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1570),
  [21525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9960),
  [21527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10881),
  [21529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14195),
  [21531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3562),
  [21533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12372),
  [21535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3565),
  [21537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3138),
  [21539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3140),
  [21541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3144),
  [21543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3150),
  [21545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9530),
  [21547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1259),
  [21549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2354),
  [21551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8805),
  [21553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7586),
  [21555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7513),
  [21557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14442),
  [21559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8952),
  [21561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1220),
  [21563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9149),
  [21565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9996),
  [21567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7571),
  [21569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3118),
  [21571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13142),
  [21573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [21575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8008),
  [21577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3207),
  [21579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3209),
  [21581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3211),
  [21583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3216),
  [21585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3566),
  [21587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10728),
  [21589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2359),
  [21591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1574),
  [21593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1495),
  [21595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6087),
  [21597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6375),
  [21599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10187),
  [21601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8961),
  [21603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10010),
  [21605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7336),
  [21607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5356),
  [21609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8744),
  [21611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3286),
  [21613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3287),
  [21615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3307),
  [21617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3313),
  [21619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7578),
  [21621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2361),
  [21623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1321),
  [21625] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_opaque_modifier, 1, 0, 0),
  [21627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7551),
  [21629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6464),
  [21631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15642),
  [21633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4258),
  [21635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1435),
  [21637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1900),
  [21639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13201),
  [21641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8655),
  [21643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3371),
  [21645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3374),
  [21647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3376),
  [21649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3378),
  [21651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7623),
  [21653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11197),
  [21655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2362),
  [21657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1420),
  [21659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3450),
  [21661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8100),
  [21663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1158),
  [21665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5359),
  [21667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8676),
  [21669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6157),
  [21671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7644),
  [21673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3459),
  [21675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10199),
  [21677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9966),
  [21679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3442),
  [21681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3449),
  [21683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3452),
  [21685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3454),
  [21687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1539),
  [21689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3460),
  [21691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2364),
  [21693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3468),
  [21695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5631),
  [21697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16386),
  [21699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1579),
  [21701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13459),
  [21703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10746),
  [21705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8104),
  [21707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5361),
  [21709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9475),
  [21711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8625),
  [21713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8751),
  [21715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9605),
  [21717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3537),
  [21719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3540),
  [21721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3541),
  [21723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3542),
  [21725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1582),
  [21727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4842),
  [21729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2365),
  [21731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9571),
  [21733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10396),
  [21735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9487),
  [21737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13631),
  [21739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1392),
  [21741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6672),
  [21743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13372),
  [21745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7001),
  [21747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4843),
  [21749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10420),
  [21751] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [21753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13501),
  [21755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3641),
  [21757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3656),
  [21759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3659),
  [21761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3660),
  [21763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10798),
  [21765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10310),
  [21767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2366),
  [21769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9492),
  [21771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1853),
  [21773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8361),
  [21775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10442),
  [21777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1108),
  [21779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1585),
  [21781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8810),
  [21783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2355),
  [21785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5549),
  [21787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13235),
  [21789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5672),
  [21791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3748),
  [21793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3753),
  [21795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3757),
  [21797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3760),
  [21799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11796),
  [21801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1427),
  [21803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2368),
  [21805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9397),
  [21807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8162),
  [21809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8078),
  [21811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7339),
  [21813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1439),
  [21815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5016),
  [21817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1178),
  [21819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12619),
  [21821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1921),
  [21823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9173),
  [21825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3097),
  [21827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3116),
  [21829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3122),
  [21831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3125),
  [21833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8835),
  [21835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13237),
  [21837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2369),
  [21839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10352),
  [21841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8267),
  [21843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11814),
  [21845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8366),
  [21847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1264),
  [21849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10441),
  [21851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5019),
  [21853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11070),
  [21855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8648),
  [21857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8842),
  [21859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1847),
  [21861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3157),
  [21863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3158),
  [21865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3159),
  [21867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3161),
  [21869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [21871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1225),
  [21873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2398),
  [21875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10227),
  [21877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [21879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1293),
  [21881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9677),
  [21883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8274),
  [21885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11825),
  [21887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10235),
  [21889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8826),
  [21891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8753),
  [21893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3186),
  [21895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3187),
  [21897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3193),
  [21899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3194),
  [21901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1593),
  [21903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2373),
  [21905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5736),
  [21907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16000),
  [21909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6317),
  [21911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5227),
  [21913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10236),
  [21915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [21917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10250),
  [21919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1502),
  [21921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9706),
  [21923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12403),
  [21925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15428),
  [21927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3219),
  [21929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3222),
  [21931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3224),
  [21933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3226),
  [21935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1596),
  [21937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2377),
  [21939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11218),
  [21941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3608),
  [21943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3408),
  [21945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12674),
  [21947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6304),
  [21949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3611),
  [21951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3621),
  [21953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3624),
  [21955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10936),
  [21957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1041),
  [21959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3244),
  [21961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3251),
  [21963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3255),
  [21965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3256),
  [21967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9152),
  [21969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5229),
  [21971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2379),
  [21973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6513),
  [21975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1942),
  [21977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9327),
  [21979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10484),
  [21981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16076),
  [21983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1559),
  [21985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5867),
  [21987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10490),
  [21989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11193),
  [21991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8118),
  [21993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3288),
  [21995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3290),
  [21997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3297),
  [21999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3299),
  [22001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6306),
  [22003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6841),
  [22005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6673),
  [22007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9768),
  [22009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11569),
  [22011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12596),
  [22013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1601),
  [22015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11708),
  [22017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5871),
  [22019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8121),
  [22021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3331),
  [22023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3337),
  [22025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3338),
  [22027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3339),
  [22029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10495),
  [22031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6310),
  [22033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5604),
  [22035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6292),
  [22037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1987),
  [22039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9838),
  [22041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13363),
  [22043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1604),
  [22045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7556),
  [22047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10320),
  [22049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5605),
  [22051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3360),
  [22053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3365),
  [22055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3366),
  [22057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3367),
  [22059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9876),
  [22061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11530),
  [22063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9201),
  [22065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11219),
  [22067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15375),
  [22069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(849),
  [22071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2381),
  [22073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6801),
  [22075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2015),
  [22077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8322),
  [22079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3393),
  [22081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3395),
  [22083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3397),
  [22085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3400),
  [22087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1374),
  [22089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1608),
  [22091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1446),
  [22093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7065),
  [22095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8384),
  [22097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15139),
  [22099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4116),
  [22101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10466),
  [22103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10375),
  [22105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3427),
  [22107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3428),
  [22109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3429),
  [22111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3432),
  [22113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3817),
  [22115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7716),
  [22117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8454),
  [22119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3818),
  [22121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3819),
  [22123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1963),
  [22125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5268),
  [22127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10558),
  [22129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3820),
  [22131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7067),
  [22133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3456),
  [22135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3457),
  [22137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3462),
  [22139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3464),
  [22141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14383),
  [22143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8470),
  [22145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9175),
  [22147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10194),
  [22149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1328),
  [22151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10981),
  [22153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6176),
  [22155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1297),
  [22157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2360),
  [22159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1613),
  [22161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2009),
  [22163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3487),
  [22165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3488),
  [22167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3491),
  [22169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3494),
  [22171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5271),
  [22173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9566),
  [22175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9181),
  [22177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9419),
  [22179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10587),
  [22181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10239),
  [22183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12687),
  [22185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7575),
  [22187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11221),
  [22189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11709),
  [22191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [22193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1455),
  [22195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3518),
  [22197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3519),
  [22199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3524),
  [22201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3525),
  [22203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1616),
  [22205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1951),
  [22207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6492),
  [22209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8821),
  [22211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12611),
  [22213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9567),
  [22215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10841),
  [22217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9980),
  [22219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(822),
  [22221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10322),
  [22223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3545),
  [22225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3546),
  [22227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3547),
  [22229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3561),
  [22231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6506),
  [22233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9569),
  [22235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5849),
  [22237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8636),
  [22239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5660),
  [22241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1230),
  [22243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10052),
  [22245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3589),
  [22247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3593),
  [22249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3594),
  [22251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3597),
  [22253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9382),
  [22255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9582),
  [22257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1619),
  [22259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15299),
  [22261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11243),
  [22263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1617),
  [22265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7679),
  [22267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3628),
  [22269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3631),
  [22271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3633),
  [22273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3637),
  [22275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3103),
  [22277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5662),
  [22279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9589),
  [22281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3105),
  [22283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3107),
  [22285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10062),
  [22287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10488),
  [22289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3664),
  [22291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3669),
  [22293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3672),
  [22295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3673),
  [22297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3113),
  [22299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7733),
  [22301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7728),
  [22303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11710),
  [22305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7684),
  [22307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5586),
  [22309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3699),
  [22311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3700),
  [22313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3703),
  [22315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3704),
  [22317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9592),
  [22319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2363),
  [22321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14253),
  [22323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8499),
  [22325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1984),
  [22327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16342),
  [22329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3729),
  [22331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3730),
  [22333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3733),
  [22335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3734),
  [22337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12663),
  [22339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13068),
  [22341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9323),
  [22343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2028),
  [22345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3761),
  [22347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3762),
  [22349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3769),
  [22351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3780),
  [22353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12697),
  [22355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1996),
  [22357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5428),
  [22359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1332),
  [22361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10496),
  [22363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3814),
  [22365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3815),
  [22367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3816),
  [22369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3823),
  [22371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5584),
  [22373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1206),
  [22375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2569),
  [22377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3837),
  [22379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3838),
  [22381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3839),
  [22383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3084),
  [22385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8550),
  [22387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13429),
  [22389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1624),
  [22391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9531),
  [22393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3098),
  [22395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3099),
  [22397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3101),
  [22399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3108),
  [22401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9532),
  [22403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9481),
  [22405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1233),
  [22407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10033),
  [22409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5430),
  [22411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3126),
  [22413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3127),
  [22415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3128),
  [22417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3129),
  [22419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13241),
  [22421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10502),
  [22423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10997),
  [22425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8981),
  [22427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10567),
  [22429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6631),
  [22431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9896),
  [22433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1627),
  [22435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5593),
  [22437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9942),
  [22439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8413),
  [22441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6364),
  [22443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9906),
  [22445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13511),
  [22447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15392),
  [22449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5830),
  [22451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6643),
  [22453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7795),
  [22455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2404),
  [22457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5596),
  [22459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3145),
  [22461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8711),
  [22463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3146),
  [22465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3147),
  [22467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3148),
  [22469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12903),
  [22471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9909),
  [22473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8674),
  [22475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2351),
  [22477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12954),
  [22479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(884),
  [22481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14329),
  [22483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8829),
  [22485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9775),
  [22487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10645),
  [22489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9829),
  [22491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14194),
  [22493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1630),
  [22495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5160),
  [22497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5696),
  [22499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(899),
  [22501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [22503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5161),
  [22505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5627),
  [22507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10695),
  [22509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6380),
  [22511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6180),
  [22513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1454),
  [22515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6690),
  [22517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1832),
  [22519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6320),
  [22521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6553),
  [22523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1933),
  [22525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12668),
  [22527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7815),
  [22529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3472),
  [22531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8945),
  [22533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12961),
  [22535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1508),
  [22537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6605),
  [22539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2005),
  [22541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14848),
  [22543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5831),
  [22545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8073),
  [22547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(910),
  [22549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9853),
  [22551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9726),
  [22553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3176),
  [22555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3474),
  [22557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9949),
  [22559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3497),
  [22561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3178),
  [22563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5917),
  [22565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10715),
  [22567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8082),
  [22569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9849),
  [22571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3180),
  [22573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3182),
  [22575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8750),
  [22577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3502),
  [22579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8833),
  [22581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11531),
  [22583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10340),
  [22585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9971),
  [22587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2367),
  [22589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11240),
  [22591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1635),
  [22593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10711),
  [22595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10551),
  [22597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1459),
  [22599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13305),
  [22601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6004),
  [22603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5919),
  [22605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10724),
  [22607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6957),
  [22609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10761),
  [22611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1638),
  [22613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10775),
  [22615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9046),
  [22617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6008),
  [22619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13168),
  [22621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8949),
  [22623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6843),
  [22625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6964),
  [22627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10785),
  [22629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12962),
  [22631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7145),
  [22633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4578),
  [22635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8853),
  [22637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9983),
  [22639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1209),
  [22641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11114),
  [22643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1642),
  [22645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7149),
  [22647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6709),
  [22649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10548),
  [22651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12898),
  [22653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1274),
  [22655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7739),
  [22657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15160),
  [22659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9905),
  [22661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3213),
  [22663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9976),
  [22665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3215),
  [22667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3217),
  [22669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3218),
  [22671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8547),
  [22673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10574),
  [22675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10133),
  [22677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11930),
  [22679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1338),
  [22681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6696),
  [22683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1466),
  [22685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(853),
  [22687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2370),
  [22689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7335),
  [22691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2029),
  [22693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8834),
  [22695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6034),
  [22697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8644),
  [22699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10585),
  [22701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1990),
  [22703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8611),
  [22705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10058),
  [22707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1400),
  [22709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9957),
  [22711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7168),
  [22713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9081),
  [22715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [22717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10154),
  [22719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6920),
  [22721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14110),
  [22723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16810),
  [22725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14327),
  [22727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9310),
  [22729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10040),
  [22731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5110),
  [22733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8846),
  [22735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9348),
  [22737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14330),
  [22739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11940),
  [22741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [22743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1647),
  [22745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1238),
  [22747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7753),
  [22749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9059),
  [22751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7170),
  [22753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7622),
  [22755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10165),
  [22757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14032),
  [22759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1873),
  [22761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [22763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15948),
  [22765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15390),
  [22767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11506),
  [22769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6185),
  [22771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7624),
  [22773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14044),
  [22775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6330),
  [22777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9615),
  [22779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3245),
  [22781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10339),
  [22783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3246),
  [22785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3247),
  [22787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [22789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3249),
  [22791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9344),
  [22793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7139),
  [22795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2372),
  [22797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8776),
  [22799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6043),
  [22801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__braced_template_body1, 1, 0, 0),
  [22803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10827),
  [22805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1318),
  [22807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5111),
  [22809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16822),
  [22811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8851),
  [22813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11683),
  [22815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1129),
  [22817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13558),
  [22819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8394),
  [22821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14392),
  [22823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5056),
  [22825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1483),
  [22827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9354),
  [22829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(834),
  [22831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6360),
  [22833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6089),
  [22835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8435),
  [22837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8516),
  [22839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1475),
  [22841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9054),
  [22843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6806),
  [22845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13032),
  [22847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8612),
  [22849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11620),
  [22851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1404),
  [22853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7140),
  [22855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1937),
  [22857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1975),
  [22859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10182),
  [22861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16829),
  [22863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11958),
  [22865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9659),
  [22867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11128),
  [22869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15511),
  [22871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6362),
  [22873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1191),
  [22875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1304),
  [22877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6105),
  [22879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9194),
  [22881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3279),
  [22883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4465),
  [22885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [22887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12910),
  [22889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3281),
  [22891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14403),
  [22893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14176),
  [22895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3283),
  [22897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8500),
  [22899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9255),
  [22901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3285),
  [22903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9250),
  [22905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1967),
  [22907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5997),
  [22909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4796),
  [22911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6952),
  [22913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [22915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2374),
  [22917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [22919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1883),
  [22921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [22923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1422),
  [22925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1480),
  [22927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10926),
  [22929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10198),
  [22931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1224),
  [22933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14406),
  [22935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14193),
  [22937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [22939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11686),
  [22941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1478),
  [22943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [22945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2011),
  [22947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9881),
  [22949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2031),
  [22951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [22953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7720),
  [22955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [22957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11984),
  [22959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10451),
  [22961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4798),
  [22963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4427),
  [22965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1991),
  [22967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2567),
  [22969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10220),
  [22971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6962),
  [22973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4581),
  [22975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8697),
  [22977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2565),
  [22979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [22981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15795),
  [22983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8688),
  [22985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9730),
  [22987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3318),
  [22989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8933),
  [22991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7722),
  [22993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [22995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3320),
  [22997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [22999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3321),
  [23001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3322),
  [23003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8539),
  [23005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3276),
  [23007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [23009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1467),
  [23011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [23013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1488),
  [23015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1850),
  [23017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6965),
  [23019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [23021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8335),
  [23023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10882),
  [23025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2375),
  [23027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5874),
  [23029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8871),
  [23031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [23033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7790),
  [23035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9241),
  [23037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10576),
  [23039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9303),
  [23041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1919),
  [23043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(968),
  [23045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [23047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6502),
  [23049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1281),
  [23051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [23053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(994),
  [23055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8757),
  [23057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8934),
  [23059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7287),
  [23061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10884),
  [23063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6979),
  [23065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [23067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11688),
  [23069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8801),
  [23071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10083),
  [23073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5647),
  [23075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8487),
  [23077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3277),
  [23079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [23081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [23083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1852),
  [23085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1195),
  [23087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [23089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3294),
  [23091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [23093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1363),
  [23095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6887),
  [23097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6490),
  [23099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14977),
  [23101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9001),
  [23103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [23105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8505),
  [23107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7291),
  [23109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3349),
  [23111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10887),
  [23113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1843),
  [23115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [23117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8571),
  [23119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [23121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3351),
  [23123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3352),
  [23125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3296),
  [23127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3353),
  [23129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [23131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11322),
  [23133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1949),
  [23135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6300),
  [23137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2378),
  [23139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10008),
  [23141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [23143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8624),
  [23145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7783),
  [23147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8820),
  [23149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [23151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8596),
  [23153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10049),
  [23155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7816),
  [23157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8179),
  [23159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [23161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11053),
  [23163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10445),
  [23165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [23167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6345),
  [23169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1222),
  [23171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [23173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(858),
  [23175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9052),
  [23177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1409),
  [23179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11928),
  [23181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [23183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2376),
  [23185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10085),
  [23187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10930),
  [23189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5878),
  [23191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [23193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5649),
  [23195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8576),
  [23197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5907),
  [23199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8223),
  [23201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8649),
  [23203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [23205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14861),
  [23207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5057),
  [23209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15928),
  [23211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5991),
  [23213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8827),
  [23215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [23217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3381),
  [23219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1910),
  [23221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3382),
  [23223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [23225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3384),
  [23227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3386),
  [23229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5340),
  [23231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13527),
  [23233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5880),
  [23235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [23237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8895),
  [23239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1496),
  [23241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [23243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1081),
  [23245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8570),
  [23247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4244),
  [23249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11508),
  [23251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [23253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14160),
  [23255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1262),
  [23257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1286),
  [23259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8634),
  [23261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14031),
  [23263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [23265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6348),
  [23267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13570),
  [23269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10089),
  [23271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5882),
  [23273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1212),
  [23275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [23277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [23279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1885),
  [23281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7396),
  [23283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13943),
  [23285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1279),
  [23287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [23289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4082),
  [23291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11089),
  [23293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1501),
  [23295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1441),
  [23297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1871),
  [23299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [23301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8667),
  [23303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10268),
  [23305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8935),
  [23307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6861),
  [23309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11995),
  [23311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [23313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15104),
  [23315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7823),
  [23317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14092),
  [23319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8096),
  [23321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [23323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12936),
  [23325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3412),
  [23327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6898),
  [23329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3414),
  [23331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3415),
  [23333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [23335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3416),
  [23337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4254),
  [23339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10972),
  [23341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1292),
  [23343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [23345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10345),
  [23347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2382),
  [23349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6567),
  [23351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12124),
  [23353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [23355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6933),
  [23357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8948),
  [23359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(837),
  [23361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7231),
  [23363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6876),
  [23365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [23367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14017),
  [23369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9257),
  [23371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1518),
  [23373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9682),
  [23375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7826),
  [23377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [23379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7076),
  [23381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1898),
  [23383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [23385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1510),
  [23387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1243),
  [23389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8115),
  [23391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [23393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12671),
  [23395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2399),
  [23397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7236),
  [23399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10910),
  [23401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [23403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6746),
  [23405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [23407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__self_type_ascription, 2, 0, 0),
  [23409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17879),
  [23411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [23413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7639),
  [23415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15313),
  [23417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6578),
  [23419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1346),
  [23421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [23423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1308),
  [23425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3443),
  [23427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7654),
  [23429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8951),
  [23431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [23433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3444),
  [23435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3446),
  [23437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3448),
  [23439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12682),
  [23441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7240),
  [23443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [23445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9174),
  [23447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8106),
  [23449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11499),
  [23451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1317),
  [23453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [23455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10293),
  [23457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [23459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [23461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2383),
  [23463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [23465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1912),
  [23467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10933),
  [23469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13062),
  [23471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8133),
  [23473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [23475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8447),
  [23477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7211),
  [23479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1356),
  [23481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1930),
  [23483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6650),
  [23485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [23487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13986),
  [23489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13084),
  [23491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16010),
  [23493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7672),
  [23495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [23497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8237),
  [23499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13476),
  [23501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6219),
  [23503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [23505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8136),
  [23507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1329),
  [23509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7640),
  [23511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10348),
  [23513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [23515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15496),
  [23517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7166),
  [23519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3479),
  [23521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12173),
  [23523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [23525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13306),
  [23527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8058),
  [23529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3481),
  [23531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3482),
  [23533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [23535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [23537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3483),
  [23539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8389),
  [23541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8193),
  [23543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6424),
  [23545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [23547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6751),
  [23549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2384),
  [23551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7909),
  [23553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [23555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8537),
  [23557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1868),
  [23559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9421),
  [23561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [23563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8378),
  [23565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7212),
  [23567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10301),
  [23569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5676),
  [23571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [23573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10162),
  [23575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12749),
  [23577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15849),
  [23579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7921),
  [23581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [23583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6904),
  [23585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7676),
  [23587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6649),
  [23589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11515),
  [23591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [23593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1520),
  [23595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1523),
  [23597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1246),
  [23599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [23601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11847),
  [23603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7171),
  [23605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8241),
  [23607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1339),
  [23609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [23611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4260),
  [23613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15789),
  [23615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6441),
  [23617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8598),
  [23619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [23621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3510),
  [23623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12761),
  [23625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9138),
  [23627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7928),
  [23629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [23631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3512),
  [23633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3513),
  [23635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3514),
  [23637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__braced_template_body2, 3, 0, 0),
  [23639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [23641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [23643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [23645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [23647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [23649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [23651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [23653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [23655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [23657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [23659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [23661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [23663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [23665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [23667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [23669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [23671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [23673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [23675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [23677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [23679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [23681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [23683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [23685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [23687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [23689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [23691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [23693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [23695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [23697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [23699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [23701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [23703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [23705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [23707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [23709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [23711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [23713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [23715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [23717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [23719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [23721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [23723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [23725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [23727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [23729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [23731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [23733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [23735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [23737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [23739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [23741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [23743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1348),
  [23745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1525),
  [23747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8459),
  [23749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6111),
  [23751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [23753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1350),
  [23755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2386),
  [23757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14048),
  [23759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1880),
  [23761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11179),
  [23763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1358),
  [23765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13036),
  [23767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [23769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1001),
  [23771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9307),
  [23773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8405),
  [23775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1368),
  [23777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9090),
  [23779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8509),
  [23781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9300),
  [23783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1945),
  [23785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9833),
  [23787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12800),
  [23789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8414),
  [23791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11242),
  [23793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6499),
  [23795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5680),
  [23797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4968),
  [23799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1373),
  [23801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13315),
  [23803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12812),
  [23805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8421),
  [23807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9092),
  [23809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8477),
  [23811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1383),
  [23813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7621),
  [23815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3155),
  [23817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14787),
  [23819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1416),
  [23821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10789),
  [23823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8519),
  [23825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3410),
  [23827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3548),
  [23829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10259),
  [23831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3551),
  [23833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3552),
  [23835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1397),
  [23837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3553),
  [23839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9143),
  [23841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1381),
  [23843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1249),
  [23845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10546),
  [23847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11199),
  [23849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1533),
  [23851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2388),
  [23853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1979),
  [23855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12677),
  [23857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9858),
  [23859] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comment, 2, 0, 0),
  [23861] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block_comment, 2, 0, 0),
  [23863] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block_comment, 3, 0, 0),
  [23865] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 4, 0, 0),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token__automatic_semicolon = 0,
  ts_external_token__indent = 1,
  ts_external_token__interpolated_string_middle = 2,
  ts_external_token__interpolated_string_end = 3,
  ts_external_token__interpolated_multiline_string_middle = 4,
  ts_external_token__interpolated_multiline_string_end = 5,
  ts_external_token__outdent = 6,
  ts_external_token__simple_multiline_string = 7,
  ts_external_token__simple_string = 8,
  ts_external_token_else = 9,
  ts_external_token_catch = 10,
  ts_external_token_finally = 11,
  ts_external_token_extends = 12,
  ts_external_token_derives = 13,
  ts_external_token_with = 14,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token__automatic_semicolon] = sym__automatic_semicolon,
  [ts_external_token__indent] = sym__indent,
  [ts_external_token__interpolated_string_middle] = sym__interpolated_string_middle,
  [ts_external_token__interpolated_string_end] = sym__interpolated_string_end,
  [ts_external_token__interpolated_multiline_string_middle] = sym__interpolated_multiline_string_middle,
  [ts_external_token__interpolated_multiline_string_end] = sym__interpolated_multiline_string_end,
  [ts_external_token__outdent] = sym__outdent,
  [ts_external_token__simple_multiline_string] = sym__simple_multiline_string,
  [ts_external_token__simple_string] = sym__simple_string,
  [ts_external_token_else] = anon_sym_else,
  [ts_external_token_catch] = anon_sym_catch,
  [ts_external_token_finally] = anon_sym_finally,
  [ts_external_token_extends] = anon_sym_extends,
  [ts_external_token_derives] = anon_sym_derives,
  [ts_external_token_with] = anon_sym_with,
};

static const bool ts_external_scanner_states[74][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__indent] = true,
    [ts_external_token__interpolated_string_middle] = true,
    [ts_external_token__interpolated_string_end] = true,
    [ts_external_token__interpolated_multiline_string_middle] = true,
    [ts_external_token__interpolated_multiline_string_end] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_extends] = true,
    [ts_external_token_derives] = true,
    [ts_external_token_with] = true,
  },
  [2] = {
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
  },
  [3] = {
    [ts_external_token__indent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
  },
  [4] = {
    [ts_external_token__outdent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
  },
  [5] = {
    [ts_external_token__indent] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
  },
  [6] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [7] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [8] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
    [ts_external_token_finally] = true,
  },
  [9] = {
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [10] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
  },
  [11] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_finally] = true,
  },
  [12] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [13] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [14] = {
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
    [ts_external_token_finally] = true,
  },
  [15] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
    [ts_external_token_finally] = true,
  },
  [16] = {
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
  },
  [17] = {
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [18] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
  },
  [19] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
  },
  [20] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_finally] = true,
  },
  [21] = {
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_finally] = true,
  },
  [22] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
  },
  [23] = {
    [ts_external_token__automatic_semicolon] = true,
  },
  [24] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
  },
  [25] = {
    [ts_external_token__indent] = true,
  },
  [26] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [27] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [28] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_else] = true,
    [ts_external_token_finally] = true,
  },
  [29] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [30] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_else] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [31] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [32] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [33] = {
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [34] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_else] = true,
    [ts_external_token_with] = true,
  },
  [35] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_else] = true,
  },
  [36] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_finally] = true,
  },
  [37] = {
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [38] = {
    [ts_external_token_else] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [39] = {
    [ts_external_token_else] = true,
    [ts_external_token_finally] = true,
  },
  [40] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_with] = true,
  },
  [41] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [42] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [43] = {
    [ts_external_token_with] = true,
  },
  [44] = {
    [ts_external_token_else] = true,
    [ts_external_token_with] = true,
  },
  [45] = {
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [46] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [47] = {
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [48] = {
    [ts_external_token_else] = true,
  },
  [49] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [50] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_else] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [51] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_else] = true,
    [ts_external_token_finally] = true,
  },
  [52] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [53] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_with] = true,
  },
  [54] = {
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [55] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_else] = true,
    [ts_external_token_with] = true,
  },
  [56] = {
    [ts_external_token_finally] = true,
  },
  [57] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_else] = true,
  },
  [58] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_finally] = true,
  },
  [59] = {
    [ts_external_token__outdent] = true,
    [ts_external_token_with] = true,
  },
  [60] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_extends] = true,
    [ts_external_token_derives] = true,
  },
  [61] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_extends] = true,
    [ts_external_token_derives] = true,
  },
  [62] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_derives] = true,
    [ts_external_token_with] = true,
  },
  [63] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_derives] = true,
    [ts_external_token_with] = true,
  },
  [64] = {
    [ts_external_token__outdent] = true,
  },
  [65] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_derives] = true,
  },
  [66] = {
    [ts_external_token_derives] = true,
    [ts_external_token_with] = true,
  },
  [67] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_derives] = true,
  },
  [68] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_extends] = true,
  },
  [69] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_extends] = true,
  },
  [70] = {
    [ts_external_token_extends] = true,
    [ts_external_token_derives] = true,
  },
  [71] = {
    [ts_external_token_derives] = true,
  },
  [72] = {
    [ts_external_token__interpolated_string_middle] = true,
    [ts_external_token__interpolated_string_end] = true,
  },
  [73] = {
    [ts_external_token__interpolated_multiline_string_middle] = true,
    [ts_external_token__interpolated_multiline_string_end] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_scala_external_scanner_create(void);
void tree_sitter_scala_external_scanner_destroy(void *);
bool tree_sitter_scala_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_scala_external_scanner_serialize(void *, char *);
void tree_sitter_scala_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_scala(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym__alpha_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_scala_external_scanner_create,
      tree_sitter_scala_external_scanner_destroy,
      tree_sitter_scala_external_scanner_scan,
      tree_sitter_scala_external_scanner_serialize,
      tree_sitter_scala_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
